\qt@newcmd\qurantrans@ur@i{اللہ کے نام سےشروع جو نہایت مہربان ہمیشہ رحم فرمانےوالا ہے ‎\qt@no{1}}%
\qt@newcmd\qurantrans@ur@ii{سب تعریفیں اللہ ہی کے لئے ہیں جو تمام جہانوں کی پرورش فرمانے والا ہے\qt@no{2}}%
\qt@newcmd\qurantrans@ur@iii{نہایت مہربان بہت رحم فرمانے والا ہے\qt@no{3}}%
\qt@newcmd\qurantrans@ur@iv{روزِ جزا کا مالک ہے\qt@no{4}}%
\qt@newcmd\qurantrans@ur@v{اے اللہ!) ہم تیری ہی عبادت کرتے ہیں اور ہم تجھ ہی سے مدد چاہتے ہیں\qt@no{5}}%
\qt@newcmd\qurantrans@ur@vi{ہمیں سیدھا راستہ دکھا\qt@no{6}}%
\qt@newcmd\qurantrans@ur@vii{ان لوگوں کا راستہ جن پر تو نے انعام فرمایا ان لوگوں کا نہیں جن پر غضب کیا گیا ہے اور نہ (ہی) گمراہوں کا\qt@no{7}}%
\qt@newcmd\qurantrans@ur@viii{\basmalahur الف لام میم (حقیقی معنی اﷲ اور رسول صلی اللہ علیہ وآلہ وسلم ہی بہتر جانتے ہیں)\qt@no{1}}%
\qt@newcmd\qurantrans@ur@ix{یہ) وہ عظیم کتاب ہے جس میں کسی شک کی گنجائش نہیں، (یہ) پرہیزگاروں کے لئے ہدایت ہے،\qt@no{2}}%
\qt@newcmd\qurantrans@ur@x{جو غیب پر ایمان لاتے اور نماز کو (تمام حقوق کے ساتھ) قائم کرتے ہیں اور جو کچھ ہم نے انہیں عطا کیا ہے اس میں سے (ہماری راہ) میں خرچ کرتے ہیں،\qt@no{3}}%
\qt@newcmd\qurantrans@ur@xi{اور وہ لوگ جو آپ کی طرف نازل کیا گیا اور جو آپ سے پہلے نازل کیا گیا (سب) پر ایمان لاتے ہیں، اور وہ آخرت پر بھی (کامل) یقین رکھتے ہیں،\qt@no{4}}%
\qt@newcmd\qurantrans@ur@xii{وہی اپنے رب کی طرف سے ہدایت پر ہیں اور وہی حقیقی کامیابی پانے والے ہیں،\qt@no{5}}%
\qt@newcmd\qurantrans@ur@xiii{بیشک جنہوں نے کفر اپنا لیا ہے ان کے لئے برابر ہے خواہ آپ انہیں ڈرائیں یا نہ ڈرائیں، وہ ایمان نہیں لائیں گے،\qt@no{6}}%
\qt@newcmd\qurantrans@ur@xiv{اللہ نے (ان کے اپنے اِنتخاب کے نتیجے میں) ان کے دلوں اور کانوں پر مُہر لگا دی ہے اور ان کی آنکھوں پر پردہ (پڑ گیا) ہے اور ان کے لئے سخت عذاب ہے،\qt@no{7}}%
\qt@newcmd\qurantrans@ur@xv{اور لوگوں میں سے بعض وہ (بھی) ہیں جو کہتے ہیں ہم اللہ پر اور یومِ قیامت پر ایمان لائے حالانکہ وہ (ہرگز) مومن نہیں ہیں،\qt@no{8}}%
\qt@newcmd\qurantrans@ur@xvi{وہ اللہ کو (یعنی رسول صلی اللہ علیہ وآلہ وسلم کو)٭ اور ایمان والوں کو دھوکہ دینا چاہتے ہیں مگر (فی الحقیقت) وہ اپنے آپ کو ہی دھوکہ دے رہے ہیں اور انہیں اس کا شعور نہیں ہے، ٭ اس مقام پر مضاف محذوف ہے جو کہ رسول ہے یعنی یُخٰدِعُونَ اﷲَ کہہ کر مراد یُخٰدِعُونَ رَسُولَ اﷲِ لیا گیا ہے۔ اکثر ائمہ مفسرین نے یہ معنی بیان کیا ہے۔ بطور حوالہ ملاحظہ فرمائیں (تفسیر القرطبی، البیضاوی، البغوی، النسفی، الکشاف، المظھری، زاد المسیر، الخازن وغیرھم)۔\qt@no{9}}%
\qt@newcmd\qurantrans@ur@xvii{ان کے دلوں میں بیماری ہے، پس اللہ نے ان کی بیماری کو اور بڑھا دیا اور ان کے لئے دردناک عذاب ہے۔ اس وجہ سے کہ وہ جھوٹ بولتے تھے،\qt@no{10}}%
\qt@newcmd\qurantrans@ur@xviii{اور جب ان سے کہا جاتا ہے کہ زمین میں فساد بپا نہ کرو، تو کہتے ہیں: ہم ہی تو اصلاح کرنے والے ہیں،\qt@no{11}}%
\qt@newcmd\qurantrans@ur@xix{آگاہ ہو جاؤ! یہی لوگ (حقیقت میں) فساد کرنے والے ہیں مگر انہیں (اس کا) احساس تک نہیں،\qt@no{12}}%
\qt@newcmd\qurantrans@ur@xx{اور جب ان سے کہا جاتا ہے کہ (تم بھی) ایمان لاؤ جیسے (دوسرے) لوگ ایمان لے آئے ہیں، تو کہتے ہیں: کیا ہم بھی (اسی طرح) ایمان لے آئیں جس طرح (وہ) بیوقوف ایمان لے آئے، جان لو! بیوقوف (درحقیقت) وہ خود ہیں لیکن انہیں (اپنی بیوقوفی اور ہلکے پن کا) علم نہیں،\qt@no{13}}%
\qt@newcmd\qurantrans@ur@xxi{اور جب وہ (منافق) اہل ایمان سے ملتے ہیں تو کہتے ہیں: ہم (بھی) ایمان لے آئے ہیں، اور جب اپنے شیطانوں سے تنہائی میں ملتے ہیں تو کہتے ہیں: ہم یقیناً تمہارے ساتھ ہیں، ہم (مسلمانوں کا تو) محض مذاق اڑاتے ہیں،\qt@no{14}}%
\qt@newcmd\qurantrans@ur@xxii{اللہ انہیں ان کے مذاق کی سزا دیتا ہے اور انہیں ڈھیل دیتا ہے (تاکہ وہ خود اپنے انجام تک جا پہنچیں) سو وہ خود اپنی سرکشی میں بھٹک رہے ہیں،\qt@no{15}}%
\qt@newcmd\qurantrans@ur@xxiii{یہی وہ لوگ ہیں جنہوں نے ہدایت کے بدلے گمراہی خریدی لیکن ان کی تجارت فائدہ مند نہ ہوئی اور وہ (فائدہ مند اور نفع بخش سودے کی) راہ جانتے ہی نہ تھے،\qt@no{16}}%
\qt@newcmd\qurantrans@ur@xxiv{ان کی مثال ایسے شخص کی مانند ہے جس نے (تاریک ماحول میں) آگ جلائی اور جب اس نے گرد و نواح کو روشن کر دیا تو اللہ نے ان کا نور سلب کر لیا اور انہیں تاریکیوں میں چھوڑ دیا اب وہ کچھ نہیں دیکھتے،\qt@no{17}}%
\qt@newcmd\qurantrans@ur@xxv{یہ بہرے، گونگے (اور) اندھے ہیں پس وہ (راہِ راست کی طرف) نہیں لوٹیں گے،\qt@no{18}}%
\qt@newcmd\qurantrans@ur@xxvi{یا ان کی مثال اس بارش کی سی ہے جو آسمان سے برس رہی ہے جس میں اندھیریاں ہیں اور گرج اور چمک (بھی) ہے تو وہ کڑک کے باعث موت کے ڈر سے اپنے کانوں میں انگلیاں ٹھونس لیتے ہیں، اور اللہ کافروں کو گھیرے ہوئے ہے،\qt@no{19}}%
\qt@newcmd\qurantrans@ur@xxvii{یوں لگتا ہے کہ بجلی ان کی بینائی اُچک لے جائے گی، جب بھی ان کے لئے (ماحول میں) کچھ چمک ہوتی ہے تو اس میں چلنے لگتے ہیں اور جب ان پر اندھیرا چھا جاتا ہے تو کھڑے ہو جاتے ہیں، اور اگر اللہ چاہتا تو ان کی سماعت اور بصارت بالکل سلب کر لیتا، بیشک اللہ ہر چیز پر قادر ہے،\qt@no{20}}%
\qt@newcmd\qurantrans@ur@xxviii{اے لوگو! اپنے رب کی عبادت کرو جس نے تمہیں پیدا کیا اور ان لوگوں کو (بھی) جو تم سے پیشتر تھے تاکہ تم پرہیزگار بن جاؤ،\qt@no{21}}%
\qt@newcmd\qurantrans@ur@xxix{جس نے تمہارے لئے زمین کو فرش اور آسمان کو عمارت بنایا اور آسمانوں کی طرف سے پانی برسایا پھر اس کے ذریعے تمہارے کھانے کے لئے (انواع و اقسام کے) پھل پیدا کئے، پس تم اللہ کے لئے شریک نہ ٹھہراؤ حالانکہ تم (حقیقتِ حال) جانتے ہو،\qt@no{22}}%
\qt@newcmd\qurantrans@ur@xxx{اور اگر تم اس (کلام) کے بارے میں شک میں مبتلا ہو جو ہم نے اپنے (برگزیدہ) بندے پر نازل کیا ہے تو اس جیسی کوئی ایک سورت ہی بنا لاؤ، اور (اس کام کے لئے بیشک) اللہ کے سوا اپنے (سب) حمائتیوں کو بلا لو اگر تم (اپنے شک اور انکار میں) سچے ہو،\qt@no{23}}%
\qt@newcmd\qurantrans@ur@xxxi{پھر اگر تم ایسا نہ کر سکو اور ہرگز نہ کر سکو گے تو اس آگ سے بچو جس کا ایندھن آدمی (یعنی کافر) اور پتھر (یعنی ان کے بت) ہیں، جو کافروں کے لئے تیار کی گئی ہے،\qt@no{24}}%
\qt@newcmd\qurantrans@ur@xxxii{اور (اے حبیب!) آپ ان لوگوں کو خوشخبری سنا دیں جو ایمان لائے اور نیک عمل کرتے رہے کہ ان کے لئے (بہشت کے) باغات ہیں جن کے نیچے نہریں بہتی ہیں، جب انہیں ان باغات میں سے کوئی پھل کھانے کو دیا جائے گا تو (اس کی ظاہری صورت دیکھ کر) کہیں گے: یہ تو وہی پھل ہے جو ہمیں (دنیا میں) پہلے دیا گیا تھا، حالانکہ انہیں (صورت میں) ملتے جلتے پھل دیئے گئے ہوں گے، ان کے لئے جنت میں پاکیزہ بیویاں (بھی) ہوں گی اور وہ ان میں ہمیشہ رہیں گے،\qt@no{25}}%
\qt@newcmd\qurantrans@ur@xxxiii{بیشک اللہ اس بات سے نہیں شرماتا کہ (سمجھانے کے لئے) کوئی بھی مثال بیان فرمائے (خواہ) مچھر کی ہو یا (ایسی چیز کی جو حقارت میں) اس سے بھی بڑھ کر ہو، تو جو لوگ ایمان لائے وہ خوب جانتے ہیں کہ یہ مثال ان کے رب کی طرف سے حق (کی نشاندہی) ہے، اور جنہوں نے کفر اختیار کیا وہ (اسے سن کر یہ) کہتے ہیں کہ ایسی تمثیل سے اللہ کو کیا سروکار؟ (اس طرح) اللہ ایک ہی بات کے ذریعے بہت سے لوگوں کو گمراہ ٹھہراتا ہے اور بہت سے لوگوں کو ہدایت دیتا ہے اور اس سے صرف انہی کو گمراہی میں ڈالتا ہے جو (پہلے ہی) نافرمان ہیں،\qt@no{26}}%
\qt@newcmd\qurantrans@ur@xxxiv{یہ نافرمان وہ لوگ ہیں) جو اللہ کے عہد کو اس سے پختہ کرنے کے بعد توڑتے ہیں، اور اس (تعلق) کو کاٹتے ہیں جس کو اللہ نے جوڑنے کا حکم دیا ہے اور زمین میں فساد بپا کرتے ہیں، یہی لوگ نقصان اٹھانے والے ہیں،\qt@no{27}}%
\qt@newcmd\qurantrans@ur@xxxv{تم کس طرح اللہ کا انکار کرتے ہو حالانکہ تم بے جان تھے اس نے تمہیں زندگی بخشی، پھر تمہیں موت سے ہمکنار کرے گا اور پھر تمہیں زندہ کرے گا، پھر تم اسی کی طرف لوٹائے جاؤ گے،\qt@no{28}}%
\qt@newcmd\qurantrans@ur@xxxvi{وہی ہے جس نے سب کچھ جو زمین میں ہے تمہارے لئے پیدا کیا، پھر وہ (کائنات کے) بالائی حصوں کی طرف متوجہ ہوا تو اس نے انہیں درست کر کے ان کے سات آسمانی طبقات بنا دیئے، اور وہ ہر چیز کا جاننے والا ہے،\qt@no{29}}%
\qt@newcmd\qurantrans@ur@xxxvii{اور (وہ وقت یاد کریں) جب آپ کے رب نے فرشتوں سے فرمایا کہ میں زمین میں اپنا نائب بنانے والا ہوں، انہوں نے عرض کیا: کیا تُو زمین میں کسی ایسے شخص کو (نائب) بنائے گا جو اس میں فساد انگیزی کرے گا اور خونریزی کرے گا؟ حالانکہ ہم تیری حمد کے ساتھ تسبیح کرتے رہتے ہیں اور (ہمہ وقت) پاکیزگی بیان کرتے ہیں، (اللہ نے) فرمایا: میں وہ کچھ جانتا ہوں جو تم نہیں جانتے،\qt@no{30}}%
\qt@newcmd\qurantrans@ur@xxxviii{اور اللہ نے آدم (علیہ السلام) کو تمام (اشیاء کے) نام سکھا دیئے پھر انہیں فرشتوں کے سامنے پیش کیا، اور فرمایا: مجھے ان اشیاء کے نام بتا دو اگر تم (اپنے خیال میں) سچے ہو،\qt@no{31}}%
\qt@newcmd\qurantrans@ur@xxxix{فرشتوں نے عرض کیا: تیری ذات (ہر نقص سے) پاک ہے ہمیں کچھ علم نہیں مگر اسی قدر جو تو نے ہمیں سکھایا ہے، بیشک تو ہی (سب کچھ) جاننے والا حکمت والا ہے،\qt@no{32}}%
\qt@newcmd\qurantrans@ur@xl{اللہ نے فرمایا: اے آدم! (اب تم) انہیں ان اشیاء کے ناموں سے آگاہ کرو، پس جب آدم (علیہ السلام) نے انہیں ان اشیاء کے ناموں سے آگاہ کیا تو (اللہ نے) فرمایا: کیا میں نے تم سے نہیں کہا تھا کہ میں آسمانوں اور زمین کی (سب) مخفی حقیقتوں کو جانتا ہوں، اور وہ بھی جانتا ہوں جو تم ظاہر کرتے ہو اور جو تم چھپاتے ہو،\qt@no{33}}%
\qt@newcmd\qurantrans@ur@xli{اور (وہ وقت بھی یاد کریں) جب ہم نے فرشتوں سے فرمایا کہ آدم (علیہ السلام) کو سجدہ کرو تو سب نے سجدہ کیا سوائے ابلیس کے، اس نے انکار اور تکبر کیا اور (نتیجۃً) کافروں میں سے ہو گیا،\qt@no{34}}%
\qt@newcmd\qurantrans@ur@xlii{اور ہم نے حکم دیا: اے آدم! تم اور تمہاری بیوی اس جنت میں رہائش رکھو اور تم دونوں اس میں سے جو چاہو، جہاں سے چاہو کھاؤ، مگر اس درخت کے قریب نہ جانا ورنہ حد سے بڑھنے والوں میں (شامل) ہو جاؤ گے،\qt@no{35}}%
\qt@newcmd\qurantrans@ur@xliii{پھر شیطان نے انہیں اس جگہ سے ہلا دیا اور انہیں اس (راحت کے) مقام سے جہاں وہ تھے الگ کر دیا، اور (بالآخر) ہم نے حکم دیا کہ تم نیچے اتر جاؤ، تم ایک دوسرے کے دشمن رہو گے۔ اب تمہارے لئے زمین میں ہی معیّنہ مدت تک جائے قرار ہے اور نفع اٹھانا مقدّر کر دیا گیا ہے،\qt@no{36}}%
\qt@newcmd\qurantrans@ur@xliv{پھر آدم (علیہ السلام) نے اپنے رب سے (عاجزی اور معافی کے) چند کلمات سیکھ لئے پس اللہ نے ان کی توبہ قبول فرما لی، بیشک وہی بہت توبہ قبول کرنے والا مہربان ہے،\qt@no{37}}%
\qt@newcmd\qurantrans@ur@xlv{ہم نے فرمایا: تم سب جنت سے اتر جاؤ، پھر اگر تمہارے پاس میری طرف سے کوئی ہدایت پہنچے تو جو بھی میری ہدایت کی پیروی کرے گا، نہ ان پر کوئی خوف (طاری) ہوگا اور نہ وہ غمگین ہوں گے،\qt@no{38}}%
\qt@newcmd\qurantrans@ur@xlvi{اور جو لوگ کفر کریں گے اور ہماری آیتوں کو جھٹلائیں گے تو وہی دوزخی ہوں گی، وہ اس میں ہمیشہ رہیں گے،\qt@no{39}}%
\qt@newcmd\qurantrans@ur@xlvii{اے اولادِ یعقوب! میرے وہ انعام یاد کرو جو میں نے تم پر کئے اور تم میرے (ساتھ کیا ہوا) وعدہ پورا کرو میں تمہارے (ساتھ کیا ہوا) وعدہ پورا کروں گا، اور مجھ ہی سے ڈرا کرو،\qt@no{40}}%
\qt@newcmd\qurantrans@ur@xlviii{اور اس (کتاب) پر ایمان لاؤ جو میں نے (اپنے رسول محمد صلی اللہ علیہ وآلہ وسلم پر) اتاری (ہے، حالانکہ) یہ اس کی (اصلاً) تصدیق کرتی ہے جو تمہارے پاس ہے اور تم ہی سب سے پہلے اس کے منکر نہ بنو اور میری آیتوں کو (دنیا کی) تھوڑی سی قیمت پر فروخت نہ کرو اور مجھ ہی سے ڈرتے رہو،\qt@no{41}}%
\qt@newcmd\qurantrans@ur@xlix{اور حق کی آمیزش باطل کے ساتھ نہ کرو اور نہ ہی حق کو جان بوجھ کر چھپاؤ،\qt@no{42}}%
\qt@newcmd\qurantrans@ur@l{اور نماز قائم رکھو اور زکوٰۃ دیا کرو اور رکوع کرنے والوں کے ساتھ (مل کر) رکوع کیا کرو،\qt@no{43}}%
\qt@newcmd\qurantrans@ur@li{کیا تم دوسرے لوگوں کو نیکی کا حکم دیتے ہو اور اپنے آپ کو بھول جاتے ہو حالانکہ تم (اللہ کی) کتاب (بھی) پڑھتے ہو، تو کیا تم نہیں سوچتے؟،\qt@no{44}}%
\qt@newcmd\qurantrans@ur@lii{اور صبر اور نماز کے ذریعے (اللہ سے) مدد چاہو، اور بیشک یہ گراں ہے مگر (ان) عاجزوں پر (ہرگز) نہیں (جن کے دل محبتِ الٰہی سے خستہ اور خشیتِ الٰہی سے شکستہ ہیں)،\qt@no{45}}%
\qt@newcmd\qurantrans@ur@liii{یہ وہ لوگ ہیں) جو یقین رکھتے ہیں کہ وہ اپنے رب سے ملاقات کرنے والے ہیں اور وہ اسی کی طرف لوٹ کر جانے والے ہیں،\qt@no{46}}%
\qt@newcmd\qurantrans@ur@liv{اے اولادِ یعقوب! میرے وہ انعام یاد کرو جو میں نے تم پر کئے اور یہ کہ میں نے تمہیں (اس زمانے میں) سب لوگوں پر فضیلت دی،\qt@no{47}}%
\qt@newcmd\qurantrans@ur@lv{اور اُس دن سے ڈرو جس دن کوئی جان کسی دوسرے کی طرف سے کچھ بدلہ نہ دے سکے گی اور نہ اس کی طرف سے (کسی ایسے شخص کی) کوئی سفارش قبول کی جائے گی (جسے اِذنِ اِلٰہی حاصل نہ ہوگا) اور نہ اس کی طرف سے (جان چھڑانے کے لئے) کوئی معاوضہ قبول کیا جائے گا اور نہ (اَمرِ الٰہی کے خلاف) ان کی اِمداد کی جا سکے گی،\qt@no{48}}%
\qt@newcmd\qurantrans@ur@lvi{اور (وہ وقت بھی یاد کرو) جب ہم نے تمہیں قومِ فرعون سے نجات بخشی جو تمہیں انتہائی سخت عذاب دیتے تھے تمہارے بیٹوں کو ذبح کرتے اور تمہاری بیٹیوں کو زندہ رکھتے تھے، اور اس میں تمہارے پروردگار کی طرف سے بڑی (کڑی) آزمائش تھی،\qt@no{49}}%
\qt@newcmd\qurantrans@ur@lvii{اور جب ہم نے تمہیں (بچانے کے) لئے دریا کو پھاڑ دیا سو ہم نے تمہیں (اس طرح) نجات عطا کی اور (دوسری طرف) ہم نے تمہاری آنکھوں کے سامنے قومِ فرعون کو غرق کر دیا،\qt@no{50}}%
\qt@newcmd\qurantrans@ur@lviii{اور (وہ وقت بھی یاد کرو) جب ہم نے موسیٰ (علیہ السلام) سے چالیس راتوں کا وعدہ فرمایا تھا پھر تم نے موسیٰ (علیہ السلام کے چلّہءِ اعتکاف میں جانے) کے بعد بچھڑے کو (اپنا) معبود بنا لیا اور تم واقعی بڑے ظالم تھے،\qt@no{51}}%
\qt@newcmd\qurantrans@ur@lix{پھر ہم نے اس کے بعد (بھی) تمہیں معاف کر دیا تاکہ تم شکرگزار ہو جاؤ،\qt@no{52}}%
\qt@newcmd\qurantrans@ur@lx{اور جب ہم نے موسیٰ (علیہ السلام) کو کتاب اور حق و باطل میں فرق کرنے والا (معجزہ) عطا کیا تاکہ تم راہِ ہدایت پاؤ،\qt@no{53}}%
\qt@newcmd\qurantrans@ur@lxi{اور جب موسیٰ (علیہ السلام) نے اپنی قوم سے کہا: اے میری قوم! بیشک تم نے بچھڑے کو (اپنا معبود) بنا کر اپنی جانوں پر (بڑا) ظلم کیا ہے، تو اب اپنے پیدا فرمانے والے (حقیقی رب) کے حضور توبہ کرو، پس (آپس میں) ایک دوسرے کو قتل کر ڈالو (اس طرح کہ جنہوں نے بچھڑے کی پرستش نہیں کی اور اپنے دین پر قائم رہے ہیں وہ بچھڑے کی پرستش کر کے دین سے پھر جانے والوں کو سزا کے طور پر قتل کر دیں)، یہی (عمل) تمہارے لئے تمہارے خالق کے نزدیک بہترین (توبہ) ہے، پھر اس نے تمہاری توبہ قبول فرما لی، یقینا وہ بڑا ہی توبہ قبول کرنے والا مہربان ہے،\qt@no{54}}%
\qt@newcmd\qurantrans@ur@lxii{اور جب تم نے کہا: اے موسیٰ! ہم آپ پر ہرگز ایمان نہ لائیں گے یہاں تک کہ ہم اللہ کو (آنکھوں کے سامنے) بالکل آشکارا دیکھ لیں پس (اس پر) تمہیں کڑک نے آلیا (جو تمہاری موت کا باعث بن گئی) اور تم (خود یہ منظر) دیکھتے رہے،\qt@no{55}}%
\qt@newcmd\qurantrans@ur@lxiii{پھر ہم نے تمہارے مرنے کے بعد تمہیں (دوبارہ) زندہ کیا تاکہ تم (ہمارا) شکر ادا کرو،\qt@no{56}}%
\qt@newcmd\qurantrans@ur@lxiv{اور (یاد کرو) جب ہم نے تم پر (وادئ تِیہ میں) بادل کا سایہ کئے رکھا اور ہم نے تم پر مَنّ و سلوٰی اتارا کہ تم ہماری عطا کی ہوئی پاکیزہ چیزوں میں سے کھاؤ، سو انہوں نے (نافرمانی اور ناشکری کر کے) ہمارا کچھ نہیں بگاڑا مگر اپنی ہی جانوں پر ظلم کرتے رہے،\qt@no{57}}%
\qt@newcmd\qurantrans@ur@lxv{اور (یاد کرو) جب ہم نے فرمایا: اس شہر میں داخل ہو جاؤ اور اس میں جہاں سے چاہو خوب جی بھر کے کھاؤ اور (یہ کہ شہر کے) دروازے میں سجدہ کرتے ہوئے داخل ہونا اور یہ کہتے جانا: (اے ہمارے رب! ہم سب خطاؤں کی) بخشش چاہتے ہیں، (تو) ہم تمہاری (گزشتہ) خطائیں معاف فرما دیں گے، اور (علاوہ اس کے) نیکوکاروں کو مزید (لطف و کرم سے) نوازیں گے،\qt@no{58}}%
\qt@newcmd\qurantrans@ur@lxvi{پھر (ان) ظالموں نے اس قول کو جو ان سے کہا گیا تھا ایک اور کلمہ سے بدل ڈالا سو ہم نے (ان) ظالموں پر آسمان سے (بصورتِ طاعون) سخت آفت اتار دی اس وجہ سے کہ وہ (مسلسل) حکم عدولی کر رہے تھے،\qt@no{59}}%
\qt@newcmd\qurantrans@ur@lxvii{اور (وہ وقت بھی یا دکرو) جب موسیٰ (علیہ السلام) نے اپنی قوم کے لئے پانی مانگا تو ہم نے فرمایا: اپنا عصا اس پتھر پر مارو، پھر اس (پتھر) سے بارہ چشمے پھوٹ پڑے، واقعۃً ہر گروہ نے اپنا اپنا گھاٹ پہچان لیا، (ہم نے فرمایا:) اﷲ کے (عطا کردہ) رزق میں سے کھاؤ اور پیو لیکن زمین میں فساد انگیزی نہ کرتے پھرو،\qt@no{60}}%
\qt@newcmd\qurantrans@ur@lxviii{اور جب تم نے کہا: اے موسیٰ! ہم فقط ایک کھانے (یعنی منّ و سلویٰ) پر ہرگز صبر نہیں کر سکتے تو آپ اپنے رب سے (ہمارے حق میں) دعا کیجئے کہ وہ ہمارے لئے زمین سے اگنے والی چیزوں میں سے ساگ اور ککڑی اور گیہوں اور مسور اور پیاز پیدا کر دے، (موسیٰ علیہ السلام نے اپنی قوم سے) فرمایا: کیا تم اس چیز کو جو ادنیٰ ہے بہتر چیز کے بدلے مانگتے ہو؟ (اگر تمہاری یہی خواہش ہے تو) کسی بھی شہر میں جا اترو یقیناً (وہاں) تمہارے لئے وہ کچھ (میسر) ہو گا جو تم مانگتے ہو، اور ان پر ذلّت اور محتاجی مسلط کر دی گئی، اور وہ اللہ کے غضب میں لوٹ گئے، یہ اس وجہ سے (ہوا) کہ وہ اللہ کی آیتوں کا انکار کیا کرتے اور انبیاء کو ناحق قتل کرتے تھے، اور یہ اس وجہ سے بھی ہوا کہ وہ نافرمانی کیا کرتے اور (ہمیشہ) حد سے بڑھ جاتے تھے،\qt@no{61}}%
\qt@newcmd\qurantrans@ur@lxix{بیشک جو لوگ ایمان لائے اور جو یہودی ہوئے اور (جو) نصاریٰ اور صابی (تھے ان میں سے) جو (بھی) اللہ پر اور آخرت کے دن پر ایمان لایا اور اس نے اچھے عمل کئے، تو ان کے لئے ان کے رب کے ہاں ان کا اجر ہے، ان پر نہ کوئی خوف ہوگا اور نہ وہ رنجیدہ ہوں گے،\qt@no{62}}%
\qt@newcmd\qurantrans@ur@lxx{اور (یاد کرو) جب ہم نے تم سے پختہ عہد لیا اور تمہارے اوپر طور کو اٹھا کھڑا کیا، کہ جو کچھ ہم نے تمہیں دیا ہے اسے مضبوطی سے پکڑے رہو اور جو کچھ اس (کتاب تورات) میں (لکھا) ہے اسے یاد رکھو تاکہ تم پرہیزگار بن جاؤ،\qt@no{63}}%
\qt@newcmd\qurantrans@ur@lxxi{پھر اس (عہد اور تنبیہ) کے بعد بھی تم نے روگردانی کی، پس اگر تم پر اللہ کا فضل اور اس کی رحمت نہ ہوتی تو تم یقینا تباہ ہو جاتے،\qt@no{64}}%
\qt@newcmd\qurantrans@ur@lxxii{اور (اے یہود!) تم یقیناً ان لوگوں سے خوب واقف ہو جنہوں نے تم میں سے ہفتہ کے دن (کے احکام کے بارے میں) سرکشی کی تھی تو ہم نے ان سے فرمایا کہ تم دھتکارے ہوئے بندر بن جاؤ،\qt@no{65}}%
\qt@newcmd\qurantrans@ur@lxxiii{پس ہم نے اس (واقعہ) کو اس زمانے اور اس کے بعد والے لوگوں کے لئے (باعثِ) عبرت اور پرہیزگاروں کے لئے (مُوجبِ) نصیحت بنا دیا،\qt@no{66}}%
\qt@newcmd\qurantrans@ur@lxxiv{اور (وہ واقعہ بھی یاد کرو) جب موسیٰ (علیہ السلام) نے اپنی قوم سے فرمایا کہ بیشک اللہ تمہیں حکم دیتا ہے کہ ایک گائے ذبح کرو، (تو) وہ بولے: کیا آپ ہمیں مسخرہ بناتے ہیں؟ موسیٰ (علیہ السلام) نے فرمایا: اللہ کی پناہ مانگتا ہوں (اس سے) کہ میں جاہلوں میں سے ہو جاؤں،\qt@no{67}}%
\qt@newcmd\qurantrans@ur@lxxv{تب) انہوں نے کہا: آپ ہمارے لئے اپنے رب سے دعا کریں کہ وہ ہم پر واضح کر دے کہ (وہ) گائے کیسی ہو؟ (موسیٰ علیہ السلام نے) کہا: بیشک وہ فرماتا ہے کہ وہ گائے نہ تو بوڑھی ہو اور نہ بالکل کم عمر (اَوسَر)، بلکہ درمیانی عمر کی (راس) ہو، پس اب تعمیل کرو جس کا تمہیں حکم دیا گیا ہے،\qt@no{68}}%
\qt@newcmd\qurantrans@ur@lxxvi{وہ (پھر) بولے: اپنے رب سے ہمارے حق میں دعا کریں وہ ہمارے لئے واضح کر دے کہ اس کا رنگ کیسا ہو؟ (موسیٰ علیہ السلام نے) کہا: وہ فرماتا ہے کہ وہ گائے زرد رنگ کی ہو، اس کی رنگت خوب گہری ہو (ایسی جاذبِ نظر ہو کہ) دیکھنے والوں کو بہت بھلی لگے،\qt@no{69}}%
\qt@newcmd\qurantrans@ur@lxxvii{اب) انہوں نے کہا: آپ ہمارے لئے اپنے رب سے درخواست کیجئے کہ وہ ہم پر واضح فرما دے کہ وہ کون سی گائے ہے؟ (کیونکہ) ہم پر گائے مشتبہ ہو گئی ہے، اور یقیناً اگر اللہ نے چاہا تو ہم ضرور ہدایت یافتہ ہو جائیں گے،\qt@no{70}}%
\qt@newcmd\qurantrans@ur@lxxviii{موسیٰ علیہ السلام نے کہا:) اللہ تعالیٰ فرماتا ہے (وہ کوئی گھٹیا گائے نہیں بلکہ) یقینی طور پر ایسی (اعلیٰ) گائے ہو جس سے نہ زمین میں ہل چلانے کی محنت لی جاتی ہو اور نہ کھیتی کو پانی دیتی ہو، بالکل تندرست ہو اس میں کوئی داغ دھبہ بھی نہ ہو، انہوں نے کہا: اب آپ ٹھیک بات لائے (ہیں)، پھر انہوں نے اس کو ذبح کیا حالانکہ وہ ذبح کرتے معلوم نہ ہوتے تھے،\qt@no{71}}%
\qt@newcmd\qurantrans@ur@lxxix{اور جب تم نے ایک شخص کو قتل کر دیا پھر تم آپس میں اس (کے الزام) میں جھگڑنے لگے، اور اللہ (وہ بات) ظاہر فرمانے والا تھا جسے تم چھپا رہے تھے،\qt@no{72}}%
\qt@newcmd\qurantrans@ur@lxxx{پھر ہم نے حکم دیا کہ اس (مُردہ) پر اس (گائے) کا ایک ٹکڑا مارو، اسی طرح اللہ مُردوں کو زندہ فرماتا ہے (یا قیامت کے دن مُردوں کو زندہ کرے گا) اور تمہیں اپنی نشانیاں دکھاتا ہے تاکہ تم عقل و شعور سے کام لو،\qt@no{73}}%
\qt@newcmd\qurantrans@ur@lxxxi{پھر اس کے بعد (بھی) تمہارے دل سخت ہوگئے چنانچہ وہ (سختی میں) پتھروں جیسے (ہوگئے) ہیں یا ان سے بھی زیادہ سخت (ہو چکے ہیں، اس لئے کہ) بیشک پتھروں میں (تو) بعض ایسے بھی ہیں جن سے نہریں پھوٹ نکلتی ہیں، اور یقیناً ان میں سے بعض وہ (پتھر) بھی ہیں جو پھٹ جاتے ہیں تو ان سے پانی ابل پڑتا ہے، اور بیشک ان میں سے بعض ایسے بھی ہیں جو اللہ کے خوف سے گر پڑتے ہیں، (افسوس! تمہارے دلوں میں اس قدر نرمی، خستگی اور شکستگی بھی نہیں رہی،) اور اللہ تمہارے کاموں سے بے خبر نہیں،\qt@no{74}}%
\qt@newcmd\qurantrans@ur@lxxxii{اے مسلمانو!) کیا تم یہ توقع رکھتے ہو کہ وہ (یہودی) تم پر یقین کر لیں گے جبکہ ان میں سے ایک گروہ کے لوگ ایسے (بھی) تھے کہ اللہ کا کلام (تورات) سنتے پھر اسے سمجھنے کے بعد (خود) بدل دیتے حالانکہ وہ خوب جانتے تھے (کہ حقیقت کیا ہے اور وہ کیا کر رہے ہیں)،\qt@no{75}}%
\qt@newcmd\qurantrans@ur@lxxxiii{اور (ان کا حال تو یہ ہو چکا ہے کہ) جب اہلِ ایمان سے ملتے ہیں (تو) کہتے ہیں: ہم (بھی تمہاری طرح حضرت محمد صلی اللہ علیہ وآلہ وسلم پر) ایمان لے آئے ہیں، اور جب آپس میں ایک دوسرے کے ساتھ تنہائی میں ہوتے ہیں (تو) کہتے ہیں: کیا تم ان (مسلمانوں) سے (نبی آخر الزمان صلی اللہ علیہ وآلہ وسلم کی رسالت اور شان کے بارے میں) وہ باتیں بیان کر دیتے ہو جو اللہ نے تم پر (تورات کے ذریعے) ظاہر کی ہیں تاکہ اس سے وہ تمہارے رب کے حضور تمہیں پر حجت قائم کریں، کیا تم (اتنی) عقل (بھی) نہیں رکھتے؟،\qt@no{76}}%
\qt@newcmd\qurantrans@ur@lxxxiv{کیا وہ نہیں جانتے کہ اللہ کو وہ سب کچھ معلوم ہے جو وہ چھپاتے ہیں اور جو ظاہر کرتے ہیں،\qt@no{77}}%
\qt@newcmd\qurantrans@ur@lxxxv{اور ان (یہود) میں سے (بعض) ان پڑھ (بھی) ہیں جنہیں (سوائے سنی سنائی جھوٹی امیدوں کے) کتاب (کے معنی و مفہوم) کا کوئی علم ہی نہیں وہ (کتاب کو) صرف زبانی پڑھنا جانتے ہیں یہ لوگ محض وہم و گمان میں پڑے رہتے ہیں،\qt@no{78}}%
\qt@newcmd\qurantrans@ur@lxxxvi{پس ایسے لوگوں کے لئے بڑی خرابی ہے جو اپنے ہی ہاتھوں سے کتاب لکھتے ہیں، پھر کہتے ہیں کہ یہ اللہ کی طرف سے ہے تاکہ اس کے عوض تھوڑے سے دام کما لیں، سو ان کے لئے اس (کتاب کی وجہ) سے ہلاکت ہے جو ان کے ہاتھوں نے تحریر کی اور اس (معاوضہ کی وجہ) سے تباہی ہے جو وہ کما رہے ہیں،\qt@no{79}}%
\qt@newcmd\qurantrans@ur@lxxxvii{اور وہ (یہود) یہ (بھی) کہتے ہیں کہ ہمیں (دوزخ کی) آگ ہرگز نہیں چھوئے گی سوائے گنتی کے چند دنوں کے، (ذرا) آپ (ان سے) پوچھیں: کیا تم اللہ سے کوئی (ایسا) وعدہ لے چکے ہو؟ پھر تو وہ اپنے وعدے کے خلاف ہرگز نہ کرے گا یا تم اللہ پر یونہی (وہ) بہتان باندھتے ہو جو تم خود بھی نہیں جانتے،\qt@no{80}}%
\qt@newcmd\qurantrans@ur@lxxxviii{ہاں واقعی جس نے برائی اختیار کی اور اس کے گناہوں نے اس کو ہر طرف سے گھیر لیا تو وہی لوگ دوزخی ہیں، وہ اس میں ہمیشہ رہنے والے ہیں،\qt@no{81}}%
\qt@newcmd\qurantrans@ur@lxxxix{اور جو لوگ ایمان لائے اور (انہوں نے) نیک عمل کیے تو وہی لوگ جنّتی ہیں، وہ اس میں ہمیشہ رہنے والے ہیں،\qt@no{82}}%
\qt@newcmd\qurantrans@ur@xc{اور (یاد کرو) جب ہم نے اولادِ یعقوب سے پختہ وعدہ لیا کہ اللہ کے سوا (کسی اور کی) عبادت نہ کرنا، اور ماں باپ کے ساتھ اچھا سلوک کرنا اور قرابت داروں اور یتیموں اور محتاجوں کے ساتھ بھی (بھلائی کرنا) اور عام لوگوں سے (بھی نرمی اور خوش خُلقی کے ساتھ) نیکی کی بات کہنا اور نماز قائم رکھنا اور زکوٰۃ دیتے رہنا، پھر تم میں سے چند لوگوں کے سوا سارے (اس عہد سے) رُوگرداں ہو گئے اور تم (حق سے) گریز ہی کرنے والے ہو،\qt@no{83}}%
\qt@newcmd\qurantrans@ur@xci{اور جب ہم نے تم سے (یہ) پختہ عہد (بھی) لیا کہ تم (آپس میں) ایک دوسرے کا خون نہیں بہاؤ گے اور نہ اپنے لوگوں کو (اپنے گھروں اور بستیوں سے نکال کر) جلاوطن کرو گے پھر تم نے (اس امر کا) اقرار کر لیا اور تم (اس کی) گواہی (بھی) دیتے ہو،\qt@no{84}}%
\qt@newcmd\qurantrans@ur@xcii{پھر تم ہی وہ لوگ ہو کہ اپنوں کو قتل کر رہے ہو اور اپنے ہی ایک گروہ کو ان کے وطن سے باہر نکال رہے ہو اور (مستزاد یہ کہ) ان کے خلاف گناہ اور زیادتی کے ساتھ (ان کے دشمنوں کی) مدد بھی کرتے ہو، اور اگر وہ قیدی ہو کر تمہارے پا س آجائیں تو ان کا فدیہ دے کر چھڑا لیتے ہو (تاکہ وہ تمہارے احسان مند رہیں) حالانکہ ان کا وطن سے نکالا جانا بھی تم پر حرام کر دیا گیا تھا، کیا تم کتاب کے بعض حصوں پر ایمان رکھتے ہو اور بعض کا انکار کرتے ہو؟ پس تم میں سے جو شخص ایسا کرے اس کی کیا سزا ہو سکتی ہے سوائے اس کے کہ دنیا کی زندگی میں ذلّت (اور رُسوائی) ہو، اور قیامت کے دن (بھی ایسے لوگ) سخت ترین عذاب کی طرف لوٹائے جائیں گے، اور اللہ تمہارے کاموں سے بے خبر نہیں،\qt@no{85}}%
\qt@newcmd\qurantrans@ur@xciii{یہی وہ لوگ ہیں جنہوں نے آخرت کے بدلے میں دنیا کی زندگی خرید لی ہے، پس نہ ان پر سے عذاب ہلکا کیا جائے گا اور نہ ہی ان کو مدد دی جائے گی،\qt@no{86}}%
\qt@newcmd\qurantrans@ur@xciv{اور بیشک ہم نے موسیٰ (علیہ السلام) کو کتاب (تورات) عطا کی اور ان کے بعد ہم نے پے در پے (بہت سے) پیغمبر بھیجے، اور ہم نے مریم (علیھا السلام) کے فرزند عیسیٰ (علیہ السلام) کو (بھی) روشن نشانیاں عطا کیں اور ہم نے پاک روح کے ذریعے ان کی تائید (اور مدد) کی، تو کیا (ہوا) جب بھی کوئی پیغمبر تمہارے پاس وہ (احکام) لایا جنہیں تمہارے نفس پسند نہیں کرتے تھے تو تم (وہیں) اکڑ گئے اور بعضوں کو تم نے جھٹلایا اور بعضوں کو تم قتل کرنے لگے،\qt@no{87}}%
\qt@newcmd\qurantrans@ur@xcv{اور یہودیوں نے کہا: ہمارے دلوں پر غلاف ہیں، (ایسا نہیں) بلکہ ان کے کفر کے باعث اللہ نے ان پر لعنت کر دی ہے سو وہ بہت ہی کم ایمان رکھتے ہیں،\qt@no{88}}%
\qt@newcmd\qurantrans@ur@xcvi{اور جب ان کے پاس اللہ کی طرف سے وہ کتاب (قرآن) آئی جو اس کتاب (تورات) کی (اصلاً) تصدیق کرنے والی ہے جو ان کے پاس موجود تھی، حالانکہ اس سے پہلے وہ خود (نبی آخر الزمان حضرت محمد صلی اللہ علیہ وآلہ وسلم اور ان پر اترنے والی کتاب قرآن کے وسیلے سے) کافروں پر فتح یابی (کی دعا) مانگتے تھے، سو جب ان کے پاس وہی نبی (حضرت محمد صلی اللہ علیہ وآلہ وسلم اپنے اوپر نازل ہونے والی کتاب قرآن کے ساتھ) تشریف لے آیا جسے وہ (پہلے ہی سے) پہچانتے تھے تو اسی کے منکر ہو گئے، پس (ایسے دانستہ) انکار کرنے والوں پر اللہ کی لعنت ہے،\qt@no{89}}%
\qt@newcmd\qurantrans@ur@xcvii{انہوں نے اپنی جانوں کا کیا برا سودا کیا کہ اللہ کی نازل کردہ کتاب کا انکار کر رہے ہیں، محض اس حسد میں کہ اللہ اپنے فضل سے اپنے بندوں میں سے جس پر چاہتا ہے (وحی) نازل فرماتا ہے، پس وہ غضب در غضب کے سزاوار ہوئے، اور کافروں کے لئے ذلّت انگیز عذاب ہے،\qt@no{90}}%
\qt@newcmd\qurantrans@ur@xcviii{اور جب ان سے کہا جاتا ہے: اس (کتاب) پر ایمان لاؤ جسے اللہ نے (اب) نازل فرمایا ہے، (تو) کہتے ہیں: ہم صرف اس (کتاب) پر ایمان رکھتے ہیں جو ہم پر نازل کی گئی، اور وہ اس کے علاوہ کا انکار کرتے ہیں، حالانکہ وہ (قرآن بھی) حق ہے (اور) اس (کتاب) کی (بھی) تصدیق کرتا ہے جو ان کے پاس ہے، آپ (ان سے) دریافت فرمائیں کہ پھر تم اس سے پہلے انبیاء کو کیوں قتل کرتے رہے ہو اگر تم (واقعی اپنی ہی کتاب پر) ایمان رکھتے ہو،\qt@no{91}}%
\qt@newcmd\qurantrans@ur@xcix{اور (صورت حال یہ ہے کہ) تمہارے پاس (خود) موسیٰ (علیہ السلام) کھلی نشانیاں لائے پھر تم نے ان کے پیچھے بچھڑے کو معبود بنا لیا اور تم (حقیقت میں) ہو ہی جفاکار،\qt@no{92}}%
\qt@newcmd\qurantrans@ur@c{اور جب ہم نے تم سے پختہ عہد لیا اور ہم نے تمہارے اوپر طور کو اٹھا کھڑا کیا (یہ فرما کر کہ) اس (کتاب) کو مضبوطی سے تھامے رکھو جو ہم نے تمہیں عطا کی ہے اور (ہمارا حکم) سنو، تو (تمہارے بڑوں نے) کہا: ہم نے سن لیا مگر مانا نہیں، اور ان کے دلوں میں ان کے کفر کے باعث بچھڑے کی محبت رچا دی گئی تھی، (اے محبوب! انہیں) بتا دیں یہ باتیں بہت (ہی) بری ہیں جن کا حکم تمہیں تمہارا (نام نہاد) ایمان دے رہا ہے اگر (تم واقعۃً ان پر) ایمان رکھتے ہو،\qt@no{93}}%
\qt@newcmd\qurantrans@ur@ci{آپ فرما دیں: اگر آخرت کا گھر اللہ کے نزدیک صرف تمہارے لئے ہی مخصوص ہے اور لوگوں کے لئے نہیں تو تم (بے دھڑک) موت کی آرزو کرو اگر تم (اپنے خیال میں) سچے ہو،\qt@no{94}}%
\qt@newcmd\qurantrans@ur@cii{وہ ہرگز کبھی بھی اس کی آرزو نہیں کریں گے ان گناہوں (اور مَظالِم) کے باعث جو ان کے ہاتھ آگے بھیج چکے ہیں (یا پہلے کر چکے ہیں) اور اللہ ظالموں کو خوب جانتا ہے،\qt@no{95}}%
\qt@newcmd\qurantrans@ur@ciii{آپ انہیں یقیناً سب لوگوں سے زیادہ جینے کی ہوس میں مبتلا پائیں گے اور (یہاں تک کہ) مشرکوں سے بھی زیادہ، ان میں سے ہر ایک چاہتا ہے کہ کاش اسے ہزار برس کی عمر مل جائے، اگر اسے اتنی عمر مل بھی جائے، تو بھی یہ اسے عذاب سے بچانے والی نہیں ہو سکتی، اور اللہ ان کے اعمال کو خوب دیکھ رہا ہے،\qt@no{96}}%
\qt@newcmd\qurantrans@ur@civ{آپ فرما دیں: جو شخص جبریل کا دشمن ہے (وہ ظلم کر رہا ہے) کیونکہ اس نے (تو) اس (قرآن) کو آپ کے دل پر اللہ کے حکم سے اتارا ہے (جو) اپنے سے پہلے (کی کتابوں) کی تصدیق کرنے والا ہے اور مؤمنوں کے لئے (سراسر) ہدایت اور خوشخبری ہے،\qt@no{97}}%
\qt@newcmd\qurantrans@ur@cv{جو شخص اللہ کا اور اس کے فرشتوں اور اس کے رسولوں کا اور جبریل اور میکائیل کا دشمن ہوا تو یقیناً اللہ (بھی ان) کافروں کا دشمن ہے،\qt@no{98}}%
\qt@newcmd\qurantrans@ur@cvi{اور بیشک ہم نے آپ کی طرف روشن آیتیں اتاری ہیں اور ان (نشانیوں) کا سوائے نافرمانوں کے کوئی انکار نہیں کر سکتا،\qt@no{99}}%
\qt@newcmd\qurantrans@ur@cvii{اور کیا (ایسا نہیں کہ) جب بھی انہوں نے کوئی عہد کیا تو ان میں سے ایک گروہ نے اسے توڑ کر پھینک دیا، بلکہ ان میں سے اکثر ایمان ہی نہیں رکھتے،\qt@no{100}}%
\qt@newcmd\qurantrans@ur@cviii{اور (اسی طرح) جب ان کے پاس اللہ کی جانب سے رسول (حضرت محمد صلی اللہ علیہ وآلہ وسلم) آئے جو اس کتاب کی (اصلاً) تصدیق کرنے والے ہیں جو ان کے پاس (پہلے سے) موجود تھی تو (انہی) اہلِ کتاب میں سے ایک گروہ نے اللہ کی (اسی) کتاب (تورات) کو پسِ پشت پھینک دیا، گویا وہ (اس کو) جانتے ہی نہیں (حالانکہ اسی تورات نے انہیں نبی آخرالزماں حضرت محمد صلی اللہ علیہ وآلہ وسلم کی تشریف آوری کی خبر دی تھی)،\qt@no{101}}%
\qt@newcmd\qurantrans@ur@cix{اور وہ (یہود تو) اس چیز (یعنی جادو) کے پیچھے (بھی) لگ گئے تھے جو سلیمان (علیہ السلام) کے عہدِ حکومت میں شیاطین پڑھا کرتے تھے حالانکہ سلیمان (علیہ السلام) نے (کوئی) کفر نہیں کیا بلکہ کفر تو شیطانوں نے کیا جو لوگوں کو جادو سکھاتے تھے اور اس (جادو کے علم) کے پیچھے (بھی) لگ گئے جو شہر بابل میں ہاروت اور ماروت (نامی) دو فرشتوں پر اتارا گیا تھا، وہ دونوں کسی کو کچھ نہ سکھاتے تھے یہاں تک کہ کہہ دیتے کہ ہم تو محض آزمائش (کے لئے) ہیں سو تم (اس پر اعتقاد رکھ کر) کافر نہ بنو، اس کے باوجود وہ (یہودی) ان دونوں سے ایسا (منتر) سیکھتے تھے جس کے ذریعے شوہر اور اس کی بیوی کے درمیان جدائی ڈال دیتے، حالانکہ وہ اس کے ذریعے کسی کو بھی نقصان نہیں پہنچا سکتے مگر اللہ ہی کے حکم سے اور یہ لوگ وہی چیزیں سیکھتے ہیں جو ان کے لئے ضرر رساں ہیں اور انہیں نفع نہیں پہنچاتیں اور انہیں (یہ بھی) یقینا معلوم تھا کہ جو کوئی اس (کفر یا جادو ٹونے) کا خریدار بنا اس کے لئے آخرت میں کوئی حصہ نہیں (ہوگا)، اور وہ بہت ہی بری چیز ہے جس کے بدلے میں انہوں نے اپنی جانوں (کی حقیقی بہتری یعنی اُخروی فلاح) کو بیچ ڈالا، کاش! وہ اس (سودے کی حقیقت) کو جانتے،\qt@no{102}}%
\qt@newcmd\qurantrans@ur@cx{اور اگر وہ ایمان لے آتے اور پرہیزگاری اختیار کرتے تو اللہ کی بارگاہ سے (تھوڑا سا) ثواب (بھی ان سب چیزوں سے) کہیں بہتر ہوتا، کاش! وہ (اس راز سے) آگاہ ہوتے،\qt@no{103}}%
\qt@newcmd\qurantrans@ur@cxi{اے ایمان والو! (نبی اکرم صلی اللہ علیہ وآلہ وسلم کو اپنی طرف متوجہ کرنے کے لئے) رَاعِنَا مت کہا کرو بلکہ (ادب سے) اُنْظُرْنَا (ہماری طرف نظرِ کرم فرمائیے) کہا کرو اور (ان کا ارشاد) بغور سنتے رہا کرو، اور کافروں کے لئے دردناک عذاب ہے،\qt@no{104}}%
\qt@newcmd\qurantrans@ur@cxii{نہ وہ لوگ جو اہلِ کتاب میں سے کافر ہو گئے اور نہ ہی مشرکین اسے پسند کرتے ہیں کہ تمہارے رب کی طرف سے تم پر کوئی بھلائی اترے، اور اللہ جسے چاہتا ہے اپنی رحمت کے ساتھ خاص کر لیتا ہے، اور اللہ بڑے فضل والا ہے،\qt@no{105}}%
\qt@newcmd\qurantrans@ur@cxiii{ہم جب کوئی آیت منسوخ کر دیتے ہیں یا اسے فراموش کرا دیتے ہیں (تو بہرصورت) اس سے بہتر یا ویسی ہی (کوئی اور آیت) لے آتے ہیں، کیا تم نہیں جانتے کہ اللہ ہر چیز پر (کامل) قدرت رکھتا ہے،\qt@no{106}}%
\qt@newcmd\qurantrans@ur@cxiv{کیا تمہیں معلوم نہیں کہ آسمانوں اور زمین کی بادشاہت اللہ ہی کے لئے ہے، اور اللہ کے سوا نہ تمہارا کوئی دوست ہے اور نہ ہی مددگار،\qt@no{107}}%
\qt@newcmd\qurantrans@ur@cxv{اے مسلمانو!) کیا تم چاہتے ہو کہ تم بھی اپنے رسول (صلی اللہ علیہ وآلہ وسلم) سے اسی طرح سوالات کرو جیسا کہ اس سے پہلے موسیٰ (علیہ السلام) سے سوال کیے گئے تھے، تو جو کوئی ایمان کے بدلے کفر حاصل کرے پس وہ واقعۃً سیدھے راستے سے بھٹک گیا،\qt@no{108}}%
\qt@newcmd\qurantrans@ur@cxvi{بہت سے اہلِ کتاب کی یہ خواہش ہے تمہارے ایمان لے آنے کے بعد پھر تمہیں کفر کی طرف لوٹا دیں، اس حسد کے باعث جو ان کے دلوں میں ہے اس کے باوجود کہ ان پر حق خوب ظاہر ہو چکا ہے، سو تم درگزر کرتے رہو اور نظرانداز کرتے رہو یہاں تک کہ اللہ اپنا حکم بھیج دے، بیشک اللہ ہر چیز پر کامل قدرت رکھتا ہے،\qt@no{109}}%
\qt@newcmd\qurantrans@ur@cxvii{اور نماز قائم (کیا) کرو اور زکوٰۃ دیتے رہا کرو، اور تم اپنے لئے جو نیکی بھی آگے بھیجو گے اسے اللہ کے حضور پا لو گے، جو کچھ تم کر رہے ہو یقینا اللہ اسے دیکھ رہا ہے،\qt@no{110}}%
\qt@newcmd\qurantrans@ur@cxviii{اور (اہلِ کتاب) کہتے ہیں کہ جنت میں ہرگز کوئی بھی داخل نہیں ہوگا سوائے اس کے کہ وہ یہودی ہو یا نصرانی، یہ ان کی باطل امیدیں ہیں، آپ فرما دیں کہ اگر تم (اپنے دعوے میں) سچے ہو تو اپنی (اس خواہش پر) سند لاؤ،\qt@no{111}}%
\qt@newcmd\qurantrans@ur@cxix{ہاں، جس نے اپنا چہرہ اﷲ کے لئے جھکا دیا (یعنی خود کو اﷲ کے سپرد کر دیا) اور وہ صاحبِ اِحسان ہو گیا تو اس کے لئے اس کا اجر اس کے رب کے ہاں ہے اور ایسے لوگوں پر نہ کوئی خوف ہو گا اورنہ وہ رنجیدہ ہوں گے،\qt@no{112}}%
\qt@newcmd\qurantrans@ur@cxx{اور یہود کہتے ہیں کہ نصرانیوں کی بنیاد کسی شے (یعنی صحیح عقیدے) پر نہیں اور نصرانی کہتے ہیں کہ یہودیوں کی بنیاد کسی شے پر نہیں، حالانکہ وہ (سب اللہ کی نازل کردہ) کتاب پڑھتے ہیں، اسی طرح وہ (مشرک) لوگ جن کے پاس (سرے سے کوئی آسمانی) علم ہی نہیں وہ بھی انہی جیسی بات کرتے ہیں، پس اللہ ان کے درمیان قیامت کے دن اس معاملے میں (خود ہی) فیصلہ فرما دے گا جس میں وہ اختلاف کرتے رہتے ہیں،\qt@no{113}}%
\qt@newcmd\qurantrans@ur@cxxi{اور اس شخص سے بڑھ کر کون ظالم ہوگا جو اللہ کی مسجدوں میں اس کے نام کا ذکر کیے جانے سے روک دے اور انہیں ویران کرنے کی کوشش کرے! انہیں ایسا کرنا مناسب نہ تھا کہ مسجدوں میں داخل ہوتے مگر ڈرتے ہوئے، ان کے لئے دنیا میں (بھی) ذلّت ہے اور ان کے لئے آخرت میں (بھی) بڑا عذاب ہے،\qt@no{114}}%
\qt@newcmd\qurantrans@ur@cxxii{اور مشرق و مغرب (سب) اللہ ہی کا ہے، پس تم جدھر بھی رخ کرو ادھر ہی اللہ کی توجہ ہے (یعنی ہر سمت ہی اللہ کی ذات جلوہ گر ہے)، بیشک اللہ بڑی وسعت والا سب کچھ جاننے والا ہے،\qt@no{115}}%
\qt@newcmd\qurantrans@ur@cxxiii{اور وہ کہتے ہیں: اللہ نے اپنے لئے اولاد بنائی ہے، حالانکہ وہ (اس سے) پاک ہے، بلکہ جو کچھ آسمانوں اور زمین میں ہے (سب) اسی کی (خَلق اور مِلک) ہے، (اور) سب کے سب اس کے فرماں بردار ہیں،\qt@no{116}}%
\qt@newcmd\qurantrans@ur@cxxiv{وہی آسمانوں اور زمین کو وجود میں لانے والا ہے، اور جب کسی چیز (کے ایجاد) کا فیصلہ فرما لیتا ہے تو پھر اس کو صرف یہی فرماتا ہے کہ ``تو ہو جا" پس وہ ہوجاتی ہے،\qt@no{117}}%
\qt@newcmd\qurantrans@ur@cxxv{اور جو لوگ علم نہیں رکھتے کہتے ہیں کہ اللہ ہم سے کلام کیوں نہیں فرماتا یا ہمارے پاس (براہِ راست) کوئی نشانی کیوں نہیں آتی؟ اسی طرح ان سے پہلے لوگوں نے بھی انہی جیسی بات کہی تھی، ان (سب) لوگوں کے دل آپس میں ایک جیسے ہیں، بیشک ہم نے یقین والوں کے لئے نشانیاں خوب واضح کر دی ہیں،\qt@no{118}}%
\qt@newcmd\qurantrans@ur@cxxvi{اے محبوبِ مکرّم!) بیشک ہم نے آپ کو حق کے ساتھ خوشخبری سنانے والا اور ڈر سنانے والا بنا کر بھیجا ہے اور اہلِ دوزخ کے بارے میں آپ سے پرسش نہیں کی جائے گی،\qt@no{119}}%
\qt@newcmd\qurantrans@ur@cxxvii{اور یہود و نصارٰی آپ سے (اس وقت تک) ہرگز خوش نہیں ہوں گے جب تک آپ ان کے مذہب کی پیروی اختیار نہ کر لیں، آپ فرما دیں کہ بیشک اللہ کی (عطا کردہ) ہدایت ہی (حقیقی) ہدایت ہے، (امت کی تعلیم کے لئے فرمایا:) اور اگر (بفرضِ محال) آپ نے اس علم کے بعد جو آپ کے پاس (اللہ کی طرف سے) آچکا ہے، ان کی خواہشات کی پیروی کی تو آپ کے لئے اللہ سے بچانے والا نہ کوئی دوست ہوگا اور نہ کوئی مددگار،\qt@no{120}}%
\qt@newcmd\qurantrans@ur@cxxviii{ایسے لوگ بھی ہیں) جنہیں ہم نے کتاب دی وہ اسے اس طرح پڑھتے ہیں جیسے پڑھنے کا حق ہے، وہی لوگ اس (کتاب) پر ایمان رکھتے ہیں، اور جو اس کا انکار کر رہے ہیں سو وہی لوگ نقصان اٹھانے والے ہیں،\qt@no{121}}%
\qt@newcmd\qurantrans@ur@cxxix{اے اولادِ یعقوب! میری اس نعمت کو یاد کرو جو میں نے تم پر ارزانی فرمائی اور (خصوصاً) یہ کہ میں نے تمہیں اس زمانے کے تمام لوگوں پر فضیلت عطا کی،\qt@no{122}}%
\qt@newcmd\qurantrans@ur@cxxx{اور اس دن سے ڈرو جب کوئی جان کسی دوسری جان کی جگہ کوئی بدلہ نہ دے سکے گی اور نہ اس کی طرف سے (اپنے آپ کو چھڑانے کے لیے) کوئی معاوضہ قبول کیا جائے گا اور نہ اس کو (اِذنِ الٰہی کے بغیر) کوئی سفارش ہی فائدہ پہنچا سکے گی اور نہ (اَمرِِ الٰہی کے خلاف) انہیں کوئی مدد دی جا سکے گی،\qt@no{123}}%
\qt@newcmd\qurantrans@ur@cxxxi{اور (وہ وقت یاد کرو) جب ابراہیم (علیہ السلام) کو ان کے رب نے کئی باتوں میں آزمایا تو انہوں نے وہ پوری کر دیں، (اس پر) اللہ نے فرمایا: میں تمہیں لوگوں کا پیشوا بناؤں گا، انہوں نے عرض کیا: (کیا) میری اولاد میں سے بھی؟ ارشاد ہوا: (ہاں! مگر) میرا وعدہ ظالموں کو نہیں پہنچتا،\qt@no{124}}%
\qt@newcmd\qurantrans@ur@cxxxii{اور (یاد کرو) جب ہم نے اس گھر (خانہ کعبہ) کو لوگوں کے لئے رجوع (اور اجتماع) کا مرکز اور جائے امان بنا دیا، اور (حکم دیا کہ) ابراہیم (علیہ السلام) کے کھڑے ہونے کی جگہ کو مقامِ نماز بنا لو، اور ہم نے ابراہیم اور اسماعیل (علیھما السلام) کو تاکید فرمائی کہ میرے گھر کو طواف کرنے والوں اور اعتکاف کرنے والوں اور رکوع و سجود کرنے والوں کے لئے پاک (صاف) کر دو،\qt@no{125}}%
\qt@newcmd\qurantrans@ur@cxxxiii{اور جب ابراہیم (علیہ السلام) نے عرض کیا: اے میرے رب! اسے امن والا شہر بنا دے اور اس کے باشندوں کو طرح طرح کے پھلوں سے نواز (یعنی) ان لوگوں کو جو ان میں سے اللہ پر اور یومِ آخرت پر ایمان لائے، (اللہ نے) فرمایا: اور جو کوئی کفر کرے گا اس کو بھی زندگی کی تھوڑی مدت (کے لئے) فائدہ پہنچاؤں گا پھر اسے (اس کے کفر کے باعث) دوزخ کے عذاب کی طرف (جانے پر) مجبور کر دوں گا اور وہ بہت بری جگہ ہے،\qt@no{126}}%
\qt@newcmd\qurantrans@ur@cxxxiv{اور (یاد کرو) جب ابراہیم اور اسماعیل (علیھما السلام) خانہ کعبہ کی بنیادیں اٹھا رہے تھے (تو دونوں دعا کر رہے تھے) کہ اے ہمارے رب! تو ہم سے (یہ خدمت) قبول فرما لے، بیشک تو خوب سننے والا خوب جاننے والا ہے،\qt@no{127}}%
\qt@newcmd\qurantrans@ur@cxxxv{اے ہمارے رب! ہم دونوں کو اپنے حکم کے سامنے جھکنے والا بنا اور ہماری اولاد سے بھی ایک امت کو خاص اپنا تابع فرمان بنا اور ہمیں ہماری عبادت (اور حج کے) قواعد بتا دے اور ہم پر (رحمت و مغفرت) کی نظر فرما، بیشک تو ہی بہت توبہ قبول فرمانے والا مہربان ہے،\qt@no{128}}%
\qt@newcmd\qurantrans@ur@cxxxvi{اے ہمارے رب! ان میں انہی میں سے (وہ آخری اور برگزیدہ) رسول (صلی اللہ علیہ وآلہ وسلم) مبعوث فرما جو ان پر تیری آیتیں تلاوت فرمائے اور انہیں کتاب اور حکمت کی تعلیم دے (کر دانائے راز بنا دے) اور ان (کے نفوس و قلوب) کو خوب پاک صاف کر دے، بیشک تو ہی غالب حکمت والا ہے،\qt@no{129}}%
\qt@newcmd\qurantrans@ur@cxxxvii{اور کون ہے جو ابراہیم (علیہ السلام) کے دین سے رُوگرداں ہو سوائے اس کے جس نے خود کو مبتلائے حماقت کر رکھا ہو، اور بیشک ہم نے انہیں ضرور دنیا میں (بھی) منتخب فرما لیا تھا اور یقیناً وہ آخرت میں (بھی) بلند رتبہ مقرّبین میں ہوں گے،\qt@no{130}}%
\qt@newcmd\qurantrans@ur@cxxxviii{اور جب ان کے رب نے ان سے فرمایا: (میرے سامنے) گردن جھکا دو، تو عرض کرنے لگے: میں نے سارے جہانوں کے رب کے سامنے سرِ تسلیم خم کر دیا،\qt@no{131}}%
\qt@newcmd\qurantrans@ur@cxxxix{اور ابراہیم (علیہ السلام) نے اپنے بیٹوں کو اسی بات کی وصیت کی اور یعقوب (علیہ السلام) نے بھی (یہی کہا:) اے میرے لڑکو! بیشک اللہ نے تمہارے لئے (یہی) دین (اسلام) پسند فرمایا ہے سو تم (بہرصورت) مسلمان رہتے ہوئے ہی مرنا،\qt@no{132}}%
\qt@newcmd\qurantrans@ur@cxl{کیا تم (اس وقت) حاضر تھے جب یعقوب (علیہ السلام) کو موت آئی، جب انہوں نے اپنے بیٹوں سے پوچھا: تم میرے (انتقال کے) بعد کس کی عبادت کرو گے؟ تو انہوں نے کہا: ہم آپ کے معبود اور آپ کے باپ دادا ابراہیم اور اسماعیل اور اسحٰق (علیھم السلام) کے معبود کی عبادت کریں گے جو معبودِ یکتا ہے، اور ہم (سب) اسی کے فرماں بردار رہیں گے،\qt@no{133}}%
\qt@newcmd\qurantrans@ur@cxli{وہ ایک امت تھی جو گزر چکی، ان کے لئے وہی کچھ ہوگا جو انہوں نے کمایا اور تمہارے لئے وہ ہوگا جو تم کماؤ گے اور تم سے ان کے اعمال کی باز پُرس نہ کی جائے گی،\qt@no{134}}%
\qt@newcmd\qurantrans@ur@cxlii{اور (اہلِ کتاب) کہتے ہیں: یہودی یا نصرانی ہو جاؤ ہدایت پا جاؤ گے، آپ فرما دیں کہ (نہیں) بلکہ ہم تو (اس) ابراہیم (علیہ السلام) کا دین اختیار کیے ہوئے ہیں جو ہر باطل سے جدا صرف اللہ کی طرف متوجہ تھے، اور وہ مشرکوں میں سے نہ تھے،\qt@no{135}}%
\qt@newcmd\qurantrans@ur@cxliii{اے مسلمانو!) تم کہہ دو: ہم اللہ پر ایمان لائے اور اس (کتاب) پر جو ہماری طرف اتاری گئی اور اس پر (بھی) جو ابراہیم اور اسماعیل اور اسحٰق اور یعقوب (علیھم السلام) اور ان کی اولاد کی طرف اتاری گئی اور ان (کتابوں) پر بھی جو موسیٰ اور عیسیٰ (علیھما السلام) کو عطا کی گئیں اور (اسی طرح) جو دوسرے انبیاء (علیھم السلام) کو ان کے رب کی طرف سے عطا کی گئیں، ہم ان میں سے کسی ایک (پر بھی ایمان) میں فرق نہیں کرتے، اور ہم اسی (معبودِ واحد) کے فرماں بردار ہیں،\qt@no{136}}%
\qt@newcmd\qurantrans@ur@cxliv{پھر اگر وہ (بھی) اسی طرح ایمان لائیں جیسے تم اس پر ایمان لائے ہو تو وہ (واقعی) ہدایت پا جائیں گے، اور اگر وہ منہ پھیر لیں تو (سمجھ لیں کہ) وہ محض مخالفت میں ہیں، پس اب اللہ آپ کو ان کے شر سے بچانے کے لئے کافی ہوگا، اور وہ خوب سننے والا جاننے والا ہے،\qt@no{137}}%
\qt@newcmd\qurantrans@ur@cxlv{کہہ دو: ہم) اللہ کے رنگ (میں رنگے گئے ہیں) اور کس کا رنگ اللہ کے رنگ سے بہتر ہے اور ہم تو اسی کے عبادت گزار ہیں،\qt@no{138}}%
\qt@newcmd\qurantrans@ur@cxlvi{فرما دیں: کیا تم اللہ کے بارے میں ہم سے جھگڑا کرتے ہو حالانکہ وہ ہمارا (بھی) رب ہے، اور تمہارا (بھی) رب ہے اور ہمارے لئے ہمارے اعمال اور تمہارے لئے تمہارے اعمال ہیں، اور ہم تو خالصۃً اسی کے ہو چکے ہیں،\qt@no{139}}%
\qt@newcmd\qurantrans@ur@cxlvii{اے اہلِ کتاب!) کیا تم یہ کہتے ہو کہ ابراہیم اور اسماعیل اور اسحٰق اور یعقوب (علیھم السلام) اور ان کے بیٹے یہودی یا نصرانی تھے، فرما دیں: کیا تم زیادہ جانتے ہو یا اللہ؟ اور اس سے بڑھ کر ظالم کون ہوگا جو اس گواہی کو چھپائے جو اس کے پاس اللہ کی طرف سے (کتاب میں موجود) ہے، اور اللہ تمہارے کاموں سے بے خبر نہیں،\qt@no{140}}%
\qt@newcmd\qurantrans@ur@cxlviii{وہ ایک جماعت تھی جو گزر چکی، جو اس نے کمایا وہ اس کے لئے تھا اور جو تم کماؤ گے وہ تمہارے لئے ہوگا، اور تم سے ان کے اعمال کی نسبت نہیں پوچھا جائے گا،\qt@no{141}}%
\qt@newcmd\qurantrans@ur@cxlix{اَب بیوقوف لوگ یہ کہیں گے کہ ان (مسلمانوں) کو اپنے اس قبلہ (بیت المقدس) سے کس نے پھیر دیا جس پر وہ (پہلے سے) تھے، آپ فرما دیں: مشرق و مغرب (سب) اﷲ ہی کے لئے ہے، وہ جسے چاہتا ہے سیدھی راہ پر ڈال دیتا ہے،\qt@no{142}}%
\qt@newcmd\qurantrans@ur@cl{اور (اے مسلمانو!) اسی طرح ہم نے تمہیں (اعتدال والی) بہتر امت بنایا تاکہ تم لوگوں پر گواہ بنو اور (ہمارا یہ برگزیدہ) رسول (صلی اللہ علیہ وآلہ وسلم) تم پر گواہ ہو، اور آپ پہلے جس قبلہ پر تھے ہم نے صرف اس لئے مقرر کیا تھا کہ ہم (پرکھ کر) ظاہر کر دیں کہ کون (ہمارے) رسول (صلی اللہ علیہ وآلہ وسلم) کی پیروی کرتا ہے (اور) کون اپنے الٹے پاؤں پھر جاتا ہے، اور بیشک یہ (قبلہ کا بدلنا) بڑی بھاری بات تھی مگر ان پر نہیں جنہیں اﷲ نے ہدایت (و معرفت) سے نوازا، اور اﷲ کی یہ شان نہیں کہ تمہارا ایمان (یونہی) ضائع کردے، بیشک اﷲ لوگوں پر بڑی شفقت فرمانے والا مہربان ہے،\qt@no{143}}%
\qt@newcmd\qurantrans@ur@cli{اے حبیب!) ہم بار بار آپ کے رُخِ انور کا آسمان کی طرف پلٹنا دیکھ رہے ہیں، سو ہم ضرور بالضرور آپ کو اسی قبلہ کی طرف پھیر دیں گے جس پر آپ راضی ہیں، پس آپ اپنا رخ ابھی مسجدِ حرام کی طرف پھیر لیجئے، اور (اے مسلمانو!) تم جہاں کہیں بھی ہو پس اپنے چہرے اسی کی طرف پھیر لو، اور وہ لوگ جنہیں کتاب دی گئی ہے ضرور جانتے ہیں کہ یہ (تحویلِ قبلہ کا حکم) ان کے رب کی طرف سے حق ہے، اور اﷲ ان کاموں سے بے خبر نہیں جو وہ انجام دے رہے ہیں،\qt@no{144}}%
\qt@newcmd\qurantrans@ur@clii{اوراگر آپ اہلِ کتاب کے پاس ہر ایک نشانی (بھی) لے آئیں تب بھی وہ آپ کے قبلہ کی پیروی نہیں کریں گے اور نہ آپ ہی ان کے قبلہ کی پیروی کرنے والے ہیں اور وہ آپس میں بھی ایک دوسرے کے قبلہ کی پیروی نہیں کرتے، (امت کی تعلیم کے لئے فرمایا:) اور اگر (بفرضِ محال) آپ نے (بھی) اپنے پاس علم آجانے کے بعد ان کی خواہشات کی پیروی کی تو بیشک آپ (اپنی جان پر) زیادتی کرنے والوں میں سے ہو جائیں گے،\qt@no{145}}%
\qt@newcmd\qurantrans@ur@cliii{اور جن لوگوں کو ہم نے کتاب عطا فرمائی ہے وہ اس رسول (آخر الزماں حضرت محمد صلی اللہ علیہ وآلہ وسلم اور ان کی شان و عظمت) کو اسی طرح پہچانتے ہیں جیسا کہ بلاشبہ اپنے بیٹوں کو پہچانتے ہیں، اور یقیناً انہی میں سے ایک طبقہ حق کو جان بوجھ کر چھپا رہا ہے،\qt@no{146}}%
\qt@newcmd\qurantrans@ur@cliv{اے سننے والے!) حق تیرے رب کی طرف سے ہے سو تو ہرگز شک کرنے والوں میں سے نہ ہو،\qt@no{147}}%
\qt@newcmd\qurantrans@ur@clv{اور ہر ایک کے لئے توجہ کی ایک سمت (مقرر) ہے وہ اسی کی طرف رُخ کرتا ہے پس تم نیکیوں کی طرف پیش قدمی کیا کرو، تم جہاں کہیں بھی ہوگے اﷲ تم سب کو جمع کر لے گا، بیشک اﷲ ہر چیز پر خوب قادر ہے،\qt@no{148}}%
\qt@newcmd\qurantrans@ur@clvi{اور تم جدھر سے بھی (سفر پر) نکلو اپنا چہرہ (نماز کے وقت) مسجدِ حرام کی طرف پھیر لو، اور یہی تمہارے رب کی طرف سے حق ہے، اور اﷲ تمہارے اعمال سے بے خبر نہیں،\qt@no{149}}%
\qt@newcmd\qurantrans@ur@clvii{اور تم جدھر سے بھی (سفر پر) نکلو اپنا چہرہ (نماز کے وقت) مسجدِ حرام کی طرف پھیر لو، اور (اے مسلمانو!) تم جہاں کہیں بھی ہو سو اپنے چہرے اسی کی سمت پھیر لیا کرو تاکہ لوگوں کے پاس تم پر اعتراض کرنے کی گنجائش نہ رہے سوائے ان لوگوں کے جو ان میں حد سے بڑھنے والے ہیں، پس تم ان سے مت ڈرو مجھ سے ڈرا کرو، اس لئے کہ میں تم پر اپنی نعمت پوری کردوں اور تاکہ تم کامل ہدایت پا جاؤ،\qt@no{150}}%
\qt@newcmd\qurantrans@ur@clviii{اسی طرح ہم نے تمہارے اندر تمہیں میں سے (اپنا) رسول بھیجا جو تم پر ہماری آیتیں تلاوت فرماتا ہے اور تمہیں (نفسًا و قلبًا) پاک صاف کرتا ہے اور تمہیں کتاب کی تعلیم دیتا ہے اور حکمت و دانائی سکھاتا ہے اور تمہیں وہ (اَسرارِ معرفت و حقیقت) سکھاتا ہے جو تم نہ جانتے تھے،\qt@no{151}}%
\qt@newcmd\qurantrans@ur@clix{سو تم مجھے یاد کیا کرو میں تمہیں یاد رکھوں گا اور میرا شکر ادا کیا کرو اور میری ناشکری نہ کیا کرو،\qt@no{152}}%
\qt@newcmd\qurantrans@ur@clx{اے ایمان والو! صبر اور نماز کے ذریعے (مجھ سے) مدد چاہا کرو، یقیناً اﷲ صبر کرنے والوں کے ساتھ (ہوتا) ہے،\qt@no{153}}%
\qt@newcmd\qurantrans@ur@clxi{اور جو لوگ اﷲ کی راہ میں مارے جائیں انہیں مت کہا کرو کہ یہ مُردہ ہیں، (وہ مُردہ نہیں) بلکہ زندہ ہیں لیکن تمہیں (ان کی زندگی کا) شعور نہیں،\qt@no{154}}%
\qt@newcmd\qurantrans@ur@clxii{اور ہم ضرور بالضرور تمہیں آزمائیں گے کچھ خوف اور بھوک سے اور کچھ مالوں اور جانوں اور پھلوں کے نقصان سے، اور (اے حبیب!) آپ (ان) صبر کرنے والوں کو خوشخبری سنا دیں،\qt@no{155}}%
\qt@newcmd\qurantrans@ur@clxiii{جن پر کوئی مصیبت پڑتی ہے تو کہتے ہیں: بیشک ہم بھی اﷲ ہی کا (مال) ہیں اور ہم بھی اسی کی طرف پلٹ کر جانے والے ہیں،\qt@no{156}}%
\qt@newcmd\qurantrans@ur@clxiv{یہی وہ لوگ ہیں جن پر ان کے رب کی طرف سے پے در پے نوازشیں ہیں اور رحمت ہے، اور یہی لوگ ہدایت یافتہ ہیں،\qt@no{157}}%
\qt@newcmd\qurantrans@ur@clxv{بیشک صفا اور مروہ اﷲ کی نشانیوں میں سے ہیں، چنانچہ جو شخص بیت اﷲ کا حج یا عمرہ کرے تو اس پر کوئی گناہ نہیں کہ ان دونوں کے (درمیان) چکر لگائے، اور جو شخص اپنی خوشی سے کوئی نیکی کرے تو یقیناً اﷲ (بڑا) قدر شناس (بڑا) خبردار ہے،\qt@no{158}}%
\qt@newcmd\qurantrans@ur@clxvi{بیشک جو لوگ ہماری نازل کردہ کھلی نشانیوں اور ہدایت کو چھپاتے ہیں اس کے بعد کہ ہم نے اسے لوگوں کے لئے (اپنی) کتاب میں واضح کردیا ہے تو انہی لوگوں پر اﷲ لعنت بھیجتا ہے (یعنی انہیں اپنی رحمت سے دور کرتا ہے) اور لعنت بھیجنے والے بھی ان پر لعنت بھیجتے ہیں،\qt@no{159}}%
\qt@newcmd\qurantrans@ur@clxvii{مگر جو لوگ توبہ کر لیں اور (اپنی) اصلاح کر لیں اور (حق کو) ظاہر کر دیں تو میں (بھی) انہیں معاف فرما دوں گا، اور میں بڑا ہی توبہ قبول کرنے والا مہربان ہوں،\qt@no{160}}%
\qt@newcmd\qurantrans@ur@clxviii{بیشک جنہوں نے (حق کو چھپا کر) کفر کیا اور اس حال میں مرے کہ وہ کافر ہی تھے ان پر اﷲ کی اور فرشتوں کی اور سب لوگوں کی لعنت ہے،\qt@no{161}}%
\qt@newcmd\qurantrans@ur@clxix{وہ ہمیشہ اسی (لعنت) میں (گرفتار) رہیں گے، ان پر سے عذاب ہلکا نہیں کیا جائے گا اور نہ ہی انہیں مہلت دی جائے گی،\qt@no{162}}%
\qt@newcmd\qurantrans@ur@clxx{اور تمہارا معبود خدائے واحد ہے اس کے سوا کوئی معبود نہیں (وہ) نہایت مہربان بہت رحم فرمانے والا ہے،\qt@no{163}}%
\qt@newcmd\qurantrans@ur@clxxi{بیشک آسمانوں اور زمین کی تخلیق میں اور رات دن کی گردش میں اور ان جہازوں (اور کشتیوں) میں جو سمندر میں لوگوں کو نفع پہنچانے والی چیزیں اٹھا کر چلتی ہیں اور اس (بارش) کے پانی میں جسے اﷲ آسمان کی طرف سے اتارتا ہے پھر اس کے ذریعے زمین کو مُردہ ہو جانے کے بعد زندہ کرتا ہے (وہ زمین) جس میں اس نے ہر قسم کے جانور پھیلا دیئے ہیں اور ہواؤں کے رُخ بدلنے میں اور اس بادل میں جو آسمان اور زمین کے درمیان (حکمِ الٰہی کا) پابند (ہو کر چلتا) ہے (ان میں) عقلمندوں کے لئے (قدرتِ الٰہی کی بہت سی) نشانیاں ہیں،\qt@no{164}}%
\qt@newcmd\qurantrans@ur@clxxii{اور لوگوں میں بعض ایسے بھی ہیں جو اﷲ کے غیروں کو اﷲ کا شریک ٹھہراتے ہیں اور ان سے”اﷲ سے محبت“ جیسی محبت کرتے ہیں، اور جو لوگ ایمان والے ہیں وہ (ہر ایک سے بڑھ کر) اﷲ سے بہت ہی زیادہ محبت کرتے ہیں، اور اگر یہ ظالم لوگ اس وقت کو دیکھ لیں جب (اُخروی) عذاب ان کی آنکھوں کے سامنے ہوگا (توجان لیں) کہ ساری قوتوں کا مالک اﷲ ہے اور بیشک اﷲ سخت عذاب دینے والا ہے،\qt@no{165}}%
\qt@newcmd\qurantrans@ur@clxxiii{اور) جب وہ (پیشوایانِ کفر) جن کی پیروی کی گئی اپنے پیروکاروں سے بے زار ہوں گے اور (وہ سب اﷲ کا) عذاب دیکھ لیں گے اور سارے اسباب ان سے منقطع ہو جائیں گے،\qt@no{166}}%
\qt@newcmd\qurantrans@ur@clxxiv{اور (یہ بے زاری دیکھ کر مشرک) پیروکار کہیں گے: کاش! ہمیں (دنیا میں جانے کا) ایک موقع مل جائے تو ہم (بھی) ان سے بے زاری ظاہر کردیں جیسے انہوں نے (آج) ہم سے بے زاری ظاہر کی ہے، یوں اﷲ انہیں ان کے اپنے اعمال انہی پر حسرت بنا کر دکھائے گا، اور وہ (کسی صورت بھی) دوزخ سے نکلنے نہ پائیں گے،\qt@no{167}}%
\qt@newcmd\qurantrans@ur@clxxv{اے لوگو! زمین کی چیزوں میں سے جو حلال اور پاکیزہ ہے کھاؤ، اور شیطان کے راستوں پر نہ چلو، بیشک وہ تمہارا کھلا دشمن ہے،\qt@no{168}}%
\qt@newcmd\qurantrans@ur@clxxvi{وہ تمہیں بدی اور بے حیائی کا ہی حکم دیتا ہے اور یہ (بھی) کہ تم اﷲ کی نسبت وہ کچھ کہو جس کا تمہیں (خود) علم نہ ہو،\qt@no{169}}%
\qt@newcmd\qurantrans@ur@clxxvii{اور جب ان (کافروں) سے کہا جاتا ہے کہ جو اﷲ نے نازل فرمایا ہے اس کی پیروی کرو تو کہتے ہیں: (نہیں) بلکہ ہم تو اسی (روش) پر چلیں گے جس پر ہم نے اپنے باپ دادا کو پایا ہے، اگرچہ ان کے باپ دادا نہ کچھ عقل رکھتے ہوں اور نہ ہی ہدایت پر ہوں،\qt@no{170}}%
\qt@newcmd\qurantrans@ur@clxxviii{اور ان کافروں (کو ہدایت کی طرف بلانے) کی مثال ایسے شخص کی سی ہے جو کسی ایسے (جانور) کو پکارے جو سوائے پکار اور آواز کے کچھ نہیں سنتا، یہ لوگ بہرے، گونگے، اندھے ہیں سو انہیں کوئی سمجھ نہیں،\qt@no{171}}%
\qt@newcmd\qurantrans@ur@clxxix{اے ایمان والو! ان پاکیزہ چیزوں میں سے کھاؤ جو ہم نے تمہیں عطا کی ہیں اور اﷲ کا شکر ادا کرو اگر تم صرف اسی کی بندگی بجا لاتے ہو،\qt@no{172}}%
\qt@newcmd\qurantrans@ur@clxxx{اس نے تم پر صرف مُردار اور خون اور سؤر کا گوشت اور وہ جانور جس پر ذبح کے وقت غیر اﷲ کا نام پکارا گیا ہو حرام کیا ہے، پھر جو شخص سخت مجبور ہو جائے نہ تو نافرمانی کرنے والا ہو اور نہ حد سے بڑھنے والا تو اس پر (زندگی بچانے کی حد تک کھا لینے میں) کوئی گناہ نہیں، بیشک اﷲ نہایت بخشنے والا مہربان ہے،\qt@no{173}}%
\qt@newcmd\qurantrans@ur@clxxxi{بیشک جو لوگ کتابِ (تورات کی ان آیتوں) کو جو اﷲ نے نازل فرمائی ہیں چھپاتے ہیں اور اس کے بدلے حقیر قیمت حاصل کرتے ہیں، وہ لوگ سوائے اپنے پیٹوں میں آگ بھرنے کے کچھ نہیں کھاتے اور اﷲ قیامت کے روز ان سے کلام تک نہیں فرمائے گا اور نہ ہی ان کو پاک کرے گا، اور ان کے لئے درد ناک عذاب ہے،\qt@no{174}}%
\qt@newcmd\qurantrans@ur@clxxxii{یہی وہ لوگ ہیں جنہوں نے ہدایت کے بدلے گمراہی خریدی اور مغفرت کے بدلے عذاب، کس چیز نے انہیں (دوزخ کی) آگ پر صبر کرنے والا بنا دیا ہے،\qt@no{175}}%
\qt@newcmd\qurantrans@ur@clxxxiii{یہ اس وجہ سے ہے کہ اﷲ نے کتاب حق کے ساتھ نازل فرمائی، اور بیشک جنہوں نے کتاب میں اختلاف ڈالا وہ مخالفت میں (حق سے) بہت دور (جا پڑے) ہیں،\qt@no{176}}%
\qt@newcmd\qurantrans@ur@clxxxiv{نیکی صرف یہی نہیں کہ تم اپنے منہ مشرق اور مغرب کی طرف پھیر لو بلکہ اصل نیکی تو یہ ہے کہ کوئی شخص اﷲ پر اور قیامت کے دن پر اور فرشتوں پر اور (اﷲ کی) کتاب پر اور پیغمبروں پر ایمان لائے، اور اﷲ کی محبت میں (اپنا) مال قرابت داروں پر اور یتیموں پر اور محتاجوں پر اور مسافروں پر اور مانگنے والوں پر اور (غلاموں کی) گردنوں (کو آزاد کرانے) میں خرچ کرے، اور نماز قائم کرے اور زکوٰۃ دے اور جب کوئی وعدہ کریں تو اپنا وعدہ پورا کرنے والے ہوں، اور سختی (تنگدستی) میں اور مصیبت (بیماری) میں اور جنگ کی شدّت (جہاد) کے وقت صبر کرنے والے ہوں، یہی لوگ سچے ہیں اور یہی پرہیزگار ہیں،\qt@no{177}}%
\qt@newcmd\qurantrans@ur@clxxxv{اے ایمان والو! تم پر ان کے خون کا بدلہ (قصاص) فرض کیا گیا ہے جو ناحق قتل کئے جائیں، آزاد کے بدلے آزاد اور غلام کے بدلے غلام اور عورت کے بدلے عورت، پھر اگر اس کو (یعنی قاتل کو) اس کے بھائی (یعنی مقتول کے وارث) کی طرف سے کچھ (یعنی قصاص) معاف کر دیا جائے تو چاہئے کہ بھلے دستور کے موافق پیروی کی جائے اور (خون بہا کو) اچھے طریقے سے اس (مقتول کے وارث) تک پہنچا دیا جائے، یہ تمہارے رب کی طرف سے رعایت اور مہربانی ہے، پس جو کوئی اس کے بعد زیادتی کرے تو اس کے لئے دردناک عذاب ہے،\qt@no{178}}%
\qt@newcmd\qurantrans@ur@clxxxvi{اور تمہارے لئے قصاص (یعنی خون کا بدلہ لینے) میں ہی زندگی (کی ضمانت) ہے اے عقلمند لوگو! تاکہ تم (خوں ریزی اور بربادی سے) بچو،\qt@no{179}}%
\qt@newcmd\qurantrans@ur@clxxxvii{تم پر فرض کیا جاتاہے کہ جب تم میں سے کسی کی موت قریب آپہنچے اگر اس نے کچھ مال چھوڑا ہو، تو (اپنے) والدین اور قریبی رشتہ داروں کے حق میں بھلے طریقے سے وصیت کرے، یہ پرہیزگاروں پر لازم ہے،\qt@no{180}}%
\qt@newcmd\qurantrans@ur@clxxxviii{پھر جس شخص نے اس (وصیّت) کو سننے کے بعد اسے بدل دیا تو اس کا گناہ انہی بدلنے والوں پر ہے، بیشک اﷲ بڑا سننے والا خوب جاننے والا ہے،\qt@no{181}}%
\qt@newcmd\qurantrans@ur@clxxxix{پس اگر کسی شخص کو وصیّت کرنے والے سے (کسی کی) طرف داری یا (کسی کے حق میں) زیادتی کا اندیشہ ہو پھر وہ ان کے درمیان صلح کرادے تو اس پر کوئی گناہ نہیں، بیشک اﷲ نہایت بخشنے والا مہربان ہے،\qt@no{182}}%
\qt@newcmd\qurantrans@ur@cxc{اے ایمان والو! تم پر اسی طرح روزے فرض کئے گئے ہیں جیسے تم سے پہلے لوگوں پر فرض کئے گئے تھے تاکہ تم پرہیزگار بن جاؤ،\qt@no{183}}%
\qt@newcmd\qurantrans@ur@cxci{یہ) گنتی کے چند دن (ہیں)، پس اگر تم میں سے کوئی بیمار ہو یا سفر پر ہو تو دوسرے دنوں (کے روزوں) سے گنتی پوری کر لے، اور جنہیں اس کی طاقت نہ ہو ان کے ذمے ایک مسکین کے کھانے کا بدلہ ہے، پھر جو کوئی اپنی خوشی سے (زیادہ) نیکی کرے تو وہ اس کے لئے بہتر ہے، اور تمہارا روزہ رکھ لینا تمہارے لئے بہتر ہے اگر تمہیں سمجھ ہو،\qt@no{184}}%
\qt@newcmd\qurantrans@ur@cxcii{رمضان کا مہینہ (وہ ہے) جس میں قرآن اتارا گیا ہے جو لوگوں کے لئے ہدایت ہے اور (جس میں) رہنمائی کرنے والی اور (حق و باطل میں) امتیاز کرنے والی واضح نشانیاں ہیں، پس تم میں سے جو کوئی اس مہینہ کو پا لے تو وہ اس کے روزے ضرور رکھے اور جو کوئی بیمار ہو یا سفر پر ہو تو دوسرے دنوں (کے روزوں) سے گنتی پوری کرے، اﷲ تمہارے حق میں آسانی چاہتا ہے اور تمہارے لئے دشواری نہیں چاہتا، اور اس لئے کہ تم گنتی پوری کر سکو اور اس لئے کہ اس نے تمہیں جو ہدایت فرمائی ہے اس پر اس کی بڑائی بیان کرو اور اس لئے کہ تم شکر گزار بن جاؤ،\qt@no{185}}%
\qt@newcmd\qurantrans@ur@cxciii{اور (اے حبیب!) جب میرے بندے آپ سے میری نسبت سوال کریں تو (بتا دیا کریں کہ) میں نزدیک ہوں، میں پکارنے والے کی پکار کا جواب دیتا ہوں جب بھی وہ مجھے پکارتا ہے، پس انہیں چاہئے کہ میری فرمانبرداری اختیار کریں اور مجھ پر پختہ یقین رکھیں تاکہ وہ راہِ (مراد) پاجائیں،\qt@no{186}}%
\qt@newcmd\qurantrans@ur@cxciv{تمہارے لئے روزوں کی راتوں میں اپنی بیویوں کے پاس جانا حلال کر دیا گیا ہے، وہ تمہاری پوشاک ہیں اور تم ان کی پوشاک ہو، اﷲ کو معلوم ہے کہ تم اپنے حق میں خیانت کرتے تھے سو اس نے تمہارے حال پر رحم کیا اور تمہیں معاف فرما دیا، پس اب (روزوں کی راتوں میں بیشک) ان سے مباشرت کیا کرو اور جو اﷲ نے تمہارے لئے لکھ دیا ہے چاہا کرو اور کھاتے پیتے رہا کرو یہاں تک کہ تم پر صبح کا سفید ڈورا (رات کے) سیاہ ڈورے سے (الگ ہو کر) نمایاں ہو جائے، پھر روزہ رات (کی آمد) تک پورا کرو، اور عورتوں سے اس دوران شب باشی نہ کیا کرو جب تم مسجدوں میں اعتکاف بیٹھے ہو، یہ اﷲ کی (قائم کردہ) حدیں ہیں پس ان (کے توڑنے) کے نزدیک نہ جاؤ، اسی طرح اﷲ لوگوں کے لئے اپنی آیتیں (کھول کر) بیان فرماتا ہے تاکہ وہ پرہیزگاری اختیار کریں،\qt@no{187}}%
\qt@newcmd\qurantrans@ur@cxcv{اور تم ایک دوسرے کے مال آپس میں ناحق نہ کھایا کرو اور نہ مال کو (بطورِ رشوت) حاکموں تک پہنچایا کرو کہ یوں لوگوں کے مال کا کچھ حصہ تم (بھی) ناجائز طریقے سے کھا سکو حالانکہ تمہارے علم میں ہو (کہ یہ گناہ ہے)،\qt@no{188}}%
\qt@newcmd\qurantrans@ur@cxcvi{اے حبیب!) لوگ آپ سے نئے چاندوں کے بارے میں دریافت کرتے ہیں، فرما دیں: یہ لوگوں کے لئے اور ماہِ حج (کے تعیّن) کے لئے وقت کی علامتیں ہیں، اور یہ کوئی نیکی نہیں کہ تم (حالتِ احرام میں) گھروں میں ان کی پشت کی طرف سے آؤ بلکہ نیکی تو (ایسی الٹی رسموں کی بجائے) پرہیزگاری اختیار کرنا ہے، اور تم گھروں میں ان کے دروازوں سے آیا کرو، اور اﷲ سے ڈرتے رہو تاکہ تم فلاح پاؤ،\qt@no{189}}%
\qt@newcmd\qurantrans@ur@cxcvii{اور اﷲ کی راہ میں ان سے جنگ کرو جو تم سے جنگ کرتے ہیں (ہاں) مگر حد سے نہ بڑھو، بیشک اﷲ حد سے بڑھنے والوں کو پسند نہیں فرماتا،\qt@no{190}}%
\qt@newcmd\qurantrans@ur@cxcviii{اور (دورانِ جنگ) ان (کافروں) کو جہاں بھی پاؤ مار ڈالو اور انہیں وہاں سے باہر نکال دو جہاں سے انہوں نے تمہیں نکالا تھا اور فتنہ انگیزی تو قتل سے بھی زیادہ سخت (جرم) ہے اور ان سے مسجدِ حرام (خانہ کعبہ) کے پاس جنگ نہ کرو جب تک وہ خود تم سے وہاں جنگ نہ کریں، پھر اگر وہ تم سے قتال کریں تو انہیں قتل کر ڈالو، (ایسے) کافروں کی یہی سزا ہے،\qt@no{191}}%
\qt@newcmd\qurantrans@ur@cxcix{پھر اگر وہ باز آجائیں تو بیشک اﷲ نہایت بخشنے والا مہربان ہے،\qt@no{192}}%
\qt@newcmd\qurantrans@ur@cc{اور ان سے جنگ کرتے رہو حتٰی کہ کوئی فتنہ باقی نہ رہے اور دین (یعنی زندگی اور بندگی کا نظام عملًا) اﷲ ہی کے تابع ہو جائے، پھر اگر وہ باز آجائیں تو سوائے ظالموں کے کسی پر زیادتی روا نہیں،\qt@no{193}}%
\qt@newcmd\qurantrans@ur@cci{حرمت والے مہینے کے بدلے حرمت والا مہینہ ہے اور (دیگر) حرمت والی چیزیں ایک دوسرے کا بدل ہیں، پس اگر تم پر کوئی زیادتی کرے تم بھی اس پر زیادتی کرو مگر اسی قدر جتنی اس نے تم پر کی، اور اﷲ سے ڈرتے رہو اور جان لو کہ اﷲ ڈرنے والوں کے ساتھ ہے،\qt@no{194}}%
\qt@newcmd\qurantrans@ur@ccii{اور اﷲ کی راہ میں خرچ کرو اور اپنے ہی ہاتھوں خود کو ہلاکت میں نہ ڈالو، اور نیکی اختیار کرو، بیشک اﷲ نیکوکاروں سے محبت فرماتا ہے،\qt@no{195}}%
\qt@newcmd\qurantrans@ur@cciii{اور حج اور عمرہ (کے مناسک) اﷲ کے لئے مکمل کرو، پھر اگر تم (راستے میں) روک لئے جاؤ تو جو قربانی بھی میسر آئے (کرنے کے لئے بھیج دو) اور اپنے سروں کو اس وقت تک نہ منڈواؤ جب تک قربانی (کا جانور) اپنے مقام پر نہ پہنچ جائے، پھر تم میں سے جو کوئی بیمار ہو یا اس کے سر میں کچھ تکلیف ہو (اس وجہ سے قبل از وقت سر منڈوالے) تو (اس کے) بدلے میں روزے (رکھے) یا صدقہ (دے) یا قربانی (کرے)، پھر جب تم اطمینان کی حالت میں ہو تو جو کوئی عمرہ کو حج کے ساتھ ملانے کا فائدہ اٹھائے تو جو بھی قربانی میّسر آئے (کر دے)، پھر جسے یہ بھی میّسر نہ ہو وہ تین دن کے روزے (زمانۂ) حج میں رکھے اور سات جب تم حج سے واپس لوٹو، یہ پورے دس (روزے) ہوئے، یہ (رعایت) اس کے لئے ہے جس کے اہل و عیال مسجدِ حرام کے پاس نہ رہتے ہوں (یعنی جو مکہ کا رہنے والا نہ ہو)، اور اﷲ سے ڈرتے رہو اور جان لو کہ اﷲ سخت عذاب دینے والا ہے،\qt@no{196}}%
\qt@newcmd\qurantrans@ur@cciv{حج کے چند مہینے معیّن ہیں (یعنی شوّال، ذوالقعدہ اور عشرہء ذی الحجہ)، تو جو شخص ان (مہینوں) میں نیت کر کے (اپنے اوپر) حج لازم کرلے تو حج کے دنوں میں نہ عورتوں سے اختلاط کرے اور نہ کوئی (اور) گناہ اور نہ ہی کسی سے جھگڑا کرے، اور تم جو بھلائی بھی کرو اﷲ اسے خوب جانتا ہے، اور (آخرت کے) سفر کا سامان کرلو، بیشک سب سے بہترزادِ راہ تقویٰ ہے، اور اے عقل والو! میرا تقویٰ اختیار کرو،\qt@no{197}}%
\qt@newcmd\qurantrans@ur@ccv{اور تم پر اس بات میں کوئی گناہ نہیں اگر تم (زمانۂ حج میں تجارت کے ذریعے) اپنے رب کا فضل (بھی) تلاش کرو، پھر جب تم عرفات سے واپس آؤ تو مشعرِ حرام (مُزدلفہ) کے پاس اﷲ کا ذکر کیا کرو اور اس کا ذکر اس طرح کرو جیسے اس نے تمہیں ہدایت فرمائی، اور بیشک اس سے پہلے تم بھٹکے ہوئے تھے،\qt@no{198}}%
\qt@newcmd\qurantrans@ur@ccvi{پھر تم وہیں سے جاکر واپس آیا کرو جہاں سے (اور) لوگ واپس آتے ہیں اور اﷲ سے (خوب) بخشش طلب کرو، بیشک اﷲ نہایت بخشنے والا مہربان ہے،\qt@no{199}}%
\qt@newcmd\qurantrans@ur@ccvii{پھر جب تم اپنے حج کے ارکان پورے کر چکو تو (منیٰ میں) اﷲ کا خوب ذکر کیا کرو جیسے تم اپنے باپ دادا کا (بڑے شوق سے) ذکر کرتے ہو یا اس سے بھی زیادہ شدّتِ شوق سے (اﷲ کا) ذکر کیا کرو، پھر لوگوں میں سے کچھ ایسے بھی ہیں جو کہتے ہیں: اے ہمارے رب! ہمیں دنیا میں (ہی) عطا کر دے اور ایسے شخص کے لئے آخرت میں کوئی حصہ نہیں ہے،\qt@no{200}}%
\qt@newcmd\qurantrans@ur@ccviii{اور انہی میں سے ایسے بھی ہیں جو عرض کرتے ہیں: اے ہمارے پروردگار! ہمیں دنیا میں (بھی) بھلائی عطا فرما اور آخرت میں (بھی) بھلائی سے نواز اور ہمیں دوزخ کے عذاب سے محفوظ رکھ،\qt@no{201}}%
\qt@newcmd\qurantrans@ur@ccix{یہی وہ لوگ ہیں جن کے لئے ان کی (نیک) کمائی میں سے حصہ ہے، اور اﷲ جلد حساب کرنے والا ہے،\qt@no{202}}%
\qt@newcmd\qurantrans@ur@ccx{اور اﷲ کو (ان) گنتی کے چند دنوں میں (خوب) یاد کیا کرو، پھر جس کسی نے (منیٰ سے واپسی میں) دو ہی دنوں میں جلدی کی تو اس پر کوئی گناہ نہیں اور جس نے (اس میں) تاخیر کی تو اس پر بھی کوئی گناہ نہیں، یہ اس کے لئے ہے جو پرہیزگاری اختیار کرے، اور اﷲ سے ڈرتے رہو اور جان لو کہ تم سب کو اسی کے پاس جمع کیا جائے گا،\qt@no{203}}%
\qt@newcmd\qurantrans@ur@ccxi{اور لوگوں میں کوئی شخص ایسا بھی (ہوتا) ہے کہ جس کی گفتگو دنیاوی زندگی میں تجھے اچھی لگتی ہے اور وہ اﷲ کو اپنے دل کی بات پر گواہ بھی بناتا ہے، حالانکہ وہ سب سے زیادہ جھگڑالو ہے،\qt@no{204}}%
\qt@newcmd\qurantrans@ur@ccxii{اور جب وہ (آپ سے) پھر جاتا ہے تو زمین میں (ہر ممکن) بھاگ دوڑ کرتا ہے تاکہ اس میں فساد انگیزی کرے اور کھیتیاں اور جانیں تباہ کر دے، اور اﷲ فساد کو پسند نہیں فرماتا،\qt@no{205}}%
\qt@newcmd\qurantrans@ur@ccxiii{اور جب اسے اس (ظلم و فساد پر) کہا جائے کہ اﷲ سے ڈرو تو اس کا غرور اسے مزید گناہ پر اکساتا ہے، پس اس کے لئے جہنم کافی ہے اور وہ یقیناً برا ٹھکانا ہے،\qt@no{206}}%
\qt@newcmd\qurantrans@ur@ccxiv{اور (اس کے برعکس) لوگوں میں کوئی شخص ایسا بھی ہوتا ہے جو اﷲ کی رضا حاصل کرنے کے لئے اپنی جان بھی بیچ ڈالتا ہے، اور اﷲ بندوں پر بڑی مہربانی فرمانے والا ہے،\qt@no{207}}%
\qt@newcmd\qurantrans@ur@ccxv{اے ایمان والو! اسلام میں پورے پورے داخل ہو جاؤ، اور شیطان کے راستوں پر نہ چلو، بیشک وہ تمہارا کھلا دشمن ہے،\qt@no{208}}%
\qt@newcmd\qurantrans@ur@ccxvi{پس اگر تم اس کے بعد بھی لغزش کرو جب کہ تمہارے پاس واضح نشانیاں آچکیں تو جان لو کہ اﷲ بہت غالب بڑی حکمت والا ہے،\qt@no{209}}%
\qt@newcmd\qurantrans@ur@ccxvii{کیا وہ اسی بات کے منتظر ہیں کہ بادل کے سائبانوں میں اﷲ (کا عذاب) آجائے اور فرشتے بھی (نیچے اتر آئیں) اور (سارا) قصہ تمام ہو جائے، تو سارے کام اﷲ ہی کی طرف لوٹائے جائیں گے،\qt@no{210}}%
\qt@newcmd\qurantrans@ur@ccxviii{آپ بنی اسرائیل سے پوچھ لیں کہ ہم نے انہیں کتنی واضح نشانیاں عطا کی تھیں، اور جو شخص اﷲ کی نعمت کو اپنے پاس آجانے کے بعد بدل ڈالے تو بیشک اﷲ سخت عذاب دینے والا ہے،\qt@no{211}}%
\qt@newcmd\qurantrans@ur@ccxix{کافروں کے لئے دنیا کی زندگی خوب آراستہ کر دی گئی ہے اور وہ ایمان والوں سے تمسخر کرتے ہیں، اور جنہوں نے تقویٰ اختیار کیا وہ قیامت کے دن ان پر سربلند ہوں گے، اور اﷲ جسے چاہتا ہے بے حساب نوازتا ہے،\qt@no{212}}%
\qt@newcmd\qurantrans@ur@ccxx{ابتداء میں) سب لوگ ایک ہی دین پر جمع تھے، (پھر جب ان میں اختلافات رونما ہو گئے) تو اﷲ نے بشارت دینے والے اور ڈر سنانے والے پیغمبروں کو بھیجا، اور ان کے ساتھ حق پر مبنی کتاب اتاری تاکہ وہ لوگوں میں ان امور کا فیصلہ کر دے جن میں وہ اختلاف کرنے لگے تھے اور اس میں اختلاف بھی فقط انہی لوگوں نے کیا جنہیں وہ کتاب دی گئی تھی، باوجود اس کے کہ ان کے پاس واضح نشانیاں آچکی تھیں، (اور انہوں نے یہ اختلاف بھی) محض باہمی بغض و حسد کے باعث (کیا) پھر اﷲ نے ایمان والوں کو اپنے حکم سے وہ حق کی بات سمجھا دی جس میں وہ اختلاف کرتے تھے، اور اﷲ جسے چاہتا ہے سیدھے راستے کی طرف ہدایت فرما دیتا ہے،\qt@no{213}}%
\qt@newcmd\qurantrans@ur@ccxxi{کیا تم یہ گمان کرتے ہو کہ تم (یونہی بلا آزمائش) جنت میں داخل ہو جاؤ گے حالانکہ تم پر تو ابھی ان لوگوں جیسی حالت (ہی) نہیں بیتی جو تم سے پہلے گزر چکے، انہیں توطرح طرح کی سختیاں اور تکلیفیں پہنچیں اور انہیں (اس طرح) ہلا ڈالا گیا کہ (خود) پیغمبر اور ان کے ایمان والے ساتھی (بھی) پکار اٹھے کہ اﷲ کی مدد کب آئے گی؟ آگاہ ہو جاؤ کہ بیشک اﷲ کی مدد قریب ہے،\qt@no{214}}%
\qt@newcmd\qurantrans@ur@ccxxii{آپ سے پوچھتے ہیں کہ (اﷲ کی راہ میں) کیا خرچ کریں، فرما دیں: جس قدر بھی مال خرچ کرو (درست ہے)، مگر اس کے حق دار تمہارے ماں باپ ہیں اور قریبی رشتہ دار ہیں اور یتیم ہیں اور محتاج ہیں اور مسافر ہیں، اور جو نیکی بھی تم کرتے ہو بیشک اﷲ اسے خوب جاننے والا ہے،\qt@no{215}}%
\qt@newcmd\qurantrans@ur@ccxxiii{اﷲ کی راہ میں) قتال تم پر فرض کر دیا گیا ہے حالانکہ وہ تمہیں طبعاً ناگوار ہے، اور ممکن ہے تم کسی چیز کو ناپسند کرو اور وہ (حقیقتاً) تمہارے لئے بہتر ہو، اور (یہ بھی) ممکن ہے کہ تم کسی چیز کو پسند کرو اور وہ (حقیقتاً) تمہارے لئے بری ہو، اور اﷲ خوب جانتا ہے اور تم نہیں جانتے،\qt@no{216}}%
\qt@newcmd\qurantrans@ur@ccxxiv{لوگ آپ سے حرمت والے مہینے میں جنگ کا حکم دریافت کرتے ہیں، فرما دیں: اس میں جنگ بڑا گناہ ہے اور اﷲ کی راہ سے روکنا اور اس سے کفر کرنا اور مسجدِ حرام (خانہ کعبہ) سے روکنا اور وہاں کے رہنے والوں کو وہاں سے نکالنا اﷲ کے نزدیک (اس سے بھی) بڑا گناہ ہے، اور یہ فتنہ انگیزی قتل و خون سے بھی بڑھ کر ہے اور (یہ کافر) تم سے ہمیشہ جنگ جاری رکھیں گے یہاں تک کہ تمہیں تمہارے دین سے پھیر دیں اگر (وہ اتنی) طاقت پاسکیں، اور تم میں سے جو شخص اپنے دین سے پھر جائے اور پھر وہ کافر ہی مرے تو ایسے لوگوں کے دنیا و آخرت میں (سب) اعمال برباد ہو جائیں گے، اور یہی لوگ جہنمی ہیں وہ اس میں ہمیشہ رہیں گے،\qt@no{217}}%
\qt@newcmd\qurantrans@ur@ccxxv{بیشک جو لوگ ایمان لائے اور جنہوں نے اﷲ کے لئے وطن چھوڑا اور اﷲ کی راہ میں جہاد کیا، یہی لوگ اﷲ کی رحمت کے امیدوار ہیں، اور اﷲ بڑا بخشنے والا مہربان ہے،\qt@no{218}}%
\qt@newcmd\qurantrans@ur@ccxxvi{آپ سے شراب اور جوئے کی نسبت سوال کرتے ہیں، فرما دیں: ان دونوں میں بڑا گناہ ہے اور لوگوں کے لئے کچھ (دنیوی) فائدے بھی ہیں مگر ان دونوں کا گناہ ان کے نفع سے بڑھ کر ہے، اور آپ سے یہ بھی پوچھتے ہیں کہ کیا کچھ خرچ کریں؟ فرما دیں: جو ضرورت سے زائد ہے (خرچ کر دو)، اسی طرح اﷲ تمہارے لئے (اپنے) احکام کھول کر بیان فرماتا ہے تاکہ تم غور و فکر کرو،\qt@no{219}}%
\qt@newcmd\qurantrans@ur@ccxxvii{تمہارا غور و فکر) دنیا اور آخرت (دونوں کے معاملات) میں (رہے)، اور آپ سے یتیموں کے بارے میں دریافت کرتے ہیں، فرما دیں: ان (کے معاملات) کا سنوارنا بہتر ہے، اور اگر انہیں (نفقہ و کاروبار میں) اپنے ساتھ ملا لو تو وہ بھی تمہارے بھائی ہیں، اور اﷲ خرابی کرنے والے کو بھلائی کرنے والے سے جدا پہچانتا ہے، اور اگر اﷲ چاہتا تو تمہیں مشقت میں ڈال دیتا، بیشک اﷲ بڑا غالب بڑی حکمت والا ہے،\qt@no{220}}%
\qt@newcmd\qurantrans@ur@ccxxviii{اور تم مشرک عورتوں کے ساتھ نکاح مت کرو جب تک وہ مسلمان نہ ہو جائیں، اور بیشک مسلمان لونڈی (آزاد) مشرک عورت سے بہتر ہے خواہ وہ تمہیں بھلی ہی لگے، اور (مسلمان عورتوں کا) مشرک مردوں سے بھی نکاح نہ کرو جب تک وہ مسلمان نہ ہو جائیں، اور یقیناً مشرک مرد سے مؤمن غلام بہتر ہے خواہ وہ تمہیں بھلا ہی لگے، وہ (کافر اور مشرک) دوزخ کی طرف بلاتے ہیں، اور اﷲ اپنے حکم سے جنت اور مغفرت کی طرف بلاتا ہے، اور اپنی آیتیں لوگوں کے لئے کھول کر بیان فرماتا ہے تاکہ وہ نصیحت حاصل کریں،\qt@no{221}}%
\qt@newcmd\qurantrans@ur@ccxxix{اور آپ سے حیض (ایامِ ماہواری) کی نسبت سوال کرتے ہیں، فرما دیں: وہ نجاست ہے، سو تم حیض کے دنوں میں عورتوں سے کنارہ کش رہا کرو، اور جب تک وہ پاک نہ ہو جائیں ان کے قریب نہ جایا کرو، اور جب وہ خوب پاک ہو جائیں تو جس راستے سے اﷲ نے تمہیں اجازت دی ہے ان کے پاس جایا کرو، بیشک اﷲ بہت توبہ کرنے والوں سے محبت فرماتا ہے اور خوب پاکیزگی اختیار کرنے والوں سے محبت فرماتا ہے،\qt@no{222}}%
\qt@newcmd\qurantrans@ur@ccxxx{تمہاری عورتیں تمہاری کھیتیاں ہیں پس تم اپنی کھیتیوں میں جیسے چاہو آؤ، اور اپنے لئے آئندہ کا کچھ سامان کرلو، اور اﷲ کا تقوٰی اختیار کرو اور جان لو کہ تم اس کے حضور پیش ہونے والے ہو، اور (اے حبیب!) آپ اہلِ ایمان کو خوشخبری سنادیں (کہ اﷲ کے حضور ان کی پیشی بہتر رہے گی)،\qt@no{223}}%
\qt@newcmd\qurantrans@ur@ccxxxi{اور اپنی قَسموں کے باعث اﷲ (کے نام) کو (لوگوں کے ساتھ) نیکی کرنے اور پرہیزگاری اختیار کرنے اور لوگوں میں صلح کرانے میں آڑ مت بناؤ، اور اﷲ خوب سننے والا بڑا جاننے والا ہے،\qt@no{224}}%
\qt@newcmd\qurantrans@ur@ccxxxii{اﷲ تمہاری بے ہودہ قَسموں پر تم سے مؤاخذہ نہیں فرمائے گا مگر ان کا ضرور مؤاخذہ فرمائے گا جن کا تمہارے دلوں نے ارادہ کیا ہو، اور اﷲ بڑا بخشنے والا بہت حلم والا ہے،\qt@no{225}}%
\qt@newcmd\qurantrans@ur@ccxxxiii{اور ان لوگوں کے لئے جو اپنی بیویوں کے قریب نہ جانے کی قسم کھالیں چار ماہ کی مہلت ہے پس اگر وہ (اس مدت میں) رجوع کر لیں تو بیشک اﷲ بڑا بخشنے والا مہربان ہے،\qt@no{226}}%
\qt@newcmd\qurantrans@ur@ccxxxiv{اور اگر انہوں نے طلاق کا پختہ ارادہ کر لیا ہو تو بیشک اﷲ خوب سننے والا جاننے والا ہے،\qt@no{227}}%
\qt@newcmd\qurantrans@ur@ccxxxv{اور طلاق یافتہ عورتیں اپنے آپ کو تین حیض تک روکے رکھیں، اور ان کے لئے جائز نہیں کہ وہ اسے چھپائیں جو اﷲ نے ان کے رحموں میں پیدا فرما دیا ہو، اگر وہ اﷲ پر اور قیامت کے دن پر ایمان رکھتی ہیں، اور اس مدت کے اندر ان کے شوہروں کو انہیں (پھر) اپنی زوجیت میں لوٹا لینے کا حق زیادہ ہے اگر وہ اصلاح کا ارادہ کر لیں، اور دستور کے مطابق عورتوں کے بھی مردوں پر اسی طرح حقوق ہیں جیسے مردوں کے عورتوں پر، البتہ مردوں کو ان پر فضیلت ہے، اور اﷲ بڑا غالب بڑی حکمت والا ہے،\qt@no{228}}%
\qt@newcmd\qurantrans@ur@ccxxxvi{طلاق (صرف) دو بار (تک) ہے، پھر یا تو (بیوی کو) اچھے طریقے سے (زوجیت میں) روک لینا ہے یا بھلائی کے ساتھ چھوڑ دینا ہے، اور تمہارے لئے جائز نہیں کہ جو چیزیں تم انہیں دے چکے ہو اس میں سے کچھ واپس لو سوائے اس کے کہ دونوں کو اندیشہ ہو کہ (اب رشتۂ زوجیت برقرار رکھتے ہوئے) دونوں اﷲ کی حدود کو قائم نہ رکھ سکیں گے، پھر اگر تمہیں اندیشہ ہو کہ دونوں اﷲ کی حدود کو قائم نہ رکھ سکیں گے، سو (اندریں صورت) ان پر کوئی گناہ نہیں کہ بیوی (خود) کچھ بدلہ دے کر (اس تکلیف دہ بندھن سے) آزادی لے لے، یہ اﷲ کی (مقرر کی ہوئی) حدیں ہیں، پس تم ان سے آگے مت بڑھو اور جو لوگ اﷲ کی حدود سے تجاوز کرتے ہیں سو وہی لوگ ظالم ہیں،\qt@no{229}}%
\qt@newcmd\qurantrans@ur@ccxxxvii{پھر اگر اس نے (تیسری مرتبہ) طلاق دے دی تو اس کے بعد وہ اس کے لئے حلال نہ ہوگی یہاں تک کہ وہ کسی اور شوہر کے ساتھ نکاح کر لے، پھر اگر وہ (دوسرا شوہر) بھی طلاق دے دے تو اب ان دونوں (یعنی پہلے شوہر اور اس عورت) پر کوئی گناہ نہ ہوگا اگر وہ (دوبارہ رشتۂ زوجیت میں) پلٹ جائیں بشرطیکہ دونوں یہ خیال کریں کہ (اب) وہ حدودِ الٰہی قائم رکھ سکیں گے، یہ اﷲ کی (مقرر کردہ) حدود ہیں جنہیں وہ علم والوں کے لئے بیان فرماتا ہے،\qt@no{230}}%
\qt@newcmd\qurantrans@ur@ccxxxviii{اور جب تم عورتوں کو طلاق دو اور وہ اپنی عدت (پوری ہونے) کو آپہنچیں تو انہیں اچھے طریقے سے (اپنی زوجیّت میں) روک لو یا انہیں اچھے طریقے سے چھوڑ دو، اور انہیں محض تکلیف دینے کے لئے نہ روکے رکھو کہ (ان پر) زیادتی کرتے رہو، اور جو کوئی ایسا کرے پس اس نے اپنی ہی جان پر ظلم کیا، اور اﷲ کے احکام کو مذاق نہ بنا لو، اور یاد کرو اﷲ کی اس نعمت کو جو تم پر (کی گئی) ہے اور اس کتاب کو جو اس نے تم پر نازل فرمائی ہے اور دانائی (کی باتوں) کو (جن کی اس نے تمہیں تعلیم دی ہے) وہ تمہیں (اس امر کی) نصیحت فرماتا ہے، اور اﷲ سے ڈرو اور جان لو کہ بیشک اﷲ سب کچھ جاننے والا ہے،\qt@no{231}}%
\qt@newcmd\qurantrans@ur@ccxxxix{اور جب تم عورتوں کو طلاق دو اور وہ اپنی عدت (پوری ہونے) کو آپہنچیں تو جب وہ شرعی دستور کے مطابق باہم رضامند ہو جائیں تو انہیں اپنے (پرانے یا نئے) شوہروں سے نکاح کرنے سے مت روکو، اس شخص کو اس امر کی نصیحت کی جاتی ہے جو تم میں سے اﷲ پراور یومِ قیامت پر ایمان رکھتا ہو، یہ تمہارے لئے بہت ستھری اور نہایت پاکیزہ بات ہے، اور اﷲ جانتا ہے اور تم (بہت سی باتوں کو) نہیں جانتے،\qt@no{232}}%
\qt@newcmd\qurantrans@ur@ccxl{اور مائیں اپنے بچوں کو پورے دو برس تک دودھ پلائیں یہ (حکم) اس کے لئے ہے جو دودھ پلانے کی مدت پوری کرنا چاہے، اور دودھ پلانے والی ماؤں کا کھانا اور پہننا دستور کے مطابق بچے کے باپ پر لازم ہے، کسی جان کو اس کی طاقت سے بڑھ کر تکلیف نہ دی جائے، (اور) نہ ماں کو اس کے بچے کے باعث نقصان پہنچایا جائے اور نہ باپ کو اس کی اولاد کے سبب سے، اور وارثوں پر بھی یہی حکم عائد ہوگا، پھر اگر ماں باپ دونوں باہمی رضا مندی اور مشورے سے (دو برس سے پہلے ہی) دودھ چھڑانا چاہیں تو ان پر کوئی گناہ نہیں، اور پھر اگر تم اپنی اولاد کو (دایہ سے) دودھ پلوانے کا ارادہ رکھتے ہو تب بھی تم پر کوئی گناہ نہیں جب کہ جو تم دستور کے مطابق دیتے ہو انہیں ادا کر دو، اور اﷲ سے ڈرتے رہو اور یہ جان لو کہ بیشک جو کچھ تم کرتے ہو اﷲ اسے خوب دیکھنے والا ہے،\qt@no{233}}%
\qt@newcmd\qurantrans@ur@ccxli{اور تم میں سے جو فوت ہو جائیں اور (اپنی) بیویاں چھوڑ جائیں تو وہ اپنے آپ کو چار ماہ دس دن انتظار میں روکے رکھیں، پھر جب وہ اپنی عدت (پوری ہونے) کو آپہنچیں تو پھر جو کچھ وہ شرعی دستور کے مطابق اپنے حق میں کریں تم پر اس معاملے میں کوئی مؤاخذہ نہیں، اور جو کچھ تم کرتے ہو اﷲ اس سے اچھی طرح خبردار ہے،\qt@no{234}}%
\qt@newcmd\qurantrans@ur@ccxlii{اور تم پر اس بات میں کوئی گناہ نہیں کہ (دورانِ عدت بھی) ان عورتوں کو اشارۃً نکاح کا پیغام دے دو یا (یہ خیال) اپنے دلوں میں چھپا رکھو، اﷲ جانتا ہے کہ تم عنقریب ان سے ذکر کرو گے مگر ان سے خفیہ طور پر بھی (ایسا) وعدہ نہ لو سوائے اس کے کہ تم فقط شریعت کی (رُو سے کنایۃً) معروف بات کہہ دو، اور (اس دوران) عقدِ نکاح کا پختہ عزم نہ کرو یہاں تک کہ مقررہ عدت اپنی انتہا کو پہنچ جائے، اور جان لو کہ اﷲ تمہارے دلوں کی بات کو بھی جانتا ہے تو اس سے ڈرتے رہا کرو، اور (یہ بھی) جان لو کہ اﷲ بڑا بخشنے والا بڑا حلم والا ہے،\qt@no{235}}%
\qt@newcmd\qurantrans@ur@ccxliii{تم پر اس بات میں (بھی) کوئی گناہ نہیں کہ اگر تم نے (اپنی منکوحہ) عورتوں کو ان کے چھونے یا ان کے مہر مقرر کرنے سے بھی پہلے طلاق دے دی ہے تو انہیں (ایسی صورت میں) مناسب خرچہ دے دو، وسعت والے پر اس کی حیثیت کے مطابق (لازم) ہے اور تنگ دست پر اس کی حیثیت کے مطابق، (بہر طور) یہ خرچہ مناسب طریق پر دیا جائے، یہ بھلائی کرنے والوں پر واجب ہے،\qt@no{236}}%
\qt@newcmd\qurantrans@ur@ccxliv{اور اگر تم نے انہیں چھونے سے پہلے طلاق دے دی درآنحالیکہ تم ان کا مَہر مقرر کر چکے تھے تو اس مَہر کا جو تم نے مقرر کیا تھا نصف دینا ضروری ہے سوائے اس کے کہ وہ (اپنا حق) خود معاف کر دیں یا وہ (شوہر) جس کے ہاتھ میں نکاح کی گرہ ہے معاف کردے (یعنی بجائے نصف کے زیادہ یا پورا ادا کردے)، اور (اے مَردو!) اگر تم معاف کر دو تو یہ تقویٰ کے قریب تر ہے، اور (کشیدگی کے ان لمحات میں بھی) آپس میں احسان کرنا نہ بھولا کرو، بیشک اﷲ تمہارے اعمال کو خوب دیکھنے والا ہے،\qt@no{237}}%
\qt@newcmd\qurantrans@ur@ccxlv{سب نمازوں کی محافظت کیا کرو اور بالخصوص درمیانی نماز کی، اور اﷲ کے حضور سراپا ادب و نیاز بن کر قیام کیا کرو،\qt@no{238}}%
\qt@newcmd\qurantrans@ur@ccxlvi{پھر اگر تم حالتِ خوف میں ہو تو پیادہ یا سوار (جیسے بھی ہو نماز پڑھ لیا کرو)، پھر جب تم حالتِ امن میں آجاؤ تو انہی طریقوں پر اﷲ کی یاد کرو جو اس نے تمہیں سکھائے ہیں جنہیں تم (پہلے) نہیں جانتے تھے،\qt@no{239}}%
\qt@newcmd\qurantrans@ur@ccxlvii{اور تم میں سے جو لوگ فوت ہوں اور (اپنی) بیویاں چھوڑ جائیں ان پر لازم ہے کہ (مرنے سے پہلے) اپنی بیویوں کے لئے انہیں ایک سال تک کا خرچہ دینے (اور) اپنے گھروں سے نہ نکالے جانے کی وصیّت کر جائیں، پھر اگر وہ خود (اپنی مرضی سی) نکل جائیں تو دستور کے مطابق جو کچھ بھی وہ اپنے حق میں کریں تم پر اس معاملے میں کوئی گناہ نہیں، اور اﷲ بڑا غالب بڑی حکمت والا ہے،\qt@no{240}}%
\qt@newcmd\qurantrans@ur@ccxlviii{اور طلاق یافتہ عورتوں کو بھی مناسب طریقے سے خرچہ دیا جائے، یہ پرہیزگاروں پر واجب ہے،\qt@no{241}}%
\qt@newcmd\qurantrans@ur@ccxlix{ا سی طرح اﷲ تمہارے لئے اپنے احکام واضح فرماتا ہے تاکہ تم سمجھ سکو،\qt@no{242}}%
\qt@newcmd\qurantrans@ur@ccl{اے حبیب!) کیا آپ نے ان لوگوں کو نہیں دیکھا جو موت کے ڈر سے اپنے گھروں سے نکل گئے حالانکہ وہ ہزاروں (کی تعداد میں) تھے، تو اﷲ نے انہیں حکم دیا: مر جاؤ (سو وہ مرگئے)، پھر انہیں زندہ فرما دیا، بیشک اﷲ لوگوں پر فضل فرمانے والا ہے مگر اکثر لوگ (اس کا) شکر ادا نہیں کرتے،\qt@no{243}}%
\qt@newcmd\qurantrans@ur@ccli{اے مسلمانو!) اﷲ کی راہ میں جنگ کرو اور جان لو کہ اﷲ خوب سننے والا جاننے والا ہے،\qt@no{244}}%
\qt@newcmd\qurantrans@ur@cclii{کون ہے جو اﷲ کو قرضِ حسنہ دے پھر وہ اس کے لئے اسے کئی گنا بڑھا دے گا، اور اﷲ ہی (تمہارے رزق میں) تنگی اور کشادگی کرتا ہے، اور تم اسی کی طرف لوٹائے جاؤگے،\qt@no{245}}%
\qt@newcmd\qurantrans@ur@ccliii{اے حبیب!) کیا آپ نے بنی اسرائیل کے اس گروہ کو نہیں دیکھا جو موسٰی (علیہ السلام) کے بعد ہوا، جب انہوں نے اپنے پیغمبر سے کہا کہ ہمارے لئے ایک بادشاہ مقرر کر دیں تاکہ ہم (اس کی قیادت میں) اﷲ کی راہ میں جنگ کریں، نبی نے (ان سے) فرمایا: کہیں ایسا نہ ہو کہ تم پر قتال فرض کردیا جائے تو تم قتال ہی نہ کرو، وہ کہنے لگے: ہمیں کیا ہوا ہے کہ ہم اﷲ کی راہ میں جنگ نہ کریں حالانکہ ہمیں اپنے گھروں سے اور اولاد سے جدا کر دیا گیا ہے، سو جب ان پر قتال فرض کردیا گیا تو ان میں سے چند ایک کے سوا سب پھر گئے، اور اﷲ ظالموں کو خوب جاننے والا ہے،\qt@no{246}}%
\qt@newcmd\qurantrans@ur@ccliv{اور ان سے ان کے نبی نے فرمایا: بیشک اﷲ نے تمہارے لئے طالوت کو بادشاہ مقرّر فرمایا ہے، تو کہنے لگے کہ اسے ہم پر حکمرانی کیسے مل گئی حالانکہ ہم اس سے حکومت (کرنے) کے زیادہ حق دار ہیں اسے تو دولت کی فراوانی بھی نہیں دی گئی، (نبی نے) فرمایا: بیشک اﷲ نے اسے تم پر منتخب کر لیا ہے اور اسے علم اور جسم میں زیادہ کشادگی عطا فرما دی ہے، اور اﷲ اپنی سلطنت (کی امانت) جسے چاہتا ہے عطا فرما دیتا ہے، اور اﷲ بڑی وسعت والا خوب جاننے والا ہے،\qt@no{247}}%
\qt@newcmd\qurantrans@ur@cclv{اور ان کے نبی نے ان سے فرمایا: اس کی سلطنت (کے مِن جانِبِ اﷲ ہونے) کی نشانی یہ ہے کہ تمہارے پاس صندوق آئے گا اس میں تمہارے رب کی طرف سے سکونِ قلب کا سامان ہوگا اور کچھ آلِ موسٰی اور آلِ ہارون کے چھوڑے ہوئے تبرکات ہوں گے اسے فرشتوں نے اٹھایا ہوا ہوگا، اگر تم ایمان والے ہو تو بیشک اس میں تمہارے لئے بڑی نشانی ہے،\qt@no{248}}%
\qt@newcmd\qurantrans@ur@cclvi{پھرجب طالوت اپنے لشکروں کو لے کر شہر سے نکلا، تو اس نے کہا: بیشک اﷲ تمہیں ایک نہر کے ذریعے آزمانے والا ہے، پس جس نے اس میں سے پانی پیا سو وہ میرے (ساتھیوں میں) سے نہیں ہوگا، اور جو اس کو نہیں پئے گا پس وہی میری (جماعت) سے ہوگا مگر جو شخص ایک چُلّو (کی حد تک) اپنے ہاتھ سے پی لے (اس پر کوئی حرج نہیں)، سو ان میں سے چند لوگوں کے سوا باقی سب نے اس سے پانی پی لیا، پس جب طالوت اور ان کے ایمان والے ساتھی نہر کے پار چلے گئے، تو کہنے لگے: آج ہم میں جالوت اور اس کی فوجوں سے مقابلے کی طاقت نہیں، جو لوگ یہ یقین رکھتے تھے کہ وہ (شہید ہو کر یا مرنے کے بعد) اﷲ سے ملاقات کا شرف پانے والے ہیں، کہنے لگے: کئی مرتبہ اﷲ کے حکم سے تھوڑی سی جماعت (خاصی) بڑی جماعت پر غالب آجاتی ہے، اور اﷲ صبر کرنے والوں کو اپنی معیّت سے نوازتا ہے،\qt@no{249}}%
\qt@newcmd\qurantrans@ur@cclvii{اور جب وہ جالوت اور اس کی فوجوں کے مقابل ہوئے تو عرض کرنے لگے: اے ہمارے پروردگار! ہم پر صبر میں وسعت ارزانی فرما اور ہمیں ثابت قدم رکھ اور ہمیں کافروں پر غلبہ عطا فرما،\qt@no{250}}%
\qt@newcmd\qurantrans@ur@cclviii{پھر انہوں نے ان (جالوتی فوجوں) کو اللہ کے امر سے شکست دی، اور داؤد (علیہ السلام) نے جالوت کو قتل کر دیا اور اﷲ نے ان کو (یعنی داؤد علیہ السلام کو) حکومت اور حکمت عطا فرمائی اور انہیں جو چاہا سکھایا، اور اگر اﷲ لوگوں کے ایک گروہ کو دوسرے گروہ کے ذریعے نہ ہٹاتا رہتا تو زمین (میں انسانی زندگی بعض جابروں کے مسلسل تسلّط اور ظلم کے باعث) برباد ہو جاتی مگر اﷲ تمام جہانوں پر بڑا فضل فرمانے والا ہے،\qt@no{251}}%
\qt@newcmd\qurantrans@ur@cclix{یہ اﷲ کی آیتیں ہیں ہم انہیں (اے حبیب!) آپ پر سچائی کے ساتھ پڑھتے ہیں، اور بیشک آپ رسولوں میں سے ہیں،\qt@no{252}}%
\qt@newcmd\qurantrans@ur@cclx{یہ سب رسول (جو ہم نے مبعوث فرمائے) ہم نے ان میں سے بعض کو بعض پر فضیلت دی ہے، ان میں سے کسی سے اﷲ نے (براہِ راست) کلام فرمایا اور کسی کو درجات میں (سب پر) فوقیّت دی (یعنی حضور نبی اکرم صلی اللہ علیہ وآلہ وسلم کو جملہ درجات میں سب پر بلندی عطا فرمائی)، اور ہم نے مریم کے فرزند عیسٰی (علیہ السلام) کو واضح نشانیاں عطا کیں اور ہم نے پاکیزہ روح کے ذریعے اس کی مدد فرمائی، اور اگر اﷲ چاہتا تو ان رسولوں کے پیچھے آنے والے لوگ اپنے پاس کھلی نشانیاں آجانے کے بعد آپس میں کبھی بھی نہ لڑتے جھگڑتے مگر انہوں نے (اس آزادانہ توفیق کے باعث جو انہیں اپنے کئے پر اﷲ کے حضور جواب دہ ہونے کے لئے دی گئی تھی) اختلاف کیا پس ان میں سے کچھ ایمان لائے اور ان میں سے کچھ نے کفر اختیار کیا، (اور یہ بات یاد رکھو کہ) اگر اﷲ چاہتا (یعنی انہیں ایک ہی بات پر مجبور رکھتا) تو وہ کبھی بھی باہم نہ لڑتے، لیکن اﷲ جو چاہتا ہے کرتا ہے،\qt@no{253}}%
\qt@newcmd\qurantrans@ur@cclxi{اے ایمان والو! جو کچھ ہم نے تمہیں عطا کیا ہے اس میں سے (اﷲ کی راہ میں) خرچ کرو قبل اس کے کہ وہ دن آجائے جس میں نہ کوئی خرید و فروخت ہوگی اور (کافروں کے لئے) نہ کوئی دوستی (کار آمد) ہوگی اور نہ (کوئی) سفارش، اور یہ کفار ہی ظالم ہیں،\qt@no{254}}%
\qt@newcmd\qurantrans@ur@cclxii{اﷲ، اس کے سوا کوئی عبادت کے لائق نہیں، ہمیشہ زندہ رہنے والا ہے (سارے عالم کو اپنی تدبیر سے) قائم رکھنے والا ہے، نہ اس کو اُونگھ آتی ہے اور نہ نیند جو کچھ آسمانوں میں ہے اور جو کچھ زمین میں ہے سب اسی کا ہے، کون ایسا شخص ہے جو اس کے حضور اس کے اِذن کے بغیر سفارش کر سکے، جو کچھ مخلوقات کے سامنے (ہو رہا ہے یا ہو چکا) ہے اور جو کچھ ان کے بعد (ہونے والا) ہے (وہ) سب جانتا ہے، اور وہ اس کی معلومات میں سے کسی چیز کا بھی احاطہ نہیں کر سکتے مگر جس قدر وہ چاہے، اس کی کرسیء (سلطنت و قدرت) تمام آسمانوں اور زمین کو محیط ہے، اور اس پر ان دونوں (یعنی زمین و آسمان) کی حفاظت ہرگز دشوار نہیں، وہی سب سے بلند رتبہ بڑی عظمت والا ہے،\qt@no{255}}%
\qt@newcmd\qurantrans@ur@cclxiii{دین میں کوئی زبردستی نہیں، بیشک ہدایت گمراہی سے واضح طور پر ممتاز ہو چکی ہے، سو جو کوئی معبودانِ باطلہ کا انکار کر دے اور اﷲ پر ایمان لے آئے تو اس نے ایک ایسا مضبوط حلقہ تھام لیا جس کے لئے ٹوٹنا (ممکن) نہیں، اور اﷲ خوب سننے والا جاننے والا ہے،\qt@no{256}}%
\qt@newcmd\qurantrans@ur@cclxiv{اﷲ ایمان والوں کا کارساز ہے وہ انہیں تاریکیوں سے نکال کر نور کی طرف لے جاتا ہے، اور جو لوگ کافر ہیں ان کے حمایتی شیطان ہیں وہ انہیں (حق کی) روشنی سے نکال کر (باطل کی) تاریکیوں کی طرف لے جاتے ہیں، یہی لوگ جہنمی ہیں، وہ اس میں ہمیشہ رہیں گے،\qt@no{257}}%
\qt@newcmd\qurantrans@ur@cclxv{اے حبیب!) کیا آپ نے اس شخص کو نہیں دیکھا جو اس وجہ سے کہ اﷲ نے اسے سلطنت دی تھی ابراہیم (علیہ السلام) سے (خود) اپنے رب (ہی) کے بارے میں جھگڑا کرنے لگا، جب ابراہیم (علیہ السلام) نے کہا: میرا رب وہ ہے جو زندہ (بھی) کرتا ہے اور مارتا (بھی) ہے، تو (جواباً) کہنے لگا: میں (بھی) زندہ کرتا ہوں اور مارتا ہوں، ابراہیم (علیہ السلام) نے کہا: بیشک اﷲ سورج کو مشرق کی طرف سے نکالتا ہے تُو اسے مغرب کی طرف سے نکال لا! سو وہ کافر دہشت زدہ ہو گیا، اور اﷲ ظالم قوم کو حق کی راہ نہیں دکھاتا،\qt@no{258}}%
\qt@newcmd\qurantrans@ur@cclxvi{یا اسی طرح اس شخص کو (نہیں دیکھا) جو ایک بستی پر سے گزرا جو اپنی چھتوں پر گری پڑی تھی تو اس نے کہا کہ اﷲ اس کی موت کے بعد اسے کیسے زندہ فرمائے گا، سو (اپنی قدرت کا مشاہدہ کرانے کے لئے) اﷲ نے اسے سو برس تک مُردہ رکھا پھر اُسے زندہ کیا، (بعد ازاں) پوچھا: تُو یہاں (مرنے کے بعد) کتنی دیر ٹھہرا رہا (ہے)؟ اس نے کہا: میں ایک دن یا ایک دن کا (بھی) کچھ حصہ ٹھہرا ہوں، فرمایا: (نہیں) بلکہ تُو سو برس پڑا رہا (ہے) پس (اب) تُو اپنے کھانے اور پینے (کی چیزوں) کو دیکھ (وہ) متغیّر (باسی) بھی نہیں ہوئیں اور (اب) اپنے گدھے کی طرف نظر کر (جس کی ہڈیاں بھی سلامت نہیں رہیں) اور یہ اس لئے کہ ہم تجھے لوگوں کے لئے (اپنی قدرت کی) نشانی بنا دیں اور (اب ان) ہڈیوں کی طرف دیکھ ہم انہیں کیسے جُنبش دیتے (اور اٹھاتے) ہیں پھر انہیں گوشت (کا لباس) پہناتے ہیں، جب یہ (معاملہ) اس پر خوب آشکار ہو گیا تو بول اٹھا: میں (مشاہداتی یقین سے) جان گیا ہوں کہ بیشک اﷲ ہر چیز پر خوب قادر ہے،\qt@no{259}}%
\qt@newcmd\qurantrans@ur@cclxvii{اور (وہ واقعہ بھی یاد کریں) جب ابراہیم (علیہ السلام) نے عرض کیا: میرے رب! مجھے دکھا دے کہ تُو مُردوں کو کس طرح زندہ فرماتا ہے؟ ارشاد ہوا: کیا تم یقین نہیں رکھتے؟ اس نے عرض کیا: کیوں نہیں (یقین رکھتا ہوں) لیکن (چاہتا ہوں کہ) میرے دل کو بھی خوب سکون نصیب ہو جائے، ارشاد فرمایا: سو تم چار پرندے پکڑ لو پھر انہیں اپنی طرف مانوس کر لو پھر (انہیں ذبح کر کے) ان کا ایک ایک ٹکڑا ایک ایک پہاڑ پر رکھ دو پھر انہیں بلاؤ وہ تمہارے پاس دوڑتے ہوئے آجائیں گے، اور جان لو کہ یقینا اﷲ بڑا غالب بڑی حکمت والا ہے،\qt@no{260}}%
\qt@newcmd\qurantrans@ur@cclxviii{جو لوگ اﷲ کی راہ میں اپنے مال خرچ کرتے ہیں ان کی مثال (اس) دانے کی سی ہے جس سے سات بالیاں اگیں (اور پھر) ہر بالی میں سو دانے ہوں (یعنی سات سو گنا اجر پاتے ہیں)، اور اﷲ جس کے لئے چاہتا ہے (اس سے بھی) اضافہ فرما دیتا ہے، اور اﷲ بڑی وسعت والا خوب جاننے والا ہے،\qt@no{261}}%
\qt@newcmd\qurantrans@ur@cclxix{جو لوگ اﷲ کی راہ میں اپنے مال خرچ کرتے ہیں پھر اپنے خرچ کئے ہوئے کے پیچھے نہ احسان جتلاتے ہیں اور نہ اذیت دیتے ہیں ان کے لئے ان کے رب کے پاس ان کا اجر ہے اور (روزِ قیامت) ان پر نہ کوئی خوف ہوگا اور نہ وہ غمگین ہوں گے،\qt@no{262}}%
\qt@newcmd\qurantrans@ur@cclxx{سائل سے) نرمی کے ساتھ گفتگو کرنا اور درگزر کرنا اس صدقہ سے کہیں بہتر ہے جس کے بعد (اس کی) دل آزاری ہو، اور اﷲ بے نیاز بڑا حلم والا ہے،\qt@no{263}}%
\qt@newcmd\qurantrans@ur@cclxxi{اے ایمان والو! اپنے صدقات (بعد ازاں) احسان جتا کر اور دُکھ دے کر اس شخص کی طرح برباد نہ کر لیا کرو جو مال لوگوں کے دکھانے کے لئے خرچ کرتا ہے اور نہ اﷲ پر ایمان رکھتا ہے اور نہ روزِ قیامت پر، اس کی مثال ایک ایسے چکنے پتھر کی سی ہے جس پر تھوڑی سی مٹی پڑی ہو پھر اس پر زوردار بارش ہو تو وہ اسے (پھر وہی) سخت اور صاف (پتھر) کر کے ہی چھوڑ دے، سو اپنی کمائی میں سے ان (ریاکاروں) کے ہاتھ کچھ بھی نہیں آئے گا، اور اﷲ کافر قوم کو ہدایت نہیں فرماتا،\qt@no{264}}%
\qt@newcmd\qurantrans@ur@cclxxii{اور جو لوگ اپنے مال اﷲ کی رضا حاصل کرنے اور اپنے آپ کو (ایمان و اطاعت پر) مضبوط کرنے کے لئے خرچ کرتے ہیں ان کی مثال ایک ایسے باغ کی سی ہے جو اونچی سطح پر ہو اس پر زوردار بارش ہو تو وہ دوگنا پھل لائے، اور اگر اسے زوردار بارش نہ ملے تو (اسے) شبنم (یا ہلکی سی پھوار) بھی کافی ہو، اور اﷲ تمہارے اعمال کو خوب دیکھنے والا ہے،\qt@no{265}}%
\qt@newcmd\qurantrans@ur@cclxxiii{کیا تم میں سے کوئی شخص یہ پسند کرے گا کہ اس کے پاس کھجوروں اور انگوروں کا ایک باغ ہو جس کے نیچے نہریں بہتی ہوں اس کے لئے اس میں (کھجوروں اور انگوروں کے علاوہ بھی) ہر قسم کے پھل ہوں اور (ایسے وقت میں) اسے بڑھاپا آپہنچے اور (ابھی) اس کی اولاد بھی ناتواں ہو اور (ایسے وقت میں) اس باغ پر ایک بگولا آجائے جس میں (نِری) آگ ہو اور وہ باغ جل جائے (تو اس کی محرومی اور پریشانی کا عالم کیا ہو گا)، اسی طرح اﷲ تمہارے لئے نشانیاں واضح طور پر بیان فرماتا ہے تاکہ تم غور کرو (سو کیا تم چاہتے ہو کہ آخرت میں تمہارے اعمال کا باغ بھی ریاکاری کی آگ میں جل کر بھسم ہو جائے اور تمہیں سنبھالا دینے والا بھی کوئی نہ ہو)،\qt@no{266}}%
\qt@newcmd\qurantrans@ur@cclxxiv{اے ایمان والو! ان پاکیزہ کمائیوں میں سے اور اس میں سے جو ہم نے تمہارے لئے زمین سے نکالا ہے (اﷲ کی راہ میں) خرچ کیا کرو اور اس میں سے گندے مال کو (اﷲ کی راہ میں) خرچ کرنے کا ارادہ مت کرو کہ (اگر وہی تمہیں دیا جائے تو) تم خود اسے ہرگز نہ لو سوائے اس کے کہ تم اس میں چشم پوشی کر لو، اور جان لو کہ بیشک اﷲ بے نیاز لائقِ ہر حمد ہے،\qt@no{267}}%
\qt@newcmd\qurantrans@ur@cclxxv{شیطان تمہیں (اﷲ کی راہ میں خرچ کرنے سے روکنے کے لئے) تنگدستی کا خوف دلاتا ہے اور بے حیائی کا حکم دیتا ہے، اور اﷲ تم سے اپنی بخشش اور فضل کا وعدہ فرماتا ہے، اور اﷲ بہت وسعت والا خوب جاننے والا ہے،\qt@no{268}}%
\qt@newcmd\qurantrans@ur@cclxxvi{جسے چاہتا ہے دانائی عطا فرما دیتا ہے، اور جسے (حکمت و) دانائی عطا کی گئی اسے بہت بڑی بھلائی نصیب ہوگئی، اور صرف وہی لوگ نصیحت حاصل کرتے ہیں جو صاحبِ عقل و دانش ہیں،\qt@no{269}}%
\qt@newcmd\qurantrans@ur@cclxxvii{اور تم جو کچھ بھی خرچ کرو یا تم جو مَنّت بھی مانو تو اﷲ اسے یقینا جانتا ہے، اور ظالموں کے لئے کوئی مددگار نہیں،\qt@no{270}}%
\qt@newcmd\qurantrans@ur@cclxxviii{اگر تم خیرات ظاہر کر کے دو تو یہ بھی اچھا ہے (اس سے دوسروں کو ترغیب ہوگی)، اور اگر تم انہیں مخفی رکھو اور وہ محتاجوں کو پہنچا دو تو یہ تمہارے لئے (اور) بہتر ہے، اور اﷲ (اس خیرات کی وجہ سے) تمہارے کچھ گناہوں کو تم سے دور فرما دے گا، اور اﷲ تمہارے اعمال سے باخبر ہے،\qt@no{271}}%
\qt@newcmd\qurantrans@ur@cclxxix{ان کو ہدایت دینا آپ کے ذمہ نہیں بلکہ اﷲ ہی جسے چاہتا ہے ہدایت سے نوازتا ہے، اور تم جو مال بھی خرچ کرو سو وہ تمہارے اپنے فائدے میں ہے، اور اﷲ کی رضاجوئی کے سوا تمہارا خرچ کرنا مناسب ہی نہیں ہے، اور تم جو مال بھی خرچ کرو گے (اس کا اجر) تمہیں پورا پورا دیا جائے گا اور تم پر کوئی ظلم نہیں کیا جائے گا،\qt@no{272}}%
\qt@newcmd\qurantrans@ur@cclxxx{خیرات) ان فقراءکا حق ہے جو اﷲ کی راہ میں (کسبِ معاش سے) روک دیئے گئے ہیں وہ (امورِ دین میں ہمہ وقت مشغول رہنے کے باعث) زمین میں چل پھر بھی نہیں سکتے ان کے (زُھداً) طمع سے باز رہنے کے باعث نادان (جو ان کے حال سے بے خبر ہے) انہیں مالدار سمجھے ہوئے ہے، تم انہیں ان کی صورت سے پہچان لو گے، وہ لوگوں سے بالکل سوال ہی نہیں کرتے کہ کہیں (مخلوق کے سامنے) گڑگڑانا نہ پڑے، اور تم جو مال بھی خرچ کرو تو بیشک اﷲ اسے خوب جانتا ہے،\qt@no{273}}%
\qt@newcmd\qurantrans@ur@cclxxxi{جو لوگ (اﷲ کی راہ میں) شب و روز اپنے مال پوشیدہ اور ظاہر خرچ کرتے ہیں تو ان کے لئے ان کے رب کے پاس ان کا اجر ہے اور (روزِ قیامت) ان پر نہ کوئی خوف ہوگا اور نہ وہ رنجیدہ ہوں گے،\qt@no{274}}%
\qt@newcmd\qurantrans@ur@cclxxxii{جو لوگ سُود کھاتے ہیں وہ (روزِ قیامت) کھڑے نہیں ہو سکیں گے مگر جیسے وہ شخص کھڑا ہوتا ہے جسے شیطان (آسیب) نے چھو کر بدحواس کر دیا ہو، یہ اس لئے کہ وہ کہتے تھے کہ تجارت (خرید و فروخت) بھی تو سود کی مانند ہے، حالانکہ اﷲ نے تجارت (سوداگری) کو حلال فرمایا ہے اور سود کو حرام کیا ہے، پس جس کے پاس اس کے رب کی جانب سے نصیحت پہنچی سو وہ (سود سے) باز آگیا تو جو پہلے گزر چکا وہ اسی کا ہے، اور اس کا معاملہ اﷲ کے سپرد ہے، اور جس نے پھر بھی لیا سو ایسے لوگ جہنمی ہیں، وہ اس میں ہمیشہ رہیں گے،\qt@no{275}}%
\qt@newcmd\qurantrans@ur@cclxxxiii{اور اﷲ سود کو مٹاتا ہے (یعنی سودی مال سے برکت کو ختم کرتا ہے) اور صدقات کو بڑھاتا ہے (یعنی صدقہ کے ذریعے مال کی برکت کو زیادہ کرتا ہے)، اور اﷲ کسی بھی ناسپاس نافرمان کو پسند نہیں کرتا،\qt@no{276}}%
\qt@newcmd\qurantrans@ur@cclxxxiv{بیشک جو لوگ ایمان لائے اور انہوں نے نیک اعمال کئے اور نماز قائم رکھی اور زکوٰۃ دیتے رہے ان کے لئے ان کے رب کے پاس ان کا اجر ہے، اور ان پر (آخرت میں) نہ کوئی خوف ہوگا اور نہ وہ رنجیدہ ہوں گے،\qt@no{277}}%
\qt@newcmd\qurantrans@ur@cclxxxv{اے ایمان والو! اﷲ سے ڈرو اور جو کچھ بھی سود میں سے باقی رہ گیا ہے چھوڑ دو اگر تم (صدقِ دل سے) ایمان رکھتے ہو،\qt@no{278}}%
\qt@newcmd\qurantrans@ur@cclxxxvi{پھر اگر تم نے ایسا نہ کیا تو اﷲ اور اس کے رسول (صلی اللہ علیہ وآلہ وسلم) کی طرف سے اعلانِ جنگ پر خبردار ہو جاؤ، اور اگر تم توبہ کر لو تو تمہارے لئے تمہارے اصل مال (جائز) ہیں، نہ تم خود ظلم کرو اور نہ تم پر ظلم کیا جائے،\qt@no{279}}%
\qt@newcmd\qurantrans@ur@cclxxxvii{اور اگر قرض دار تنگدست ہو تو خوشحالی تک مہلت دی جانی چاہئے، اور تمہارا (قرض کو) معاف کر دینا تمہارے لئے بہتر ہے اگر تمہیں معلوم ہو (کہ غریب کی دل جوئی اﷲ کی نگاہ میں کیا مقام رکھتی ہے)،\qt@no{280}}%
\qt@newcmd\qurantrans@ur@cclxxxviii{اور اس دن سے ڈرو جس میں تم اﷲ کی طرف لوٹائے جاؤ گے، پھر ہر شخص کو جو کچھ عمل اس نے کیا ہے اس کی پوری پوری جزا دی جائے گی اور ان پر ظلم نہیں ہوگا،\qt@no{281}}%
\qt@newcmd\qurantrans@ur@cclxxxix{اے ایمان والو! جب تم کسی مقررہ مدت تک کے لئے آپس میں قرض کا معاملہ کرو تو اسے لکھ لیا کرو، اور تمہارے درمیان جو لکھنے والا ہو اسے چاہئے کہ انصاف کے ساتھ لکھے اور لکھنے والا لکھنے سے انکار نہ کرے جیسا کہ اسے اﷲ نے لکھنا سکھایا ہے، پس وہ لکھ دے (یعنی شرع اور ملکی دستور کے مطابق وثیقہ نویسی کا حق پوری دیانت سے ادا کرے)، اور مضمون وہ شخص لکھوائے جس کے ذمہ حق (یعنی قرض) ہو اور اسے چاہئے کہ اﷲ سے ڈرے جو اس کا پروردگار ہے اور اس (زرِ قرض) میں سے (لکھواتے وقت) کچھ بھی کمی نہ کرے، پھر اگر وہ شخص جس کے ذمہ حق واجب ہوا ہے ناسمجھ یا ناتواں ہو یا خود مضمون لکھوانے کی صلاحیت نہ رکھتا ہو تو اس کے کارندے کو چاہئے کہ وہ انصاف کے ساتھ لکھوا دے، اور اپنے لوگوں میں سے دو مردوں کو گواہ بنا لو، پھر اگر دونوں مرد میسر نہ ہوں تو ایک مرد اور دو عورتیں ہوں (یہ) ان لوگوں میں سے ہوں جنہیں تم گواہی کے لئے پسند کرتے ہو (یعنی قابلِ اعتماد سمجھتے ہو) تاکہ ان دو میں سے ایک عورت بھول جائے تو اس ایک کو دوسری یاد دلا دے، اور گواہوں کو جب بھی (گواہی کے لئے) بلایا جائے وہ انکار نہ کریں، اور معاملہ چھوٹا ہو یا بڑا اسے اپنی میعاد تک لکھ رکھنے میں اکتایا نہ کرو، یہ تمہارا دستاویز تیار کر لینا اﷲ کے نزدیک زیادہ قرینِ انصاف ہے اور گواہی کے لئے مضبوط تر اور یہ اس کے بھی قریب تر ہے کہ تم شک میں مبتلا نہ ہو سوائے اس کے کہ دست بدست ایسی تجارت ہو جس کا لین دین تم آپس میں کرتے رہتے ہو تو تم پر اس کے نہ لکھنے کا کوئی گناہ نہیں، اور جب بھی آپس میں خرید و فروخت کرو تو گواہ بنا لیا کرو، اور نہ لکھنے والے کو نقصان پہنچایا جائے اور نہ گواہ کو، اور اگر تم نے ایسا کیا تو یہ تمہاری حکم شکنی ہوگی، اور اﷲ سے ڈرتے رہو، اور اﷲ تمہیں (معاملات کی) تعلیم دیتا ہے اور اﷲ ہر چیز کا خوب جاننے والا ہے،\qt@no{282}}%
\qt@newcmd\qurantrans@ur@ccxc{اور اگر تم سفر پر ہو اور کوئی لکھنے والا نہ پاؤ تو باقبضہ رہن رکھ لیا کرو، پھر اگر تم میں سے ایک کو دوسرے پر اعتماد ہو تو جس کی دیانت پر اعتماد کیا گیا اسے چاہئے کہ اپنی امانت ادا کر دے اور وہ اﷲ سے ڈرتا رہے جو اس کا پالنے والا ہے، اور تم گواہی کو چُھپایا نہ کرو، اور جو شخص گواہی چُھپاتا ہے تو یقینا اس کا دل گنہگار ہے، اور اﷲ تمہارے اعمال کو خوب جاننے والا ہے،\qt@no{283}}%
\qt@newcmd\qurantrans@ur@ccxci{جو کچھ آسمانوں میں اور زمین میں ہے سب اﷲ کے لئے ہے، وہ باتیں جو تمہارے دلوں میں ہیں خواہ انہیں ظاہر کرو یا انہیں چھپاؤ اﷲ تم سے اس کا حساب لے گا، پھر جسے وہ چاہے گا بخش دے گا اور جسے چاہے گا عذاب دے گا، اور اﷲ ہر چیز پر کامل قدرت رکھتا ہے،\qt@no{284}}%
\qt@newcmd\qurantrans@ur@ccxcii{وہ) رسول (صلی اللہ علیہ وآلہ وسلم) اس پر ایمان لائے (یعنی اس کی تصدیق کی) جو کچھ ان پر ان کے رب کی طرف سے نازل کیا گیا اور اہلِ ایمان نے بھی، سب ہی (دل سے) اﷲ پر اور اس کے فرشتوں پر اور اس کی کتابوں پر اور اس کے رسولوں پر ایمان لائے، (نیز کہتے ہیں:) ہم اس کے پیغمبروں میں سے کسی کے درمیان بھی (ایمان لانے میں) فرق نہیں کرتے، اور (اﷲ کے حضور) عرض کرتے ہیں: ہم نے (تیرا حکم) سنا اور اطاعت (قبول) کی، اے ہمارے رب! ہم تیری بخشش کے طلب گار ہیں اور (ہم سب کو) تیری ہی طرف لوٹنا ہے،\qt@no{285}}%
\qt@newcmd\qurantrans@ur@ccxciii{اﷲ کسی جان کو اس کی طاقت سے بڑھ کر تکلیف نہیں دیتا، اس نے جو نیکی کمائی اس کے لئے اس کا اجر ہے اور اس نے جو گناہ کمایا اس پر اس کا عذاب ہے، اے ہمارے رب! اگر ہم بھول جائیں یا خطا کر بیٹھیں تو ہماری گرفت نہ فرما، اے ہمارے پروردگار! اور ہم پر اتنا (بھی) بوجھ نہ ڈال جیسا تو نے ہم سے پہلے لوگوں پر ڈالا تھا، اے ہمارے پروردگار! اور ہم پر اتنا بوجھ (بھی) نہ ڈال جسے اٹھانے کی ہم میں طاقت نہیں، اور ہمارے (گناہوں) سے درگزر فرما، اور ہمیں بخش دے، اور ہم پر رحم فرما، تو ہی ہمارا کارساز ہے پس ہمیں کافروں کی قوم پر غلبہ عطا فرما،\qt@no{286}}%
\qt@newcmd\qurantrans@ur@ccxciv{\basmalahur الف لام میم (حقیقی معنی اﷲ اور رسول صلی اللہ علیہ وآلہ وسلم ہی بہتر جانتے ہیں)،\qt@no{1}}%
\qt@newcmd\qurantrans@ur@ccxcv{اﷲ، اس کے سوا کوئی لائقِ عبادت نہیں (وہ) ہمیشہ زندہ رہنے والا ہے (سارے عالم کو اپنی تدبیر سے) قائم رکھنے والا ہے،\qt@no{2}}%
\qt@newcmd\qurantrans@ur@ccxcvi{اے حبیب!) اسی نے (یہ) کتاب آپ پر حق کے ساتھ نازل فرمائی ہے (یہ) ان (سب کتابوں) کی تصدیق کرنے والی ہے جو اس سے پہلے اتری ہیں اور اسی نے تورات اور انجیل نازل فرمائی ہے،\qt@no{3}}%
\qt@newcmd\qurantrans@ur@ccxcvii{جیسے) اس سے قبل لوگوں کی رہنمائی کے لئے (کتابیں اتاری گئیں) اور (اب اسی طرح) اس نے حق اور باطل میں امتیاز کرنے والا (قرآن) نازل فرمایا ہے، بیشک جو لوگ اﷲ کی آیتوں کا انکار کرتے ہیں ان کے لئے سنگین عذاب ہے، اور اﷲ بڑا غالب انتقام لینے والا ہے،\qt@no{4}}%
\qt@newcmd\qurantrans@ur@ccxcviii{یقینا اﷲ پر زمین اور آسمان کی کوئی بھی چیز مخفی نہیں،\qt@no{5}}%
\qt@newcmd\qurantrans@ur@ccxcix{وہی ہے جو (ماؤں کے) رحموں میں تمہاری صورتیں جس طرح چاہتا ہے بناتا ہے، اس کے سوا کوئی لائقِ پرستش نہیں (وہ) بڑا غالب بڑی حکمت والا ہے،\qt@no{6}}%
\qt@newcmd\qurantrans@ur@ccc{وہی ہے جس نے آپ پر کتاب نازل فرمائی جس میں سے کچھ آیتیں محکم (یعنی ظاہراً بھی صاف اور واضح معنی رکھنے والی) ہیں وہی (احکام) کتاب کی بنیاد ہیں اور دوسری آیتیں متشابہ (یعنی معنی میں کئی احتمال اور اشتباہ رکھنے والی) ہیں، سو وہ لوگ جن کے دلوں میں کجی ہے اس میں سے صرف متشابہات کی پیروی کرتے ہیں (فقط) فتنہ پروری کی خواہش کے زیرِ اثر اور اصل مراد کی بجائے من پسند معنی مراد لینے کی غرض سے، اور اس کی اصل مراد کو اﷲ کے سوا کوئی نہیں جانتا، اور علم میں کامل پختگی رکھنے والے کہتے ہیں کہ ہم اس پر ایمان لائے، ساری (کتاب) ہمارے رب کی طرف سے اتری ہے، اور نصیحت صرف اہلِ دانش کو ہی نصیب ہوتی ہے،\qt@no{7}}%
\qt@newcmd\qurantrans@ur@ccci{اور عرض کرتے ہیں:) اے ہمارے رب! ہمارے دلوں میں کجی پیدا نہ کر اس کے بعد کہ تو نے ہمیں ہدایت سے سرفراز فرمایا ہے اور ہمیں خاص اپنی طرف سے رحمت عطا فرما، بیشک تو ہی بہت عطا فرمانے والا ہے،\qt@no{8}}%
\qt@newcmd\qurantrans@ur@cccii{اے ہمارے رب! بیشک تو اس دن کہ جس میں کوئی شک نہیں سب لوگوں کو جمع فرمانے والا ہے، یقینا اﷲ (اپنے) وعدہ کے خلاف نہیں کرتا،\qt@no{9}}%
\qt@newcmd\qurantrans@ur@ccciii{بیشک جنہوں نے کفر کیا نہ ان کے مال انہیں اﷲ (کے عذاب) سے کچھ بھی بچا سکیں گے اور نہ ان کی اولاد، اور وہی لوگ دوزخ کا ایندھن ہیں،\qt@no{10}}%
\qt@newcmd\qurantrans@ur@ccciv{ان کا بھی) قومِ فرعون اور ان سے پہلی قوموں جیسا طریقہ ہے، جنہوں نے ہماری آیتوں کو جھٹلایا تو اﷲ نے ان کے گناہوں کے باعث انہیں پکڑ لیا، اور اﷲ سخت عذاب دینے والا ہے،\qt@no{11}}%
\qt@newcmd\qurantrans@ur@cccv{کافروں سے فرما دیں: تم عنقریب مغلوب ہو جاؤ گے اور جہنم کی طرف ہانکے جاؤ گے، اور وہ بہت ہی برا ٹھکانا ہے،\qt@no{12}}%
\qt@newcmd\qurantrans@ur@cccvi{بیشک تمہارے لئے ان دو جماعتوں میں ایک نشانی ہے (جو میدانِ بدر میں) آپس میں مقابل ہوئیں، ایک جماعت نے اﷲ کی راہ میں جنگ کی اور دوسری کافر تھی وہ انہیں (اپنی) آنکھوں سے اپنے سے دوگنا دیکھ رہے تھے، اور اﷲ اپنی مدد کے ذریعے جسے چاہتا ہے تقویت دیتا ہے، یقینا اس واقعہ میں آنکھ والوں کے لئے (بڑی) عبرت ہے،\qt@no{13}}%
\qt@newcmd\qurantrans@ur@cccvii{لوگوں کے لئے ان خواہشات کی محبت (خوب) آراستہ کر دی گئی ہے (جن میں) عورتیں اور اولاد اور سونے اور چاندی کے جمع کئے ہوئے خزانے اور نشان کئے ہوئے خوبصورت گھوڑے اور مویشی اور کھیتی (شامل ہیں)، یہ (سب) دنیوی زندگی کا سامان ہے، اور اﷲ کے پاس بہتر ٹھکانا ہے،\qt@no{14}}%
\qt@newcmd\qurantrans@ur@cccviii{اے حبیب!) آپ فرما دیں: کیا میں تمہیں ان سب سے بہترین چیز کی خبر دوں؟ (ہاں) پرہیزگاروں کے لئے ان کے رب کے پاس (ایسی) جنتیں ہیں جن کے نیچے نہریں بہتی ہیں وہ ان میں ہمیشہ رہیں گے (ان کے لئے) پاکیزہ بیویاں ہوں گی اور (سب سے بڑی بات یہ کہ) اﷲ کی طرف سے خوشنودی نصیب ہوگی، اور اﷲ بندوں کو خوب دیکھنے والا ہے،\qt@no{15}}%
\qt@newcmd\qurantrans@ur@cccix{یہ وہ لوگ ہیں) جو کہتے ہیں: اے ہمارے رب! ہم یقینا ایمان لے آئے ہیں سو ہمارے گناہ معاف فرما دے اور ہمیں دوزخ کے عذاب سے بچا لے،\qt@no{16}}%
\qt@newcmd\qurantrans@ur@cccx{یہ لوگ) صبر کرنے والے ہیں اور قول و عمل میں سچائی والے ہیں اور ادب و اطاعت میں جھکنے والے ہیں اور اﷲ کی راہ میں خرچ کرنے والے ہیں اور رات کے پچھلے پہر (اٹھ کر) اﷲ سے معافی مانگنے والے ہیں،\qt@no{17}}%
\qt@newcmd\qurantrans@ur@cccxi{اﷲ نے اس بات پر گواہی دی کہ اس کے سوا کوئی لائقِ عبادت نہیں اور فرشتوں نے اور علم والوں نے بھی (اور ساتھ یہ بھی) کہ وہ ہر تدبیر عدل کے ساتھ فرمانے والا ہے، اس کے سوا کوئی لائقِ پرستش نہیں وہی غالب حکمت والا ہے،\qt@no{18}}%
\qt@newcmd\qurantrans@ur@cccxii{بیشک دین اﷲ کے نزدیک اسلام ہی ہے، اور اہلِ کتاب نے جو اپنے پاس علم آجانے کے بعد اختلاف کیا وہ صرف باہمی حسد و عناد کے باعث تھا، اور جو کوئی اﷲ کی آیتوں کا انکار کرے تو بیشک اﷲ حساب میں جلدی فرمانے والا ہے،\qt@no{19}}%
\qt@newcmd\qurantrans@ur@cccxiii{اے حبیب!) اگر پھر بھی آپ سے جھگڑا کریں تو فرما دیں کہ میں نے اور جس نے (بھی) میری پیروی کی اپنا روئے نیاز اﷲ کے حضور جھکا دیا ہے، اور آپ اہلِ کتاب اور اَن پڑھ لوگوں سے فرما دیں: کیا تم بھی اﷲ کے حضور جھکتے ہو (یعنی اسلام قبول کرتے ہو)؟ پھر اگر وہ فرمانبرداری اختیار کر لیں تو وہ حقیقتاً ہدایت پا گئے، اور اگر منہ پھیر لیں تو آپ کے ذمہ فقط حکم پہنچا دینا ہی ہے، اور اﷲ بندوں کو خوب دیکھنے والا ہے،\qt@no{20}}%
\qt@newcmd\qurantrans@ur@cccxiv{یقینا جو لوگ اﷲ کی آیتوں کا انکار کرتے ہیں اور انبیاءکو ناحق قتل کرتے ہیں اور لوگوں میں سے بھی انہیں قتل کرتے ہیں جو عدل و انصاف کا حکم دیتے ہیں سو آپ انہیں دردناک عذاب کی خبر سنا دیں،\qt@no{21}}%
\qt@newcmd\qurantrans@ur@cccxv{یہ وہ لوگ ہیں جن کے اعمال دنیا اور آخرت (دونوں) میں غارت ہوگئے اور ان کا کوئی مددگار نہیں ہوگا،\qt@no{22}}%
\qt@newcmd\qurantrans@ur@cccxvi{کیا آپ نے ان لوگوں کو نہیں دیکھا جنہیں (علمِ) کتاب میں سے ایک حصہ دیا گیا وہ کتابِ الٰہی کی طرف بلائے جاتے ہیں تاکہ وہ (کتاب) ان کے درمیان (نزاعات کا) فیصلہ کر دے تو پھر ان میں سے ایک طبقہ منہ پھیر لیتا ہے اور وہ روگردانی کرنے والے ہی ہیں،\qt@no{23}}%
\qt@newcmd\qurantrans@ur@cccxvii{یہ (روگردانی کی جرأت) اس لئے کہ وہ کہتے ہیں کہ ہمیں گنتی کے چند دنوں کے سوا دوزخ کی آگ مَس نہیں کرے گی، اور وہ (اﷲ پر) جو بہتان باندھتے رہتے ہیں اس نے ان کو اپنے دین کے بارے میں فریب میں مبتلا کر دیا ہے،\qt@no{24}}%
\qt@newcmd\qurantrans@ur@cccxviii{سو کیا حال ہو گا جب ہم ان کو اس دن جس (کے بپا ہونے) میں کوئی شک نہیں جمع کریں گے، اور جس جان نے جو کچھ بھی (اعمال میں سے) کمایا ہو گا اسے اس کا پورا پورا بدلہ دیا جائے گا اور ان پر کوئی ظلم نہیں کیا جائے گا،\qt@no{25}}%
\qt@newcmd\qurantrans@ur@cccxix{اے حبیب! یوں) عرض کیجئے: اے اﷲ، سلطنت کے مالک! تُو جسے چاہے سلطنت عطا فرما دے اور جس سے چاہے سلطنت چھین لے اور تُو جسے چاہے عزت عطا فرما دے اور جسے چاہے ذلّت دے، ساری بھلائی تیرے ہی دستِ قدرت میں ہے، بیشک تُو ہر چیز پر بڑی قدرت والا ہے،\qt@no{26}}%
\qt@newcmd\qurantrans@ur@cccxx{تو ہی رات کو دن میں داخل کرتا ہے اور دن کو رات میں داخل کرتا ہے اور تُو ہی زندہ کو مُردہ سے نکالتا ہے اورمُردہ کو زندہ سے نکالتا ہے اور جسے چاہتا ہے بغیر حساب کے (اپنی نوازشات سے) بہرہ اندوز کرتا ہے،\qt@no{27}}%
\qt@newcmd\qurantrans@ur@cccxxi{مسلمانوں کو چاہئے کہ اہلِ ایمان کو چھوڑ کر کافروں کو دوست نہ بنائیں اور جو کوئی ایسا کرے گا اس کے لئے اﷲ (کی دوستی میں) سے کچھ نہیں ہوگا سوائے اس کے کہ تم ان (کے شر) سے بچنا چاہو، اور اﷲ تمہیں اپنی ذات (کے غضب) سے ڈراتا ہے، اور اﷲ ہی کی طرف لوٹ کر جانا ہے،\qt@no{28}}%
\qt@newcmd\qurantrans@ur@cccxxii{آپ فرما دیں کہ جو تمہارے سینوں میں ہے خواہ تم اسے چھپاؤ یا اسے ظاہر کر دو اﷲ اسے جانتا ہے، اور جو کچھ آسمانوں اور زمین میں ہے وہ خوب جانتا ہے، اور اﷲ ہر چیز پر بڑا قادر ہے،\qt@no{29}}%
\qt@newcmd\qurantrans@ur@cccxxiii{جس دن ہر جان ہر اس نیکی کو بھی (اپنے سامنے) حاضر پا لے گی جو اس نے کی تھی اور ہر برائی کو بھی جو اس نے کی تھی، تو وہ آرزو کرے گی: کاش! میرے اور اس برائی (یا اس دن) کے درمیان بہت زیادہ فاصلہ ہوتا، اور اﷲ تمہیں اپنی ذات (کے غضب) سے ڈراتا ہے، اور اﷲ بندوں پر بہت مہربان ہے،\qt@no{30}}%
\qt@newcmd\qurantrans@ur@cccxxiv{اے حبیب!) آپ فرما دیں: اگر تم اﷲ سے محبت کرتے ہو تو میری پیروی کرو تب اﷲ تمہیں (اپنا) محبوب بنا لے گا اور تمہارے لئے تمہارے گناہ معاف فرما دے گا، اور اﷲ نہایت بخشنے والا مہربان ہے،\qt@no{31}}%
\qt@newcmd\qurantrans@ur@cccxxv{آپ فرما دیں کہ اﷲ اور رسول (صلی اللہ علیہ وآلہ وسلم) کی اطاعت کرو پھر اگر وہ روگردانی کریں تو اﷲ کافروں کو پسند نہیں کرتا،\qt@no{32}}%
\qt@newcmd\qurantrans@ur@cccxxvi{بیشک اﷲ نے آدم (علیہ السلام) کو اور نوح (علیہ السلام) کو اور آلِ ابراہیم کو اور آلِ عمران کو سب جہان والوں پر (بزرگی میں) منتخب فرما لیا،\qt@no{33}}%
\qt@newcmd\qurantrans@ur@cccxxvii{یہ ایک ہی نسل ہے ان میں سے بعض بعض کی اولاد ہیں، اور اﷲ خوب سننے والا خوب جاننے والا ہے،\qt@no{34}}%
\qt@newcmd\qurantrans@ur@cccxxviii{اور (یاد کریں) جب عمران کی بیوی نے عرض کیا: اے میرے رب! جو میرے پیٹ میں ہے میں اسے (دیگر ذمہ داریوں سے) آزاد کر کے خالص تیری نذر کرتی ہوں سو تو میری طرف سے (یہ نذرانہ) قبول فرما لے، بیشک تو خوب سننے خوب جاننے والا ہے،\qt@no{35}}%
\qt@newcmd\qurantrans@ur@cccxxix{پھر جب اس نے لڑکی جنی تو عرض کرنے لگی: مولا! میں نے تو یہ لڑکی جنی ہے، حالانکہ جو کچھ اس نے جنا تھا اﷲ اسے خوب جانتا تھا، (وہ بولی:) اور لڑکا (جو میں نے مانگا تھا) ہرگز اس لڑکی جیسا نہیں (ہو سکتا) تھا (جو اﷲ نے عطا کی ہے)، اور میں نے اس کا نام ہی مریم (عبادت گزار) رکھ دیا ہے اور بیشک میں اس کو اور اس کی اولاد کو شیطان مردود (کے شر) سے تیری پناہ میں دیتی ہوں،\qt@no{36}}%
\qt@newcmd\qurantrans@ur@cccxxx{سو اس کے رب نے اس (مریم) کو اچھی قبولیت کے ساتھ قبول فرما لیا اور اسے اچھی پرورش کے ساتھ پروان چڑھایا اور اس کی نگہبانی زکریا (علیہ السلام) کے سپرد کر دی، جب بھی زکریا (علیہ السلام) اس کے پاس عبادت گاہ میں داخل ہوتے تو وہ اس کے پاس (نئی سے نئی) کھانے کی چیزیں موجود پاتے، انہوں نے پوچھا: اے مریم! یہ چیزیں تمہارے لئے کہاں سے آتی ہیں؟ اس نے کہا: یہ (رزق) اﷲ کے پاس سے آتا ہے، بیشک اﷲ جسے چاہتا ہے بے حساب رزق عطا کرتا ہے،\qt@no{37}}%
\qt@newcmd\qurantrans@ur@cccxxxi{اسی جگہ زکریا (علیہ السلام) نے اپنے رب سے دعا کی، عرض کیا: میرے مولا! مجھے اپنی جناب سے پاکیزہ اولاد عطا فرما، بیشک تو ہی دعا کا سننے والا ہے،\qt@no{38}}%
\qt@newcmd\qurantrans@ur@cccxxxii{ابھی وہ حجرے میں کھڑے نماز ہی پڑھ رہے تھے (یا دعا ہی کر رہے تھے) کہ انہیں فرشتوں نے آواز دی: بیشک اﷲ آپ کو (فرزند) یحیٰی (علیہ السلام) کی بشارت دیتا ہے جو کلمۃ اﷲ (یعنی عیسٰی علیہ السلام) کی تصدیق کرنے والا ہو گا اور سردار ہو گا اور عورتوں (کی رغبت) سے بہت محفوظ ہو گا اور (ہمارے) خاص نیکوکار بندوں میں سے نبی ہو گا،\qt@no{39}}%
\qt@newcmd\qurantrans@ur@cccxxxiii{زکریاعلیہ السلام نے) عرض کیا: اے میرے رب! میرے ہاں لڑکا کیسے ہو گا؟ درآنحالیکہ مجھے بڑھاپا پہنچ چکا ہے اور میری بیوی (بھی) بانجھ ہے، فرمایا: اسی طرح اﷲ جو چاہتا ہے کرتا ہے،\qt@no{40}}%
\qt@newcmd\qurantrans@ur@cccxxxiv{عرض کیا: اے میرے رب! میرے لئے کوئی نشانی مقرر فرما، فرمایا: تمہارے لئے نشانی یہ ہے کہ تم تین دن تک لوگوں سے سوائے اشارے کے بات نہیں کر سکو گے، اور اپنے رب کو کثرت سے یاد کرو اور شام اور صبح اس کی تسبیح کرتے رہو،\qt@no{41}}%
\qt@newcmd\qurantrans@ur@cccxxxv{اور جب فرشتوں نے کہا: اے مریم! بیشک اﷲ نے تمہیں منتخب کر لیا ہے اور تمہیں پاکیزگی عطا کی ہے اور تمہیں آج سارے جہان کی عورتوں پر برگزیدہ کر دیا ہے،\qt@no{42}}%
\qt@newcmd\qurantrans@ur@cccxxxvi{اے مریم! تم اپنے رب کی بڑی عاجزی سے بندگی بجا لاتی رہو اور سجدہ کرو اور رکوع کرنے والوں کے ساتھ رکوع کیا کرو،\qt@no{43}}%
\qt@newcmd\qurantrans@ur@cccxxxvii{اے محبوب!) یہ غیب کی خبریں ہیں جو ہم آپ کی طرف وحی فرماتے ہیں، حالانکہ آپ (اس وقت) ان کے پاس نہ تھے جب وہ (قرعہ اندازی کے طور پر) اپنے قلم پھینک رہے تھے کہ ان میں سے کون مریم (علیہا السلام) کی کفالت کرے اور نہ آپ اس وقت ان کے پاس تھے جب وہ آپس میں جھگڑ رہے تھے،\qt@no{44}}%
\qt@newcmd\qurantrans@ur@cccxxxviii{جب فرشتوں نے کہا: اے مریم! بیشک اﷲ تمہیں اپنے پاس سے ایک کلمۂ (خاص) کی بشارت دیتا ہے جس کا نام مسیح عیسٰی بن مریم (علیھما السلام) ہوگا وہ دنیا اور آخرت (دونوں) میں قدر و منزلت والا ہو گا اور اﷲ کے خاص قربت یافتہ بندوں میں سے ہوگا،\qt@no{45}}%
\qt@newcmd\qurantrans@ur@cccxxxix{اور وہ لوگوں سے گہوارے میں اور پختہ عمر میں (یکساں) گفتگو کرے گا اور وہ (اﷲ کے) نیکوکار بندوں میں سے ہو گا،\qt@no{46}}%
\qt@newcmd\qurantrans@ur@cccxl{مریم علیہا السلام نے) عرض کیا: اے میرے رب! میرے ہاں کیسے لڑکا ہوگا درآنحالیکہ مجھے تو کسی شخص نے ہاتھ تک نہیں لگایا، ارشاد ہوا: اسی طرح اﷲ جو چاہتا ہے پیدا فرماتا ہے، جب کسی کام (کے کرنے) کا فیصلہ فرما لیتا ہے تو اس سے فقط اتنا فرماتا ہے کہ ’ہو جا‘ وہ ہو جاتا ہے،\qt@no{47}}%
\qt@newcmd\qurantrans@ur@cccxli{اور اﷲ اسے کتاب اور حکمت اور تورات اور انجیل (سب کچھ) سکھائے گا،\qt@no{48}}%
\qt@newcmd\qurantrans@ur@cccxlii{اور وہ بنی اسرائیل کی طرف رسول ہو گا (ان سے کہے گا) کہ بیشک میں تمہارے پاس تمہارے رب کی جانب سے ایک نشانی لے کر آیا ہوں میں تمہارے لئے مٹی سے پرندے کی شکل جیسا (ایک پُتلا) بناتا ہوں پھر میں اس میں پھونک مارتا ہوں سو وہ اﷲ کے حکم سے فوراً اڑنے والا پرندہ ہو جاتا ہے، اور میں مادرزاد اندھے اور سفید داغ والے کو شفایاب کرتا ہوں اور میں اﷲ کے حکم سے مُردے کو زندہ کر دیتا ہوں، اور جو کچھ تم کھا کر آئے ہو اور جو کچھ تم اپنے گھروں میں جمع کرتے ہو میں تمہیں (وہ سب کچھ) بتا دیتا ہوں، بیشک اس میں تمہارے لئے نشانی ہے اگر تم ایمان رکھتے ہو،\qt@no{49}}%
\qt@newcmd\qurantrans@ur@cccxliii{اور میں اپنے سے پہلے اتری ہوئی (کتاب) تورات کی تصدیق کرنے والا ہوں اور یہ اس لئے کہ تمہاری خاطر بعض ایسی چیزیں حلال کر دوں جو تم پر حرام کر دی گئی تھیں اور تمہارے پاس تمہارے رب کی طرف سے نشانی لے کر آیا ہوں، سو اﷲ سے ڈرو اور میری اطاعت اختیار کر لو،\qt@no{50}}%
\qt@newcmd\qurantrans@ur@cccxliv{بیشک اﷲ میرا رب ہے اور تمہارا بھی (وہی) رب ہے پس اسی کی عبادت کرو، یہی سیدھا راستہ ہے،\qt@no{51}}%
\qt@newcmd\qurantrans@ur@cccxlv{پھر جب عیسٰی (علیہ السلام) نے ان کا کفر محسوس کیا تو اس نے کہا: اﷲ کی طرف کون لوگ میرے مددگار ہیں؟ تو اس کے مخلص ساتھیوں نے عرض کیا: ہم اﷲ (کے دین) کے مددگار ہیں، ہم اﷲ پر ایمان لائے ہیں، اور آپ گواہ رہیں کہ ہم یقیناً مسلمان ہیں،\qt@no{52}}%
\qt@newcmd\qurantrans@ur@cccxlvi{اے ہمارے رب! ہم اس کتاب پر ایمان لائے جو تو نے نازل فرمائی اور ہم نے اس رسول کی اتباع کی سو ہمیں (حق کی) گواہی دینے والوں کے ساتھ لکھ لے،\qt@no{53}}%
\qt@newcmd\qurantrans@ur@cccxlvii{پھر (یہودی) کافروں نے (عیسٰی علیہ السلام کے قتل کے لئے) خفیہ سازش کی اور اﷲ نے (عیسٰی علیہ السلام کو بچانے کے لئے) مخفی تدبیر فرمائی، اور اﷲ سب سے بہتر مخفی تدبیر فرمانے والا ہے،\qt@no{54}}%
\qt@newcmd\qurantrans@ur@cccxlviii{جب اﷲ نے فرمایا: اے عیسٰی! بیشک میں تمہیں پوری عمر تک پہنچانے والا ہوں اور تمہیں اپنی طرف (آسمان پر) اٹھانے والا ہوں اور تمہیں کافروں سے نجات دلانے والا ہوں اور تمہارے پیروکاروں کو (ان) کافروں پر قیامت تک برتری دینے والا ہوں، پھر تمہیں میری ہی طرف لوٹ کر آنا ہے سو جن باتوں میں تم جھگڑتے تھے میں تمہارے درمیان ان کا فیصلہ کر دوں گا،\qt@no{55}}%
\qt@newcmd\qurantrans@ur@cccxlix{پھر جو لوگ کافر ہوئے انہیں دنیا اور آخرت (دونوں میں) سخت عذاب دوں گا اور ان کا کوئی مددگار نہ ہو گا،\qt@no{56}}%
\qt@newcmd\qurantrans@ur@cccl{اور جو لوگ ایمان لائے اور انہوں نے نیک عمل کئے تو (اﷲ) انہیں ان کا بھرپور اجر دے گا، اور اﷲ ظالموں کو پسند نہیں کرتا،\qt@no{57}}%
\qt@newcmd\qurantrans@ur@cccli{یہ جو ہم آپ کو پڑھ کر سناتے ہیں (یہ) نشانیاں ہیں اور حکمت والی نصیحت ہے،\qt@no{58}}%
\qt@newcmd\qurantrans@ur@ccclii{بیشک عیسٰی (علیہ السلام) کی مثال اﷲ کے نزدیک آدم (علیہ السلام) کی سی ہے، جسے اس نے مٹی سے بنایا پھر (اسے) فرمایا ’ہو جا‘ وہ ہو گیا،\qt@no{59}}%
\qt@newcmd\qurantrans@ur@cccliii{امت کی تنبیہ کے لئے فرمایا:) یہ تمہارے رب کی طرف سے حق ہے پس شک کرنے والوں میں سے نہ ہو جانا،\qt@no{60}}%
\qt@newcmd\qurantrans@ur@cccliv{پس آپ کے پاس علم آجانے کے بعد جو شخص عیسٰی (علیہ السلام) کے معاملے میں آپ سے جھگڑا کرے تو آپ فرما دیں کہ آجاؤ ہم (مل کر) اپنے بیٹوں کو اور تمہارے بیٹوں کو اور اپنی عورتوں کو اور تمہاری عورتوں کو اور اپنے آپ کو بھی اور تمہیں بھی (ایک جگہ پر) بلا لیتے ہیں، پھر ہم مباہلہ (یعنی گڑگڑا کر دعا) کرتے ہیں اور جھوٹوں پر اﷲ کی لعنت بھیجتے ہیں،\qt@no{61}}%
\qt@newcmd\qurantrans@ur@ccclv{بیشک یہی سچا بیان ہے، اور کوئی بھی اﷲ کے سوا لائقِ عبادت نہیں، اور بیشک اﷲ ہی تو بڑا غالب حکمت والا ہے،\qt@no{62}}%
\qt@newcmd\qurantrans@ur@ccclvi{پھر اگر وہ لوگ روگردانی کریں تو یقینا اﷲ فساد کرنے والوں کو خوب جانتا ہے،\qt@no{63}}%
\qt@newcmd\qurantrans@ur@ccclvii{آپ فرما دیں: اے اہلِ کتاب! تم اس بات کی طرف آجاؤ جو ہمارے اور تمہارے درمیان یکساں ہے، (وہ یہ) کہ ہم اﷲ کے سوا کسی کی عبادت نہیں کریں گے اور ہم اس کے ساتھ کسی کو شریک نہیں ٹھہرائیں گے اور ہم میں سے کوئی ایک دوسرے کو اﷲ کے سوا رب نہیں بنائے گا، پھر اگر وہ روگردانی کریں تو کہہ دو کہ گواہ ہو جاؤ کہ ہم تو اﷲ کے تابع فرمان (مسلمان) ہیں،\qt@no{64}}%
\qt@newcmd\qurantrans@ur@ccclviii{اے اہلِ کتاب! تم ابراہیم (علیہ السلام) کے بارے میں کیوں جھگڑتے ہو (یعنی انہیں یہودی یا نصرانی کیوں ٹھہراتے ہو) حالانکہ تورات اور انجیل (جن پر تمہارے دونوں مذہبوں کی بنیاد ہے) تو نازل ہی ان کے بعد کی گئی تھیں، کیا تم (اتنی بھی) عقل نہیں رکھتے،\qt@no{65}}%
\qt@newcmd\qurantrans@ur@ccclix{سن لو! تم وہی لوگ ہو جو ان باتوں میں بھی جھگڑتے رہے ہو جن کا تمہیں (کچھ نہ کچھ) علم تھا مگر ان باتوں میں کیوں تکرار کرتے ہو جن کا تمہیں (سرے سے) کوئی علم ہی نہیں، اور اﷲ جانتا ہے اور تم نہیں جانتے،\qt@no{66}}%
\qt@newcmd\qurantrans@ur@ccclx{ابراہیم (علیہ السلام) نہ یہودی تھے اور نہ نصرانی وہ ہر باطل سے جدا رہنے والے (سچے) مسلمان تھے، اور وہ مشرکوں میں سے بھی نہ تھے،\qt@no{67}}%
\qt@newcmd\qurantrans@ur@ccclxi{بیشک سب لوگوں سے بڑھ کر ابراہیم (علیہ السلام) کے قریب (اور حق دار) تو وہی لوگ ہیں جنہوں نے ان (کے دین) کی پیروی کی ہے اور (وہ) یہی نبی (صلی اللہ علیہ وآلہ وسلم) اور (ان پر) ایمان لانے والے ہیں، اور اﷲ ایمان والوں کا مددگار ہے،\qt@no{68}}%
\qt@newcmd\qurantrans@ur@ccclxii{اے مسلمانو!) اہلِ کتاب میں سے ایک گروہ تو (شدید) خواہش رکھتا ہے کہ کاش وہ تمہیں گمراہ کر سکیں، مگر وہ فقط اپنے آپ ہی کو گمراہی میں مبتلا کئے ہوئے ہیں اور انہیں (اس بات کا) شعور نہیں،\qt@no{69}}%
\qt@newcmd\qurantrans@ur@ccclxiii{اے اہلِ کتاب! تم اﷲ کی آیتوں کا انکار کیوں کر رہے ہو حالانکہ تم خود گواہ ہو (یعنی تم اپنی کتابوں میں سب کچھ پڑھ چکے ہو)،\qt@no{70}}%
\qt@newcmd\qurantrans@ur@ccclxiv{اے اہلِ کتاب! تم حق کو باطل کے ساتھ کیوں خلط ملط کرتے ہو اور حق کو کیوں چھپاتے ہو حالانکہ تم جانتے ہو،\qt@no{71}}%
\qt@newcmd\qurantrans@ur@ccclxv{اور اہلِ کتاب کا ایک گروہ (لوگوں سے) کہتا ہے کہ تم اس کتاب (قرآن) پر جو مسلمانوں پر نازل کی گئی ہے دن چڑھے (یعنی صبح) ایمان لایا کرو اور شام کو انکار کر دیا کرو تاکہ (تمہیں دیکھ کر) وہ بھی برگشتہ ہو جائیں،\qt@no{72}}%
\qt@newcmd\qurantrans@ur@ccclxvi{اور کسی کی بات نہ مانو سوائے اس شخص کے جو تمہارے (ہی) دین کا پیرو ہو، فرما دیں کہ بیشک ہدایت تو (فقط) ہدایتِ الٰہی ہے (اور اپنے لوگوں سے مزید کہتے ہیں کہ یہ بھی ہرگز نہ ماننا) کہ جیسی کتاب (یا دِین) تمہیں دیا گیا اس جیسا کسی اور کو بھی دیا جائے گا یا یہ کہ کوئی تمہارے رب کے پاس تمہارے خلاف حجت لا سکے گا، فرما دیں: بیشک فضل تو اﷲ کے ہاتھ میں ہے، جسے چاہتا ہے عطا فرماتا ہے، اور اﷲ وسعت والا بڑے علم والا ہے،\qt@no{73}}%
\qt@newcmd\qurantrans@ur@ccclxvii{وہ جسے چاہتا ہے اپنی رحمت کے ساتھ خاص فرما لیتا ہے، اور اﷲ بڑے فضل والا ہے،\qt@no{74}}%
\qt@newcmd\qurantrans@ur@ccclxviii{اور اہلِ کتاب میں ایسے بھی ہیں کہ اگر آپ اس کے پاس مال کا ڈھیر امانت رکھ دیں تو وہ آپ کو لوٹا دے گا اور انہی میں ایسے بھی ہیں کہ اگر اس کے پاس ایک دینار امانت رکھ دیں تو آپ کو وہ بھی نہیں لوٹائے گا سوائے اس کے کہ آپ اس کے سر پر کھڑے رہیں، یہ اس لئے کہ وہ کہتے ہیں کہ اَن پڑھوں کے معاملہ میں ہم پر کوئی مؤاخذہ نہیں، اور اﷲ پر جھوٹ باندھتے ہیں اور انہیں خود (بھی) معلوم ہے،\qt@no{75}}%
\qt@newcmd\qurantrans@ur@ccclxix{ہاں جو اپنا وعدہ پورا کرے اور تقویٰ اختیار کرے (اس پر واقعی کوئی مؤاخذہ نہیں) سو بیشک اﷲ پرہیز گاروں سے محبت فرماتا ہے،\qt@no{76}}%
\qt@newcmd\qurantrans@ur@ccclxx{بیشک جو لوگ اﷲ کے عہد اور اپنی قَسموں کا تھوڑی سی قیمت کے عوض سودا کر دیتے ہیں یہی وہ لوگ ہیں جن کے لئے آخرت میں کوئی حصہ نہیں اور نہ قیامت کے دن اﷲ ان سے کلام فرمائے گا اور نہ ہی ان کی طرف نگاہ فرمائے گا اور نہ انہیں پاکیزگی دے گا اور ان کے لئے دردناک عذاب ہو گا،\qt@no{77}}%
\qt@newcmd\qurantrans@ur@ccclxxi{اور بیشک ان میں ایک گروہ ایسا بھی ہے جو کتاب پڑھتے ہوئے اپنی زبانوں کو مروڑ لیتے ہیں تاکہ تم ان کی الٹ پھیر کو بھی کتاب (کا حصّہ) سمجھو حالانکہ وہ کتاب میں سے نہیں ہے، اور کہتے ہیں: یہ (سب) اﷲ کی طرف سے ہے، اور وہ (ہرگز) اﷲ کی طرف سے نہیں ہے، اور وہ اﷲ پر جھوٹ گھڑتے ہیں اور (یہ) انہیں خود بھی معلوم ہے،\qt@no{78}}%
\qt@newcmd\qurantrans@ur@ccclxxii{کسی بشر کو یہ حق نہیں کہ اﷲ اسے کتاب اور حکمت اور نبوت عطا فرمائے پھر وہ لوگوں سے یہ کہنے لگے کہ تم اﷲ کو چھوڑ کر میرے بندے بن جاؤ بلکہ (وہ تو یہ کہے گا) تم اﷲ والے بن جاؤ اس سبب سے کہ تم کتاب سکھاتے ہو اور اس وجہ سے کہ تم خود اسے پڑھتے بھی ہو،\qt@no{79}}%
\qt@newcmd\qurantrans@ur@ccclxxiii{اور وہ پیغمبر تمہیں یہ حکم کبھی نہیں دیتا کہ تم فرشتوں اور پیغمبروں کو رب بنا لو، کیا وہ تمہارے مسلمان ہو جانے کے بعد (اب) تمہیں کفر کا حکم دے گا،\qt@no{80}}%
\qt@newcmd\qurantrans@ur@ccclxxiv{اور (اے محبوب! وہ وقت یاد کریں) جب اﷲ نے انبیاءسے پختہ عہد لیا کہ جب میں تمہیں کتاب اور حکمت عطا کر دوں پھر تمہارے پاس وہ (سب پر عظمت والا) رسول (صلی اللہ علیہ وآلہ وسلم) تشریف لائے جو ان کتابوں کی تصدیق فرمانے والا ہو جو تمہارے ساتھ ہوں گی تو ضرور بالضرور ان پر ایمان لاؤ گے اور ضرور بالضرور ان کی مدد کرو گے، فرمایا: کیا تم نے اِقرار کیا اور اس (شرط) پر میرا بھاری عہد مضبوطی سے تھام لیا؟ سب نے عرض کیا: ہم نے اِقرار کر لیا، فرمایا کہ تم گواہ ہو جاؤ اور میں بھی تمہارے ساتھ گواہوں میں سے ہوں،\qt@no{81}}%
\qt@newcmd\qurantrans@ur@ccclxxv{اب پوری نسل آدم کے لئے تنبیہاً فرمایا:) پھر جس نے اس (اقرار) کے بعد روگردانی کی پس وہی لوگ نافرمان ہوں گے،\qt@no{82}}%
\qt@newcmd\qurantrans@ur@ccclxxvi{کیا یہ اﷲ کے دین کے سوا کوئی اور دین چاہتے ہیں اور جو کوئی بھی آسمانوں اور زمین میں ہے اس نے خوشی سے یا لاچاری سے (بہرحال) اسی کی فرمانبرداری اختیار کی ہے اور سب اسی کی طرف لوٹائے جائیں گے،\qt@no{83}}%
\qt@newcmd\qurantrans@ur@ccclxxvii{آپ فرمائیں: ہم اﷲ پر ایمان لائے ہیں اور جو کچھ ہم پر اتارا گیا ہے اور جو کچھ ابراہیم اور اسماعیل اور اسحاق اور یعقوب (علیھم السلام) اور ان کی اولاد پر اتارا گیا ہے اور جو کچھ موسٰی اور عیسٰی اور جملہ انبیاء (علیھم السلام) کو ان کے رب کی طرف سے عطا کیا گیا ہے (سب پر ایمان لائے ہیں)، ہم ان میں سے کسی پر بھی ایمان میں فرق نہیں کرتے اور ہم اسی کے تابع فرمان ہیں،\qt@no{84}}%
\qt@newcmd\qurantrans@ur@ccclxxviii{اور جو کوئی اسلام کے سوا کسی اور دین کو چاہے گا تو وہ اس سے ہرگز قبول نہیں کیا جائے گا، اور وہ آخرت میں نقصان اٹھانے والوں میں سے ہوگا،\qt@no{85}}%
\qt@newcmd\qurantrans@ur@ccclxxix{اﷲ ان لوگوں کو کیونکر ہدایت فرمائے جو ایمان لانے کے بعد کافر ہو گئے حالانکہ وہ اس امر کی گواہی دے چکے تھے کہ یہ رسول سچا ہے اور ان کے پاس واضح نشانیاں بھی آچکی تھیں، اور اﷲ ظالم قوم کو ہدایت نہیں فرماتا،\qt@no{86}}%
\qt@newcmd\qurantrans@ur@ccclxxx{ایسے لوگوں کی سزا یہ ہے کہ ان پر اﷲ کی اور فرشتوں کی اور تمام انسانوں کی لعنت پڑتی رہے،\qt@no{87}}%
\qt@newcmd\qurantrans@ur@ccclxxxi{وہ اس پھٹکار میں ہمیشہ (گرفتار) رہیں گے اور ان سے اس عذاب میں کمی نہیں کی جائے گی اور نہ انہیں مہلت دی جائے گے،\qt@no{88}}%
\qt@newcmd\qurantrans@ur@ccclxxxii{سوائے ان لوگوں کے جنہوں نے اس کے بعد توبہ کر لی اور (اپنی) اصلاح کر لی، تو بیشک اﷲ بڑا بخشنے والا مہربان ہے،\qt@no{89}}%
\qt@newcmd\qurantrans@ur@ccclxxxiii{بیشک جن لوگوں نے اپنے ایمان کے بعد کفر کیا پھر وہ کفر میں بڑھتے گئے ان کی توبہ ہرگز قبول نہیں کی جائے گے، اور وہی لوگ گمراہ ہیں،\qt@no{90}}%
\qt@newcmd\qurantrans@ur@ccclxxxiv{بیشک جو لوگ کافر ہوئے اور حالتِ کفر میں ہی مر گئے سو ان میں سے کوئی شخص اگر زمین بھر سونا بھی (اپنی نجات کے لئے) معاوضہ میں دینا چاہے تو اس سے ہرگز قبول نہیں کیا جائے گا، انہی لوگوں کے لئے دردناک عذاب ہے اور ان کا کوئی مددگار نہیں ہو سکے گا،\qt@no{91}}%
\qt@newcmd\qurantrans@ur@ccclxxxv{تم ہرگز نیکی کو نہیں پہنچ سکو گے جب تک تم (اللہ کی راہ میں) اپنی محبوب چیزوں میں سے خرچ نہ کرو، اور تم جو کچھ بھی خرچ کرتے ہو بیشک اللہ اسے خوب جاننے والا ہے،\qt@no{92}}%
\qt@newcmd\qurantrans@ur@ccclxxxvi{تورات کے اترنے سے پہلے بنی اسرائیل کے لئے ہر کھانے کی چیز حلال تھی سوائے ان (چیزوں) کے جو یعقوب (علیہ السلام) نے خود اپنے اوپر حرام کر لی تھیں، فرما دیں: تورات لاؤ اور اسے پڑھو اگر تم سچے ہو،\qt@no{93}}%
\qt@newcmd\qurantrans@ur@ccclxxxvii{پھر اس کے بعد بھی جو شخص اللہ پر جھوٹ گھڑے تو وہی لوگ ظالم ہیں،\qt@no{94}}%
\qt@newcmd\qurantrans@ur@ccclxxxviii{فرما دیں کہ اللہ نے سچ فرمایا ہے، سو تم ابراہیم (علیہ السلام) کے دین کی پیروی کرو جو ہر باطل سے منہ موڑ کر صرف اللہ کے ہوگئے تھے، اور وہ مشرکوں میں سے نہیں تھے،\qt@no{95}}%
\qt@newcmd\qurantrans@ur@ccclxxxix{بیشک سب سے پہلا گھر جو لوگوں (کی عبادت) کے لئے بنایا گیا وہی ہے جو مکہّ میں ہے، برکت والا ہے اور سارے جہان والوں کے لئے (مرکزِ) ہدایت ہے،\qt@no{96}}%
\qt@newcmd\qurantrans@ur@cccxc{اس میں کھلی نشانیاں ہیں (ان میں سے ایک) ابراہیم (علیہ السلام) کی جائے قیام ہے، اور جو اس میں داخل ہوگیا امان پا گیا، اور اللہ کے لئے لوگوں پر اس گھر کا حج فرض ہے جو بھی اس تک پہنچنے کی استطاعت رکھتا ہو، اور جو (اس کا) منکر ہو تو بیشک اللہ سب جہانوں سے بے نیاز ہے،\qt@no{97}}%
\qt@newcmd\qurantrans@ur@cccxci{فرما دیں: اے اہلِ کتاب! تم اللہ کی آیتوں کا انکار کیوں کرتے ہو؟ اور اللہ تمہارے کاموں کا مشاہدہ فرما رہا ہے،\qt@no{98}}%
\qt@newcmd\qurantrans@ur@cccxcii{فرما دیں: اے اہلِ کتاب! جو شخص ایمان لے آیا ہے تم اسے اللہ کی راہ سے کیوں روکتے ہو؟ تم ان کی راہ میں بھی کجی چاہتے ہو حالانکہ تم (اس کے حق ہونے پر) خود گواہ ہو، اور اللہ تمہارے اعمال سے بے خبر نہیں،\qt@no{99}}%
\qt@newcmd\qurantrans@ur@cccxciii{اے ایمان والو! اگر تم اہلِ کتاب میں سے کسی گروہ کا بھی کہنا مانو گے تو وہ تمہارے ایمان (لانے) کے بعد پھر تمہیں کفر کی طرف لوٹا دیں گے،\qt@no{100}}%
\qt@newcmd\qurantrans@ur@cccxciv{اور تم (اب) کس طرح کفر کرو گے حالانکہ تم وہ (خوش نصیب) ہو کہ تم پر اللہ کی آیتیں تلاوت کی جاتی ہیں اور تم میں (خود) اللہ کے رسول (صلی اللہ علیہ وآلہ وسلم) موجود ہیں، اور جو شخص اللہ (کے دامن) کو مضبوط پکڑ لیتا ہے تو اسے ضرور سیدھی راہ کی طرف ہدایت کی جاتی ہے،\qt@no{101}}%
\qt@newcmd\qurantrans@ur@cccxcv{اے ایمان والو! اللہ سے ڈرا کرو جیسے اس سے ڈرنے کا حق ہے اور تمہاری موت صرف اسی حال پر آئے کہ تم مسلمان ہو،\qt@no{102}}%
\qt@newcmd\qurantrans@ur@cccxcvi{اور تم سب مل کر اللہ کی رسی کو مضبوطی سے تھام لو اور تفرقہ مت ڈالو، اور اپنے اوپر اللہ کی اس نعمت کو یاد کرو جب تم (ایک دوسرے کے) دشمن تھے تو اس نے تمہارے دلوں میں الفت پیدا کردی اور تم اس کی نعمت کے باعث آپس میں بھائی بھائی ہوگئے، اور تم (دوزخ کی) آگ کے گڑھے کے کنارے پر(پہنچ چکے) تھے پھر اس نے تمہیں اس گڑھے سے بچا لیا، یوں ہی اللہ تمہارے لئے اپنی نشانیاں کھول کر بیان فرماتا ہے تاکہ تم ہدایت پا جاؤ،\qt@no{103}}%
\qt@newcmd\qurantrans@ur@cccxcvii{اور تم میں سے ایسے لوگوں کی ایک جماعت ضرور ہونی چاہئے جو لوگوں کو نیکی کی طرف بلائیں اور بھلائی کا حکم دیں اور برائی سے روکیں، اور وہی لوگ بامراد ہیں،\qt@no{104}}%
\qt@newcmd\qurantrans@ur@cccxcviii{اور ان لوگوں کی طرح نہ ہو جانا جو فرقوں میں بٹ گئے تھے اور جب ان کے پاس واضح نشانیاں آچکیں اس کے بعد بھی اختلاف کرنے لگے، اور انہی لوگوں کے لئے سخت عذاب ہے،\qt@no{105}}%
\qt@newcmd\qurantrans@ur@cccxcix{جس دن کئی چہرے سفید ہوں گے اور کئی چہرے سیاہ ہوں گے، تو جن کے چہرے سیاہ ہو جائیں گے (ان سے کہا جائے گا:) کیا تم نے ایمان لانے کے بعد کفر کیا؟ تو جو کفر تم کرتے رہے تھے سواس کے عذاب (کا مزہ) چکھ لو،\qt@no{106}}%
\qt@newcmd\qurantrans@ur@cd{اور جن لوگوں کے چہرے سفید (روشن) ہوں گے تو وہ اللہ کی رحمت میں ہوں گے اور وہ اس میں ہمیشہ رہیں گے،\qt@no{107}}%
\qt@newcmd\qurantrans@ur@cdi{یہ اللہ کی آیتیں ہیں جنہیں ہم آپ پر حق کے ساتھ پڑھتے ہیں، اور اللہ جہان والوں پر ظلم نہیں چاہتا،\qt@no{108}}%
\qt@newcmd\qurantrans@ur@cdii{اور اللہ ہی کے لئے ہے جو کچھ آسمانوں اور زمین میں ہے اور سب کام اللہ ہی کی طرف لوٹائے جائیں گے،\qt@no{109}}%
\qt@newcmd\qurantrans@ur@cdiii{تم بہترین اُمّت ہو جو سب لوگوں (کی رہنمائی) کے لئے ظاہر کی گئی ہے، تم بھلائی کا حکم دیتے ہو اور برائی سے منع کرتے ہو اور اللہ پر ایمان رکھتے ہو، اور اگر اہلِ کتاب بھی ایمان لے آتے تو یقیناً ان کے لئے بہتر ہوتا، ان میں سے کچھ ایمان والے بھی ہیں اور ان میں سے اکثر نافرمان ہیں،\qt@no{110}}%
\qt@newcmd\qurantrans@ur@cdiv{یہ لوگ ستانے کے سوا تمہارا کچھ نہیں بگاڑ سکیں گے، اور اگر یہ تم سے جنگ کریں تو تمہارے سامنے پیٹھ پھیر جائیں گے، پھر ان کی مدد (بھی) نہیں کی جائے گے،\qt@no{111}}%
\qt@newcmd\qurantrans@ur@cdv{وہ جہاں کہیں بھی پائے جائیں ان پر ذلّت مسلط کر دی گئی ہے سوائے اس کے کہ انہیں کہیں اللہ کے عہد سے یا لوگوں کے عہد سے (پناہ دے دی جائے) اور وہ اللہ کے غضب کے سزاوار ہوئے ہیں اور ان پر محتاجی مسلط کی گئی ہے، یہ اس لئے کہ وہ اللہ کی آیتوں کا انکار کرتے تھے اور انبیاء کو ناحق قتل کرتے تھے، کیونکہ وہ نافرمان ہو گئے تھے اور (سرکشی میں) حد سے بڑھ گئے تھے،\qt@no{112}}%
\qt@newcmd\qurantrans@ur@cdvi{یہ سب برابر نہیں ہیں، اہلِ کتاب میں سے کچھ لوگ حق پر (بھی) قائم ہیں وہ رات کی ساعتوں میں اللہ کی آیات کی تلاوت کرتے ہیں اور سر بسجود رہتے ہیں،\qt@no{113}}%
\qt@newcmd\qurantrans@ur@cdvii{وہ اللہ پر اور آخرت کے دن پر ایمان لاتے ہیں اور بھلائی کا حکم دیتے ہیں اور برائی سے منع کرتے ہیں اور نیک کاموں میں تیزی سے بڑھتے ہیں، اور یہی لوگ نیکوکاروں میں سے ہیں،\qt@no{114}}%
\qt@newcmd\qurantrans@ur@cdviii{اور یہ لوگ جو نیک کام بھی کریں اس کی ناقدری نہیں کی جائے گے اور اللہ پرہیزگاروں کو خوب جاننے والا ہے،\qt@no{115}}%
\qt@newcmd\qurantrans@ur@cdix{یقینا جن لوگوں نے کفر کیا ہے نہ ان کے مال انہیں اللہ (کے عذاب) سے کچھ بھی بچا سکیں گے اور نہ ان کی اولاد، اور وہی لوگ جہنمی ہیں، جو اس میں ہمیشہ رہیں گے،\qt@no{116}}%
\qt@newcmd\qurantrans@ur@cdx{یہ لوگ) جو مال (بھی) اس دنیا کی زندگی میں خرچ کرتے ہیں اس کی مثال اس ہوا جیسی ہے جس میں سخت پالا ہو (اور) وہ ایسی قوم کی کھیتی پر جا پڑے جو اپنی جانوں پر ظلم کرتی ہو اور وہ اسے تباہ کر دے، اور اللہ نے ان پر کوئی ظلم نہیں کیا بلکہ وہ خود اپنی جانوں پر ظلم کرتے ہیں،\qt@no{117}}%
\qt@newcmd\qurantrans@ur@cdxi{اے ایمان والو! تم غیروں کو (اپنا) راز دار نہ بناؤ وہ تمہاری نسبت فتنہ انگیزی میں (کبھی) کمی نہیں کریں گے، وہ تمہیں سخت تکلیف پہنچنے کی خواہش رکھتے ہیں، بغض تو ان کی زبانوں سے خود ظاہر ہو چکا ہے، اور جو (عداوت) ان کے سینوں نے چھپا رکھی ہے وہ اس سے (بھی) بڑھ کر ہے۔ ہم نے تمہارے لئے نشانیاں واضح کر دی ہیں اگر تمہیں عقل ہو،\qt@no{118}}%
\qt@newcmd\qurantrans@ur@cdxii{آگاہ ہو جاؤ! تم وہ لوگ ہو کہ ان سے محبت رکھتے ہو اور وہ تمہیں پسند (تک) نہیں کرتے حالانکہ تم سب کتابوں پر ایمان رکھتے ہو، اور جب وہ تم سے ملتے ہیں (تو) کہتے ہیں: ہم ایمان لے آئے ہیں، اور جب اکیلے ہوتے ہیں تو تم پر غصے سے انگلیاں چباتے ہیں، فرما دیں: مر جاؤ اپنی گھٹن میں، بیشک اللہ دلوں کی (پوشیدہ) باتوں کو خوب جاننے والا ہے،\qt@no{119}}%
\qt@newcmd\qurantrans@ur@cdxiii{اگر تمہیں کوئی بھلائی پہنچے تو انہیں بری لگتی ہے اور تمہیں کوئی رنج پہنچے تو وہ اس سے خوش ہوتے ہیں، اور اگر تم صبر کرتے رہو اور تقوٰی اختیار کئے رکھو تو ان کا فریب تمہیں کوئی نقصان نہیں پہنچا سکے گا، جو کچھ وہ کر رہے ہیں بیشک اللہ اس پر احاطہ فرمائے ہوئے ہے،\qt@no{120}}%
\qt@newcmd\qurantrans@ur@cdxiv{اور (وہ وقت یاد کیجئے) جب آپ صبح سویرے اپنے درِ دولت سے روانہ ہو کر مسلمانوں کو (غزوۂ احد کے موقع پر) جنگ کے لئے مورچوں پر ٹھہرا رہے تھے، اور اللہ خوب سننے والا جاننے والا ہے،\qt@no{121}}%
\qt@newcmd\qurantrans@ur@cdxv{جب تم میں سے (بنو سلمہ خزرج اور بنوحارثہ اوس) دو گروہوں کا ارادہ ہوا کہ بزدلی کر جائیں، حالانکہ اللہ ان دونوں کا مدد گار تھا، اور ایمان والوں کو اللہ ہی پر بھروسہ کرنا چاہئے،\qt@no{122}}%
\qt@newcmd\qurantrans@ur@cdxvi{اور اللہ نے بدر میں تمہاری مدد فرمائی حالانکہ تم (اس وقت) بالکل بے سرو سامان تھے پس اللہ سے ڈرا کرو تاکہ تم شکر گزار بن جاؤ،\qt@no{123}}%
\qt@newcmd\qurantrans@ur@cdxvii{جب آپ مسلمانوں سے فرما رہے تھے کہ کیا تمہارے لئے یہ کافی نہیں کہ تمہارا رب تین ہزار اتارے ہوئے فرشتوں کے ذریعے تمہاری مدد فرمائے،\qt@no{124}}%
\qt@newcmd\qurantrans@ur@cdxviii{ہاں اگر تم صبر کرتے رہو اور پرہیزگاری قائم رکھو اور وہ (کفّار) تم پر اسی وقت (پورے) جوش سے حملہ آور ہو جائیں تو تمہارا رب پانچ ہزار نشان والے فرشتوں کے ذریعے تمہاری مدد فرمائے گا،\qt@no{125}}%
\qt@newcmd\qurantrans@ur@cdxix{اور اللہ نے اس (مدد) کو محض تمہارے لئے خوشخبری بنایا اور اس لئے کہ اس سے تمہارے دل مطمئن ہو جائیں، اور مدد تو صرف اللہ ہی کی طرف سے ہوتی ہے جو بڑا غالب حکمت والا ہے،\qt@no{126}}%
\qt@newcmd\qurantrans@ur@cdxx{مزید) اس لئے کہ (اللہ) کافروں کے ایک گروہ کو ہلاک کر دے یا انہیں ذلیل کر دے سو وہ ناکام ہو کر واپس پلٹ جائیں،\qt@no{127}}%
\qt@newcmd\qurantrans@ur@cdxxi{اے حبیب! اب) آپ کا اس معاملہ سے کوئی تعلق نہیں چاہے تو اللہ انہیں توبہ کی توفیق دے یا انہیں عذاب دے کیونکہ وہ ظالم ہیں،\qt@no{128}}%
\qt@newcmd\qurantrans@ur@cdxxii{اور اللہ ہی کے لئے ہے جو کچھ آسمانوں میں اور زمین میں ہے۔ وہ جسے چاہے بخش دے جسے چاہے عذاب دے، اور اللہ نہایت بخشنے والا مہربان ہے،\qt@no{129}}%
\qt@newcmd\qurantrans@ur@cdxxiii{اے ایمان والو! دو گنا اور چوگنا کر کے سود مت کھایا کرو، اور اللہ سے ڈرا کرو تاکہ تم فلاح پاؤ،\qt@no{130}}%
\qt@newcmd\qurantrans@ur@cdxxiv{اور اس آگ سے ڈرو جو کافروں کے لئے تیار کی گئی ہے،\qt@no{131}}%
\qt@newcmd\qurantrans@ur@cdxxv{اور اللہ کی اور رسول (صلی اللہ علیہ وآلہ وسلم) کی فرمانبرداری کرتے رہو تاکہ تم پر رحم کیا جائے،\qt@no{132}}%
\qt@newcmd\qurantrans@ur@cdxxvi{اور اپنے رب کی بخشش اور اس جنت کی طرف تیزی سے بڑھو جس کی وسعت میں سب آسمان اور زمین آجاتے ہیں، جو پرہیزگاروں کے لئے تیار کی گئی ہے،\qt@no{133}}%
\qt@newcmd\qurantrans@ur@cdxxvii{یہ وہ لوگ ہیں جو فراخی اور تنگی (دونوں حالتوں) میں خرچ کرتے ہیں اور غصہ ضبط کرنے والے ہیں اور لوگوں سے (ان کی غلطیوں پر) درگزر کرنے والے ہیں، اور اللہ احسان کرنے والوں سے محبت فرماتا ہے،\qt@no{134}}%
\qt@newcmd\qurantrans@ur@cdxxviii{اور (یہ) ایسے لوگ ہیں کہ جب کوئی برائی کر بیٹھتے ہیں یا اپنی جانوں پر ظلم کر بیٹھتے ہیں تو اللہ کا ذکر کرتے ہیں پھر اپنے گناہوں کی معافی مانگتے ہیں، اور اللہ کے سوا گناہوں کی بخشش کون کرتا ہے، اور پھر جو گناہ وہ کر بیٹھے تھے ان پر جان بوجھ کر اصرار بھی نہیں کرتے،\qt@no{135}}%
\qt@newcmd\qurantrans@ur@cdxxix{یہ وہ لوگ ہیں جن کی جزا ان کے رب کی طرف سے مغفرت ہے اور جنتیں ہیں جن کے نیچے نہریں رواں ہیں وہ ان میں ہمیشہ رہنے والے ہیں، اور (نیک) عمل کرنے والوں کا کیا ہی اچھا صلہ ہے،\qt@no{136}}%
\qt@newcmd\qurantrans@ur@cdxxx{تم سے پہلے (گذشتہ امتوں کے لئے قانونِ قدرت کے) بہت سے ضابطے گزر چکے ہیں سو تم زمین میں چلا پھرا کرو اور دیکھا کرو کہ جھٹلانے والوں کا کیا انجام ہوا،\qt@no{137}}%
\qt@newcmd\qurantrans@ur@cdxxxi{یہ قرآن لوگوں کے لئے واضح بیان ہے اور ہدایت ہے اور پرہیزگاروں کے لئے نصیحت ہے،\qt@no{138}}%
\qt@newcmd\qurantrans@ur@cdxxxii{اور تم ہمت نہ ہارو اور نہ غم کرو اور تم ہی غالب آؤ گے اگر تم (کامل) ایمان رکھتے ہو،\qt@no{139}}%
\qt@newcmd\qurantrans@ur@cdxxxiii{اگر تمہیں (اب) کوئی زخم لگا ہے تو (یاد رکھو کہ) ان لوگوں کو بھی اسی طرح کا زخم لگ چکا ہے، اور یہ دن ہیں جنہیں ہم لوگوں کے درمیان پھیرتے رہتے ہیں، اور یہ (گردشِ ا یّام) اس لئے ہے کہ اللہ اہلِ ایمان کی پہچان کرا دے اور تم میں سے بعض کو شہادت کا رتبہ عطا کرے، اور اللہ ظالموں کو پسند نہیں کرتا،\qt@no{140}}%
\qt@newcmd\qurantrans@ur@cdxxxiv{اور یہ اس لئے (بھی) ہے کہ اللہ ایمان والوں کو (مزید) نکھار دے (یعنی پاک و صاف کر دے) اور کافروں کو مٹا دے،\qt@no{141}}%
\qt@newcmd\qurantrans@ur@cdxxxv{کیا تم یہ گمان کئے ہوئے ہو کہ تم (یونہی) جنت میں چلے جاؤ گے؟ حالانکہ ابھی اللہ نے تم میں سے جہاد کرنے والوں کو پرکھا ہی نہیں ہے اور نہ ہی صبر کرنے والوں کو جانچا ہے،\qt@no{142}}%
\qt@newcmd\qurantrans@ur@cdxxxvi{اور تم تو اس کا سامنا کرنے سے پہلے (شہادت کی) موت کی تمنا کیا کرتے تھے، سو اب تم نے اسے اپنی آنکھوں کے سامنے دیکھ لیا ہے،\qt@no{143}}%
\qt@newcmd\qurantrans@ur@cdxxxvii{اور محمد (صلی اللہ علیہ وآلہ وسلم بھی تو) رسول ہی ہیں (نہ کہ خدا)، آپ سے پہلے بھی کئی پیغمبر (مصائب اور تکلیفیں جھیلتے ہوئے اس دنیا سے) گزر چکے ہیں، پھر اگر وہ وفات فرما جائیں یا شہید کر دیئے جائیں تو کیا تم اپنے (پچھلے مذہب کی طرف) الٹے پاؤں پھر جاؤ گے (یعنی کیا ان کی وفات یا شہادت کو معاذ اللہ دینِ اسلام کے حق نہ ہونے پر یا ان کے سچے رسول نہ ہونے پر محمول کرو گے)، اور جو کوئی اپنے الٹے پاؤں پھرے گا تو وہ اللہ کا ہرگز کچھ نہیں بگاڑے گا، اور اللہ عنقریب (مصائب پر ثابت قدم رہ کر) شکر کرنے والوں کو جزا عطا فرمائے گا،\qt@no{144}}%
\qt@newcmd\qurantrans@ur@cdxxxviii{اور کوئی شخص اللہ کے حکم کے بغیر نہیں مر سکتا (اس کا) وقت لکھا ہوا ہے، اور جو شخص دنیا کا انعام چاہتا ہے ہم اسے اس میں سے دے دیتے ہیں، اور جو آخرت کا انعام چاہتا ہے ہم اسے اس میں سے دے دیتے ہیں، اور ہم عنقریب شکر گزاروں کو (خوب) صلہ دیں گے،\qt@no{145}}%
\qt@newcmd\qurantrans@ur@cdxxxix{اور کتنے ہی انبیاءایسے ہوئے جنہوں نے جہاد کیا ان کے ساتھ بہت سے اللہ والے (اولیاء) بھی شریک ہوئے، تو نہ انہوں نے ان مصیبتوں کے باعث جو انہیں اللہ کی راہ میں پہنچیں ہمت ہاری اور نہ وہ کمزور پڑے اور نہ وہ جھکے، اور اللہ صبر کرنے والوں سے محبت کرتا ہے،\qt@no{146}}%
\qt@newcmd\qurantrans@ur@cdxl{اور ان کا کہنا کچھ نہ تھا سوائے اس التجا کے کہ اے ہمارے رب! ہمارے گناہ بخش دے اور ہمارے کام میں ہم سے ہونے والی زیادتیوں سے درگزر فرما اور ہمیں (اپنی راہ میں) ثابت قدم رکھ اور ہمیں کافروں پر غلبہ عطا فرما،\qt@no{147}}%
\qt@newcmd\qurantrans@ur@cdxli{پس اللہ نے انہیں دنیا کا بھی انعام عطا فرمایا اور آخرت کے بھی عمدہ اجر سے نوازا، اور اللہ (ان) نیکو کاروں سے پیار کرتا ہے (جو صرف اسی کو چاہتے ہیں)،\qt@no{148}}%
\qt@newcmd\qurantrans@ur@cdxlii{اے ایمان والو! اگر تم نے کافروں کا کہا مانا تو وہ تمہیں الٹے پاؤں (کفر کی جانب) پھیر دیں گے پھر تم نقصان اٹھاتے ہوئے پلٹو گے،\qt@no{149}}%
\qt@newcmd\qurantrans@ur@cdxliii{بلکہ اللہ تمہارا مولیٰ ہے اور وہ سب سے بہتر مدد فرمانے والا ہے،\qt@no{150}}%
\qt@newcmd\qurantrans@ur@cdxliv{ہم عنقریب کافروں کے دلوں میں (تمہارا) رعب ڈال دیں گے اس وجہ سے کہ انہوں نے اس چیز کو اللہ کا شریک ٹھہرایا ہے جس کے لئے اللہ نے کوئی سند نہیں اتاری اور ان کا ٹھکانا دوزخ ہے اور ظالموں کا (وہ) ٹھکانا بہت ہی برا ہے،\qt@no{151}}%
\qt@newcmd\qurantrans@ur@cdxlv{اور بیشک اللہ نے تمہیں اپنا وعدہ سچ کر دکھایا جب تم اس کے حکم سے انہیں قتل کر رہے تھے، یہاں تک کہ تم نے بزدلی کی اور (رسول صلی اللہ علیہ وآلہ وسلم کے) حکم کے بارے میں جھگڑنے لگے اور تم نے اس کے بعد (ان کی) نافرمانی کی جب کہ اللہ نے تمہیں وہ (فتح) دکھا دی تھی جو تم چاہتے تھے، تم میں سے کوئی دنیا کا خواہش مند تھا اور تم میں سے کوئی آخرت کا طلب گار تھا، پھر اس نے تمہیں ان سے (مغلوب کر کے) پھیر دیا تاکہ وہ تمہیں آزمائے، (بعد ازاں) اس نے تمہیں معاف کر دیا، اور اللہ اہلِ ایمان پر بڑے فضل والا ہے،\qt@no{152}}%
\qt@newcmd\qurantrans@ur@cdxlvi{جب تم (افراتفری کی حالت میں) بھاگے جا رہے تھے اور کسی کو مڑ کر نہیں دیکھتے تھے اور رسول (صلی اللہ علیہ وآلہ وسلم) اس جماعت میں (کھڑے) جو تمہارے پیچھے (ثابت قدم) رہی تھی تمہیں پکار رہے تھے پھر اس نے تمہیں غم پر غم دیا (یہ نصیحت و تربیت تھی) تاکہ تم اس پر جو تمہارے ہاتھ سے جاتا رہا اور اس مصیبت پر جو تم پر آن پڑی رنج نہ کرو، اور اللہ تمہارے کاموں سے خبردار ہے،\qt@no{153}}%
\qt@newcmd\qurantrans@ur@cdxlvii{پھر اس نے غم کے بعد تم پر (تسکین کے لئے) غنودگی کی صورت میں امان اتاری جو تم میں سے ایک جماعت پر چھا گئی اور ایک گروہ کو (جو منافقوں کا تھا) صرف اپنی جانوں کی فکر پڑی ہوئی تھی وہ اللہ کے ساتھ ناحق گمان کرتے تھے جو (محض) جاہلیت کے گمان تھے، وہ کہتے ہیں: کیا اس کام میں ہمارے لئے بھی کچھ (اختیار) ہے؟ فرما دیں کہ سب کام اللہ ہی کے ہاتھ میں ہے، وہ اپنے دلوں میں وہ باتیں چھپائے ہوئے ہیں جو آپ پر ظاہر نہیں ہونے دیتے۔ کہتے ہیں کہ اگر اس کام میں کچھ ہمارا اختیار ہوتا تو ہم اس جگہ قتل نہ کئے جاتے۔ فرما دیں: اگر تم اپنے گھروں میں (بھی) ہوتے تب بھی جن کا مارا جانا لکھا جا چکا تھا وہ ضرور اپنی قتل گاہوں کی طرف نکل کر آجاتے، اور یہ اس لئے (کیا گیا) ہے کہ جو کچھ تمہارے سینوں میں ہے اللہ اسے آزمائے اور جو (وسوسے) تمہارے دلوں میں ہیں انہیں خوب صاف کر دے، اور اللہ سینوں کی بات خوب جانتا ہے،\qt@no{154}}%
\qt@newcmd\qurantrans@ur@cdxlviii{بیشک جو لوگ تم میں سے اس دن بھاگ کھڑے ہوئے تھے جب دونوں فوجیں آپس میں گتھم گتھا ہو گئی تھیں تو انہیں محض شیطان نے پھسلا دیا تھا، ان کے کسی عمل کے باعث جس کے وہ مرتکب ہوئے، بیشک اللہ نے انہیں معاف فرما دیا، یقینا اللہ بہت بخشنے والا بڑے حلم والا ہے،\qt@no{155}}%
\qt@newcmd\qurantrans@ur@cdxlix{اے ایمان والو! تم ان کافروں کی طرح نہ ہو جاؤ جو اپنے ان بھائیوں کے بارے میں یہ کہتے ہیں جو (کہیں) سفر پر گئے ہوں یا جہاد کر رہے ہوں (اور وہاں مر جائیں) کہ اگر وہ ہمارے پاس ہوتے تو نہ مرتے اور نہ قتل کئے جاتے، تاکہ اللہ اس (گمان) کو ان کے دلوں میں حسرت بنائے رکھے، اور اللہ ہی زندہ رکھتا اور مارتا ہے، اور اللہ تمہارے اعمال خوب دیکھ رہا ہے،\qt@no{156}}%
\qt@newcmd\qurantrans@ur@cdl{اور اگر تم اللہ کی راہ میں قتل کر دئیے جاؤ یا تمہیں موت آجائے تو اللہ کی مغفرت اور رحمت اس (مال و متاع) سے بہت بہتر ہے جو تم جمع کرتے ہو،\qt@no{157}}%
\qt@newcmd\qurantrans@ur@cdli{اور اگر تم مر جاؤ یا مارے جاؤ تو تم (سب) اللہ ہی کے حضور جمع کئے جاؤ گے،\qt@no{158}}%
\qt@newcmd\qurantrans@ur@cdlii{اے حبیبِ والا صفات!) پس اللہ کی کیسی رحمت ہے کہ آپ ان کے لئے نرم طبع ہیں، اور اگر آپ تُندخُو (اور) سخت دل ہوتے تو لوگ آپ کے گرد سے چھٹ کر بھاگ جاتے، سو آپ ان سے درگزر فرمایا کریں اور ان کے لئے بخشش مانگا کریں اور (اہم) کاموں میں ان سے مشورہ کیا کریں، پھر جب آپ پختہ ارادہ کر لیں تو اللہ پر بھروسہ کیا کریں، بیشک اللہ توکّل والوں سے محبت کرتا ہے،\qt@no{159}}%
\qt@newcmd\qurantrans@ur@cdliii{اگر اللہ تمہاری مدد فرمائے تو تم پر کوئی غالب نہیں آسکتا، اور اگر وہ تمہیں بے سہارا چھوڑ دے تو پھر کون ایسا ہے جو اس کے بعد تمہاری مدد کر سکے، اور مؤمنوں کو اللہ ہی پر بھروسہ رکھنا چاہئے،\qt@no{160}}%
\qt@newcmd\qurantrans@ur@cdliv{اور کسی نبی کی نسبت یہ گمان ہی ممکن نہیں کہ وہ کچھ چھپائے گا، اور جو کوئی (کسی کا حق) چھپاتا ہے تو قیامت کے دن اسے وہ لانا پڑے گا جو اس نے چھپایا تھا، پھر ہر شخص کو اس کے عمل کا پورا بدلہ دیا جائے گا اور ان پر ظلم نہیں کیا جائے گا،\qt@no{161}}%
\qt@newcmd\qurantrans@ur@cdlv{بھلا وہ شخص جو اللہ کی مرضی کے تابع ہو گیا اس شخص کی طرح کیسے ہو سکتا ہے جو اللہ کے غضب کا سزاوار ہوا اور اس کا ٹھکانا جہنم ہے، اور وہ بہت ہی بری جگہ ہے،\qt@no{162}}%
\qt@newcmd\qurantrans@ur@cdlvi{اللہ کے حضور ان کے مختلف درجات ہیں، اور اللہ ان کے اعمال کو خوب دیکھتا ہے،\qt@no{163}}%
\qt@newcmd\qurantrans@ur@cdlvii{بیشک اللہ نے مسلمانوں پر بڑا احسان فرمایا کہ ان میں انہی میں سے (عظمت والا) رسول (صلی اللہ علیہ وآلہ وسلم) بھیجا جو ان پر اس کی آیتیں پڑھتا اور انہیں پاک کرتا ہے اور انہیں کتاب و حکمت کی تعلیم دیتا ہے، اگرچہ وہ لوگ اس سے پہلے کھلی گمراہی میں تھے،\qt@no{164}}%
\qt@newcmd\qurantrans@ur@cdlviii{کیا جب تمہیں ایک مصیبت آپہنچی حالانکہ تم اس سے دو چند (دشمن کو) پہنچا چکے تھے تو تم کہنے لگے کہ یہ کہاں سے آپڑی؟ فرما دیں: یہ تمہاری اپنی ہی طرف سے ہے بیشک اللہ ہر چیز پر خوب قدرت رکھتا ہے،\qt@no{165}}%
\qt@newcmd\qurantrans@ur@cdlix{اور اُس دن جو تکلیف تمہیں پہنچی جب دونوں لشکر باہم مقابل ہو گئے تھے سو وہ اللہ کے حکم (ہی) سے تھے اور یہ اس لئے کہ اللہ ایمان والوں کی پہچان کرا دے،\qt@no{166}}%
\qt@newcmd\qurantrans@ur@cdlx{اور ایسے لوگوں کی بھی پہچان کرا دے جو منافق ہیں، اور جب ان سے کہا گیا کہ آؤ اللہ کی راہ میں جنگ کرو یا (دشمن کے حملے کا) دفاع کرو، تو کہنے لگے: اگر ہم جانتے کہ (واقعۃً کسی ڈھب کی) لڑائی ہوگی (یا ہم اسے اللہ کی راہ میں جنگ جانتے) تو ضرور تمہاری پیروی کرتے، اس دن وہ (ظاہری) ایمان کی نسبت کھلے کفر سے زیادہ قریب تھے، وہ اپنے منہ سے وہ باتیں کہتے ہیں جو ان کے دلوں میں نہیں ہیں، اور اللہ (ان باتوں) کو خوب جانتا ہے جو وہ چھپا رہے ہیں،\qt@no{167}}%
\qt@newcmd\qurantrans@ur@cdlxi{یہ) وہی لوگ ہیں جنہوں نے باوجود اس کے کہ خود (گھروں میں) بیٹھے رہے اپنے بھائیوں کی نسبت کہا کہ اگر وہ ہمارا کہا مانتے تو نہ مارے جاتے، فرما دیں: تم اپنے آپ کو موت سے بچا لینا اگر تم سچے ہو،\qt@no{168}}%
\qt@newcmd\qurantrans@ur@cdlxii{اور جو لوگ اللہ کی راہ میں قتل کئے جائیں انہیں ہرگز مردہ خیال (بھی) نہ کرنا، بلکہ وہ اپنے ربّ کے حضور زندہ ہیں انہیں (جنت کی نعمتوں کا) رزق دیا جاتا ہے،\qt@no{169}}%
\qt@newcmd\qurantrans@ur@cdlxiii{وہ (حیاتِ جاودانی کی) ان (نعمتوں) پر فرحاں و شاداں رہتے ہیں جو اللہ نے انہیں اپنے فضل سے عطا فرما رکھی ہیں اور اپنے ان پچھلوں سے بھی جو (تاحال) ان سے نہیں مل سکے (انہیں ایمان اور طاعت کی راہ پر دیکھ کر) خوش ہوتے ہیں کہ ان پر بھی نہ کوئی خوف ہو گا اور نہ وہ رنجیدہ ہوں گے،\qt@no{170}}%
\qt@newcmd\qurantrans@ur@cdlxiv{وہ اللہ کی (تجلیّاتِ قُرب کی) نعمت اور (لذّاتِ وصال کے) فضل سے مسرور رہتے ہیں اور اس پر (بھی) کہ اللہ ایمان والوں کا اجر ضائع نہیں فرماتا،\qt@no{171}}%
\qt@newcmd\qurantrans@ur@cdlxv{جن لوگوں نے زخم کھا چکنے کے بعد بھی اللہ اور رسول (صلی اللہ علیہ وآلہ وسلم) کے حکم پر لبیک کہا، اُن میں جو صاحبانِ اِحسان ہیں اور پرہیزگار ہیں، ان کے لئے بڑا اَجر ہے،\qt@no{172}}%
\qt@newcmd\qurantrans@ur@cdlxvi{یہ) وہ لوگ (ہیں) جن سے لوگوں نے کہا کہ مخالف لوگ تمہارے مقابلے کے لئے (بڑی کثرت سے) جمع ہو چکے ہیں سو ان سے ڈرو، تو (اس بات نے) ان کے ایمان کو اور بڑھا دیا اور وہ کہنے لگے: ہمیں اللہ کافی ہے اور وہ کیا اچھا کارساز ہے،\qt@no{173}}%
\qt@newcmd\qurantrans@ur@cdlxvii{پھر وہ (مسلمان) اللہ کے انعام اور فضل کے ساتھ واپس پلٹے انہیں کوئی گزند نہ پہنچی اور انہوں نے رضائے الٰہی کی پیروی کی اور اللہ بڑے فضل والا ہے،\qt@no{174}}%
\qt@newcmd\qurantrans@ur@cdlxviii{بیشک یہ (مخبر) شیطان ہی ہے جو (تمہیں) اپنے دوستوں سے دھمکاتا ہے، پس ان سے مت ڈرا کرو اور مجھ ہی سے ڈرا کرو اگر تم مومن ہو،\qt@no{175}}%
\qt@newcmd\qurantrans@ur@cdlxix{اے غمگسارِ عالم!) جو لوگ کفر (کی مدد کرنے) میں بہت تیزی کرتے ہیں وہ آپ کو غمزدہ نہ کریں، وہ اللہ (کے دین) کا کچھ نہیں بگاڑ سکتے اور اللہ چاہتا ہے کہ ان کے لئے آخرت میں کوئی حصہ نہ رکھے اور ان کے لئے زبردست عذاب ہے،\qt@no{176}}%
\qt@newcmd\qurantrans@ur@cdlxx{بیشک جنہوں نے ایمان کے بدلے کفر خرید لیا ہے وہ اللہ کا کچھ نقصان نہیں کر سکتے اور ان کے لئے دردناک عذاب ہے،\qt@no{177}}%
\qt@newcmd\qurantrans@ur@cdlxxi{اور کافر یہ گمان ہرگز نہ کریں کہ ہم جو انہیں مہلت دے رہے ہیں (یہ) ان کی جانوں کے لئے بہتر ہے، ہم تو (یہ) مہلت انہیں صرف اس لئے دے رہے ہیں کہ وہ گناہ میں اور بڑھ جائیں، اور ان کے لئے (بالآخر) ذلّت انگیز عذاب ہے،\qt@no{178}}%
\qt@newcmd\qurantrans@ur@cdlxxii{اور اللہ مسلمانوں کو ہرگز اس حال پر نہیں چھوڑے گا جس پر تم (اس وقت) ہو جب تک وہ ناپاک کو پاک سے جدا نہ کر دے، اور اللہ کی یہ شان نہیں کہ (اے عامۃ الناس!) تمہیں غیب پر مطلع فرما دے لیکن اللہ اپنے رسولوں سے جسے چاہے (غیب کے علم کے لئے) چن لیتا ہے، سو تم اللہ اور اس کے رسولوں پر ایمان لاؤ، اور اگر تم ایمان لے آؤ اور تقویٰ اختیار کرو تو تمہارے لئے بڑا ثواب ہے،\qt@no{179}}%
\qt@newcmd\qurantrans@ur@cdlxxiii{اور جو لوگ اس (مال و دولت) میں سے دینے میں بخل کرتے ہیں جو اللہ نے انہیں اپنے فضل سے عطا کیا ہے وہ ہرگز اس بخل کو اپنے حق میں بہتر خیال نہ کریں، بلکہ یہ ان کے حق میں برا ہے، عنقریب روزِ قیامت انہیں (گلے میں) اس مال کا طوق پہنایا جائے گا جس میں وہ بخل کرتے رہے ہوں گے، اور اللہ ہی آسمانوں اور زمین کا وارث ہے (یعنی جیسے اب مالک ہے ایسے ہی تمہارے سب کے مر جانے کے بعد بھی وہی مالک رہے گا)، اور اللہ تمہارے سب کاموں سے آگاہ ہے،\qt@no{180}}%
\qt@newcmd\qurantrans@ur@cdlxxiv{بیشک اللہ نے ان لوگوں کی بات سن لی جو کہتے ہیں کہ اللہ محتاج ہے اور ہم غنی ہیں، اب ہم ان کی ساری باتیں اور ان کا انبیاءکو ناحق قتل کرنا (بھی) لکھ رکھیں گے، اور (روزِ قیامت) فرمائیں گے کہ (اب تم) جلا ڈالنے والے عذاب کا مزہ چکھو،\qt@no{181}}%
\qt@newcmd\qurantrans@ur@cdlxxv{یہ ان اعمال کا بدلہ ہے جو تمہارے ہاتھ خود آگے بھیج چکے ہیں اور بیشک اللہ بندوں پر ظلم کرنے والا نہیں ہے،\qt@no{182}}%
\qt@newcmd\qurantrans@ur@cdlxxvi{جو لوگ (یعنی یہود حیلہ جوئی کے طور پر) یہ کہتے ہیں کہ اللہ نے ہمیں یہ حکم بھیجا تھا کہ ہم کسی پیغمبر پر ایمان نہ لائیں جب تک وہ (اپنی رسالت کے ثبوت میں) ایسی قربانی نہ لائے جسے آگ (آکر) کھا جائے، آپ (ان سے) فرما دیں: بیشک مجھ سے پہلے بہت سے رسول واضح نشانیاں لے کر آئے اور اس نشانی کے ساتھ بھی (آئے) جو تم کہہ رہے ہو تو (اس کے باوجود) تم نے انہیں شہید کیوں کیا اگر تم (اتنے ہی) سچے ہو،\qt@no{183}}%
\qt@newcmd\qurantrans@ur@cdlxxvii{پھر بھی اگر آپ کو جھٹلائیں تو (محبوب آپ رنجیدہ خاطر نہ ہوں) آپ سے پہلے بھی بہت سے رسولوں کو جھٹلایا گیا جو واضح نشانیاں (یعنی معجزات) اور صحیفے اور روشن کتاب لے کر آئے تھے،\qt@no{184}}%
\qt@newcmd\qurantrans@ur@cdlxxviii{ہر جان موت کا مزہ چکھنے والی ہے، اور تمہارے اجر پورے کے پورے تو قیامت کے دن ہی دئیے جائیں گے، پس جو کوئی دوزخ سے بچا لیا گیا اور جنت میں داخل کیا گیا وہ واقعۃً کامیاب ہو گیا، اور دنیا کی زندگی دھوکے کے مال کے سوا کچھ بھی نہیں،\qt@no{185}}%
\qt@newcmd\qurantrans@ur@cdlxxix{اے مسلمانو!) تمہیں ضرور بالضرور تمہارے اموال اور تمہاری جانوں میں آزمایا جائے گا، اور تمہیں بہر صورت ان لوگوں سے جنہیں تم سے پہلے کتاب دی گئی تھی اور ان لوگوں سے جو مشرک ہیں بہت سے اذیت ناک (طعنے) سننے ہوں گے، اور اگر تم صبر کرتے رہو اور تقوٰی اختیار کئے رکھو تو یہ بڑی ہمت کے کاموں سے ہے،\qt@no{186}}%
\qt@newcmd\qurantrans@ur@cdlxxx{اور جب اللہ نے ان لوگوں سے پختہ وعدہ لیا جنہیں کتاب عطا کی گئی تھی کہ تم ضرور اسے لوگوں سے صاف صاف بیان کرو گے اور (جو کچھ اس میں بیان ہوا ہے) اسے نہیں چھپاؤ گے تو انہوں نے اس عہد کو پسِ پشت ڈال دیا اور اس کے بدلے تھوڑی سی قیمت وصول کر لی، سو یہ ان کی بہت ہی بُری خریداری ہے،\qt@no{187}}%
\qt@newcmd\qurantrans@ur@cdlxxxi{آپ ایسے لوگوں کو ہرگز (نجات پانے والا) خیال نہ کریں جو اپنی کارستانیوں پر خوش ہو رہے ہیں اور ناکردہ اعمال پر بھی اپنی تعریف کے خواہش مند ہیں، (دوبارہ تاکید کے لئے فرمایا:) پس آپ انہیں ہرگز عذاب سے نجات پانے والا نہ سمجھیں، اور ان کے لئے دردناک عذاب ہے،\qt@no{188}}%
\qt@newcmd\qurantrans@ur@cdlxxxii{اور سب آسمانوں اور زمین کی بادشاہی اللہ ہی کے لئے ہے اور اللہ ہر چیز پر قادر ہے (سو تم اپنا دھیان اور توکّل اسی پر رکھو)،\qt@no{189}}%
\qt@newcmd\qurantrans@ur@cdlxxxiii{بیشک آسمانوں اور زمین کی تخلیق میں اور شب و روز کی گردش میں عقلِ سلیم والوں کے لئے (اللہ کی قدرت کی) نشانیاں ہیں،\qt@no{190}}%
\qt@newcmd\qurantrans@ur@cdlxxxiv{یہ وہ لوگ ہیں جو (سراپا نیاز بن کر) کھڑے اور (سراپا ادب بن کر) بیٹھے اور (ہجر میں تڑپتے ہوئے) اپنی کروٹوں پر (بھی) اللہ کو یاد کرتے رہتے ہیں اور آسمانوں اور زمین کی تخلیق (میں کارفرما اس کی عظمت اور حُسن کے جلووں) میں فکر کرتے رہتے ہیں، (پھر اس کی معرفت سے لذت آشنا ہو کر پکار اٹھتے ہیں:) اے ہمارے رب! تو نے یہ (سب کچھ) بے حکمت اور بے تدبیر نہیں بنایا، تو (سب کوتاہیوں اور مجبوریوں سے) پاک ہے پس ہمیں دوزخ کے عذاب سے بچا لے،\qt@no{191}}%
\qt@newcmd\qurantrans@ur@cdlxxxv{اے ہمارے رب! بیشک تو جسے دوزخ میں ڈال دے تو تُو نے اسے واقعۃً رسوا کر دیا، اور ظالموں کے لئے کوئی مددگار نہیں ہے،\qt@no{192}}%
\qt@newcmd\qurantrans@ur@cdlxxxvi{اے ہمارے رب! (ہم تجھے بھولے ہوئے تھے) سو ہم نے ایک ندا دینے والے کو سنا جو ایمان کی ندا دے رہا تھا کہ (لوگو!) اپنے رب پر ایمان لاؤ تو ہم ایمان لے آئے۔ اے ہمارے رب! اب ہمارے گناہ بخش دے اور ہماری خطاؤں کو ہمارے (نوشتۂ اعمال) سے محو فرما دے اور ہمیں نیک لوگوں کی سنگت میں موت دے،\qt@no{193}}%
\qt@newcmd\qurantrans@ur@cdlxxxvii{اے ہمارے رب! اور ہمیں وہ سب کچھ عطا فرما جس کا تو نے ہم سے اپنے رسولوں کے ذریعے وعدہ فرمایا ہے اور ہمیں قیامت کے دن رسوا نہ کر، بیشک تو وعدہ کے خلاف نہیں کرتا،\qt@no{194}}%
\qt@newcmd\qurantrans@ur@cdlxxxviii{پھر ان کے رب نے ان کی دعا قبول فرما لی (اور فرمایا:) یقیناً میں تم میں سے کسی محنت والے کی مزدوری ضائع نہیں کرتا خواہ مرد ہو یا عورت، تم سب ایک دوسرے میں سے (ہی) ہو، پس جن لوگوں نے (اللہ کے لئے) وطن چھوڑ دیئے اور (اسی کے باعث) اپنے گھروں سے نکال دیئے گئے اور میری راہ میں ستائے گئے اور (میری خاطر) لڑے اور مارے گئے تو میں ضرور ان کے گناہ ان (کے نامۂ اعمال) سے مٹا دوں گا اور انہیں یقیناً ان جنتوں میں داخل کروں گا جن کے نیچے نہریں بہتی ہوں گی، یہ اللہ کے حضور سے اجر ہے، اور اللہ ہی کے پاس (اس سے بھی) بہتر اجر ہے،\qt@no{195}}%
\qt@newcmd\qurantrans@ur@cdlxxxix{اے اللہ کے بندے!) کافروں کا شہروں میں (عیش و عشرت کے ساتھ) گھومنا پھرنا تجھے کسی دھوکہ میں نہ ڈال دے،\qt@no{196}}%
\qt@newcmd\qurantrans@ur@cdxc{یہ تھوڑی سی (چند دنوں کی) متاع ہے، پھر ان کا ٹھکانا دوزخ ہوگا، اور وہ بہت ہی برا ٹھکانا ہے،\qt@no{197}}%
\qt@newcmd\qurantrans@ur@cdxci{لیکن جو لوگ اپنے رب سے ڈرتے رہے ان کے لئے بہشتیں ہیں جن کے نیچے نہریں بہہ رہی ہیں، وہ ان میں ہمیشہ رہنے والے ہیں، اللہ کے ہاں سے (ان کی) مہمانی ہے اور (پھر اس کا حریمِ قُرب، جلوۂ حُسن اور نعمتِ وصال، الغرض) جو کچھ بھی اللہ کے پاس ہے وہ نیک لوگوں کے لئے بہت ہی اچھا ہے،\qt@no{198}}%
\qt@newcmd\qurantrans@ur@cdxcii{اور بیشک کچھ اہلِ کتاب ایسے بھی ہیں جو اللہ پر ایمان رکھتے ہیں اور اس کتاب پر بھی (ایمان لاتے ہیں) جو تمہاری طرف نازل کی گئی ہے اور جو ان کی طرف نازل کی گئی اور ان کے دل اللہ کے حضور جھکے رہتے ہیں اور اللہ کی آیتوں کے عوض قلیل دام وصول نہیں کرتے، یہ وہ لوگ ہیں جن کا اجر ان کے رب کے پاس ہے، بیشک اللہ حساب میں جلدی فرمانے والا ہے،\qt@no{199}}%
\qt@newcmd\qurantrans@ur@cdxciii{اے ایمان والو! صبر کرو اور ثابت قدمی میں (دشمن سے بھی) زیادہ محنت کرو اور (جہاد کے لئے) خوب مستعد رہو، اور (ہمیشہ) اللہ کا تقوٰی قائم رکھو تاکہ تم کامیاب ہو سکو،\qt@no{200}}%
\qt@newcmd\qurantrans@ur@cdxciv{\basmalahur اے لوگو! اپنے رب سے ڈرو جس نے تمہاری پیدائش (کی ابتداء) ایک جان سے کی پھر اسی سے اس کا جوڑ پیدا فرمایا پھر ان دونوں میں سے بکثرت مردوں اور عورتوں (کی تخلیق) کو پھیلا دیا، اور ڈرو اس اللہ سے جس کے واسطے سے تم ایک دوسرے سے سوال کرتے ہو اور قرابتوں (میں بھی تقوٰی اختیار کرو)، بیشک اللہ تم پر نگہبان ہے،\qt@no{1}}%
\qt@newcmd\qurantrans@ur@cdxcv{اور یتیموں کو ان کے مال دے دو اور بُری چیز کو عمدہ چیز سے نہ بدلا کرو اور نہ ان کے مال اپنے مالوں میں ملا کر کھایا کرو، یقیناً یہ بہت بڑا گناہ ہے،\qt@no{2}}%
\qt@newcmd\qurantrans@ur@cdxcvi{اور اگر تمہیں اندیشہ ہو کہ تم یتیم لڑکیوں کے بارے میں انصاف نہ کر سکو گے تو ان عورتوں سے نکاح کرو جو تمہارے لئے پسندیدہ اور حلال ہوں، دو دو اور تین تین اور چار چار (مگر یہ اجازت بشرطِ عدل ہے)، پھر اگر تمہیں اندیشہ ہو کہ تم (زائد بیویوں میں) عدل نہیں کر سکو گے تو صرف ایک ہی عورت سے (نکاح کرو) یا وہ کنیزیں جو (شرعاً) تمہاری ملکیت میں آئی ہوں، یہ بات اس سے قریب تر ہے کہ تم سے ظلم نہ ہو،\qt@no{3}}%
\qt@newcmd\qurantrans@ur@cdxcvii{اور عورتوں کو ان کے مَہر خوش دلی سے ادا کیا کرو، پھر اگر وہ اس (مَہر) میں سے کچھ تمہارے لئے اپنی خوشی سے چھوڑ دیں تو تب اسے (اپنے لئے) سازگار اور خوشگوار سمجھ کر کھاؤ،\qt@no{4}}%
\qt@newcmd\qurantrans@ur@cdxcviii{اور تم بے سمجھوں کو اپنے (یا ان کے) مال سپرد نہ کرو جنہیں اللہ نے تمہاری معیشت کی استواری کا سبب بنایا ہے۔ ہاں انہیں اس میں سے کھلاتے رہو اور پہناتے رہو اور ان سے بھلائی کی بات کیا کرو،\qt@no{5}}%
\qt@newcmd\qurantrans@ur@cdxcix{اور یتیموں کی (تربیتہً) جانچ اور آزمائش کرتے رہو یہاں تک کہ نکاح (کی عمر) کو پہنچ جائیں پھر اگر تم ان میں ہوشیاری (اور حُسنِ تدبیر) دیکھ لو تو ان کے مال ان کے حوالے کر دو، اور ان کے مال فضول خرچی اور جلد بازی میں (اس اندیشے سے) نہ کھا ڈالو کہ وہ بڑے ہو (کر واپس لے) جائیں گے، اور جو کوئی خوشحال ہو وہ (مالِ یتیم سے) بالکل بچا رہے اور جو (خود) نادار ہو اسے (صرف) مناسب حد تک کھانا چاہئے، اور جب تم ان کے مال ان کے سپرد کرنے لگو تو ان پر گواہ بنا لیا کرو، اور حساب لینے والا اللہ ہی کافی ہے،\qt@no{6}}%
\qt@newcmd\qurantrans@ur@d{مردوں کے لئے اس (مال) میں سے حصہ ہے جو ماں باپ اور قریبی رشتہ داروں نے چھوڑا ہو اور عورتوں کے لئے (بھی) ماں باپ اور قریبی رشتہ داروں کے ترکہ میں سے حصہ ہے۔ وہ ترکہ تھوڑا ہو یا زیادہ (اللہ کا) مقرر کردہ حصہ ہے،\qt@no{7}}%
\qt@newcmd\qurantrans@ur@di{اور اگر تقسیمِ (وراثت) کے موقع پر (غیر وارث) رشتہ دار اور یتیم اور محتاج موجود ہوں تو اس میں سے کچھ انہیں بھی دے دو اور ان سے نیک بات کہو،\qt@no{8}}%
\qt@newcmd\qurantrans@ur@dii{اور (یتیموں سے معاملہ کرنے والے) لوگوں کو ڈرنا چاہئے کہ اگر وہ اپنے پیچھے ناتواں بچے چھوڑ جاتے تو (مرتے وقت) ان بچوں کے حال پر (کتنے) خوفزدہ (اور فکر مند) ہوتے، سو انہیں (یتیموں کے بارے میں) اللہ سے ڈرتے رہنا چاہئے اور (ان سے) سیدھی بات کہنی چاہئے،\qt@no{9}}%
\qt@newcmd\qurantrans@ur@diii{بیشک جو لوگ یتیموں کے مال ناحق طریقے سے کھاتے ہیں وہ اپنے پیٹوں میں نری آگ بھرتے ہیں، اور وہ جلد ہی دہکتی ہوئی آگ میں جا گریں گے،\qt@no{10}}%
\qt@newcmd\qurantrans@ur@div{اللہ تمہیں تمہاری اولاد (کی وراثت) کے بارے میں حکم دیتا ہے کہ لڑکے کے لئے دو لڑکیوں کے برابر حصہ ہے، پھر اگر صرف لڑکیاں ہی ہوں (دو یا) دو سے زائد تو ان کے لئے اس ترکہ کا دو تہائی حصہ ہے، اور اگر وہ اکیلی ہو تو اس کے لئے آدھا ہے، اور مُورِث کے ماں باپ کے لئے ان دونوں میں سے ہر ایک کو ترکہ کا چھٹا حصہ (ملے گا) بشرطیکہ مُورِث کی کوئی اولاد ہو، پھر اگر اس میت (مُورِث) کی کوئی اولاد نہ ہو اور اس کے وارث صرف اس کے ماں باپ ہوں تو اس کی ماں کے لئے تہائی ہے (اور باقی سب باپ کا حصہ ہے)، پھر اگر مُورِث کے بھائی بہن ہوں تو اس کی ماں کے لئے چھٹا حصہ ہے (یہ تقسیم) اس وصیت (کے پورا کرنے) کے بعد جو اس نے کی ہو یا قرض (کی ادائیگی) کے بعد (ہو گی)، تمہارے باپ اور تمہارے بیٹے تمہیں معلوم نہیں کہ فائدہ پہنچانے میں ان میں سے کون تمہارے قریب تر ہے، یہ (تقسیم) اللہ کی طرف سے فریضہ (یعنی مقرر) ہے، بیشک اللہ خوب جاننے والا بڑی حکمت والا ہے،\qt@no{11}}%
\qt@newcmd\qurantrans@ur@dv{اور تمہارے لئے اس (مال) کا آدھا حصہ ہے جو تمہاری بیویاں چھوڑ جائیں بشرطیکہ ان کی کوئی اولاد نہ ہو، پھر اگر ان کی کوئی اولاد ہو تو تمہارے لئے ان کے ترکہ سے چوتھائی ہے (یہ بھی) اس وصیت (کے پورا کرنے) کے بعد جو انہوں نے کی ہو یا قرض (کی ادائیگی) کے بعد، اور تمہاری بیویوں کا تمہارے چھوڑے ہوئے (مال) میں سے چوتھا حصہ ہے بشرطیکہ تمہاری کوئی اولاد نہ ہو، پھر اگر تمہاری کوئی اولاد ہو تو ان کے لئے تمہارے ترکہ میں سے آٹھواں حصہ ہے تمہاری اس (مال) کی نسبت کی ہوئی وصیت (پوری کرنے) یا (تمہارے) قرض کی ادائیگی کے بعد، اور اگر کسی ایسے مرد یا عورت کی وراثت تقسیم کی جا رہی ہو جس کے نہ ماں باپ ہوں نہ کوئی اولاد اور اس کا (ماں کی طرف سے) ایک بھائی یا ایک بہن ہو (یعنی اخیافی بھائی یا بہن) تو ان دونوں میں سے ہر ایک کے لئے چھٹا حصہ ہے، پھر اگر وہ بھائی بہن ایک سے زیادہ ہوں تو سب ایک تہائی میں شریک ہوں گے (یہ تقسیم بھی) اس وصیت کے بعد (ہو گی) جو (وارثوں کو) نقصان پہنچائے بغیر کی گئی ہو یا قرض (کی ادائیگی) کے بعد، یہ اللہ کی طرف سے حکم ہے، اور اللہ خوب علم و حلم والا ہے،\qt@no{12}}%
\qt@newcmd\qurantrans@ur@dvi{یہ اللہ کی (مقرر کردہ) حدیں ہیں، اور جو کوئی اللہ اور اس کے رسول (صلی اللہ علیہ وآلہ وسلم) کی فرمانبرداری کرے اسے وہ بہشتوں میں داخل فرمائے گا جن کے نیچے نہریں رواں ہیں ان میں ہمیشہ رہیں گے، اور یہ بڑی کامیابی ہے،\qt@no{13}}%
\qt@newcmd\qurantrans@ur@dvii{اور جو کوئی اللہ اور اس کے رسول (صلی اللہ علیہ وآلہ وسلم) کی نافرمانی کرے اور اس کی حدود سے تجاوز کرے اسے وہ دوزخ میں داخل کرے گا جس میں وہ ہمیشہ رہے گا، اور اس کے لئے ذلّت انگیز عذاب ہے،\qt@no{14}}%
\qt@newcmd\qurantrans@ur@dviii{اور تمہاری عورتوں میں سے جو بدکاری کا ارتکاب کر بیٹھیں تو ان پر اپنے لوگوں میں سے چار مردوں کی گواہی طلب کرو، پھر اگر وہ گواہی دے دیں تو ان عورتوں کو گھروں میں بند کر دو یہاں تک کہ موت ان کے عرصۂ حیات کو پورا کر دے یا اللہ ان کے لئے کوئی راہ (یعنی نیا حکم) مقرر فرما دے،\qt@no{15}}%
\qt@newcmd\qurantrans@ur@dix{اور تم میں سے جو بھی کوئی بدکاری کا ارتکاب کریں تو ان دونوں کو ایذا پہنچاؤ، پھر اگر وہ توبہ کر لیں اور (اپنی) اصلاح کر لیں تو انہیں سزا دینے سے گریز کرو، بیشک اللہ بڑا توبہ قبول فرمانے والا مہربان ہے،\qt@no{16}}%
\qt@newcmd\qurantrans@ur@dx{اللہ نے صرف انہی لوگوں کی توبہ قبول کرنے کا وعدہ فرمایا ہے جو نادانی کے باعث برائی کر بیٹھیں پھر جلد ہی توبہ کر لیں پس اللہ ایسے لوگوں پر اپنی رحمت کے ساتھ رجوع فرمائے گا، اور اللہ بڑے علم بڑی حکمت والا ہے،\qt@no{17}}%
\qt@newcmd\qurantrans@ur@dxi{اور ایسے لوگوں کے لئے توبہ (کی قبولیت) نہیں ہے جو گناہ کرتے چلے جائیں، یہاں تک کہ ان میں سے کسی کے سامنے موت آپہنچے تو (اس وقت) کہے کہ میں اب توبہ کرتا ہوں اور نہ ہی ایسے لوگوں کے لئے ہے جو کفر کی حالت پر مریں، ان کے لئے ہم نے دردناک عذاب تیار کر رکھا ہے،\qt@no{18}}%
\qt@newcmd\qurantrans@ur@dxii{اے ایمان والو! تمہارے لئے یہ حلال نہیں کہ تم زبردستی عورتوں کے وارث بن جاؤ، اور انہیں اس غرض سے نہ روک رکھو کہ جو مال تم نے انہیں دیا تھا اس میں سے کچھ (واپس) لے جاؤ سوائے اس کے کہ وہ کھلی بدکاری کی مرتکب ہوں، اور ان کے ساتھ اچھے طریقے سے برتاؤ کرو، پھر اگر تم انہیں نا پسند کرتے ہو تو ممکن ہے کہ تم کسی چیز کو ناپسند کرو اور اللہ اس میں بہت سی بھلائی رکھ دے،\qt@no{19}}%
\qt@newcmd\qurantrans@ur@dxiii{اور اگر تم ایک بیوی کے بدلے دوسری بیوی بدلنا چاہو اور تم اسے ڈھیروں مال دے چکے ہو تب بھی اس میں سے کچھ واپس مت لو، کیا تم ناحق الزام اور صریح گناہ کے ذریعے وہ مال (واپس) لینا چاہتے ہو،\qt@no{20}}%
\qt@newcmd\qurantrans@ur@dxiv{اور تم اسے کیسے واپس لے سکتے ہو حالانکہ تم ایک دوسرے سے پہلو بہ پہلو مل چکے ہو اور وہ تم سے پختہ عہد (بھی) لے چکی ہیں،\qt@no{21}}%
\qt@newcmd\qurantrans@ur@dxv{اور ان عورتوں سے نکاح نہ کرو جن سے تمہارے باپ دادا نکاح کر چکے ہوں مگر جو (اس حکم سے پہلے) گزر چکا (وہ معاف ہے)، بیشک یہ بڑی بے حیائی اور غضب (کا باعث) ہے اور بہت بری روِش ہے،\qt@no{22}}%
\qt@newcmd\qurantrans@ur@dxvi{تم پر تمہاری مائیں اور تمہاری بیٹیاں اور تمہاری بہنیں اور تمہاری پھوپھیاں اور تمہاری خالائیں اور بھتیجیاں اور بھانجیاں اور تمہاری (وہ) مائیں جنہوں نے تمہیں دودھ پلایا ہو اور تمہاری رضاعت میں شریک بہنیں اور تمہاری بیویوں کی مائیں (سب) حرام کر دی گئی ہیں، اور (اسی طرح) تمہاری گود میں پرورش پانے والی وہ لڑکیاں جو تمہاری ان عورتوں (کے بطن) سے ہیں جن سے تم صحبت کر چکے ہو (بھی حرام ہیں)، پھر اگر تم نے ان سے صحبت نہ کی ہو تو تم پر (ان کی لڑکیوں سے نکاح کرنے میں) کوئی حرج نہیں، اور تمہارے ان بیٹوں کی بیویاں (بھی تم پر حرام ہیں) جو تمہاری پشت سے ہیں، اور یہ (بھی حرام ہے) کہ تم دو بہنوں کو ایک ساتھ (نکاح میں) جمع کرو سوائے اس کے کہ جو دورِ جہالت میں گزر چکا۔ بیشک اللہ بڑا بخشنے والا مہربان ہے،\qt@no{23}}%
\qt@newcmd\qurantrans@ur@dxvii{اور شوہر والی عورتیں (بھی تم پرحرام ہیں) سوائے ان (کافروں کی قیدی عورتوں) کے جو تمہاری مِلک میں آجائیں، (ان احکامِ حرمت کو) اللہ نے تم پر فرض کر دیا ہے، اور ان کے سوا (سب عورتیں) تمہارے لئے حلال کر دی گئی ہیں تاکہ تم اپنے اموال کے ذریعے طلبِ نکاح کرو پاک دامن رہتے ہوئے نہ کہ شہوت رانی کرتے ہوئے، پھر ان میں سے جن سے تم نے اس (مال) کے عوض فائدہ اٹھایا ہے انہیں ان کا مقرر شدہ مَہر ادا کر دو، اور تم پر اس مال کے بارے میں کوئی گناہ نہیں جس پر تم مَہر مقرر کرنے کے بعد باہم رضا مند ہو جاؤ، بیشک اللہ خوب جاننے والا بڑی حکمت والا ہے،\qt@no{24}}%
\qt@newcmd\qurantrans@ur@dxviii{اور تم میں سے جو کوئی (اتنی) استطاعت نہ رکھتا ہو کہ آزاد مسلمان عورتوں سے نکاح کر سکے تو ان مسلمان کنیزوں سے نکاح کرلے جو (شرعاً) تمہاری ملکیت میں ہیں، اور اللہ تمہارے ایمان (کی کیفیت) کو خوب جانتا ہے، تم (سب) ایک دوسرے کی جنس میں سے ہی ہو، پس ان (کنیزوں) سے ان کے مالکوں کی اجازت کے ساتھ نکاح کرو اور انہیں ان کے مَہر حسبِ دستور ادا کرو درآنحالیکہ وہ (عفت قائم رکھتے ہوئے) قیدِ نکاح میں آنے والی ہوں نہ بدکاری کرنے والی ہوں اور نہ درپردہ آشنائی کرنے والی ہوں، پس جب وہ نکاح کے حصار میں آجائیں پھر اگر بدکاری کی مرتکب ہوں تو ان پر اس سزا کی آدھی سزا لازم ہے جو آزاد (کنواری) عورتوں کے لئے (مقرر) ہے، یہ اجازت اس شخص کے لئے ہے جسے تم میں سے گناہ (کے ارتکاب) کا اندیشہ ہو، اور اگر تم صبر کرو تو (یہ) تمہارے حق میں بہتر ہے، اور اللہ بخشنے والا مہر بان ہے،\qt@no{25}}%
\qt@newcmd\qurantrans@ur@dxix{اللہ چاہتا ہے کہ تمہارے لئے (اپنے احکام کی) وضاحت فرما دے اور تمہیں ان (نیک) لوگوں کی راہوں پر چلائے جو تم سے پہلے ہوگزرے ہیں اور تمہارے اوپر رحمت کے ساتھ رجوع فرمائے، اور اللہ خوب جاننے والا بڑی حکمت والا ہے،\qt@no{26}}%
\qt@newcmd\qurantrans@ur@dxx{اور اللہ تم پر مہربانی فرمانا چاہتا ہے، اور جو لوگ خواہشاتِ (نفسانی) کی پیروی کر رہے ہیں وہ چاہتے ہیں کہ تم راہِ راست سے بھٹک کر بہت دور جا پڑو،\qt@no{27}}%
\qt@newcmd\qurantrans@ur@dxxi{اللہ چاہتا ہے کہ تم سے بوجھ ہلکا کر دے، اور اِنسان کمزور پیدا کیا گیا ہے،\qt@no{28}}%
\qt@newcmd\qurantrans@ur@dxxii{اے ایمان والو! تم ایک دوسرے کا مال آپس میں ناحق طریقے سے نہ کھاؤ سوائے اس کے کہ تمہاری باہمی رضا مندی سے کوئی تجارت ہو، اور اپنی جانوں کو مت ہلاک کرو، بیشک اللہ تم پر مہربان ہے،\qt@no{29}}%
\qt@newcmd\qurantrans@ur@dxxiii{اور جو کوئی تعدی اور ظلم سے ایسا کرے گا تو ہم عنقریب اسے (دوزخ کی) آگ میں ڈال دیں گے، اور یہ اللہ پر بالکل آسان ہے،\qt@no{30}}%
\qt@newcmd\qurantrans@ur@dxxiv{اگر تم کبیرہ گناہوں سے جن سے تمہیں روکا گیا ہے بچتے رہو تو ہم تم سے تمہاری چھوٹی برائیاں مٹا دیں گے اور تمہیں عزت والی جگہ میں داخل فرما دیں گے،\qt@no{31}}%
\qt@newcmd\qurantrans@ur@dxxv{اور تم اس چیز کی تمنا نہ کیا کرو جس میں اللہ نے تم میں سے بعض کو بعض پر فضیلت دی ہے، مردوں کے لئے اس میں سے حصہ ہے جو انہوں نے کمایا، اور عورتوں کے لئے اس میں سے حصہ ہے جو انہوں نے کمایا، اور اللہ سے اس کا فضل مانگا کرو، بیشک اللہ ہر چیز کو خوب جاننے والا ہے،\qt@no{32}}%
\qt@newcmd\qurantrans@ur@dxxvi{اور ہم نے سب کے لئے ماں باپ اور قریبی رشتہ داروں کے چھوڑے ہوئے مال میں حق دار (یعنی وارث) مقرر کر دیئے ہیں، اور جن سے تمہارا معاہدہ ہو چکا ہے سو اُنہیں ان کا حصہ دے دو، بیشک اللہ ہر چیز کا مشاہدہ فرمانے والا ہے،\qt@no{33}}%
\qt@newcmd\qurantrans@ur@dxxvii{مرد عورتوں پر محافظ و منتظِم ہیں اس لئے کہ اللہ نے ان میں سے بعض کو بعض پر فضیلت دی ہے اور اس وجہ سے (بھی) کہ مرد (ان پر) اپنے مال خرچ کرتے ہیں، پس نیک بیویاں اطاعت شعار ہوتی ہیں شوہروں کی عدم موجودگی میں اللہ کی حفاظت کے ساتھ (اپنی عزت کی) حفاظت کرنے والی ہوتی ہیں، اور تمہیں جن عورتوں کی نافرمانی و سرکشی کا اندیشہ ہو تو انہیں نصیحت کرو اور (اگر نہ سمجھیں تو) انہیں خواب گاہوں میں (خود سے) علیحدہ کر دو اور (اگر پھر بھی اصلاح پذیر نہ ہوں تو) انہیں (تادیباً ہلکا سا) مارو، پھر اگر وہ تمہاری فرمانبردار ہو جائیں تو ان پر (ظلم کا) کوئی راستہ تلاش نہ کرو، بیشک اللہ سب سے بلند سب سے بڑا ہے،\qt@no{34}}%
\qt@newcmd\qurantrans@ur@dxxviii{اور اگر تمہیں ان دونوں کے درمیان مخالفت کا اندیشہ ہو تو تم ایک مُنصِف مرد کے خاندان سے اور ایک مُنصِف عورت کے خاندان سے مقرر کر لو، اگر وہ دونوں (مُنصِف) صلح کرانے کا اِرادہ رکھیں تو اللہ ان دونوں کے درمیان موافقت پیدا فرما دے گا، بیشک اللہ خوب جاننے والا خبردار ہے،\qt@no{35}}%
\qt@newcmd\qurantrans@ur@dxxix{اور تم اللہ کی عبادت کرو اور اس کے ساتھ کسی کو شریک نہ ٹھہراؤ اور ماں باپ کے ساتھ بھلائی کرو اور رشتہ داروں اور یتیموں اور محتاجوں (سے) اور نزدیکی ہمسائے اور اجنبی پڑوسی اور ہم مجلس اور مسافر (سے)، اور جن کے تم مالک ہو چکے ہو، (ان سے نیکی کیا کرو)، بیشک اللہ اس شخص کو پسند نہیں کرتا جو تکبرّ کرنے والا (مغرور) فخر کرنے والا (خود بین) ہو،\qt@no{36}}%
\qt@newcmd\qurantrans@ur@dxxx{جو لوگ (خود بھی) بخل کرتے ہیں اور لوگوں کو (بھی) بخل کا حکم دیتے ہیں اور اس (نعمت) کو چھپاتے ہیں جواللہ نے انہیں اپنے فضل سے عطا کی ہے، اور ہم نے کافروں کے لئے ذلت انگیز عذاب تیار کر رکھا ہے،\qt@no{37}}%
\qt@newcmd\qurantrans@ur@dxxxi{اور جو لوگ اپنے مال لوگوں کے دکھاوے کے لئے خرچ کرتے ہیں اور نہ اللہ پر ایمان رکھتے ہیں اور نہ یومِ آخرت پر، اور شیطان جس کا بھی ساتھی ہوگیا تو وہ برا ساتھی ہے،\qt@no{38}}%
\qt@newcmd\qurantrans@ur@dxxxii{اور ان کا کیا نقصان تھا اگر وہ اللہ پر اور یومِ آخرت پر ایمان لے آتے اور جو کچھ اللہ نے انہیں دیا تھا اس میں سے (اس کی راہ میں) خرچ کرتے، اور اللہ ان (کے حال) سے خوب واقف ہے،\qt@no{39}}%
\qt@newcmd\qurantrans@ur@dxxxiii{بیشک اللہ ذرّہ برابر بھی ظلم نہیں کرتا، اور اگر کوئی نیکی ہو تو اسے دوگنا کر دیتا ہے اور اپنے پاس سے بڑا اجر عطا فرماتا ہے،\qt@no{40}}%
\qt@newcmd\qurantrans@ur@dxxxiv{پھر اس دن کیا حال ہوگا جب ہم ہر امت سے ایک گواہ لائیں گے اور (اے حبیب!) ہم آپ کو ان سب پر گواہ لائیں گے،\qt@no{41}}%
\qt@newcmd\qurantrans@ur@dxxxv{اس دن وہ لوگ جنہوں نے کفر کیا اور رسول (صلی اللہ علیہ وآلہ وسلم) کی نافرمانی کی، آرزو کریں گے کہ کاش (انہیں مٹی میں دبا کر) ان پر زمین برابر کر دی جاتی، اور وہ اللہ سے کوئی بات نہ چھپا سکیں گے،\qt@no{42}}%
\qt@newcmd\qurantrans@ur@dxxxvi{اے ایمان والو! تم نشہ کی حالت میں نماز کے قریب مت جاؤ یہاں تک کہ تم وہ بات سمجھنے لگو جو کہتے ہو اور نہ حالتِ جنابت میں (نماز کے قریب جاؤ) تا آنکہ تم غسل کر لو سوائے اس کے کہ تم سفر میں راستہ طے کر رہے ہو، اور اگر تم بیمار ہو یا سفر میں ہو یا تم میں سے کوئی قضائے حاجت سے لوٹے یا تم نے (اپنی) عورتوں سے مباشرت کی ہو پھر تم پانی نہ پاسکو تو تم پاک مٹی سے تیمم کر لو پس اپنے چہروں اور اپنے ہاتھوں پر مسح کر لیا کرو، بیشک اللہ معاف فرمانے والا بہت بخشنے والا ہے،\qt@no{43}}%
\qt@newcmd\qurantrans@ur@dxxxvii{کیا آپ نے ان لوگوں کو نہیں دیکھا جنہیں (آسمانی) کتاب کا ایک حصہ عطا کیا گیا وہ گمراہی خریدتے ہیں اور چاہتے ہیں کہ تم (بھی) سیدھے راستے سے بہک جاؤ،\qt@no{44}}%
\qt@newcmd\qurantrans@ur@dxxxviii{اور اللہ تمہارے دشمنوں کو خوب جانتا ہے، اور اللہ (بطور) کارساز کافی ہے اور اللہ (بطور) مددگار کافی ہے،\qt@no{45}}%
\qt@newcmd\qurantrans@ur@dxxxix{اور کچھ یہودی (تورات کے) کلمات کو اپنے (اصل) مقامات سے پھیر دیتے ہیں اور کہتے ہیں: ہم نے سن لیا اور نہیں مانا، اور (یہ بھی کہتے ہیں:) سنیئے! (معاذ اللہ!) آپ سنوائے نہ جائیں، اور اپنی زبانیں مروڑ کر دین میں طعنہ زنی کرتے ہوئے”رَاعِنَا“ کہتے ہیں، اور اگر وہ لوگ (اس کی جگہ) یہ کہتے کہ ہم نے سنا اور ہم نے اطاعت کی اور (حضور! ہماری گزارش) سنئے اور ہماری طرف نظرِ (کرم) فرمائیے تو یہ اُن کے لئے بہتر ہوتا اور (یہ قول بھی) درست اور مناسب ہوتا، لیکن اللہ نے ان کے کفر کے باعث ان پر لعنت کی سو تھوڑے لوگوں کے سوا وہ ایمان نہیں لاتے،\qt@no{46}}%
\qt@newcmd\qurantrans@ur@dxl{اے اہلِ کتاب! اس (کتاب) پر ایمان لاؤ جو ہم نے (اب اپنے حبیب محمد صلی اللہ علیہ وآلہ وسلم پر) اتاری ہے جو اس کتاب کی (اصلاً) تصدیق کرتی ہے جو تمہارے پاس ہے، اس سے قبل کہ ہم (بعض) چہروں (کے نقوش) کو مٹا دیں اور انہیں ان کی پشت کی حالت پر پھیر دیں یا ان پر اسی طرح لعنت کریں جیسے ہم نے ہفتہ کے دن (نافرمانی کرنے) والوں پر لعنت کی تھی اور اللہ کا حکم پورا ہو کر ہی رہتا ہے،\qt@no{47}}%
\qt@newcmd\qurantrans@ur@dxli{بیشک اللہ اِس بات کو نہیں بخشتا کہ اس کے ساتھ شرک کیا جائے اور اس سے کم تر (جو گناہ بھی ہو) جس کے لئے چاہتا ہے بخش دیتا ہے، اور جس نے اللہ کے ساتھ شرک کیا اس نے واقعۃً زبردست گناہ کا بہتان باندھا،\qt@no{48}}%
\qt@newcmd\qurantrans@ur@dxlii{کیا آپ نے ایسے لوگوں کو نہیں دیکھا جو خود کو پاک ظاہر کرتے ہیں، بلکہ اللہ ہی جسے چاہتا ہے پاک فرماتا ہے اور ان پر ایک دھاگہ کے برابر بھی ظلم نہیں کیا جائے گا،\qt@no{49}}%
\qt@newcmd\qurantrans@ur@dxliii{آپ دیکھئے وہ اللہ پر کیسے جھوٹا بہتان باندھتے ہیں، اور (ان کے عذاب کے لئے) یہی کھلا گناہ کافی ہے،\qt@no{50}}%
\qt@newcmd\qurantrans@ur@dxliv{کیا آپ نے ان لوگوں کو نہیں دیکھا جنہیں (آسمانی) کتاب کا حصہ دیا گیا ہے (پھر بھی) وہ بتوں اور شیطان پر ایمان رکھتے ہیں اور کافروں کے بارے میں کہتے ہیں کہ مسلمانوں کی نسبت یہ (کافر) زیادہ سیدھی راہ پر ہیں،\qt@no{51}}%
\qt@newcmd\qurantrans@ur@dxlv{یہ وہ لوگ ہیں جن پر اللہ نے لعنت کی، اور جس پر اللہ لعنت کرے تُو اس کے لئے ہرگز کوئی مددگار نہ پائے گا،\qt@no{52}}%
\qt@newcmd\qurantrans@ur@dxlvi{کیا ان کا سلطنت میں کچھ حصہ ہے؟ اگر ایسا ہو تو یہ (اپنے بخل کے باعث) لوگوں کو تِل برابر بھی (کوئی چیز) نہیں دیں گے،\qt@no{53}}%
\qt@newcmd\qurantrans@ur@dxlvii{کیا یہ (یہود) لوگوں (سے ان نعمتوں) پر حسد کرتے ہیں جو اللہ نے انہیں اپنے فضل سے عطا فرمائی ہیں، سو واقعی ہم نے ابراہیم (علیہ السلام) کے خاندان کو کتاب اور حکمت عطا کی اور ہم نے انہیں بڑی سلطنت بخشی،\qt@no{54}}%
\qt@newcmd\qurantrans@ur@dxlviii{پس ان میں سے کوئی تو اس پر ایمان لے آیا اور ان میں سے کسی نے اس سے روگردانی کی، اور (روگردانی کرنے والے کے لئے) دوزخ کی بھڑکتی آگ کافی ہے،\qt@no{55}}%
\qt@newcmd\qurantrans@ur@dxlix{بیشک جن لوگوں نے ہماری آیتوں سے کفر کیا ہم عنقریب انہیں (دوزخ کی) آگ میں جھونک دیں گے، جب ان کی کھالیں جل جائیں گی تو ہم انہیں دوسری کھالیں بدل دیں گے تاکہ وہ (مسلسل) عذاب (کا مزہ) چکھتے رہیں، بیشک اللہ غالب حکمت والا ہے،\qt@no{56}}%
\qt@newcmd\qurantrans@ur@dl{اور جو لوگ ایمان لائے اور نیک عمل کرتے رہے تو ہم انہیں بہشتوں میں داخل کریں گے جن کے نیچے نہریں رواں ہیں وہ ان میں ہمیشہ رہیں گے، ان کے لئے وہاں پاکیزہ بیویاں ہوں گی اور ہم ان کو بہت گھنے سائے میں داخل کریں گے،\qt@no{57}}%
\qt@newcmd\qurantrans@ur@dli{بیشک اللہ تمہیں حکم دیتا ہے کہ امانتیں انہی لوگوں کے سپرد کرو جو ان کے اہل ہیں، اور جب تم لوگوں کے درمیان فیصلہ کرو تو عدل کے ساتھ فیصلہ کیا کرو، بیشک اللہ تمہیں کیا ہی اچھی نصیحت فرماتا ہے، بیشک اللہ خوب سننے والا خوب دیکھنے والا ہے،\qt@no{58}}%
\qt@newcmd\qurantrans@ur@dlii{اے ایمان والو! اللہ کی اطاعت کرو اور رسول (صلی اللہ علیہ وآلہ وسلم) کی اطاعت کرو اوراپنے میں سے (اہلِ حق) صاحبانِ اَمر کی، پھر اگر کسی مسئلہ میں تم باہم اختلاف کرو تو اسے (حتمی فیصلہ کے لئے) اللہ اور رسول (صلی اللہ علیہ وآلہ وسلم) کی طرف لوٹا دو اگر تم اللہ پر اور یومِ آخرت پر ایمان رکھتے ہو، (تو) یہی (تمہارے حق میں) بہتر اور انجام کے لحاظ سے بہت اچھا ہے،\qt@no{59}}%
\qt@newcmd\qurantrans@ur@dliii{کیا آپ نے اِن (منافقوں) کو نہیں دیکھا جو (زبان سے) دعوٰی کرتے ہیں کہ وہ اس (کتاب یعنی قرآن) پر ایمان لائے جوآپ کی طرف اتارا گیا اور ان (آسمانی کتابوں) پر بھی جو آپ سے پہلے اتاری گئیں (مگر) چاہتے یہ ہیں کہ اپنے مقدمات (فیصلے کے لئے) شیطان (یعنی احکامِ الٰہی سے سرکشی پر مبنی قانون) کی طرف لے جائیں حالانکہ انہیں حکم دیا جا چکا ہے کہ اس کا (کھلا) انکار کر دیں، اور شیطان تویہی چاہتا ہے کہ انہیں دور دراز گمراہی میں بھٹکاتا رہے،\qt@no{60}}%
\qt@newcmd\qurantrans@ur@dliv{اور جب ان سے کہا جاتا ہے کہ اللہ کے نازل کردہ (قرآن) کی طرف اور رسول(صلی اللہ علیہ وآلہ وسلم) کی طرف آجاؤ تو آپ منافقوں کو دیکھیں گے کہ وہ آپ (کی طرف رجوع کرنے) سے گریزاں رہتے ہیں،\qt@no{61}}%
\qt@newcmd\qurantrans@ur@dlv{پھر (اس وقت) ان کی حالت کیا ہوگی جب اپنی کارستانیوں کے باعث ان پر کوئی مصیبت آن پڑے تو اللہ کی قَسمیں کھاتے ہوئے آپ کی خدمت میں حاضر ہوں (اور یہ کہیں) کہ ہم نے تو صرف بھلائی اور باہمی موافقت کا ہی ارادہ کیا تھا،\qt@no{62}}%
\qt@newcmd\qurantrans@ur@dlvi{یہ وہ (منافق اور مُفسِد) لوگ ہیں کہ اللہ ان کے دلوں کی ہر بات کو خوب جانتا ہے، پس آپ ان سے اِعراض برتیں اور انہیں نصیحت کرتے رہیں اور ان سے ان کے بارے میں مؤثر گفتگو فرماتے رہیں،\qt@no{63}}%
\qt@newcmd\qurantrans@ur@dlvii{اور ہم نے کوئی پیغمبر نہیں بھیجا مگر اس لئے کہ اللہ کے حکم سے اس کی اطاعت کی جائے، اور (اے حبیب!) اگر وہ لوگ جب اپنی جانوں پر ظلم کر بیٹھے تھے آپ کی خدمت میں حاضر ہو جاتے اوراللہ سے معافی مانگتے اور رسول(صلی اللہ علیہ وآلہ وسلم) بھی ان کے لئے مغفرت طلب کرتے تو وہ (اس وسیلہ اور شفاعت کی بنا پر) ضرور اللہ کو توبہ قبول فرمانے والا نہایت مہربان پاتے،\qt@no{64}}%
\qt@newcmd\qurantrans@ur@dlviii{پس (اے حبیب!) آپ کے رب کی قسم یہ لوگ مسلمان نہیں ہوسکتے یہاں تک کہ وہ اپنے درمیان واقع ہونے والے ہر اختلاف میں آپ کو حاکم بنالیں پھر اس فیصلہ سے جو آپ صادر فرما دیں اپنے دلوں میں کوئی تنگی نہ پائیں اور (آپ کے حکم کو) بخوشی پوری فرمانبرداری کے ساتھ قبول کر لیں،\qt@no{65}}%
\qt@newcmd\qurantrans@ur@dlix{اور اگر ہم ان پر فرض کر دیتے کہ تم اپنے آپ کو قتل کر ڈالو یا اپنے گھروں کو چھوڑ کر نکل جاؤ تو ان میں سے بہت تھوڑے لوگ اس پر عمل کرتے، اورانہیں جو نصیحت کی جاتی ہے اگر وہ اس پر عمل پیرا ہو جاتے تویہ ان کے حق میں بہتر ہوتا اور (ایمان پر) بہت زیادہ ثابت قدم رکھنے والا ہوتا،\qt@no{66}}%
\qt@newcmd\qurantrans@ur@dlx{اور اس وقت ہم بھی انہیں اپنے حضور سے عظیم اجر عطا فرماتے،\qt@no{67}}%
\qt@newcmd\qurantrans@ur@dlxi{اور ہم انہیں واقعۃً سیدھی راہ پر لگا دیتے،\qt@no{68}}%
\qt@newcmd\qurantrans@ur@dlxii{اور جو کوئی اللہ اور رسول(صلی اللہ علیہ وآلہ وسلم) کی اطاعت کرے تو یہی لوگ (روزِ قیامت) ان (ہستیوں) کے ساتھ ہوں گے جن پر اللہ نے (خاص) انعام فرمایا ہے جو کہ انبیاء، صدیقین، شہداءاور صالحین ہیں، اور یہ بہت اچھے ساتھی ہیں،\qt@no{69}}%
\qt@newcmd\qurantrans@ur@dlxiii{یہ فضل (خاص) اللہ کی طرف سے ہے، اور اللہ جاننے والا کافی ہے،\qt@no{70}}%
\qt@newcmd\qurantrans@ur@dlxiv{اے ایمان والو! اپنی حفاظت کا سامان لے لیا کرو پھر (جہاد کے لئے) متفرق جماعتیں ہو کر نکلو یا سب اکٹھے ہو کر کوچ کرو،\qt@no{71}}%
\qt@newcmd\qurantrans@ur@dlxv{اور یقیناً تم میں سے بعض ایسے بھی ہیں جو (عمداً سستی کرتے ہوئے) دیر لگاتے ہیں، پھر اگر (جنگ میں) تمہیں کوئی مصیبت پہنچے تو (شریک نہ ہونے والا شخص) کہتا ہے کہ بیشک اللہ نے مجھ پراحسان فرمایا کہ میں ان کے ساتھ (میدانِ جنگ میں) حاضر نہ تھا،\qt@no{72}}%
\qt@newcmd\qurantrans@ur@dlxvi{اور اگر تمہیں اللہ کی جانب سے کوئی نعمت نصیب ہو جائے تو (پھر) یہی (منافق افسوس کرتے ہوئے) ضرور (یوں) کہے گا گویا تمہارے اور اس کے درمیان کچھ دوستی ہی نہ تھی کہ اے کاش! میں ان کے ساتھ ہوتا تو میں بھی بڑی کامیابی حاصل کرتا،\qt@no{73}}%
\qt@newcmd\qurantrans@ur@dlxvii{پس ان (مؤمنوں) کو اللہ کی راہ میں (دین کی سربلندی کے لئے) لڑنا چاہئے جو آخرت کے عوض دنیوی زندگی کو بیچ دیتے ہیں، اور جو کوئی اللہ کی راہ میں جنگ کرے، خواہ وہ (خود) قتل ہو جائے یا غالب آجائے توہم (دونوں صورتوں میں) عنقریب اسے عظیم اجر عطا فرمائیں گے،\qt@no{74}}%
\qt@newcmd\qurantrans@ur@dlxviii{اور (مسلمانو!) تمہیں کیا ہوگیا ہے کہ تم اللہ کی راہ میں (غلبۂ دین کے لئے) اور ان بے بس (مظلوم و مقہور) مردوں، عورتوں اور بچوں (کی آزادی) کے لئے جنگ نہیں کرتے جو (ظلم و ستم سے تنگ ہو کر) پکارتے ہیں: اے ہمارے رب! ہمیں اس بستی سے نکال لے جہاں کے (وڈیرے) لوگ ظالم ہیں، اور کسی کو اپنی بارگاہ سے ہمارا کارساز مقرر فرما دے، اور کسی کو اپنی بارگاہ سے ہمارا مددگار بنا دے،\qt@no{75}}%
\qt@newcmd\qurantrans@ur@dlxix{جو لوگ ایمان لائے وہ اللہ کی راہ میں (نیک مقاصد کے لئے) جنگ کرتے ہیں اورجنہوں نے کفر کیا وہ شیطان کی راہ میں (طاغوتی مقاصد کے لئے) جنگ کرتے ہیں، پس (اے مؤمنو!) تم شیطان کے دوستوں (یعنی شیطانی مشن کے مددگاروں) سے لڑو، بیشک شیطان کا داؤ کمزور ہے،\qt@no{76}}%
\qt@newcmd\qurantrans@ur@dlxx{کیا آپ نے ان لوگوں کا حال نہیں دیکھا جنہیں (ابتداءً کچھ عرصہ کے لئے) یہ کہا گیا کہ اپنے ہاتھ (قتال سے) روکے رکھو اور نماز قائم کئے رہواور زکوٰۃ دیتے رہو (تو وہ اس پر خوش تھے)، پھر جب ان پر جہاد (یعنی کفر اور ظلم سے ٹکرانا) فرض کر دیا گیا تو ان میں سے ایک گروہ (مخالف) لوگوں سے (یوں) ڈرنے لگا جیسے اللہ سے ڈرا جاتا ہے یا اس سے بھی بڑھ کر۔ اور کہنے لگے: اے ہمارے رب! تو نے ہم پر (اس قدر جلدی) جہاد کیوں فرض کر دیا؟ تو نے ہمیں مزید تھوڑی مدت تک مہلت کیوں نہ دی؟ آپ (انہیں) فرما دیجئے کہ دنیا کا مفاد بہت تھوڑا (یعنی معمولی شے) ہے، اور آخرت بہت اچھی (نعمت) ہے اس کے لئے جو پرہیزگار بن جائے، وہاں ایک دھاگے کے برابر بھی تمہاری حق تلفی نہیں کی جائے گی،\qt@no{77}}%
\qt@newcmd\qurantrans@ur@dlxxi{اے موت کے ڈر سے جہاد سے گریز کرنے والو!) تم جہاں کہیں (بھی) ہوگے موت تمہیں (وہیں) آپکڑے گی خواہ تم مضبوط قلعوں میں (ہی) ہو، اور (ان کی ذہنیت یہ ہے کہ) اگر انہیں کوئی بھلائی (فائدہ) پہنچے توکہتے ہیں کہ یہ (تو) اللہ کی طرف سے ہے (اس میں رسول صلی اللہ علیہ وآلہ وسلم کی برکت اور واسطے کا کوئی دخل نہیں)، اور اگر انہیں کوئی برائی (نقصان) پہنچے تو کہتے ہیں: (اے رسول!) یہ آپ کی طرف سے (یعنی آپ کی وجہ سے) ہے۔ آپ فرما دیں: (حقیقۃً) سب کچھ اللہ کی طرف سے (ہوتا) ہے۔ پس اس قوم کو کیا ہوگیا ہے کہ یہ کوئی بات سمجھنے کے قریب ہی نہیں آتے،\qt@no{78}}%
\qt@newcmd\qurantrans@ur@dlxxii{اے انسان! اپنی تربیت یوں کر کہ) جب تجھے کوئی بھلائی پہنچے تو (سمجھ کہ) وہ اللہ کی طرف سے ہے (اسے اپنے حسنِ تدبیر کی طرف منسوب نہ کر)، اور جب تجھے کوئی برائی پہنچے تو (سمجھ کہ) وہ تیری اپنی طرف سے ہے (یعنی اسے اپنی خرابئ نفس کی طرف منسوب کر)، اور (اے محبوب!) ہم نے آپ کو تمام انسانوں کے لئے رسول بنا کر بھیجا ہے، اور (آپ کی رسالت پر) اللہ گواہی میں کافی ہے،\qt@no{79}}%
\qt@newcmd\qurantrans@ur@dlxxiii{جس نے رسول (صلی اللہ علیہ وآلہ وسلم) کا حکم مانا بیشک اس نے اللہ (ہی) کا حکم مانا، اور جس نے روگردانی کی تو ہم نے آپ کو ان پر نگہبان بنا کر نہیں بھیجا،\qt@no{80}}%
\qt@newcmd\qurantrans@ur@dlxxiv{اور (ان منافقوں کا یہ حال ہے کہ آپ کے سامنے) کہتے ہیں کہ (ہم نے آپ کا حکم) مان لیا، پھر وہ آپ کے پاس سے (اٹھ کر) باہر جاتے ہیں تو ان میں سے ایک گروہ آپ کی کہی ہوئی بات کے برعکس رات کو رائے زنی (اور سازشی مشورے) کرتا ہے، اور اللہ (وہ سب کچھ) لکھ رہا ہے جو وہ رات بھر منصوبے بناتے ہیں۔ پس (اے محبوب!) آپ ان سے رُخِ انور پھیر لیجئے اوراللہ پر بھروسہ رکھئیے، اور اللہ کافی کارساز ہے،\qt@no{81}}%
\qt@newcmd\qurantrans@ur@dlxxv{تو کیا وہ قرآن میں غور و فکر نہیں کرتے، اور اگر یہ (قرآن) غیرِ خدا کی طرف سے (آیا) ہوتا تو یہ لوگ اس میں بہت سا اختلاف پاتے،\qt@no{82}}%
\qt@newcmd\qurantrans@ur@dlxxvi{اور جب ان کے پاس کوئی خبر امن یا خوف کی آتی ہے تو وہ اسے پھیلا دیتے ہیں اور اگر وہ (بجائے شہرت دینے کے) اسے رسول (صلی اللہ علیہ وآلہ وسلم) اور اپنے میں سے صاحبانِ امر کی طرف لوٹادیتے تو ضرور ان میں سے وہ لوگ جو (کسی) بات کانتیجہ اخذ کرسکتے ہیں اس (خبر کی حقیقت) کو جان لیتے، اگر تم پر اللہ کا فضل اور اس کی رحمت نہ ہوتی تو یقیناً چند ایک کے سوا تم (سب) شیطان کی پیروی کرنے لگتے،\qt@no{83}}%
\qt@newcmd\qurantrans@ur@dlxxvii{پس (اے محبوب!) آپ اللہ کی راہ میں جہاد کیجئے، آپ کو اپنی جان کے سوا (کسی اور کے لئے) ذمہ دار نہیں ٹھہرایا جائے گا اور آپ مسلمانوں کو (جہاد کے لئے) اُبھاریں، عجب نہیں کہ اللہ کافروں کا جنگی زور توڑ دے، اور اللہ گرفت میں (بھی) بہت سخت ہے اور سزا دینے میں (بھی) بہت سخت،\qt@no{84}}%
\qt@newcmd\qurantrans@ur@dlxxviii{جو شخص کوئی نیک سفارش کرے تو اس کے لئے اس (کے ثواب) سے حصہ (مقرر) ہے، اور جو کوئی بری سفارش کرے تو اس کے لئے اس (کے گناہ) سے حصہ (مقرر) ہے، اور اللہ ہر چیز پر قادر ہے،\qt@no{85}}%
\qt@newcmd\qurantrans@ur@dlxxix{اور جب (کسی لفظ) سلام کے ذریعے تمہاری تکریم کی جائے تو تم (جواب میں) اس سے بہتر (لفظ کے ساتھ) سلام پیش کیا کرو یا (کم از کم) وہی (الفاظ جواب میں) لوٹا دیا کرو، بیشک اللہ ہر چیز پر حساب لینے والا ہے،\qt@no{86}}%
\qt@newcmd\qurantrans@ur@dlxxx{اللہ ہے (کہ) اس کے سوا کوئی لائقِ عبادت نہیں۔ وہ تمہیں ضرور قیامت کے دن جمع کرے گا جس میں کوئی شک نہیں، اور اللہ سے بات میں زیادہ سچا کون ہے،\qt@no{87}}%
\qt@newcmd\qurantrans@ur@dlxxxi{پس تمہیں کیا ہوگیا ہے کہ منافقوں کے بارے میں تم دو گروہ ہو گئے ہو حالانکہ اللہ نے ان کے اپنے کرتوتوں کے باعث ان (کی عقل اور سوچ) کو اوندھا کر دیا ہے۔ کیا تم اس شخص کو راہِ راست پر لانا چاہتے ہو جسے اللہ نے گمراہ ٹھہرا دیا ہے، اور (اے مخاطب!) جسے اللہ گمراہ ٹھہرا دے تو اس کے لئے ہرگز کوئی راہِ (ہدایت) نہیں پاسکتا،\qt@no{88}}%
\qt@newcmd\qurantrans@ur@dlxxxii{وہ (منافق تو) یہ تمنا کرتے ہیں کہ تم بھی کفر کروجیسے انہوں نے کفر کیا تاکہ تم سب برابر ہو جاؤ۔ سو تم ان میں سے (کسی کو) دوست نہ بناؤ یہاں تک کہ وہ اللہ کی راہ میں ہجرت (کر کے اپنا ایمان اور اخلاص ثابت) کریں، پھر اگر وہ روگردانی کریں تو انہیں پکڑ لو اور جہاں بھی پاؤ انہیں قتل کر ڈالو اور ان میں سے (کسی کو) دوست نہ بناؤ اور نہ مددگار،\qt@no{89}}%
\qt@newcmd\qurantrans@ur@dlxxxiii{مگر ان لوگوں کو (قتل نہ کرو) جو ایسی قوم سے جا ملے ہوں کہ تمہارے اور ان کے درمیان معاہدۂ (امان ہوچکا) ہو یا وہ (حوصلہ ہار کر) تمہارے پاس اس حال میں آجائیں کہ ان کے سینے (اس بات سے) تنگ آچکے ہوں کہ وہ تم سے لڑیں یا اپنی قوم سے لڑیں، اور اگر اللہ چاہتا تو (ان کے دلوں کو ہمت دیتے ہوئے) یقینا انہیں تم پر غالب کر دیتا تو وہ تم سے ضرور لڑتے، پس اگر وہ تم سے کنارہ کشی کر لیں اور تمہارے ساتھ جنگ نہ کریں اور تمہاری طرف صلح (کا پیغام) بھیجیں تو اللہ نے تمہارے لئے (بھی صلح جوئی کی صورت میں) ان پر (دست درازی کی) کوئی راہ نہیں بنائی،\qt@no{90}}%
\qt@newcmd\qurantrans@ur@dlxxxiv{اب تم کچھ دوسرے لوگوں کو بھی پاؤ گے جو چاہتے ہیں کہ (منافقانہ طریقے سے ایمان ظاہر کرکے) تم سے (بھی) امن میں رہیں اور (پوشیدہ طریقے سے کفر کی موافقت کرکے) اپنی قوم سے (بھی) امن میں رہیں، (مگر ان کی حالت یہ ہے کہ) جب بھی (مسلمانوں کے خلاف) فتنہ انگیزی کی طرف پھیرے جاتے ہیں تو وہ اس میں (اوندھے) کود پڑتے ہیں، سو اگر یہ (لوگ) تم سے (لڑنے سے) کنارہ کش نہ ہوں اور (نہ ہی) تمہاری طرف صلح (کا پیغام) بھیجیں اور (نہ ہی) اپنے ہاتھ (فتنہ انگیزی سے) روکیں تو تم انہیں پکڑ (کر قید کر) لو اور انہیں قتل کر ڈالو جہاں کہیں بھی انہیں پاؤ، اور یہ وہ لوگ ہیں جن پر ہم نے تمہیں کھلا اختیار دیا ہے،\qt@no{91}}%
\qt@newcmd\qurantrans@ur@dlxxxv{اور کسی مسلمان کے لئے (جائز) نہیں کہ وہ کسی مسلمان کو قتل کر دے مگر (بغیر قصد) غلطی سے، اور جس نے کسی مسلمان کو نادانستہ قتل کر دیا تو (اس پر) ایک مسلمان غلام / باندی کا آزاد کرنا اور خون بہا (کا ادا کرنا) جو مقتول کے گھر والوں کے سپرد کیا جائے (لازم ہے) مگر یہ کہ وہ معاف کر دیں، پھر اگر وہ (مقتول) تمہاری دشمن قوم سے ہو اور وہ مومن (بھی) ہو تو (صرف) ایک غلام / باندی کا آزاد کرنا (ہی لازم) ہے اور اگر وہ (مقتول) اس قوم میں سے ہو کہ تمہارے اور ان کے درمیان (صلح کا) معاہدہ ہے تو خون بہا (بھی) جو اس کے گھر والوں کے سپرد کیا جائے اور ایک مسلمان غلام / باندی کا آزاد کرنا (بھی لازم) ہے۔ پھر جس شخص کو (غلام / باندی) میسر نہ ہو تو (اس پر) پے در پے دو مہینے کے روزے (لازم) ہیں۔ اللہ کی طرف سے (یہ اس کی) توبہ ہے، اور اللہ خوب جاننے والا بڑی حکمت والا ہے،\qt@no{92}}%
\qt@newcmd\qurantrans@ur@dlxxxvi{اور جو شخص کسی مسلمان کو قصداً قتل کرے تو اس کی سزا دوزخ ہے کہ مدتوں اس میں رہے گا اور اس پر اللہ غضبناک ہوگا اور اس پر لعنت کرے گا اور اس نے اس کے لئے زبردست عذاب تیار کر رکھا ہے،\qt@no{93}}%
\qt@newcmd\qurantrans@ur@dlxxxvii{اے ایمان والو! جب تم اللہ کی راہ میں (جہاد کے لئے) سفر پر نکلو تو تحقیق کر لیا کرو اور اس کو جو تمہیں سلام کرے یہ نہ کہو کہ تو مسلمان نہیں ہے، تم (ایک مسلمان کو کافر کہہ کر مارنے کے بعد مالِ غنیمت کی صورت میں) دنیوی زندگی کا سامان تلاش کرتے ہو تو (یقین کرو) اللہ کے پاس بہت اَموالِ غنیمت ہیں۔ اس سے پیشتر تم (بھی) توایسے ہی تھے پھر اللہ نے تم پر احسان کیا (اور تم مسلمان ہوگئے) پس (دوسروں کے بارے میں بھی) تحقیق کر لیا کرو۔ بیشک اللہ تمہارے کاموں سے خبردار ہے،\qt@no{94}}%
\qt@newcmd\qurantrans@ur@dlxxxviii{مسلمانوں میں سے وہ لوگ جو (جہاد سے جی چرا کر) بغیر کسی (عذر) تکلیف کے (گھروں میں) بیٹھ رہنے والے ہیں اور وہ لوگ جو اللہ کی راہ میں اپنے مالوں اور اپنی جانوں سے جہاد کرنے والے ہیں (یہ دونوں درجہ و ثواب میں) برابر نہیں ہوسکتے۔ اللہ نے اپنے مالوں اور اپنی جانوں سے جہاد کرنے والوں کو بیٹھ رہنے والوں پر مرتبہ میں فضیلت بخشی ہے اوراللہ نے سب (ایمان والوں) سے وعدہ (تو) بھلائی کا (ہی) فرمایا ہے، اور اللہ نے جہاد کرنے والوں کو (بہر طور) بیٹھ رہنے والوں پر زبردست اجر (و ثواب) کی فضیلت دی ہے،\qt@no{95}}%
\qt@newcmd\qurantrans@ur@dlxxxix{اس کی طرف سے (ان کے لئے بہت) درجات ہیں اور بخشائش اور رحمت ہے، اور اللہ بڑا بخشنے والا مہربان ہے،\qt@no{96}}%
\qt@newcmd\qurantrans@ur@dxc{بیشک جن لوگوں کی روح فرشتے اس حال میں قبض کرتے ہیں کہ وہ (اسلام دشمن ماحول میں رہ کر) اپنی جانوں پر ظلم کرنے والے ہیں (تو) وہ ان سے دریافت کرتے ہیں کہ تم کس حال میں تھے (تم نے اِقامتِ دین کی جد و جہد کی نہ سرزمینِ کُفر کو چھوڑا)؟ وہ (معذرۃً) کہتے ہیں کہ ہم زمین میں کمزور و بے بس تھے، فرشتے (جواباً) کہتے ہیں: کیا اللہ کی زمین فراخ نہ تھی کہ تم اس میں (کہیں) ہجرت کر جاتے، سو یہی وہ لوگ ہیں جن کا ٹھکانا جہنم ہے، اور وہ بہت ہی برا ٹھکانا ہے،\qt@no{97}}%
\qt@newcmd\qurantrans@ur@dxci{سوائے ان واقعی مجبور و بے بس مردوں اور عورتوں اور بچوں کے، جو نہ کسی تدبیر پر قدرت رکھتے ہیں اور نہ (وہاں سے نکلنے کا) کوئی راستہ جانتے ہیں،\qt@no{98}}%
\qt@newcmd\qurantrans@ur@dxcii{سو یہ وہ لوگ ہیں کہ یقیناً اللہ ان سے درگزر فرمائے گا، اور اللہ بڑا معاف فرمانے والا بخشنے والا ہے،\qt@no{99}}%
\qt@newcmd\qurantrans@ur@dxciii{اور جو کوئی اللہ کی راہ میں گھر بار چھوڑ کرنکلے وہ زمین میں (ہجرت کے لئے) بہت سی جگہیں اور (معاش کے لئے) کشائش پائے گا، اور جو شخص بھی اپنے گھر سے اللہ اور اس کے رسول (صلی اللہ علیہ وآلہ وسلم) کی طرف ہجرت کرتے ہوئے نکلے پھر اسے (راستے میں ہی) موت آپکڑے تو اس کا اجر اللہ کے ذمے ثابت ہو گیا، اور اللہ بڑا بخشنے والا مہربان ہے،\qt@no{100}}%
\qt@newcmd\qurantrans@ur@dxciv{اور جب تم زمین میں سفر کرو تو تم پر کوئی گناہ نہیں کہ تم نماز میں قصر کرو (یعنی چار رکعت فرض کی جگہ دو پڑھو) اگر تمہیں اندیشہ ہے کہ کافر تمہیں تکلیف میں مبتلا کر دیں گے۔ بیشک کفار تمہارے کھلے دشمن ہیں،\qt@no{101}}%
\qt@newcmd\qurantrans@ur@dxcv{اور (اے محبوب!) جب آپ ان (مجاہدوں) میں (تشریف فرما) ہوں تو ان کے لئے نماز (کی جماعت) قائم کریں پس ان میں سے ایک جماعت کو (پہلے) آپ کے ساتھ (اقتداءً) کھڑا ہونا چاہئے اور انہیں اپنے ہتھیار بھی لئے رہنا چاہئیں، پھر جب وہ سجدہ کر چکیں تو (ہٹ کر) تم لوگوں کے پیچھے ہو جائیں اور (اب) دوسری جماعت کو جنہوں نے (ابھی) نماز نہیں پڑھی آجانا چاہیے پھر وہ آپ کے ساتھ (مقتدی بن کر) نماز پڑھیں اور چاہئے کہ وہ (بھی بدستور) اپنے اسبابِ حفاظت اور اپنے ہتھیار لئے رہیں، کافر چاہتے ہیں کہ کہیں تم اپنے ہتھیاروں اور اپنے اسباب سے غافل ہو جاؤ تو وہ تم پر دفعۃً حملہ کر دیں، اور تم پر کچھ مضائقہ نہیں کہ اگر تمہیں بارش کی وجہ سے کوئی تکلیف ہو یا بیمار ہو تو اپنے ہتھیار (اُتار کر) رکھ دو، اوراپنا سامانِ حفاظت لئے رہو۔ بیشک اللہ نے کافروں کے لئے ذلّت انگیز عذاب تیار کر رکھا ہے،\qt@no{102}}%
\qt@newcmd\qurantrans@ur@dxcvi{پھر (اے مسلمانو!) جب تم نماز ادا کر چکو تو اللہ کو کھڑے اور بیٹھے اور اپنے پہلوؤں پر (لیٹے ہر حال میں) یاد کرتے رہو، پھر جب تم (حالتِ خوف سے نکل کر) اطمینان پالو تو نماز کو (حسبِ دستور) قائم کرو۔ بیشک نماز مومنوں پر مقررہ وقت کے حساب سے فرض ہے،\qt@no{103}}%
\qt@newcmd\qurantrans@ur@dxcvii{اور تم (دشمن) قوم کی تلاش میں سستی نہ کرو۔ اگر تمہیں (پیچھا کرنے میں) تکلیف پہنچتی ہے تو انہیں بھی (تو ایسی ہی) تکلیف پہنچتی ہے جیسی تکلیف تمہیں پہنچ رہی ہے حالانکہ تم اللہ سے (اجر و ثواب کی) وہ امیدیں رکھتے ہو جو اُمیدیں وہ نہیں رکھتے۔ اور اللہ خوب جاننے والا بڑی حکمت والا ہے،\qt@no{104}}%
\qt@newcmd\qurantrans@ur@dxcviii{اے رسولِ گرامی!) بیشک ہم نے آپ کی طرف حق پر مبنی کتاب نازل کی ہے تاکہ آپ لوگوں میں اس (حق) کے مطابق فیصلہ فرمائیں جو اللہ نے آپ کو دکھایا ہے، اور آپ (کبھی) بددیانت لوگوں کی طرف داری میں بحث کرنے والے نہ بنیں،\qt@no{105}}%
\qt@newcmd\qurantrans@ur@dxcix{اور آپ اللہ سے بخشش طلب کریں، بیشک اللہ بڑا بخشنے والا مہربان ہے،\qt@no{106}}%
\qt@newcmd\qurantrans@ur@dc{اور آپ ایسے لوگوں کی طرف سے (دفاعاً) نہ جھگڑیں جو اپنی ہی جانوں سے دھوکہ کر رہے ہیں۔ بیشک اللہ کسی (ایسے شخص) کو پسند نہیں فرماتا جو بڑا بددیانت اور بدکار ہے،\qt@no{107}}%
\qt@newcmd\qurantrans@ur@dci{وہ لوگوں سے (شرماتے ہوئے اپنی دغابازی کو) چھپاتے ہیں اور اللہ سے نہیں شرماتے درآنحالیکہ وہ ان کے ساتھ ہوتا ہے جب وہ رات کو (کسی) ایسی بات سے متعلق (چھپ کر) مشورہ کرتے ہیں جسے اللہ ناپسند فرماتا ہے، اور اللہ جو کچھ وہ کرتے ہیں (اسے) احاطہ کئے ہوئے ہے،\qt@no{108}}%
\qt@newcmd\qurantrans@ur@dcii{خبردار! تم وہ لوگ ہو جو دنیا کی زندگی میں ان کی طرف سے جھگڑے۔ پھر کون ایسا شخص ہے جو قیامت کے دن (بھی) ان کی طرف سے اللہ کے ساتھ جھگڑے گا یا کون ہے جو (اس دن بھی) ان پر وکیل ہوگا؟،\qt@no{109}}%
\qt@newcmd\qurantrans@ur@dciii{اور جو کوئی برا کام کرے یا اپنی جان پر ظلم کرے پھر اللہ سے بخشش طلب کرے وہ اللہ کو بڑا بخشنے والا نہایت مہربان پائے گا،\qt@no{110}}%
\qt@newcmd\qurantrans@ur@dciv{اور جو شخص کوئی گناہ کرے تو بس وہ اپنی ہی جان پر (اس کا وبال عائد) کر رہا ہے اور اللہ خوب جاننے والا بڑی حکمت والا ہے،\qt@no{111}}%
\qt@newcmd\qurantrans@ur@dcv{اور جو شحص کسی خطا یا گناہ کا ارتکاب کرے پھر اس کی تہمت کسی بے گناہ پرلگا دے تو اس نے یقیناً ایک بہتان اور کھلے گناہ (کے بوجھ) کو اٹھا لیا،\qt@no{112}}%
\qt@newcmd\qurantrans@ur@dcvi{اور (اے حبیب!) اگر آپ پر اللہ کا فضل اور اس کی رحمت نہ ہوتی تو ان (دغابازوں) میں سے ایک گروہ یہ ارادہ کر چکا تھا کہ آپ کو بہکا دیں، جب کہ وہ محض اپنے آپ کو ہی گمراہ کر رہے ہیں اور آپ کا تو کچھ بگاڑ ہی نہیں سکتے، اور اللہ نے آپ پر کتاب اور حکمت نازل فرمائی ہے اور اس نے آپ کو وہ سب علم عطا کر دیا ہے جوآپ نہیں جانتے تھے، اورآپ پر اللہ کا بہت بڑا فضل ہے،\qt@no{113}}%
\qt@newcmd\qurantrans@ur@dcvii{ان کے اکثر خفیہ مشوروں میں کوئی بھلائی نہیں سوائے اس شخص (کے مشورے) کے جو کسی خیرات کا یا نیک کام کا یا لوگوں میں صلح کرانے کا حکم دیتا ہے اور جو کوئی یہ کام اللہ کی رضا جوئی کے لئے کرے تو ہم اس کو عنقریب عظیم اجر عطا کریں گے،\qt@no{114}}%
\qt@newcmd\qurantrans@ur@dcviii{اور جو شخص رسول (صلی اللہ علیہ وآلہ وسلم) کی مخالفت کرے اس کے بعد کہ اس پر ہدایت کی راہ واضح ہو چکی اور مسلمانوں کی راہ سے جدا راہ کی پیروی کرے تو ہم اسے اسی (گمراہی) کی طرف پھیرے رکھیں گے جدھر وہ (خود) پھر گیا ہے اور (بالآخر) اسے دوزخ میں ڈالیں گے، اور وہ بہت ہی برا ٹھکانا ہے،\qt@no{115}}%
\qt@newcmd\qurantrans@ur@dcix{بیشک اللہ اس (بات) کو معاف نہیں کرتا کہ اس کے ساتھ کسی کو شریک ٹھہرایا جائے اور جو (گناہ) اس سے نیچے ہے جس کے لئے چاہے معاف فرما دیتا ہے، اور جو کوئی اللہ کے ساتھ شرک کرے وہ واقعی دور کی گمراہی میں بھٹک گیا،\qt@no{116}}%
\qt@newcmd\qurantrans@ur@dcx{یہ (مشرکین) اللہ کے سوا محض زنانی چیزوں ہی کی پرستش کرتے ہیں اور یہ فقط سرکش شیطان ہی کی پوجا کرتے ہیں،\qt@no{117}}%
\qt@newcmd\qurantrans@ur@dcxi{جس پراللہ نے لعنت کی ہے اور جس نے کہا تھا کہ میں تیرے بندوں میں سے ایک معیّن حصہ (اپنے لئے) ضرور لے لوں گا،\qt@no{118}}%
\qt@newcmd\qurantrans@ur@dcxii{میں انہیں ضرور گمراہ کردوں گا اور ضرور انہیں غلط اُمیدیں دلاؤں گا اور انہیں ضرور حکم دیتا رہوں گا سو وہ یقیناً جانوروں کے کان چیرا کریں گے اور میں انہیں ضرور حکم دیتا رہوں گا سو وہ یقیناً اللہ کی بنائی ہوئی چیزوں کو بدلا کریں گے، اور جو کوئی اللہ کو چھوڑ کر شیطان کو دوست بنالے تو واقعی وہ صریح نقصان میں رہا،\qt@no{119}}%
\qt@newcmd\qurantrans@ur@dcxiii{شیطان انہیں (غلط) وعدے دیتا ہے اور انہیں (جھوٹی) اُمیدیں دلاتا ہے اور شیطان فریب کے سوا ان سے کوئی وعدہ نہیں کرتا،\qt@no{120}}%
\qt@newcmd\qurantrans@ur@dcxiv{یہ وہ لوگ ہیں جن کا ٹھکانا دوزخ ہے اور وہ وہاں سے بھاگنے کی کوئی جگہ نہ پائیں گے،\qt@no{121}}%
\qt@newcmd\qurantrans@ur@dcxv{اور جو لوگ ایمان لائے اور نیک عمل کرتے رہے ہم انہیں عنقریب بہشتوں میں داخل کریں گے جن کے نیچے نہریں بہہ رہی ہوں گی وہ ان میں ہمیشہ ہمیشہ رہیں گے۔ (یہ) اللہ کا سچا وعدہ ہے، اور اللہ سے زیادہ بات کا سچا کون ہوسکتا ہے،\qt@no{122}}%
\qt@newcmd\qurantrans@ur@dcxvi{اللہ کا وعدۂ مغفرت) نہ تمہاری خواہشات پر موقوف ہے اور نہ اہلِ کتاب کی خواہشات پر، جو کوئی برا عمل کرے گا اسے اس کی سزا دی جائے گی اور نہ وہ اللہ کے سوا اپنا کوئی حمایتی پائے گا اور نہ مددگار،\qt@no{123}}%
\qt@newcmd\qurantrans@ur@dcxvii{اور جو کوئی نیک اعمال کرے گا (خواہ) مرد ہو یا عورت درآنحالیکہ وہ مومن ہے پس وہی لوگ جنت میں داخل ہوں گے اوران کی تِل برابر (بھی) حق تلفی نہیں کی جائے گے،\qt@no{124}}%
\qt@newcmd\qurantrans@ur@dcxviii{اور دینی اعتبار سے اُس شخص سے بہتر کون ہو سکتا ہے جس نے اپنا رُوئے نیاز اللہ کے لئے جھکا دیا اور وہ صاحبِ احسان بھی ہوا، اور وہ دینِ ابراہیم (علیہ السلام) کی پیروی کرتا رہا جو (اللہ کے لئے) یک سُو (اور) راست رَو تھے، اور اللہ نے ابراہیم (علیہ السلام) کو اپنا مخلص دوست بنا لیا تھا (سو وہ شخص بھی حضرت ابراہیم علیہ السلام کی نسبت سے اللہ کا دوست ہو گیا)،\qt@no{125}}%
\qt@newcmd\qurantrans@ur@dcxix{اور (سب) اللہ ہی کا ہے جو کچھ آسمانوں میں اور جو کچھ زمین میں ہے اور اللہ ہر چیز کا احاطہ فرمائے ہوئے ہے،\qt@no{126}}%
\qt@newcmd\qurantrans@ur@dcxx{اور (اے پیغمبر!) لوگ آپ سے (یتیم) عورتوں کے بارے میں فتویٰ پوچھتے ہیں۔ آپ فرما دیں کہ اللہ تمہیں ان کے بارے میں حکم دیتا ہے اور جو حکم تم کو (پہلے سے) کتابِ مجید میں سنایا جا رہا ہے (وہ بھی) ان یتیم عورتوں ہی کے بارے میں ہے جنہیں تم وہ (حقوق) نہیں دیتے جو ان کے لئے مقرر کئے گئے ہیں اور چاہتے ہو کہ (ان کا مال قبضے میں لینے کی خاطر) ان کے ساتھ خود نکاح کر لو اور نیز بے بس بچوں کے بارے میں (بھی حکم) ہے کہ یتیموں کے معاملے میں انصاف پر قائم رہا کرو، اور تم جو بھلائی بھی کروگے تو بیشک اللہ اسے خوب جاننے والا ہے،\qt@no{127}}%
\qt@newcmd\qurantrans@ur@dcxxi{اور اگر کوئی عورت اپنے شوہر کی جانب سے زیادتی یا بے رغبتی کا خوف رکھتی ہو تو دونوں (میاں بیوی) پر کوئی حرج نہیں کہ وہ آپس میں کسی مناسب بات پر صلح کر لیں، اور صلح (حقیقت میں) اچھی چیز ہے اور طبیعتوں میں (تھوڑا بہت) بخل (ضرور) رکھ دیا گیا ہے، اور اگر تم احسان کرو اور پرہیزگاری اختیار کرو تو بیشک اللہ ان کاموں سے جو تم کر رہے ہو (اچھی طرح) خبردار ہے،\qt@no{128}}%
\qt@newcmd\qurantrans@ur@dcxxii{اور تم ہرگز اس بات کی طاقت نہیں رکھتے کہ (ایک سے زائد) بیویوں کے درمیان (پورا پورا) عدل کر سکو اگرچہ تم کتنا بھی چاہو۔ پس (ایک کی طرف) پورے میلان طبع کے ساتھ (یوں) نہ جھک جاؤ کہ دوسری کو (درمیان میں) لٹکتی ہوئی چیز کی طرح چھوڑ دو۔ اور اگر تم اصلاح کر لو اور (حق تلفی و زیادتی سے) بچتے رہو تو اللہ بڑا بخشنے والا نہایت مہربان ہے،\qt@no{129}}%
\qt@newcmd\qurantrans@ur@dcxxiii{اور اگر دونوں (میاں بیوی) جدا ہو جائیں تواللہ ہر ایک کو اپنی کشائش سے (ایک دوسرے سے) بے نیاز کر دے گا اور اللہ بڑی وسعت والا بڑی حکمت والا ہے،\qt@no{130}}%
\qt@newcmd\qurantrans@ur@dcxxiv{اور اللہ ہی کا ہے جو کچھ آسمانوں میں اورجو کچھ زمین میں ہے۔ اور بیشک ہم نے ان لوگوں کو (بھی) جنہیں تم سے پہلے کتاب دی گئی حکم دیا ہے اور تمہیں (بھی) کہ اللہ سے ڈرتے رہا کرو۔ اور اگر تم نافرمانی کرو گے تو بیشک (سب کچھ) اللہ ہی کا ہے جو آسمانوں میں اورجو زمین میں ہے اوراللہ بے نیاز، ستودہ صفات ہے،\qt@no{131}}%
\qt@newcmd\qurantrans@ur@dcxxv{اوراللہ ہی کا ہے جو آسمانوں میں ہے اور جو زمین میں ہے، اور اللہ کا کارساز ہونا کافی ہے،\qt@no{132}}%
\qt@newcmd\qurantrans@ur@dcxxvi{اے لوگو! اگر وہ چاہے تو تمہیں نابود کر دے اور (تمہاری جگہ) دوسروں کو لے آئے، اور اللہ اس پر بڑی قدرت والا ہے،\qt@no{133}}%
\qt@newcmd\qurantrans@ur@dcxxvii{جو کوئی دنیا کا انعام چاہتا ہے تو اللہ کے پاس دنیا و آخرت (دونوں) کاانعام ہے، اور اللہ خوب سننے والا خوب دیکھنے والا ہے،\qt@no{134}}%
\qt@newcmd\qurantrans@ur@dcxxviii{اے ایمان والو! تم انصاف پر مضبوطی کے ساتھ قائم رہنے والے (محض) اللہ کے لئے گواہی دینے والے ہو جاؤ خواہ (گواہی) خود تمہارے اپنے یا (تمہارے) والدین یا (تمہارے) رشتہ داروں کے ہی خلاف ہو، اگرچہ (جس کے خلاف گواہی ہو) مال دار ہے یا محتاج، اللہ ان دونوں کا (تم سے) زیادہ خیر خواہ ہے۔ سو تم خواہشِ نفس کی پیروی نہ کیا کرو کہ عدل سے ہٹ جاؤ (گے)، اور اگر تم (گواہی میں) پیچ دار بات کرو گے یا (حق سے) پہلو تہی کرو گے تو بیشک اللہ ان سب کاموں سے جو تم کر رہے ہو خبردار ہے،\qt@no{135}}%
\qt@newcmd\qurantrans@ur@dcxxix{اے ایمان والو! تم اللہ پر اور اس کے رسول (صلی اللہ علیہ وآلہ وسلم) پر اور اس کتاب پر جو اس نے اپنے رسول (صلی اللہ علیہ وآلہ وسلم) پر نازل فرمائی ہے اور اس کتاب پر جو اس نے (اس سے) پہلے اتاری تھی ایمان لاؤ، اور جو کوئی اللہ کا اور اس کے فرشتوں کا اور اس کی کتابوں کا اور اس کے رسولوں کا اور آخرت کے دن کا انکار کرے تو بیشک وہ دور دراز کی گمراہی میں بھٹک گیا،\qt@no{136}}%
\qt@newcmd\qurantrans@ur@dcxxx{بیشک جو لوگ ایمان لائے پھر کافر ہوگئے، پھر ایمان لائے پھر کافر ہوگئے، پھر کفر میں اوربڑھ گئے تواللہ ہرگز (یہ ارادہ فرمانے والا) نہیں کہ انہیں بخش دے اور نہ (یہ کہ) انہیں سیدھا راستہ دکھائے،\qt@no{137}}%
\qt@newcmd\qurantrans@ur@dcxxxi{اے نبی!) آپ منافقوں کو یہ خبر سنا دیں کہ ان کے لئے دردناک عذاب ہے،\qt@no{138}}%
\qt@newcmd\qurantrans@ur@dcxxxii{یہ) ایسے لوگ (ہیں) جو مسلمانوں کی بجائے کافروں کو دوست بناتے ہیں، کیا یہ ان کے پاس عزت تلاش کرتے ہیں؟ پس عزت تو ساری اللہ (تعالٰی) کے لئے ہے،\qt@no{139}}%
\qt@newcmd\qurantrans@ur@dcxxxiii{اور بیشک (اللہ نے) تم پر کتاب میں یہ (حکم) نازل فرمایا ہے کہ جب تم سنو کہ اللہ کی آیتوں کا انکار کیا جا رہا ہے اور ان کا مذاق اُڑایا جا رہا ہے تو تم ان لوگوں کے ساتھ مت بیٹھو یہاں تک کہ وہ (انکار اور تمسخر کو چھوڑ کر) کسی دوسری بات میں مشغول ہو جائیں۔ ورنہ تم بھی انہی جیسے ہو جاؤ گے۔ بیشک اللہ منافقوں اور کافروں سب کو دوزخ میں جمع کرنے والا ہے،\qt@no{140}}%
\qt@newcmd\qurantrans@ur@dcxxxiv{وہ (منافق) جو تمہاری (فتح و شکست کی) تاک میں رہتے ہیں، پھر اگر تمہیں اللہ کی طرف سے فتح نصیب ہو جائے تو کہتے ہیں: کیا ہم تمہارے ساتھ نہ تھے؟ اور اگر کافروں کو (ظاہری فتح میں سے) کچھ حصہ مل گیا تو (ان سے) کہتے ہیں: کیا ہم تم پر غالب نہیں ہو گئے تھے اور (اس کے باوجود) کیا ہم نے تمہیں مسلمانوں (کے ہاتھوں نقصان) سے نہیں بچایا؟ پس اللہ تمہارے درمیان قیامت کے دن فیصلہ فرمائے گا، اور اللہ کافروں کو مسلمانوں پر (غلبہ پانے کی) ہرگز کوئی راہ نہ دے گا،\qt@no{141}}%
\qt@newcmd\qurantrans@ur@dcxxxv{بیشک منافق (بزعمِ خویش) اللہ کو دھوکہ دینا چاہتے ہیں حالانکہ وہ انہیں (اپنے ہی) دھوکے کی سزا دینے والا ہے، اور جب وہ نماز کے لئے کھڑے ہوتے ہیں تو سستی کے ساتھ (محض) لوگوں کو دکھانے کیلئے کھڑے ہوتے ہیں اور اللہ کویاد (بھی) نہیں کرتے مگر تھوڑا،\qt@no{142}}%
\qt@newcmd\qurantrans@ur@dcxxxvi{اس (کفر اور ایمان) کے درمیان تذبذب میں ہیں نہ ان (کافروں) کی طرف ہیں اور نہ ان (مؤمنوں) کی طرف ہیں، اورجسے اللہ گمراہ ٹھہرا دے تو آپ ہرگز اس کے لئے کوئی (ہدایت کی) راہ نہ پائیں گے،\qt@no{143}}%
\qt@newcmd\qurantrans@ur@dcxxxvii{اے ایمان والو! مسلمانوں کے سوا کافروں کو دوست نہ بناؤ، کیا تم چاہتے ہو کہ (نافرمانوں کی دوستی کے ذریعے) اپنے خلاف اللہ کی صریح حجت قائم کر لو،\qt@no{144}}%
\qt@newcmd\qurantrans@ur@dcxxxviii{بیشک منافق لوگ دوزخ کے سب سے نچلے درجے میں ہوں گے اور آپ ان کے لئے ہرگز کوئی مددگار نہ پائیں گے،\qt@no{145}}%
\qt@newcmd\qurantrans@ur@dcxxxix{مگر وہ لوگ جنہوں نے توبہ کر لی وہ سنور گئے اورانہوں نے اللہ سے مضبوط تعلق جوڑ لیا اور انہوں نے اپنا دین اللہ کے لئے خالص کر لیا تو یہ مؤمنوں کی سنگت میں ہوں گے اور عنقریب اللہ مومنوں کو عظیم اجر عطا فرمائے گا،\qt@no{146}}%
\qt@newcmd\qurantrans@ur@dcxl{اللہ تمہیں عذاب دے کر کیا کرے گا اگر تم شکر گزار بن جاؤ اور ایمان لے آؤ، اور اللہ (ہر حق کا) قدر شناس ہے (ہر عمل کا) خوب جاننے والا ہے،\qt@no{147}}%
\qt@newcmd\qurantrans@ur@dcxli{اﷲ کسی (کی) بری بات کا بآوازِ بلند (ظاہراً و علانیۃً) کہنا پسند نہیں فرماتا سوائے اس کے جس پر ظلم ہوا ہو (اسے ظالم کا ظلم آشکار کرنے کی اجازت ہے)، اور اﷲ خوب سننے والا جاننے والا ہے،\qt@no{148}}%
\qt@newcmd\qurantrans@ur@dcxlii{اگر تم کسی کارِ خیر کو ظاہر کرو یا اسے مخفی رکھو یا کسی (کی) برائی سے در گزر کرو تو بیشک اﷲ بڑا معاف فرمانے والا بڑی قدرت والا ہے،\qt@no{149}}%
\qt@newcmd\qurantrans@ur@dcxliii{بلا شبہ جو لوگ اﷲ اور اس کے رسولوں کے ساتھ کفر کرتے ہیں اور چاہتے ہیں کہ اﷲ اور اس کے رسولوں کے درمیان تفریق کریں اور کہتے ہیں کہ ہم بعض کو مانتے ہیں اور بعض کو نہیں مانتے اور چاہتے ہیں کہ اس (ایمان و کفر) کے درمیان کوئی راہ نکال لیں،\qt@no{150}}%
\qt@newcmd\qurantrans@ur@dcxliv{ایسے ہی لوگ درحقیقت کافر ہیں، اور ہم نے کافروں کے لئے رُسوا کن عذاب تیار کر رکھا ہے،\qt@no{151}}%
\qt@newcmd\qurantrans@ur@dcxlv{اور جو لوگ اﷲ اور اس کے (سب) رسولوں پر ایمان لائے اور ان (پیغمبروں) میں سے کسی کے درمیان (ایمان لانے میں) فرق نہ کیا تو عنقریب وہ انہیں ان کے اجر عطا فرمائے گا، اور اﷲ بڑا بخشنے والا نہایت مہربان ہے،\qt@no{152}}%
\qt@newcmd\qurantrans@ur@dcxlvi{اے حبیب!) آپ سے اہلِ کتاب سوال کرتے ہیں کہ آپ ان پر آسمان سے (ایک ہی دفعہ پوری لکھی ہوئی) کوئی کتاب اتار لائیں، تو وہ موسٰی (علیہ السلام) سے اس سے بھی بڑا سوال کر چکے ہیں، انہوں نے کہا تھا کہ ہمیں اﷲ (کی ذات) کھلم کھلا دکھا دو، پس ان کے (اس) ظلم (یعنی گستاخانہ سوال) کی وجہ سے انہیں آسمانی بجلی نے آپکڑا (جس کے باعث وہ مرگئے، پھر موسٰی علیہ السلام کی دعا سے زندہ ہوئے)، پھر انہوں نے بچھڑے کو (اپنا معبود) بنا لیا اس کے بعد کہ ان کے پاس (حق کی نشاندہی کرنے والی) واضح نشانیاں آچکی تھیں، پھر ہم نے اس (جرم) سے بھی درگزر کیا اور ہم نے موسٰی (علیہ السلام) کو (ان پر) واضح غلبہ عطا فرمایا،\qt@no{153}}%
\qt@newcmd\qurantrans@ur@dcxlvii{اور (جب یہود تورات کے احکام سے پھر انکاری ہوگئے تو) ہم نے ان سے (پختہ) عہد لینے کے لئے (کوہِ) طور کو ان کے اوپر اٹھا (کر معلّق کر) دیا، اور ہم نے ان سے فرمایا کہ تم (اس شہر کے) دروازے (یعنی بابِ ایلیاء) میں سجدۂ (شکر) کرتے ہوئے داخل ہونا، اور ہم نے ان سے (مزید) فرمایا کہ ہفتہ کے دن (مچھلی کے شکار کی ممانعت کے حکم) میں بھی تجاوز نہ کرنا اور ہم نے ان سے بڑا تاکیدی عہد لیا تھا،\qt@no{154}}%
\qt@newcmd\qurantrans@ur@dcxlviii{پس (انہیں جو سزائیں ملیں وہ) ان کی اپنی عہد شکنی پر اور آیاتِ الٰہی سے انکار (کے سبب) اور انبیاء کو ان کے ناحق قتل کر ڈالنے (کے باعث)، نیز ان کی اس بات (کے سبب) سے کہ ہمارے دلوں پر غلاف (چڑھے ہوئے) ہیں، (حقیقت میں ایسا نہ تھا) بلکہ اﷲ نے ان کے کفر کے باعث ان کے دلوں پر مُہر لگا دی ہے، سو وہ چند ایک کے سوا ایمان نہیں لائیں گے،\qt@no{155}}%
\qt@newcmd\qurantrans@ur@dcxlix{اور (مزید یہ کہ) ان کے (اس) کفر اور قول کے باعث جو انہوں نے مریم (علیہا السلام) پر زبردست بہتان لگایا،\qt@no{156}}%
\qt@newcmd\qurantrans@ur@dcl{اور ان کے اس کہنے (یعنی فخریہ دعوٰی) کی وجہ سے (بھی) کہ ہم نے اﷲ کے رسول، مریم کے بیٹے عیسٰی مسیح کو قتل کر ڈالا ہے، حالانکہ انہوں نے نہ ان کو قتل کیا اور نہ انہیں سولی چڑھایا مگر (ہوا یہ کہ) ان کے لئے (کسی کو عیسٰی علیہ السلام کا) ہم شکل بنا دیا گیا، اور بیشک جو لوگ ان کے بارے میں اختلاف کر رہے ہیں وہ یقیناً اس (قتل کے حوالے) سے شک میں پڑے ہوئے ہیں، انہیں (حقیقتِ حال کا) کچھ بھی علم نہیں مگر یہ کہ گمان کی پیروی (کر رہے ہیں)، اور انہوں نے عیسٰی (علیہ السلام) کو یقیناً قتل نہیں کیا،\qt@no{157}}%
\qt@newcmd\qurantrans@ur@dcli{بلکہ اﷲ نے انہیں اپنی طرف (آسمان پر) اٹھا لیا، اور اﷲ غالب حکمت والا ہے،\qt@no{158}}%
\qt@newcmd\qurantrans@ur@dclii{اور (قربِ قیامت نزولِ مسیح علیہ السلام کے وقت) اہلِ کتاب میں سے کوئی (فرد یا فرقہ) نہ رہے گا مگر وہ عیسٰی (علیہ السلام) پر ان کی موت سے پہلے ضرور (صحیح طریقے سے) ایمان لے آئے گا، اور قیامت کے دن عیسٰی (علیہ السلام) ان پر گواہ ہوں گے،\qt@no{159}}%
\qt@newcmd\qurantrans@ur@dcliii{پھر یہودیوں کے ظلم ہی کی وجہ سے ہم نے ان پر (کئی) پاکیزہ چیزیں حرام کر دیں جو (پہلے) ان کے لئے حلال کی جاچکی تھیں، اور اس وجہ سے (بھی) کہ وہ (لوگوں کو) اﷲ کی راہ سے بکثرت روکتے تھے،\qt@no{160}}%
\qt@newcmd\qurantrans@ur@dcliv{اور ان کے سود لینے کے سبب سے، حالانکہ وہ اس سے روکے گئے تھے، اور ان کے لوگوں کا ناحق مال کھانے کی وجہ سے (بھی انہیں سزا ملی) اور ہم نے ان میں سے کافروں کے لئے دردناک عذاب تیار کر رکھا ہے،\qt@no{161}}%
\qt@newcmd\qurantrans@ur@dclv{لیکن ان میں سے پختہ علم والے اور مومن لوگ اس (وحی) پر جو آپ کی طرف نازل کی گئی ہے اور اس (وحی) پر جو آپ سے پہلے نازل کی گئی (برابر) ایمان لاتے ہیں، اور وہ (کتنے اچھے ہیں کہ) نماز قائم کرنے والے (ہیں) اور زکوٰۃ دینے والے (ہیں) اور اﷲ اور قیامت کے دن پر ایمان رکھنے والے (ہیں)۔ ایسے ہی لوگوں کو ہم عنقریب بڑا اجر عطا فرمائیں گے،\qt@no{162}}%
\qt@newcmd\qurantrans@ur@dclvi{اے حبیب!) بیشک ہم نے آپ کی طرف (اُسی طرح) وحی بھیجی ہے جیسے ہم نے نوح (علیہ السلام) کی طرف اور ان کے بعد (دوسرے) پیغمبروں کی طرف بھیجی تھی۔ اور ہم نے ابراہیم و اسماعیل اور اسحاق و یعقوب اور (ان کی) اولاد اور عیسٰی اور ایوب اور یونس اور ہارون اور سلیمان (علیھم السلام) کی طرف (بھی) وحی فرمائی، اور ہم نے داؤد (علیہ السلام) کو (بھی) زبور عطا کی تھی،\qt@no{163}}%
\qt@newcmd\qurantrans@ur@dclvii{اور (ہم نے کئی) ایسے رسول (بھیجے) ہیں جن کے حالات ہم (اس سے) پہلے آپ کو سنا چکے ہیں اور (کئی) ایسے رسول بھی (بھیجے) ہیں جن کے حالات ہم نے (ابھی تک) آپ کو نہیں سنائے اور اﷲ نے موسٰی (علیہ السلام) سے (بلاواسطہ) گفتگو (بھی) فرمائی،\qt@no{164}}%
\qt@newcmd\qurantrans@ur@dclviii{رسول جو خوشخبری دینے والے اور ڈر سنانے والے تھے (اس لئے بھیجے گئے) تاکہ (ان) پیغمبروں (کے آجانے) کے بعد لوگوں کے لئے اﷲ پر کوئی عذر باقی نہ رہے، اور اﷲ بڑا غالب حکمت والا ہے،\qt@no{165}}%
\qt@newcmd\qurantrans@ur@dclix{اے حبیب! کوئی آپ کی نبوت پر ایمان لائے یا نہ لائے) مگر اﷲ (خود اس بات کی) گواہی دیتا ہے کہ جو کچھ اس نے آپ کی طرف نازل فرمایا ہے، اسے اپنے علم سے نازل فرمایا ہے اور فرشتے (بھی آپ کی خاطر) گواہی دیتے ہیں، اور اﷲ کا گواہ ہونا (ہی) کافی ہے،\qt@no{166}}%
\qt@newcmd\qurantrans@ur@dclx{بیشک جنہوں نے کفر کیا (یعنی نبوتِ محمدی صلی اللہ علیہ وآلہ وسلم کی تکذیب کی) اور (لوگوں کو) اﷲ کی راہ سے روکا، یقینا وہ (حق سے) بہت دور کی گمراہی میں جا بھٹکے،\qt@no{167}}%
\qt@newcmd\qurantrans@ur@dclxi{بیشک جنہوں نے (اﷲ کی گواہی کو نہ مان کر) کفر کیا اور (رسول کی شان کو نہ مان کر) ظلم کیا، اﷲ ہرگز (ایسا) نہیں کہ انہیں بخش دے اور نہ (ایسا ہے کہ آخرت میں) انہیں کوئی راستہ دکھائے،\qt@no{168}}%
\qt@newcmd\qurantrans@ur@dclxii{سوائے جہنم کے راستے کے جس میں وہ ہمیشہ ہمیشہ رہیں گے، اور یہ کام اﷲ پر آسان ہے،\qt@no{169}}%
\qt@newcmd\qurantrans@ur@dclxiii{اے لوگو! بیشک تمہارے پاس یہ رسول (صلی اللہ علیہ وآلہ وسلم) تمہارے رب کی طرف سے حق کے ساتھ تشریف لایا ہے، سو تم (ان پر) اپنی بہتری کے لئے ایمان لے آؤ اور اگر تم کفر (یعنی ان کی رسالت سے انکار) کرو گے تو (جان لو وہ تم سے بے نیاز ہے کیونکہ) جو کچھ آسمانوں اور زمین میں ہے یقیناً (وہ سب) اﷲ ہی کا ہے اور اﷲ خوب جاننے والا بڑی حکمت والا ہے،\qt@no{170}}%
\qt@newcmd\qurantrans@ur@dclxiv{اے اہلِ کتاب! تم اپنے دین میں حد سے زائد نہ بڑھو اور اﷲ کی شان میں سچ کے سوا کچھ نہ کہو، حقیقت صرف یہ ہے کہ مسیح عیسٰی ابن مریم (علیہما السلام) اﷲ کا رسول اور اس کا کلمہ ہے جسے اس نے مریم کی طرف پہنچا دیا اور اس (کی طرف) سے ایک روح ہے۔ پس تم اﷲ اور اس کے رسولوں پر ایمان لاؤ اور مت کہو کہ (معبود) تین ہیں، (اس عقیدہ سے) باز آجاؤ، (یہ) تمہارے لئے بہتر ہے۔ بیشک اﷲ ہی یکتا معبود ہے، وہ اس سے پاک ہے کہ اس کے لئے کوئی اولاد ہو، (سب کچھ) اسی کا ہے جو کچھ آسمانوں میں ہے اور جو کچھ زمین میں ہے، اور اﷲ کا کارساز ہونا کافی ہے،\qt@no{171}}%
\qt@newcmd\qurantrans@ur@dclxv{مسیح (علیہ السلام) اس (بات) سے ہرگز عار نہیں رکھتا کہ وہ اﷲ کا بندہ ہو اور نہ ہی مقرّب فرشتوں کو (اس سے کوئی عار ہے)، اور جو کوئی اس کی بندگی سے عار محسوس کرے اور تکبر کرے تو وہ ایسے تمام لوگوں کو عنقریب اپنے پاس جمع فرمائے گا،\qt@no{172}}%
\qt@newcmd\qurantrans@ur@dclxvi{پس جو لوگ ایمان لائے اور نیک عمل کرتے رہے وہ انہیں پورے پورے اجر عطا فرمائے گا اور (پھر) اپنے فضل سے انہیں اور زیادہ دے گا، اور وہ لوگ جنہوں نے (اﷲ کی عبادت سے) عار محسوس کی اور تکبرّ کیا تو وہ انہیں دردناک عذاب دے گا، اور وہ اپنے لئے اﷲ کے سوا نہ کوئی دوست پائیں گے اور نہ کوئی مددگار،\qt@no{173}}%
\qt@newcmd\qurantrans@ur@dclxvii{اے لوگو! بیشک تمہارے پاس تمہارے رب کی جانب سے (ذاتِ محمدی صلی اللہ علیہ وآلہ وسلم کی صورت میں ذاتِ حق جل مجدہ کی سب سے زیادہ مضبوط، کامل اور واضح) دلیلِ قاطع آگئی ہے اور ہم نے تمہاری طرف (اسی کے ساتھ قرآن کی صورت میں) واضح اور روشن نُور (بھی) اتار دیا ہے،\qt@no{174}}%
\qt@newcmd\qurantrans@ur@dclxviii{پس جو لوگ اﷲ پر ایمان لائے اور اس (کے دامن) کو مضبوطی سے پکڑے رکھا تو عنقریب (اﷲ) انہیں اپنی (خاص) رحمت اور فضل میں داخل فرمائے گا، اور انہیں اپنی طرف (پہنچنے کا) سیدھا راستہ دکھائے گا،\qt@no{175}}%
\qt@newcmd\qurantrans@ur@dclxix{لوگ آپ سے فتویٰ (یعنی شرعی حکم) دریافت کرتے ہیں۔ فرما دیجئے کہ اﷲ تمہیں (بغیر اولاد اور بغیر والدین کے فوت ہونے والے) کلالہ (کی وراثت) کے بارے میں یہ حکم دیتا ہے کہ اگر کوئی ایسا شخص فوت ہو جائے جو بے اولاد ہو مگر اس کی ایک بہن ہو تو اس کے لئے اس (مال) کا آدھا (حصہ) ہے جو اس نے چھوڑا ہے، اور (اگر اس کے برعکس بہن کلالہ ہو تو اس کے مرنے کی صورت میں اس کا) بھائی اس (بہن) کا وارث (کامل) ہوگا اگر اس (بہن) کی کوئی اولاد نہ ہو، پھر اگر (کلالہ بھائی کی موت پر) دو (بہنیں وارث) ہوں تو ان کے لئے اس (مال) کا دو تہائی (حصہ) ہے جو اس نے چھوڑا ہے، اور اگر (بصورتِ کلالہ مرحوم کے) چند بھائی بہن مرد (بھی) اور عورتیں (بھی وارث) ہوں تو پھر (ہر) ایک مرد کا (حصہ) دو عورتوں کے حصہ کے برابر ہوگا۔ (یہ احکام) اﷲ تمہارے لئے کھول کر بیان فرما رہا ہے تاکہ تم بھٹکتے نہ پھرو، اور اﷲ ہر چیز کو خوب جاننے والا ہے،\qt@no{176}}%
\qt@newcmd\qurantrans@ur@dclxx{\basmalahur اے ایمان والو! (اپنے) عہد پورے کرو۔ تمہارے لئے چوپائے جانور (یعنی مویشی) حلال کر دیئے گئے (ہیں) سوائے ان (جانوروں) کے جن کا بیان تم پر آئندہ کیا جائے گا (لیکن) جب تم اِحرام کی حالت میں ہو، شکار کو حلال نہ سمجھنا۔ بیشک اﷲ جو چاہتا ہے حکم فرماتا ہے،\qt@no{1}}%
\qt@newcmd\qurantrans@ur@dclxxi{اے ایمان والو! اﷲ کی نشانیوں کی بے حرمتی نہ کرو اور نہ حرمت (و ادب) والے مہینے کی (یعنی ذوالقعدہ، ذوالحجہ، محرم اور رجب میں سے کسی ماہ کی) اور نہ حرمِ کعبہ کو بھیجے ہوئے قربانی کے جانوروں کی اور نہ مکّہ لائے جانے والے ان جانوروں کی جن کے گلے میں علامتی پٹے ہوں اور نہ حرمت والے گھر (یعنی خانہ کعبہ) کا قصد کرکے آنے والوں (کے جان و مال اور عزت و آبرو) کی (بے حرمتی کرو کیونکہ یہ وہ لوگ ہیں) جو اپنے رب کا فضل اور رضا تلاش کر رہے ہیں، اور جب تم حالتِ اِحرام سے باہر نکل آؤ تو تم شکار کرسکتے ہو، اور تمہیں کسی قوم کی (یہ) دشمنی کہ انہوں نے تم کو مسجدِ حرام (یعنی خانہ کعبہ کی حاضری) سے روکا تھا اس بات پر ہرگز نہ ابھارے کہ تم (ان کے ساتھ) زیادتی کرو، اور نیکی اور پرہیزگاری (کے کاموں) پر ایک دوسرے کی مدد کیا کرو اور گناہ اور ظلم (کے کاموں) پر ایک دوسرے کی مدد نہ کرو اور اﷲ سے ڈرتے رہو۔ بیشک اﷲ (نافرمانی کرنے والوں کو) سخت سزا دینے والا ہے،\qt@no{2}}%
\qt@newcmd\qurantrans@ur@dclxxii{تم پر مردار (یعنی بغیر شرعی ذبح کے مرنے والا جانور) حرام کر دیا گیا ہے اور (بہایا ہوا) خون اور سؤر کا گوشت اور وہ (جانور) جس پر ذبح کے وقت غیر اﷲ کا نام پکارا گیا ہو اور گلا گھٹ کر مرا ہوا (جانور) اور (دھار دار آلے کے بغیر کسی چیز کی) ضرب سے مرا ہوا اور اوپر سے گر کر مرا ہوا اور (کسی جانور کے) سینگ مارنے سے مرا ہوا اور وہ (جانور) جسے درندے نے پھاڑ کھایا ہو سوائے اس کے جسے (مرنے سے پہلے) تم نے ذبح کر لیا، اور (وہ جانور بھی حرام ہے) جو باطل معبودوں کے تھانوں (یعنی بتوں کے لئے مخصوص کی گئی قربان گاہوں) پر ذبح کیا گیا ہو اور یہ (بھی حرام ہے) کہ تم پانسوں (یعنی فال کے تیروں) کے ذریعے قسمت کا حال معلوم کرو (یا حصے تقسیم کرو)، یہ سب کام گناہ ہیں۔ آج کافر لوگ تمہارے دین (کے غالب آجانے کے باعث اپنے ناپاک ارادوں) سے مایوس ہو گئے، سو (اے مسلمانو!) تم ان سے مت ڈرو اور مجھ ہی سے ڈرا کرو۔ آج میں نے تمہارے لئے تمہارا دین مکمل کر دیا اور تم پر اپنی نعمت پوری کر دی اور تمہارے لئے اسلام کو (بطور) دین (یعنی مکمل نظامِ حیات کی حیثیت سے) پسند کر لیا۔ پھر اگر کوئی شخص بھوک (اور پیاس) کی شدت میں اضطراری (یعنی انتہائی مجبوری کی) حالت کو پہنچ جائے (اس شرط کے ساتھ) کہ گناہ کی طرف مائل ہونے والا نہ ہو (یعنی حرام چیز گناہ کی رغبت کے باعث نہ کھائے) تو بیشک اﷲ بہت بخشنے والا نہایت مہربان ہے،\qt@no{3}}%
\qt@newcmd\qurantrans@ur@dclxxiii{لوگ آپ سے سوال کرتے ہیں کہ ان کے لئے کیا چیزیں حلال کی گئی ہیں، آپ (ان سے) فرما دیں کہ تمہارے لئے پاک چیزیں حلال کر دی گئی ہیں اور وہ شکاری جانور جنہیں تم نے شکار پر دوڑاتے ہوئے یوں سدھار لیا ہے کہ تم انہیں (شکار کے وہ طریقے) سکھاتے ہو جو تمہیں اﷲ نے سکھائے ہیں، سو تم اس (شکار) میں سے (بھی) کھاؤ جو وہ (شکاری جانور) تمہارے لئے (مار کر) روک رکھیں اور (شکار پر چھوڑتے وقت) اس (شکاری جانور) پر اﷲ کا نام لیا کرو اور اﷲ سے ڈرتے رہو۔ بیشک اﷲ حساب میں جلدی فرمانے والا ہے،\qt@no{4}}%
\qt@newcmd\qurantrans@ur@dclxxiv{آج تمہارے لئے پاکیزہ چیزیں حلال کر دی گئیں، اور ان لوگوں کا ذبیحہ (بھی) جنہیں (اِلہامی) کتاب دی گئی تمہارے لئے حلال ہے اور تمہارا ذبیحہ ان کے لئے حلال ہے، اور (اسی طرح) پاک دامن مسلمان عورتیں اور ان لوگوں میں سے پاک دامن عورتیں جنہیں تم سے پہلے کتاب دی گئی تھی (تمہارے لئے حلال ہیں) جب کہ تم انہیں ان کے مَہر ادا کر دو، (مگر شرط) یہ کہ تم (انہیں) قیدِ نکاح میں لانے والے (عفت شعار) بنو نہ کہ (محض ہوس رانی کی خاطر) اِعلانیہ بدکاری کرنے والے اور نہ خفیہ آشنائی کرنے والے، اور جو شخص (اَحکامِ الٰہی پر) ایمان (لانے) سے انکار کرے تو اس کا سارا عمل برباد ہوگیا اور وہ آخرت میں (بھی) نقصان اٹھانے والوں میں سے ہوگا،\qt@no{5}}%
\qt@newcmd\qurantrans@ur@dclxxv{اے ایمان والو! جب (تمہارا) نماز کیلئے کھڑے (ہونے کا ارادہ) ہو تو (وضو کے لئے) اپنے چہروں کو اور اپنے ہاتھوں کو کہنیوں سمیت دھو لو اور اپنے سروں کا مسح کرو اور اپنے پاؤں (بھی) ٹخنوں سمیت (دھو لو)، اور اگر تم حالتِ جنابت میں ہو تو (نہا کر) خوب پاک ہو جاؤ، اور اگر تم بیمار ہو یا سفر میں ہو یا تم سے کوئی رفعِ حاجت سے (فارغ ہو کر) آیا ہو یا تم نے عورتوں سے قربت (مجامعت) کی ہو پھر تم پانی نہ پاؤ تو (اندریں صورت) پاک مٹی سے تیمم کر لیا کرو۔ پس (تیمم یہ ہے کہ) اس (پاک مٹی) سے اپنے چہروں اور اپنے (پورے) ہاتھوں کا مسح کر لو۔ اﷲ نہیں چاہتا کہ وہ تمہارے اوپر کسی قسم کی سختی کرے لیکن وہ (یہ) چاہتا ہے کہ تمہیں پاک کردے اور تم پر اپنی نعمت پوری کر دے تاکہ تم شکر گزار بن جاؤ،\qt@no{6}}%
\qt@newcmd\qurantrans@ur@dclxxvi{اور اﷲ کی (اس) نعمت کو یاد کرو جو تم پر (کی گئی) ہے اور اس کے عہد کو (بھی یاد کرو) جو اس نے تم سے (پختہ طریقے سے) لیا تھا جب کہ تم نے (اقراراً) کہا تھا کہ ہم نے (اﷲ کے حکم کو) سنا اور ہم نے (اس کی) اطاعت کی اور اﷲ سے ڈرتے رہو، بیشک اﷲ سینوں کی (پوشیدہ) باتوں کو خوب جانتا ہے،\qt@no{7}}%
\qt@newcmd\qurantrans@ur@dclxxvii{اے ایمان والو! اﷲ کے لئے مضبوطی سے قائم رہتے ہوئے انصاف پر مبنی گواہی دینے والے ہو جاؤ اور کسی قوم کی سخت دشمنی (بھی) تمہیں اس بات پر برانگیختہ نہ کرے کہ تم (اس سے) عدل نہ کرو۔ عدل کیا کرو (کہ) وہ پرہیزگاری سے نزدیک تر ہے، اور اﷲ سے ڈرا کرو، بیشک اﷲ تمہارے کاموں سے خوب آگاہ ہے،\qt@no{8}}%
\qt@newcmd\qurantrans@ur@dclxxviii{اﷲ نے ایسے لوگوں سے جو ایمان لائے اور نیک عمل کرتے رہے وعدہ فرمایا ہے (کہ) ان کے لئے بخشش اور بڑا اجر ہے،\qt@no{9}}%
\qt@newcmd\qurantrans@ur@dclxxix{اور جن لوگوں نے کفر کیا اور ہماری آیتوں کو جھٹلایا وہی لوگ دوزخ (میں جلنے) والے ہیں،\qt@no{10}}%
\qt@newcmd\qurantrans@ur@dclxxx{اے ایمان والو! تم اﷲ کے (اُس) انعام کو یاد کرو (جو) تم پر ہوا جب قوم (کفّار) نے یہ ارادہ کیا کہ اپنے ہاتھ (قتل و ہلاکت کے لئے) تمہاری طرف دراز کریں تو اﷲ نے ان کے ہاتھ تم سے روک دیئے، اور اﷲ سے ڈرتے رہو، اور ایمان والوں کو اﷲ ہی پر بھروسہ رکھنا چاہئے،\qt@no{11}}%
\qt@newcmd\qurantrans@ur@dclxxxi{اور بیشک اﷲ نے بنی اسرائیل سے پختہ عہد لیا اور (اس کی تعمیل، تنفیذ اور نگہبانی کے لئے) ہم نے ان میں بارہ سردار مقرر کئے، اور اﷲ نے (بنی اسرائیل سے) فرمایا کہ میں تمہارے ساتھ ہوں (یعنی میری خصوصی مدد و نصرت تمہارے ساتھ رہے گی)، اگر تم نے نماز قائم رکھی اور تم زکوٰۃ دیتے رہے اور میرے رسولوں پر (ہمیشہ) ایمان لاتے رہے اور ان (کے پیغمبرانہ مشن) کی مدد کرتے رہے اور اﷲ کو (اس کے دین کی حمایت و نصرت میں مال خرچ کرکے) قرضِ حسن دیتے رہے تو میں تم سے تمہارے گناہوں کو ضرور مٹا دوں گا اور تمہیں یقیناً ایسی جنتوں میں داخل کر دوں گا جن کے نیچے نہریں جاری ہیں۔ پھر اس کے بعد تم میں سے جس نے (بھی) کفر (یعنی عہد سے انحراف) کیا تو بیشک وہ سیدھی راہ سے بھٹک گیا،\qt@no{12}}%
\qt@newcmd\qurantrans@ur@dclxxxii{پھر ان کی اپنی عہد شکنی کی وجہ سے ہم نے ان پر لعنت کی (یعنی وہ ہماری رحمت سے محروم ہوگئے)، اور ہم نے ان کے دلوں کو سخت کر دیا (یعنی وہ ہدایت اور اثر پذیری سے محروم ہوگئے، چنانچہ) وہ لوگ (کتابِ الٰہی کے) کلمات کو ان کے (صحیح) مقامات سے بدل دیتے ہیں اور اس (رہنمائی) کا ایک (بڑا) حصہ بھول گئے ہیں جس کی انہیں نصیحت کی گئی تھی، اور آپ ہمیشہ ان کی کسی نہ کسی خیانت پر مطلع ہوتے رہیں گے سوائے ان میں سے چند ایک کے (جو ایمان لا چکے ہیں) سو آپ انہیں معاف فرما دیجئے اور درگزر فرمائیے، بیشک اﷲ احسان کرنے والوں کو پسند فرماتا ہے،\qt@no{13}}%
\qt@newcmd\qurantrans@ur@dclxxxiii{اور ہم نے ان لوگوں سے (بھی اسی قسم کا) عہد لیا تھا جو کہتے ہیں: ہم نصاریٰ ہیں، پھر وہ (بھی) اس (رہنمائی) کا ایک (بڑا) حصہ فراموش کر بیٹھے جس کی انہیں نصیحت کی گئی تھی۔ سو (اس بدعہدی کے باعث) ہم نے ان کے درمیان دشمنی اور کینہ روزِ قیامت تک ڈال دیا، اور عنقریب اﷲ انہیں ان (اعمال کی حقیقت) سے آگاہ فرما دے گا جو وہ کرتے رہتے تھے،\qt@no{14}}%
\qt@newcmd\qurantrans@ur@dclxxxiv{اے اہلِ کتاب! بیشک تمہارے پاس ہمارے (یہ) رسول تشریف لائے ہیں جو تمہارے لئے بہت سی ایسی باتیں (واضح طور پر) ظاہر فرماتے ہیں جو تم کتاب میں سے چھپائے رکھتے تھے اور (تمہاری) بہت سی باتوں سے درگزر (بھی) فرماتے ہیں۔ بیشک تمہارے پاس اﷲ کی طرف سے ایک نور (یعنی حضرت محمد صلی اللہ علیہ وآلہ وسلم) آگیا ہے اور ایک روشن کتاب (یعنی قرآن مجید)،\qt@no{15}}%
\qt@newcmd\qurantrans@ur@dclxxxv{اﷲ اس کے ذریعے ان لوگوں کو جو اس کی رضا کے پیرو ہیں، سلامتی کی راہوں کی ہدایت فرماتا ہے اور انہیں اپنے حکم سے (کفر و جہالت کی) تاریکیوں سے نکال کر (ایمان و ہدایت کی) روشنی کی طرف لے جاتا ہے اور انہیں سیدھی راہ کی سمت ہدایت فرماتا ہے،\qt@no{16}}%
\qt@newcmd\qurantrans@ur@dclxxxvi{بیشک ان لوگوں نے کفر کیا جو کہتے ہیں کہ یقیناً اﷲ مسیح ابن مریم ہی (تو) ہے، آپ فرما دیں: پھر کون (ایسا شخص) ہے جو اﷲ (کی مشیت میں) سے کسی شے کا مالک ہو؟ اگر وہ اس بات کا ارادہ فرمالے کہ مسیح ابن مریم اور اس کی ماں اور سب زمین والوں کو ہلاک فرما دے گا (تو اس کے فیصلے کے خلاف انہیں کون بچا سکتا ہے؟) اور آسمانوں اور زمین اور جو (کائنات) ان دونوں کے درمیان ہے (سب) کی بادشاہی اﷲ ہی کے لئے ہے، وہ جو چاہتا ہے پیدا فرماتا ہے، اور اﷲ ہر چیز پر بڑا قادر ہے،\qt@no{17}}%
\qt@newcmd\qurantrans@ur@dclxxxvii{اور یہود اور نصارٰی نے کہا: ہم اﷲ کے بیٹے اور اس کے محبوب ہیں۔ آپ فرما دیجئے: (اگر تمہاری بات درست ہے) تو وہ تمہارے گناہوں پر تمہیں عذاب کیوں دیتا ہے؟ بلکہ (حقیقت یہ ہے کہ) جن (مخلوقات) کو اﷲ نے پیدا کیا ہے تم (بھی) ان (ہی) میں سے بشر ہو (یعنی دیگر طبقاتِ انسانی ہی کی مانند ہو)، وہ جسے چاہے بخشش سے نوازتا ہے اور جسے چاہے عذاب سے دوچار کرتا ہے، اور آسمانوں اور زمین اور وہ (کائنات) جو دونوں کے درمیان ہے (سب) کی بادشاہی اﷲ ہی کے لئے ہے اور (ہر ایک کو) اسی کی طرف پلٹ کر جانا ہے،\qt@no{18}}%
\qt@newcmd\qurantrans@ur@dclxxxviii{اے اہلِ کتاب! بیشک تمہارے پاس ہمارے (یہ آخر الزمان) رسول (صلی اللہ علیہ وآلہ وسلم) پیغمبروں کی آمد (کے سلسلے) کے منقطع ہونے (کے موقع) پر تشریف لائے ہیں، جو تمہارے لئے (ہمارے احکام) خوب واضح کرتے ہیں، (اس لئے) کہ تم (عذر کرتے ہوئے یہ) کہہ دوگے کہ ہمارے پاس نہ (تو) کوئی خوشخبری سنانے والا آیا ہے اور نہ ڈر سنانے والا۔ (اب تمہارا یہ عذر بھی ختم ہو چکا ہے کیونکہ) بلاشبہ تمہارے پاس (آخری) خوشخبری سنانے اور ڈر سنانے والا (بھی) آگیا ہے، اور اﷲ ہر چیز پر بڑا قادر ہے،\qt@no{19}}%
\qt@newcmd\qurantrans@ur@dclxxxix{اور (وہ وقت بھی یاد کریں) جب موسٰی (علیہ السلام) نے اپنی قوم سے کہا: اے میری قوم! تم اپنے اوپر (کیا گیا) اﷲ کا وہ انعام یاد کرو جب اس نے تم میں انبیاء پیدا فرمائے اور تمہیں بادشاہ بنایا اور تمہیں وہ (کچھ) عطا فرمایا جو (تمہارے زمانے میں) تمام جہانوں میں سے کسی کو نہیں دیا تھا،\qt@no{20}}%
\qt@newcmd\qurantrans@ur@dcxc{اے میری قوم! (ملکِ شام یا بیت المقدس کی) اس مقدس سرزمین میں داخل ہو جاؤ جو اﷲ نے تمہارے لئے لکھ دی ہے اور اپنی پشت پر (پیچھے) نہ پلٹنا ورنہ تم نقصان اٹھانے والے بن کر پلٹو گے،\qt@no{21}}%
\qt@newcmd\qurantrans@ur@dcxci{انہوں نے (جوابًا) کہا: اے موسٰی! اس میں تو زبردست (ظالم) لوگ (رہتے) ہیں اور ہم اس میں ہرگز داخل نہیں ہوں گے یہاں تک کہ وہ اس (زمین) سے نکل جائیں، پس اگر وہ یہاں سے نکل جائیں تو ہم ضرور داخل ہو جائیں گے،\qt@no{22}}%
\qt@newcmd\qurantrans@ur@dcxcii{ان (چند) لوگوں میں سے جو (اﷲ سے) ڈرتے تھے دو (ایسے) شخص بول اٹھے جن پر اﷲ نے انعام فرمایا تھا (اپنی قوم سے کہنے لگے:) تم ان لوگوں پر (بلا خوف حملہ کرتے ہوئے شہر کے) دروازے سے داخل ہو جاؤ، سو جب تم اس (دروازے) میں داخل ہو جاؤ گے تو یقیناً تم غالب ہو جاؤ گے، اور اﷲ ہی پر توکل کرو بشرطیکہ تم ایمان والے ہو،\qt@no{23}}%
\qt@newcmd\qurantrans@ur@dcxciii{انہوں نے کہا: اے موسٰی! جب تک وہ لوگ اس (سرزمین) میں ہیں ہم ہرگز کبھی بھی وہاں داخل نہیں ہوں گے، پس تم جاؤ اور تمہارا رب (ساتھ جائے) سو تم دونوں (ہی ان سے) جنگ کرو، ہم تو یہیں بیٹھے ہیں،\qt@no{24}}%
\qt@newcmd\qurantrans@ur@dcxciv{موسٰی علیہ السلام نے) عرض کیا: اے میرے رب! میں اپنی ذات اور اپنے بھائی (ہارون علیہ السلام) کے سوا (کسی پر) اختیار نہیں رکھتا پس تو ہمارے اور (اس) نافرمان قوم کے درمیان (اپنے حکم سے) جدائی فرما دے،\qt@no{25}}%
\qt@newcmd\qurantrans@ur@dcxcv{ربّ نے) فرمایا: پس یہ (سرزمین) ان (نافرمان) لوگوں پر چالیس سال تک حرام کر دی گئی ہے، یہ لوگ زمین میں (پریشان حال) سرگرداں پھرتے رہیں گے، سو (اے موسٰی! اب) اس نافرمان قوم (کے عبرت ناک حال) پر افسوس نہ کرنا،\qt@no{26}}%
\qt@newcmd\qurantrans@ur@dcxcvi{اے نبی مکرم!) آپ ان لوگوں کو آدم (علیہ السلام) کے دو بیٹوں (ہابیل و قابیل) کی خبر سنائیں جو بالکل سچی ہے۔ جب دونوں نے (اﷲ کے حضور ایک ایک) قربانی پیش کی سو ان میں سے ایک (ہابیل) کی قبول کر لی گئی اور دوسرے (قابیل) سے قبول نہ کی گئی تو اس (قابیل) نے (ہابیل سے حسداً و انتقاماً) کہا: میں تجھے ضرور قتل کر دوں گا، اس (ہابیل) نے (جواباً) کہا: بیشک اﷲ پرہیزگاروں سے ہی (نیاز) قبول فرماتا ہے،\qt@no{27}}%
\qt@newcmd\qurantrans@ur@dcxcvii{اگر تو اپنا ہاتھ مجھے قتل کرنے کے لئے میری طرف بڑھائے گا (تو پھر بھی) میں اپنا ہاتھ تجھے قتل کرنے کے لئے تیری طرف نہیں بڑھاؤں گا کیونکہ میں اﷲ سے ڈرتا ہوں جو تمام جہانوں کا پروردگار ہے،\qt@no{28}}%
\qt@newcmd\qurantrans@ur@dcxcviii{میں چاہتا ہوں (کہ مجھ سے کوئی زیادتی نہ ہو اور) میرا گناہ ِ (قتل) اور تیرا اپنا (سابقہ) گناہ (جس کے باعث تیری قربانی نامنظور ہوئی سب) توہی حاصل کرلے پھر تو اہلِ جہنم میں سے ہو جائے گا، اور یہی ظالموں کی سزا ہے،\qt@no{29}}%
\qt@newcmd\qurantrans@ur@dcxcix{پھر اس (قابیل) کے نفس نے اس کے لئے اپنے بھائی (ہابیل) کا قتل آسان (اور مرغوب) کر دکھایا، سو اس نے اس کو قتل کردیا، پس وہ نقصان اٹھانے والوں میں سے ہوگیا،\qt@no{30}}%
\qt@newcmd\qurantrans@ur@dcc{پھر اﷲ نے ایک کوّا بھیجا جو زمین کریدنے لگا تاکہ اسے دکھائے کہ وہ اپنے بھائی کی لاش کس طرح چھپائے، (یہ دیکھ کر) اس نے کہا: ہائے افسوس! کیا میں اس کوّے کی مانند بھی نہ ہوسکا کہ اپنے بھائی کی لاش چھپا دیتا، سو وہ پشیمان ہونے والوں میں سے ہوگیا،\qt@no{31}}%
\qt@newcmd\qurantrans@ur@dcci{اسی وجہ سے ہم نے بنی اسرائیل پر (نازل کی گئی تورات میں یہ حکم) لکھ دیا (تھا) کہ جس نے کسی شخص کو بغیر قصاص کے یا زمین میں فساد (پھیلانے یعنی خونریزی اور ڈاکہ زنی وغیرہ کی سزا) کے (بغیر ناحق) قتل کر دیا تو گویا اس نے (معاشرے کے) تمام لوگوں کو قتل کر ڈالا اور جس نے اسے (ناحق مرنے سے بچا کر) زندہ رکھا تو گویا اس نے (معاشرے کے) تمام لوگوں کو زندہ رکھا (یعنی اس نے حیاتِ انسانی کا اجتماعی نظام بچا لیا)، اور بیشک ان کے پاس ہمارے رسول واضح نشانیاں لے کر آئے پھر (بھی) اس کے بعد ان میں سے اکثر لوگ یقیناً زمین میں حد سے تجاوز کرنے والے ہیں،\qt@no{32}}%
\qt@newcmd\qurantrans@ur@dccii{بیشک جو لوگ اﷲ اور اس کے رسول سے جنگ کرتے ہیں اور زمین میں فساد انگیزی کرتے پھرتے ہیں (یعنی مسلمانوں میں خونریز رہزنی اور ڈاکہ زنی وغیرہ کے مرتکب ہوتے ہیں) ان کی سزا یہی ہے کہ وہ قتل کئے جائیں یا پھانسی دیئے جائیں یا ان کے ہاتھ اور ان کے پاؤں مخالف سمتوں سے کاٹے جائیں یا (وطن کی) زمین (میں چلنے پھرنے) سے دور (یعنی ملک بدر یاقید) کر دیئے جائیں۔ یہ (تو) ان کے لئے دنیا میں رسوائی ہے اور ان کے لئے آخرت میں (بھی) بڑا عذاب ہے،\qt@no{33}}%
\qt@newcmd\qurantrans@ur@dcciii{مگر جن لوگوں نے، قبل اس کے کہ تم ان پر قابو پا جاؤ، توبہ کرلی، سو جان لو کہ اﷲ بہت بخشنے والا نہایت مہربان ہے،\qt@no{34}}%
\qt@newcmd\qurantrans@ur@dcciv{اے ایمان والو! اﷲ سے ڈرتے رہو اور اس (کے حضور) تک (تقرب اور رسائی کا) وسیلہ تلاش کرو اور اس کی راہ میں جہاد کرو تاکہ تم فلاح پاجاؤ،\qt@no{35}}%
\qt@newcmd\qurantrans@ur@dccv{بیشک جو لوگ کفر کے مرتکب ہو رہے ہیں اگر ان کے پاس وہ سب کچھ (مال و متاع اور خزانہ موجود) ہو جو روئے زمین میں ہے بلکہ اس کے ساتھ اتنا اور (بھی) تاکہ وہ روزِ قیامت کے عذاب سے (نجات کے لئے) اسے فدیہ (یعنی اپنی جان کے بدلہ) میں دے دیں تو (وہ سب کچھ بھی) ان سے قبول نہیں کیا جائے گا، اور ان کے لئے درد ناک عذاب ہے،\qt@no{36}}%
\qt@newcmd\qurantrans@ur@dccvi{وہ چاہیں گے کہ (کسی طرح) دوزخ سے نکل جائیں جب کہ وہ اس سے نہیں نکل سکیں گے اور ان کے لئے دائمی عذاب ہے،\qt@no{37}}%
\qt@newcmd\qurantrans@ur@dccvii{اور چوری کرنے والا (مرد) اور چوری کرنے والی (عورت) سو دونوں کے ہاتھ کاٹ دو اس (جرم) کی پاداش میں جو انہوں نے کمایا ہے۔ (یہ) اﷲ کی طرف سے عبرت ناک سزا (ہے)، اور اﷲ بڑا غالب ہے بڑی حکمت والا ہے،\qt@no{38}}%
\qt@newcmd\qurantrans@ur@dccviii{پھر جو شخص اپنے (اس) ظلم کے بعد توبہ اور اصلاح کرلے تو بیشک اﷲ اس پر رحمت کے ساتھ رجوع فرمانے والا ہے۔ یقیناً اﷲ بڑا بخشنے والا بہت رحم فرمانے والا ہے،\qt@no{39}}%
\qt@newcmd\qurantrans@ur@dccix{اے انسان!) کیا تو نہیں جانتا کہ آسمانوں اور زمین کی (ساری) بادشاہت اﷲ ہی کے لئے ہے، وہ جسے چاہتا ہے عذاب دیتا ہے اور جسے چاہتا ہے بخش دیتا ہے، اور اللہ ہر چیز پر خوب قدرت رکھتا ہے،\qt@no{40}}%
\qt@newcmd\qurantrans@ur@dccx{اے رسول! وہ لوگ آپ کور نجیدہ خاطر نہ کریں جو کفر میں تیزی (سے پیش قدمی) کرتے ہیں ان میں (ایک) وہ (منافق) ہیں جو اپنے منہ سے کہتے ہیں کہ ہم ایمان لائے حالانکہ ان کے دل ایمان نہیں لائے، اور ان میں (دوسرے) یہودی ہیں، (یہ) جھوٹی باتیں بنانے کے لئے (آپ کو)خوب سنتے ہیں (یہ حقیقت میں) دوسرے لوگوں کے لئے (جاسوسی کی خاطر) سننے والے ہیں جو (ابھی تک) آپ کے پاس نہیں آئے، (یہ وہ لوگ ہیں) جو (اﷲ کے) کلمات کوان کے مواقع (مقرر ہونے) کے بعد (بھی) بدل دیتے ہیں (اور) کہتے ہیں: اگر تمہیں یہ (حکم جو ان کی پسند کا ہو) دیا جائے تو اسے اختیار کرلو اور اگر تمہیں یہ (حکم) نہ دیا جائے تو(اس سے) احتراز کرو، اور اﷲ جس شخص کی گمراہی کا ارادہ فرمالے تو تم اس کے لئے اﷲ (کے حکم کو روکنے) کا ہرگز کوئی اختیار نہیں رکھتے۔ یہی وہ لوگ ہیں جن کے دلوں کو پاک کرنے کااﷲ نے ارادہ (ہی) نہیں فرمایا۔ ان کے لئے دنیا میں (کفر کی) ذلّت ہے اور ان کے لئے آخرت میں بڑا عذاب ہے،\qt@no{41}}%
\qt@newcmd\qurantrans@ur@dccxi{یہ لوگ) جھوٹی باتیں بنانے کے لئے جاسوسی کرنے والے ہیں (مزید یہ کہ) حرام مال خوب کھانے والے ہیں۔ سو اگر (یہ لوگ) آپ کے پاس (کوئی نزاعی معاملہ لے کر) آئیں تو آپ (کو اختیار ہے کہ) ان کے درمیان فیصلہ فرمادیں یا ان سے گریز فرما لیں، اور اگر آپ ان سے گریز (بھی) فرمالیں تو (تب بھی) یہ آپ کو ہرگز کوئی ضرر نہیں پہنچا سکتے، اور اگر آپ فیصلہ فرمائیں تو ان کے درمیان (بھی) عدل سے (ہی) فیصلہ فرمائیں (یعنی ان کی دشمنی عادلانہ فیصلے میں رکاوٹ نہ بنے)، بیشک اﷲ عدل کرنے والوں کو پسند فرماتا ہے،\qt@no{42}}%
\qt@newcmd\qurantrans@ur@dccxii{اور یہ لوگ آپ کو کیوں کر حاکم مان سکتے ہیں در آنحالیکہ ان کے پاس تورات (موجود) ہے جس میں اللہ کا حکم (مذکور) ہے، پھر یہ اس کے بعد (بھی حق سے) رُوگردانی کرتے ہیں، اور وہ لوگ (بالکل) ایمان لانے والے نہیں ہیں،\qt@no{43}}%
\qt@newcmd\qurantrans@ur@dccxiii{بیشک ہم نے تورات نازل فرمائی جس میں ہدایت اور نور تھا، اس کے مطابق انبیاء جو (اﷲ کے) فرمانبردار (بندے) تھے یہودیوں کو حکم دیتے رہے اور اﷲ والے (یعنی ان کے اولیاء) اور علماء (بھی اسی کے مطابق فیصلے کرتے رہے)، اس وجہ سے کہ وہ اﷲ کی کتاب کے محافظ بنائے گئے تھے اور وہ اس پر نگہبان (و گواہ) تھے۔ پس تم (اقامتِ دین اور احکامِ الٰہی کے نفاذ کے معاملے میں) لوگوں سے مت ڈرو اور (صرف) مجھ سے ڈرا کرو اور میری آیات (یعنی احکام) کے بدلے (دنیا کی) حقیر قیمت نہ لیا کرو، اور جو شخص اللہ کے نازل کردہ حکم کے مطابق فیصلہ (و حکومت) نہ کرے سو وہی لوگ کافر ہیں،\qt@no{44}}%
\qt@newcmd\qurantrans@ur@dccxiv{اور ہم نے اس (تورات) میں ان پر فرض کردیا تھا کہ جان کے بدلے جان اور آنکھ کے عوض آنکھ اور ناک کے بدلے ناک اور کان کے عوض کان اور دانت کے بدلے دانت اور زخموں میں (بھی) بدلہ ہے، تو جو شخص اس (قصاص) کو صدقہ (یعنی معاف) کر دے تو یہ اس (کے گناہوں) کے لئے کفارہ ہوگا، اور جو شخص اللہ کے نازل کردہ حکم کے مطابق فیصلہ (و حکومت) نہ کرے سو وہی لوگ ظالم ہیں،\qt@no{45}}%
\qt@newcmd\qurantrans@ur@dccxv{اور ہم نے ان (پیغمبروں) کے پیچھے ان (ہی) کے نقوشِ قدم پر عیسٰی ابن مریم (علیھما السلام) کو بھیجا جو اپنے سے پہلے کی (کتاب) تورات کی تصدیق کرنے والے تھے اور ہم نے ان کو انجیل عطا کی جس میں ہدایت اور نور تھا اور (یہ انجیل بھی) اپنے سے پہلے کی (کتاب) تورات کی تصدیق کرنے والی (تھی) اور (سراسر) ہدایت تھی اور پرہیز گاروں کے لئے نصیحت تھی،\qt@no{46}}%
\qt@newcmd\qurantrans@ur@dccxvi{اور اہلِ انجیل کو (بھی) اس (حکم) کے مطابق فیصلہ کرنا چاہئے جو اللہ نے اس میں نازل فرمایا ہے، اور جو شخص اللہ کے نازل کردہ حکم کے مطابق فیصلہ (و حکومت) نہ کرے سو وہی لوگ فاسق ہیں،\qt@no{47}}%
\qt@newcmd\qurantrans@ur@dccxvii{اور (اے نبئ مکرّم!) ہم نے آپ کی طرف (بھی) سچائی کے ساتھ کتاب نازل فرمائی ہے جو اپنے سے پہلے کی کتاب کی تصدیق کرنے والی ہے اور اس (کے اصل احکام و مضامین) پر نگہبان ہے، پس آپ ان کے درمیان ان (احکام) کے مطابق فیصلہ فرمائیں جو اﷲ نے نازل فرمائے ہیں اور آپ ان کی خواہشات کی پیروی نہ کریں، اس حق سے دور ہو کر جو آپ کے پاس آچکا ہے۔ ہم نے تم میں سے ہر ایک کے لئے الگ شریعت اور کشادہ راہِ عمل بنائی ہے، اور اگر اﷲ چاہتا تو تم سب کو (ایک شریعت پر متفق) ایک ہی امّت بنا دیتا لیکن وہ تمہیں ان (الگ الگ احکام) میں آزمانا چاہتا ہے جو اس نے تمہیں (تمہارے حسبِ حال) دیئے ہیں، سو تم نیکیوں میں جلدی کرو۔ اﷲ ہی کی طرف تم سب کو پلٹنا ہے، پھر وہ تمہیں ان (سب باتوں میں حق و باطل) سے آگاہ فرمادے گا جن میں تم اختلاف کرتے رہتے تھے،\qt@no{48}}%
\qt@newcmd\qurantrans@ur@dccxviii{اور (اے حبیب! ہم نے یہ حکم کیا ہے کہ) آپ ان کے درمیان اس (فرمان) کے مطابق فیصلہ فرمائیں جو اﷲ نے نازل فرمایا ہے اور ان کی خواہشات کی پیروی نہ کریں اور آپ ان سے بچتے رہیں کہیں وہ آپ کو ان بعض (احکام) سے جو اللہ نے آپ کی طرف نازل فرمائے ہیں پھیر (نہ) دیں، پھر اگر وہ (آپ کے فیصلہ سے) روگردانی کریں تو آپ جان لیں کہ بس اﷲ ان کے بعض گناہوں کے باعث انہیں سزا دینا چاہتا ہے، اور لوگوں میں سے اکثر نافرمان (ہوتے) ہیں،\qt@no{49}}%
\qt@newcmd\qurantrans@ur@dccxix{کیا یہ لوگ (زمانۂ) جاہلیت کا قانون چاہتے ہیں، اور یقین رکھنے والی قوم کے لئے حکم (دینے) میں اﷲ سے بہتر کون ہو سکتا ہے،\qt@no{50}}%
\qt@newcmd\qurantrans@ur@dccxx{اے ایمان والو! یہود اور نصارٰی کو دوست مت بناؤ یہ (سب تمہارے خلاف) آپس میں ایک دوسرے کے دوست ہیں، اور تم میں سے جو شخص ان کو دوست بنائے گا بیشک وہ (بھی) ان میں سے ہو (جائے) گا، یقیناً اﷲ ظالم قوم کو ہدایت نہیں فرماتا،\qt@no{51}}%
\qt@newcmd\qurantrans@ur@dccxxi{سو آپ ایسے لوگوں کو دیکھیں گے جن کے دلوں میں (نفاق اور ذہنوں میں غلامی کی) بیماری ہے کہ وہ ان (یہود و نصارٰی) میں (شامل ہونے کے لئے) دوڑتے ہیں، کہتے ہیں: ہمیں خوف ہے کہ ہم پر کوئی گردش (نہ) آجائے (یعنی ان کے ساتھ ملنے سے شاید ہمیں تحفظ مل جائے)، تو بعید نہیں کہ اﷲ (واقعۃً مسلمانوں کی) فتح لے آئے یا اپنی طرف سے کوئی امر (فتح و کامرانی کا نشان بنا کر بھیج دے) تو یہ لوگ اس (منافقانہ سوچ) پر جسے یہ اپنے دلوں میں چھپائے ہوئے ہیں شرمندہ ہوکر رہ جائیں گے،\qt@no{52}}%
\qt@newcmd\qurantrans@ur@dccxxii{اور (اس وقت) ایمان والے یہ کہیں گے کیا یہی وہ لوگ ہیں جنہوں نے بڑے تاکیدی حلف (کی صورت) میں اﷲ کی قَسمیں کھائی تھیں کہ بیشک وہ ضرور تمہارے (ہی) ساتھ ہیں، (مگر) ان کے سارے اعمال اکارت گئے، سو وہ نقصان اٹھانے والے ہوگئے،\qt@no{53}}%
\qt@newcmd\qurantrans@ur@dccxxiii{اے ایمان والو! تم میں سے جو شخص اپنے دین سے پھر جائے گا تو عنقریب اﷲ (ان کی جگہ) ایسی قوم کو لائے گا جن سے وہ (خود) محبت فرماتا ہوگا اور وہ اس سے محبت کرتے ہوں گے وہ مومنوں پر نرم (اور) کافروں پر سخت ہوں گے اﷲ کی راہ میں (خوب) جہاد کریں گے اور کسی ملامت کرنے والے کی ملامت سے خوفزدہ نہیں ہوں گے۔ یہ (انقلابی کردار) اللہ کافضل ہے وہ جسے چاہتا ہے عطا فرماتا ہے اور اﷲ وسعت والا (ہے) خوب جاننے والا ہے،\qt@no{54}}%
\qt@newcmd\qurantrans@ur@dccxxiv{بیشک تمہارا (مددگار) دوست تو اﷲ اور اس کا رسول (صلی اللہ علیہ وآلہ وسلم) ہی ہے اور (ساتھ) وہ ایمان والے ہیں جو نماز قائم رکھتے ہیں اور زکوٰۃ ادا کرتے ہیں اور وہ (اﷲ کے حضور عاجزی سے) جھکنے والے ہیں،\qt@no{55}}%
\qt@newcmd\qurantrans@ur@dccxxv{اور جو شخص اﷲ اور اس کے رسول (صلی اللہ علیہ وآلہ وسلم) اور ایمان والوں کو دوست بنائے گا تو (وہی اﷲ کی جماعت ہے اور) اللہ کی جماعت (کے لوگ) ہی غالب ہونے والے ہیں،\qt@no{56}}%
\qt@newcmd\qurantrans@ur@dccxxvi{اے ایمان والو! ایسے لوگوں میں سے جنہیں تم سے پہلے کتاب دی گئی تھی، ان کو جو تمہارے دین کو ہنسی اور کھیل بنائے ہوئے ہیں اور کافروں کو دوست مت بناؤ، اور اﷲ سے ڈرتے رہو بشرطیکہ تم (واقعی) صاحبِ ایمان ہو،\qt@no{57}}%
\qt@newcmd\qurantrans@ur@dccxxvii{اور جب تم نماز کے لئے (لوگوں کو بصورتِ اذان) پکارتے ہو تو یہ (لوگ) اسے ہنسی اور کھیل بنا لیتے ہیں۔ یہ اس لئے کہ وہ ایسے لوگ ہیں جو (بالکل) عقل ہی نہیں رکھتے،\qt@no{58}}%
\qt@newcmd\qurantrans@ur@dccxxviii{اے نبئ مکرّم!) آپ فرما دیجئے: اے اہلِ کتاب! تمہیں ہماری کون سی بات بری لگی ہے بجز اس کے کہ ہم اﷲ پر اور اس (کتاب) پر جو ہماری طرف نازل کی گئی ہے اور ان (کتابوں) پر جو پہلے نازل کی جا چکی ہیں ایمان لائے ہیں اور بیشک تمہارے اکثر لوگ نافرمان ہیں،\qt@no{59}}%
\qt@newcmd\qurantrans@ur@dccxxix{فرما دیجئے: کیا میں تمہیں اس شخص سے آگاہ کروں جو سزا کے اعتبار سے اللہ کے نزدیک اس سے (بھی) برا ہے (جسے تم برا سمجھتے ہو، اور یہ وہ شخص ہی) جس پر اللہ نے لعنت کی ہے اور اس پر غضب ناک ہوا ہے اور اس نے ان (برے لوگوں) میں سے (بعض کو) بندر اور (بعض کو) سؤر بنا دیا ہے، اور (یہ ایسا شخص ہے) جس نے شیطان کی (اطاعت و) پرستش کی ہے، یہی لوگ ٹھکانے کے اعتبار سے بدترین اور سیدھی راہ سے بہت ہی بھٹکے ہوئے ہیں،\qt@no{60}}%
\qt@newcmd\qurantrans@ur@dccxxx{اور جب وہ(منافق) تمہارے پاس آتے ہیں (تو) کہتے ہیں: ہم ایمان لے آئے ہیں حالانکہ وہ (تمہاری مجلس میں) کفر کے ساتھ ہی داخل ہوئے اور اسی (کفر) کے ساتھ ہی نکل گئے، اور اﷲ ان (باتوں) کو خوب جانتا ہے جنہیں وہ چھپائے پھرتے ہیں،\qt@no{61}}%
\qt@newcmd\qurantrans@ur@dccxxxi{اور آپ ان میں بکثرت ایسے لوگ دیکھیں گے جو گناہ اور ظلم اور اپنی حرام خوری میں بڑی تیزی سے کوشاں ہوتے ہیں۔ بیشک وہ جو کچھ کررہے ہیں بہت برا ہے،\qt@no{62}}%
\qt@newcmd\qurantrans@ur@dccxxxii{انہیں (روحانی) درویش اور (دینی) علماء ان کے قولِ گناہ اور اکلِ حرام سے منع کیوں نہیں کرتے؟ بیشک وہ (بھی برائی کے خلاف آواز بلند نہ کر کے) جو کچھ تیار کر رہے ہیں بہت برا ہے،\qt@no{63}}%
\qt@newcmd\qurantrans@ur@dccxxxiii{اور یہود کہتے ہیں کہ اﷲ کا ہاتھ بندھا ہوا ہے (یعنی معاذ اﷲ وہ بخیل ہے)، ان کے (اپنے) ہاتھ باندھے جائیں اور جو کچھ انہوں نے کہا اس کے باعث ان پر لعنت کی گئی، بلکہ (حق یہ ہے کہ) اس کے دونوں ہاتھ (جود و سخا کے لئے) کشادہ ہیں، وہ جس طرح چاہتا ہے خرچ (یعنی بندوں پر عطائیں) فرماتا ہے، اور (اے حبیب!) جو (کتاب) آپ کی طرف آپ کے ربّ کی جانب سے نازل کی گئی ہے یقیناً ان میں سے اکثر لوگوں کو (حسداً) سر کشی اور کفر میں اور بڑھا دے گی، اور ہم نے ان کے درمیان روزِ قیامت تک عداوت اور بغض ڈال دیا ہے، جب بھی یہ لوگ جنگ کی آگ بھڑکاتے ہیں اﷲ اسے بجھا دیتا ہے اور یہ (روئے) زمین میں فساد انگیزی کرتے رہتے ہیں، اور اﷲ فساد کرنے والوں کو پسند نہیں کرتا،\qt@no{64}}%
\qt@newcmd\qurantrans@ur@dccxxxiv{اور اگر اہلِ کتاب (حضرت محمد مصطفی صلی اللہ علیہ وآلہ وسلم پر) ایمان لے آتے اور تقوٰی اختیار کر لیتے تو ہم ان (کے دامن) سے ان کے سارے گناہ مٹا دیتے اور انہیں یقیناً نعمت والی جنتوں میں داخل کردیتے،\qt@no{65}}%
\qt@newcmd\qurantrans@ur@dccxxxv{اور اگر وہ لوگ تورات اور انجیل اور جو کچھ (مزید) ان کی طرف ان کے رب کی جانب سے نازل کیا گیا تھا (نافذ اور) قائم کردیتے تو (انہیں مالی وسائل کی اس قدر وسعت عطا ہوجاتی کہ) وہ اپنے اوپر سے (بھی) اور اپنے پاؤں کے نیچے سے (بھی) کھاتے (مگر رزق ختم نہ ہوتا)۔ ان میں سے ایک گروہ میانہ رَو (یعنی اعتدال پسند ہے)، اور ان میں سے اکثر لوگ جو کچھ کررہے ہیں نہایت ہی برا ہے،\qt@no{66}}%
\qt@newcmd\qurantrans@ur@dccxxxvi{اے (برگزیدہ) رسول! جو کچھ آپ کی طرف آپ کے رب کی جانب سے نازل کیا گیا ہے (وہ سارا لوگوں کو) پہنچا دیجئے، اور اگر آپ نے (ایسا) نہ کیا تو آپ نے اس (ربّ) کا پیغام پہنچایا ہی نہیں، اور اﷲ (مخالف) لوگوں سے آپ (کی جان) کی (خود) حفاظت فرمائے گا۔ بیشک اﷲ کافروں کو راہِ ہدایت نہیں دکھاتا،\qt@no{67}}%
\qt@newcmd\qurantrans@ur@dccxxxvii{فرما دیجئے: اے اہلِ کتاب! تم (دین میں سے) کسی شے پر بھی نہیں ہو، یہاں تک کہ تم تورات اور انجیل اور جو کچھ تمہاری طرف تمہارے رب کی جانب سے نازل کیا گیا ہے (نافذ اور) قائم کر دو، اور (اے حبیب!) جو (کتاب) آپ کی طرف آپ کے رب کی جانب سے نازل کی گئی ہے یقیناً ان میں سے اکثر لوگوں کو (حسداً) سرکشی اور کفر میں بڑھا دے گی، سو آپ گروہِ کفار (کی حالت) پر افسوس نہ کیا کریں،\qt@no{68}}%
\qt@newcmd\qurantrans@ur@dccxxxviii{بیشک (خود کو) مسلمان (کہنے والے) اور یہودی اور صابی (یعنی ستارہ پرست) اور نصرانی جو بھی (سچے دل سے تعلیماتِ محمدی کے مطابق) اللہ پر اور یومِ آخرت پر ایمان لائے اور نیک عمل کرتے رہے تو ان پر نہ کوئی خوف ہوگا اور نہ وہ غمگین ہوں گے،\qt@no{69}}%
\qt@newcmd\qurantrans@ur@dccxxxix{بیشک ہم نے بنی اسرائیل سے عہد (بھی) لیا اور ہم نے ان کی طرف (بہت سے) پیغمبر (بھی) بھیجے، (مگر) جب بھی ان کے پاس کوئی پیغمبر ایسا حکم لایا جسے ان کے نفس نہیں چاہتے تھے تو انہوں نے (انبیاء کی) ایک جماعت کو جھٹلایا اور ایک کو (مسلسل) قتل کرتے رہے،\qt@no{70}}%
\qt@newcmd\qurantrans@ur@dccxl{اور وہ (ساتھ) یہ خیال کرتے رہے کہ (انبیاء کے قتل و تکذیب سے) کوئی عذاب نہیں آئے گا، سو وہ اندھے اور بہرے ہوگئے تھے۔ پھر اﷲ نے ان کی توبہ قبول فرما لی، پھر ان میں سے اکثر لوگ (دوبارہ) اندھے اور بہرے (یعنی حق دیکھنے اور سننے سے قاصر) ہوگئے، اور اﷲ ان کاموں کو خوب دیکھ رہا ہے جو وہ کر رہے ہیں،\qt@no{71}}%
\qt@newcmd\qurantrans@ur@dccxli{درحقیقت ایسے لوگ کافر ہوگئے ہیں جنہوں نے کہا کہ اﷲ ہی مسیح ابنِ مریم (علیہما السلام) ہے حالانکہ مسیح (علیہ السلام) نے (تو یہ) کہا تھا: اے بنی اسرائیل! تم اللہ کی عبادت کرو جو میرا (بھی) ربّ ہے اور تمہارا (بھی) ربّ ہے۔ بیشک جو اللہ کے ساتھ شرک کرے گا تو یقیناً اﷲ نے اس پر جنت حرام فرما دی ہے اور اس کا ٹھکانا دوزخ ہے، اور ظالموں کے لئے کوئی بھی مدد گار نہ ہوگا،\qt@no{72}}%
\qt@newcmd\qurantrans@ur@dccxlii{بیشک ایسے لوگ (بھی) کافر ہوگئے ہیں جنہوں نے کہا کہ اللہ تین (معبودوں) میں سے تیسرا ہے، حالانکہ معبودِ یکتا کے سوا کوئی عبادت کے لائق نہیں، اور اگر وہ ان (بیہودہ باتوں) سے جو وہ کہہ رہے ہیں بازنہ آئے تو ان میں سے کافروں کو دردناک عذاب ضرور پہنچے گا،\qt@no{73}}%
\qt@newcmd\qurantrans@ur@dccxliii{کیا یہ لوگ اللہ کی بارگاہ میں رجوع نہیں کرتے اور اس سے مغفرت طلب (نہیں) کرتے، حالانکہ اﷲ بڑا بخشنے والا بہت رحم فرمانے والا ہے،\qt@no{74}}%
\qt@newcmd\qurantrans@ur@dccxliv{مسیح ابنِ مریم (علیھما السلام) رسول کے سوا (کچھ) نہیں ہیں (یعنی خدا یا خدا کا بیٹا اور شریک نہیں ہیں)، یقیناً ان سے پہلے (بھی) بہت سے رسول گزر چکے ہیں، اور ان کی والدہ بڑی صاحبِ صدق (ولیّہ) تھیں، وہ دونوں (مخلوق تھے کیونکہ) کھانا بھی کھایا کرتے تھے۔ (اے حبیب!) دیکھئے ہم ان (کی رہنمائی) کے لئے کس طرح آیتوں کو وضاحت سے بیان کرتے ہیں پھر ملاحظہ فرمائیے کہ (اس کے باوجود) وہ کس طرح (حق سے) پھرے جارہے ہیں،\qt@no{75}}%
\qt@newcmd\qurantrans@ur@dccxlv{فرما دیجئے: کیا تم اللہ کے سوا اس کی عبادت کرتے ہو جو نہ تمہارے لئے کسی نقصان کا مالک ہے نہ نفع کا، اور اﷲ ہی تو خوب سننے والا اور خوب جاننے والا ہے،\qt@no{76}}%
\qt@newcmd\qurantrans@ur@dccxlvi{فرما دیجئیے: اے اہلِ کتاب! تم اپنے دین میں ناحق حد سے تجاوز نہ کیا کرو اور نہ ان لوگوں کی خواہشات کی پیروی کیا کرو جو (بعثتِ محمدی صلی اللہ علیہ وآلہ وسلم سے) پہلے ہی گمراہ ہو چکے تھے اور بہت سے (اور) لوگوں کو (بھی) گمراہ کرگئے اور (بعثتِ محمدی صلی اللہ علیہ وآلہ وسلم کے بعد بھی) سیدھی راہ سے بھٹکے رہے،\qt@no{77}}%
\qt@newcmd\qurantrans@ur@dccxlvii{بنی اسرائیل میں سے جن لوگوں نے کفر کیا تھا انہیں داؤد اور عیسٰی ابن مریم (علیھما السلام) کی زبان پر (سے) لعنت کی جا چکی (ہے)۔ یہ اس لئے کہ انہوں نے نافرمانی کی اور حد سے تجاوز کرتے تھے،\qt@no{78}}%
\qt@newcmd\qurantrans@ur@dccxlviii{اور اس لعنت کا ایک سبب یہ بھی تھا کہ) وہ جو برا کام کرتے تھے ایک دوسرے کو اس سے منع نہیں کرتے تھے۔ بیشک وہ کام برے تھے جنہیں وہ انجام دیتے تھے،\qt@no{79}}%
\qt@newcmd\qurantrans@ur@dccxlix{آپ ان میں سے اکثر لوگوں کو دیکھیں گے کہ وہ کافروں سے دوستی رکھتے ہیں۔ کیا ہی بری چیز ہے جو انہوں نے اپنے (حسابِ آخرت) کے لئے آگے بھیج رکھی ہے (اور وہ) یہ کہ اﷲ ان پر (سخت) ناراض ہوگیا، اور وہ لوگ ہمیشہ عذاب ہی میں (گرفتار) رہنے والے ہیں،\qt@no{80}}%
\qt@newcmd\qurantrans@ur@dccl{اور اگر وہ اللہ پر اور نبی (آخرالزماں صلی اللہ علیہ وآلہ وسلم) پر اور اس (کتاب) پر جو ان کی طرف نازل کی گئی ہے ایمان لے آتے تو ان (دشمنانِ اسلام) کو دوست نہ بناتے، لیکن ان میں سے اکثر لوگ نافرمان ہیں،\qt@no{81}}%
\qt@newcmd\qurantrans@ur@dccli{آپ یقیناً ایمان والوں کے حق میں بلحاظِ عداوت سب لوگوں سے زیادہ سخت یہودیوں اور مشرکوں کو پائیں گے، اور آپ یقیناً ایمان والوں کے حق میں بلحاظِ محبت سب سے قریب تر ان لوگوں کو پائیں گے جو کہتے ہیں: بیشک ہم نصاریٰ ہیں۔ یہ اس لئے کہ ان میں علماءِ (شریعت بھی) ہیں اور (عبادت گزار) گوشہ نشین بھی ہیں اور (نیز) وہ تکبر نہیں کرتے،\qt@no{82}}%
\qt@newcmd\qurantrans@ur@dcclii{اور (یہی وجہ ہے کہ ان میں سے بعض سچے عیسائی جب اس (قرآن) کو سنتے ہیں جو رسول (صلی اللہ علیہ وآلہ وسلم) کی طرف اتارا گیا ہے تو آپ ان کی آنکھوں کو اشک ریز دیکھتے ہیں۔ (یہ آنسوؤں کا چھلکنا) اس حق کے باعث (ہے) جس کی انہیں معرفت (نصیب) ہوگئی ہے۔ (ساتھ یہ) عرض کرتے ہیں: اے ہمارے رب! ہم (تیرے بھیجے ہوئے حق پر) ایمان لے آئے ہیں سو تو ہمیں (بھی حق کی) گواہی دینے والوں کے ساتھ لکھ لے،\qt@no{83}}%
\qt@newcmd\qurantrans@ur@dccliii{اور ہمیں کیا ہے کہ ہم اللہ پر اور اس حق (یعنی حضرت محمد مصطفیٰ صلی اللہ علیہ وآلہ وسلم اور قرآن مجید) پر جو ہمارے پاس آیا ہے، ایمان نہ لائیں حالانکہ ہم (بھی یہ) طمع رکھتے ہیں کہ ہمارا رب ہمیں نیک لوگوں کے ساتھ (اپنی رحمت و جنت میں) داخل فرما دے،\qt@no{84}}%
\qt@newcmd\qurantrans@ur@dccliv{سو اللہ نے ان کی اس (مومنانہ) بات کے عوض انہیں ثواب میں جنتیں عطا فرما دیں جن کے نیچے نہریں بہہ رہی ہیں۔ (وہ) ان میں ہمیشہ رہنے والے ہیں، اور یہی نیکوکاروں کی جزا ہے،\qt@no{85}}%
\qt@newcmd\qurantrans@ur@dcclv{اور جن لوگوں نے کفر کیا اور ہماری آیتوں کو جھٹلایا وہی لوگ دوزخ (میں رہنے) والے ہیں،\qt@no{86}}%
\qt@newcmd\qurantrans@ur@dcclvi{اے ایمان والو! جو پاکیزہ چیزیں اللہ نے تمہارے لئے حلال کی ہیں انہیں (اپنے اوپر) حرام مت ٹھہراؤ اور نہ (ہی) حد سے بڑھو، بیشک اللہ حد سے تجاوز کرنے والوں کو پسند نہیں فرماتا،\qt@no{87}}%
\qt@newcmd\qurantrans@ur@dcclvii{اور جو حلال پاکیزہ رزق اللہ نے تمہیں عطا فرمایا ہے اس میں سے کھایا کرو اور اللہ سے ڈرتے رہو جس پر تم ایمان رکھتے ہو،\qt@no{88}}%
\qt@newcmd\qurantrans@ur@dcclviii{اللہ تمہاری بے مقصد (اور غیر سنجیدہ) قَسموں میں تمہاری گرفت نہیں فرماتا لیکن تمہاری ان (سنجیدہ) قَسموں پر گرفت فرماتا ہے جنہیں تم (ارادی طور پر) مضبوط کرلو، (اگر تم ایسی قَسم کو توڑ ڈالو) تو اس کا کفّارہ دس مسکینوں کو اوسط (درجہ کا) کھانا کھلانا ہے جو تم اپنے گھر والوں کو کھلاتے ہو یا (اسی طرح) ان (مسکینوں) کو کپڑے دینا ہے یا ایک گردن (یعنی غلام یا باندی کو) آزاد کرنا ہے، پھر جسے (یہ سب کچھ) میسر نہ ہو تو تین دن روزہ رکھنا ہے۔ یہ تمہاری قَسموں کا کفّارہ ہے جب تم کھالو (اور پھر توڑ بیٹھو)، اور اپنی قَسموں کی حفاظت کیا کرو، اسی طرح اللہ تمہارے لئے اپنی آیتیں خوب واضح فرماتا ہے تاکہ تم (اس کے احکام کی اطاعت کر کے) شکر گزار بن جاؤ،\qt@no{89}}%
\qt@newcmd\qurantrans@ur@dcclix{اے ایمان والو! بیشک شراب اور جُوا اور (عبادت کے لئے) نصب کئے گئے بُت اور (قسمت معلوم کرنے کے لئے) فال کے تیر (سب) ناپاک شیطانی کام ہیں۔ سو تم ان سے (کلیتاً) پرہیز کرو تاکہ تم فلاح پا جاؤ،\qt@no{90}}%
\qt@newcmd\qurantrans@ur@dcclx{شیطان یہی چاہتا ہے کہ شراب اور جوئے کے ذریعے تمہارے درمیان عداوت اور کینہ ڈلوا دے اور تمہیں اللہ کے ذکر سے اور نماز سے روک دے۔ کیا تم (ان شرانگیز باتوں سے) باز آؤ گے،\qt@no{91}}%
\qt@newcmd\qurantrans@ur@dcclxi{اور تم اللہ کی اطاعت کرو اور رسول (صلی اللہ علیہ وآلہ وسلم) کی اطاعت کرو اور (خدا اور رسول صلی اللہ علیہ وآلہ وسلم کی مخالفت سے) بچتے رہو، پھر اگر تم نے رُوگردانی کی تو جان لو کہ ہمارے رسول (صلی اللہ علیہ وآلہ وسلم) پر صرف (احکام کا) واضح طور پر پہنچا دینا ہی ہے (اور وہ یہ فریضہ ادا فرما چکے ہیں)،\qt@no{92}}%
\qt@newcmd\qurantrans@ur@dcclxii{ان لوگوں پر جو ایمان لائے اور نیک عمل کرتے رہے اس (حرام) میں کوئی گناہ نہیں جو وہ (حکمِ حرمت اترنے سے پہلے) کھا پی چکے ہیں جب کہ وہ (بقیہ معاملات میں) بچتے رہے اور (دیگر اَحکامِ اِلٰہی پر) ایمان لائے اور اَعمالِ صالحہ پر عمل پیرا رہے، پھر (اَحکامِ حرمت کے آجانے کے بعد بھی ان سب حرام اَشیاء سے پرہیز کرتے رہے اور (اُن کی حرمت پر صدقِ دل سے ایمان لائے، پھر صاحبانِ تقویٰ ہوئے اور (بالآخر) صاحبانِ اِحسان (یعنی اﷲ کے خاص محبوب و مقرب و نیکوکار بندے) بن گئے، اور اﷲ اِحسان والوں سے محبت فرماتا ہے،\qt@no{93}}%
\qt@newcmd\qurantrans@ur@dcclxiii{اے ایمان والو! اللہ کسی قدر (ایسے) شکار سے تمہیں ضرور آزمائے گا جس تک تمہارے ہاتھ اور تمہارے نیزے پہنچ سکتے ہیں تاکہ اللہ اس شخص کی پہچان کروا دے جو اس سے غائبانہ ڈرتا ہے پھر جو شخص اس کے بعد (بھی) حد سے تجاوز کر جائے تو اس کے لئے دردناک عذاب ہے،\qt@no{94}}%
\qt@newcmd\qurantrans@ur@dcclxiv{اے ایمان والو! تم احرام کی حالت میں شکار کو مت مارا کرو، اور تم میں سے جس نے (بحالتِ احرام) قصداً اسے مار ڈالا تو (اس کا) بدلہ مویشیوں میں سے اسی کے برابر (کوئی جانور) ہے جسے اس نے قتل کیا ہے جس کی نسبت تم میں سے دو عادل شخص فیصلہ کریں (کہ واقعی یہ جانور اس شکار کے برابر ہے بشرطیکہ) وہ قربانی کعبہ پہنچنے والی ہو یا (اس کا) کفّارہ چند محتاجوں کا کھانا ہے (یعنی جانور کی قیمت کے برابر معمول کا کھانا جتنے بھی محتاجوں کو پورا آجائے) یا اس کے برابر (یعنی جتنے محتاجوں کا کھانا بنے اس قدر) روزے ہیں تاکہ وہ اپنے کیے (کے بوجھ) کا مزہ چکھے۔ جو کچھ (اس سے) پہلے ہو گزرا اللہ نے اسے معاف فرما دیا، اور جو کوئی (ایسا کام) دوبارہ کرے گا تو اللہ اس سے (نافرمانی) کا بدلہ لے لے گا، اور اللہ بڑا غالب بدلہ لینے والا ہے،\qt@no{95}}%
\qt@newcmd\qurantrans@ur@dcclxv{تمہارے لئے دریا کا شکار اور اس کا کھانا تمہارے اور مسافروں کے فائدے کی خاطر حلال کر دیا گیا ہے، اور خشکی کا شکار تم پر حرام کیا گیا ہے جب تک کہ تم حالتِ احرام میں ہو، اور اللہ سے ڈرتے رہو جس کی (بارگاہ کی) طرف تم (سب) جمع کئے جاؤ گے،\qt@no{96}}%
\qt@newcmd\qurantrans@ur@dcclxvi{اللہ نے عزت (و ادب) والے گھر کعبہ کو لوگوں کے (دینی و دنیوی امور میں) قیام (امن) کا باعث بنا دیا ہے اور حرمت والے مہینے کو اور کعبہ کی قربانی کو اور گلے میں علامتی پٹے والے جانوروں کو بھی (جو حرمِ مکہ میں لائے گئے ہوں سب کو اسی نسبت سے عزت و احترام عطا کر دیا گیا ہے)، یہ اس لئے کہ تمہیں علم ہو جائے کہ جو کچھ آسمانوں میں ہے اور جو کچھ زمین میں ہے اللہ خوب جانتا ہے اور اللہ ہر چیز سے بہت واقف ہے،\qt@no{97}}%
\qt@newcmd\qurantrans@ur@dcclxvii{جان لو کہ اللہ سخت گرفت والا ہے اور یہ کہ اللہ بڑا بخشنے والا بہت رحم فرمانے والا (بھی) ہے،\qt@no{98}}%
\qt@newcmd\qurantrans@ur@dcclxviii{رسول (صلی اللہ علیہ وآلہ وسلم) پر (احکام کاملاً) پہنچا دینے کے سوا (کوئی اور ذمہ داری) نہیں، اور اللہ وہ (سب) کچھ جانتا ہے جو تم ظاہر کرتے ہو اور جو تم چھپاتے ہو،\qt@no{99}}%
\qt@newcmd\qurantrans@ur@dcclxix{فرما دیجئے: پاک اور ناپاک (دونوں) برابر نہیں ہو سکتے (اے مخاطب!) اگرچہ تمہیں ناپاک (چیزوں) کی کثرت بھلی لگے۔ پس اے عقلمند لوگو! تم (کثرت و قلت کا فرق دیکھنے کی بجائے) اللہ سے ڈرا کرو تاکہ تم فلاح پا جاؤ،\qt@no{100}}%
\qt@newcmd\qurantrans@ur@dcclxx{اے ایمان والو! تم ایسی چیزوں کی نسبت سوال مت کیا کرو (جن پر قرآن خاموش ہو) کہ اگر وہ تمہارے لئے ظاہر کر دی جائیں تو تمہیں مشقت میں ڈال دیں (اور تمہیں بری لگیں)، اور اگر تم ان کے بارے میں اس وقت سوال کرو گے جبکہ قرآن نازل کیا جا رہا ہے تو وہ تم پر (نزولِ حکم کے ذریعے ظاہر (یعنی متعیّن) کر دی جائیں گی (جس سے تمہاری صواب دید ختم ہو جائے گی اور تم ایک ہی حکم کے پابند ہو جاؤ گے)۔ اللہ نے ان (باتوں اور سوالوں) سے (اب تک) درگزر فرمایا ہے، اور اللہ بڑا بخشنے والا بردبار ہے،\qt@no{101}}%
\qt@newcmd\qurantrans@ur@dcclxxi{بیشک تم سے پہلے ایک قوم نے ایسی (ہی) باتیں پوچھی تھیں، (جب وہ بیان کر دی گئیں) پھر وہ ان کے منکر ہوگئے،\qt@no{102}}%
\qt@newcmd\qurantrans@ur@dcclxxii{اللہ نے نہ تو بحیرہ کو (اَمرِ شرعی) مقرر کیا ہے اور نہ سائبہ کو اور نہ وصیلہ کو اور نہ حام کو، لیکن کافر لوگ اللہ پر جھوٹا بہتان باندھتے ہیں، اور ان میں سے اکثر عقل نہیں رکھتے،\qt@no{103}}%
\qt@newcmd\qurantrans@ur@dcclxxiii{اور جب ان سے کہا جاتا ہے کہ اس (قرآن) کی طرف جسے اللہ نے نازل فرمایا ہے اور رسولِ (مکرّم صلی اللہ علیہ وآلہ وسلم) کی طرف رجوع کرو تو کہتے ہیں: ہمیں وہی (طریقہ) کافی ہے جس پر ہم نے اپنے باپ دادا کو پایا۔ اگرچہ ان کے باپ دادا نہ کچھ (دین کا) علم رکھتے ہوں اور نہ ہی ہدایت یافتہ ہوں،\qt@no{104}}%
\qt@newcmd\qurantrans@ur@dcclxxiv{اے ایمان والو! تم اپنی جانوں کی فکر کرو، تمہیں کوئی گمراہ نقصان نہیں پہنچا سکتا اگر تم ہدایت یافتہ ہو چکے ہو، تم سب کو اللہ ہی کی طرف پلٹنا ہے، پھر وہ تمہیں ان کاموں سے خبردار فرما دے گا جو تم کرتے رہے تھے،\qt@no{105}}%
\qt@newcmd\qurantrans@ur@dcclxxv{اے ایمان والو! جب تم میں سے کسی کی موت آئے تو وصیت کرتے وقت تمہارے درمیان گواہی (کے لئے) تم میں سے دو عادل شخص ہوں یا تمہارے غیروں میں سے (کوئی) دوسرے دو شخص ہوں اگر تم ملک میں سفر کر رہے ہو پھر (اسی حال میں) تمہیں موت کی مصیبت آپہنچے تو تم ان دونوں کو نماز کے بعد روک لو، اگر تمہیں (ان پر) شک گزرے تو وہ دونوں اللہ کی قَسمیں کھائیں کہ ہم اس کے عوض کوئی قیمت حاصل نہیں کریں گے خواہ کوئی (کتنا ہی) قرابت دار ہو اور نہ ہم اللہ کی (مقرر کردہ) گواہی کو چھپائیں گے (اگر چھپائیں تو) ہم اسی وقت گناہگاروں میں ہو جائیں گے،\qt@no{106}}%
\qt@newcmd\qurantrans@ur@dcclxxvi{پھر اگر اس (بات) کی اطلاع ہو جائے کہ وہ دونوں (صحیح گواہی چھپانے کے باعث) گناہ کے سزاوار ہو گئے ہیں تو ان کی جگہ دو اور (گواہ) ان لوگوں میں سے کھڑے ہو جائیں جن کا حق پہلے دو (گواہوں) نے دبایا ہے (وہ میت کے زیادہ قرابت دار ہوں) پھر وہ اللہ کی قَسم کھائیں کہ بیشک ہماری گواہی ان دونوں کی گواہی سے زیادہ سچی ہے اور ہم (حق سے) تجاوز نہیں کر رہے، (اگر ایسا کریں تو) ہم اسی وقت ظالموں میں سے ہو جائیں گے،\qt@no{107}}%
\qt@newcmd\qurantrans@ur@dcclxxvii{یہ (طریقہ) اس بات سے قریب تر ہے کہ لوگ صحیح طور پر گواہی ادا کریں یا اس بات سے خوفزدہ ہوں کہ (غلط گواہی کی صورت میں) ان کی قََسموں کے بعد (وہی) قَسمیں (زیادہ قریبی ورثاء کی طرف) لوٹائی جائیں گی، اور اللہ سے ڈرتے رہو اور (اس کے احکام کو غور سے) سنا کرو، اور اللہ نافرمان قوم کو ہدایت نہیں دیتا،\qt@no{108}}%
\qt@newcmd\qurantrans@ur@dcclxxviii{اس دن سے ڈرو) جس دن اللہ تمام رسولوں کوجمع فرمائے گا پھر (ان سے) فرمائے گا کہ تمہیں (تمہاری امتوں کی طرف سے دعوتِ دین کا) کیا جواب دیا گیا تھا؟ وہ (حضورِ الٰہی میں) عرض کریں گے: ہمیں کچھ علم نہیں، بیشک تو ہی غیب کی سب باتوں کا خوب جاننے والا ہے،\qt@no{109}}%
\qt@newcmd\qurantrans@ur@dcclxxix{جب اللہ فرمائے گا: اے عیسٰی ابن مریم! تم اپنے اوپر اور اپنی والدہ پر میرا احسان یاد کرو جب میں نے پاک روح (جبرائیل) کے ذریعے تمہیں تقویت بخشی، تم گہوارے میں (بعہدِ طفولیت) اور پختہ عمری میں (بعہدِ تبلیغ و رسالت یکساں انداز سے) لوگوں سے گفتگو کرتے تھے، اور جب میں نے تمہیں کتاب اور حکمت (و دانائی) اور تورات اور انجیل سکھائی، اور جب تم میرے حکم سے مٹی کے گارے سے پرندے کی شکل کی مانند (مورتی) بناتے تھے پھر تم اس میں پھونک مارتے تھے تو وہ (مورتی) میرے حکم سے پرندہ بن جاتی تھی، اور جب تم مادر زاد اندھوں اور کوڑھیوں (یعنی برص زدہ مریضوں) کو میرے حکم سے اچھا کر دیتے تھے، اور جب تم میرے حکم سے مُردوں کو (زندہ کر کے قبر سے) نکال (کھڑا کر) دیتے تھے، اور جب میں نے بنی اسرائیل کو تمہارے (قتل) سے روک دیا تھا جب کہ تم ان کے پاس واضح نشانیاں لے کر آئے تو ان میں سے کافروں نے (یہ) کہہ دیا کہ یہ تو کھلے جادو کے سوا کچھ نہیں،\qt@no{110}}%
\qt@newcmd\qurantrans@ur@dcclxxx{اور جب میں نے حواریوں کے دل میں (یہ) ڈال دیا کہ تم مجھ پر اور میرے پیغمبر (عیسٰی علیہ السلام) پر ایمان لاؤ، (تو) انہوں نے کہا: ہم ایمان لے آئے اور تو گواہ ہو جا کہ ہم یقیناً مسلمان ہیں،\qt@no{111}}%
\qt@newcmd\qurantrans@ur@dcclxxxi{اور (یہ بھی یاد کرو) جب حواریوں نے کہا: اے عیسٰی ابن مریم! کیا تمہارا رب ایسا کر سکتا ہے کہ ہم پر آسمان سے (کھانے کا) خوان اتار دے، (تو) عیسٰی (علیہ السلام) نے (جواباً) کہا: (لوگو!) اللہ سے ڈرو اگر تم صاحبِ ایمان ہو،\qt@no{112}}%
\qt@newcmd\qurantrans@ur@dcclxxxii{وہ کہنے لگے: ہم (تو صرف) یہ چاہتے ہیں کہ اس میں سے کھائیں اور ہمارے دل مطمئن ہو جائیں اور ہم (مزید یقین سے) جان لیں کہ آپ نے ہم سے سچ کہا ہے اور ہم اس (خوانِ نعمت کے اترنے) پر گواہ ہو جائیں،\qt@no{113}}%
\qt@newcmd\qurantrans@ur@dcclxxxiii{عیسٰی ابن مریم (علیہ السلام) نے عرض کیا: اے اﷲ! اے ہمارے رب! ہم پر آسمان سے خوانِ (نعمت) نازل فرما دے کہ (اس کے اترنے کا دن) ہمارے لئے عید ہوجائے ہمار ے اگلوں کے لئے (بھی) اور ہمارے پچھلوں کے لئے (بھی) اور (وہ خوان) تیری طرف سے نشانی ہو، اور ہمیں رزق عطا کر اور تو سب سے بہتر رزق دینے والا ہے،\qt@no{114}}%
\qt@newcmd\qurantrans@ur@dcclxxxiv{اﷲ نے فرمایا: بیشک میں اسے تم پر نازل فرماتا ہوں، پھر تم میں سے جو شخص (اس کے) بعد کفر کرے گا تو یقیناً میں اسے ایسا عذاب دوں گا کہ تمام جہان والوں میں سے کسی کو بھی ایسا عذاب نہ دوں گا،\qt@no{115}}%
\qt@newcmd\qurantrans@ur@dcclxxxv{اور جب اﷲ فرمائے گا: اے عیسٰی ابن مریم! کیا تم نے لوگوں سے کہا تھا کہ تم مجھ کو اور میری ماں کو اﷲ کے سوا دو معبود بنا لو، وہ عرض کریں گے: تو پاک ہے، میرے لئے یہ (روا) نہیں کہ میں ایسی بات کہوں جس کا مجھے کوئی حق نہیں۔ اگر میں نے یہ بات کہی ہوتی تو یقیناً تو اسے جانتا، تو ہر اس (بات) کو جانتا ہے جو میرے دل میں ہے اور میں ان (باتوں) کو نہیں جانتا جو تیرے علم میں ہیں۔ بیشک تو ہی غیب کی سب باتوں کو خوب جاننے والا ہے،\qt@no{116}}%
\qt@newcmd\qurantrans@ur@dcclxxxvi{میں نے انہیں سوائے اس (بات) کے کچھ نہیں کہا تھا جس کا تو نے مجھے حکم دیا تھا کہ تم (صرف) اﷲ کی عبادت کیا کرو جو میرا (بھی) رب ہے اور تمہارا(بھی) رب ہے، اور میں ان (کے عقائد و اعمال) پر (اس وقت تک) خبردار رہا جب تک میں ان لوگوں میں موجود رہا، پھر جب تو نے مجھے اٹھا لیا تو تو ہی ان (کے حالات) پر نگہبان تھا، اور تو ہر چیز پر گواہ ہے،\qt@no{117}}%
\qt@newcmd\qurantrans@ur@dcclxxxvii{اگر توانہیں عذاب دے تو وہ تیرے (ہی) بندے ہیں اور اگر تو انہیں بخش دے تو بیشک تو ہی بڑا غالب حکمت والا ہے،\qt@no{118}}%
\qt@newcmd\qurantrans@ur@dcclxxxviii{اللہ فرمائے گا: یہ ایسا دن ہے (جس میں) سچے لوگوں کو ان کا سچ فائدہ دے گا، ان کے لئے جنتیں ہیں جن کے نیچے نہریں جاری ہیں، وہ ان میں ہمیشہ ہمیشہ رہنے والے ہیں۔ اﷲ ان سے راضی ہوگیا اور وہ اس سے راضی ہوگئے، یہی (رضائے الٰہی) سب سے بڑی کامیابی ہے،\qt@no{119}}%
\qt@newcmd\qurantrans@ur@dcclxxxix{تمام آسمانوں اور زمین کی اور جو کچھ ان میں ہے (سب کی) بادشاہی اﷲ ہی کے لئے ہے، اور وہ ہر چیز پر بڑا قادر ہے،\qt@no{120}}%
\qt@newcmd\qurantrans@ur@dccxc{\basmalahur تمام تعریفیں اﷲ ہی کے لئے ہیں جس نے آسمانوں اور زمین کو پیدا فرمایا اور تاریکیوں اور روشنی کو بنایا، پھر بھی کافر لوگ (معبودانِ باطلہ کو) اپنے رب کے برابر ٹھہراتے ہیں،\qt@no{1}}%
\qt@newcmd\qurantrans@ur@dccxci{اﷲ) وہی ہے جس نے تمہیں مٹی کے گارے سے پیدا فرمایا (یعنی کرّۂ اَرضی پر حیاتِ انسانی کی کیمیائی ابتداء اس سے کی)۔ پھر اس نے (تمہاری موت کی) میعاد مقرر فرما دی، اور (انعقادِ قیامت کا) معیّنہ وقت اسی کے پاس (مقرر) ہے پھر (بھی) تم شک کرتے ہو،\qt@no{2}}%
\qt@newcmd\qurantrans@ur@dccxcii{اور آسمانوں میں اور زمین میں وہی اﷲ ہی (معبودِ برحق) ہے، جو تمہاری پوشیدہ اور تمہاری ظاہر(سب باتوں) کو جانتا ہے اور جو کچھ تم کما رہے ہو وہ (اسے بھی) جانتا ہے،\qt@no{3}}%
\qt@newcmd\qurantrans@ur@dccxciii{اور ان کے رب کی نشانیوں میں سے ان کے پاس کوئی نشانی نہیں آتی مگر (یہ کہ) وہ اس سے روگردانی کرتے ہیں،\qt@no{4}}%
\qt@newcmd\qurantrans@ur@dccxciv{پھر بیشک انہوں نے (اسی طرح) حق (یعنی قرآن) کو (بھی) جھٹلا دیا جب وہ ان کے پاس (اُلوہی نشانی کے طور پر) آیا، پس عنقریب ان کے پاس اس کی خبریں آیا چاہتی ہیں جس کا وہ مذاق اڑاتے تھے،\qt@no{5}}%
\qt@newcmd\qurantrans@ur@dccxcv{کیا انہوں نے نہیں دیکھا کہ ہم نے ان سے پہلے کتنی ہی قوموں کو ہلاک کردیا جنہیں ہم نے زمین میں (ایسا مستحکم) اقتدار دیا تھا کہ ایسا اقتدار (اور جماؤ) تمہیں بھی نہیں دیا اور ہم نے ان پر لگا تار برسنے والی بارش بھیجی اور ہم نے ان (کے مکانات و محلّات) کے نیچے سے نہریں بہائیں پھر (اتنی پُرعشرت زندگی دینے کے باوجود) ہم نے ان کے گناہوں کے باعث انہیں ہلاک کردیا اور ان کے بعد ہم نے دوسری اُمتوں کو پیدا کیا،\qt@no{6}}%
\qt@newcmd\qurantrans@ur@dccxcvi{اور ہم اگر آپ پر کاغذ پہ لکھی ہوئی کتاب نازل فرما دیتے پھر یہ لوگ اسے اپنے ہاتھوں سے چھو بھی لیتے تب (بھی) کافر لوگ (یہی) کہتے کہ یہ صریح جادو کے سوا (کچھ) نہیں،\qt@no{7}}%
\qt@newcmd\qurantrans@ur@dccxcvii{اور وہ (کفّار) کہتے ہیں کہ اس (رسولِ مکرّم) پر کوئی فرشتہ کیوں نہ اتارا گیا (جسے ہم ظاہراً دیکھ سکتے اور وہ ان کی تصدیق کردیتا)، اور ہم اگر فرشتہ اتار دیتے تو (ان کا) کام ہی تمام ہوچکا ہوتا پھر انہیں (ذرا بھی) مہلت نہ دی جاتی،\qt@no{8}}%
\qt@newcmd\qurantrans@ur@dccxcviii{اور اگر ہم رسول کو فرشتہ بناتے تو اسے بھی آدمی ہی (کی صورت) بناتے اور ہم ان پر(تب بھی) وہی شبہ وارد کردیتے جو شبہ (و التباس) وہ (اب) کر رہے ہیں (یعنی اس کی بھی ظاہری صورت دیکھ کر کہتے کہ یہ ہماری مثل بشر ہے)،\qt@no{9}}%
\qt@newcmd\qurantrans@ur@dccxcix{اور بیشک آپ سے پہلے (بھی) رسولوں کے ساتھ مذاق کیا جاتا رہا، پھر ان میں سے مسخرہ پن کرنے والوں کو(حق کے) اسی (عذاب) نے آگھیرا جس کا وہ مذاق اڑاتے تھے،\qt@no{10}}%
\qt@newcmd\qurantrans@ur@dccc{فرمادیجئے کہ تم زمین پر چلو پھرو، پھر (نگاہِ عبرت سے) دیکھو کہ (حق کو) جھٹلانے والوں کا انجام کیسا ہوا،\qt@no{11}}%
\qt@newcmd\qurantrans@ur@dccci{آپ (ان سے سوال) فرمائیں کہ آسمانوں اور زمین میں جو کچھ ہے کس کا ہے؟ (پھر یہ بھی) فرما دیں کہ اﷲ ہی کا ہے، اس نے اپنی ذات پر رحمت لازم فرمالی ہے، وہ تمہیں روزِ قیامت جس میں کوئی شک نہیں ضرور جمع فرمائے گا، جنہوں نے اپنی جانوں کو (دائمی) خسارے میں ڈال دیا ہے سو وہ ایمان نہیں لائیں گے،\qt@no{12}}%
\qt@newcmd\qurantrans@ur@dcccii{اور وہ (ساری مخلوق) جو رات میں اور دن میں آرام کرتی ہے، اسی کی ہے، اور وہ خوب سننے والا جاننے والا ہے،\qt@no{13}}%
\qt@newcmd\qurantrans@ur@dccciii{فرما دیجئے: کیا میں کسی دوسرے کو (عبادت کے لئے اپنا) دوست بنا لوں (اس) اﷲ کے سوا جو آسمانوں اور زمین کا پیدا کرنے والا ہے اور وہ (سب کو) کھلاتا ہے اور (خود اسے) کھلایا نہیں جاتا۔ فرما دیں: مجھے حکم دیا گیا ہے کہ میں (اس کے حضور) سب سے پہلا (سرجھکانے والا) مسلمان ہوجاؤں اور (یہ بھی فرمادیا گیا ہے کہ) تم مشرکوں میں سے ہرگز نہ ہوجانا،\qt@no{14}}%
\qt@newcmd\qurantrans@ur@dccciv{فرما دیجئے کہ بیشک میں (تو) بڑے عذاب کے دن سے ڈرتا ہوں، اگر میں اپنے رب کی نافرمانی کروں (سو یہ کیسے ممکن ہے؟)،\qt@no{15}}%
\qt@newcmd\qurantrans@ur@dcccv{اس دن جس شخص سے وہ (عذاب) پھیر دیا گیا تو بیشک (اﷲ نے) اس پر رحم فرمایا، اور یہی (اُخروی بخشش) کھلی کامیابی ہے،\qt@no{16}}%
\qt@newcmd\qurantrans@ur@dcccvi{اور اگر اﷲ تجھے کوئی تکلیف پہنچائے تو اس کے سوا اسے کوئی دور کرنے والا نہیں، اور اگر وہ تجھے کوئی بھلائی پہنچائے تو وہ ہر چیز پر خوب قادر ہے،\qt@no{17}}%
\qt@newcmd\qurantrans@ur@dcccvii{اور وہی اپنے بندوں پر غالب ہے، اور وہ بڑی حکمت والا خبردار ہے،\qt@no{18}}%
\qt@newcmd\qurantrans@ur@dcccviii{آپ (ان سے دریافت) فرمائیے کہ گواہی دینے میں سب سے بڑھ کر کون ہے؟ آپ (ہی) فرما دیجئے کہ اﷲ میرے اور تمہارے درمیان گواہ ہے، اور میری طرف یہ قرآن اس لئے وحی کیا گیا ہے کہ اس کے ذریعے تمہیں اور ہر اس شخص کو جس تک (یہ قرآن) پہنچے ڈر سناؤں۔ کیا تم واقعی اس بات کی گواہی دیتے ہو کہ اﷲ کے ساتھ دوسرے معبود (بھی) ہیں؟ آپ فرما دیں: میں (تو اس غلط بات کی) گواہی نہیں دیتا، فرما دیجئے: بس معبود تو وہی ایک ہی ہے اور میں ان(سب) چیزوں سے بیزار ہوں جنہیں تم (اﷲ کا) شریک ٹھہراتے ہو،\qt@no{19}}%
\qt@newcmd\qurantrans@ur@dcccix{وہ لوگ جنہیں ہم نے کتاب دی تھی اس (نبئ آخر الزماں صلی اللہ علیہ وآلہ وسلم) کو ویسے ہی پہچانتے ہیں جیسے اپنے بیٹوں کو پہچانتے ہیں، جنہوں نے اپنی جانوں کو (دائمی) خسارے میں ڈال دیا ہے سو وہ ایمان نہیں لائیں گے،\qt@no{20}}%
\qt@newcmd\qurantrans@ur@dcccx{اور اس سے بڑا ظالم کون ہوسکتا ہے جس نے اﷲ پر جھوٹا بہتان باندھا یا اس نے اس کی آیتوں کو جھٹلایا؟ بیشک ظالم لوگ فلاح نہیں پائیں گے،\qt@no{21}}%
\qt@newcmd\qurantrans@ur@dcccxi{اور جس دن ہم سب کو جمع کریں گے پھر ہم ان لوگوں سے کہیں گے جو شرک کرتے تھے: تمہارے وہ شریک کہاں ہیں جنہیں تم (معبود) خیال کرتے تھے،\qt@no{22}}%
\qt@newcmd\qurantrans@ur@dcccxii{پھر ان کی (کوئی) معذرت نہ رہے گی بجز اس کے کہ وہ کہیں (گے): ہمیں اپنے رب اﷲ کی قَسم ہے! ہم مشرک نہ تھے،\qt@no{23}}%
\qt@newcmd\qurantrans@ur@dcccxiii{دیکھئے انہوں نے خود اپنے اوپر کیسا جھوٹ بولا اور جو بہتان وہ (دنیا میں) تراشا کرتے تھے وہ ان سے غائب ہوگیا،\qt@no{24}}%
\qt@newcmd\qurantrans@ur@dcccxiv{اور ان میں کچھ وہ (بھی) ہیں جو آپ کی طرف کان لگائے رہتے ہیں اور ہم نے ان کے دلوں پر(ان کی اپنی بدنیتی کے باعث) پردے ڈال دیئے ہیں (سو اب ان کے لئے ممکن نہیں) کہ وہ اس (قرآن) کو سمجھ سکیں اور (ہم نے) ان کے کانوں میں ڈاٹ دے دی ہے، اور اگر وہ تمام نشانیوں کو (کھلا بھی) دیکھ لیں تو (بھی) اس پر ایمان نہیں لائیں گے۔ حتیٰ کہ جب آپ کے پاس آتے ہیں، آپ سے جھگڑا کرتے ہیں (اس وقت) کافر لوگ کہتے ہیں کہ یہ (قرآن) پہلے لوگوں کی جھوٹی کہانیوں کے سوا (کچھ) نہیں،\qt@no{25}}%
\qt@newcmd\qurantrans@ur@dcccxv{اور وہ (دوسروں کو) اس (نبی کی اتباع اور قرآن) سے روکتے ہیں اور (خود بھی) اس سے دور بھاگتے ہیں، اور وہ محض اپنی ہی جانوں کو ہلاک کررہے ہیں اور وہ (اس ہلاکت کا) شعور (بھی) نہیں رکھتے،\qt@no{26}}%
\qt@newcmd\qurantrans@ur@dcccxvi{اگر آپ (انہیں اس وقت) دیکھیں جب وہ آگ (کے کنارے) پر کھڑے کئے جائیں گے تو کہیں گے: اے کاش! ہم (دنیا میں) پلٹا دیئے جائیں تو (اب) ہم اپنے رب کی آیتوں کو (کبھی) نہیں جھٹلائیں گے اور ایمان والوں میں سے ہو جائیں گے،\qt@no{27}}%
\qt@newcmd\qurantrans@ur@dcccxvii{اس اقرار میں کوئی سچائی نہیں) بلکہ ان پر وہ (سب کچھ) ظاہر ہوگیا ہے جو وہ پہلے چھپایا کرتے تھے، اور اگر وہ (دنیا میں) لوٹا (بھی) دیئے جائیں تو (پھر) وہی دہرائیں گے جس سے وہ روکے گئے تھے اور بیشک وہ (پکے) جھوٹے ہیں،\qt@no{28}}%
\qt@newcmd\qurantrans@ur@dcccxviii{اور وہ (یہی) کہتے رہیں گے (جیسے انہوں نے پہلے کہا تھا) کہ ہماری اس دنیوی زندگی کے سوا (اور) کوئی (زندگی) نہیں اور ہم (مرنے کے بعد) نہیں اٹھائے جائیں گے،\qt@no{29}}%
\qt@newcmd\qurantrans@ur@dcccxix{اور اگر آپ (انہیں اس وقت) دیکھیں جب وہ اپنے رب کے حضور کھڑے کئے جائیں گے، (اور انہیں) اﷲ فرمائے گا: کیا یہ (زندگی) حق نہیں ہے؟ (تو) کہیں گے: کیوں نہیں! ہمارے رب کی قسم (یہ حق ہے، پھر) اﷲ فرمائے گا: پس (اب) تم عذاب کا مزہ چکھو اس وجہ سے کہ تم کفر کیا کرتے تھے،\qt@no{30}}%
\qt@newcmd\qurantrans@ur@dcccxx{پس ایسے لوگ نقصان میں رہے جنہوں نے اﷲ کی ملاقات کو جھٹلا دیا یہاں تک کہ جب ان کے پاس اچانک قیامت آپہنچے گی (تو) کہیں گے: ہائے افسوس! ہم پر جو ہم نے اس (قیامت پر ایمان لانے) کے بارے میں (تقصیر) کی، اور وہ اپنی پیٹھوں پر اپنے (گناہوں کے) بوجھ لادے ہوئے ہوں گے، سن لو! وہ بہت برا بوجھ ہے جو یہ اٹھا رہے ہیں،\qt@no{31}}%
\qt@newcmd\qurantrans@ur@dcccxxi{اور دنیوی زندگی (کی عیش و عشرت) کھیل اور تماشے کے سوا کچھ نہیں، اور یقیناً آخرت کا گھر ہی ان لوگوں کے لئے بہتر ہے جو تقویٰ اختیار کرتے ہیں، کیا تم (یہ حقیقت) نہیں سمجھتے،\qt@no{32}}%
\qt@newcmd\qurantrans@ur@dcccxxii{اے حبیب!) بیشک ہم جانتے ہیں کہ وہ (بات) یقیناً آپ کو رنجیدہ کررہی ہے کہ جو یہ لوگ کہتے ہیں، پس یہ آپ کو نہیں جھٹلا رہے لیکن (حقیقت یہ ہے کہ) ظالم لوگ اﷲ کی آیتوں سے ہی انکار کررہے ہیں،\qt@no{33}}%
\qt@newcmd\qurantrans@ur@dcccxxiii{اور بیشک آپ سے قبل (بھی بہت سے) رسول جھٹلائے گئے مگر انہوں نے جھٹلائے جانے اور اذیت پہنچائے جانے پر صبر کیا حتٰی کہ انہیں ہماری مدد آپہنچی، اور اﷲ کی باتوں (یعنی وعدوں کو) کوئی بدلنے والا نہیں، اور بیشک آپ کے پاس (تسکینِ قلب کے لیے) رسولوں کی خبریں آچکی ہیں،\qt@no{34}}%
\qt@newcmd\qurantrans@ur@dcccxxiv{اور اگر آپ پر ان کی رُوگردانی شاق گزر رہی ہے (اور آپ بہر صورت ان کے ایمان لانے کے خواہش مند ہیں) تو اگر آپ سے (یہ) ہو سکے کہ زمین میں (اترنے والی) کوئی سرنگ یا آسمان میں (چڑھنے والی) کوئی سیڑھی تلاش کرلیں پھر (انہیں دکھانے کے لیے) ان کے پاس کوئی (خاص) نشانی لے آئیں (وہ تب بھی ایمان نہیں لائیں گے)، اور اگر اﷲ چاہتا تو ان کو ہدایت پر ضرور جمع فرما دیتا پس آپ (اپنی رحمت و شفقت کے بے پایاں جوش کے باعث ان کی بدبختی سے) بے خبر نہ ہوجائیں،\qt@no{35}}%
\qt@newcmd\qurantrans@ur@dcccxxv{بات یہ ہے کہ (دعوتِ حق) صرف وہی لوگ قبول کرتے ہیں جو (اسے سچے دل سے) سنتے ہیں، اور مُردوں (یعنی حق کے منکروں) کو اﷲ (حالتِ کفر میں ہی قبروں سے) اٹھائے گا پھر وہ اسی (رب) کی طرف (جس کا انکار کرتے تھے) لوٹائے جائیں گے،\qt@no{36}}%
\qt@newcmd\qurantrans@ur@dcccxxvi{اور انہوں نے کہا کہ اس (رسول صلی اللہ علیہ وآلہ وسلم) پراس کے رب کی طرف سے (ہروقت ساتھ رہنے والی) کوئی نشانی کیوں نہیں اتاری گئی؟ فرما دیجئے: بیشک اﷲ اس بات پر (بھی) قادر ہے کہ وہ (ایسی) کوئی نشانی اتار دے لیکن ان میں سے اکثر لوگ (اس کی حکمتوں کو) نہیں جانتے،\qt@no{37}}%
\qt@newcmd\qurantrans@ur@dcccxxvii{اور (اے انسانو!) کوئی بھی چلنے پھرنے والا (جانور) اور پرندہ جو اپنے دو بازوؤں سے اڑتا ہو (ایسا) نہیں ہے مگر یہ کہ (بہت سی صفات میں) وہ سب تمہارے ہی مماثل طبقات ہیں، ٭ ہم نے کتاب میں کوئی چیز نہیں چھوڑی (جسے صراحۃً یا اشارۃً بیان نہ کردیا ہو) پھر سب (لوگ) اپنے رب کے پاس جمع کئے جائیں گے، ٭ انہی مماثلتوں کے باعث انسانی ارتقاء کے باب میں ڈاروِن اور اس کے ہم نوا سائنس دانوں کو یہ مغالطہ لاحق ہوا ہے کہ شاید انسان انہی جانوروں کی ایک ارتقائی شکل ہے۔ ”أُمَمٌ أَمثَالُکُمۡ“ کے الفاط نے واضح کر دیا ہے کہ جانوروں، پرندوں اور انسانوں میں جسمانی، حیاتیاتی اور خصلتی مماثلتیں ضرور موجود ہیں اور یہ نظامِ تخلیق کی وحدت کی دلیل ہے مگر یہ سب الگ الگ طبقاتِ خلق ہیں۔ یہ درست ہے کہ انسانی حیات کا ظہور ارضی زندگی کے مختلف مراحل و ادوار کی تاریخ میں سب سے آخری دور میں ہوا ہے۔ یہ اس کے اکمل الخلق اور اشرف المخلوقات ہونے کی دلیل ہے۔\qt@no{38}}%
\qt@newcmd\qurantrans@ur@dcccxxviii{اور جن لوگوں نے ہماری آیتوں کو جھٹلایا وہ بہرے اور گونگے ہیں، تاریکیوں میں (بھٹک رہے) ہیں۔ اﷲ جسے چاہتا ہے اسے (انکارِ حق اور ضد کے باعث) گمراہ کردیتا ہے، اور جسے چاہتا ہے اسے (قبولِ حق کے باعث) سیدھی راہ پر لگا دیتا ہے،\qt@no{39}}%
\qt@newcmd\qurantrans@ur@dcccxxix{آپ (ان کافروں سے) فرمائیے: ذرا یہ تو بتاؤ اگر تم پر اﷲ کا عذاب آجائے یا تم پر قیامت آپہنچے تو کیا (اس وقت عذاب سے بچنے کے لیے) اﷲ کے سوا کسی اور کو پکارو گے؟ (بتاؤ) اگر تم سچے ہو،\qt@no{40}}%
\qt@newcmd\qurantrans@ur@dcccxxx{ایسا ہرگز ممکن نہیں) بلکہ تم (اب بھی) اسی (اﷲ) کو ہی پکارتے ہو پھر اگر وہ چاہے تو ان (مصیبتوں) کو دور فرما دیتا ہے جن کے لئے تم (اسے) پکارتے ہو اور (اس وقت) تم ان (بتوں) کو بھول جاتے ہو جنہیں (اﷲ کا) شریک ٹھہراتے ہو،\qt@no{41}}%
\qt@newcmd\qurantrans@ur@dcccxxxi{اور بیشک ہم نے آپ سے پہلے بہت سی اُمتوں کی طرف رسول بھیجے، پھر ہم نے ان کو (نافرمانی کے باعث) تنگ دستی اور تکلیف کے ذریعے پکڑ لیا تاکہ وہ (عجز و نیاز کے ساتھ) گِڑگڑائیں،\qt@no{42}}%
\qt@newcmd\qurantrans@ur@dcccxxxii{پھر جب ان تک ہمارا عذاب آپہنچا تو انہوں نے عاجزی و زاری کیوں نہ کی؟ لیکن (حقیقت یہ ہے کہ) ان کے دل سخت ہوگئے تھے اور شیطان نے ان کے لئے وہ (گناہ) آراستہ کر دکھائے تھے جو وہ کیا کرتے تھے،\qt@no{43}}%
\qt@newcmd\qurantrans@ur@dcccxxxiii{پھر جب انہوں نے اس نصیحت کو فراموش کردیا جو ان سے کی گئی تھی تو ہم نے (انہیں اپنے انجام تک پہنچانے کے لیے) ان پر ہر چیز (کی فراوانی) کے دروازے کھول دیئے، یہاں تک کہ جب وہ ان چیزوں (کی لذتوں اور راحتوں) سے خوب خوش ہو (کر مدہوش ہو) گئے جو انہیں دی گئی تھیں تو ہم نے اچانک انہیں (عذاب میں) پکڑ لیا تو اس وقت وہ مایوس ہوکر رہ گئے،\qt@no{44}}%
\qt@newcmd\qurantrans@ur@dcccxxxiv{پس ظلم کرنے والی قوم کی جڑ کاٹ دی گئی، اور تمام تعریفیں اﷲ ہی کے لئے ہیں جو سارے جہانوں کا پروردگار ہے،\qt@no{45}}%
\qt@newcmd\qurantrans@ur@dcccxxxv{ان سے) فرما دیجئے کہ تم یہ تو بتاؤ اگر اﷲ تمہاری سماعت اور تمہاری آنکھیں لے لے اور تمہارے دلوں پر مُہر لگا دے (تو) اﷲ کے سوا کون معبود ایسا ہے جو یہ (نعمتیں دوبارہ) تمہارے پاس لے آئے؟ دیکھئے ہم کس طرح گونا گوں آیتیں بیان کرتے ہیں پھر(بھی) وہ روگردانی کئے جاتے ہیں،\qt@no{46}}%
\qt@newcmd\qurantrans@ur@dcccxxxvi{آپ (ان سے یہ بھی) فرما دیجئے کہ تم مجھے بتاؤ اگر تم پر اﷲ کا عذاب اچانک یا کھلم کھلا آن پڑے تو کیا ظالم قوم کے سوا (کوئی اور) ہلاک کیا جائے گا،\qt@no{47}}%
\qt@newcmd\qurantrans@ur@dcccxxxvii{اور ہم پیغمبروں کو نہیں بھیجتے مگر خوشخبری سنانے والے اور ڈر سنانے والے بنا کر، سو جو شخص ایمان لے آیا اور (عملاً) درست ہوگیا تو ان پرنہ کوئی خوف ہوگا اور نہ ہی وہ غمگین ہوں گے،\qt@no{48}}%
\qt@newcmd\qurantrans@ur@dcccxxxviii{اور جن لوگوں نے ہماری آیتوں کو جھٹلایا انہیں عذاب چھو کر رہے گا، اس وجہ سے کہ وہ نافرمانی کیا کرتے تھے،\qt@no{49}}%
\qt@newcmd\qurantrans@ur@dcccxxxix{آپ (ان کافروں سے) فرما دیجئے کہ میں تم سے (یہ) نہیں کہتا کہ میرے پاس اﷲ کے خزانے ہیں اور نہ میں اَز خود غیب جانتا ہوں اور نہ میں تم سے (یہ) کہتا ہوں کہ میں فرشتہ ہوں، میں تو صرف اسی (حکم) کی پیروی کرتا ہوں جو میری طرف وحی کیا جاتاہے۔ فرما دیجئے: کیا اندھا اور بینا برابر ہوسکتے ہیں؟ سو کیا تم غور نہیں کرتے،\qt@no{50}}%
\qt@newcmd\qurantrans@ur@dcccxl{اور آپ اس (قرآن) کے ذریعے ان لوگوں کو ڈر سنائیے جو اپنے رب کے پاس اس حال میں جمع کئے جانے سے خوف زدہ ہیں کہ ان کے لئے اس کے سوا نہ کوئی مددگار ہو اور نہ (کوئی) سفارشی تاکہ وہ پرہیزگار بن جائیں،\qt@no{51}}%
\qt@newcmd\qurantrans@ur@dcccxli{اور آپ ان (شکستہ دل اور خستہ حال) لوگوں کو (اپنی صحبت و قربت سے) دور نہ کیجئے جو صبح و شام اپنے رب کو صرف اس کی رضا چاہتے ہوئے پکارتے رہتے ہیں، ان کے (عمل و جزا کے) حساب میں سے آپ پر کوئی چیز (واجب) نہیں اور نہ آپ کے حساب میں سے کوئی چیز ان پر (واجب) ہے (اگر) پھر بھی آپ انہیں (اپنے لطف و کرم سے) دور کردیں تو آپ حق تلفی کرنے والوں میں سے ہوجائیں گے (جوآپ کے شایانِ شان نہیں)،\qt@no{52}}%
\qt@newcmd\qurantrans@ur@dcccxlii{اور اسی طرح ہم ان میں سے بعض کو بعض کے ذریعے آزماتے ہیں تاکہ وہ (دولت مند کافر غریب مسلمانوں کو دیکھ کر استہزاءً یہ) کہیں: کیا ہم میں سے یہی وہ لوگ ہیں جن پر اﷲ نے احسان کیا ہے؟ کیا اﷲ شکر گزاروں کو خوب جاننے والا نہیں ہے،\qt@no{53}}%
\qt@newcmd\qurantrans@ur@dcccxliii{اور جب آپ کے پاس وہ لوگ آئیں جو ہماری آیتوں پرایمان رکھتے ہیں تو آپ (ان سے شفقتًا) فرمائیں کہ تم پر سلام ہو تمہارے رب نے اپنی ذات (کے ذمّہ کرم) پر رحمت لازم کرلی ہے، سو تم میں سے جو شخص نادانی سے کوئی برائی کر بیٹھے پھر اس کے بعد توبہ کرلے اور (اپنی) اصلاح کر لے تو بیشک وہ بڑا بخشنے والا بہت رحم فرمانے والا ہے،\qt@no{54}}%
\qt@newcmd\qurantrans@ur@dcccxliv{اور اسی طرح ہم آیتوں کو تفصیلاً بیان کرتے ہیں اور (یہ) اس لئے کہ مجرموں کا راستہ (سب پر) ظاہر ہوجائے،\qt@no{55}}%
\qt@newcmd\qurantrans@ur@dcccxlv{فرمادیجئے کہ مجھے اس بات سے روک دیا گیا ہے کہ میں ان (جھوٹے معبودوں) کی عبادت کروں جن کی تم اﷲ کے سوا پرستش کرتے ہو۔ فرما دیجئے کہ میں تمہاری خواہشات کی پیروی نہیں کرسکتا اگر ایسے ہو تو میں یقیناً بہک جاؤں اور میں ہدایت یافتہ لوگوں سے (بھی) نہ رہوں (جو کہ ناممکن ہے)،\qt@no{56}}%
\qt@newcmd\qurantrans@ur@dcccxlvi{فرما دیجئے: (کافرو!) بیشک میں اپنے رب کی طرف سے روشن دلیل پر (قائم) ہوں اور تم اسے جھٹلاتے ہو۔ میرے پاس وہ (عذاب) نہیں ہے جس کی تم جلدی مچا رہے ہو۔ حکم صرف اللہ ہی کا ہے۔ وہ حق بیان فرماتا ہے اور وہی بہتر فیصلہ فرمانے والاہے،\qt@no{57}}%
\qt@newcmd\qurantrans@ur@dcccxlvii{ان سے) فرما دیں: اگر وہ (عذاب) میرے پاس ہوتا جسے تم جلدی چاہتے ہو تو یقیناً میر ے اور تمہارے درمیان کام تمام ہوچکا ہوتا۔ اور اﷲ ظالموں کو خوب جاننے والا ہے،\qt@no{58}}%
\qt@newcmd\qurantrans@ur@dcccxlviii{اور غیب کی کُنجیاں (یعنی وہ راستے جس سے غیب کسی پر آشکار کیا جاتا ہے) اسی کے پاس (اس کی قدرت و ملکیت میں) ہیں، انہیں اس کے سوا (اَز خود) کوئی نہیں جانتا، اور وہ ہر اس چیز کو (بلاواسطہ) جانتا ہے جو خشکی میں اور دریاؤں میں ہے، اور کوئی پتّا نہیں گرتا مگر (یہ کہ) وہ اسے جانتا ہے اور نہ زمین کی تاریکیوں میں کوئی (ایسا) دانہ ہے اور نہ کوئی تر چیز ہے اور نہ کوئی خشک چیز مگر روشن کتاب میں (سب کچھ لکھ دیا گیا ہے)،\qt@no{59}}%
\qt@newcmd\qurantrans@ur@dcccxlix{اور وہی ہے جو رات کے وقت تمہاری روحیں قبض فرما لیتا ہے اور جو کچھ تم دن کے وقت کماتے ہو وہ جانتا ہے پھر وہ تمہیں دن میں اٹھا دیتا ہے تاکہ (تمہاری زندگی کی) معینّہ میعاد پوری کر دی جائے پھر تمہارا پلٹنا اسی کی طرف ہے، پھر وہ (روزِ محشر) تمہیں ان (تمام اعمال) سے آگاہ فرما دے گا جو تم (اس زندگانی میں) کرتے رہے تھے،\qt@no{60}}%
\qt@newcmd\qurantrans@ur@dcccl{اور وہی اپنے بندوں پر غالب ہے اور وہ تم پر (فرشتوں کو بطور) نگہبان بھیجتا ہے، یہاں تک کہ جب تم میں سے کسی کو موت آتی ہے (تو) ہمارے بھیجے ہوئے (فرشتے) اس کی روح قبض کرلیتے ہیں اور وہ خطا (یا کوتاہی) نہیں کرتے،\qt@no{61}}%
\qt@newcmd\qurantrans@ur@dcccli{پھر وہ (سب) اللہ کے حضور لوٹائے جائیں گے جو ان کا مالکِ حقیقی ہے، جان لو! حکم (فرمانا) اسی کا (کام) ہے، اور وہ سب سے جلد حساب کرنے والا ہے،\qt@no{62}}%
\qt@newcmd\qurantrans@ur@dccclii{آپ (ان سے دریافت) فرمائیں کہ بیابان اور دریا کی تاریکیوں سے تمہیں کون نجات دیتا ہے؟ (اس وقت تو) تم گڑگڑا کر (بھی) اور چپکے چپکے (بھی) اسی کو پکارتے ہو کہ اگر وہ ہمیں اس (مصیبت) سے نجات دے دے تو ہم ضرور شکر گزاروں میں سے ہو جائیں گے،\qt@no{63}}%
\qt@newcmd\qurantrans@ur@dcccliii{فرما دیجئے کہ اﷲ ہی تمہیں اس (مصیبت) سے اور ہر تکلیف سے نجات دیتا ہے تم پھر (بھی) شرک کرتے ہو،\qt@no{64}}%
\qt@newcmd\qurantrans@ur@dcccliv{فرما دیجئے: وہ اس پر قادر ہے کہ تم پر عذاب بھیجے (خواہ) تمہارے اوپر کی طرف سے یا تمہارے پاؤں کے نیچے سے یا تمہیں فرقہ فرقہ کر کے آپس میں بھڑائے اور تم میں سے بعض کو بعض کی لڑائی کا مزہ چکھا دے۔ دیکھئے! ہم کس کس طرح آیتیں بیان کرتے ہیں تاکہ یہ (لوگ) سمجھ سکیں،\qt@no{65}}%
\qt@newcmd\qurantrans@ur@dccclv{اور آپ کی قوم نے اس (قرآن) کو جھٹلا ڈالا حالانکہ وہ سراسر حق ہے۔ فرما دیجئے: میں تم پر نگہبان نہیں ہوں،\qt@no{66}}%
\qt@newcmd\qurantrans@ur@dccclvi{ہر خبر (کے واقع ہونے) کا وقت مقرر ہے اور تم عنقریب جان لو گے،\qt@no{67}}%
\qt@newcmd\qurantrans@ur@dccclvii{اور جب تم ایسے لوگوں کو دیکھو جو ہماری آیتوں میں (کج بحثی اور استہزاء میں) مشغول ہوں تو تم ان سے کنارہ کش ہوجایا کرو یہاں تک کہ وہ کسی دوسری بات میں مشغول ہوجائیں، اور اگر شیطان تمہیں (یہ بات) بھلا دے تو یاد آنے کے بعد تم (کبھی بھی) ظالم قوم کے ساتھ نہ بیٹھا کرو،\qt@no{68}}%
\qt@newcmd\qurantrans@ur@dccclviii{اور لوگوں پر جو پرہیزگاری اختیار کئے ہوئے ہیں ان (کافروں) کے حساب سے کچھ بھی (لازم) نہیں ہے مگر (انہیں) نصیحت (کرنا چاہیے) تاکہ وہ (کفر سے اور قرآن کی مذمت سے) بچ جائیں،\qt@no{69}}%
\qt@newcmd\qurantrans@ur@dccclix{اور آپ ان لوگوں کو چھوڑے رکھیئے جنہوں نے اپنے دین کو کھیل اور تماشا بنا لیا ہے اور جنہیں دنیا کی زندگی نے فریب دے رکھا ہے اور اس (قرآن) کے ذریعے (ان کی آگاہی کی خاطر) نصیحت فرماتے رہئے تاکہ کوئی جان اپنے کئے کے بدلے سپردِ ہلاکت نہ کر دی جائے، (پھر) اس کے لئے اﷲ کے سوا نہ کوئی مدد گار ہوگا اور نہ کوئی سفارشی، اور اگر وہ (جان اپنے گناہوں کا) پورا پورا بدلہ (یعنی معاوضہ) بھی دے تو (بھی) اس سے قبول نہیں کیا جائے گا۔ یہی وہ لوگ ہیں جو اپنے کئے کے بدلے ہلاکت میں ڈال دیئے گئے ان کے لئے کھولتے ہوئے پانی کا پینا ہے اور دردناک عذاب ہے اس وجہ سے کہ وہ کفر کیا کرتے تھے،\qt@no{70}}%
\qt@newcmd\qurantrans@ur@dccclx{فرما دیجئے: کیا ہم اﷲ کے سوا ایسی چیز کی عبادت کریں جو ہمیں نہ (تو) نفع پہنچا سکے اور نہ (ہی) ہمیں نقصان دے سکے اور اس کے بعد کہ اﷲ نے ہمیں ہدایت دے دی ہم اس شخص کی طرح اپنے الٹے پاؤں پھر جائیں جسے زمین میں شیطانوں نے راہ بھلا کر درماندہ و حیرت زدہ کر دیا ہو جس کے ساتھی اسے سیدھی راہ کی طرف بلا رہے ہوں کہ ہمارے پاس آجا (مگر اسے کچھ سوجھتا نہ ہو)، فرما دیں کہ اﷲ کی ہدایت ہی (حقیقی) ہدایت ہے، اور (اسی لیے) ہمیں (یہ) حکم دیا گیا ہے کہ ہم تمام جہانوں کے رب کی فرمانبرداری کریں،\qt@no{71}}%
\qt@newcmd\qurantrans@ur@dccclxi{اور یہ (بھی حکم ہوا ہے) کہ تم نماز قائم رکھو اور اس سے ڈرتے رہو اور وہی اﷲ ہے جس کی طرف تم (سب) جمع کئے جاؤ گے،\qt@no{72}}%
\qt@newcmd\qurantrans@ur@dccclxii{اور وہی (اﷲ) ہے جس نے آسمانوں اور زمین کو حق (پر مبنی تدبیر) کے ساتھ پیدا فرمایا ہے اور جس دن وہ فرمائے گا: ہوجا، تو وہ (روزِ محشر بپا) ہو جائے گا۔ اس کا فرمان حق ہے، اور اس دن اسی کی بادشاہی ہوگی جب (اسرافیل کے ذریعے صور میں پھونک ماری جائے گے، (وہی) ہر پوشیدہ اور ظاہر کا جاننے والا ہے، اور وہی بڑا حکمت والا خبردار ہے،\qt@no{73}}%
\qt@newcmd\qurantrans@ur@dccclxiii{اور (یاد کیجئے) جب ابراہیم (علیہ السلام) نے اپنے باپ آزر (جو حقیقت میں چچا تھا محاورۂ عرب میں اسے باپ کہا گیا ہے) سے کہا: کیا تم بتوں کو معبود بناتے ہو؟ بیشک میں تمہیں اور تمہاری قوم کو صریح گمراہی میں (مبتلا) دیکھتا ہوں،\qt@no{74}}%
\qt@newcmd\qurantrans@ur@dccclxiv{اور اسی طرح ہم نے ابراہیم (علیہ السلام) کو آسمانوں اور زمین کی تمام بادشاہتیں (یعنی عجائباتِ خلق) دکھائیں اور (یہ) اس لئے کہ وہ عین الیقین والوں میں ہوجائے،\qt@no{75}}%
\qt@newcmd\qurantrans@ur@dccclxv{پھر جب ان پر رات نے اندھیرا کر دیا تو انہوں نے (ایک) ستارہ دیکھا (تو) کہا: (کیا تمہارے خیال میں) یہ میرا رب ہے؟ پھر جب وہ ڈوب گیا تو (اپنی قوم کو سنا کر) کہنے لگے: میں ڈوب جانے والوں کو پسند نہیں کرتا،\qt@no{76}}%
\qt@newcmd\qurantrans@ur@dccclxvi{پھر جب چاند کو چمکتے دیکھا (تو) کہا: (کیا تمہارے خیال میں) یہ میرا رب ہے؟ پھرجب وہ (بھی) غائب ہوگیا تو (اپنی قوم کو سنا کر) کہنے لگے: اگر میرا رب مجھے ہدایت نہ فرماتا تو میں بھی ضرور (تمہاری طرح) گمراہوں کی قوم میں سے ہو جاتا،\qt@no{77}}%
\qt@newcmd\qurantrans@ur@dccclxvii{پھر جب سورج کو چمکتے دیکھا (تو) کہا: (کیا اب تمہارے خیال میں) یہ میرا رب ہے (کیونکہ) یہ سب سے بڑا ہے؟ پھر جب وہ (بھی) چھپ گیا تو بول اٹھے: اے لوگو! میں ان (سب چیزوں) سے بیزار ہوں جنہیں تم (اﷲ کا) شریک گردانتے ہو،\qt@no{78}}%
\qt@newcmd\qurantrans@ur@dccclxviii{بیشک میں نے اپنا رُخ (ہر سمت سے ہٹا کر) یکسوئی سے اس (ذات) کی طرف پھیر لیا ہے جس نے آسمانوں اور زمین کو بے مثال پیدا فرمایا ہے اور (جان لو کہ) میں مشرکوں میں سے نہیں ہوں،\qt@no{79}}%
\qt@newcmd\qurantrans@ur@dccclxix{اور ان کی قوم ان سے بحث و جدال کرنے لگی (تو) انہوں نے کہا: بھلا تم مجھ سے اللہ کے بارے میں جھگڑتے ہو حالانکہ اس نے مجھے ہدایت فرما دی ہے، اور میں ان (باطل معبودوں) سے نہیں ڈرتا جنہیں تم اس کا شریک ٹھہرا رہے ہو مگر (یہ کہ) میرا رب جو کچھ (ضرر) چاہے (پہنچا سکتا ہے)۔ میرے رب نے ہر چیز کو (اپنے) علم سے احاطہ میں لے رکھا ہے، سو کیا تم نصیحت قبول نہیں کرتے،\qt@no{80}}%
\qt@newcmd\qurantrans@ur@dccclxx{اور میں ان (معبودانِ باطلہ) سے کیونکر خوفزدہ ہوسکتا ہوں جنہیں تم (اﷲ کا) شریک ٹھہراتے ہو درآنحالیکہ تم اس بات سے نہیں ڈرتے کہ تم نے اﷲ کے ساتھ (بتوں کو) شریک بنا رکھا ہے (جبکہ) اس نے تم پر اس (شرک) کی کوئی دلیل نہیں اتاری (اب تم ہی جواب دو!) سو ہر دو فریق میں سے (عذاب سے) بے خوف رہنے کا زیادہ حق دار کون ہے؟ اگر تم جانتے ہو،\qt@no{81}}%
\qt@newcmd\qurantrans@ur@dccclxxi{جو لوگ ایمان لائے اور اپنے ایمان کو (شرک کے ظلم کے ساتھ نہیں ملایا انہی لوگوں کے لئے امن (یعنی اُخروی بے خوفی) ہے اور وہی ہدایت یافتہ ہیں،\qt@no{82}}%
\qt@newcmd\qurantrans@ur@dccclxxii{اور یہی ہماری (توحید کی) دلیل تھی جو ہم نے ابراہیم (علیہ السلام) کو ان کی (مخالف) قوم کے مقابلہ میں دی تھی۔ ہم جس کے چاہتے ہیں درجات بلند کر دیتے ہیں۔ بیشک آپ کا رب بڑی حکمت والا خوب جاننے والا ہے،\qt@no{83}}%
\qt@newcmd\qurantrans@ur@dccclxxiii{اور ہم نے ان (ابراہیم علیہ السلام) کو اسحاق اور یعقوب (بیٹا اور پوتا علیھما السلام) عطا کئے، ہم نے (ان) سب کو ہدایت سے نوازا، اور ہم نے (ان سے) پہلے نوح (علیہ السلام) کو (بھی) ہدایت سے نوازا تھا اور ان کی اولاد میں سے داؤد اور سلیمان اور ایوب اور یوسف اور موسٰی اور ہارون (علیھم السلام کو بھی ہدایت عطا فرمائی تھی)، اور ہم اسی طرح نیکو کاروں کو جزا دیا کرتے ہیں،\qt@no{84}}%
\qt@newcmd\qurantrans@ur@dccclxxiv{اور زکریا اور یحیٰی اور عیسٰی اور الیاس (علیھم السلام کو بھی ہدایت بخشی)۔ یہ سب نیکو کار (قربت اور حضوری والے) لوگ تھے،\qt@no{85}}%
\qt@newcmd\qurantrans@ur@dccclxxv{اور اسمٰعیل اور الیسع اور یونس اور لوط (علیھم السلام کو بھی ہدایت سے شرف یاب فرمایا)، اور ہم نے ان سب کو (اپنے زمانے کے) تمام جہان والوں پر فضیلت بخشی،\qt@no{86}}%
\qt@newcmd\qurantrans@ur@dccclxxvi{اور ان کے آباؤ (و اجداد) اور ان کی اولاد اور ان کے بھائیوں میں سے بھی (بعض کو ایسی فضیلت عطا فرمائی) اور ہم نے انہیں (اپنے لطفِ خاص اور بزرگی کے لئے) چن لیا تھا اور انہیں سیدھی راہ کی طرف ہدایت فرما دی تھی،\qt@no{87}}%
\qt@newcmd\qurantrans@ur@dccclxxvii{یہ اللہ کی ہدایت ہے وہ اپنے بندوں میں سے جسے چاہتا ہے اس کے ذریعے رہنمائی فرماتا ہے، اور اگر (بالفرض) یہ لوگ شرک کرتے تو ان سے وہ سارے اعمالِ (خیر) ضبط (یعنی نیست و نابود) ہو جاتے جو وہ انجام دیتے تھے،\qt@no{88}}%
\qt@newcmd\qurantrans@ur@dccclxxviii{یہی) وہ لوگ ہیں جنہیں ہم نے کتاب اور حکمِ (شریعت) اور نبوّت عطا فرمائی تھی۔ پھر اگر یہ لوگ (یعنی کفّار) ان باتوں سے انکار کر دیں تو بیشک ہم نے ان (باتوں) پر (ایمان لانے کے لیے) ایسی قوم کو مقرر کردیا ہے جو ان سے انکار کرنے والے نہیں (ہوں گے)،\qt@no{89}}%
\qt@newcmd\qurantrans@ur@dccclxxix{یہی) وہ لوگ (یعنی پیغمبرانِ خدا) ہیں جنہیں اﷲ نے ہدایت فرمائی ہے پس (اے رسولِ آخر الزمان!) آپ ان کے (فضیلت والے سب) طریقوں (کو اپنی سیرت میں جمع کر کے ان) کی پیروی کریں (تاکہ آپ کی ذات میں ان تمام انبیاء و رسل کے فضائل و کمالات یکجا ہوجائیں)، آپ فرما دیجئے: (اے لوگو!) میں تم سے اس (ہدایت کی فراہمی پر کوئی اجرت نہیں مانگتا۔ یہ تو صرف جہان والوں کے لئے نصیحت ہے،\qt@no{90}}%
\qt@newcmd\qurantrans@ur@dccclxxx{اور انہوں نے (یعنی یہود نے) اﷲ کی وہ قدر نہ جانی جیسی قدر جاننا چاہیے تھی، جب انہوں نے یہ کہہ (کر رسالتِ محمدی صلی اللہ علیہ وآلہ وسلم کا انکار کر) دیا کہ اﷲ نے کسی آدمی پر کوئی چیز نہیں اتاری۔ آپ فرما دیجئے: وہ کتاب کس نے اتاری تھی جو موسٰی (علیہ السلام) لے کر آئے تھے جو لوگوں کے لئے روشنی اور ہدایت تھی؟ تم نے جس کے الگ الگ کاغذ بنا لئے ہیں تم اسے (لوگوں پر) ظاہر (بھی) کرتے ہو اور (اس میں سے) بہت کچھ چھپاتے (بھی) ہو، اور تمہیں وہ (کچھ) سکھایا گیا ہے جو نہ تم جانتے تھے اور نہ تمہارے باپ دادا، آپ فرما دیجئے: (یہ سب) اﷲ (ہی کا کرم ہے) پھر آپ انہیں (ان کے حال پر) چھوڑ دیں کہ وہ اپنی خرافات میں کھیلتے رہیں،\qt@no{91}}%
\qt@newcmd\qurantrans@ur@dccclxxxi{اور یہ (وہ) کتاب ہے جسے ہم نے نازل فرمایا ہے، بابرکت ہے، جو کتابیں اس سے پہلے تھیں ان کی (اصلاً) تصدیق کرنے والی ہے۔ اور (یہ) اس لئے (نازل کی گئی ہے) کہ آپ (اولاً) سب (انسانی) بستیوں کے مرکز (مکّہ) والوں کو اور (ثانیاً ساری دنیا میں) اس کے ارد گرد والوں کو ڈر سنائیں، اور جو لوگ آخرت پر ایمان رکھتے ہیں اس پر وہی ایمان لاتے ہیں اور وہی لوگ اپنی نماز کی پوری حفاظت کرتے ہیں،\qt@no{92}}%
\qt@newcmd\qurantrans@ur@dccclxxxii{اور اس سے بڑھ کر ظالم کون ہوگا جو اللہ پر جھوٹا بہتان باندھے یا (نبوت کا جھوٹا دعوٰی کرتے ہوئے یہ) کہے کہ میری طرف وحی کی گئی ہے حالانکہ اس کی طرف کچھ بھی وحی نہ کی گئی ہو اور (اس سے بڑھ کر ظالم کون ہوگا) جو (خدائی کا جھوٹا دعویٰ کرتے ہوئے یہ) کہے کہ میں (بھی) عنقریب ایسی ہی (کتاب) نازل کرتا ہوں جیسی اللہ نے نازل کی ہے۔ اور اگر آپ (اس وقت کا منظر) دیکھیں جب ظالم لوگ موت کی سختیوں میں (مبتلا) ہوں گے اور فرشتے (ان کی طرف) اپنے ہاتھ پھیلائے ہوئے ہوں گے اور (ان سے کہتے ہوں گے:) تم اپنی جانیں جسموں سے نکالو۔ آج تمہیں سزا میں ذلّت کا عذاب دیا جائے گا۔ اس وجہ سے کہ تم اﷲ پر ناحق باتیں کیا کرتے تھے اور تم اس کی آیتوں سے سرکشی کیا کرتے تھے،\qt@no{93}}%
\qt@newcmd\qurantrans@ur@dccclxxxiii{اور بیشک تم (روزِ قیامت) ہمارے پاس اسی طرح تنہا آؤ گے جیسے ہم نے تمہیں پہلی مرتبہ (تنہا) پیدا کیا تھا اور (اموال و اولاد میں سے) جو کچھ ہم نے تمہیں دے رکھا تھا وہ سب اپنی پیٹھ پیچھے چھوڑ آؤ گے، اور ہم تمہارے ساتھ تمہارے ان سفارشیوں کو نہیں دیکھیں گے جن کی نسبت تم (یہ) گمان کرتے تھے کہ وہ تمہارے (معاملات) میں ہمارے شریک ہیں۔ بیشک (آج) تمہارا باہمی تعلق (و اعتماد) منقطع ہوگیا اور وہ (سب) دعوے جو تم کیا کرتے تھے تم سے جاتے رہے،\qt@no{94}}%
\qt@newcmd\qurantrans@ur@dccclxxxiv{بیشک اﷲ دانے اور گٹھلی کو پھاڑ نکالنے والا ہے وہ مُردہ سے زندہ کو پیدا فرماتا ہے اور زندہ سے مُردہ کو نکالنے والا ہے، یہی (شان والا) تو اﷲ ہے پھر تم کہاں بہکے پھرتے ہو،\qt@no{95}}%
\qt@newcmd\qurantrans@ur@dccclxxxv{وہی) صبح (کی روشنی) کو رات کا اندھیرا چاک کر کے نکالنے والاہے، اور اسی نے رات کو آرام کے لئے بنایا ہے اور سورج اور چاند کوحساب و شمار کے لئے، یہ بہت غالب بڑے علم والے (ربّ) کا مقررہ اندازہ ہے،\qt@no{96}}%
\qt@newcmd\qurantrans@ur@dccclxxxvi{اور وہی ہے جس نے تمہارے لئے ستاروں کو بنایا تاکہ تم ان کے ذریعے بیابانوں اور دریاؤں کی تاریکیوں میں راستے پاسکو۔ بیشک ہم نے علم رکھنے والی قوم کے لئے (اپنی) نشانیاں کھول کر بیان کر دی ہیں،\qt@no{97}}%
\qt@newcmd\qurantrans@ur@dccclxxxvii{اور وہی (اﷲ) ہے جس نے تمہیں ایک جان (یعنی ایک خلیہ) سے پیدا فرمایا ہے پھر (تمہارے لئے) ایک جائے اقامت (ہے) اور ایک جائے امانت (مراد رحمِ مادر اور دنیا ہے یا دنیا اور قبر ہے)۔ بیشک ہم نے سمجھنے والے لوگوں کے لئے (اپنی قدرت کی) نشانیاں کھول کر بیان کردی ہیں،\qt@no{98}}%
\qt@newcmd\qurantrans@ur@dccclxxxviii{اور وہی ہے جس نے آسمان کی طرف سے پانی اتارا پھر ہم نے اس (بارش) سے ہر قسم کی روئیدگی نکالی پھر ہم نے اس سے سرسبز (کھیتی) نکالی جس سے ہم اوپر تلے پیوستہ دانے نکالتے ہیں اور کھجور کے گابھے سے لٹکتے ہوئے گچھے اور انگوروں کے باغات اور زیتون اور انار (بھی پیدا کئے جو کئی اعتبارات سے) آپس میں ایک جیسے (لگتے) ہیں اور (پھل، ذائقے اور تاثیرات) جداگانہ ہیں۔ تم درخت کے پھل کی طرف دیکھو جب وہ پھل لائے اور اس کے پکنے کو (بھی دیکھو)، بیشک ان میں ایمان رکھنے والے لوگوں کے لئے نشانیاں ہیں،\qt@no{99}}%
\qt@newcmd\qurantrans@ur@dccclxxxix{اور ان کافروں نے جِنّات کو اﷲ کا شریک بنایا حالانکہ اسی نے ان کو پیدا کیا تھا اورانہوں نے اللہ کے لئے بغیر علم (و دانش) کے لڑکے اور لڑکیاں (بھی) گھڑ لیں۔ وہ ان (تمام) باتوں سے پاک اور بلند و بالا ہے جو یہ (اس سے متعلق) کرتے پھرتے ہیں،\qt@no{100}}%
\qt@newcmd\qurantrans@ur@dcccxc{وہی آسمانوں اور زمینوں کا مُوجِد ہے، بھلا اس کی اولاد کیونکر ہو سکتی ہے حالانکہ اس کی بیوی (ہی) نہیں ہے، اور اسی نے ہر چیز کو پیدا فرمایا ہے اور وہ ہر چیز کو خوب جاننے والا ہے،\qt@no{101}}%
\qt@newcmd\qurantrans@ur@dcccxci{یہی (اﷲ) تمہارا پروردگار ہے، اس کے سوا کوئی لائقِ عبادت نہیں، (وہی) ہر چیز کا خالق ہے پس تم اسی کی عبادت کیا کرو اور وہ ہر چیز پر نگہبان ہے،\qt@no{102}}%
\qt@newcmd\qurantrans@ur@dcccxcii{نگاہیں اس کا احاطہ نہیں کر سکتیں اور وہ سب نگاہوں کا احاطہ کئے ہوئے ہے، اور وہ بڑا باریک بین بڑا باخبر ہے،\qt@no{103}}%
\qt@newcmd\qurantrans@ur@dcccxciii{بیشک تمہارے پاس تمہارے رب کی جانب سے (ہدایت کی) نشانیاں آچکی ہیں پس جس نے (انہیں نگاہِ بصیرت سے) دیکھ لیا تو (یہ) اس کی اپنی ذات کے لئے (فائدہ مند) ہے، اور جو اندھا رہا تو اس کا وبال (بھی) اسی پر ہے، اور میں تم پر نگہبان نہیں ہوں،\qt@no{104}}%
\qt@newcmd\qurantrans@ur@dcccxciv{اور ہم اسی طرح (اپنی) آیتوں کو بار بار (انداز بدل کر) بیان کرتے ہیں اور یہ اس لئے کہ وہ(کافر) بول اٹھیں کہ آپ نے (تو کہیں سے) پڑھ لیا ہے تاکہ ہم اس کو جاننے والے لوگوں کے لئے خوب واضح کردیں،\qt@no{105}}%
\qt@newcmd\qurantrans@ur@dcccxcv{آپ اس (قرآن) کی پیروی کیجئے جو آپ کی طرف آپ کے رب کی جانب سے وحی کیا گیا ہے، اللہ کے سوا کوئی معبود نہیں، اور آپ مشرکوں سے کنارہ کشی کر لیجئے،\qt@no{106}}%
\qt@newcmd\qurantrans@ur@dcccxcvi{اور اگر اﷲ (ان کو جبراً روکنا) چاہتا تو یہ لوگ (کبھی) شرک نہ کرتے، اور ہم نے آپ کو (بھی) ان پر نگہبان نہیں بنایا اور نہ آپ ان پر پاسبان ہیں،\qt@no{107}}%
\qt@newcmd\qurantrans@ur@dcccxcvii{اور (اے مسلمانو!) تم ان (جھوٹے معبودوں) کو گالی مت دو جنہیں یہ (مشرک لوگ) اللہ کے سوا پوجتے ہیں پھر وہ لوگ (بھی جواباً) جہالت کے باعث ظلم کرتے ہوئے اللہ کی شان میں دشنام طرازی کرنے لگیں گے۔ اسی طرح ہم نے ہر فرقہ (و جماعت) کے لئے ان کا عمل (ان کی آنکھوں میں) مرغوب کر رکھا ہے (اور وہ اسی کو حق سمجھتے رہتے ہیں)، پھر سب کو اپنے رب ہی کی طرف لوٹنا ہے اور وہ انہیں ان اعمال کے نتائج سے آگاہ فرما دے گا جو وہ انجام دیتے تھے،\qt@no{108}}%
\qt@newcmd\qurantrans@ur@dcccxcviii{وہ بڑے تاکیدی حلف کے ساتھ اللہ کی قَسم کھاتے ہیں کہ اگر ان کے پاس کوئی (کھلی) نشانی آجائے تو وہ اس پر ضرور ایمان لے آئیں گے۔ (ان سے) کہہ دو کہ نشانیاں توصرف اﷲ ہی کے پاس ہیں، اور (اے مسلمانو!) تمہیں کیا خبر کہ جب وہ نشانی آجائے گی (تو) وہ (پھر بھی) ایمان نہیں لائیں گے،\qt@no{109}}%
\qt@newcmd\qurantrans@ur@dcccxcix{اور ہم ان کے دلوں کو اور ان کی آنکھوں کو (ان کی اپنی بدنیتی کے باعث قبولِ حق) سے (اسی طرح) پھیر دیں گے جس طرح وہ اس (نبی) پر پہلی بار ایمان نہیں لائے (سو وہ نشانی دیکھ کر بھی ایمان نہیں لائیں گے) اور ہم انہیں ان کی سرکشی میں (ہی) چھوڑ دیں گے کہ وہ بھٹکتے پھریں،\qt@no{110}}%
\qt@newcmd\qurantrans@ur@cm{اور اگر ہم ان کی طرف فرشتے اتار دیتے اور ان سے مُردے باتیں کرنے لگتے اور ہم ان پر ہر چیز (آنکھوں کے سامنے) گروہ در گروہ جمع کر دیتے وہ تب بھی ایمان نہ لاتے سوائے اس کے جو اﷲ چاہتا اور ان میں سے اکثر لوگ جہالت سے کام لیتے ہیں،\qt@no{111}}%
\qt@newcmd\qurantrans@ur@cmi{اور اسی طرح ہم نے ہر نبی کے لئے انسانوں اور جِنّوں میں سے شیطانوں کو دشمن بنا دیا جو ایک دوسرے کے دل میں ملمع کی ہوئی (چکنی چپڑی) باتیں (وسوسہ کے طور پر) دھوکہ دینے کے لئے ڈالتے رہتے ہیں، اور اگر آپ کا ربّ (انہیں جبراً روکنا) چاہتا (تو) وہ ایسا نہ کر پاتے، سو آپ انہیں (بھی) چھوڑ دیں اور جو کچھ وہ بہتان باندھ رہے ہیں (اسے بھی)،\qt@no{112}}%
\qt@newcmd\qurantrans@ur@cmii{اور (یہ) اس لئے کہ ان لوگوں کے دل اس (فریب) کی طرف مائل ہو جائیں جو آخرت پر ایمان نہیں رکھتے اور (یہ) کہ وہ اسے پسند کرنے لگیں اور (یہ بھی) کہ وہ (انہی اعمالِ بد کا) ارتکاب کرنے لگیں جن کے وہ خود (مرتکب) ہو رہے ہیں،\qt@no{113}}%
\qt@newcmd\qurantrans@ur@cmiii{فرما دیجئے:) کیا میں اﷲ کے سوا کسی اور کو حاکم (و فیصل) تلاش کروں حالانکہ وہ (اﷲ) ہی ہے جس نے تمہاری طرف مفصّل (یعنی واضح لائحہ عمل پر مشتمل) کتاب نازل فرمائی ہے، اور وہ لوگ جن کو ہم نے (پہلے) کتاب دی تھی (دل سے) جانتے ہیں کہ یہ (قرآن) آپ کے رب کی طرف سے (مبنی) برحق اتارا ہوا ہے پس آپ (ان اہلِ کتاب کی نسبت) شک کرنے والوں میں نہ ہوں (کہ یہ لوگ قرآن کا وحی ہونا جانتے ہیں یا نہیں)،\qt@no{114}}%
\qt@newcmd\qurantrans@ur@cmiv{اور آپ کے رب کی بات سچائی اور عدل کی رُو سے پوری ہو چکی، اس کی باتوں کو کوئی بدلنے والا نہیں، اور وہ خوب سننے والا خوب جاننے والا ہے،\qt@no{115}}%
\qt@newcmd\qurantrans@ur@cmv{اور اگر تو زمین میں (موجود) لوگوں کی اکثریت کا کہنا مان لے تو وہ تجھے اﷲ کی راہ سے بھٹکا دیں گے۔ وہ (حق و یقین کی بجائے) صرف وہم و گمان کی پیروی کرتے ہیں اور محض غلط قیاس آرائی (اور دروغ گوئی) کرتے رہتے ہیں،\qt@no{116}}%
\qt@newcmd\qurantrans@ur@cmvi{بیشک آپ کا رب ہی اسے خوب جانتا ہے جو اس کی راہ سے بہکا ہے اور وہی ہدایت یافتہ لوگوں سے (بھی) خوب واقف ہے،\qt@no{117}}%
\qt@newcmd\qurantrans@ur@cmvii{سو تم اس (ذبیحہ) سے کھایا کرو جس پر (ذبح کے وقت) اﷲ کا نام لیا گیا ہو اگر تم اس کی آیتوں پر ایمان رکھنے والے ہو،\qt@no{118}}%
\qt@newcmd\qurantrans@ur@cmviii{اور تمہیں کیا ہے کہ تم اس (ذبیحہ) سے نہیں کھاتے جس پر (ذبح کے وقت) اﷲ کا نام لیا گیا ہے (تم ان حلال جانوروں کو بلاوجہ حرام ٹھہراتے ہو)؟ حالانکہ اس نے تمہارے لئے ان (تمام) چیزوں کو تفصیلاً بیان کر دیا ہے جو اس نے تم پر حرام کی ہیں، سوائے اس (صورت) کے کہ تم (محض جان بچانے کے لئے) ان (کے بقدرِ حاجت کھانے) کی طرف انتہائی مجبور ہو جاؤ (سو اب تم اپنی طرف سے اور چیزوں کو مزید حرام نہ ٹھہرایا کرو)۔ بیشک بہت سے لوگ بغیر (پختہ) علم کے اپنی خواہشات (اور من گھڑت تصورات) کے ذریعے (لوگوں کو) بہکاتے رہتے ہیں، اور یقینا آپ کا ربّ حد سے تجاوز کرنے والوں کو خوب جانتا ہے،\qt@no{119}}%
\qt@newcmd\qurantrans@ur@cmix{اور تم ظاہری اور باطنی (یعنی آشکار و پنہاں دونوں قسم کے) گناہ چھوڑ دو۔ بیشک جو لوگ گناہ کما رہے ہیں انہیں عنقریب سزا دی جائے گی ان (اَعمالِ بد) کے باعث جن کا وہ ارتکاب کرتے تھے،\qt@no{120}}%
\qt@newcmd\qurantrans@ur@cmx{اور تم اس (جانور کے گوشت) سے نہ کھایا کرو جس پر (ذبح کے وقت) اﷲ کا نام نہ لیا گیا ہو اور بیشک وہ (گوشت کھانا) گناہ ہے، اور بیشک شیاطین اپنے دوستوں کے دلوں میں (وسوسے) ڈالتے رہتے ہیں تاکہ وہ تم سے جھگڑا کریں اور اگر تم ان کے کہنے پر چل پڑے (تو) تم بھی مشرک ہو جاؤ گے،\qt@no{121}}%
\qt@newcmd\qurantrans@ur@cmxi{بھلا وہ شخص جو مُردہ (یعنی ایمان سے محروم) تھا پھر ہم نے اسے (ہدایت کی بدولت) زندہ کیا اور ہم نے اس کے لئے (ایمان و معرفت کا) نور پیدا فرما دیا (اب) وہ اس کے ذریعے (بقیہ) لوگوں میں (بھی روشنی پھیلانے کے لئے) چلتا ہے اس شخص کی مانند ہو سکتا ہے جس کا حال یہ ہو کہ (وہ جہالت اور گمراہی کے) اندھیروں میں (اس طرح گھِرا) پڑا ہے کہ اس سے نکل ہی نہیں سکتا۔ اسی طرح کافروں کے لئے ان کے وہ اعمال (ان کی نظروں میں) خوش نما دکھائے جاتے ہیں جو وہ انجام دیتے رہتے ہیں،\qt@no{122}}%
\qt@newcmd\qurantrans@ur@cmxii{اور اسی طرح ہم نے ہر بستی میں وڈیروں (اور رئیسوں) کو وہاں کے جرائم کا سرغنہ بنایا تاکہ وہ اس (بستی) میں مکاریاں کریں، اور وہ (حقیقت میں) اپنی جانوں کے سوا کسی (اور) سے فریب نہیں کر رہے اور وہ (اس کے انجامِ بد کا) شعور نہیں رکھتے،\qt@no{123}}%
\qt@newcmd\qurantrans@ur@cmxiii{اور جب ان کے پاس کوئی نشانی آتی ہے (تو) کہتے ہیں: ہم ہرگز ایمان نہیں لائیں گے یہاں تک کہ ہمیں بھی ویسی ہی (نشانی) دی جائے جیسی اﷲ کے رسولوں کو دی گئی ہے۔ اﷲ خوب جانتا ہے کہ اسے اپنی رسالت کا محل کسے بنانا ہے۔ عنقریب مجرموں کو اﷲ کے حضور ذلت رسید ہوگی اور سخت عذاب بھی (ملے گا) اس وجہ سے کہ وہ مکر (اور دھوکہ دہی) کرتے تھے،\qt@no{124}}%
\qt@newcmd\qurantrans@ur@cmxiv{پس اﷲ جس کسی کو (فضلاً) ہدایت دینے کا ارادہ فرماتا ہے اس کا سینہ اسلام کے لئے کشادہ فرما دیتا ہے اور جس کسی کو (عدلاً اس کی اپنی خرید کردہ) گمراہی پر ہی رکھنے کا ارادہ فرماتا ہے اس کا سینہ (ایسی) شدید گھٹن کے ساتھ تنگ کر دیتا ہے گویا وہ بمشکل آسمان (یعنی بلندی) پر چڑھ رہا ہو، اسی طرح اﷲ ان لوگوں پر عذابِ (ذّلت) واقع فرماتا ہے جو ایمان نہیں لاتے،\qt@no{125}}%
\qt@newcmd\qurantrans@ur@cmxv{اور یہ (اسلام ہی) آپ کے رب کا سیدھا راستہ ہے، بیشک ہم نے نصیحت قبول کرنے والے لوگوں کے لئے آیتیں تفصیل سے بیان کر دی ہیں،\qt@no{126}}%
\qt@newcmd\qurantrans@ur@cmxvi{انہی کے لئے ان کے رب کے حضور سلامتی کا گھر ہے اور وہی ان کا مولٰی ہے ان اعمالِ (صالحہ) کے باعث جو وہ انجام دیا کرتے تھے،\qt@no{127}}%
\qt@newcmd\qurantrans@ur@cmxvii{اور جس دن وہ ان سب کو جمع فرمائے گا (تو ارشاد ہوگا:) اے گروہِ جنّات (یعنی شیاطین!) بیشک تم نے بہت سے انسانوں کو (گمراہ) کر لیا، اور انسانوں میں سے ان کے دوست کہیں گے: اے ہمارے رب! ہم نے ایک دوسرے سے (خوب) فائدے حاصل کئے اور (اسی غفلت اور مفاد پرستی کے عالم میں) ہم اپنی اس میعاد کو پہنچ گئے جو تو نے ہمارے لئے مقرر فرمائی تھی (مگر ہم اس کے لئے کچھ تیاری نہ کر سکے)۔ اﷲ فرمائے گا کہ (اب) دوزخ ہی تمہارا ٹھکانا ہے ہمیشہ اسی میں رہو گے مگر جو اﷲ چاہے۔ بیشک آپ کا رب بڑی حکمت والا خوب جاننے والا ہے،\qt@no{128}}%
\qt@newcmd\qurantrans@ur@cmxviii{اسی طرح ہم ظالموں میں سے بعض کو بعض پر مسلط کرتے رہتے ہیں ان اعمالِ(بد) کے باعث جو وہ کمایا کرتے ہیں،\qt@no{129}}%
\qt@newcmd\qurantrans@ur@cmxix{اے گروہِ جن و انس! کیا تمہارے پاس تم ہی میں سے رسول نہیں آئے تھے جو تم پر میری آیتیں بیان کرتے تھے اور تمہاری اس دن کی پیشی سے تمہیں ڈراتے تھے؟ (تو) وہ کہیں گے: ہم اپنی جانوں کے خلاف گواہی دیتے ہیں، اور انہیں دنیا کی زندگی نے دھوکہ میں ڈال رکھا تھا اور وہ اپنی جانوں کے خلاف اس (بات) کی گواہی دیں گے کہ وہ (دنیا میں) کافر (یعنی حق کے انکاری) تھے،\qt@no{130}}%
\qt@newcmd\qurantrans@ur@cmxx{یہ (رسولوں کا بھیجنا) اس لئے تھا کہ آپ کا رب بستیوں کو ظلم کے باعث ایسی حالت میں تباہ کرنے والا نہیں ہے کہ وہاں کے رہنے والے (حق کی تعلیمات سے بالکل) بے خبر ہوں (یعنی انہیں کسی نے حق سے آگاہ ہی نہ کیا ہو)،\qt@no{131}}%
\qt@newcmd\qurantrans@ur@cmxxi{اور ہر ایک کے لئے ان کے اعمال کے لحاظ سے درجات (مقرر) ہیں، اور آپ کا رب ان کاموں سے بے خبر نہیں جو وہ انجام دیتے ہیں،\qt@no{132}}%
\qt@newcmd\qurantrans@ur@cmxxii{اور آپ کا رب بے نیاز ہے، (بڑی) رحمت والا ہے، اگر چاہے تو تمہیں نابود کر دے اور تمہارے بعد جسے چاہے (تمہارا) جانشین بنا دے جیسا کہ اس نے دوسرے لوگوں کی اولاد سے تم کو پیدا فرمایا ہے،\qt@no{133}}%
\qt@newcmd\qurantrans@ur@cmxxiii{بیشک جس (عذاب) کا تم سے وعدہ کیا جا رہا ہے وہ ضرور آنے والا ہے اور تم (اﷲ کو) عاجز نہیں کر سکتے،\qt@no{134}}%
\qt@newcmd\qurantrans@ur@cmxxiv{فرما دیجئے: اے (میری) قوم! تم اپنی جگہ پر عمل کرتے رہو بیشک میں (اپنی جگہ) عمل کئے جا رہا ہوں۔ پھر تم عنقریب جان لو گے کہ آخرت کا انجام کس کے لئے (بہتر ہے)۔ بیشک ظالم لوگ نجات نہیں پائیں گے،\qt@no{135}}%
\qt@newcmd\qurantrans@ur@cmxxv{انہوں نے اﷲ کے لئے انہی (چیزوں) میں سے ایک حصہ مقرر کر لیا ہے جنہیں اس نے کھیتی اور مویشیوں میں سے پیدا فرمایا ہے پھر اپنے گمانِ (باطل) سے کہتے ہیں کہ یہ (حصہ) اﷲ کے لئے ہے اور یہ ہمارے (خود ساختہ) شریکوں کے لئے ہے، پھر جو (حصہ) ان کے شریکوں کے لئے ہے سو وہ تو اﷲ تک نہیں پہنچتا اور جو (حصہ) اﷲ کے لئے ہے تو وہ ان کے شریکوں تک پہنچ جاتا ہے، (وہ) کیا ہی برا فیصلہ کر رہے ہیں،\qt@no{136}}%
\qt@newcmd\qurantrans@ur@cmxxvi{اور اسی طرح بہت سے مشرکوں کے لئے ان کے شریکوں نے اپنی اولاد کو مار ڈالنا (ان کی نگاہ میں) خوش نما کر دکھایا ہے تاکہ وہ انہیں برباد کر ڈالیں اور ان کے (بچے کھچے) دین کو (بھی) ان پر مشتبہ کر دیں، اور اگر اﷲ (انہیں جبراً روکنا) چاہتا تو وہ ایسا نہ کر پاتے پس آپ انہیں اور جو افترا پردازی وہ کر رہے ہیں (اسے نظرانداز کرتے ہوئے) چھوڑ دیجئے،\qt@no{137}}%
\qt@newcmd\qurantrans@ur@cmxxvii{اور اپنے خیالِ (باطل) سے (یہ بھی) کہتے ہیں کہ یہ (مخصوص) مویشی اور کھیتی ممنوع ہے، اسے کوئی نہیں کھا سکتا سوائے اس کے جسے ہم چاہیں اور (یہ کہ بعض) چوپائے ایسے ہیں جن کی پیٹھ (پر سواری) کو حرام کیا گیا ہے اور (بعض) مویشی ایسے ہیں کہ جن پر (ذبح کے وقت) یہ لوگ اﷲ کا نام نہیں لیتے (یہ سب) اﷲ پر بہتان باندھنا ہے، عنقریب وہ انہیں (اس بات کی) سزا دے گا جو وہ بہتان باندھتے تھے،\qt@no{138}}%
\qt@newcmd\qurantrans@ur@cmxxviii{اور (یہ بھی) کہتے ہیں کہ جو (بچہ) ان چوپایوں کے پیٹ میں ہے وہ ہمارے مَردوں کے لئے مخصوص ہے اور ہماری عورتوں پر حرام کر دیا گیا ہے، اور اگر وہ (بچہ) مرا ہوا (پیدا) ہو تو وہ (مرد اور عورتیں) سب اس میں شریک ہوتے ہیں، عنقریب وہ انہیں ان کی (من گھڑت) باتوں کی سزا دے گا، بیشک وہ بڑی حکمت والا خوب جاننے والا ہے،\qt@no{139}}%
\qt@newcmd\qurantrans@ur@cmxxix{واقعی ایسے لوگ برباد ہوگئے جنہوں نے اپنی اولاد کو بغیر علمِ (صحیح) کے (محض) بیوقوفی سے قتل کر ڈالا اور ان (چیزوں) کو جو اﷲ نے انہیں (روزی کے طور پر) بخشی تھیں اﷲ پر بہتان باندھتے ہوئے حرام کر ڈالا، بیشک وہ گمراہ ہو گئے اور ہدایت یافتہ نہ ہو سکے،\qt@no{140}}%
\qt@newcmd\qurantrans@ur@cmxxx{اور وہی ہے جس نے برداشتہ اور غیر برداشتہ (یعنی بیلوں کے ذریعے اوپر چڑھائے گئے اور بغیر اوپر چڑھائے گئے) باغات پیدا فرمائے اور کھجور (کے درخت) اور زراعت جس کے پھل گوناگوں ہیں اور زیتون اور انار (جو شکل میں) ایک دوسرے سے ملتے جلتے ہیں اور (ذائقہ میں) جداگانہ ہیں (بھی پیدا کئے)۔ جب (یہ درخت) پھل لائیں تو تم ان کے پھل کھایا (بھی) کرو اور اس (کھیتی اور پھل) کے کٹنے کے دن اس کا (اﷲ کی طرف سے مقرر کردہ) حق (بھی) ادا کر دیا کرو اور فضول خرچی نہ کیا کرو، بیشک وہ بے جا خرچ کرنے والوں کو پسند نہیں کرتا،\qt@no{141}}%
\qt@newcmd\qurantrans@ur@cmxxxi{اور (اس نے) بار برداری کرنے والے (بلند قامت) چوپائے اور زمین پر (ذبح کے لئے یا چھوٹے قد کے باعث) بچھنے والے (مویشی پیدا فرمائے)، تم اس (رزق) میں سے (بھی بطریقِ ذبح) کھایا کرو جو اﷲ نے تمہیں بخشا ہے اور شیطان کے راستوں پر نہ چلا کرو، بیشک وہ تمہارا کھلا دشمن ہے،\qt@no{142}}%
\qt@newcmd\qurantrans@ur@cmxxxii{اﷲ نے) آٹھ جوڑے پیدا کئے دو (نر و مادہ) بھیڑ سے اور دو (نر و مادہ) بکری سے۔ (آپ ان سے) فرما دیجئے: کیا اس نے دونوں نر حرام کئے ہیں یا دونوں مادہ یا وہ (بچہ) جو دونوں ماداؤں کے رحموں میں موجود ہے؟ مجھے علم و دانش کے ساتھ بتاؤ اگر تم سچے ہو،\qt@no{143}}%
\qt@newcmd\qurantrans@ur@cmxxxiii{اور دو (نر و مادہ) اونٹ سے اور دو (نر و مادہ) گائے سے۔ (آپ ان سے) فرما دیجئے: کیا اس نے دونوں نر حرام کئے ہیں یا دونوں مادہ یا وہ (بچہ) جو دونوں ماداؤں کے رحموں میں موجود ہے؟ کیا تم اس وقت موجود تھے جب اﷲ نے تمہیں اس (حرمت) کا حکم دیا تھا؟ پھر اس سے بڑھ کر ظالم کون ہو سکتا ہے جو اﷲ پر جھوٹا بہتان باندھتا ہے تاکہ لوگوں کو بغیر جانے گمراہ کرتا پھرے۔ بیشک اﷲ ظالم قوم کو ہدایت نہیں فرماتا،\qt@no{144}}%
\qt@newcmd\qurantrans@ur@cmxxxiv{آپ فرما دیں کہ میری طرف جو وحی بھیجی گئی ہے اس میں تو میں کسی (بھی) کھانے والے پر (ایسی چیز کو) جسے وہ کھاتا ہو حرام نہیں پاتا سوائے اس کے کہ وہ مُردار ہو یا بہتا ہوا خون ہو یا سؤر کا گوشت ہو کیو نکہ یہ ناپاک ہے یا نافرمانی کا جانور جس پر ذبح کے وقت غیر اﷲ کا نام بلند کیا گیا ہو۔ پھر جو شخص (بھوک کے باعث) سخت لاچار ہو جائے نہ تو نافرمانی کر رہا ہو اور نہ حد سے تجاوز کر رہا ہو تو بیشک آپ کا رب بڑا بخشنے والا نہایت مہربان ہے،\qt@no{145}}%
\qt@newcmd\qurantrans@ur@cmxxxv{اور یہودیوں پر ہم نے ہر ناخن والا (جانور) حرام کر دیا تھا اور گائے اور بکری میں سے ہم نے ان پر دونوں کی چربی حرام کر دی تھی سوائے اس (چربی) کے جو دونوں کی پیٹھ میں ہو یا اوجھڑی میں لگی ہو یا جو ہڈی کے ساتھ ملی ہو۔ یہ ہم نے ان کی سرکشی کے باعث انہیں سزا دی تھی اور یقینا ہم سچے ہیں،\qt@no{146}}%
\qt@newcmd\qurantrans@ur@cmxxxvi{پھر اگر وہ آپ کو جھٹلائیں تو فرما دیجئے کہ تمہارا رب وسیع رحمت والا ہے اور اس کا عذاب مجرم قوم سے نہیں ٹالا جائے گا،\qt@no{147}}%
\qt@newcmd\qurantrans@ur@cmxxxvii{جلد ہی مشرک لوگ کہیں گے کہ اگر اﷲ چاہتا تو نہ (ہی) ہم شرک کرتے اور نہ ہمارے آباء و اجداد اور نہ کسی چیز کو (بلا سند) حرام قرار دیتے۔ اسی طرح ان لوگوں نے بھی جھٹلایا تھا جو ان سے پہلے تھے حتٰی کہ انہوں نے ہمارا عذاب چکھ لیا۔ فرما دیجئے: کیا تمہارے پاس کوئی (قابلِ حجت) علم ہے کہ تم اسے ہمارے لئے نکال لاؤ (تو اسے پیش کرو)، تم (علمِ یقینی کو چھوڑ کر) صرف گمان ہی کی پیروی کرتے ہو اور تم محض (تخمینہ کی بنیاد پر) دروغ گوئی کرتے ہو،\qt@no{148}}%
\qt@newcmd\qurantrans@ur@cmxxxviii{فرما دیجئے کہ دلیلِ محکم تو اﷲ ہی کی ہے، پس اگر وہ (تمہیں مجبور کرنا) چاہتا تو یقیناً تم سب کو (پابندِ) ہدایت فرما دیتا٭، ٭ وہ حق و باطل کا فرق اور دونوں کا انجام سمجھانے کے بعد ہر ایک کو آزادی سے اپنا راستہ اختیار کرنے کا موقع دیتا ہے، تاکہ ہر شخص اپنے کئے کا خود ذمہ دار ٹھہرے اور اس پر جزا و سزا کا حق دار قرار پائے۔\qt@no{149}}%
\qt@newcmd\qurantrans@ur@cmxxxix{ان مشرکوں سے) فرما دیجئے کہ تم اپنے ان گواہوں کو پیش کرو جو (آکر) اس بات کی گواہی دیں کہ اﷲ نے اسے حرام کیا ہے، پھر اگر وہ (جھوٹی) گواہی دے ہی دیں تو ان کی گواہی کو تسلیم نہ کرنا (بلکہ ان کا جھوٹا ہونا ان پر آشکار کر دینا)، اور نہ ایسے لوگوں کی خواہشات کی پیروی کرنا جو ہماری آیتوں کو جھٹلاتے ہیں اور جو آخرت پر ایمان نہیں رکھتے اور وہ (معبودانِ باطلہ کو) اپنے رب کے برابر ٹھہراتے ہیں،\qt@no{150}}%
\qt@newcmd\qurantrans@ur@cmxl{فرما دیجئے: آؤ میں وہ چیزیں پڑھ کر سنا دوں جو تمہارے رب نے تم پر حرام کی ہیں (وہ) یہ کہ تم اس کے ساتھ کسی چیز کو شریک نہ ٹھہراؤ اور ماں باپ کے ساتھ اچھا سلوک کرو، اور مفلسی کے باعث اپنی اولاد کو قتل مت کرو۔ ہم ہی تمہیں رزق دیتے ہیں اور انہیں بھی (دیں گے)، اور بے حیائی کے کاموں کے قریب نہ جاؤ (خواہ) وہ ظاہر ہوں اور (خواہ) وہ پوشیدہ ہوں، اور اس جان کو قتل نہ کرو جسے (قتل کرنا) اﷲ نے حرام کیا ہے بجز حقِ (شرعی) کے، یہی وہ (امور) ہیں جن کا اس نے تمہیں تاکیدی حکم دیا ہے تاکہ تم عقل سے کام لو،\qt@no{151}}%
\qt@newcmd\qurantrans@ur@cmxli{اور یتیم کے مال کے قریب مت جانا مگر ایسے طریق سے جو بہت ہی پسندیدہ ہو یہاں تک کہ وہ اپنی جوانی کو پہنچ جائے، اور پیمانے اور ترازو (یعنی ناپ اور تول) کو انصاف کے ساتھ پورا کیا کرو۔ ہم کسی شخص کو اس کی طاقت سے زیادہ تکلیف نہیں دیتے، اور جب تم (کسی کی نسبت کچھ) کہو تو عدل کرو اگرچہ وہ (تمہارا) قرابت دار ہی ہو، اور اﷲ کے عہد کو پورا کیا کرو، یہی (باتیں) ہیں جن کا اس نے تمہیں تاکیدی حکم دیا ہے تاکہ تم نصیحت قبول کرو،\qt@no{152}}%
\qt@newcmd\qurantrans@ur@cmxlii{اور یہ کہ یہی (شریعت) میرا سیدھا راستہ ہے سو تم اس کی پیروی کرو، اور (دوسرے) راستوں پر نہ چلو پھر وہ (راستے) تمہیں اﷲ کی راہ سے جدا کر دیں گے، یہی وہ بات ہے جس کا اس نے تمہیں تاکیدی حکم دیا ہے تاکہ تم پرہیزگار بن جاؤ،\qt@no{153}}%
\qt@newcmd\qurantrans@ur@cmxliii{پھر ہم نے موسٰی (علیہ السلام) کو کتاب عطا کی اس شخص پر (نعمت) پوری کرنے کے لئے جو نیکو کار بنے اور (اسے) ہر چیز کی تفصیل اور ہدایت اور رحمت بنا کر (اتارا) تاکہ وہ (لوگ قیامت کے دن) اپنے رب سے ملاقات پر ایمان لائیں،\qt@no{154}}%
\qt@newcmd\qurantrans@ur@cmxliv{اور یہ (قرآن) برکت والی کتاب ہے جسے ہم نے نازل فرمایا ہے سو (اب) تم اس کی پیروی کیا کرو اور (اﷲ سے) ڈرتے رہو تاکہ تم پر رحم کیا جائے،\qt@no{155}}%
\qt@newcmd\qurantrans@ur@cmxlv{قرآن اس لئے نازل کیا ہے) کہ تم کہیں یہ (نہ) کہو کہ بس (آسمانی) کتاب تو ہم سے پہلے صرف دو گروہوں (یہود و نصارٰی) پر اتاری گئی تھی اور بیشک ہم ان کے پڑھنے پڑھانے سے بے خبر تھے،\qt@no{156}}%
\qt@newcmd\qurantrans@ur@cmxlvi{یا یہ (نہ) کہو کہ اگر ہم پر کتاب اتاری جاتی تو ہم یقیناً ان سے زیادہ ہدایت یافتہ ہوتے، سو اب تمہارے رب کی طرف تمہارے پاس واضح دلیل اور ہدایت اور رحمت آچکی ہے، پھر اس سے بڑھ کر ظالم کون ہو سکتا ہے جو اﷲ کی آیتوں کو جھٹلائے اور ان سے کترائے۔ ہم عنقریب ان لوگوں کو جو ہماری آیتوں سے گریز کرتے ہیں برے عذاب کی سزا دیں گے اس وجہ سے کہ وہ (آیاتِ ربّانی سے) اِعراض کرتے تھے،\qt@no{157}}%
\qt@newcmd\qurantrans@ur@cmxlvii{وہ فقط اسی انتظار میں ہیں کہ ان کے پاس (عذاب کے) فرشتے آپہنچیں یا آپ کا رب (خود) آجائے یا آپ کے رب کی کچھ (مخصوص) نشانیاں (عیاناً) آجائیں۔ (انہیں بتا دیجئے کہ) جس دن آپ کے رب کی بعض نشانیاں (یوں ظاہراً) آپہنچیں گی (تو اس وقت) کسی (ایسے) شخص کا ایمان اسے فائدہ نہیں پہنچائے گا جو پہلے سے ایمان نہیں لایا تھا یا اس نے اپنے ایمان (کی حالت) میں کوئی نیکی نہیں کمائی تھی، فرما دیجئے: تم انتظار کرو ہم (بھی) منتظر ہیں،\qt@no{158}}%
\qt@newcmd\qurantrans@ur@cmxlviii{بیشک جن لوگوں نے (جدا جدا راہیں نکال کر) اپنے دین کو پارہ پارہ کر دیا اور وہ (مختلف) فرقوں میں بٹ گئے، آپ کسی چیز میں ان کے (تعلق دار اور ذمہ دار) نہیں ہیں، بس ان کا معاملہ اﷲ ہی کے حوالے ہے پھر وہ انہیں ان کاموں سے آگاہ فرما دے گا جو وہ کیا کرتے تھے،\qt@no{159}}%
\qt@newcmd\qurantrans@ur@cmxlix{جو کوئی ایک نیکی لائے گا تو اس کے لئے (بطورِ اجر) اس جیسی دس نیکیاں ہیں، اور جو کوئی ایک گناہ لائے گا تو اس کو اس جیسے ایک (گناہ) کے سوا سزا نہیں دی جائے گی اور وہ ظلم نہیں کئے جائیں گے،\qt@no{160}}%
\qt@newcmd\qurantrans@ur@cml{فرما دیجئے: بیشک مجھے میرے رب نے سیدھے راستے کی ہدایت فرما دی ہے، (یہ) مضبوط دین (کی راہ ہے اور یہی) اﷲ کی طرف یک سو اور ہر باطل سے جدا ابراہیم (علیہ السلام) کی ملت ہے، اور وہ مشرکوں میں سے نہ تھے،\qt@no{161}}%
\qt@newcmd\qurantrans@ur@cmli{فرما دیجئے کہ بیشک میری نماز اور میرا حج اور قربانی (سمیت سب بندگی) اور میری زندگی اور میری موت اﷲ کے لئے ہے جو تمام جہانوں کا رب ہے،\qt@no{162}}%
\qt@newcmd\qurantrans@ur@cmlii{اس کا کوئی شریک نہیں اور اسی کا مجھے حکم دیا گیا ہے اور میں (جمیع مخلوقات میں) سب سے پہلا مسلمان ہوں،\qt@no{163}}%
\qt@newcmd\qurantrans@ur@cmliii{فرما دیجئے: کیا میں اﷲ کے سوا کوئی دوسرا رب تلاش کروں حالانکہ وہی ہر شے کا پروردگار ہے، اور ہر شخص جو بھی (گناہ) کرتا ہے (اس کا وبال) اسی پر ہوتا ہے اور کوئی بوجھ اٹھانے والا دوسرے کا بوجھ نہیں اٹھائے گا۔ پھر تمہیں اپنے رب ہی کی طرف لوٹنا ہے پھر وہ تمہیں ان (باتوں کی حقیقت) سے آگاہ فرما دے گا جن میں تم اختلاف کیا کرتے تھے،\qt@no{164}}%
\qt@newcmd\qurantrans@ur@cmliv{اور وہی ہے جس نے تم کو زمین میں نائب بنایا اور تم میں سے بعض کو بعض پر درجات میں بلند کیا تاکہ وہ ان (چیزوں) میں تمہیں آزمائے جو اس نے تمہیں (امانتاً) عطا کر رکھی ہیں۔ بیشک آپ کا رب (عذاب کے حق داروں کو) جلد سزا دینے والا ہے اور بیشک وہ (مغفرت کے امیدواروں کو) بڑا بخشنے والا اور بے حد رحم فرمانے والا ہے،\qt@no{165}}%
\qt@newcmd\qurantrans@ur@cmlv{\basmalahur الف، لام، میم، صاد (حقیقی معنی اﷲ اور رسول صلی اللہ علیہ وآلہ وسلم ہی بہتر جانتے ہیں)،\qt@no{1}}%
\qt@newcmd\qurantrans@ur@cmlvi{اے حبیبِ مکرّم!) یہ کتاب ہے (جو) آپ کی طرف اتاری گئی ہے سو آپ کے سینۂ (انور) میں اس (کی تبلیغ پر کفار کے انکار و تکذیب کے خیال) سے کوئی تنگی نہ ہو (یہ تو اتاری ہی اس لئے گئی ہے) کہ آپ اس کے ذریعے (منکرین کو) ڈر سنا سکیں اور یہ مومنین کے لئے نصیحت (ہے)،\qt@no{2}}%
\qt@newcmd\qurantrans@ur@cmlvii{اے لوگو!) تم اس (قرآن) کی پیروی کرو جو تمہارے رب کی طرف سے تمہاری طرف اتارا گیا ہے اور اس کے غیروں میں سے (باطل حاکموں اور) دوستوں کے پیچھے مت چلو، تم بہت ہی کم نصیحت قبول کرتے ہو،\qt@no{3}}%
\qt@newcmd\qurantrans@ur@cmlviii{اور کتنی ہی بستیاں (ایسی) ہیں جنہیں ہم نے ہلاک کر ڈالا سو ان پر ہمارا عذاب رات کے وقت آیا یا (جبکہ) وہ دوپہر کو سو رہے تھے،\qt@no{4}}%
\qt@newcmd\qurantrans@ur@cmlix{پھر جب ان پر ہمارا عذاب آگیا تو ان کی پکار سوائے اس کے (کچھ) نہ تھی کہ وہ کہنے لگے کہ بیشک ہم ظالم تھے،\qt@no{5}}%
\qt@newcmd\qurantrans@ur@cmlx{پھر ہم ان لوگوں سے ضرور پرسش کریں گے جن کی طرف رسول بھیجے گئے اور ہم یقیناً رسولوں سے بھی (ان کی دعوت و تبلیغ کے ردِّ عمل کی نسبت) دریافت کریں گے،\qt@no{6}}%
\qt@newcmd\qurantrans@ur@cmlxi{پھر ہم ان پر (اپنے) علم سے (ان کے سب) حالات بیان کریں گے اور ہم (کہیں) غائب نہ تھے (کہ انہیں دیکھتے نہ ہوں)،\qt@no{7}}%
\qt@newcmd\qurantrans@ur@cmlxii{اور اس دن (اعمال کا) تولا جانا حق ہے، سو جن کے (نیکیوں کے) پلڑے بھاری ہوں گے تو وہی لوگ کامیاب ہوں گے،\qt@no{8}}%
\qt@newcmd\qurantrans@ur@cmlxiii{اور جن کے (نیکیوں کے) پلڑے ہلکے ہوں گے تو یہی وہ لوگ ہیں جنہوں نے اپنی جانوں کو نقصان پہنچایا، اس وجہ سے کہ وہ ہماری آیتوں کے ساتھ ظلم کرتے تھے،\qt@no{9}}%
\qt@newcmd\qurantrans@ur@cmlxiv{اور بیشک ہم نے تم کو زمین میں تمکّن و تصرّف عطا کیا اور ہم نے اس میں تمہارے لئے اسبابِ معیشت پیدا کئے، تم بہت ہی کم شکر بجا لاتے ہو،\qt@no{10}}%
\qt@newcmd\qurantrans@ur@cmlxv{اور بیشک ہم نے تمہیں (یعنی تمہاری اصل کو) پیدا کیا پھر تمہاری صورت گری کی (یعنی تمہاری زندگی کی کیمیائی اور حیاتیاتی ابتداء و ارتقاء کے مراحل کو آدم (علیہ السلام) کے وجود کی تشکیل تک مکمل کیا)، پھر ہم نے فرشتوں سے فرمایا کہ آدم (علیہ السلام) کو سجدہ کرو تو سب نے سجدہ کیا سوائے ابلیس کے۔ وہ سجدہ کرنے والوں میں سے نہ ہوا،\qt@no{11}}%
\qt@newcmd\qurantrans@ur@cmlxvi{ارشاد ہوا: (اے ابلیس!) تجھے کس (بات) نے روکا تھا کہ تو نے سجدہ نہ کیا جبکہ میں نے تجھے حکم دیا تھا، اس نے کہا: میں اس سے بہتر ہوں، تو نے مجھے آگ سے پیدا کیا ہے اور اس کو تو نے مٹی سے بنایا ہے،\qt@no{12}}%
\qt@newcmd\qurantrans@ur@cmlxvii{ارشاد ہوا: پس تو یہاں سے اتر جا تجھے کوئی حق نہیں پہنچتا کہ تو یہاں تکّبر کرے پس (میری بارگاہ سے) نکل جا بیشک تو ذلیل و خوار لوگوں میں سے ہے،\qt@no{13}}%
\qt@newcmd\qurantrans@ur@cmlxviii{اس نے کہا: مجھے اس دن تک (زندگی کی) مہلت دے جس دن لوگ (قبروں سے) اٹھائے جائیں گے،\qt@no{14}}%
\qt@newcmd\qurantrans@ur@cmlxix{ارشاد ہوا: بیشک تو مہلت دیئے جانے والوں میں سے ہے،\qt@no{15}}%
\qt@newcmd\qurantrans@ur@cmlxx{اس (ابلیس) نے کہا: پس اس وجہ سے کہ تو نے مجھے گمراہ کیا ہے (مجھے قَسم ہے کہ) میں (بھی) ان (افرادِ بنی آدم کو گمراہ کرنے) کے لئے تیری سیدھی راہ پر ضرور بیٹھوں گا (تآنکہ انہیں راہِ حق سے ہٹا دوں)،\qt@no{16}}%
\qt@newcmd\qurantrans@ur@cmlxxi{پھر میں یقیناً ان کے آگے سے اور ان کے پیچھے سے اور ان کے دائیں سے اور ان کے بائیں سے ان کے پاس آؤں گا، اور (نتیجتاً) تو ان میں سے اکثر لوگوں کو شکر گزار نہ پائے گا،\qt@no{17}}%
\qt@newcmd\qurantrans@ur@cmlxxii{ارشاد باری ہوا: (اے ابلیس!) تو یہاں سے ذلیل و مردود ہو کر نکل جا، ان میں سے جو کوئی تیری پیروی کرے گا تو میں ضرور تم سب سے دوزخ بھر دوں گا،\qt@no{18}}%
\qt@newcmd\qurantrans@ur@cmlxxiii{اور اے آدم! تم اور تمہاری زوجہ (دونوں) جنت میں سکونت اختیار کرو سو جہاں سے تم دونوں چاہو کھایا کرو اور (بس) اس درخت کے قریب مت جانا ورنہ تم دونوں حد سے تجاوز کرنے والوں میں سے ہو جاؤ گے،\qt@no{19}}%
\qt@newcmd\qurantrans@ur@cmlxxiv{پھر شیطان نے دونوں کے دل میں وسوسہ ڈالا تاکہ ان کی شرم گاہیں جو ان (کی نظروں) سے پوشیدہ تھیں ان پر ظاہر کر دے اور کہنے لگا: (اے آدم و حوا!) تمہارے رب نے تمہیں اس درخت (کا پھل کھانے) سے نہیں روکا مگر (صرف اس لئے کہ اسے کھانے سے) تم دونوں فرشتے بن جاؤ گے (یعنی علائقِ بشری سے پاک ہو جاؤ گے) یا تم دونوں (اس میں) ہمیشہ رہنے والے بن جاؤ گے (یعنی اس مقامِ قرب سے کبھی محروم نہیں کئے جاؤ گے)،\qt@no{20}}%
\qt@newcmd\qurantrans@ur@cmlxxv{اور ان دونوں سے قَسم کھا کر کہا کہ بیشک میں تمہارے خیرخواہوں میں سے ہوں،\qt@no{21}}%
\qt@newcmd\qurantrans@ur@cmlxxvi{پس وہ فریب کے ذریعے دونوں کو (درخت کا پھل کھانے تک) اتار لایا، سو جب دونوں نے درخت (کے پھل) کو چکھ لیا تو دونوں کی شرم گاہیں ان کے لئے ظاہر ہوگئیں اور دونوں اپنے (بدن کے) اوپر جنت کے پتے چپکانے لگے، تو ان کے رب نے انہیں ندا فرمائی کہ کیا میں نے تم دونوں کو اس درخت (کے قریب جانے) سے روکا نہ تھا اور تم سے یہ (نہ) فرمایا تھا کہ بیشک شیطان تم دونوں کا کھلا دشمن ہے،\qt@no{22}}%
\qt@newcmd\qurantrans@ur@cmlxxvii{دونوں نے عرض کیا: اے ہمارے رب! ہم نے اپنی جانوں پر زیادتی کی؛ اور اگر تو نے ہم کو نہ بخشا اور ہم پر رحم (نہ) فرمایا تو ہم یقیناً نقصان اٹھانے والوں میں سے ہو جائیں گے،\qt@no{23}}%
\qt@newcmd\qurantrans@ur@cmlxxviii{ارشادِ باری ہوا: تم (سب) نیچے اتر جاؤ تم میں سے بعض بعض کے دشمن ہیں، اور تمہارے لئے زمین میں معیّن مدت تک جائے سکونت اور متاعِ حیات (مقرر کر دیئے گئے ہیں گویا تمہیں زمین میں قیام و معاش کے دو بنیادی حق دے کر اتارا جا رہا ہے، اس پر اپنا نظامِ زندگی استوار کرنا)،\qt@no{24}}%
\qt@newcmd\qurantrans@ur@cmlxxix{ارشاد فرمایا: تم اسی (زمین) میں زندگی گزارو گے اور اسی میں مَرو گے اور (قیامت کے روز) اسی میں سے نکالے جاؤ گے،\qt@no{25}}%
\qt@newcmd\qurantrans@ur@cmlxxx{اے اولادِ آدم! بیشک ہم نے تمہارے لئے (ایسا) لباس اتارا ہے جو تمہاری شرم گاہوں کو چھپائے اور (تمہیں) زینت بخشے اور (اس ظاہری لباس کے ساتھ ایک باطنی لباس بھی اتارا ہے اور وہی) تقوٰی کا لباس ہی بہتر ہے۔ یہ (ظاہر و باطن کے لباس سب) اﷲ کی نشانیاں ہیں تاکہ وہ نصیحت قبول کریں،\qt@no{26}}%
\qt@newcmd\qurantrans@ur@cmlxxxi{اے اولادِ آدم! (کہیں) تمہیں شیطان فتنہ میں نہ ڈال دے جس طرح اس نے تمہارے ماں باپ کو جنت سے نکال دیا، ان سے ان کا لباس اتروا دیا تاکہ انہیں ان کی شرم گاہیں دکھا دے۔ بیشک وہ (خود) اور اس کا قبیلہ تمہیں (ایسی ایسی جگہوں سے) دیکھتا (رہتا) ہے جہاں سے تم انہیں نہیں دیکھ سکتے۔ بیشک ہم نے شیطانوں کو ایسے لوگوں کا دوست بنا دیا ہے جو ایمان نہیں رکھتے،\qt@no{27}}%
\qt@newcmd\qurantrans@ur@cmlxxxii{اور جب وہ کوئی بے حیائی کا کام کرتے ہیں (تو) کہتے ہیں: ہم نے اپنے باپ دادا کو اسی (طریقہ) پر پایا اور اﷲ نے ہمیں اسی کا حکم دیا ہے۔ فرما دیجئے کہ اﷲ بے حیائی کے کاموں کا حکم نہیں دیتا۔ کیا تم اﷲ (کی ذات) پر ایسی باتیں کرتے ہو جو تم خود (بھی) نہیں جانتے،\qt@no{28}}%
\qt@newcmd\qurantrans@ur@cmlxxxiii{فرما دیجئے: میرے رب نے انصاف کا حکم دیا ہے، اور تم ہر سجدہ کے وقت و مقام پر اپنے رُخ (کعبہ کی طرف) سیدھے کر لیا کرو اور تمام تر فرمانبرداری اس کے لئے خالص کرتے ہوئے اس کی عبادت کیا کرو۔ جس طرح اس نے تمہاری (خلق و حیات کی) ابتداء کی تم اسی طرح (اس کی طرف) پلٹو گے،\qt@no{29}}%
\qt@newcmd\qurantrans@ur@cmlxxxiv{ایک گروہ کو اس نے ہدایت فرمائی اور ایک گروہ پر (اس کے اپنے کسب و عمل کے نتیجے میں) گمراہی ثابت ہو گئی۔ بیشک انہوں نے اﷲ کو چھوڑ کر شیطانوں کو دوست بنا لیا تھا اور وہ یہ گمان کرتے ہیں کہ وہ ہدایت یافتہ ہیں،\qt@no{30}}%
\qt@newcmd\qurantrans@ur@cmlxxxv{اے اولادِ آدم! تم ہر نماز کے وقت اپنا لباسِ زینت (پہن) لیا کرو اور کھاؤ اور پیو اور حد سے زیادہ خرچ نہ کرو کہ بیشک وہ بے جا خرچ کرنے والوں کو پسند نہیں فرماتا،\qt@no{31}}%
\qt@newcmd\qurantrans@ur@cmlxxxvi{فرما دیجئے: اﷲ کی اس زینت (و آرائش) کو کس نے حرام کیا ہے جو اس نے اپنے بندوں کے لئے پیدا فرمائی ہے اور کھانے کی پاک ستھری چیزوں کو (بھی کس نے حرام کیا ہے)؟ فرما دیجئے: یہ (سب نعمتیں جو) اہلِ ایمان کی دنیا کی زندگی میں (بالعموم روا) ہیں قیامت کے دن بالخصوص (انہی کے لئے) ہوں گی۔ اس طرح ہم جاننے والوں کے لئے آیتیں تفصیل سے بیان کرتے ہیں،\qt@no{32}}%
\qt@newcmd\qurantrans@ur@cmlxxxvii{فرما دیجئے کہ میرے ربّ نے (تو) صرف بے حیائی کی باتوں کو حرام کیا ہے جو ان میں سے ظاہر ہوں اور جو پوشیدہ ہوں (سب کو) اور گناہ کو اور ناحق زیادتی کو اور اس بات کو کہ تم اﷲ کا شریک ٹھہراؤ جس کی اس نے کوئی سند نہیں اتاری اور (مزید) یہ کہ تم اﷲ (کی ذات) پر ایسی باتیں کہو جو تم خود بھی نہیں جانتے،\qt@no{33}}%
\qt@newcmd\qurantrans@ur@cmlxxxviii{اور ہر گروہ کے لئے ایک میعاد (مقرر) ہے پھر جب ان کا (مقررہ) وقت آجاتا ہے تو وہ ایک گھڑی (بھی) پیچھے نہیں ہٹ سکتے اور نہ آگے بڑھ سکتے ہیں،\qt@no{34}}%
\qt@newcmd\qurantrans@ur@cmlxxxix{اے اولادِ آدم! اگر تمہارے پاس تم میں سے رسول آئیں جو تم پر میری آیتیں بیان کریں پس جو پرہیزگار بن گیا اور اس نے (اپنی) اصلاح کر لی تو ان پر نہ کوئی خوف ہوگا اور نہ (ہی) وہ رنجیدہ ہوں گے،\qt@no{35}}%
\qt@newcmd\qurantrans@ur@cmxc{اور جن لوگوں نے ہماری آیتوں کو جھٹلایا اور ان (پر ایمان لانے) سے سرکشی کی، وہی اہلِ جہنم ہیں، وہ اس میں ہمیشہ رہنے والے ہیں،\qt@no{36}}%
\qt@newcmd\qurantrans@ur@cmxci{پھر اس شخص سے زیادہ ظالم کون ہو سکتا ہے جو اﷲ پر جھوٹا بہتان باندھے یا اس کی آیتوں کو جھٹلائے؟ ان لوگوں کو ان کا (وہ) حصہ پہنچ جائے گا (جو) نوشۃٔ کتاب ہے، یہاں تک کہ جب ان کے پاس ہمارے بھیجے ہوئے (فرشتے) آئیں گے کہ ان کی روحیں قبض کر لیں (تو ان سے) کہیں گے: اب وہ (جھوٹے معبود) کہاں ہیں جن کی تم اﷲ کے سوا عبادت کرتے تھے؟ وہ (جواباً) کہیں گے کہ وہ ہم سے گم ہوگئے (یعنی اب کہاں نظر آتے ہیں) اور وہ اپنی جانوں کے خلاف (خود یہ) گواہی دیں گے کہ بیشک وہ کافر تھے،\qt@no{37}}%
\qt@newcmd\qurantrans@ur@cmxcii{اﷲ فرمائے گا: تم جنوں اور انسانوں کی ان (جہنّمی) جماعتوں میں شامل ہو کر جو تم سے پہلے گزر چکی ہیں دوزخ میں داخل ہو جاؤ۔ جب بھی کوئی جماعت (دوزخ میں) داخل ہوگی وہ اپنے جیسی دوسری جماعت پر لعنت بھیجے گی، یہاں تک کہ جب اس میں سارے (گروہ) جمع ہو جائیں گے تو ان کے پچھلے اپنے اگلوں کے حق میں کہیں گے کہ اے ہمارے ربّ! انہی لوگوں نے ہمیں گمراہ کیا تھا سو ان کو دوزخ کا دوگنا عذاب دے۔ ارشاد ہوگا: ہر ایک کے لئے دوگنا ہے مگر تم جانتے نہیں ہو،\qt@no{38}}%
\qt@newcmd\qurantrans@ur@cmxciii{اور ان کے اگلے اپنے پچھلوں سے کہیں گے: سو تمہیں ہم پر کچھ فضیلت نہ ہوئی پس (اب) تم (بھی) عذاب (کا مزہ) چکھو اس کے سبب جو کچھ تم کماتے تھے،\qt@no{39}}%
\qt@newcmd\qurantrans@ur@cmxciv{بیشک جن لوگوں نے ہماری آیتوں کو جھٹلایا اور ان سے سرکشی کی ان کے لئے آسمانِ (رحمت و قبولیت) کے دروازے نہیں کھولے جائیں گے اور نہ ہی وہ جنت میں داخل ہو سکیں گے یہاں تک کہ سوئی کے سوراخ میں اونٹ داخل ہو جائے (یعنی جیسے یہ ناممکن ہے اسی طرح ان کا جنت میں داخل ہونا بھی ناممکن ہے)، اور ہم مجرموں کو اسی طرح سزا دیتے ہیں،\qt@no{40}}%
\qt@newcmd\qurantrans@ur@cmxcv{اور ان کے لئے (آتشِ) دوزخ کا بچھونا اور ان کے اوپر (اسی کا) اوڑھنا ہوگا، اور ہم ظالموں کو اسی طرح سزا دیتے ہیں،\qt@no{41}}%
\qt@newcmd\qurantrans@ur@cmxcvi{اور جو لوگ ایمان لائے اور نیک عمل کرتے رہے، ہم کسی شخص کو اس کی طاقت سے زیادہ مکلّف نہیں کرتے، یہی لوگ اہلِ جنت ہیں وہ اس میں ہمیشہ رہیں گے،\qt@no{42}}%
\qt@newcmd\qurantrans@ur@cmxcvii{اور ہم وہ (رنجش و) کینہ جو ان کے سینوں میں (دنیا کے اندر ایک دوسرے کے لئے) تھا نکال (کے دور کر) دیں گے ان کے (محلوں کے) نیچے نہریں جاری ہوں گی، اور وہ کہیں گے: سب تعریفیں اﷲ ہی کے لئے ہیں جس نے ہمیں یہاں تک پہنچا دیا، اور ہم (اس مقام تک کبھی) راہ نہ پا سکتے تھے اگر اﷲ ہمیں ہدایت نہ فرماتا، بیشک ہمارے رب کے رسول حق (کا پیغام) لائے تھے، اور (اس دن) ندا دی جائے گی کہ تم لوگ اس جنت کے وارث بنا دیئے گئے ہو ان (نیک) اعمال کے باعث جو تم انجام دیتے تھے،\qt@no{43}}%
\qt@newcmd\qurantrans@ur@cmxcviii{اور اہلِ جنت دوزخ والوں کو پکار کر کہیں گے: ہم نے تو واقعتاً اسے سچّا پالیا جو وعدہ ہمارے رب نے ہم سے فرمایا تھا، سو کیا تم نے (بھی) اسے سچّا پایا جو وعدہ تمہارے ربّ نے (تم سے) کیا تھا؟ وہ کہیں گے: ہاں۔ پھر ان کے درمیان ایک آواز دینے والا آواز دے گا کہ ظالموں پر اﷲ کی لعنت ہے،\qt@no{44}}%
\qt@newcmd\qurantrans@ur@cmxcix{یہ وہی ہیں) جو (لوگوں کو) اﷲ کی راہ سے روکتے تھے اور اس میں کجی تلاش کرتے تھے اور وہ آخرت کا انکار کرنے والے تھے،\qt@no{45}}%
\qt@newcmd\qurantrans@ur@m{اور (ان) دونوں (یعنی جنتیوں اور دوزخیوں) کے درمیان ایک حجاب (یعنی فصیل) ہے، اور اَعراف (یعنی اسی فصیل) پر کچھ مرد ہوں گے جو سب کو ان کی نشانیوں سے پہچان لیں گے۔ اور وہ اہلِ جنت کو پکار کر کہیں گے کہ تم پر سلامتی ہو۔ وہ (اہلِ اَعراف خود ابھی) جنت میں داخل نہیں ہوئے ہوں گے حالانکہ وہ (اس کے) امیدوار ہوں گے،\qt@no{46}}%
\qt@newcmd\qurantrans@ur@mi{اور جب ان کی نگاہیں دوزخ والوں کی طرف پھیری جائیں گی تو وہ کہیں گے: اے ہمارے ربّ! ہمیں ظالم گروہ کے ساتھ (جمع) نہ کر،\qt@no{47}}%
\qt@newcmd\qurantrans@ur@mii{اور اہلِ اعراف (ان دوزخی) مردوں کو پکاریں گے جنہیں وہ ان کی نشانیوں سے پہچان رہے ہوں گے (ان سے) کہیں گے: تمہاری جماعتیں تمہارے کام نہ آسکیں اور نہ (وہ) تکبّر (تمہیں بچا سکا) جو تم کیا کرتے تھے،\qt@no{48}}%
\qt@newcmd\qurantrans@ur@miii{کیا یہی وہ لوگ ہیں (جن کی خستہ حالت دیکھ کر) تم قَسمیں کھایا کرتے تھے کہ اﷲ انہیں اپنی رحمت سے (کبھی) نہیں نوازے گا؟ (سن لو! اب انہی کو کہا جا رہا ہے:) تم جنت میں داخل ہو جاؤ نہ تم پر کوئی خوف ہوگا اور نہ تم غمگین ہوگے،\qt@no{49}}%
\qt@newcmd\qurantrans@ur@miv{اور دوزخ والے اہلِ جنت کو پکار کر کہیں گے کہ ہمیں (جنّتی) پانی سے کچھ فیض یاب کر دو یا اس (رزق) میں سے جو اﷲ نے تمہیں بخشا ہے۔ وہ کہیں گے: بیشک اﷲ نے یہ دونوں (نعمتیں) کافروں پر حرام کر دی ہیں،\qt@no{50}}%
\qt@newcmd\qurantrans@ur@mv{جنہوں نے اپنے دین کو تماشا اور کھیل بنا لیا اور جنہیں دنیوی زندگی نے فریب دے رکھا تھا، آج ہم انہیں اسی طرح بھلا دیں گے جیسے وہ (ہم سے) اپنے اس دن کی ملاقات کو بھولے ہوئے تھے اور جیسے وہ ہماری آیتوں کا انکار کرتے تھے،\qt@no{51}}%
\qt@newcmd\qurantrans@ur@mvi{اور بیشک ہم ان کے پاس ایسی کتاب (قرآن) لائے جسے ہم نے (اپنے) علم (کی بنا) پر مفصّل (یعنی واضح) کیا، وہ ایمان والوں کے لئے ہدایت اور رحمت ہے،\qt@no{52}}%
\qt@newcmd\qurantrans@ur@mvii{وہ صرف اس (کہی ہوئی بات) کے انجام کے منتظر ہیں، جس دن اس (بات) کا انجام سامنے آجائے گا وہ لوگ جو اس سے قبل اسے بھلا چکے تھے کہیں گے: بیشک ہمارے رب کے رسول حق (بات) لے کر آئے تھے، سو کیا (آج) ہمارے کوئی سفارشی ہیں جو ہمارے لئے سفارش کر دیں یا ہم (پھر دنیا میں) لوٹا دیئے جائیں تاکہ ہم (اس مرتبہ) ان (اعمال) سے مختلف عمل کریں جو (پہلے) کرتے رہے تھے۔ بیشک انہوں نے اپنے آپ کو نقصان پہنچایا اور وہ (بہتان و افتراء) ان سے جاتا رہا جو وہ گھڑا کرتے تھے،\qt@no{53}}%
\qt@newcmd\qurantrans@ur@mviii{بیشک تمہارا رب اﷲ ہے جس نے آسمانوں اور زمین (کی کائنات) کو چھ مدتوں (یعنی چھ اَدوار) میں پیدا فرمایا پھر (اپنی شان کے مطابق) عرش پر استواء (یعنی اس کائنات میں اپنے حکم و اقتدار کے نظام کا اجراء) فرمایا۔ وہی رات سے دن کو ڈھانک دیتا ہے (درآنحالیکہ دن رات میں سے) ہر ایک دوسرے کے تعاقب میں تیزی سے لگا رہتا ہے اور سورج اور چاند اور ستارے (سب) اسی کے حکم (سے ایک نظام) کے پابند بنا دیئے گئے ہیں۔ خبردار! (ہر چیز کی) تخلیق اور حکم و تدبیر کا نظام چلانا اسی کا کام ہے۔ اﷲ بڑی برکت والا ہے جو تمام جہانوں کی (تدریجاً) پرورش فرمانے والا ہے،\qt@no{54}}%
\qt@newcmd\qurantrans@ur@mix{تم اپنے رب سے گڑگڑا کر اور آہستہ (دونوں طریقوں سے) دعا کیا کرو، بیشک وہ حد سے بڑھنے والوں کو پسند نہیں کرتا،\qt@no{55}}%
\qt@newcmd\qurantrans@ur@mx{اور زمین میں اس کے سنور جانے (یعنی ملک کا ماحولِ حیات درست ہو جانے) کے بعد فساد انگیزی نہ کرو اور (اس کے عذاب سے) ڈرتے ہوئے اور (اس کی رحمت کی) امید رکھتے ہوئے اس سے دعا کرتے رہا کرو، بیشک اﷲ کی رحمت احسان شعار لوگوں (یعنی نیکوکاروں) کے قریب ہوتی ہے،\qt@no{56}}%
\qt@newcmd\qurantrans@ur@mxi{اور وہی ہے جو اپنی رحمت (یعنی بارش) سے پہلے ہواؤں کو خوشخبری بنا کر بھیجتا ہے، یہاں تک کہ جب وہ (ہوائیں) بھاری بھاری بادلوں کو اٹھا لاتی ہیں تو ہم ان (بادلوں) کو کسی مردہ (یعنی بے آب و گیاہ) شہر کی طرف ہانک دیتے ہیں پھر ہم اس (بادل) سے پانی برساتے ہیں پھر ہم اس (پانی) کے ذریعے (زمین سے) ہر قسم کے پھل نکالتے ہیں۔ اسی طرح ہم (روزِ قیامت) مُردوں کو (قبروں سے) نکالیں گے تاکہ تم نصیحت قبول کرو،\qt@no{57}}%
\qt@newcmd\qurantrans@ur@mxii{اور جو اچھی (یعنی زرخیز) زمین ہے اس کا سبزہ اﷲ کے حکم سے (خوب) نکلتا ہے اور جو (زمین) خراب ہے (اس سے) تھوڑی سی بے فائدہ چیز کے سوا کچھ نہیں نکلتا۔ اسی طرح ہم (اپنی) آیتیں (یعنی دلائل اور نشانیاں) ان لوگوں کے لئے بار بار بیان کرتے ہیں جو شکرگزار ہیں،\qt@no{58}}%
\qt@newcmd\qurantrans@ur@mxiii{بیشک ہم نے نوح (علیہ السلام) کو ان کی قوم کی طرف بھیجا سو انہوں نے کہا: اے میری قوم (کے لوگو!) تم اﷲ کی عبادت کیا کرو اس کے سوا تمہارا کوئی معبود نہیں، یقیناً مجھے تمہارے اوپر ایک بڑے دن کے عذاب کا خوف آتا ہے،\qt@no{59}}%
\qt@newcmd\qurantrans@ur@mxiv{ان کی قوم کے سرداروں اور رئیسوں نے کہا: (اے نوح!) بیشک ہم تمہیں کھلی گمراہی میں (مبتلا) دیکھتے ہیں،\qt@no{60}}%
\qt@newcmd\qurantrans@ur@mxv{انہوں نے کہا: اے میری قوم! مجھ میں کوئی گمراہی نہیں لیکن (یہ حقیقت ہے کہ) میں تمام جہانوں کے رب کی طرف سے رسول (مبعوث ہوا) ہوں،\qt@no{61}}%
\qt@newcmd\qurantrans@ur@mxvi{میں تمہیں اپنے رب کے پیغامات پہنچا رہا ہوں اور تمہیں نصیحت کر رہا ہوں اور اﷲ کی طرف سے وہ کچھ جانتا ہوں جو تم نہیں جانتے،\qt@no{62}}%
\qt@newcmd\qurantrans@ur@mxvii{کیا تمہیں اس بات پر تعجب ہے کہ تمہارے پاس تمہارے رب کی طرف سے تم ہی میں سے ایک مرد (کی زبان) پر نصیحت آئی تاکہ وہ تمہیں (عذابِ الٰہی سے) ڈرائے اور تم پرہیزگار بن جاؤ اور یہ اس لئے ہے کہ تم پر رحم کیا جائے،\qt@no{63}}%
\qt@newcmd\qurantrans@ur@mxviii{پھر ان لوگوں نے انہیں جھٹلایا سو ہم نے انہیں اور ان لوگوں کو جو کَشتی میں ان کی معیّت میں تھے نجات دی اور ہم نے ان لوگوں کو غرق کر دیا جنہوں نے ہماری آیتوں کو جھٹلایا تھا، بیشک وہ اندھے (یعنی بے بصیرت) لوگ تھے،\qt@no{64}}%
\qt@newcmd\qurantrans@ur@mxix{اور ہم نے (قومِ) عاد کی طرف ان کے (قومی) بھائی ہُود (علیہ السلام) کو (بھیجا)، انہوں نے کہا: اے میری قوم! تم اﷲ کی عبادت کیا کرو اس کے سوا کوئی تمہارا معبود نہیں، کیا تم پرہیزگار نہیں بنتے،\qt@no{65}}%
\qt@newcmd\qurantrans@ur@mxx{ان کی قوم کے سرداروں اور رئیسوں نے جو کفر (یعنی دعوتِ حق کی مخالفت و مزاحمت) کر رہے تھے کہا: (اے ہود!) بیشک ہم تمہیں حماقت (میں مبتلا) دیکھتے ہیں اور بیشک ہم تمہیں جھوٹے لوگوں میں گمان کرتے ہیں،\qt@no{66}}%
\qt@newcmd\qurantrans@ur@mxxi{انہوں نے کہا: اے میری قوم! مجھ میں کوئی حماقت نہیں لیکن (یہ حقیقت ہے کہ) میں تمام جہانوں کے رب کی طرف سے رسول (مبعوث ہوا) ہوں،\qt@no{67}}%
\qt@newcmd\qurantrans@ur@mxxii{میں تمہیں اپنے رب کے پیغامات پہنچا رہا ہوں اور میں تمہارا امانت دار خیرخواہ ہوں،\qt@no{68}}%
\qt@newcmd\qurantrans@ur@mxxiii{کیا تمہیں اس بات پر تعجب ہے کہ تمہارے پاس تمہارے رب کی طرف سے تم ہی میں سے ایک مرد (کی زبان) پر نصیحت آئی تاکہ وہ تمہیں (عذابِ الٰہی سے) ڈرائے، اور یاد کرو جب اس نے تمہیں قومِ نوح کے بعد (زمین پر) جانشین بنایا اور تمہاری خلقت میں (قد و قامت اور) قوت کو مزید بڑھا دے، سو تم اﷲ کی نعمتوں کو یاد کرو تاکہ تم فلاح پا جاؤ،\qt@no{69}}%
\qt@newcmd\qurantrans@ur@mxxiv{وہ کہنے لگے: کیا تم ہمارے پاس (اس لئے) آئے ہو کہ ہم صرف ایک اﷲ کی عبادت کریں اور ان (سب خداؤں) کو چھوڑ دیں جن کی پرستش ہمارے باپ دادا کیا کرتے تھے؟ سو تم ہمارے پاس وہ (عذاب) لے آؤ جس کی تم ہمیں وعید سناتے ہو اگر تم سچے لوگوں میں سے ہو،\qt@no{70}}%
\qt@newcmd\qurantrans@ur@mxxv{انہوں نے کہا: یقیناً تم پر تمہارے رب کی طرف سے عذاب اور غضب واجب ہو گیا۔ کیا تم مجھ سے ان (بتوں کے) ناموں کے بارے میں جھگڑ رہے ہو جو تم نے اور تمہارے باپ دادا نے (خود ہی فرضی طور پر) رکھ لئے ہیں جن کی اﷲ نے کوئی سند نہیں اتاری؟ سو تم (عذاب کا) انتظار کرو میں (بھی) تمہارے ساتھ انتظار کرنے والوں میں سے ہوں،\qt@no{71}}%
\qt@newcmd\qurantrans@ur@mxxvi{پھر ہم نے ان کو اور جو لوگ ان کے ساتھ تھے اپنی رحمت کے باعث نجات بخشی اور ان لوگوں کی جڑ کاٹ دی جنہوں نے ہماری آیتوں کو جھٹلایا تھا اور وہ ایمان لانے والے نہ تھے،\qt@no{72}}%
\qt@newcmd\qurantrans@ur@mxxvii{اور (قومِ) ثمود کی طرف ان کے (قومی) بھائی صالح (علیہ السلام) کو (بھیجا)، انہوں نے کہا: اے میری قوم! اﷲ کی عبادت کیا کرو، اس کے سوا تمہارا کوئی معبود نہیں، بیشک تمہارے پاس تمہارے رب کی طرف سے ایک روشن دلیل آگئی ہے۔ یہ اﷲ کی اونٹنی تمہارے لئے نشانی ہے، سو تم اسے (آزاد) چھوڑے رکھنا کہ اﷲ کی زمین میں چَرتی رہے اور اسے برائی (کے ارادے) سے ہاتھ نہ لگانا ورنہ تمہیں دردناک عذاب آپکڑے گا،\qt@no{73}}%
\qt@newcmd\qurantrans@ur@mxxviii{اور یاد کرو جب اس نے تمہیں (قومِ) عاد کے بعد (زمین میں) جانشین بنایا اور تمہیں زمین میں سکونت بخشی کہ تم اس کے نرم (میدانی) علاقوں میں محلات بناتے ہو اور پہاڑوں کو تراش کر (ان میں) گھر بناتے ہو، سو تم اﷲ کی (ان) نعمتوں کو یاد کرو اور زمین میں فساد انگیزی نہ کرتے پھرو،\qt@no{74}}%
\qt@newcmd\qurantrans@ur@mxxix{ان کی قوم کے ان سرداروں اور رئیسوں نے جو متکّبر و سرکش تھے ان غریب پسے ہوئے لوگوں سے کہا جو ان میں سے ایمان لے آئے تھے: کیا تمہیں یقین ہے کہ واقعی صالح (علیہ السلام) اپنے ربّ کی طرف سے رسول بنا کر بھیجے گئے ہیں؟ انہوں نے کہا: جو کچھ انہیں دے کر بھیجا گیا ہے بیشک ہم اس پر ایمان رکھنے والے ہیں،\qt@no{75}}%
\qt@newcmd\qurantrans@ur@mxxx{متکبّر لوگ کہنے لگے: بیشک جس (چیز) پر تم ایمان لائے ہو ہم اس کے سخت منکر ہیں،\qt@no{76}}%
\qt@newcmd\qurantrans@ur@mxxxi{پس انہوں نے اونٹنی کو (کاٹ کر) مار ڈالا اور اپنے ربّ کے حکم سے سرکشی کی اور کہنے لگے: اے صالح! تم وہ (عذاب) ہمارے پاس لے آؤ جس کی تم ہمیں وعید سناتے تھے اگر تم (واقعی) رسولوں میں سے ہو،\qt@no{77}}%
\qt@newcmd\qurantrans@ur@mxxxii{سو انہیں سخت زلزلہ (کے عذاب) نے آپکڑا پس وہ (ہلاک ہو کر) صبح اپنے گھروں میں اوندھے پڑے رہ گئے،\qt@no{78}}%
\qt@newcmd\qurantrans@ur@mxxxiii{پھر (صالح علیہ السلام نے) ان سے منہ پھیر لیا اور کہا: اے میری قوم! بیشک میں نے تمہیں اپنے رب کا پیغام پہنچا دیا تھا اور نصیحت (بھی) کر دی تھی لیکن تم نصیحت کرنے والوں کو پسند (ہی) نہیں کرتے،\qt@no{79}}%
\qt@newcmd\qurantrans@ur@mxxxiv{اور لوط(علیہ السلام) کو (بھی ہم نے اسی طرح بھیجا) جب انہوں نے اپنی قوم سے کہا: کیا تم (ایسی) بے حیائی کا ارتکاب کرتے ہو جسے تم سے پہلے اہلِ جہاں میں سے کسی نے نہیں کیا تھا،\qt@no{80}}%
\qt@newcmd\qurantrans@ur@mxxxv{بیشک تم نفسانی خواہش کے لئے عورتوں کو چھوڑ کر مَردوں کے پاس آتے ہو بلکہ تم حد سے گزر جانے والے ہو،\qt@no{81}}%
\qt@newcmd\qurantrans@ur@mxxxvi{اور ان کی قوم کا سوائے اس کے کوئی جواب نہ تھا کہ وہ کہنے لگے: ان کو بستی سے نکال دو بیشک یہ لوگ بڑے پاکیزگی کے طلب گار ہیں،\qt@no{82}}%
\qt@newcmd\qurantrans@ur@mxxxvii{پس ہم نے ان کو (یعنی لوط علیہ السلام کو) اور ان کے اہلِ خانہ کو نجات دے دی سوائے ان کی بیوی کے، وہ عذاب میں پڑے رہنے والوں میں سے تھی،\qt@no{83}}%
\qt@newcmd\qurantrans@ur@mxxxviii{اور ہم نے ان پر (پتھروں کی) بارش کر دی سو آپ دیکھئے کہ مجرموں کا انجام کیسا ہوا،\qt@no{84}}%
\qt@newcmd\qurantrans@ur@mxxxix{اور مدین کی طرف (ہم نے) ان کے (قومی) بھائی شعیب (علیہ السلام) کو (بھیجا)، انہوں نے کہا: اے میری قوم! تم اﷲ کی عبادت کیا کرو، اس کے سوا تمہارا کوئی معبود نہیں، بیشک تمہارے پاس تمہارے رب کی طرف سے روشن دلیل آچکی ہے سو تم ماپ اور تول پورے کیا کرو اور لوگوں کو ان کی چیزیں گھٹا کر نہ دیا کرو اور زمین میں اس (کے ماحولِ حیات) کی اصلاح کے بعد فساد بپا نہ کیا کرو، یہ تمہارے حق میں بہتر ہے اگر تم (اس الُوہی پیغام کو) ماننے والے ہو،\qt@no{85}}%
\qt@newcmd\qurantrans@ur@mxl{اور تم ہر راستہ پر اس لئے نہ بیٹھا کرو کہ تم ہر اس شخص کو جو اس (دعوت) پر ایمان لے آیا ہے خوفزدہ کرو اور (اسے) اﷲ کی راہ سے روکو اور اس (دعوت) میں کجی تلاش کرو (تاکہ اسے دینِ حق سے برگشتہ اور متنفر کر سکو) اور (اﷲ کا احسان) یاد کرو جب تم تھوڑے تھے تو اس نے تمہیں کثرت بخشی، اور دیکھو فساد پھیلانے والوں کا انجام کیسا ہوا،\qt@no{86}}%
\qt@newcmd\qurantrans@ur@mxli{اور اگر تم میں سے کوئی ایک گروہ اس (دین) پر جس کے ساتھ میں بھیجا گیا ہوں ایمان لے آیا ہے اور دوسرا گروہ ایمان نہیں لایا تو (اے ایمان والو!) صبر کرو یہاں تک کہ اﷲ ہمارے درمیان فیصلہ فرما دے، اور وہ سب سے بہتر فیصلہ فرمانے والا ہے،\qt@no{87}}%
\qt@newcmd\qurantrans@ur@mxlii{ان کی قوم کے سرداروں اور رئیسوں نے جو سرکش و متکبر تھے کہا: اے شعیب! ہم تمہیں اور ان لوگوں کو جو تمہاری معیت میں ایمان لائے ہیں اپنی بستی سے بہر صورت نکال دیں گے یا تمہیں ضرور ہمارے مذہب میں پلٹ آنا ہوگا۔ شعیب (علیہ السلام) نے کہا: اگرچہ ہم (تمہارے مذہب میں پلٹنے سے) بے زار ہی ہوں،\qt@no{88}}%
\qt@newcmd\qurantrans@ur@mxliii{بیشک ہم اللہ پر جھوٹا بہتان باندھیں گے اگر ہم تمہارے مذہب میں اس امر کے بعد پلٹ جائیں کہ اللہ نے ہمیں اس سے بچا لیا ہے، اور ہمارے لئے ہرگز (مناسب) نہیں کہ ہم اس (مذہب) میں پلٹ جائیں مگر یہ کہ اللہ چاہے جو ہمارا رب ہے۔ ہمارا رب اَز روئے علم ہر چیز پر محیط ہے۔ ہم نے اللہ ہی پر بھروسہ کرلیا ہے، اے ہمارے رب! ہمارے اور ہماری (مخالف) قوم کے درمیان حق کے ساتھ فیصلہ فرما دے اور تو سب سے بہتر فیصلہ فرمانے والا ہے،\qt@no{89}}%
\qt@newcmd\qurantrans@ur@mxliv{اور ان کی قوم کے سرداروں اور رئیسوں نے جو کفر (و انکار) کے مرتکب ہو رہے تھے کہا: (اے لوگو!) اگر تم نے شعیب (علیہ السلام) کی پیروی کی تو اس وقت تم یقیناً نقصان اٹھانے والے ہوجاؤ گے،\qt@no{90}}%
\qt@newcmd\qurantrans@ur@mxlv{پس انہیں شدید زلزلہ (کے عذاب) نے آپکڑا، سو وہ (ہلاک ہوکر) صبح اپنے گھروں میں اوندھے پڑے رہ گئے،\qt@no{91}}%
\qt@newcmd\qurantrans@ur@mxlvi{جن لوگوں نے شعیب (علیہ السلام) کو جھٹلایا (وہ ایسے نیست و نابود ہوئے) گویا وہ اس (بستی) میں (کبھی) بسے ہی نہ تھے۔ جن لوگوں نے شعیب (علیہ السلام) کو جھٹلایا (حقیقت میں) وہی نقصان اٹھانے والے ہوگئے،\qt@no{92}}%
\qt@newcmd\qurantrans@ur@mxlvii{تب (شعیب علیہ السلام) ان سے کنارہ کش ہوگئے اور کہنے لگے: اے میری قوم! بیشک میں نے تمہیں اپنے رب کے پیغامات پہنچا دیئے تھے اور میں نے تمہیں نصیحت (بھی) کردی تھی پھر میں کافر قوم (کے تباہ ہونے) پر افسوس کیونکر کروں،\qt@no{93}}%
\qt@newcmd\qurantrans@ur@mxlviii{اور ہم نے کسی بستی میں کوئی نبی نہیں بھیجا مگر ہم نے اس کے باشندوں کو (نبی کی تکذیب و مزاحمت کے باعث) سختی و تنگی اور تکلیف و مصیبت میں گرفتار کرلیا تاکہ وہ آہ و زاری کریں،\qt@no{94}}%
\qt@newcmd\qurantrans@ur@mxlix{پھر ہم نے (ان کی) بدحالی کی جگہ خوش حالی بدل دی، یہاں تک کہ وہ (ہر لحاظ سے) بہت بڑھ گئے۔ اور (نا شکری سے) کہنے لگے کہ ہمارے باپ دادا کو بھی (اسی طرح) رنج اور راحت پہنچتی رہی ہے سو ہم نے انہیں اس کفرانِ نعمت پر اچانک پکڑ لیا اور انہیں (اس کی) خبر بھی نہ تھی،\qt@no{95}}%
\qt@newcmd\qurantrans@ur@ml{اور اگر (ان) بستیوں کے باشندے ایمان لے آتے اور تقوٰی اختیار کرتے تو ہم ان پر آسمان اور زمین سے برکتیں کھول دیتے لیکن انہوں نے (حق کو) جھٹلایا، سو ہم نے انہیں ان اَعمالِ (بد) کے باعث جو وہ انجام دیتے تھے (عذاب کی) گرفت میں لے لیا،\qt@no{96}}%
\qt@newcmd\qurantrans@ur@mli{کیا اب بستیوں کے باشندے اس بات سے بے خوف ہوگئے ہیں کہ ان پر ہمارا عذاب (پھر) رات کو آپہنچے اس حال میں کہ وہ (غفلت کی نیند) سوئے ہوئے ہیں،\qt@no{97}}%
\qt@newcmd\qurantrans@ur@mlii{یا بستیوں کے باشندے ا س بات سے بے خوف ہیں کہ ان پر ہمارا عذاب (پھر) دن چڑھے آجائے اس حال میں کہ (وہ دنیا میں مدہوش ہوکر) کھیل رہے ہوں؟،\qt@no{98}}%
\qt@newcmd\qurantrans@ur@mliii{کیا وہ لو گ اللہ کی مخفی تدبیر سے بے خوف ہیں؟ پس اللہ کی مخفی تدبیر سے کوئی بے خوف نہیں ہوا کرتا سوائے نقصان اٹھانے والی قوم کے،\qt@no{99}}%
\qt@newcmd\qurantrans@ur@mliv{کیا (یہ بات بھی) ان لوگوں کو (شعور و) ہدایت نہیں دیتی جو (ایک زمانے میں) زمین پر رہنے والوں (کی ہلاکت) کے بعد (خود) زمین کے وارث بن رہے ہیں کہ اگر ہم چاہیں تو ان کے گناہوں کے باعث انہیں (بھی) سزا دیں، اور ہم ان کے دلوں پر (ان کی بداَعمالیوں کی وجہ سے) مُہر لگا دیں گے سو وہ (حق کو) سن (سمجھ) بھی نہیں سکیں گے،\qt@no{100}}%
\qt@newcmd\qurantrans@ur@mlv{یہ وہ بستیاں ہیں جن کی خبریں ہم آپ کو سنا رہے ہیں، اور بیشک ان کے پاس ان کے رسول روشن نشانیاں لے کر آئے تو وہ (پھر بھی) اس قابل نہ ہوئے کہ اس پر ایمان لے آتے جسے وہ پہلے جھٹلا چکے تھے، اس طرح اللہ کافروں کے دلوں پر مہر لگا دیتا ہے،\qt@no{101}}%
\qt@newcmd\qurantrans@ur@mlvi{اور ہم نے ان میں سے اکثر لوگوں میں عہد (کا نباہ) نہ پایا اور ان میں سے اکثر لوگوں کو ہم نے نافرمان ہی پایا،\qt@no{102}}%
\qt@newcmd\qurantrans@ur@mlvii{پھر ہم نے ان کے بعد موسٰی (علیہ السلام) کو اپنی نشانیوں کے ساتھ فرعون اور اس کے (درباری) سرداروں کے پاس بھیجا تو انہوں نے ان (دلائل اور معجزات) کے ساتھ ظلم کیا، پھر آپ دیکھئے کہ فساد پھیلانے والوں کا انجام کیسا ہوا؟،\qt@no{103}}%
\qt@newcmd\qurantrans@ur@mlviii{اور موسٰی (علیہ السلام) نے کہا: اے فرعون! بیشک میں تمام جہانوں کے رب کی طرف سے رسول (آیا) ہوں،\qt@no{104}}%
\qt@newcmd\qurantrans@ur@mlix{مجھے یہی زیب دیتا ہے کہ اللہ کے بارے میں حق بات کے سوا (کچھ) نہ کہوں۔ بیشک میں تمہارے رب (کی جانب) سے تمہارے پاس واضح نشانی لایا ہوں، سو تُو بنی اسرائیل کو (اپنی غلامی سے آزاد کر کے) میرے ساتھ بھیج دے،\qt@no{105}}%
\qt@newcmd\qurantrans@ur@mlx{اس (فرعون) نے کہا: اگر تم کوئی نشانی لائے ہو تو اسے (سامنے) لاؤ اگر تم سچے ہو،\qt@no{106}}%
\qt@newcmd\qurantrans@ur@mlxi{پس موسٰی (علیہ السلام) نے اپنا عصا (نیچے) ڈال دیا تو اسی وقت صریحاً اژدہا بن گیا،\qt@no{107}}%
\qt@newcmd\qurantrans@ur@mlxii{اور اپنا ہاتھ (گریبان میں ڈال کر) نکالا تو وہ (بھی) اسی وقت دیکھنے والوں کے لئے (چمک دار) سفید ہوگیا،\qt@no{108}}%
\qt@newcmd\qurantrans@ur@mlxiii{قومِ فرعون کے سردار بولے: بیشک یہ (تو کوئی) بڑا ماہر جادوگر ہے،\qt@no{109}}%
\qt@newcmd\qurantrans@ur@mlxiv{لوگو!) یہ تمہیں تمہارے ملک سے نکالنا چاہتا ہے، سو تم کیا مشورہ دیتے ہو،\qt@no{110}}%
\qt@newcmd\qurantrans@ur@mlxv{انہوں نے کہا: (ابھی) اس کے اور اس کے بھائی (کے معاملہ) کو مؤخر کر دو اور (مختلف) شہروں میں (جادوگروں کو) جمع کرنے والے افراد بھیج دو،\qt@no{111}}%
\qt@newcmd\qurantrans@ur@mlxvi{وہ تمہارے پاس ہر ماہر جادوگر کو لے آئیں،\qt@no{112}}%
\qt@newcmd\qurantrans@ur@mlxvii{اور جادوگر فرعون کے پاس آئے تو انہوں نے کہا: یقیناً ہمارے لئے کچھ اُجرت ہونی چاہیے بشرطیکہ ہم غالب آجائیں،\qt@no{113}}%
\qt@newcmd\qurantrans@ur@mlxviii{فرعون نے کہا: ہاں! اور بیشک (عام اُجرت تو کیا اس صورت میں) تم (میرے دربار کی) قربت والوں میں سے ہو جاؤ گے،\qt@no{114}}%
\qt@newcmd\qurantrans@ur@mlxix{ان جادوگروں نے کہا: اے موسٰی! یا تو (اپنی چیز) آپ ڈال دیں یا ہم ہی (پہلے) ڈالنے والے ہوجائیں،\qt@no{115}}%
\qt@newcmd\qurantrans@ur@mlxx{موسٰی (علیہ السلام) نے کہا: تم ہی (پہلے) ڈال دو پھر جب انہوں نے (اپنی رسیوں اور لاٹھیوں کو زمین پر) ڈالا (تو انہوں نے) لوگوں کی آنکھوں پرجادو کردیا اور انہیں ڈرا دیا اور وہ زبردست جادو (سامنے) لے آئے،\qt@no{116}}%
\qt@newcmd\qurantrans@ur@mlxxi{اور ہم نے موسٰی (علیہ السلام) کی طرف وحی فرمائی کہ (اب) آپ اپنا عصا (زمین پر) ڈال دیں تو وہ فوراً ان چیزوں کو نگلنے لگا جو انہوں نے فریب کاری سے وضع کر رکھی تھیں،\qt@no{117}}%
\qt@newcmd\qurantrans@ur@mlxxii{پس حق ثابت ہوگیا اور جو کچھ وہ کر رہے تھے (سب) باطل ہوگیا،\qt@no{118}}%
\qt@newcmd\qurantrans@ur@mlxxiii{سو وہ (فرعونی نمائندے) اس جگہ مغلوب ہوگئے اور ذلیل ہوکر پلٹ گئے،\qt@no{119}}%
\qt@newcmd\qurantrans@ur@mlxxiv{اور (تمام) جادوگر سجدہ میں گر پڑے،\qt@no{120}}%
\qt@newcmd\qurantrans@ur@mlxxv{وہ بول اٹھے: ہم سارے جہانوں کے (حقیقی) رب پر ایمان لے آئے،\qt@no{121}}%
\qt@newcmd\qurantrans@ur@mlxxvi{جو) موسٰی اور ہارون (علیہما السلام) کا رب ہے،\qt@no{122}}%
\qt@newcmd\qurantrans@ur@mlxxvii{فرعون کہنے لگا: (کیا) تم اس پر ایمان لے آئے ہو قبل اس کے کہ میں تمہیں اجازت دیتا؟ بیشک یہ ایک فریب ہے جو تم (سب) نے مل کر (مجھ سے) اس شہر میں کیا ہے تاکہ تم اس (ملک) سے اس کے (قبطی) باشندوں کو نکال کر لے جاؤ، سو تم عنقریب (اس کا انجام) جان لو گے،\qt@no{123}}%
\qt@newcmd\qurantrans@ur@mlxxviii{میں یقیناً تمہارے ہاتھوں کو اور تمہارے پاؤں کو ایک دوسرے کی الٹی سمت سے کاٹ ڈالوں گا پھر ضرور بالضرور تم سب کو پھانسی دے دوں گا،\qt@no{124}}%
\qt@newcmd\qurantrans@ur@mlxxix{انہوں نے کہا: بیشک ہم اپنے رب کی طرف پلٹنے والے ہیں،\qt@no{125}}%
\qt@newcmd\qurantrans@ur@mlxxx{اور تمہیں ہمارا کون سا عمل برا لگا ہے؟ صرف یہی کہ ہم اپنے رب کی (سچی) نشانیوں پر ایمان لے آئے ہیں جب وہ ہمارے پاس پہنچ گئیں۔ اے ہمارے رب! تو ہم پر صبر کے سرچشمے کھول دے اور ہم کو (ثابت قدمی سے) مسلمان رہتے ہوئے (دنیا سے) اٹھالے،\qt@no{126}}%
\qt@newcmd\qurantrans@ur@mlxxxi{اور قومِ فرعون کے سرداروں نے (فرعون سے) کہا: کیا تو موسٰی اور اس کی (اِنقلاب پسند) قوم کو چھوڑ دے گا کہ وہ ملک میں فساد پھیلائیں اور (پھر کیا) وہ تجھ کو اور تیرے معبودوں کو چھوڑ دیں گے؟ اس نے کہا: (نہیں) اب ہم ان کے لڑکوں کو قتل کردیں گے (تاکہ ان کی مردانہ افرادی قوت ختم ہوجائے) اور ان کی عورتوں کو زندہ رکھیں گے (تاکہ ان سے زیادتی کی جاسکے)، اور بیشک ہم ان پر غالب ہیں،\qt@no{127}}%
\qt@newcmd\qurantrans@ur@mlxxxii{موسٰی (علیہ السلام) نے اپنی قوم سے فرمایا: تم اللہ سے مدد مانگو اور صبر کرو، بیشک زمین اللہ کی ہے وہ اپنے بندوں میں سے جسے چاہتا ہے اس کا وارث بنا دیتا ہے، اور انجامِ خیر پرہیزگاروں کے لئے ہی ہے،\qt@no{128}}%
\qt@newcmd\qurantrans@ur@mlxxxiii{لوگ کہنے لگے: (اے موسٰی!) ہمیں تو آپ کے ہمارے پاس آنے سے پہلے بھی اذیتیں پہنچائی گئیں اور آپ کے ہمارے پاس آنے کے بعد بھی (گویا ہم دونوں طرح مارے گئے، ہماری مصیبت کب دور ہو گی؟) موسٰی (علیہ السلام) نے (اپنی قوم کو تسلی دیتے ہوئے) فرمایا: قریب ہے کہ تمہارا رب تمہارے دشمن کو ہلاک کردے اور (اس کے بعد) زمین (کی سلطنت) میں تمہیں جانشین بنا دے پھر وہ دیکھے کہ تم (اقتدار میں آکر) کیسے عمل کرتے ہو،\qt@no{129}}%
\qt@newcmd\qurantrans@ur@mlxxxiv{پھر ہم نے اہلِ فرعون کو (قحط کے) چند سالوں اور میووں کے نقصان سے (عذاب کی) گرفت میں لے لیا تاکہ وہ نصیحت حاصل کریں،\qt@no{130}}%
\qt@newcmd\qurantrans@ur@mlxxxv{پھر جب انہیں آسائش پہنچتی تو کہتے: یہ ہماری اپنی وجہ سے ہے۔ اور اگر انہیں سختی پہنچتی، وہ موسٰی (علیہ السلام) اور ان کے (ایمان والے) ساتھیوں کی نسبت بدشگونی کرتے، خبردار! ان کا شگون (یعنی شامتِ اَعمال) تو اللہ ہی کے پاس ہے مگر ان میں سے اکثر لوگ علم نہیں رکھتے،\qt@no{131}}%
\qt@newcmd\qurantrans@ur@mlxxxvi{اور وہ (اہلِ فرعون متکبرانہ طور پر) کہنے لگے: (اے موسٰی!) تم ہمارے پاس جو بھی نشانی لاؤ کہ تم اس کے ذریعے ہم پر جادو کر سکو، تب بھی ہم تم پر ایمان لانے والے نہیں ہیں،\qt@no{132}}%
\qt@newcmd\qurantrans@ur@mlxxxvii{پھر ہم نے ان پر طوفان، ٹڈیاں، گھن، مینڈک اور خون (کتنی ہی) جداگانہ نشانیاں (بطورِ عذاب) بھیجیں، پھر (بھی) انہوں نے تکبر و سرکشی اختیار کئے رکھی اور وہ (نہایت) مجرم قوم تھے،\qt@no{133}}%
\qt@newcmd\qurantrans@ur@mlxxxviii{اور جب ان پر (کوئی) عذاب واقع ہوتا تو کہتے: اے موسٰی! آپ ہمارے لئے اپنے رب سے دعا کریں اس عہد کے وسیلہ سے جو (اس کا) آپ کے پاس ہے، اگر آپ ہم سے اس عذاب کو ٹال دیں تو ہم ضرور آپ پر ایمان لے آئیں گے اور بنی اسرائیل کو (بھی آزاد کر کے) آپ کے ساتھ بھیج دیں گے،\qt@no{134}}%
\qt@newcmd\qurantrans@ur@mlxxxix{پھر جب ہم ان سے اس مدت تک کے لئے جس کو وہ پہنچنے والے ہوتے وہ عذاب ٹال دیتے تو وہ فوراً ہی عہد توڑ دیتے،\qt@no{135}}%
\qt@newcmd\qurantrans@ur@mxc{پھر ہم نے ان سے (بالآخر تمام نافرمانیوں اور بدعہدیوں کا) بدلہ لے لیا اور ہم نے انہیں دریا میں غرق کردیا، اس لئے کہ انہوں نے ہماری آیتوں کی (پے در پے) تکذیب کی تھی اور وہ ان سے (بالکل) غافل تھے،\qt@no{136}}%
\qt@newcmd\qurantrans@ur@mxci{اور ہم نے اس قوم (بنی اسرائیل) کو جو کمزور اور استحصال زدہ تھی اس سرزمین کے مشرق و مغرب (مصر اور شام) کا وارث بنا دیا جس میں ہم نے برکت رکھی تھی، اور (یوں) بنی اسرائیل کے حق میں آپ کے رب کا نیک وعدہ پورا ہوگیا اس وجہ سے کہ انہوں نے (فرعونی مظالم پر) صبر کیا تھا، اور ہم نے ان (عالیشان محلات) کو تباہ و برباد کردیا جو فرعون اور اس کی قوم نے بنا رکھے تھے اور ان چنائیوں (اور باغات) کو بھی جنہیں وہ بلندیوں پر چڑھاتے تھے،\qt@no{137}}%
\qt@newcmd\qurantrans@ur@mxcii{اور ہم نے بنی اسرائیل کو سمندر (یعنی بحرِ قلزم) کے پار اتارا تو وہ ایک ایسی قوم کے پاس جا پہنچے جو اپنے بتوں کے گرد (پرستش کے لئے) آسن مارے بیٹھے تھے، (بنی اسرائیل کے لوگ) کہنے لگے: اے موسٰی! ہمارے لئے بھی ایسا (ہی) معبود بنا دیں جیسے ان کے معبود ہیں، موسٰی (علیہ السلام) نے کہا: تم یقیناً بڑے جاہل لوگ ہو،\qt@no{138}}%
\qt@newcmd\qurantrans@ur@mxciii{بلاشبہ یہ لوگ جس چیز (کی پوجا) میں (پھنسے ہوئے) ہیں وہ ہلاک ہوجانے والی ہے اور جو کچھ وہ کر رہے ہیں وہ (بالکل) باطل ہے،\qt@no{139}}%
\qt@newcmd\qurantrans@ur@mxciv{موسیٰ علیہ السلام نے) کہا: کیا میں تمہارے لئے اللہ کے سوا کوئی اور معبود تلاش کروں، حالانکہ اسی (اللہ) نے تمہیں سارے جہانوں پر فضیلت بخشی ہے،\qt@no{140}}%
\qt@newcmd\qurantrans@ur@mxcv{اور (وہ وقت) یاد کرو جب ہم نے تم کو اہلِ فرعون سے نجات بخشی جو تمہیں بہت ہی سخت عذاب دیتے تھے، وہ تمہارے لڑکوں کو قتل کردیتے اور تمہاری لڑکیوں کو زندہ چھوڑ دیتے تھے، اور اس میں تمہارے رب کی طرف سے زبردست آزمائش تھی،\qt@no{141}}%
\qt@newcmd\qurantrans@ur@mxcvi{اور ہم نے موسٰی (علیہ السلام) سے تیس راتوں کا وعدہ فرمایا اور ہم نے اسے (مزید) دس (راتیں) ملا کر پورا کیا، سو ان کے رب کی (مقرر کردہ) میعاد چالیس راتوں میں پوری ہوگئی۔ اور موسٰی (علیہ السلام) نے اپنے بھائی ہارون (علیہ السلام) سے فرمایا: تم (اس دوران) میری قوم میں میرے جانشین رہنا اور (ان کی) اصلاح کرتے رہنا اور فساد کرنے والوں کی راہ پر نہ چلنا (یعنی انہیں اس راہ پر نہ چلنے دینا)،\qt@no{142}}%
\qt@newcmd\qurantrans@ur@mxcvii{اور جب موسٰی (علیہ السلام) ہمارے (مقرر کردہ) وقت پر حاضر ہوا اور اس کے رب نے اس سے کلام فرمایا تو (کلامِ ربانی کی لذت پا کر دیدار کا آرزو مند ہوا اور) عرض کرنے لگا: اے رب! مجھے (اپنا جلوہ) دکھا کہ میں تیرا دیدار کرلوں، ارشاد ہوا: تم مجھے (براہِ راست) ہرگز دیکھ نہ سکوگے مگر پہاڑ کی طرف نگاہ کرو پس اگر وہ اپنی جگہ ٹھہرا رہا تو عنقریب تم میرا جلوہ کرلوگے۔ پھر جب اس کے رب نے پہاڑ پر (اپنے حسن کا) جلوہ فرمایا تو (شدّتِ اَنوار سے) اسے ریزہ ریزہ کر دیا اور موسٰی (علیہ السلام) بے ہوش ہو کر گر پڑا۔ پھر جب اسے افاقہ ہوا تو عرض کیا: تیری ذات پاک ہے میں تیری بارگاہ میں توبہ کرتا ہوں اور میں سب سے پہلا ایمان لانے والا ہوں،\qt@no{143}}%
\qt@newcmd\qurantrans@ur@mxcviii{ارشاد ہوا: اے موسٰی! بیشک میں نے تمہیں لوگوں پر اپنے پیغامات اور اپنے کلام کے ذریعے برگزیدہ و منتخب فرما لیا۔ سو میں نے تمہیں جو کچھ عطا فرمایا ہے اسے تھام لو اور شکر گزاروں میں سے ہوجاؤ،\qt@no{144}}%
\qt@newcmd\qurantrans@ur@mxcix{اور ہم نے ان کے لئے (تورات کی) تختیوں میں ہر ایک چیز کی نصیحت اور ہر ایک چیز کی تفصیل لکھ دی (ہے)، تم اسے مضبوطی سے تھامے رکھو اور اپنی قوم کو (بھی) حکم دو کہ وہ اس کی بہترین باتوں کو اختیار کرلیں۔ میں عنقریب تمہیں نافرمانوں کا مقام دکھاؤں گا،\qt@no{145}}%
\qt@newcmd\qurantrans@ur@mc{میں اپنی آیتوں (کے سمجھنے اور قبول کرنے) سے ان لوگوں کو باز رکھوں گا جو زمین میں ناحق تکبر کرتے ہیں اور اگر وہ تمام نشانیاں دیکھ لیں (تب بھی) اس پر ایمان نہیں لائیں گے اور اگر وہ ہدایت کی راہ دیکھ لیں (پھر بھی) اسے (اپنا) راستہ نہیں بنائیں گے اور اگر وہ گمراہی کا راستہ دیکھ لیں (تو) اسے اپنی راہ کے طور پر اپنالیں گے، یہ اس وجہ سے کہ انہوں نے ہماری آیتوں کو جھٹلایا اور ان سے غافل بنے رہے،\qt@no{146}}%
\qt@newcmd\qurantrans@ur@mci{اور جن لوگوں نے ہماری آیتوں کو اور آخرت کی ملاقات کو جھٹلایا ان کے اعمال برباد ہوگئے۔ انہیں کیا بدلہ ملے گا مگر وہی جوکچھ وہ کیا کرتے تھے،\qt@no{147}}%
\qt@newcmd\qurantrans@ur@mcii{اور موسٰی (علیہ السلام) کی قوم نے ان کے (کوہِ طور پر جانے کے) بعد اپنے زیوروں سے ایک بچھڑا بنا لیا (جو) ایک جسم تھا، اس کی آواز گائے کی تھی، کیا انہوں نے یہ نہیں دیکھا کہ وہ نہ ان سے بات کرسکتا ہے اور نہ ہی انہیں راستہ دکھا سکتا ہے۔ انہوں نے اسی کو (معبود) بنا لیا اور وہ ظالم تھے،\qt@no{148}}%
\qt@newcmd\qurantrans@ur@mciii{اور جب وہ اپنے کئے پر شدید نادم ہوئے اور انہوں نے دیکھ لیا کہ وہ واقعی گمراہ ہوگئے ہیں (تو) کہنے لگے: اگر ہمارے رب نے ہم پر رحم نہ فرمایا اور ہمیں نہ بخشا تو ہم یقیناً نقصان اٹھانے والوں میں سے ہوجائیں گے،\qt@no{149}}%
\qt@newcmd\qurantrans@ur@mciv{اور جب موسٰی (علیہ السلام) اپنی قوم کی طرف نہایت غم و غصہ سے بھرے ہوئے پلٹے تو کہنے لگے کہ تم نے میرے (جانے کے) بعد میرے پیچھے بہت ہی برا کام کیا ہے، کیا تم نے اپنے رب کے حکم پر جلد بازی کی؟ اور (موسٰی علیہ السلام نے تورات کی) تختیاں نیچے رکھ دیں اور اپنے بھائی کے سر کو پکڑ کر اپنی طرف کھینچا (تو) ہارون (علیہ السلام) نے کہا: اے میری ماں کے بیٹے! بیشک اس قوم نے مجھے کمزور سمجھا اور قریب تھا کہ (میرے منع کرنے پر) مجھے قتل کر ڈالیں، سو آپ دشمنوں کو مجھ پر ہنسنے کا موقع نہ دیں اور مجھے ان ظالم لوگوں (کے زمرے) میں شامل نہ کریں،\qt@no{150}}%
\qt@newcmd\qurantrans@ur@mcv{موسٰی علیہ السلام نے) عرض کیا: اے میرے رب! مجھے اور میرے بھائی کو معاف فرما دے اور ہمیں اپنی رحمت (کے دامن) میں داخل فرما لے اور تو سب سے بڑھ کر رحم فرمانے والا ہے،\qt@no{151}}%
\qt@newcmd\qurantrans@ur@mcvi{بیشک جن لوگوں نے بچھڑے کو (معبود) بنا لیا ہے انہیں ان کے رب کی طرف سے غضب بھی پہنچے گا اور دنیوی زندگی میں ذلت بھی، اور ہم اسی طرح افترا پردازوں کو سزا دیتے ہیں،\qt@no{152}}%
\qt@newcmd\qurantrans@ur@mcvii{اور جن لوگوں نے برے کام کئے پھر اس کے بعد توبہ کرلی اور ایمان لے آئے (تو) بیشک آپ کا رب اس کے بعد بڑا ہی بخشنے والا مہربان ہے،\qt@no{153}}%
\qt@newcmd\qurantrans@ur@mcviii{اور جب موسٰی (علیہ السلام) کا غصہ تھم گیا تو انہوں نے تختیاں اٹھالیں اور ان (تختیوں) کی تحریر میں ہدایت اور ایسے لوگوں کے لئے رحمت (مذکور) تھی جو اپنے رب سے بہت ڈرتے ہیں،\qt@no{154}}%
\qt@newcmd\qurantrans@ur@mcix{اور موسٰی (علیہ السلام) نے اپنی قوم کے ستر مَردوں کو ہمارے مقرر کردہ وقت (پر ہمارے حضور معذرت کی پیشی) کے لئے چن لیا، پھر جب انہیں (قوم کو برائی سے منع نہ کرنے پر تادیباً) شدید زلزلہ نے آپکڑا تو (موسٰی علیہ السلام نے) عرض کیا: اے رب! اگر تو چاہتا تو اس سے پہلے ہی ان لوگوں کو اور مجھے ہلاک فرما دیتا، کیا تو ہمیں اس (خطا) کے سبب ہلاک فرمائے گا جو ہم میں سے بیوقوف لوگوں نے انجام دی ہے، یہ تو محض تیری آزمائش ہے، اس کے ذریعے تو جسے چاہتا ہے گمراہ فرماتا ہے اور جسے چاہتا ہے ہدایت فرماتا ہے۔ تو ہی ہمارا کارساز ہے، سو ُتو ہمیں بخش دے اور ہم پر رحم فرما اور تو سب سے بہتر بخشنے والا ہے،\qt@no{155}}%
\qt@newcmd\qurantrans@ur@mcx{اور تو ہمارے لئے اس دنیا (کی زندگی) میں (بھی) بھلائی لکھ دے اور آخرت میں (بھی) بیشک ہم تیری طرف تائب و راغب ہوچکے، ارشاد ہوا: میں اپنا عذاب جسے چاہتا ہوں اسے پہنچاتا ہوں اور میری رحمت ہر چیز پر وسعت رکھتی ہے، سو میں عنقریب اس (رحمت) کو ان لوگوں کے لئے لکھ دوں گا جو پرہیزگاری اختیار کرتے ہیں اور زکوٰۃ دیتے رہتے ہیں اور وہی لوگ ہی ہماری آیتوں پر ایمان رکھتے ہیں،\qt@no{156}}%
\qt@newcmd\qurantrans@ur@mcxi{یہ وہ لوگ ہیں) جو اس رسول (صلی اللہ علیہ وآلہ وسلم) کی پیروی کرتے ہیں جو اُمّی (لقب) نبی ہیں (یعنی دنیا میں کسی شخص سے پڑھے بغیر مِن جانبِ اللہ لوگوں کو اخبارِ غیب اورمعاش و معاد کے علوم و معارف بتاتے ہیں) جن (کے اوصاف و کمالات) کو وہ لوگ اپنے پاس تورات اور انجیل میں لکھا ہوا پاتے ہیں، جو انہیں اچھی باتوں کا حکم دیتے ہیں اور بری باتوں سے منع فرماتے ہیں اور ان کے لئے پاکیزہ چیزوں کو حلال کرتے ہیں اور ان پر پلید چیزوں کو حرام کرتے ہیں اور ان سے ان کے بارِگراں اور طوقِ (قیود) جو ان پر (نافرمانیوں کے باعث مسلّط) تھے، ساقط فرماتے (اور انہیں نعمتِ آزادی سے بہرہ یاب کرتے) ہیں۔ پس جو لوگ اس (برگزیدہ رسول صلی اللہ علیہ وآلہ وسلم) پر ایمان لائیں گے اور ان کی تعظیم و توقیر کریں گے اور ان (کے دین) کی مدد و نصرت کریں گے اور اس نورِ (قرآن) کی پیروی کریں گے جو ان کے ساتھ اتارا گیا ہے، وہی لوگ ہی فلاح پانے والے ہیں،\qt@no{157}}%
\qt@newcmd\qurantrans@ur@mcxii{آپ فرما دیں: اے لوگو! میں تم سب کی طرف اس اللہ کا رسول (بن کر آیا) ہوں جس کے لئے تمام آسمانوں اور زمین کی بادشاہت ہے، اس کے سوا کوئی معبود نہیں، وہی جلاتا اور مارتا ہے، سو تم اللہ اور اس کے رسول (صلی اللہ علیہ وآلہ وسلم) پر ایمان لاؤ جو (شانِ اُمیّت کا حامل) نبی ہے (یعنی اس نے اللہ کے سوا کسی سے کچھ نہیں پڑھا مگر جمیع خلق سے زیادہ جانتا ہے اور کفر و شرک کے معاشرے میں جوان ہوا مگر بطنِ مادر سے نکلے ہوئے بچے کی طرح معصوم اور پاکیزہ ہے) جو اللہ پر اور اس کے (سارے نازل کردہ) کلاموں پر ایمان رکھتا ہے اور تم انہی کی پیروی کرو تاکہ تم ہدایت پا سکو،\qt@no{158}}%
\qt@newcmd\qurantrans@ur@mcxiii{اور موسٰی (علیہ السلام) کی قوم میں سے ایک جماعت (ایسے لوگوں کی بھی) ہے جو حق کی راہ بتاتے ہیں اور اسی کے مطابق عدل (پر مبنی فیصلے) کرتے ہیں،\qt@no{159}}%
\qt@newcmd\qurantrans@ur@mcxiv{اور ہم نے انہیں گروہ در گروہ بارہ قبیلوں میں تقسیم کر دیا، اور ہم نے موسٰی (علیہ السلام) کے پاس (یہ) وحی بھیجی جب اس سے اس کی قوم نے پانی مانگا کہ اپنا عصا پتھر پر مارو، سو اس میں سے بارہ چشمے پھوٹ نکلے، پس ہر قبیلہ نے اپنا گھاٹ معلوم کرلیا، اور ہم نے ان پر اَبر کا سائبان تان دیا، اور ہم نے ان پر منّ و سلوٰی اتارا، (اور ان سے فرمایا:) جن پاکیزہ چیزوں کا رزق ہم نے تمہیں عطا کیا ہے اس میں سے کھاؤ، (مگر نافرمانی اور کفرانِ نعمت کر کے) انہوں نے ہم پر ظلم نہیں کیا بلکہ وہ اپنی ہی جانوں پر ظلم کر رہے تھے،\qt@no{160}}%
\qt@newcmd\qurantrans@ur@mcxv{اور (یاد کرو) جب ان سے فرمایا گیا کہ تم اس شہر (بیت المقدس یا اریحا) میں سکونت اختیار کرو اور تم وہاں سے جس طرح چاہو کھانا اور (زبان سے) کہتے جانا کہ (ہمارے گناہ) بخش دے اور (شہر کے) دروازے میں سجدہ کرتے ہوئے داخل ہونا (تو) ہم تمہاری تمام خطائیں بخش دیں گے، عنقریب ہم نیکو کاروں کو اور زیادہ عطا فرمائیں گے،\qt@no{161}}%
\qt@newcmd\qurantrans@ur@mcxvi{پھر ان میں سے ظالموں نے اس بات کو جو ان سے کہی گئی تھی، دوسری بات سے بدل ڈالا، سو ہم نے ان پر آسمان سے عذاب بھیجا اس وجہ سے کہ وہ ظلم کرتے تھے،\qt@no{162}}%
\qt@newcmd\qurantrans@ur@mcxvii{اور آپ ان سے اس بستی کا حال دریافت فرمائیں جو سمندر کے کنارے واقع تھی، جب وہ لوگ ہفتہ (کے دن کے احکام) میں حد سے تجاوز کرتے تھے (یہ اس وقت ہوا) جب (ان کے سامنے) ان کی مچھلیاں ان کے (تعظیم کردہ) ہفتہ کے دن کو پانی (کی سطح) پر ہر طرف سے خوب ظاہر ہونے لگیں اور (باقی) ہر دن جس کی وہ یومِ شنبہ کی طرح تعظیم نہیں کرتے تھے (مچھلیاں) ان کے پاس نہ آتیں، اس طرح ہم ان کی آزمائش کر رہے تھے بایں وجہ کہ وہ نافرمان تھے،\qt@no{163}}%
\qt@newcmd\qurantrans@ur@mcxviii{اور جب ان میں سے ایک گروہ نے (فریضۂ دعوت انجام دینے والوں سے) کہا کہ تم ایسے لوگوں کو نصیحت کیوں کر رہے ہو جنہیں اللہ ہلاک کرنے والا ہے یا جنہیں نہایت سخت عذاب دینے والا ہے؟ تو انہوں نے جواب دیا کہ تمہارے رب کے حضور (اپنی) معذرت پیش کرنے کے لئے اور اس لئے (بھی) کہ شاید وہ پرہیزگار بن جائیں،\qt@no{164}}%
\qt@newcmd\qurantrans@ur@mcxix{پھر جب وہ ان (سب) باتوں کو فراموش کر بیٹھے جن کی انہیں نصیحت کی گئی تھی (تو) ہم نے ان لوگوں کو نجات دے دی جو برائی سے منع کرتے تھے (یعنی نہی عنِ المنکر کا فریضہ ادا کرتے تھے) اور ہم نے (بقیہ سب) لوگوں کو جو (عملاً یا سکوتاً) ظلم کرتے تھے نہایت برے عذاب میں پکڑ لیا اس وجہ سے کہ وہ نافرمانی کر رہے تھے،\qt@no{165}}%
\qt@newcmd\qurantrans@ur@mcxx{پھر جب انہوں نے اس چیز (کے ترک کرنے کے حکم) سے سرکشی کی جس سے وہ روکے گئے تھے (تو) ہم نے انہیں حکم دیا کہ تم ذلیل و خوار بندر ہوجاؤ،\qt@no{166}}%
\qt@newcmd\qurantrans@ur@mcxxi{اور (وہ وقت بھی یاد کریں) جب آپ کے رب نے (یہود کو یہ) حکم سنایا کہ (اللہ) ان پر روزِ قیامت تک (کسی نہ کسی) ایسے شخص کو ضرور مسلّط کرتا رہے گا جو انہیں بری تکلیفیں پہنچاتا رہے۔ بیشک آپ کا رب جلد سزا دینے والا ہے، اور بیشک وہ بڑا بخشنے والا مہربان (بھی) ہے،\qt@no{167}}%
\qt@newcmd\qurantrans@ur@mcxxii{اور ہم نے انہیں زمین میں گروہ در گروہ تقسیم (اور منتشر) کر دیا، ان میں سے بعض نیکوکار بھی ہیں اور ان (ہی) میں سے بعض اس کے سوا (بدکار) بھی اور ہم نے ان کی آزمائش انعامات اور مشکلات (دونوں طریقوں) سے کی تاکہ وہ (اللہ کی طرف) رجوع کریں،\qt@no{168}}%
\qt@newcmd\qurantrans@ur@mcxxiii{پھر ان کے بعد ناخلف (ان کے) جانشین بنے جو کتاب کے وارث ہوئے، یہ (جانشین) اس کم تر (دنیا) کا مال و دولت (رشوت کے طور پر) لے لیتے ہیں اور کہتے ہیں: عنقریب ہمیں بخش دیا جائے گا، حالانکہ اسی طرح کا مال و متاع اور بھی ان کے پاس آجائے (تو) اسے بھی لے لیں، کیا ان سے کتابِ (الٰہی) کا یہ عہد نہیں لیا گیا تھا کہ وہ اللہ کے بارے میں حق (بات) کے سوا کچھ اور نہ کہیں گے؟ اور وہ (سب کچھ) پڑھ چکے تھے جو اس میں (لکھا) تھا؟ اور آخرت کا گھر ان لوگوں کے لئے بہتر ہے جو پرہیزگاری اختیار کرتے ہیں، کیا تم سمجھتے نہیں ہو،\qt@no{169}}%
\qt@newcmd\qurantrans@ur@mcxxiv{اور جو لوگ کتابِ (الٰہی) کو مضبوط پکڑے رہتے ہیں او ر نماز (پابندی سے) قائم رکھتے ہیں (تو) بیشک ہم اصلاح کرنے والوں کا اجر ضائع نہیں کرتے،\qt@no{170}}%
\qt@newcmd\qurantrans@ur@mcxxv{اور (وہ وقت یاد کیجئے) جب ہم نے ان کے اوپر پہاڑ کو (یوں) بلند کر دیا جیسا کہ وہ (ایک) سائبان ہو اور وہ (یہ) گمان کرنے لگے کہ ان پر گرنے والا ہے۔ (سو ہم نے ان سے فرمایا: ڈرو نہیں بلکہ) تم وہ (کتاب) مضبوطی سے (عملاً) تھامے رکھو جو ہم نے تمہیں عطا کی ہے اور ان (احکام) کو (خوب) یاد رکھو جو اس میں (مذکور) ہیں تاکہ تم (عذاب سے) بچ جاؤ،\qt@no{171}}%
\qt@newcmd\qurantrans@ur@mcxxvi{اور (یاد کیجئے!) جب آپ کے رب نے اولادِ آدم کی پشتوں سے ان کی نسل نکالی اور ان کو انہی کی جانوں پر گواہ بنایا (اور فرمایا:) کیا میں تمہارا رب نہیں ہوں؟ وہ (سب) بول اٹھے: کیوں نہیں! (تو ہی ہمارا رب ہے،) ہم گواہی دیتے ہیں تاکہ قیامت کے دن یہ (نہ) کہو کہ ہم اس عہد سے بے خبر تھے،\qt@no{172}}%
\qt@newcmd\qurantrans@ur@mcxxvii{یا (ایسا نہ ہو کہ) تم کہنے لگو کہ شرک تو محض ہمارے آباء و اجداد نے پہلے کیا تھا اور ہم تو ان کے بعد (ان کی) اولاد تھے (گویا ہم مجرم نہیں اصل مجرم وہ ہیں)، تو کیا تو ہمیں اس (گناہ) کی پاداش میں ہلاک فرمائے گا جو اہلِ باطل نے انجام دیا تھا،\qt@no{173}}%
\qt@newcmd\qurantrans@ur@mcxxviii{اور اسی طرح ہم آیتوں کو تفصیل سے بیان کرتے ہیں تاکہ وہ (حق کی طرف) رجوع کریں،\qt@no{174}}%
\qt@newcmd\qurantrans@ur@mcxxix{اور آپ انہیں اس شخص کا قصہ (بھی) سنا دیں جسے ہم نے اپنی نشانیاں دیں پھر وہ ان (کے علم و نصیحت) سے نکل گیا اور شیطان اس کے پیچھے لگ گیا تو وہ گمراہوں میں سے ہوگیا،\qt@no{175}}%
\qt@newcmd\qurantrans@ur@mcxxx{اور اگر ہم چاہتے تو اسے ان (آیتوں کے علم و عمل) کے ذریعے بلند فرما دیتے لیکن وہ (خود) زمینی دنیا کی (پستی کی) طرف راغب ہوگیا اور اپنی خواہش کا پیرو بن گیا، تو (اب) اس کی مثال اس کتے کی مثال جیسی ہے کہ اگر تو اس پر سختی کرے تو وہ زبان نکال دے یا تو اسے چھوڑ دے (تب بھی) زبان نکالے رہے۔ یہ ایسے لوگوں کی مثال ہے جنہوں نے ہماری آیتوں کو جھٹلایا، سو آپ یہ واقعات (لوگوں سے) بیان کریں تاکہ وہ غور و فکر کریں،\qt@no{176}}%
\qt@newcmd\qurantrans@ur@mcxxxi{مثال کے لحاظ سے وہ قوم بہت ہی بری ہے جنہوں نے ہماری آیتوں کو جھٹلایا اور (درحقیقت) وہ اپنی ہی جانوں پر ظلم کرتے رہے،\qt@no{177}}%
\qt@newcmd\qurantrans@ur@mcxxxii{جسے اللہ ہدایت فرماتا ہے پس وہی ہدایت پانے والا ہے، اور جسے وہ گمراہ ٹھہراتا ہے پس وہی لوگ نقصان اٹھانے والے ہیں،\qt@no{178}}%
\qt@newcmd\qurantrans@ur@mcxxxiii{اور بیشک ہم نے جہنم کے لئے جِنّوں اور انسانوں میں سے بہت سے (افراد) کو پیدا فرمایا وہ دل (و دماغ) رکھتے ہیں (مگر) وہ ان سے (حق کو) سمجھ نہیں سکتے اور وہ آنکھیں رکھتے ہیں (مگر) وہ ان سے (حق کو) دیکھ نہیں سکتے اور وہ کان (بھی) رکھتے ہیں (مگر) وہ ان سے (حق کو) سن نہیں سکتے، وہ لوگ چوپایوں کی طرح ہیں بلکہ (ان سے بھی) زیادہ گمراہ، وہی لوگ ہی غافل ہیں،\qt@no{179}}%
\qt@newcmd\qurantrans@ur@mcxxxiv{اور اللہ ہی کے لئے اچھے اچھے نام ہیں، سو اسے ان ناموں سے پکارا کرو اور ایسے لوگوں کو چھوڑ دو جو اس کے ناموں میں حق سے انحراف کرتے ہیں، عنقریب انہیں ان (اعمالِ بد) کی سزا دی جائے گی جن کا وہ ارتکاب کرتے ہیں،\qt@no{180}}%
\qt@newcmd\qurantrans@ur@mcxxxv{اور جنہیں ہم نے پیدا فرمایا ہے ان میں سے ایک جماعت (ایسے لوگوں کی بھی) ہے جو حق بات کی ہدایت کرتے ہیں اور اسی کے ساتھ عدل پر مبنی فیصلے کرتے ہیں،\qt@no{181}}%
\qt@newcmd\qurantrans@ur@mcxxxvi{اور جن لوگوں نے ہماری آیتوں کو جھٹلایا ہے ہم عنقریب انہیں آہستہ آہستہ ہلاکت کی طرف لے جائیں گے ایسے طریقے سے کہ انہیں خبر بھی نہیں ہوگی،\qt@no{182}}%
\qt@newcmd\qurantrans@ur@mcxxxvii{اور میں انہیں مہلت دے رہا ہوں، بیشک میری گرفت بڑی مضبوط ہے،\qt@no{183}}%
\qt@newcmd\qurantrans@ur@mcxxxviii{کیا انہوں نے غور نہیں کیا کہ انہیں (اپنی) صحبت کے شرف سے نوازنے والے (رسول صلی اللہ علیہ وآلہ وسلم) کو جنون سے کوئی علاقہ نہیں، وہ تو (نافرمانوں کو) صرف واضح ڈر سنانے والے ہیں،\qt@no{184}}%
\qt@newcmd\qurantrans@ur@mcxxxix{کیا انہوں نے آسمانوں اور زمین کی بادشاہت میں اور (علاوہ ان کے) جو کوئی چیز بھی اللہ نے پیدا فرمائی ہے (اس میں) نگاہ نہیں ڈالی؟ اور اس میں کہ کیا عجب ہے ان کی مدتِ (موت) قریب آچکی ہو، پھر اس کے بعد وہ کس بات پر ایمان لائیں گے،\qt@no{185}}%
\qt@newcmd\qurantrans@ur@mcxl{جسے اللہ گمراہ ٹھہرا دے تو اس کے لئے (کوئی) راہ دکھانے والا نہیں، اور وہ انہیں ان کی سرکشی میں چھوڑے رکھتا ہے تاکہ (مزید) بھٹکتے رہیں،\qt@no{186}}%
\qt@newcmd\qurantrans@ur@mcxli{یہ (کفار) آپ سے قیامت کی نسبت دریافت کرتے ہیں کہ اس کے قائم ہونے کا وقت کب ہے؟ فرما دیں کہ اس کا علم تو صرف میرے رب کے پاس ہے، اسے اپنے (مقررہ) وقت پر اس (اللہ) کے سوا کوئی ظاہر نہیں کرے گا۔ وہ آسمانوں اور زمین (کے رہنے والوں) پر (شدائد و مصائب کے خوف کے باعث) بوجھل (لگ رہی) ہے۔ وہ تم پر اچانک (حادثاتی طور پر) آجائے گی، یہ لوگ آپ سے (اس طرح) سوال کرتے ہیں گویا آپ اس کی کھوج میں لگے ہوئے ہیں، فرما دیں کہ اس کا علم تو محض اللہ کے پاس ہے لیکن اکثر لوگ (اس حقیقت کو) نہیں جانتے،\qt@no{187}}%
\qt@newcmd\qurantrans@ur@mcxlii{آپ (ان سے یہ بھی) فرما دیجئے کہ میں اپنی ذات کے لئے کسی نفع اور نقصان کا خود مالک نہیں ہوں مگر (یہ کہ) جس قدر اللہ نے چاہا، اور (اسی طرح بغیر عطاءِ الٰہی کے) اگر میں خود غیب کا علم رکھتا تو میں اَز خود بہت سی بھلائی (اور فتوحات) حاصل کرلیتا اور مجھے (کسی موقع پر) کوئی سختی (اور تکلیف بھی) نہ پہنچتی، میں تو (اپنے منصبِ رسالت کے باعث) فقط ڈر سنانے والا اور خوشخبری دینے والا ہوں ان لوگوں کو جو ایمان رکھتے ہیں٭، ٭ڈر اور خوشی کی خبریں بھی اُمورِ غیب میں سے ہیں جن پر اللہ تعالیٰ اپنے نبی صلی اللہ علیہ وآلہ وسلم کو مطلع فرماتا ہے کیونکہ مِن جانبِ اللہ ایسی اِطلاع علی الغیب کے بغیر نہ تو نبوت و رسالت متحقق ہوتی ہے اور نہ ہی یہ فریضہ ادا ہو سکتا ہے، اس لئے آپ صلی اللہ علیہ وآلہ وسلم کی شان میں فرمایا گیا ہے: وَمَا ھُوَ عَلَی الغَیبِ بِضَنِین ٍ(التکویر، ٨١: ٢٤) (اور یہ نیی (صلی اللہ علیہ وآلہ وسلم) غیب بتانے میں ہر گز بخیل نہیں)۔ اس قرآنی ارشاد کے مطابق غیب بتانے میں بخیل نہ ہونا تب ہی ممکن ہو سکتا ہے اگر باری تعالیٰ نے کمال فراوانی کے ساتھ حضور نبی اکرم صلی اللہ علیہ وآلہ وسلم کو علوم و اَخبارِ غیب پر مطلع فرمایا ہو، اگر سرے سے علمِ غیب عطا ہی نہ کیا گیا ہو تو حضور نبی اکرم صلی اللہ علیہ وآلہ وسلم کا غیب بتانا کیسا اور پھر اس پر بخیل نہ ہونے کا کیا مطلب؟ سو معلوم ہوا کہ حضور نبی اکرم صلی اللہ علیہ وآلہ وسلم کے مطلع علی الغیب ہونے کی قطعاً نفی نہیں بلکہ نفع و نقصان پر خود قادر و مالک اور بالذات عالم الغیب ہونے کی نفی ہے کیونکہ یہ شان صرف اللہ تعالیٰ کی ہے۔\qt@no{188}}%
\qt@newcmd\qurantrans@ur@mcxliii{اور وہی (اللہ) ہے جس نے تم کو ایک جان سے پیدا فرمایا اور اسی میں سے اس کا جوڑ بنایا تاکہ وہ اس سے سکون حاصل کرے، پھر جب مرد نے اس (عورت) کو ڈھانپ لیا تو وہ خفیف بوجھ کے ساتھ حاملہ ہوگئی، پھر وہ اس کے ساتھ چلتی پھرتی رہی، پھر جب وہ گراں بار ہوئی تو دونوں نے اپنے رب اللہ سے دعا کی کہ اگر تو ہمیں اچھا تندرست بچہ عطا فرما دے تو ہم ضرور شکر گزاروں میں سے ہوں گے،\qt@no{189}}%
\qt@newcmd\qurantrans@ur@mcxliv{پھر جب اس نے انہیں تندرست بچہ عطا فرما دیا تو دونوں اس (بچے) میں جو انہیں عطا فرمایا تھا اس کے لئے شریک ٹھہرانے لگے تو اللہ ان کے شریک بنانے سے بلند و برتر ہے،\qt@no{190}}%
\qt@newcmd\qurantrans@ur@mcxlv{کیا وہ ایسوں کو شریک بناتے ہیں جو کسی چیز کو پیدا نہیں کرسکتے اور وہ (خود) پیدا کئے گئے ہیں،\qt@no{191}}%
\qt@newcmd\qurantrans@ur@mcxlvi{اور نہ وہ ان (مشرکوں) کی مدد کرنے پر قدرت رکھتے ہیں اور نہ اپنے آپ ہی کی مدد کرسکتے ہیں،\qt@no{192}}%
\qt@newcmd\qurantrans@ur@mcxlvii{اور اگر تم ان کو (راہِ) ہدایت کی طرف بلاؤ تو تمہاری پیروی نہ کریں گے۔ تمہارے حق میں برابر ہے خواہ تم انہیں (حق و ہدایت کی طرف) بلاؤ یا تم خاموش رہو،\qt@no{193}}%
\qt@newcmd\qurantrans@ur@mcxlviii{بیشک جن (بتوں) کی تم اللہ کے سوا عبادت کرتے ہو وہ بھی تمہاری ہی طرح (اللہ کے) مملوک ہیں، پھر جب تم انہیں پکارو تو انہیں چاہئے کہ تمہیں جواب دیں اگر تم (انہیں معبود بنانے میں) سچے ہو،\qt@no{194}}%
\qt@newcmd\qurantrans@ur@mcxlix{کیا ان کے پاؤں ہیں جن سے وہ چل سکیں، یا ان کے ہاتھ ہیں جن سے وہ پکڑ سکیں، یا ان کی آنکھیں ہیں جن سے وہ دیکھ سکیں یا ان کے کان ہیں جن سے وہ سن سکیں؟ آپ فرما دیں: (اے کافرو!) تم اپنے (باطل) شریکوں کو (میری ہلاکت کے لئے) بلا لو پھر مجھ پر (اپنا) داؤ چلاؤ اور مجھے کوئی مہلت نہ دو،\qt@no{195}}%
\qt@newcmd\qurantrans@ur@mcl{بیشک میرا مددگار اللہ ہے جس نے کتاب نازل فرمائی ہے اور وہی صلحاء کی بھی نصرت و ولایت فرماتا ہے،\qt@no{196}}%
\qt@newcmd\qurantrans@ur@mcli{اور جن (بتوں) کو تم اس کے سوا پوجتے ہو وہ تمہاری مدد کرنے پر کوئی قدرت نہیں رکھتے اور نہ ہی اپنے آپ کی مدد کرسکتے ہیں،\qt@no{197}}%
\qt@newcmd\qurantrans@ur@mclii{اور اگر تم انہیں ہدایت کی طرف بلاؤ تو وہ سن (بھی) نہیں سکیں گے، اور آپ ان (بتوں) کو دیکھتے ہیں (وہ اس طرح تراشے گئے ہیں) کہ تمہاری طرف دیکھ رہے ہیں حالانکہ وہ (کچھ) نہیں دیکھتے،\qt@no{198}}%
\qt@newcmd\qurantrans@ur@mcliii{اے حبیبِ مکرّم!) آپ درگزر فرمانا اختیار کریں، اور بھلائی کا حکم دیتے رہیں اور جاہلوں سے کنارہ کشی اختیار کرلیں،\qt@no{199}}%
\qt@newcmd\qurantrans@ur@mcliv{اور (اے انسان!) اگر شیطان کی طرف سے کوئی وسوسہ (ان امور کے خلاف) تجھے ابھارے تو اللہ سے پناہ طلب کیا کر، بیشک وہ سننے والا جاننے والا ہے،\qt@no{200}}%
\qt@newcmd\qurantrans@ur@mclv{بیشک جن لوگوں نے پرہیزگاری اختیار کی ہے، جب انہیں شیطان کی طرف سے کوئی خیال بھی چھو لیتا ہے (تو وہ اللہ کے امر و نہی اور شیطان کے دجل و عداوت کو) یاد کرنے لگتے ہیں سو اسی وقت ان کی (بصیرت کی) آنکھیں کھل جاتی ہیں،\qt@no{201}}%
\qt@newcmd\qurantrans@ur@mclvi{اور (جو) ان شیطانوں کے بھائی (ہیں) وہ انہیں (اپنی وسوسہ اندازی کے ذریعہ) گمراہی میں ہی کھینچے رکھتے ہیں پھر اس (فتنہ پروری اور ہلاکت انگیزی) میں کوئی کوتاہی نہیں کرتے،\qt@no{202}}%
\qt@newcmd\qurantrans@ur@mclvii{اور جب آپ ان کے پاس کوئی نشانی نہیں لاتے (تو) وہ کہتے ہیں کہ آپ اسے اپنی طرف سے وضع کر کے کیوں نہیں لائے؟ فرما دیں: میں تو محض اس (حکم) کی پیروی کرتا ہوں جو میرے رب کی جانب سے میری طرف وحی کیا جاتا ہے یہ (قرآن) تمہارے رب کی طرف سے دلائل قطعیہ (کا مجموعہ) ہے اور ہدایت و رحمت ہے ان لوگوں کے لئے جو ایمان لاتے ہیں،\qt@no{203}}%
\qt@newcmd\qurantrans@ur@mclviii{اور جب قرآن پڑھا جائے تو اسے توجہ سے سنا کرو اور خاموش رہا کرو تاکہ تم پر رحم کیا جائے،\qt@no{204}}%
\qt@newcmd\qurantrans@ur@mclix{اور اپنے رب کا اپنے دل میں ذکر کیا کرو عاجزی و زاری اور خوف و خستگی سے اور میانہ آواز سے پکار کر بھی، صبح و شام (یادِ حق جاری رکھو) اور غافلوں میں سے نہ ہوجاؤ،\qt@no{205}}%
\qt@newcmd\qurantrans@ur@mclx{بیشک جو (ملائکہ مقربین) تمہارے رب کے حضور میں ہیں وہ (کبھی بھی) اس کی عبادت سے سرکشی نہیں کرتے اور (ہمہ وقت) اس کی تسبیح کرتے رہتے ہیں اور اس کی بارگاہ میں سجدہ ریز رہتے ہیں،\qt@no{206}}%
\qt@newcmd\qurantrans@ur@mclxi{\basmalahur (اے نبئ مکرّم!) آپ سے اَموالِ غنیمت کی نسبت سوال کرتے ہیں۔ فرما دیجئے: اَموالِ غنیمت کے مالک اللہ اور رسول (صلی اللہ علیہ وآلہ وسلم) ہیں۔ سو تم اللہ سے ڈرو اور اپنے باہمی معاملات کو درست رکھا کرو اور اللہ اور اس کے رسول (صلی اللہ علیہ وآلہ وسلم) کی اطاعت کیا کرو اگر تم ایمان والے ہو،\qt@no{1}}%
\qt@newcmd\qurantrans@ur@mclxii{ایمان والے (تو) صرف وہی لوگ ہیں کہ جب (ان کے سامنے) اللہ کا ذکر کیا جاتا ہے (تو) ان کے دل (اس کی عظمت و جلال کے تصور سے) خوفزدہ ہو جاتے ہیں اور جب ان پر اس کی آیات تلاوت کی جاتی ہیں تو وہ (کلامِ محبوب کی لذت انگیز اور حلاوت آفریں باتیں) ان کے ایمان میں زیادتی کر دیتی ہیں اور وہ (ہر حال میں) اپنے رب پر توکل (قائم) رکھتے ہیں (اور کسی غیر کی طرف نہیں تکتے)،\qt@no{2}}%
\qt@newcmd\qurantrans@ur@mclxiii{یہ) وہ لوگ ہیں جو نماز قائم رکھتے ہیں اور جو کچھ ہم نے انہیں عطا کیا ہے اس میں سے (اس کی راہ میں) خرچ کرتے رہتے ہیں،\qt@no{3}}%
\qt@newcmd\qurantrans@ur@mclxiv{حقیقت میں) یہی لوگ سچے مومن ہیں، ان کے لئے ان کے رب کی بارگاہ میں (بڑے) درجات ہیں اور مغفرت اور بلند درجہ رزق ہے،\qt@no{4}}%
\qt@newcmd\qurantrans@ur@mclxv{اے حبیب!) جس طرح آپ کا رب آپ کو آپ کے گھر سے حق کے (عظیم مقصد) کے ساتھ (جہاد کے لئے) باہر نکال لایا حالانکہ مسلمانوں کا ایک گروہ (اس پر) ناخوش تھا،\qt@no{5}}%
\qt@newcmd\qurantrans@ur@mclxvi{وہ آپ سے اَمرِ حق میں (اس بشارت کے) ظاہر ہوجانے کے بعد بھی جھگڑنے لگے (کہ اللہ کی نصرت آئے گی اور لشکرِ محمدی صلی اللہ علیہ وآلہ وسلم کو فتح نصیب ہوگی) گویا وہ موت کی طرف ہانکے جا رہے ہیں اور وہ (موت کو آنکھوں سے) دیکھ رہے ہیں،\qt@no{6}}%
\qt@newcmd\qurantrans@ur@mclxvii{اور (وہ وقت یاد کرو) جب اللہ نے تم سے (کفارِ مکہ کے) دو گروہوں میں سے ایک پر غلبہ و فتح کا وعدہ فرمایا تھا کہ وہ یقیناً تمہارے لئے ہے اور تم یہ چاہتے تھے کہ غیر مسلح (کمزور گروہ) تمہارے ہاتھ آجائے اور اللہ یہ چاہتا تھا کہ اپنے کلام سے حق کو حق ثابت فرما دے اور (دشمنوں کے بڑے مسلح لشکر پر مسلمانوں کی فتح یابی کی صورت میں) کافروں کی (قوت اور شان و شوکت کے) جڑ کاٹ دے،\qt@no{7}}%
\qt@newcmd\qurantrans@ur@mclxviii{تاکہ (معرکۂ بدر اس عظیم کامیابی کے ذریعے) حق کو حق ثابت کر دے اور باطل کو باطل کر دے اگرچہ مجرم لوگ (معرکۂ حق و باطل کی اس نتیجہ خیزی کو) ناپسند ہی کرتے رہیں،\qt@no{8}}%
\qt@newcmd\qurantrans@ur@mclxix{وہ وقت یاد کرو) جب تم اپنے رب سے (مدد کے لئے) فریاد کر رہے تھے تو اس نے تمہاری فریاد قبول فرمالی (اور فرمایا) کہ میں ایک ہزار پے در پے آنے والے فرشتوں کے ذریعے تمہاری مدد کرنے والا ہوں،\qt@no{9}}%
\qt@newcmd\qurantrans@ur@mclxx{اور اس (مدد کی صورت) کو اللہ نے محض بشارت بنایا (تھا) اور (یہ) اس لئے کہ اس سے تمہارے دل مطمئن ہو جائیں اور (حقیقت میں تو) اللہ کی بارگاہ سے مدد کے سوا کوئی (اور) مدد نہیں، بیشک اللہ (ہی) غالب حکمت والا ہے،\qt@no{10}}%
\qt@newcmd\qurantrans@ur@mclxxi{جب اس نے اپنی طرف سے (تمہیں) راحت و سکون (فراہم کرنے) کے لئے تم پر غنودگی طاری فرما دی اور تم پر آسمان سے پانی اتارا تاکہ اس کے ذریعے تمہیں (ظاہری و باطنی) طہارت عطا فرما دے اور تم سے شیطان (کے باطل وسوسوں) کی نجاست کو دور کردے اور تمہارے دلوں کو (قوتِ یقین) سے مضبوط کر دے اور اس سے تمہارے قدم (خوب) جما دے،\qt@no{11}}%
\qt@newcmd\qurantrans@ur@mclxxii{اے حبیبِ مکرم! اپنے اعزاز کا وہ منظر بھی یاد کیجئے) جب آپ کے رب نے فرشتوں کو پیغام بھیجا کہ (اَصحابِ رسول کی مدد کے لئے) میں (بھی) تمہارے ساتھ ہوں، سو تم (بشارت و نصرت کے ذریعے) ایمان والوں کو ثابت قدم رکھو، میں ابھی کافروں کے دلوں میں (لشکرِ محمدی صلی اللہ علیہ وآلہ وسلم کا) رعب و ہیبت ڈالے دیتا ہوں سو تم (کافروں کی) گردنوں کے اوپر سے ضرب لگانا اور ان کے ایک ایک جوڑ کو توڑ دینا،\qt@no{12}}%
\qt@newcmd\qurantrans@ur@mclxxiii{یہ اس لئے کہ انہوں نے اللہ اور اس کے رسول (صلی اللہ علیہ وآلہ وسلم) کی مخالفت کی، اور جو شخص اللہ اور اس کے رسول (صلی اللہ علیہ وآلہ وسلم) کی مخالفت کرے تو بیشک اللہ (اسے) سخت عذاب دینے والا ہے،\qt@no{13}}%
\qt@newcmd\qurantrans@ur@mclxxiv{یہ (عذابِ دنیا) ہے سو تم اسے (تو) چکھ لو اور بیشک کافروں کے لئے (آخرت میں) دوزخ کا (دوسرا) عذاب (بھی) ہے،\qt@no{14}}%
\qt@newcmd\qurantrans@ur@mclxxv{اے ایمان والو! جب تم (میدانِ جنگ میں) کافروں سے مقابلہ کرو (خواہ وہ) لشکرِ گراں ہو پھر بھی انہیں پیٹھ مت دکھانا،\qt@no{15}}%
\qt@newcmd\qurantrans@ur@mclxxvi{اور جو شخص اس دن ان سے پیٹھ پھیرے گا، سوائے اس کے جو جنگ (ہی) کے لئے کوئی داؤ چل رہا ہو یا اپنے (ہی) کسی لشکر سے (تعاون کے لئے) ملنا چاہتا ہو، تو واقعتاً وہ اللہ کے غضب کے ساتھ پلٹا اور اس کا ٹھکانا دوزخ ہے، اور وہ (بہت ہی) برا ٹھکانا ہے،\qt@no{16}}%
\qt@newcmd\qurantrans@ur@mclxxvii{اے سپاہیانِ لشکرِ اسلام!) ان کافروں کو تم نے قتل نہیں کیا بلکہ اللہ نے انہیں قتل کر دیا، اور (اے حبیبِ محتشم!) جب آپ نے (ان پر سنگ ریزے) مارے تھے (وہ) آپ نے نہیں مارے تھے بلکہ (وہ تو) اللہ نے مارے تھے، اور یہ (اس لئے) کہ وہ اہلِ ایمان کو اپنی طرف سے اچھے انعامات سے نوازے، بیشک اللہ خوب سننے والا جاننے والا ہے،\qt@no{17}}%
\qt@newcmd\qurantrans@ur@mclxxviii{یہ (تو ایک لطف و احسان) ہے اور (دوسرا) یہ کہ اللہ کافروں کے مکر و فریب کو کمزور کرنے والا ہے،\qt@no{18}}%
\qt@newcmd\qurantrans@ur@mclxxix{اے کافرو!) اگر تم نے فیصلہ کن فتح مانگی تھی تو یقیناً تمہارے پاس (حق کی) فتح آچکی اور اگر تم (اب بھی) باز آجاؤ تو یہ تمہارے حق میں بہتر ہے، اور اگر تم پھر یہی (شرارت) کرو گے (تو) ہم (بھی) پھر یہی (سزا) دیں گے اور تمہارا لشکر تمہیں ہرگز کفایت نہ کرسکے گا اگرچہ کتنا ہی زیادہ ہو اور بیشک اللہ مومنوں کے ساتھ ہے،\qt@no{19}}%
\qt@newcmd\qurantrans@ur@mclxxx{اے ایمان والو! تم اللہ کی اور اس کے رسول (صلی اللہ علیہ وآلہ وسلم) کی اطاعت کرو اور اس سے روگردانی مت کرو حالانکہ تم سن رہے ہو،\qt@no{20}}%
\qt@newcmd\qurantrans@ur@mclxxxi{اور ان لوگوں کی طرح مت ہو جانا جنہوں نے (دھوکہ دہی کے طور پر) کہا: ہم نے سن لیا، حالانکہ وہ نہیں سنتے،\qt@no{21}}%
\qt@newcmd\qurantrans@ur@mclxxxii{بیشک اللہ کے نزدیک جانداروں میں سب سے بدتر وہی بہرے، گونگے ہیں جو (نہ حق سنتے ہیں، نہ حق کہتے ہیں اور حق کو حق) سمجھتے بھی نہیں ہیں،\qt@no{22}}%
\qt@newcmd\qurantrans@ur@mclxxxiii{اور اگر اللہ ان میں کچھ بھی خیر (کی طرف رغبت) جانتا تو انہیں (ضرور) سنا دیتا، اور (ان کی حالت یہ ہے کہ) اگر وہ انہیں (حق) سنا دے تو وہ (پھر بھی) روگردانی کر لیں اور وہ (حق سے) گریز ہی کرنے والے ہیں،\qt@no{23}}%
\qt@newcmd\qurantrans@ur@mclxxxiv{اے ایمان والو! جب (بھی) رسول (صلی اللہ علیہ وآلہ وسلم) تمہیں کسی کام کے لئے بلائیں جو تمہیں (جاودانی) زندگی عطا کرتا ہے تو اللہ اور رسول (صلی اللہ علیہ وآلہ وسلم) کو فرمانبرداری کے ساتھ جواب دیتے ہوئے (فوراً) حاضر ہو جایا کرو، اور جان لو کہ اللہ آدمی اور اس کے قلب کے درمیان (شانِ قربتِ خاصہ کے ساتھ) حائل ہوتا ہے اور یہ کہ تم سب (بالآخر) اسی کی طرف جمع کئے جاؤ گے،\qt@no{24}}%
\qt@newcmd\qurantrans@ur@mclxxxv{اور اس فتنہ سے ڈرو جو خاص طور پر صرف ان لوگوں ہی کو نہیں پہنچے گا جو تم میں سے ظالم ہیں (بلکہ اس ظلم کا ساتھ دینے والے اور اس پر خاموش رہنے والے بھی انہی میں شریک کر لئے جائیں گے)، اور جان لو کہ اللہ عذاب میں سختی فرمانے والا ہے،\qt@no{25}}%
\qt@newcmd\qurantrans@ur@mclxxxvi{اور (وہ وقت یاد کرو) جب تم (مکی زندگی میں عدداً) تھوڑے (یعنی اَقلیّت میں) تھے ملک میں دبے ہوئے تھے (یعنی معاشی طور پر کمزور اور استحصال زدہ تھے) تم اس بات سے (بھی) خوفزدہ رہتے تھے کہ (طاقتور) لوگ تمہیں اچک لیں گے (یعنی سماجی طور پر بھی تمہیں آزادی اور تحفظ حاصل نہ تھا) پس (ہجرتِ مدینہ کے بعد) اس (اللہ) نے تمہیں (آزاد اور محفوظ) ٹھکانا عطا فرما دیا اور (اسلامی حکومت و اقتدار کی صورت میں) تمہیں اپنی مدد سے قوت بخش دی اور (مواخات، اَموالِ غنیمت اور آزاد معیشت کے ذریعے) تمہیں پاکیزہ چیزوں سے روزی عطا فرما دی تاکہ تم اللہ کی بھرپور بندگی کے ذریعے اس کا) شکر بجا لا سکو،\qt@no{26}}%
\qt@newcmd\qurantrans@ur@mclxxxvii{اے ایمان والو! تم اللہ اور رسول (صلی اللہ علیہ وآلہ وسلم) سے (ان کے حقوق کی ادائیگی میں) خیانت نہ کیا کرو اور نہ آپس کی امانتوں میں خیانت کیا کرو حالانکہ تم (سب حقیقت) جانتے ہو،\qt@no{27}}%
\qt@newcmd\qurantrans@ur@mclxxxviii{اور جان لو کہ تمہارے اموال اور تمہاری اولاد تو بس فتنہ ہی ہیں اور یہ کہ اللہ ہی کے پاس اجرِ عظیم ہے،\qt@no{28}}%
\qt@newcmd\qurantrans@ur@mclxxxix{اے ایمان والو! اگر تم اللہ کا تقوٰی اختیار کرو گے (تو) وہ تمہارے لئے حق و باطل میں فرق کرنے والی حجت (و ہدایت) مقرر فرما دے گا اور تمہارے (دامن) سے تمہارے گناہوں کو مٹا دے گا اور تمہاری مغفرت فرما دے گا، اور اللہ بڑے فضل والا ہے،\qt@no{29}}%
\qt@newcmd\qurantrans@ur@mcxc{اور جب کافر لوگ آپ کے خلاف خفیہ سازشیں کر رہے تھے کہ وہ آپ کو قید کر دیں یا آپ کو قتل کر ڈالیں یا آپ کو (وطن سے) نکال دیں، اور (اِدھر) وہ سازشی منصوبے بنا رہے تھے اور (اُدھر) اللہ (ان کے مکر کے ردّ کے لئے اپنی) تدبیر فرما رہا تھا، اور اللہ سب سے بہتر مخفی تدبیر فرمانے والا ہے،\qt@no{30}}%
\qt@newcmd\qurantrans@ur@mcxci{اور جب ان پر ہماری آیتیں پڑھی جاتی ہیں (تو) وہ کہتے ہیں: بیشک ہم نے سن لیا اگر ہم چاہیں تو ہم بھی اس (کلام) کے مثل کہہ سکتے ہیں یہ تو اگلوں کی (خیالی) داستانوں کے سوا (کچھ بھی) نہیں ہے،\qt@no{31}}%
\qt@newcmd\qurantrans@ur@mcxcii{اور جب انہوں نے (طعناً) کہا: اے اللہ! اگر یہی (قرآن) تیری طرف سے حق ہے تو (اس کی نافرمانی کے باعث) ہم پر آسمان سے پتھر برسا دے یا ہم پر کوئی دردناک عذاب بھیج دے،\qt@no{32}}%
\qt@newcmd\qurantrans@ur@mcxciii{اور (درحقیقت بات یہ ہے کہ) اللہ کو یہ شان نہیں دیتا کہ ان پر عذاب فرمائے درآنحالیکہ (اے حبیبِ مکرّم!) آپ بھی ان میں (موجود) ہوں، اور نہ ہی اللہ ایسی حالت میں ان پر عذاب فرمانے والا ہے کہ وہ (اس سے) مغفرت طلب کر رہے ہوں،\qt@no{33}}%
\qt@newcmd\qurantrans@ur@mcxciv{آپ کی ہجرتِ مدینہ کے بعد مکہ کے) ان (کافروں) کے لئے اور کیا وجہ ہوسکتی ہے کہ اللہ انہیں (اب) عذاب نہ دے حالانکہ وہ (لوگوں کو) مسجدِ حرام (یعنی کعبۃ اللہ) سے روکتے ہیں اور وہ اس کے ولی (یا متّولی) ہونے کے اہل بھی نہیں، اس کے اولیاء (یعنی دوست) تو صرف پرہیزگار لوگ ہوتے ہیں مگر ان میں سے اکثر (اس حقیقت کو) جانتے ہی نہیں،\qt@no{34}}%
\qt@newcmd\qurantrans@ur@mcxcv{اور بیت اللہ (یعنی خانہ کعبہ) کے پاس ان کی (نام نہاد) نماز سیٹیاں اور تالیاں بجانے کے سوا کچھ بھی نہیں ہے، سو تم عذاب (کا مزہ) چکھو اس وجہ سے کہ تم کفر کیا کرتے تھے،\qt@no{35}}%
\qt@newcmd\qurantrans@ur@mcxcvi{بیشک کافر لوگ اپنا مال و دولت (اس لئے) خرچ کرتے ہیں کہ (اس کے اثر سے) وہ (لوگوں کو) اللہ (کے دین) کی راہ سے روکیں، سو ابھی وہ اسے خرچ کرتے رہیں گے پھر (یہ خرچ کرنا) ان کے حق میں پچھتاوا (یعنی حسرت و ندامت) بن جائے گا پھر وہ (گرفتِ الٰہی کے ذریعے) مغلوب کر دیئے جائیں گے، اور جن لوگوں نے کفر اپنا لیا ہے وہ دوزخ کی طرف ہانکے جائیں گے،\qt@no{36}}%
\qt@newcmd\qurantrans@ur@mcxcvii{تاکہ اللہ (تعالیٰ) ناپاک کو پاکیزہ سے جدا فرما دے اور ناپاک (یعنی نجاست بھرے کرداروں) کو ایک دوسرے کے اوپر تلے رکھ دے پھر سب کو اکٹھا ڈھیر بنا دے گا پھر اس (ڈھیر) کو دوزخ میں ڈال دے گا، یہی لوگ خسارہ اٹھانے والے ہیں،\qt@no{37}}%
\qt@newcmd\qurantrans@ur@mcxcviii{آپ کفر کرنے والوں سے فرما دیں: اگر وہ (اپنے کافرانہ اَفعال سے) باز آجائیں تو ان کے وہ (گناہ) بخش دیئے جائیں گے جو پہلے گزر چکے ہیں، اور اگر وہ پھر وہی کچھ کریں گے تو یقیناً اگلوں (کے عذاب در عذاب) کا طریقہ گزر چکا ہے (ان کے ساتھ بھی وہی کچھ ہوگا)،\qt@no{38}}%
\qt@newcmd\qurantrans@ur@mcxcix{اور (اے اہلِ حق!) تم ان (کفر و طاغوت کے سرغنوں) کے ساتھ (انقلابی) جنگ کرتے رہو، یہاں تک کہ (دین دشمنی کا) کوئی فتنہ (باقی) نہ رہ جائے اور سب دین (یعنی نظامِ بندگی و زندگی) اللہ ہی کا ہو جائے، پھر اگر وہ باز آجائیں تو بیشک اللہ اس (عمل) کو جو وہ انجام دے رہے ہیں، خوب دیکھ رہا ہے،\qt@no{39}}%
\qt@newcmd\qurantrans@ur@mcc{اور اگر انہوں نے (اطاعتِ حق سے) روگردانی کی تو جان لو کہ بیشک اللہ ہی تمہارا مولیٰ (یعنی حمایتی) ہے، (وہی) بہتر حمایتی اور بہتر مددگار ہے،\qt@no{40}}%
\qt@newcmd\qurantrans@ur@mcci{اور جان لو کہ جو کچھ مالِ غنیمت تم نے پایا ہو تو اس کا پانچواں حصہ اللہ کے لئے اور رسول (صلی اللہ علیہ وآلہ وسلم) کے لئے اور (رسول صلی اللہ علیہ وآلہ وسلم کے) قرابت داروں کے لئے (ہے) اور یتیموں اور محتاجوں اور مسافروں کے لئے ہے۔ اگر تم اللہ پر اور اس (وحی) پر ایمان لائے ہو جو ہم نے اپنے (برگزیدہ) بندے پر (حق و باطل کے درمیان) فیصلے کے دن نازل فرمائی وہ دن (جب میدانِ بدر میں مومنوں اور کافروں کے) دونوں لشکر باہم مقابل ہوئے تھے، اور اللہ ہر چیز پر قادر ہے،\qt@no{41}}%
\qt@newcmd\qurantrans@ur@mccii{جب تم (مدینہ کی جانب) وادی کے قریبی کنارے پر تھے اور وہ (کفّار دوسری جانب) دور والے کنارے پر تھے اور (تجارتی) قافلہ تم سے نیچے تھا، اور اگر تم آپس میں (جنگ کے لئے) کوئی وعدہ کر لیتے تو ضرور (اپنے) وعدہ سے مختلف (وقتوں میں) پہنچتے لیکن (اللہ نے تمہیں بغیر وعدہ ایک ہی وقت پر جمع فرما دیا) یہ اس لئے (ہوا) کہ اللہ اس کام کو پورا فرما دے جو ہو کر رہنے والا تھا تاکہ جس شخص کو مرنا ہے وہ حجت (تمام ہونے) سے مرے اور جسے جینا ہے وہ حجت (تمام ہونے) سے جئے (یعنی ہر کسی کے سامنے اسلام اور رسول برحق صلی اللہ علیہ وآلہ وسلم کی صداقت پر حجت قائم ہو جائے)، اور بیشک اللہ خوب سننے والا جاننے والا ہے،\qt@no{42}}%
\qt@newcmd\qurantrans@ur@mcciii{وہ واقعہ یاد دلائیے) جب آپ کو اللہ نے آپ کے خواب میں ان کافروں (کے لشکر) کو تھوڑ ا کر کے دکھایا تھا اور اگر (اللہ) آپ کو وہ زیادہ کر کے دکھاتا تو (اے مسلمانو!) تم ہمت ہار جاتے اور تم یقیناً اس (جنگ کے) معاملے میں باہم جھگڑنے لگتے لیکن اللہ نے (مسلمانوں کو بزدلی اور باہمی نزاع سے) بچا لیا۔ بیشک وہ سینوں کی (چھپی) باتوں کو خوب جاننے والا ہے،\qt@no{43}}%
\qt@newcmd\qurantrans@ur@mcciv{اور (وہ منظر بھی انہیں یاد دلائیے) جب اس نے ان کافروں (کی فوج) کو باہم مقابلہ کے وقت (بھی محض) تمہاری آنکھوں میں تمہیں تھوڑا کر کے دکھایا اور تمہیں ان کی آنکھوں میں تھوڑا دکھلایا (تاکہ دونوں لشکر لڑائی میں مستعد رہیں) یہ اس لئے کہ اللہ اس (بھر پور جنگ کے نتیجے میں کفار کی شکستِ فاش کے) امر کو پورا کر دے جو (عند اللہ) مقرر ہو چکا تھا، اور (بالآخر) اللہ ہی کی طرف تمام کام لوٹائے جاتے ہیں،\qt@no{44}}%
\qt@newcmd\qurantrans@ur@mccv{اے ایمان والو! جب (دشمن کی) کسی فوج سے تمہارا مقابلہ ہو تو ثابت قدم رہا کرو اور اللہ کو کثرت سے یاد کیا کرو تاکہ تم فلاح پاجاؤ،\qt@no{45}}%
\qt@newcmd\qurantrans@ur@mccvi{اور اللہ اور اس کے رسول (صلی اللہ علیہ وآلہ وسلم) کی اطاعت کرو اور آپس میں جھگڑا مت کرو ورنہ (متفرق اور کمزور ہو کر) بزدل ہو جاؤ گے اور (دشمنوں کے سامنے) تمہاری ہوا (یعنی قوت) اکھڑ جائے گی اور صبر کرو، بیشک اللہ صبر کرنے والوں کے ساتھ ہے،\qt@no{46}}%
\qt@newcmd\qurantrans@ur@mccvii{اور ایسے لوگوں کی طرح نہ ہو جاؤ جو اپنے گھروں سے اِتراتے ہوئے اور لوگوں کو دکھلاتے ہوئے نکلے تھے اور (جو لوگوں کو) اللہ کی راہ سے روکتے تھے، اور اللہ ان کاموں کو جو وہ کر رہے ہیں (اپنے علم و قدرت کے ساتھ) احاطہ کئے ہوئے ہے،\qt@no{47}}%
\qt@newcmd\qurantrans@ur@mccviii{اور جب شیطان نے ان (کافروں) کے لئے ان کے اَعمال خوش نما کر دکھائے اور اس نے (ان سے) کہا: آج لوگوں میں سے کوئی تم پر غالب نہیں (ہو سکتا) اور بیشک میں تمہیں پناہ دینے والا (مددگار) ہوں۔ پھر جب دونوں فوجوں نے ایک دوسرے کو (مقابل) دیکھ لیا تو وہ الٹے پاؤں بھاگ گیا اور کہنے لگا: بیشک میں تم سے بے زار ہوں، یقیناً میں وہ (کچھ) دیکھ رہا ہوں جو تم نہیں دیکھتے، بیشک میں اللہ سے ڈرتا ہوں، اور اللہ سخت عذاب دینے والا ہے،\qt@no{48}}%
\qt@newcmd\qurantrans@ur@mccix{اور (وہ وقت بھی یاد کرو) جب منافقین اور وہ لوگ جن کے دل میں (کفر کی) بیماری ہے کہہ رہے تھے کہ ان (مسلمانوں) کو ان کے دین نے بڑا مغرور کر رکھا ہے، (جبکہ حقیقتِ حال یہ ہے کہ) جو کوئی اللہ پر توکل کرتا ہے تو (اللہ اس کے جملہ امور کا کفیل ہو جاتا ہے)، بیشک اللہ بہت غالب بڑی حکمت والا ہے،\qt@no{49}}%
\qt@newcmd\qurantrans@ur@mccx{اور اگر آپ (وہ منظر) دیکھیں (تو بڑا تعجب کریں) جب فرشتے کافروں کی جان قبض کرتے ہیں وہ ان کے چہروں اور ان کی پشتوں پر (ہتھوڑے) مارتے جاتے ہیں اور (کہتے ہیں کہ دوزخ کی) آگ کا عذاب چکھ لو،\qt@no{50}}%
\qt@newcmd\qurantrans@ur@mccxi{یہ (عذاب) ان (اعمالِ بد) کے بدلہ میں ہے جو تمہارے ہاتھوں نے آگے بھیجے اور اللہ ہرگز بندوں پر ظلم فرمانے والا نہیں،\qt@no{51}}%
\qt@newcmd\qurantrans@ur@mccxii{ان کافروں کا حال بھی) قومِ فرعون اور ان سے پہلے کے لوگوں کے حال کی مانند ہے۔ انہوں نے (بھی) اللہ کی آیات کا انکار کیا تھا، سو اللہ نے انہیں ان کے گناہوں کے باعث (عذاب میں) پکڑ لیا۔ بیشک اللہ قوت والا سخت عذاب دینے والا ہے،\qt@no{52}}%
\qt@newcmd\qurantrans@ur@mccxiii{یہ (عذاب) اس وجہ سے ہے کہ اللہ کسی نعمت کو ہرگز بدلنے والا نہیں جو اس نے کسی قوم پر اَرزانی فرمائی ہو یہاں تک کہ وہ لوگ اَز خود اپنی حالتِ نعمت کو بدل دیں (یعنی کفرانِ نعمت اور معصیت و نافرمانی کے مرتکب ہوں اور پھر ان میں احساسِ زیاں بھی باقی نہ رہے تب وہ قوم ہلاکت و بربادی کی زد میں آجاتی ہے)، بیشک اللہ خوب سننے والا جاننے والا ہے،\qt@no{53}}%
\qt@newcmd\qurantrans@ur@mccxiv{یہ (عذاب بھی) قومِ فرعون اور ان سے پہلے کے لوگوں کے دستور کی مانند ہے، انہوں نے (بھی) اپنے رب کی نشانیوں کو جھٹلایا تھا سو ہم نے ان کے گناہوں کے باعث انہیں ہلاک کر ڈالا اور ہم نے فرعون والوں کو (دریا میں) غرق کر دیا اور وہ سب کے سب ظالم تھے،\qt@no{54}}%
\qt@newcmd\qurantrans@ur@mccxv{بیشک اللہ کے نزدیک سب جانوروں سے (بھی) بدتر وہ لوگ ہیں جنہوں نے کفر کیا پھر وہ ایمان نہیں لاتے،\qt@no{55}}%
\qt@newcmd\qurantrans@ur@mccxvi{یہ (وہ) لوگ ہیں جن سے آپ نے (بارہا) عہد لیا پھر وہ ہر بار اپنا عہد توڑ ڈالتے ہیں اور وہ (اللہ سے) نہیں ڈرتے،\qt@no{56}}%
\qt@newcmd\qurantrans@ur@mccxvii{سو اگر آپ انہیں (میدانِ) جنگ میں پالیں تو ان کے عبرت ناک قتل کے ذریعے ان کے پچھلوں کو (بھی) بھگا دیں تاکہ انہیں نصیحت حاصل ہو،\qt@no{57}}%
\qt@newcmd\qurantrans@ur@mccxviii{اور اگر آپ کو کسی قوم سے خیانت کا اندیشہ ہو تو ان کا عہد ان کی طرف برابری کی بنیاد پر پھینک دیں۔ بیشک اللہ دغابازوں کو پسند نہیں کرتا،\qt@no{58}}%
\qt@newcmd\qurantrans@ur@mccxix{اور کافر لوگ اس گمان میں ہرگز نہ رہیں کہ وہ (بچ کر) نکل گئے۔ بیشک وہ (ہمیں) عاجز نہیں کر سکتے،\qt@no{59}}%
\qt@newcmd\qurantrans@ur@mccxx{اور (اے مسلمانو!) ان کے (مقابلے کے) لئے تم سے جس قدر ہو سکے (ہتھیاروں اور آلاتِ جنگ کی) قوت مہیا کر رکھو اور بندھے ہوئے گھوڑوں کی (کھیپ بھی) اس (دفاعی تیاری) سے تم اللہ کے دشمن اور اپنے دشمن کو ڈراتے رہو اور ان کے سوا دوسروں کو بھی جن (کی چھپی دشمنی) کو تم نہیں جانتے، اللہ انہیں جانتا ہے، اور تم جو کچھ (بھی) اللہ کی راہ میں خرچ کرو گے تمہیں اس کا پورا پورا بدلہ دیا جائے گا اور تم سے ناانصافی نہ کی جائے گی،\qt@no{60}}%
\qt@newcmd\qurantrans@ur@mccxxi{اور اگر وہ (کفار) صلح کے لئے جھکیں تو آپ بھی اس کی طرف مائل ہوجائیں اور اللہ پر بھروسہ رکھیں۔ بیشک وہی خوب سننے والا جاننے والا ہے،\qt@no{61}}%
\qt@newcmd\qurantrans@ur@mccxxii{اور اگر وہ چاہیں کہ آپ کو دھوکہ دیں تو بیشک آپ کے لئے اللہ کافی ہے، وہی ہے جس نے آپ کو اپنی مدد کے ذریعے اور اہلِ ایمان کے ذریعے طاقت بخشی،\qt@no{62}}%
\qt@newcmd\qurantrans@ur@mccxxiii{اور (اسی نے) ان (مسلمانوں) کے دلوں میں باہمی الفت پیدا فرما دی۔ اگر آپ وہ سب کچھ جو زمین میں ہے خرچ کر ڈالتے تو (ان تمام مادی وسائل سے) بھی آپ ان کے دلوں میں (یہ) الفت پیدا نہ کر سکتے لیکن اللہ نے ان کے درمیان (ایک روحانی رشتے سے) محبت پیدا فرما دی۔ بیشک وہ بڑے غلبہ والا حکمت والا ہے،\qt@no{63}}%
\qt@newcmd\qurantrans@ur@mccxxiv{اے نبئ (معّظم!) آپ کے لئے اللہ کافی ہے اور وہ مسلمان جنہوں نے آپ کی پیروی اختیار کرلی،\qt@no{64}}%
\qt@newcmd\qurantrans@ur@mccxxv{اے نبئ (مکرّم!) آپ ایمان والوں کو جہاد کی ترغیب دیں (یعنی حق کی خاطر لڑنے پر آمادہ کریں)، اگر تم میں سے (جنگ میں) بیس (٢٠) ثابت قدم رہنے والے ہوں تو وہ دو سو (٢٠٠) (کفار) پر غالب آئیں گے اور اگر تم میں سے (ایک) سو (ثابت قدم) ہوں گے تو کافروں میں سے (ایک) ہزار پر غالب آئیں گے اس وجہ سے کہ وہ (آخرت اور اس کے اجرِ عظیم کی) سمجھ نہیں رکھتے (سو وہ اس قدر جذبہ و شوق سے نہیں لڑ سکتے جس قدر وہ مومن جو اپنی جانوں کا جنت اور اللہ کی رضا کے عوض سودا کر چکے ہیں)،\qt@no{65}}%
\qt@newcmd\qurantrans@ur@mccxxvi{اب اللہ نے تم سے (اپنے حکم کا بوجھ) ہلکا کر دیا اسے معلوم ہے کہ تم میں (کسی قدر) کمزوری ہے سو (اب تخفیف کے بعد حکم یہ ہے کہ) اگر تم میں سے (ایک) سو (آدمی) ثابت قدم رہنے والے ہوں (تو) وہ دو سو (کفار) پر غالب آئیں گے اور اگر تم میں سے (ایک) ہزار ہوں تو وہ اللہ کے حکم سے دو ہزار (کافروں) پر غالب آئیں گے، اور اللہ صبر کرنے والوں کے ساتھ ہے (یہ مومنوں کے لئے ہدف ہے کہ میدانِ جہاد میں ان کے جذبۂ ایمانی کا اثر کم سے کم یہ ہونا چاہیئے)،\qt@no{66}}%
\qt@newcmd\qurantrans@ur@mccxxvii{کسی نبی کو یہ سزاوار نہیں کہ اس کے لئے (کافر) قیدی ہوں جب تک کہ وہ زمین میں ان (حربی کافروں) کا اچھی طرح خون نہ بہا لے۔ تم لوگ دنیا کا مال و اسباب چاہتے ہو، اور اللہ آخرت کی (بھلائی) چاہتا ہے، اور اللہ خوب غالب حکمت والا ہے،\qt@no{67}}%
\qt@newcmd\qurantrans@ur@mccxxviii{اگر اللہ کی طرف سے پہلے ہی (معافی کا حکم) لکھا ہوا نہ ہوتا تو یقیناً تم کو اس (مال فدیہ کے بارے) میں جو تم نے (بدر کے قیدیوں سے) حاصل کیا تھا بڑا عذاب پہنچتا،\qt@no{68}}%
\qt@newcmd\qurantrans@ur@mccxxix{سو تم اس میں سے کھاؤ جو حلال، پاکیزہ مالِ غنیمت تم نے پایا ہے اور اللہ سے ڈرتے رہو، بیشک اللہ بڑا بخشنے والا نہایت مہربان ہے،\qt@no{69}}%
\qt@newcmd\qurantrans@ur@mccxxx{اے نبی! آپ ان سے جو آپ کے ہاتھوں میں قیدی ہیں فرما دیجئے: اگر اللہ نے تمہارے دلوں میں بھلائی جان لی تو تمہیں اس (مال) سے بہتر عطا فرمائے گا جو (فدیہ میں) تم سے لیا جا چکا ہے اور تمہیں بخش دے گا، اور اللہ بڑا بخشنے والا نہایت مہربان ہے،\qt@no{70}}%
\qt@newcmd\qurantrans@ur@mccxxxi{اور (اے محبوب!) اگر وہ آپ سے خیانت کرنا چاہیں تو یقیناً وہ اس سے قبل (بھی) اللہ سے خیانت کر چکے ہیں سو (اسی وجہ سے) اس نے ان میں سے بعض کو (آپ کی) قدرت میں دے دیا، اور اللہ خوب جاننے والا حکمت والا ہے،\qt@no{71}}%
\qt@newcmd\qurantrans@ur@mccxxxii{بیشک جو لوگ ایمان لائے اور انہوں نے (اللہ کے لئے) وطن چھوڑ دیئے اور اپنے مالوں اور اپنی جانوں سے اللہ کی راہ میں جہاد کیا اور جن لوگوں نے (مہاجرین کو) جگہ دی اور (ان کی) مدد کی وہی لوگ ایک دوسرے کے حقیقی دوست ہیں، اور جو لوگ ایمان لائے (مگر) انہوں نے (اللہ کے لئے) گھر بار نہ چھوڑے تو تمہیں ان کی دوستی سے کوئی سروکار نہیں یہاں تک کہ وہ ہجرت کریں اور اگر وہ دین (کے معاملات) میں تم سے مدد چاہیں تو تم پر (ان کی) مدد کرنا واجب ہے مگر اس قوم کے مقابلہ میں (مدد نہ کرنا) کہ تمہارے اور ان کے درمیان (صلح و امن کا) معاہدہ ہو، اور اللہ ان کاموں کو جو تم کر رہے ہو خوب دیکھنے والا ہے،\qt@no{72}}%
\qt@newcmd\qurantrans@ur@mccxxxiii{اور جو لوگ کافر ہیں وہ ایک دوسرے کے مددگار ہیں، (اے مسلمانو!) اگر تم (ایک دوسرے کے ساتھ) ایسا (تعاون اور مدد و نصرت) نہیں کرو گے تو زمین میں (غلبۂ کفر و باطل کا) فتنہ اور بڑا فساد بپا ہو جائے گا،\qt@no{73}}%
\qt@newcmd\qurantrans@ur@mccxxxiv{اور جو لوگ ایمان لائے اور انہوں نے ہجرت کی اور اللہ کی راہ میں جہاد کیا اور جن لوگوں نے (راہِ خدا میں گھر بار اور وطن قربان کر دینے والوں کو) جگہ دی اور (ان کی) مدد کی، وہی لوگ حقیقت میں سچے مسلمان ہیں، ان ہی کے لئے بخشش اور عزت کی روزی ہے،\qt@no{74}}%
\qt@newcmd\qurantrans@ur@mccxxxv{اور جو لوگ اس کے بعد ایمان لائے اور انہوں نے راہِ حق میں (قربانی دیتے ہوئے) گھر بار چھوڑ دیئے اور تمہارے ساتھ مل کر جہاد کیا تو وہ لوگ (بھی) تم ہی میں سے ہیں، اور رشتہ دار اللہ کی کتاب میں (صلہ رحمی اور وراثت کے لحاظ سے) ایک دوسرے کے زیادہ حق دار ہیں، بیشک اللہ ہر چیز کو خوب جاننے والا ہے،\qt@no{75}}%
\qt@newcmd\qurantrans@ur@mccxxxvi{\basmalahur اللہ اور اس کے رسول (صلی اللہ علیہ وآلہ وسلم) کی طرف سے بے زاری (و دست برداری) کا اعلان ہے ان مشرک لوگوں کی طرف جن سے تم نے (صلح و امن کا) معاہدہ کیا تھا (اور وہ اپنے عہد پر قائم نہ رہے تھے)،\qt@no{1}}%
\qt@newcmd\qurantrans@ur@mccxxxvii{پس (اے مشرکو!) تم زمین میں چار ماہ (تک) گھوم پھر لو (اس مہلت کے اختتام پر تمہیں جنگ کا سامنا کرنا ہوگا) اور جان لو کہ تم اللہ کو ہرگز عاجز نہیں کر سکتے اور بیشک اللہ کافروں کو رسوا کرنے والا ہے،\qt@no{2}}%
\qt@newcmd\qurantrans@ur@mccxxxviii{یہ آیات) اللہ اور اس کے رسول (صلی اللہ علیہ وآلہ وسلم) کی جانب سے تمام لوگوں کی طرف حجِ اکبر کے دن اعلانِ (عام) ہے کہ اللہ مشرکوں سے بے زار ہے اور اس کا رسول (صلی اللہ علیہ وآلہ وسلم) بھی (ان سے بری الذمّہ ہے)، پس (اے مشرکو!) اگر تم توبہ کر لو تو وہ تمہارے حق میں بہتر ہے اور اگر تم نے روگردانی کی تو جان لو کہ تم ہرگز اللہ کو عاجز نہ کر سکو گے، اور (اے حبیب!) آپ کافروں کو دردناک عذاب کی خبر سنا دیں،\qt@no{3}}%
\qt@newcmd\qurantrans@ur@mccxxxix{سوائے ان مشرکوں کے جن سے تم نے معاہدہ کیا تھا پھر انہوں نے تمہارے ساتھ (اپنے عہد کو پورا کرنے میں) کوئی کمی نہیں کی اور نہ تمہارے مقابلہ پر کسی کی مدد (یا پشت پناہی) کی سو تم ان کے عہد کو ان کی مقررہ مدت تک ان کے ساتھ پورا کرو، بیشک اللہ پرہیزگاروں کو پسند فرماتا ہے،\qt@no{4}}%
\qt@newcmd\qurantrans@ur@mccxl{پھر جب حرمت والے مہینے گزر جائیں تو تم (حسبِ اعلان) مشرکوں کو قتل کر دو جہاں کہیں بھی تم ان کو پاؤ اور انہیں گرفتار کر لو اور انہیں قید کر دو اور انہیں (پکڑنے اور گھیرنے کے لئے) ہر گھات کی جگہ ان کی تاک میں بیٹھو، پس اگر وہ توبہ کر لیں اور نماز قائم کریں اور زکوٰۃ ادا کرنے لگیں تو ان کا راستہ چھوڑ دو۔ بیشک اللہ بڑا بخشنے والا نہایت مہربان ہے،\qt@no{5}}%
\qt@newcmd\qurantrans@ur@mccxli{اور اگر مشرکوں میں سے کوئی بھی آپ سے پناہ کا خواست گار ہو تو اسے پناہ دے دیں تاآنکہ وہ اللہ کا کلام سنے پھر آپ اسے اس کی جائے امن تک پہنچا دیں، یہ اس لئے کہ وہ لوگ (حق کا) علم نہیں رکھتے،\qt@no{6}}%
\qt@newcmd\qurantrans@ur@mccxlii{بھلا) مشرکوں کے لئے اللہ کے ہاں اور اس کے رسول (صلی اللہ علیہ وآلہ وسلم) کے ہاں کوئی عہد کیوں کر ہو سکتا ہے؟ سوائے ان لوگوں کے جن سے تم نے مسجدِ حرام کے پاس (حدیبیہ میں) معاہدہ کیا ہے سو جب تک وہ تمہارے ساتھ (عہد پر) قائم رہیں تم ان کے ساتھ قائم رہو۔ بیشک اللہ پرہیزگاروں کو پسند فرماتا ہے،\qt@no{7}}%
\qt@newcmd\qurantrans@ur@mccxliii{بھلا ان سے عہد کی پاسداری کی توقع) کیونکر ہو، ان کا حال تو یہ ہے کہ اگر تم پر غلبہ پا جائیں تو نہ تمہارے حق میں کسی قرابت کا لحاظ کریں اور نہ کسی عہد کا، وہ تمہیں اپنے مونہہ سے تو راضی رکھتے ہیں اور ان کے دل (ان باتوں سے) انکار کرتے ہیں اور ان میں سے اکثر عہد شکن ہیں،\qt@no{8}}%
\qt@newcmd\qurantrans@ur@mccxliv{انہوں نے آیاتِ الٰہی کے بدلے (دنیوی مفاد کی) تھوڑی سی قیمت حاصل کر لی پھر اس (کے دین) کی راہ سے (لوگوں کو) روکنے لگے، بیشک بہت ہی برا کام ہے جو وہ کرتے رہتے ہیں،\qt@no{9}}%
\qt@newcmd\qurantrans@ur@mccxlv{نہ وہ کسی مسلمان کے حق میں قرابت کا لحاظ کرتے ہیں اور نہ عہد کا، اور وہی لوگ (سرکشی میں) حد سے بڑھنے والے ہیں،\qt@no{10}}%
\qt@newcmd\qurantrans@ur@mccxlvi{پھر (بھی) اگر وہ توبہ کر لیں اور نماز قائم کریں اور زکوٰۃ ادا کرنے لگیں تو (وہ) دین میں تمہارے بھائی ہیں، اور ہم (اپنی) آیتیں ان لوگوں کے لئے تفصیل سے بیان کرتے ہیں جو علم و دانش رکھتے ہیں،\qt@no{11}}%
\qt@newcmd\qurantrans@ur@mccxlvii{اور اگر وہ اپنے عہد کے بعد اپنی قََسمیں توڑ دیں اور تمہارے دین میں طعنہ زنی کریں تو تم (ان) کفر کے سرغنوں سے جنگ کرو بیشک ان کی قَسموں کا کوئی اعتبار نہیں تاکہ وہ (اپنی فتنہ پروری سے) باز آجائیں،\qt@no{12}}%
\qt@newcmd\qurantrans@ur@mccxlviii{کیا تم ایسی قوم سے جنگ نہیں کرو گے جنہوں نے اپنی قََسمیں توڑ ڈالیں اور رسول (صلی اللہ علیہ وآلہ وسلم) کو جلاوطن کرنے کا ارادہ کیا حالانکہ پہلی مرتبہ انہوں نے تم سے (عہد شکنی اور جنگ کی) ابتداء کی، کیا تم ان سے ڈرتے ہو جبکہ اللہ زیادہ حقدار ہے کہ تم اس سے ڈرو بشرطیکہ تم مومن ہو،\qt@no{13}}%
\qt@newcmd\qurantrans@ur@mccxlix{تم ان سے جنگ کرو، اللہ تمہارے ہاتھوں انہیں عذاب دے گا اور انہیں رسوا کرے گا اور ان (کے مقابلہ) پر تمہاری مدد فرمائے گا اور ایمان والوں کے سینوں کو شفا بخشے گا،\qt@no{14}}%
\qt@newcmd\qurantrans@ur@mccl{اور ان کے دلوں کا غم و غصہ دور فرمائے گا اور جس کی چاہے گا توبہ قبول فرمائے گا، اور اللہ بڑے علم والا بڑی حکمت والا ہے،\qt@no{15}}%
\qt@newcmd\qurantrans@ur@mccli{کیا تم یہ سمجھتے ہو کہ تم (مصائب و مشکلات سے گزرے بغیر یونہی) چھوڑ دیئے جاؤ گے حالانکہ (ابھی) اللہ نے ایسے لوگوں کو متمیّز نہیں فرمایا جنہوں نے تم میں سے جہاد کیا ہے اور (جنہوں نے) اللہ کے سوا اور اس کے رسول (صلی اللہ علیہ وآلہ وسلم) کے سوا اور اہلِ ایمان کے سوا (کسی کو) محرمِ راز نہیں بنایا، اور اللہ ان کاموں سے خوب آگاہ ہے جو تم کرتے ہو،\qt@no{16}}%
\qt@newcmd\qurantrans@ur@mcclii{مشرکوں کے لئے یہ روا نہیں کہ وہ اللہ کی مسجدیں آباد کریں درآنحالیکہ وہ خود اپنے اوپر کفر کے گواہ ہیں، ان لوگوں کے تمام اعمال باطل ہو چکے ہیں اور وہ ہمیشہ دوزخ ہی میں رہنے والے ہیں،\qt@no{17}}%
\qt@newcmd\qurantrans@ur@mccliii{اللہ کی مسجدیں صرف وہی آباد کر سکتا ہے جو اللہ پر اور یومِ آخرت پر ایمان لایا اور اس نے نماز قائم کی اور زکوٰۃ ادا کی اور اللہ کے سوا (کسی سے) نہ ڈرا۔ سو امید ہے کہ یہی لوگ ہدایت پانے والوں میں ہو جائیں گے،\qt@no{18}}%
\qt@newcmd\qurantrans@ur@mccliv{کیا تم نے (محض) حاجیوں کو پانی پلانے اور مسجدِ حرام کی آبادی و مرمت کا بندوبست کرنے (کے عمل) کو اس شخص کے (اعمال) کے برابر قرار دے رکھا ہے جو اللہ اور یومِ آخرت پر ایمان لے آیا اور اس نے اللہ کی راہ میں جہاد کیا، یہ لوگ اللہ کے حضور برابر نہیں ہو سکتے، اور اللہ ظالم قوم کو ہدایت نہیں فرماتا،\qt@no{19}}%
\qt@newcmd\qurantrans@ur@mcclv{جو لوگ ایمان لائے اور انہوں نے ہجرت کی اور اللہ کی راہ میں اپنے اموال اور اپنی جانوں سے جہاد کرتے رہے وہ اللہ کی بارگاہ میں درجہ کے لحاظ سے بہت بڑے ہیں، اور وہی لوگ ہی مراد کو پہنچے ہوئے ہیں،\qt@no{20}}%
\qt@newcmd\qurantrans@ur@mcclvi{ان کا رب انہیں اپنی جانب سے رحمت کی اور (اپنی) رضا کی اور (ان) جنتوں کی خوشخبری دیتا ہے جن میں ان کے لئے دائمی نعمتیں ہیں،\qt@no{21}}%
\qt@newcmd\qurantrans@ur@mcclvii{وہ) ان میں ہمیشہ ہمیشہ رہیں گے بیشک اللہ ہی کے پاس بڑا اجر ہے،\qt@no{22}}%
\qt@newcmd\qurantrans@ur@mcclviii{اے ایمان والو! تم اپنے باپ (دادا) اور بھائیوں کو بھی دوست نہ بناؤ اگر وہ ایمان پر کفر کو محبوب رکھتے ہوں، اور تم میں سے جو شخص بھی انہیں دوست رکھے گا سو وہی لوگ ظالم ہیں،\qt@no{23}}%
\qt@newcmd\qurantrans@ur@mcclix{اے نبی مکرم!) آپ فرما دیں: اگر تمہارے باپ (دادا) اور تمہارے بیٹے (بیٹیاں) اور تمہارے بھائی (بہنیں) اور تمہاری بیویاں اور تمہارے (دیگر) رشتہ دار اور تمہارے اموال جو تم نے (محنت سے) کمائے اور تجارت و کاروبار جس کے نقصان سے تم ڈرتے رہتے ہو اور وہ مکانات جنہیں تم پسند کرتے ہو، تمہارے نزدیک اللہ اور اس کے رسول (صلی اللہ علیہ وآلہ وسلم) اور اس کی راہ میں جہاد سے زیادہ محبوب ہیں تو پھر انتظار کرو یہاں تک کہ اللہ اپنا حکمِ (عذاب) لے آئے، اور اللہ نافرمان لوگوں کو ہدایت نہیں فرماتا،\qt@no{24}}%
\qt@newcmd\qurantrans@ur@mcclx{بیشک اللہ نے بہت سے مقامات میں تمہاری مدد فرمائی اور (خصوصاً) حنین کے دن جب تمہاری (افرادی قوت کی) کثرت نے تمہیں نازاں بنا دیا تھا پھر وہ (کثرت) تمہیں کچھ بھی نفع نہ دے سکی اور زمین باوجود اس کے کہ وہ فراخی رکھتی تھی، تم پر تنگ ہو گئی چنانچہ تم پیٹھ دکھاتے ہوئے پھر گئے،\qt@no{25}}%
\qt@newcmd\qurantrans@ur@mcclxi{پھر اللہ نے اپنے رسول (صلی اللہ علیہ وآلہ وسلم) پر اور ایمان والوں پر اپنی تسکین (رحمت) نازل فرمائی اور اس نے (ملائکہ کے ایسے) لشکر اتارے جنہیں تم نہ دیکھ سکے اور اس نے ان لوگوں کو عذاب دیا جو کفر کر رہے تھے، اور یہی کافروں کی سزا ہے،\qt@no{26}}%
\qt@newcmd\qurantrans@ur@mcclxii{پھر اللہ اس کے بعد بھی جس کی چاہتا ہے توبہ قبول فرماتا ہے (یعنی اسے توفیقِ اسلام اور توجہِ رحمت سے نوازتا ہے)، اور اللہ بڑا بخشنے والا نہایت مہربان ہے،\qt@no{27}}%
\qt@newcmd\qurantrans@ur@mcclxiii{اے ایمان والو! مشرکین تو سراپا نجاست ہیں سو وہ اپنے اس سال کے بعد (یعنی فتحِ مکہ کے بعد ۹ ھ سے) مسجدِ حرام کے قریب نہ آنے پائیں، اور اگر تمہیں (تجارت میں کمی کے باعث) مفلسی کا ڈر ہے تو (گھبراؤ نہیں) عنقریب اللہ اگر چاہے گا تو تمہیں اپنے فضل سے مال دار کر دے گا، بیشک اللہ خوب جاننے والا بڑی حکمت والا ہے،\qt@no{28}}%
\qt@newcmd\qurantrans@ur@mcclxiv{اے مسلمانو!) تم اہلِ کتاب میں سے ان لوگوں کے ساتھ (بھی) جنگ کرو جو نہ اللہ پر ایمان رکھتے ہیں نہ یومِ آخرت پر اور نہ ان چیزوں کو حرام جانتے ہیں جنہیں اللہ اور اس کے رسول (صلی اللہ علیہ وآلہ وسلم) نے حرام قرار دیا ہے اور نہ ہی دینِ حق (یعنی اسلام) اختیار کرتے ہیں، یہاں تک کہ وہ (حکمِ اسلام کے سامنے) تابع و مغلوب ہو کر اپنے ہاتھ سے خراج ادا کریں،\qt@no{29}}%
\qt@newcmd\qurantrans@ur@mcclxv{اور یہود نے کہا: عزیر (علیہ السلام) اللہ کے بیٹے ہیں اور نصارٰی نے کہا: مسیح (علیہ السلام) اللہ کے بیٹے ہیں۔ یہ ان کا (لغو) قول ہے جو اپنے مونہہ سے نکالتے ہیں۔ یہ ان لوگوں کے قول سے مشابہت (اختیار) کرتے ہیں جو (ان سے) پہلے کفر کر چکے ہیں، اللہ انہیں ہلاک کرے یہ کہاں بہکے پھرتے ہیں،\qt@no{30}}%
\qt@newcmd\qurantrans@ur@mcclxvi{انہوں نے اللہ کے سوا اپنے عالموں اور زاہدوں کو رب بنا لیا تھا اور مریم کے بیٹے مسیح (علیہ السلام) کو (بھی) حالانکہ انہیں بجز اس کے (کوئی) حکم نہیں دیا گیا تھا کہ وہ اکیلے ایک (ہی) معبود کی عبادت کریں، جس کے سوا کوئی معبود نہیں، وہ ان سے پاک ہے جنہیں یہ شریک ٹھہراتے ہیں،\qt@no{31}}%
\qt@newcmd\qurantrans@ur@mcclxvii{وہ چاہتے ہیں کہ اللہ کا نور اپنی پھونکوں سے بجھا دیں اور اللہ (یہ بات) قبول نہیں فرماتا مگر یہ (چاہتا ہے) کہ وہ اپنے نور کو کمال تک پہنچا دے اگرچہ کفار (اسے) ناپسند ہی کریں،\qt@no{32}}%
\qt@newcmd\qurantrans@ur@mcclxviii{وہی (اللہ) ہے جس نے اپنے رسول (صلی اللہ علیہ وآلہ وسلم) کو ہدایت اور دینِ حق کے ساتھ بھیجا تاکہ اس (رسول صلی اللہ علیہ وآلہ وسلم) کو ہر دین (والے) پر غالب کر دے اگرچہ مشرکین کو برا لگے،\qt@no{33}}%
\qt@newcmd\qurantrans@ur@mcclxix{اے ایمان والو! بیشک (اہلِ کتاب کے) اکثر علماء اور درویش، لوگوں کے مال ناحق (طریقے سے) کھاتے ہیں اور اللہ کی راہ سے روکتے ہیں (یعنی لوگوں کے مال سے اپنی تجوریاں بھرتے ہیں اور دینِ حق کی تقویت و اشاعت پر خرچ کئے جانے سے روکتے ہیں)، اور جو لوگ سونا اور چاندی کا ذخیرہ کرتے ہیں اور اسے اللہ کی راہ میں خرچ نہیں کرتے تو انہیں دردناک عذاب کی خبر سنا دیں،\qt@no{34}}%
\qt@newcmd\qurantrans@ur@mcclxx{جس دن اس (سونے، چاندی اور مال) پر دوزخ کی آگ میں تاپ دی جائے گی پھر اس (تپے ہوئے مال) سے ان کی پیشانیاں اور ان کے پہلو اور ان کی پیٹھیں داغی جائیں گی، (اور ان سے کہا جائے گا) کہ یہ وہی (مال) ہے جو تم نے اپنی جانوں (کے مفاد) کے لئے جمع کیا تھا سو تم (اس مال کا) مزہ چکھو جسے تم جمع کرتے رہے تھے،\qt@no{35}}%
\qt@newcmd\qurantrans@ur@mcclxxi{بیشک اللہ کے نزدیک مہینوں کی گنتی اللہ کی کتاب (یعنی نوشتۂ قدرت) میں بارہ مہینے (لکھی) ہے جس دن سے اس نے آسمانوں اور زمین (کے نظام) کو پیدا فرمایا تھا ان میں سے چار مہینے (رجب، ذو القعدہ، ذو الحجہ اور محرم) حرمت والے ہیں۔ یہی سیدھا دین ہے سو تم ان مہینوں میں (ازخود جنگ و قتال میں ملوث ہو کر) اپنی جانوں پر ظلم نہ کرنا اور تم (بھی) تمام مشرکین سے اسی طرح (جوابی) جنگ کیا کرو جس طرح وہ سب کے سب (اکٹھے ہو کر) تم سے جنگ کرتے ہیں، اور جان لو کہ بیشک اللہ پرہیزگاروں کے ساتھ ہے،\qt@no{36}}%
\qt@newcmd\qurantrans@ur@mcclxxii{حرمت والے مہینوں کو) آگے پیچھے ہٹا دینا محض کفر میں زیادتی ہے اس سے وہ کافر لوگ بہکائے جاتے ہیں جو اسے ایک سال حلال گردانتے ہیں اور دوسرے سال اسے حرام ٹھہرا لیتے ہیں تاکہ ان (مہینوں) کا شمار پورا کر دیں جنہیں اللہ نے حرمت بخشی ہے اور اس (مہینے) کو حلال (بھی) کر دیں جسے اللہ نے حرام فرمایا ہے۔ ان کے لئے ان کے برے اعمال خوش نما بنا دیئے گئے ہیں اور اللہ کافروں کے گروہ کو ہدایت نہیں فرماتا،\qt@no{37}}%
\qt@newcmd\qurantrans@ur@mcclxxiii{اے ایمان والو! تمہیں کیا ہو گیا ہے کہ جب تم سے کہا جاتا ہے کہ تم اللہ کی راہ میں (جہاد کے لئے) نکلو تو تم بوجھل ہو کر زمین (کی مادی و سفلی دنیا) کی طرف جھک جاتے ہو، کیا تم آخرت کے بدلے دنیا کی زندگی سے راضی ہو گئے ہو؟ سو آخرت (کے مقابلہ) میں دنیوی زندگی کا ساز و سامان کچھ بھی نہیں مگر بہت ہی کم (حیثیت رکھتا ہے)،\qt@no{38}}%
\qt@newcmd\qurantrans@ur@mcclxxiv{اگر تم (جہاد کے لئے) نہ نکلو گے تو وہ تمہیں دردناک عذاب میں مبتلا فرمائے گا اور تمہاری جگہ (کسی) اور قوم کو لے آئے گا اور تم اسے کچھ بھی نقصان نہیں پہنچا سکو گے، اور اللہ ہر چیز پر بڑی قدرت رکھتا ہے،\qt@no{39}}%
\qt@newcmd\qurantrans@ur@mcclxxv{اگر تم ان کی (یعنی رسول اللہ صلی اللہ علیہ وآلہ وسلم کی غلبۂ اسلام کی جد و جہد میں) مدد نہ کرو گے (تو کیا ہوا) سو بیشک اللہ نے ان کو (اس وقت بھی) مدد سے نوازا تھا جب کافروں نے انہیں (وطنِ مکہ سے) نکال دیا تھا درآنحالیکہ وہ دو (ہجرت کرنے والوں) میں سے دوسرے تھے جبکہ دونوں (رسول اللہ صلی اللہ علیہ وآلہ وسلم اور ابوبکر صدیق رضی اللہ تعالیٰ عنہ) غارِ (ثور) میں تھے جب وہ اپنے ساتھی (ابوبکر صدیق رضی اللہ تعالیٰ عنہ) سے فرما رہے تھے: غمزدہ نہ ہو بیشک اللہ ہمارے ساتھ ہے، پس اللہ نے ان پر اپنی تسکین نازل فرما دی اور انہیں (فرشتوں کے) ایسے لشکروں کے ذریعہ قوت بخشی جنہیں تم نہ دیکھ سکے اور اس نے کافروں کی بات کو پست و فروتر کر دیا، اور اللہ کا فرمان تو (ہمیشہ) بلند و بالا ہی ہے، اور اللہ غالب، حکمت والا ہے،\qt@no{40}}%
\qt@newcmd\qurantrans@ur@mcclxxvi{تم ہلکے اور گراں بار (ہر حال میں) نکل کھڑے ہو اور اپنے مال و جان سے اللہ کی راہ میں جہاد کرو، یہ تمہارے لئے بہتر ہے اگر تم (حقیقت) آشنا ہو،\qt@no{41}}%
\qt@newcmd\qurantrans@ur@mcclxxvii{اگر مالِ (غنیمت) قریب الحصول ہوتا اور (جہاد کا) سفر متوسط و آسان تو وہ (منافقین) یقیناً آپ کے پیچھے چل پڑتے لیکن (وہ) پُرمشقّت مسافت انہیں بہت دور دکھائی دی، اور (اب) وہ عنقریب اللہ کی قَسمیں کھائیں گے کہ اگر ہم میں استطاعت ہوتی تو ضرور تمہارے ساتھ نکل کھڑے ہوتے، وہ (ان جھوٹی باتوں سے) اپنے آپ کو (مزید) ہلاکت میں ڈال رہے ہیں، اور اللہ جانتا ہے کہ وہ واقعی جھوٹے ہیں،\qt@no{42}}%
\qt@newcmd\qurantrans@ur@mcclxxviii{اللہ آپ کو سلامت (اور باعزت و عافیت) رکھے، آپ نے انہیں رخصت (ہی) کیوں دی (کہ وہ شریکِ جنگ نہ ہوں) یہاں تک کہ وہ لوگ (بھی) آپ کے لئے ظاہر ہو جاتے جو سچ بول رہے تھے اور آپ جھوٹ بولنے والوں کو (بھی) معلوم فرما لیتے،\qt@no{43}}%
\qt@newcmd\qurantrans@ur@mcclxxix{وہ لوگ جو اللہ پر اور یومِ آخرت پر ایمان رکھتے ہیں آپ سے (اس بات کی) رخصت طلب نہیں کریں گے کہ وہ اپنے مال و جان سے جہاد (نہ) کریں، اور اللہ پرہیزگاروں کو خوب جانتا ہے،\qt@no{44}}%
\qt@newcmd\qurantrans@ur@mcclxxx{آپ سے (جہاد میں شریک نہ ہونے کی) رخصت صرف وہی لوگ چاہیں گے جو اللہ پر اور یومِ آخرت پر ایمان نہیں رکھتے اور ان کے دل شک میں پڑے ہوئے ہیں سو وہ اپنے شک میں حیران و سرگرداں ہیں،\qt@no{45}}%
\qt@newcmd\qurantrans@ur@mcclxxxi{اگر انہوں نے (واقعی جہاد کے لئے) نکلنے کا ارادہ کیا ہوتا تو وہ اس کے لئے (کچھ نہ کچھ) سامان تو ضرور مہیا کر لیتے لیکن (حقیقت یہ ہے کہ ان کے کذب و منافقت کے باعث) اللہ نے ان کا (جہاد کے لئے) کھڑے ہونا (ہی) ناپسند فرمایا سو اس نے انہیں (وہیں) روک دیا اور ان سے کہہ دیا گیا کہ تم (جہاد سے جی چرا کر) بیٹھ رہنے والوں کے ساتھ بیٹھے رہو،\qt@no{46}}%
\qt@newcmd\qurantrans@ur@mcclxxxii{اگر وہ تم میں (شامل ہو کر) نکل کھڑے ہوتے تو تمہارے لئے محض شر و فساد ہی بڑھاتے اور تمہارے درمیان (بگاڑ پیدا کرنے کے لئے) دوڑ دھوپ کرتے وہ تمہارے اندر فتنہ بپا کرنا چاہتے ہیں اور تم میں (اب بھی) ان کے (بعض) جاسوس موجود ہیں، اور اللہ ظالموں سے خوب واقف ہے،\qt@no{47}}%
\qt@newcmd\qurantrans@ur@mcclxxxiii{درحقیقت وہ پہلے بھی فتنہ پردازی میں کوشاں رہے ہیں اور آپ کے کام الٹ پلٹ کرنے کی تدبیریں کرتے رہے ہیں یہاں تک کہ حق آپہنچا اور اللہ کا حکم غالب ہو گیا اور وہ (اسے) ناپسند ہی کرتے رہے،\qt@no{48}}%
\qt@newcmd\qurantrans@ur@mcclxxxiv{اور ان میں سے وہ شخص (بھی) ہے جو کہتا ہے کہ آپ مجھے اجازت دے دیجئے (کہ میں جہاد پر جانے کی بجائے گھر ٹھہرا رہوں) اور مجھے فتنہ میں نہ ڈالئے، سن لو! کہ وہ فتنہ میں (تو خود ہی) گر پڑے ہیں، اور بیشک جہنم کافروں کو گھیرے ہوئے ہے،\qt@no{49}}%
\qt@newcmd\qurantrans@ur@mcclxxxv{اگر آپ کو کوئی بھلائی (یا آسائش) پہنچتی ہے (تو) وہ انہیں بری لگتی ہے اور اگر آپ کو مصیبت (یا تکلیف) پہنچتی ہے (تو) کہتے ہیں کہ ہم نے تو پہلے سے ہی اپنے کام (میں احتیاط) کو اختیار کر لیا تھا اور خوشیاں مناتے ہوئے پلٹتے ہیں،\qt@no{50}}%
\qt@newcmd\qurantrans@ur@mcclxxxvi{اے حبیب!) آپ فرما دیجئے کہ ہمیں ہرگز (کچھ) نہیں پہنچے گا مگر وہی کچھ جو اللہ نے ہمارے لئے لکھ دیا ہے، وہی ہمارا کارساز ہے اور اللہ ہی پر ایمان والوں کو بھروسہ کرنا چاہیے،\qt@no{51}}%
\qt@newcmd\qurantrans@ur@mcclxxxvii{آپ فرما دیں: کیا تم ہمارے حق میں دو بھلائیوں (یعنی فتح اور شہادت) میں سے ایک ہی کا انتظار کر رہے ہو (کہ ہم شہید ہوتے ہیں یا غازی بن کر لوٹتے ہیں)؟ اور ہم تمہارے حق میں (تمہاری منافقت کے باعث) اس بات کا انتظار کر رہے ہیں کہ اللہ اپنی بارگاہ سے تمہیں (خصوصی) عذاب پہنچاتا ہے یا ہمارے ہاتھوں سے۔ سو تم (بھی) انتظار کرو ہم (بھی) تمہارے ساتھ منتظر ہیں (کہ کس کا انتظار نتیجہ خیز ہے)،\qt@no{52}}%
\qt@newcmd\qurantrans@ur@mcclxxxviii{فرما دیجئے: تم خوشی سے خرچ کرو یا ناخوشی سے تم سے ہرگز وہ (مال) قبول نہیں کیا جائے گا، بیشک تم نافرمان لوگ ہو،\qt@no{53}}%
\qt@newcmd\qurantrans@ur@mcclxxxix{اور ان سے ان کے نفقات (یعنی صدقات) کے قبول کئے جانے میں کوئی (اور) چیز انہیں مانع نہیں ہوئی سوائے اس کے کہ وہ اللہ اور اس کے رسول (صلی اللہ علیہ وآلہ وسلم) کے منکر ہیں اور وہ نماز کی ادائیگی کے لئے نہیں آتے مگر کاہلی و بے رغبتی کے ساتھ اور وہ (اللہ کی راہ میں) خرچ (بھی) نہیں کرتے مگر اس حال میں کہ وہ ناخوش ہوتے ہیں،\qt@no{54}}%
\qt@newcmd\qurantrans@ur@mccxc{سو آپ کو نہ (تو) ان کے اموال تعجب میں ڈالیں اور نہ ہی ان کی اولاد۔ بس اللہ تو یہ چاہتا ہے کہ انہیں انہی (چیزوں) کی وجہ سے دنیوی زندگی میں عذاب دے اور ان کی جانیں اس حال میں نکلیں کہ وہ کافر ہوں،\qt@no{55}}%
\qt@newcmd\qurantrans@ur@mccxci{اور وہ (اس قدر بزدل ہیں کہ) اللہ کی قَسمیں کھاتے ہیں کہ وہ تم ہی میں سے ہیں حالانکہ وہ تم میں سے نہیں لیکن وہ ایسے لوگ ہیں جو (اپنے نفاق کے ظاہر ہونے اور اس کے انجام سے) ڈرتے ہیں (اس لئے وہ بصورتِ تقیہ اپنا مسلمان ہونا ظاہر کرتے ہیں)،\qt@no{56}}%
\qt@newcmd\qurantrans@ur@mccxcii{ان کی کیفیت یہ ہے کہ) اگر وہ کوئی پناہ گاہ یا غار یا سرنگ پا لیں تو انتہائی تیزی سے بھاگتے ہوئے اس کی طرف پلٹ جائیں (اور آپ کے ساتھ ایک لمحہ بھی نہ رہیں مگر اس وقت وہ مجبور ہیں اس لئے جھوٹی وفاداری جتلاتے ہیں)،\qt@no{57}}%
\qt@newcmd\qurantrans@ur@mccxciii{اور ان ہی میں سے بعض ایسے ہیں جو صدقات (کی تقسیم) میں آپ پر طعنہ زنی کرتے ہیں، پھر اگر انہیں ان (صدقات) میں سے کچھ دے دیا جائے تو وہ راضی ہو جائیں اور اگر انہیں اس میں سے کچھ نہ دیا جائے تو وہ فوراً خفا ہو جاتے ہیں،\qt@no{58}}%
\qt@newcmd\qurantrans@ur@mccxciv{اور کیا ہی اچھا ہوتا اگر وہ لوگ اس پر راضی ہو جاتے جو ان کو اللہ اور اس کے رسول (صلی اللہ علیہ وآلہ وسلم) نے عطا فرمایا تھا اور کہتے کہ ہمیں اللہ کافی ہے۔ عنقریب ہمیں اللہ اپنے فضل سے اور اس کا رسول (صلی اللہ علیہ وآلہ وسلم مزید) عطا فرمائے گا۔ بیشک ہم اللہ ہی کی طرف راغب ہیں (اور رسول صلی اللہ علیہ وآلہ وسلم اسی کا واسطہ اور وسیلہ ہے، اس کا دینا بھی اللہ ہی کا دینا ہے۔ اگر یہ عقیدہ رکھتے اور طعنہ زنی نہ کرتے تو یہ بہتر ہوتا،\qt@no{59}}%
\qt@newcmd\qurantrans@ur@mccxcv{بیشک صدقات (زکوٰۃ) محض غریبوں اور محتاجوں اور ان کی وصولی پر مقرر کئے گئے کارکنوں اور ایسے لوگوں کے لئے ہیں جن کے دلوں میں اسلام کی الفت پیدا کرنا مقصود ہو اور (مزید یہ کہ) انسانی گردنوں کو (غلامی کی زندگی سے) آزاد کرانے میں اور قرض داروں کے بوجھ اتارنے میں اور اللہ کی راہ میں (جہاد کرنے والوں پر) اور مسافروں پر (زکوٰۃ کا خرچ کیا جانا حق ہے)۔ یہ (سب) اللہ کی طرف سے فرض کیا گیا ہے، اور اللہ خوب جاننے والا بڑی حکمت والا ہے،\qt@no{60}}%
\qt@newcmd\qurantrans@ur@mccxcvi{اور ان (منافقوں) میں سے وہ لوگ بھی ہیں جو نبی (مکرّم صلی اللہ علیہ وآلہ وسلم) کو ایذا پہنچاتے ہیں اور کہتے ہیں: وہ تو کان (کے کچے) ہیں۔ فرما دیجئے: تمہارے لئے بھلائی کے کان ہیں۔ وہ اللہ پر ایمان رکھتے ہیں اور اہلِ ایمان (کی باتوں) پر یقین کرتے ہیں اور تم میں سے جو ایمان لے آئے ہیں ان کے لئے رحمت ہیں، اور جو لوگ رسول اللہ (صلی اللہ علیہ وآلہ وسلم) کو (اپنی بدعقیدگی، بدگمانی اور بدزبانی کے ذریعے) اذیت پہنچاتے ہیں ان کے لئے دردناک عذاب ہے،\qt@no{61}}%
\qt@newcmd\qurantrans@ur@mccxcvii{مسلمانو! (یہ منافقین) تمہارے سامنے اللہ کی قَسمیں کھاتے ہیں تاکہ تمہیں راضی رکھیں حالانکہ اللہ اور اس کا رسول (صلی اللہ علیہ وآلہ وسلم) زیادہ حق دار ہے کہ اسے راضی کیا جائے اگر یہ لوگ ایمان والے ہوتے (تو یہ حقیقت جان لیتے اور رسول صلی اللہ علیہ وآلہ وسلم کو راضی کرتے، رسول صلی اللہ علیہ وآلہ وسلم کے راضی ہونے سے ہی اللہ راضی ہو جاتا ہے کیونکہ دونوں کی رضا ایک ہے،\qt@no{62}}%
\qt@newcmd\qurantrans@ur@mccxcviii{کیا وہ نہیں جانتے کہ جو شخص اللہ اور اس کے رسول (صلی اللہ علیہ وآلہ وسلم) کی مخالفت کرتا ہے تو اس کے لئے دوزخ کی آگ (مقرر) ہے جس میں وہ ہمیشہ رہنے والا ہے، یہ زبردست رسوائی ہے،\qt@no{63}}%
\qt@newcmd\qurantrans@ur@mccxcix{منافقین اس بات سے ڈرتے ہیں کہ مسلمانوں پر کوئی ایسی سورت نازل کر دی جائے جو انہیں ان باتوں سے خبردار کر دے جو ان (منافقوں) کے دلوں میں (مخفی) ہیں۔ فرما دیجئے: تم مذاق کرتے رہو، بیشک اللہ وہ (بات) ظاہر فرمانے والا ہے جس سے تم ڈر رہے ہو،\qt@no{64}}%
\qt@newcmd\qurantrans@ur@mccc{اور اگر آپ ان سے دریافت کریں تو وہ ضرور یہی کہیں گے کہ ہم تو صرف (سفر کاٹنے کے لئے) بات چیت اور دل لگی کرتے تھے۔ فرما دیجئے: کیا تم اللہ اور اس کی آیتوں اور اس کے رسول (صلی اللہ علیہ وآلہ وسلم) کے ساتھ مذاق کر رہے تھے،\qt@no{65}}%
\qt@newcmd\qurantrans@ur@mccci{اب) تم معذرت مت کرو، بیشک تم اپنے ایمان (کے اظہار) کے بعد کافر ہو گئے ہو، اگر ہم تم میں سے ایک گروہ کو معاف بھی کر دیں (تب بھی) دوسرے گروہ کو عذاب دیں گے اس وجہ سے کہ وہ مجرم تھے،\qt@no{66}}%
\qt@newcmd\qurantrans@ur@mcccii{منافق مرد اور منافق عورتیں ایک دوسرے (کی جنس) سے ہیں۔ یہ لوگ بری باتوں کا حکم دیتے ہیں اور اچھی باتوں سے روکتے ہیں اور اپنے ہاتھ (اللہ کی راہ میں خرچ کرنے سے) بند رکھتے ہیں، انہوں نے اللہ کو فراموش کر دیا تو اللہ نے انہیں فراموش کر دیا، بیشک منافقین ہی نافرمان ہیں،\qt@no{67}}%
\qt@newcmd\qurantrans@ur@mccciii{اللہ نے منافق مردوں اور منافق عورتوں اور کافروں سے آتشِ دوزخ کا وعدہ فرما رکھا ہے (وہ) اس میں ہمیشہ رہیں گے، وہ (آگ) انہیں کافی ہے، اور اللہ نے ان پر لعنت کی ہے اور ان کے لئے ہمیشہ برقرار رہنے والا عذاب ہے،\qt@no{68}}%
\qt@newcmd\qurantrans@ur@mccciv{اے منافقو! تم) ان لوگوں کی مثل ہو جو تم سے پہلے تھے۔ وہ تم سے بہت زیادہ طاقتور اور مال و اولاد میں کہیں زیادہ بڑھے ہوئے تھے۔ پس وہ اپنے (دنیوی) حصے سے فائدہ اٹھا چکے سو تم (بھی) اپنے حصے سے (اسی طرح) فائدہ اٹھا رہے ہو جیسے تم سے پہلے لوگوں نے (لذّتِ دنیا کے) اپنے مقررہ حصے سے فائدہ اٹھایا تھا نیز تم (بھی اسی طرح) باطل میں داخل اور غلطاں ہو جیسے وہ باطل میں داخل اور غلطاں تھے۔ ان لوگوں کے اعمال دنیا اور آخرت میں برباد ہو گئے اور وہی لوگ خسارے میں ہیں،\qt@no{69}}%
\qt@newcmd\qurantrans@ur@mcccv{کیا ان کے پاس ان لوگوں کی خبر نہیں پہنچی جو ان سے پہلے تھے، قومِ نوح اور عاد اور ثمود اور قومِ ابراہیم اور باشندگانِ مدین اور ان بستیوں کے مکین جو الٹ دی گئیں، ان کے پاس (بھی) ان کے رسول واضح نشانیاں لے کر آئے تھے (مگر انہوں نے نافرمانی کی) پس اللہ تو ایسا نہ تھا کہ ان پر ظلم کرتا لیکن وہ (انکارِ حق کے باعث) اپنے اوپر خود ہی ظلم کرتے تھے،\qt@no{70}}%
\qt@newcmd\qurantrans@ur@mcccvi{اور اہلِ ایمان مرد اور اہلِ ایمان عورتیں ایک دوسرے کے رفیق و مددگار ہیں۔ وہ اچھی باتوں کا حکم دیتے ہیں اور بری باتوں سے روکتے ہیں اور نماز قائم رکھتے ہیں اور زکوٰۃ ادا کرتے ہیں اور اللہ اور اس کے رسول (صلی اللہ علیہ وآلہ وسلم) کی اطاعت بجا لاتے ہیں، ان ہی لوگوں پر اللہ عنقریب رحم فرمائے گا، بیشک اللہ بڑا غالب بڑی حکمت والا ہے،\qt@no{71}}%
\qt@newcmd\qurantrans@ur@mcccvii{اللہ نے مومن مردوں اور مومن عورتوں سے جنتوں کا وعدہ فرما لیا ہے جن کے نیچے سے نہریں بہہ رہی ہیں، وہ ان میں ہمیشہ رہنے والے ہیں اور ایسے پاکیزہ مکانات کا بھی (وعدہ فرمایا ہے) جوجنت کے خاص مقام پر سدا بہار باغات میں ہیں، اور (پھر) اللہ کی رضا اور خوشنودی (ان سب نعمتوں سے) بڑھ کر ہے (جو بڑے اجر کے طور پر نصیب ہوگی)، یہی زبردست کامیابی ہے،\qt@no{72}}%
\qt@newcmd\qurantrans@ur@mcccviii{اے نبی (معظم!) آپ کافروں اور منافقوں سے جہاد کریں اور ان پر سختی کریں، اور ان کا ٹھکانا دوزخ ہے، اور وہ برا ٹھکانا ہے،\qt@no{73}}%
\qt@newcmd\qurantrans@ur@mcccix{یہ منافقین) اللہ کی قَسمیں کھاتے ہیں کہ انہوں نے (کچھ) نہیں کہا حالانکہ انہوں نے یقیناً کلمہ کفر کہا اور وہ اپنے اسلام (کو ظاہر کرنے) کے بعد کافر ہو گئے اور انہوں نے (کئی اذیت رساں باتوں کا) ارادہ (بھی) کیا تھا جنہیں وہ نہ پا سکے اور وہ (اسلام اور رسول صلی اللہ علیہ وآلہ وسلم کے عمل میں سے) اور کسی چیز کو ناپسند نہ کر سکے سوائے اس کے کہ انہیں اللہ اور اس کے رسول (صلی اللہ علیہ وآلہ وسلم) نے اپنے فضل سے غنی کر دیا تھا، سو اگر یہ (اب بھی) توبہ کر لیں تو ان کے لئے بہتر ہے اور اگر (اسی طرح) روگرداں رہیں تو اللہ انہیں دنیا اور آخرت (دونوں زندگیوں) میں دردناک عذاب میں مبتلا فرمائے گا اور ان کے لئے زمین میں نہ کوئی دوست ہوگا اور نہ کوئی مددگار،\qt@no{74}}%
\qt@newcmd\qurantrans@ur@mcccx{اور ان (منافقوں) میں (بعض) وہ بھی ہیں جنہوں نے اللہ سے عہد کیا تھا کہ اگر اس نے ہمیں اپنے فضل سے (دولت) عطا فرمائی تو ہم ضرور (اس کی ر اہ میں) خیرات کریں گے اور ہم ضرور نیکو کاروں میں سے ہو جائیں گے،\qt@no{75}}%
\qt@newcmd\qurantrans@ur@mcccxi{پس جب اس نے انہیں اپنے فضل سے (دولت) بخشی (تو) وہ اس میں بخل کرنے لگے اور وہ (اپنے عہد سے) روگردانی کرتے ہوئے پھر گئے،\qt@no{76}}%
\qt@newcmd\qurantrans@ur@mcccxii{پس اس نے ان کے دلوں میں نفاق کو (ان کے اپنے بخل کا) انجام بنا دیا اس دن تک کہ جب وہ اس سے ملیں گے اس وجہ سے کہ انہوں نے اللہ سے اپنے کئے ہوئے عہد کی خلاف ورزی کی اور اس وجہ سے (بھی) کہ وہ کذب بیانی کیا کرتے تھے،\qt@no{77}}%
\qt@newcmd\qurantrans@ur@mcccxiii{کیا انہیں معلوم نہیں کہ اللہ ان کے بھید اور ان کی سرگوشیاں جانتا ہے اور یہ کہ اللہ سب غیب کی باتوں کو بہت خوب جاننے والا ہے،\qt@no{78}}%
\qt@newcmd\qurantrans@ur@mcccxiv{جو لوگ برضا و رغبت خیرات دینے والے مومنوں پر (ان کے) صدقات میں (ریاکاری و مجبوری کا) الزام لگاتے ہیں اور ان (نادار مسلمانوں) پر بھی (عیب لگاتے ہیں) جو اپنی محنت و مشقت کے سوا (کچھ زیادہ مقدور) نہیں پاتے سو یہ (ان کے جذبۂ اِنفاق کا بھی) مذاق اڑاتے ہیں، اللہ انہیں ان کے تمسخر کی سزا دے گا اور ان کے لئے دردناک عذاب ہے،\qt@no{79}}%
\qt@newcmd\qurantrans@ur@mcccxv{آپ خواہ ان (بدبخت، گستاخ اور آپ کی شان میں طعنہ زنی کرنے والے منافقوں) کے لئے بخشش طلب کریں یا ان کے لئے بخشش طلب نہ کریں، اگر آپ (اپنی طبعی شفقت اور عفو و درگزر کی عادتِ کریمانہ کے پیشِ نظر) ان کے لئے ستر مرتبہ بھی بخشش طلب کریں تو بھی اللہ انہیں ہرگز نہیں بخشے گا، یہ اس وجہ سے کہ انہوں نے اللہ اور اس کے رسول (صلی اللہ علیہ وآلہ وسلم) کے ساتھ کفر کیا ہے، اور اللہ نافرمان قوم کو ہدایت نہیں فرماتا،\qt@no{80}}%
\qt@newcmd\qurantrans@ur@mcccxvi{رسول اللہ (صلی اللہ علیہ وآلہ وسلم) کی مخالفت کے باعث (جہاد سے) پیچھے رہ جانے والے (یہ منافق) اپنے بیٹھ رہنے پر خوش ہو رہے ہیں وہ اس بات کو ناپسند کرتے تھے کہ اپنے مالوں اور اپنی جانوں سے اللہ کی راہ میں جہاد کریں اور کہتے تھے کہ اس گرمی میں نہ نکلو، فرما دیجئے: دوزخ کی آگ سب سے زیادہ گرم ہے، اگر وہ سمجھتے ہوتے (تو کیا ہی اچھا ہوتا،\qt@no{81}}%
\qt@newcmd\qurantrans@ur@mcccxvii{پس انہیں چاہیئے کہ تھوڑا ہنسیں اور زیادہ روئیں (کیونکہ آخرت میں انہیں زیادہ رونا ہے) یہ اس کا بدلہ ہے جو وہ کماتے تھے،\qt@no{82}}%
\qt@newcmd\qurantrans@ur@mcccxviii{پس (اے حبیب!) اگر اللہ آپ کو (غزوۂ تبوک سے فارغ ہونے کے بعد) ان (منافقین) میں سے کسی گروہ کی طرف دوبارہ واپس لے جائے اور وہ آپ سے (آئندہ کسی اور غزوہ کے موقع پر جہاد کے لئے) نکلنے کی اجازت چاہیں تو ان سے فرما دیجئے گا کہ (اب) تم میرے ساتھ کبھی بھی ہرگز نہ نکلنا اور تم میرے ساتھ ہو کر کبھی بھی ہرگز دشمن سے جنگ نہ کرنا (کیونکہ) تم پہلی مرتبہ (جہاد چھوڑ کر) پیچھے بیٹھے رہنے سے خوش ہوئے تھے سو (اب بھی) پیچھے بیٹھے رہ جانے والوں کے ساتھ بیٹھے رہو،\qt@no{83}}%
\qt@newcmd\qurantrans@ur@mcccxix{اور آپ کبھی بھی ان (منافقوں) میں سے جو کوئی مر جائے اس (کے جنازے) پر نماز نہ پڑھیں اور نہ ہی آپ اس کی قبر پر کھڑے ہوں (کیونکہ آپ کا کسی جگہ قدم رکھنا بھی رحمت و برکت کا باعث ہوتا ہے اور یہ آپ کی رحمت و برکت کے حق دار نہیں ہیں)۔ بیشک انہوں نے اللہ اور اس کے رسول (صلی اللہ علیہ وآلہ وسلم) کے ساتھ کفر کیا اور وہ نافرمان ہونے کی حالت میں ہی مر گئے،\qt@no{84}}%
\qt@newcmd\qurantrans@ur@mcccxx{اور ان کے مال اور ان کی اولاد آپ کو تعجب میں نہ ڈالیں۔ اللہ فقط یہ چاہتا ہے کہ ان چیزوں کے ذریعے انہیں دنیا میں (بھی) عذاب دے اور ان کی جانیں اس حال میں نکلیں کہ وہ کافر (ہی) ہوں،\qt@no{85}}%
\qt@newcmd\qurantrans@ur@mcccxxi{اور جب کوئی (ایسی) سورت نازل کی جاتی ہے کہ تم اللہ پر ایمان لاؤ اور اس کے رسول (صلی اللہ علیہ وآلہ وسلم) کی معیت میں جہاد کرو تو ان میں سے دولت اور طاقت والے لوگ آپ سے رخصت چاہتے ہیں اور کہتے ہیں: آپ ہمیں چھوڑ دیں ہم (پیچھے) بیٹھے رہنے والوں کے ساتھ ہو جائیں،\qt@no{86}}%
\qt@newcmd\qurantrans@ur@mcccxxii{انہوں نے یہ پسند کیا کہ وہ پیچھے رہ جانے والی عورتوں، بچوں اور معذوروں کے ساتھ ہو جائیں اور ان کے دلوں پر مُہر لگا دی گئی ہے سو وہ کچھ نہیں سمجھتے،\qt@no{87}}%
\qt@newcmd\qurantrans@ur@mcccxxiii{لیکن رسول (صلی اللہ علیہ وآلہ وسلم) اور جو لوگ ان کے ساتھ ایمان لائے اپنے مالوں اور اپنی جانوں کے ساتھ جہاد کرتے ہیں اور انہی لوگوں کے لئے سب بھلائیاں ہیں اور وہی لوگ مراد پانے والے ہیں،\qt@no{88}}%
\qt@newcmd\qurantrans@ur@mcccxxiv{اللہ نے ان کے لئے جنتیں تیار فرما رکھی ہیں جن کے نیچے سے نہریں جاری ہیں (وہ) ان میں ہمیشہ رہنے والے ہیں، یہی بہت بڑی کامیابی ہے،\qt@no{89}}%
\qt@newcmd\qurantrans@ur@mcccxxv{اور صحرا نشینوں میں سے کچھ بہانہ ساز (معذرت کرنے کے لئے دربارِ رسالت صلی اللہ علیہ وآلہ وسلم میں) آئے تاکہ انہیں (بھی) رخصت دے دی جائے، اور وہ لوگ جنہوں نے (اپنے دعویٰ ایمان میں) اللہ اور اس کے رسول (صلی اللہ علیہ وآلہ وسلم) سے جھوٹ بولا تھا (جہاد چھوڑ کر پیچھے) بیٹھے رہے، عنقریب ان میں سے ان لوگوں کو جنہوں نے کفر کیا دردناک عذاب پہنچے گا،\qt@no{90}}%
\qt@newcmd\qurantrans@ur@mcccxxvi{ضعیفوں (کمزوروں) پر کوئی گناہ نہیں اور نہ بیماروں پر اور نہ (ہی) ایسے لوگوں پر ہے جو اس قدر (وسعت بھی) نہیں پاتے جسے خرچ کریں جبکہ وہ اللہ اور اس کے رسول (صلی اللہ علیہ وآلہ وسلم) کے لئے خالص و مخلص ہو چکے ہوں، نیکوکاروں (یعنی صاحبانِ احسان) پر الزام کی کوئی راہ نہیں اور اللہ بڑا بخشنے والا نہایت مہربان ہے،\qt@no{91}}%
\qt@newcmd\qurantrans@ur@mcccxxvii{اور نہ ایسے لوگوں پر (طعنہ و الزام کی راہ ہے) جبکہ وہ آپ کی خدمت میں (اس لئے) حاضر ہوئے کہ آپ انہیں (جہاد کے لئے) سوار کریں (کیونکہ ان کے پاس اپنی کوئی سواری نہ تھی تو) آپ نے فرمایا: میں (بھی) کوئی (زائد سواری) نہیں پاتا ہوں جس پر تمہیں سوار کر سکوں، (تو) وہ (آپ کے اذن سے) اس حالت میں لوٹے کہ ان کی آنکھیں (جہاد سے محرومی کے) غم میں اشکبار تھیں کہ (افسوس) وہ (اس قدر) زادِ راہ نہیں پاتے جسے وہ خرچ کر سکیں (اور شریک جہاد ہو سکیں)،\qt@no{92}}%
\qt@newcmd\qurantrans@ur@mcccxxviii{الزام کی) راہ تو فقط ان لوگوں پر ہے جو آپ سے رخصت طلب کرتے ہیں حالانکہ وہ مال دار ہیں، وہ اس بات سے خوش ہیں کہ وہ پیچھے رہ جانے والی عورتوں اور معذوروں کے ساتھ رہیں اور اللہ نے ان کے دلوں پر مہر لگا دی ہے، سو وہ جانتے ہی نہیں (کہ حقیقی سود و زیاں کیا ہے)،\qt@no{93}}%
\qt@newcmd\qurantrans@ur@mcccxxix{اے مسلمانو!) وہ تم سے عذر خواہی کریں گے جب تم ان کی طرف (اس سفرِ تبوک سے) پلٹ کر جاؤ گے، (اے حبیب!) آپ فرما دیجئے: بہانے مت بناؤ ہم ہرگز تمہاری بات پر یقین نہیں کریں گے، ہمیں اﷲ نے تمہارے حالات سے باخبر کردیا ہے، اور اب (آئندہ) تمہارا عمل (دنیا میں بھی) اﷲ دیکھے گا اور اس کا رسول (صلی اللہ علیہ وآلہ وسلم) بھی (دیکھے گا) پھر تم (آخرت میں بھی) ہر پوشیدہ اور ظاہر کو جاننے والے (رب) کی طرف لوٹائے جاؤ گے تو وہ تمہیں ان تمام (اعمال) سے خبردار فرما دے گا جو تم کیا کرتے تھے،\qt@no{94}}%
\qt@newcmd\qurantrans@ur@mcccxxx{اب وہ تمہارے لئے اﷲ کی قََسمیں کھائیں گے جب تم ان کی طرف پلٹ کر جاؤ گے تاکہ تم ان سے درگزر کرو، پس تم ان کی طرف التفات ہی نہ کرو بیشک وہ پلید ہیں اور ان کا ٹھکانا جہنم ہے یہ اس کا بدلہ ہے جو وہ کمایا کرتے تھے،\qt@no{95}}%
\qt@newcmd\qurantrans@ur@mcccxxxi{یہ تمہارے لئے قَسمیں کھاتے ہیں تاکہ تم ان سے راضی ہو جاؤ، سو (اے مسلمانو!) اگرتم ان سے راضی بھی ہوجاؤ تو (بھی) اﷲ نافرمان قو م سے راضی نہیں ہوگا،\qt@no{96}}%
\qt@newcmd\qurantrans@ur@mcccxxxii{یہ) دیہاتی لوگ سخت کافر اور سخت منافق ہیں اور (اپنے کفر و نفاق کی شدت کے باعث) اسی قابل ہیں کہ وہ ان حدود و احکام سے جاہل رہیں جو اللہ نے اپنے رسول (صلی اللہ علیہ وآلہ وسلم) پر نازل فرمائے ہیں، اور اﷲ خوب جاننے والا، بڑی حکمت والا ہے،\qt@no{97}}%
\qt@newcmd\qurantrans@ur@mcccxxxiii{اور ان دیہاتی گنواروں میں سے وہ شخص (بھی) ہے جو اس (مال) کو تاوان قرار دیتا ہے جسے وہ (راہِ خدا میں) خرچ کرتا ہے اور تم پر زمانہ کی گردشوں (یعنی مصائب و آلام) کا انتظار کرتا رہتا ہے، (بَلا و مصیبت کی) بری گردش انہی پر ہے، اور اﷲ خوب سننے والا خوب جاننے والا ہے،\qt@no{98}}%
\qt@newcmd\qurantrans@ur@mcccxxxiv{اور بادیہ نشینوں میں (ہی) وہ شخص (بھی) ہے جو اﷲ پر اور یومِ آخرت پر ایمان رکھتا ہے اور جو کچھ (راہِ خدا میں) خرچ کرتاہے اسے اﷲ کے حضور تقرب اور رسول (صلی اللہ علیہ وآلہ وسلم) کی (رحمت بھری) دعائیں لینے کا ذریعہ سمجھتا ہے، سن لو! بیشک وہ ان کے لئے باعثِ قربِ الٰہی ہے، جلد ہی اﷲ انہیں اپنی رحمت میں داخل فرما دے گا۔ بیشک اللہ بڑا بخشنے والا نہایت مہربان ہے،\qt@no{99}}%
\qt@newcmd\qurantrans@ur@mcccxxxv{اور مہاجرین اور ان کے مددگار (انصار) میں سے سبقت لے جانے والے، سب سے پہلے ایمان لانے والے اور درجۂ احسان کے ساتھ اُن کی پیروی کرنے والے، اللہ ان (سب) سے راضی ہوگیا اور وہ (سب) اس سے راضی ہوگئے اور اس نے ان کے لئے جنتیں تیار فرما رکھی ہیں جن کے نیچے نہریں بہہ رہی ہیں، وہ ان میں ہمیشہ ہمیشہ رہنے والے ہیں، یہی زبردست کامیابی ہے،\qt@no{100}}%
\qt@newcmd\qurantrans@ur@mcccxxxvi{اور (مسلمانو!) تمہارے گرد و نواح کے دیہاتی گنواروں میں بعض منافق ہیں اور بعض باشندگانِ مدینہ بھی، یہ لوگ نفاق پر اڑے ہوئے ہیں، آپ انہیں (اب تک) نہیں جانتے، ہم انہیں جانتے ہیں (بعد میں حضور صلی اللہ علیہ وآلہ وسلم کو بھی جملہ منافقین کا علم اور معرفت عطا کر دی گئی)۔ عنقریب ہم انہیں دو مرتبہ (دنیا ہی میں) عذاب دیں گے٭ پھر وہ (قیامت میں) بڑے عذاب کی طرف پلٹائے جائیں گے، ٭ ایک بار جب ان کی پہچان کرا دی گئی اور حضور صلی اللہ علیہ وآلہ وسلم نے خطبۂ جمعہ کے دوران ان منافقین کو نام لے لے کر مسجد سے نکال دیا، یہ پہلا عذاب بصورتِ ذلت و رسوائی تھا؛ اور دوسرا عذاب بصورتِ ہلاکت و مُقاتلہ ہوا جس کا حکم بعد میں آیا۔\qt@no{101}}%
\qt@newcmd\qurantrans@ur@mcccxxxvii{اور دوسرے وہ لو گ کہ (جنہوں نے) اپنے گناہوں کا اعتراف کر لیا ہے انہوں نے کچھ نیک عمل اور دوسرے برے کاموں کو (غلطی سے) ملا جلا دیا ہے، قریب ہے کہ اﷲ ان کی توبہ قبول فرمالے، بیشک اﷲ بڑا بخشنے والا نہایت مہربان ہے،\qt@no{102}}%
\qt@newcmd\qurantrans@ur@mcccxxxviii{آپ ان کے اموال میں سے صدقہ (زکوٰۃ) وصول کیجئے کہ آپ اس (صدقہ) کے باعث انہیں (گناہوں سے) پاک فرما دیں اور انہیں (ایمان و مال کی پاکیزگی سے) برکت بخش دیں اور ان کے حق میں دعا فرمائیں، بیشک آپ کی دعا ان کے لئے (باعثِ) تسکین ہے، اور اﷲ خوب سننے والا خوب جاننے والا ہے،\qt@no{103}}%
\qt@newcmd\qurantrans@ur@mcccxxxix{کیا وہ نہیں جانتے کہ بیشک اﷲ ہی تو اپنے بندوں سے (ان کی) توبہ قبول فرماتا ہے اور صدقات (یعنی زکوٰۃ و خیرات اپنے دستِ قدرت سے) وصول فرماتا ہے اور یہ کہ اﷲ ہی بڑا توبہ قبول فرمانے والا نہایت مہربان ہے؟،\qt@no{104}}%
\qt@newcmd\qurantrans@ur@mcccxl{اور فرما دیجئے: تم عمل کرو، سو عنقریب تمہارے عمل کو اﷲ (بھی) دیکھ لے گا اور اس کا رسول (صلی اللہ علیہ وآلہ وسلم بھی) اور اہلِ ایمان (بھی)، اور تم عنقریب ہر پوشیدہ اور ظاہر کو جاننے والے (رب) کی طرف لوٹائے جاؤ گے، سو وہ تمہیں ان اعمال سے خبردار فرما دے گا جو تم کرتے رہتے تھے،\qt@no{105}}%
\qt@newcmd\qurantrans@ur@mcccxli{اور کچھ دوسرے (بھی) ہیں جو اللہ کے (آئندہ) حکم کے لئے مؤخر رکھے گئے ہیں وہ یا تو انہیں عذاب دے گا یا ان کی توبہ قبول فرمالے گا، اور اﷲ خوب جاننے والا بڑی حکمت والا ہے،\qt@no{106}}%
\qt@newcmd\qurantrans@ur@mcccxlii{اور (منافقین میں سے وہ بھی ہیں) جنہوں نے ایک مسجد تیار کی ہے (مسلمانوں کو) نقصان پہنچانے اور کفر (کو تقویت دینے) اور اہلِ ایمان کے درمیان تفرقہ پیدا کرنے اور اس شخص کی گھات کی جگہ بنانے کی غرض سے جو اﷲ اور اس کے رسول (صلی اللہ علیہ وآلہ وسلم) سے پہلے ہی سے جنگ کر رہا ہے، اور وہ ضرور قَسمیں کھائیں گے کہ ہم نے (اس مسجد کے بنانے سے) سوائے بھلائی کے اور کوئی ارادہ نہیں کیا، اور اﷲ گواہی دیتا ہے کہ وہ یقیناً جھوٹے ہیں،\qt@no{107}}%
\qt@newcmd\qurantrans@ur@mcccxliii{اے حبیب!) آپ اس (مسجد کے نام پر بنائی گئی عمارت) میں کبھی بھی کھڑے نہ ہوں۔ البتہ وہ مسجد، جس کی بنیاد پہلے ہی دن سے تقوٰی پر رکھی گئی ہے، حق دار ہے کہ آپ اس میں قیام فرما ہوں۔ اس میں ایسے لوگ ہیں جو (ظاہراً و باطناً) پاک رہنے کو پسند کرتے ہیں، اور اﷲ طہارت شعار لوگوں سے محبت فرماتا ہے،\qt@no{108}}%
\qt@newcmd\qurantrans@ur@mcccxliv{بھلا وہ شخص جس نے اپنی عمارت (یعنی مسجد) کی بنیاد اللہ سے ڈرنے او ر (اس کی) رضا و خوشنودی پر رکھی، بہتر ہے یا وہ شخص جس نے اپنی عمارت کی بنیاد ایسے گڑھے کے کنارے پر رکھی جو گرنے والا ہے۔ سو وہ (عمارت) اس معمار کے ساتھ ہی آتشِ دوزخ میں گر پڑی، اور اللہ ظالم لوگوں کو ہدایت نہیں فرماتا،\qt@no{109}}%
\qt@newcmd\qurantrans@ur@mcccxlv{ان کی عمارت جسے انہوں نے (مسجد کے نام پر) بنا رکھا ہے ہمیشہ ان کے دلوں میں (شک اور نفاق کے باعث) کھٹکتی رہے گی سوائے اس کے کہ ان کے دل (مسلسل خراش کی وجہ سے) پارہ پارہ ہو جائیں، اور اﷲ خوب جاننے والا بڑی حکمت والا ہے،\qt@no{110}}%
\qt@newcmd\qurantrans@ur@mcccxlvi{بیشک اﷲ نے اہلِ ایمان سے ان کی جانیں اور ان کے مال، ان کے لئے جنت کے عوض خرید لئے ہیں، (اب) وہ اللہ کی راہ میں قتال کرتے ہیں، سو وہ (حق کی خاطر) قتل کرتے ہیں اور (خود بھی) قتل کئے جاتے ہیں۔ (اﷲ نے) اپنے ذمۂ کرم پر پختہ وعدہ (لیا) ہے، تَورات میں (بھی) انجیل میں (بھی) اور قرآن میں (بھی)، اور کون اپنے وعدہ کو اﷲ سے زیادہ پورا کرنے والا ہے، سو (ایمان والو!) تم اپنے سودے پر خوشیاں مناؤ جس کے عوض تم نے (جان و مال کو) بیچا ہے، اور یہی تو زبردست کامیابی ہے،\qt@no{111}}%
\qt@newcmd\qurantrans@ur@mcccxlvii{یہ مومنین جنہوں نے اللہ سے اُخروی سودا کر لیا ہے) توبہ کرنے والے، عبادت گذار، (اللہ کی) حمد و ثنا کرنے والے، دنیوی لذتوں سے کنارہ کش روزہ دار، (خشوع و خضوع سے) رکوع کرنے والے، (قربِ الٰہی کی خاطر) سجود کرنے والے، نیکی کاحکم کرنے والے اور برائی سے روکنے والے اور اللہ کی (مقرر کردہ) حدود کی حفاظت کرنے والے ہیں، اور ان اہلِ ایمان کو خوشخبری سنا دیجئے،\qt@no{112}}%
\qt@newcmd\qurantrans@ur@mcccxlviii{نبی (صلی اللہ علیہ وآلہ وسلم) اور ایمان والوں کی شان کے لائق نہیں کہ مشرکوں کے لئے دعائے مغفرت کریں اگرچہ وہ قرابت دار ہی ہوں اس کے بعد کہ ان کے لئے واضح ہو چکا کہ وہ (مشرکین) اہلِ جہنم ہیں،\qt@no{113}}%
\qt@newcmd\qurantrans@ur@mcccxlix{اور ابراہیم (علیہ السلام) کا اپنے باپ (یعنی چچا آزر، جس نے آپ کو پالا تھا) کے لئے دعائے مغفرت کرنا صرف اس وعدہ کی غرض سے تھا جو وہ اس سے کر چکے تھے، پھر جب ان پر یہ ظاہر ہوگیا کہ وہ اللہ کا دشمن ہے تو وہ اس سے بے زار ہوگئے (اس سے لاتعلق ہوگئے اور پھر کبھی اس کے حق میں دعا نہ کی)۔ بیشک ابراہیم (علیہ السلام) بڑے دردمند (گریہ و زاری کرنے والے اور) نہایت بردبار تھے،\qt@no{114}}%
\qt@newcmd\qurantrans@ur@mcccl{اور اللہ کی شان نہیں کہ وہ کسی قوم کو گمراہ کر دے اس کے بعد کہ اس نے انہیں ہدایت سے نواز دیا ہو، یہاں تک کہ وہ ان کے لئے وہ چیزیں واضح فرما دے جن سے انہیں پرہیزکرنا چاہئے، بیشک اﷲ ہر چیز کو خوب جاننے والا ہے،\qt@no{115}}%
\qt@newcmd\qurantrans@ur@mcccli{بیشک اللہ ہی کے لئے آسمانوں اور زمین کی ساری بادشاہی ہے، (وہی) جِلاتا اور مارتا ہے، اور تمہارے لئے اﷲ کے سوا نہ کوئی دوست ہے اور نہ کوئی مددگار (جو اَمرِ الہٰی کے خلاف تمہاری حمایت کر سکے،\qt@no{116}}%
\qt@newcmd\qurantrans@ur@mccclii{یقیناً اﷲ نے نبی (معظم صلی اللہ علیہ وآلہ وسلم) پر رحمت سے توجہ فرمائی اور ان مہاجرین اور انصار پر (بھی) جنہوں نے (غزوۂ تبوک کی) مشکل گھڑی میں (بھی) آپ (صلی اللہ علیہ وآلہ وسلم) کی پیروی کی اس (صورتِ حال) کے بعد کہ قریب تھا کہ ان میں سے ایک گروہ کے دل پھر جاتے، پھر وہ ان پر لطف و رحمت سے متوجہ ہوا، بیشک وہ ان پر نہایت شفیق، نہایت مہربان ہے،\qt@no{117}}%
\qt@newcmd\qurantrans@ur@mcccliii{اور ان تینوں شخصوں پر (بھی نظرِ رحمت فرما دی) جن (کے فیصلہ) کو مؤخر کیا گیا تھا یہاں تک کہ جب زمین باوجود کشادگی کے ان پر تنگ ہوگئی اور (خود) ان کی جانیں (بھی) ان پر دوبھر ہوگئیں اور انہیں یقین ہوگیا کہ اﷲ (کے عذاب) سے پناہ کا کوئی ٹھکانا نہیں بجز اس کی طرف (رجوع کے)، تب اﷲ ان پر لطف وکرم سے مائل ہوا تاکہ وہ (بھی) توبہ و رجوع پر قائم رہیں، بیشک اﷲ ہی بڑا توبہ قبول فرمانے والا، نہایت مہربان ہے،\qt@no{118}}%
\qt@newcmd\qurantrans@ur@mcccliv{اے ایمان والو! اﷲ سے ڈرتے رہو اور اہلِ صدق (کی معیت) میں شامل رہو،\qt@no{119}}%
\qt@newcmd\qurantrans@ur@mccclv{اہلِ مدینہ اور ان کے گرد و نواح کے (رہنے والے) دیہاتی لوگوں کے لئے مناسب نہ تھا کہ وہ رسول اﷲ (صلی اللہ علیہ وآلہ وسلم) سے (الگ ہو کر) پیچھے رہ جائیں اور نہ یہ کہ ان کی جانِ (مبارک) سے زیادہ اپنی جانوں سے رغبت رکھیں، یہ (حکم) اس لئے ہے کہ انہیں اﷲ کی راہ میں جو پیاس (بھی) لگتی ہے اور جو مشقت (بھی) پہنچتی ہے اور جو بھوک (بھی) لگتی ہے اور جو کسی ایسی جگہ پر چلتے ہیں جہاں کاچلنا کافروں کو غضبناک کرتا ہے اور دشمن سے جو کچھ بھی پاتے ہیں (خواہ قتل اور زخم ہو یا مالِ غنیمت وغیرہ) مگر یہ کہ ہر ایک بات کے بدلہ میں ان کے لئے ایک نیک عمل لکھا جاتا ہے۔ بیشک اللہ نیکوکاروں کا اَجر ضائع نہیں فرماتا،\qt@no{120}}%
\qt@newcmd\qurantrans@ur@mccclvi{اور نہ یہ کہ وہ (مجاہدین) تھوڑا خرچہ کرتے ہیں اور نہ بڑا اور نہ (ہی) کسی میدان کو (راہِ خدا میں) طے کرتے ہیں مگر ان کے لئے (یہ سب صرف و سفر) لکھ دیا جاتا ہے تاکہ اللہ انہیں (ہر اس عمل کی) بہتر جزا دے جو وہ کیا کرتے تھے،\qt@no{121}}%
\qt@newcmd\qurantrans@ur@mccclvii{اور یہ تو ہو نہیں سکتا کہ سارے کے سارے مسلمان (ایک ساتھ) نکل کھڑے ہوں، تو ان میں سے ہر ایک گروہ (یا قبیلہ) کی ایک جماعت کیوں نہ نکلے کہ وہ لوگ دین میں تفقہ (یعنی خوب فہم و بصیرت) حاصل کریں اور وہ اپنی قوم کو ڈرائیں جب وہ ان کی طرف پلٹ کر آئیں تاکہ وہ (گناہوں اور نافرمانی کی زندگی سے) بچیں،\qt@no{122}}%
\qt@newcmd\qurantrans@ur@mccclviii{اے ایمان والو! تم کافروں میں سے ایسے لوگوں سے جنگ کرو جو تمہارے قریب ہیں (یعنی جو تمہیں اور تمہارے دین کو براہِ راست نقصان پہنچا رہے ہیں) اور (جہاد ایسا اور اس وقت ہو کہ) وہ تمہارے اندر (طاقت و شجاعت کی) سختی پائیں، اورجان لو کہ اللہ پرہیزگاروں کے ساتھ ہے،\qt@no{123}}%
\qt@newcmd\qurantrans@ur@mccclix{اور جب بھی کوئی سورت نازل کی جاتی ہے تو ان (منافقوں) میں سے بعض (شرارتاً) یہ کہتے ہیں کہ تم میں سے کون ہے جسے اس (سورت) نے ایمان میں زیادتی بخشی ہے، پس جو لوگ ایمان لے آئے ہیں سو اس (سورت) نے ان کے ایمان کو زیادہ کردیا اور وہ (اس کیفیتِ ایمانی پر) خوشیاں مناتے ہیں،\qt@no{124}}%
\qt@newcmd\qurantrans@ur@mccclx{اور جن لوگوں کے دلوں میں بیماری ہے تو اس (سورت) نے ان کی خباثتِ (کفر و نفاق) پر مزید پلیدی (اور خباثت) بڑھا دی اور وہ اس حالت میں مرے کہ کافر ہی تھے،\qt@no{125}}%
\qt@newcmd\qurantrans@ur@mccclxi{کیا وہ نہیں دیکھتے کہ وہ ہر سال میں ایک بار یا دو بار مصیبت میں مبتلا کئے جاتے ہیں پھر (بھی) وہ توبہ نہیں کرتے اور نہ ہی وہ نصیحت پکڑتے ہیں،\qt@no{126}}%
\qt@newcmd\qurantrans@ur@mccclxii{اورجب بھی کوئی سورت نازل کی جاتی ہے تو وہ ایک دوسرے کی طرف دیکھتے ہیں، (اور اشاروں سے پوچھتے ہیں) کہ کیا تمہیں کوئی دیکھ تو نہیں رہا پھر وہ پلٹ جاتے ہیں۔ اللہ نے ان کے دلوں کو پلٹ دیا ہے کیونکہ یہ وہ لوگ ہیں جو سمجھ نہیں رکھتے،\qt@no{127}}%
\qt@newcmd\qurantrans@ur@mccclxiii{بیشک تمہارے پاس تم میں سے (ایک باعظمت) رسول (صلی اللہ علیہ وآلہ وسلم) تشریف لائے۔ تمہارا تکلیف و مشقت میں پڑنا ان پر سخت گراں (گزرتا) ہے۔ (اے لوگو!) وہ تمہارے لئے (بھلائی اور ہدایت کے) بڑے طالب و آرزو مند رہتے ہیں (اور) مومنوں کے لئے نہایت (ہی) شفیق بے حد رحم فرمانے والے ہیں،\qt@no{128}}%
\qt@newcmd\qurantrans@ur@mccclxiv{اگر (ان بے پناہ کرم نوازیوں کے باوجود) پھر (بھی) وہ روگردانی کریں تو فرما دیجئے: مجھے اللہ کافی ہے اس کے سوا کوئی معبود نہیں، میں اسی پر بھروسہ کئے ہوئے ہوں اور وہ عرشِ عظیم کا مالک ہے،\qt@no{129}}%
\qt@newcmd\qurantrans@ur@mccclxv{\basmalahur الف، لام، را (حقیقی معنی اﷲ اور رسول صلی اللہ علیہ وآلہ وسلم ہی بہتر جانتے ہیں)، یہ حکمت والی کتاب کی آیتیں ہیں،\qt@no{1}}%
\qt@newcmd\qurantrans@ur@mccclxvi{کیا یہ بات لوگوں کے لئے تعجب خیز ہے کہ ہم نے انہی میں سے ایک مردِ (کامل) کی طرف وحی بھیجی کہ آپ (بھولے بھٹکے ہوئے) لوگوں کو (عذابِ الٰہی کا) ڈر سنائیں اور ایمان والوں کو خوشخبری سنائیں کہ ان کے لئے ان کے رب کی بارگاہ میں بلند پایہ (یعنی اونچا مرتبہ) ہے، کافر کہنے لگے: بیشک یہ شخص تو کھلا جادوگر ہے،\qt@no{2}}%
\qt@newcmd\qurantrans@ur@mccclxvii{یقیناً تمہارا رب اللہ ہے جس نے آسمانوں اور زمین (کی بالائی و زیریں کائنات) کو چھ دنوں (یعنی چھ مدتوں یا مرحلوں) میں (تدریجاً) پیدا فرمایا پھر وہ عرش پر (اپنے اقتدار کے ساتھ) جلوہ افروز ہوا (یعنی تخلیقِ کائنات کے بعد اس کے تمام عوالم اور اَجرام میں اپنے قانون اور نظام کے اجراء کی صورت میں متمکن ہوا) وہی ہر کام کی تدبیر فرماتا ہے (یعنی ہر چیز کو ایک نظام کے تحت چلاتا ہے۔ اس کے حضور) اس کی اجازت کے بغیر کوئی سفارش کرنے والا نہیں، یہی (عظمت و قدرت والا) اللہ تمہارا رب ہے، سو تم اسی کی عبادت کرو، پس کیا تم (قبولِ نصیحت کے لئے) غور نہیں کرتے،\qt@no{3}}%
\qt@newcmd\qurantrans@ur@mccclxviii{لوگو!) تم سب کو اسی کی طرف لوٹ کر جانا ہے (یہ) اللہ کا سچا وعدہ ہے۔ بیشک وہی پیدائش کی ابتداء کرتا ہے پھر وہی اسے دہرائے گا تاکہ ان لوگوں کو جو ایمان لائے اور نیک عمل کئے، انصاف کے ساتھ جزا دے، اور جن لوگوں نے کفر کیا ان کے لئے پینے کو کھولتا ہوا پانی اور دردناک عذاب ہے، اس کا بدلہ جو وہ کفر کیا کرتے تھے،\qt@no{4}}%
\qt@newcmd\qurantrans@ur@mccclxix{وہی ہے جس نے سورج کو روشنی (کا منبع) بنایا اور چاند کو (اس سے) روشن (کیا) اور اس کے لئے (کم و بیش دکھائی دینے کی) منزلیں مقرر کیں تاکہ تم برسوں کا شمار اور (اوقات کا) حساب معلوم کر سکو، اور اللہ نے یہ (سب کچھ) نہیں پیدا فرمایا مگر درست تدبیر کے ساتھ، وہ (ان کائناتی حقیقتوں کے ذریعے اپنی خالقیت، وحدانیت اور قدرت کی) نشانیاں ان لوگوں کے لئے تفصیل سے واضح فرماتا ہے جو علم رکھتے ہیں،\qt@no{5}}%
\qt@newcmd\qurantrans@ur@mccclxx{بیشک رات اور دن کے بدلتے رہنے میں اور ان (جملہ) چیزوں میں جو اللہ نے آسمانوں اور زمین میں پیدا فرمائی ہیں (اسی طرح) ان لوگوں کے لئے نشانیاں ہیں جو تقوٰی رکھتے ہیں،\qt@no{6}}%
\qt@newcmd\qurantrans@ur@mccclxxi{بیشک جو لوگ ہم سے ملنے کی امید نہیں رکھتے اور دنیوی زندگی سے خوش ہیں اور اسی سے مطمئن ہوگئے ہیں اور جو ہماری نشانیوں سے غافل ہیں،\qt@no{7}}%
\qt@newcmd\qurantrans@ur@mccclxxii{انہی لوگوں کا ٹھکانا جہنم ہے ان اعمال کے بدلہ میں جو وہ کماتے رہے،\qt@no{8}}%
\qt@newcmd\qurantrans@ur@mccclxxiii{بیشک جو لوگ ایمان لائے اور نیک عمل کرتے رہے انہیں ان کا رب ان کے ایمان کے باعث (جنتوں تک) پہنچا دے گا، جہاں ان (کی رہائش گاہوں) کے نیچے سے نہریں بہہ رہی ہوں گی (یہ ٹھکانے) اُخروی نعمت کے باغات میں (ہوں گے)،\qt@no{9}}%
\qt@newcmd\qurantrans@ur@mccclxxiv{نعمتوں اور بہاروں کو دیکھ کر) ان (جنتوں) میں ان کی دعا (یہ) ہوگی: ”اے اللہ! تو پاک ہے“ اور اس میں ان کی آپس میں دعائے خیر (کا کلمہ) ”سلام“ ہوگا (یا اللہ تعالیٰ اور فرشتوں کی طرف سے ان کے لئے کلمۂ استقبال ”سلام“ ہوگا) اور ان کی دعا (ان کلمات پر) ختم ہوگی کہ ”تمام تعریفیں اللہ کے لئے ہیں جو سب جہانوں کا پروردگار ہے“،\qt@no{10}}%
\qt@newcmd\qurantrans@ur@mccclxxv{اور اگر اللہ (ان کافر) لوگوں کو برائی (یعنی عذاب) پہنچانے میں جلدبازی کرتا، جیسے وہ طلبِ نعمت میں جلدبازی کرتے ہیں تو یقیناً ان کی میعادِ (عمر) ان کے حق میں (جلد) پوری کردی گئی ہوتی (تاکہ وہ مَر کے جلد دوزخ میں پہنچیں)، بلکہ ہم ایسے لوگوں کو جو ہم سے ملاقات کی توقع نہیں رکھتے ان کی سرکشی میں چھوڑے رکھتے ہیں کہ وہ بھٹکتے رہیں،\qt@no{11}}%
\qt@newcmd\qurantrans@ur@mccclxxvi{اور جب (ایسے) انسان کو کوئی تکلیف پہنچتی ہے تو وہ ہمیں اپنے پہلو پر لیٹے یا بیٹھے یا کھڑے پکارتا ہے، پھر جب ہم اس سے اس کی تکلیف دور کردیتے ہیں تو وہ (ہمیں بھلا کر اس طرح) چل دیتا ہے گویا اس نے کسی تکلیف میں جو اسے پہنچی تھی ہمیں (کبھی) پکارا ہی نہیں تھا۔ اسی طرح حد سے بڑھنے والوں کے لئے ان کے (غلط) اَعمال آراستہ کر کے دکھائے گئے ہیں جو وہ کرتے رہے تھے،\qt@no{12}}%
\qt@newcmd\qurantrans@ur@mccclxxvii{اور بیشک ہم نے تم سے پہلے (بھی بہت سی) قوموں کو ہلاک کر دیا جب انہوں نے ظلم کیا، اور ان کے رسول ان کے پاس واضح نشانیاں لے کر آئے مگر وہ ایمان لاتے ہی نہ تھے، اسی طرح ہم مجرم قوم کو (ان کے عمل کی) سزا دیتے ہیں،\qt@no{13}}%
\qt@newcmd\qurantrans@ur@mccclxxviii{پھر ہم نے ان کے بعد تمہیں زمین میں (ان کا) جانشین بنایا تاکہ ہم دیکھیں کہ (اب) تم کیسے عمل کرتے ہو،\qt@no{14}}%
\qt@newcmd\qurantrans@ur@mccclxxix{اور جب ان پر ہماری روشن آیتیں تلاوت کی جاتی ہیں تو وہ لوگ جو ہم سے ملاقات کی توقع نہیں رکھتے، کہتے ہیں کہ اس (قرآن) کے سوا کوئی اور قرآن لے آئیے یا اسے بدل دیجئے، (اے نبیِ مکرّم!) فرما دیں: مجھے حق نہیں کہ میں اسے اپنی طرف سے بدل دوں، میں تو فقط جو میری طرف وحی کی جاتی ہے (اس کی) پیروی کرتا ہوں، اگر میں اپنے رب کی نافرمانی کروں تو بیشک میں بڑے دن کے عذاب سے ڈرتا ہوں،\qt@no{15}}%
\qt@newcmd\qurantrans@ur@mccclxxx{فرما دیجئے: اگر اللہ چاہتا تو نہ ہی میں اس (قرآن) کو تمہارے اوپر تلاوت کرتا اور نہ وہ (خود) تمہیں اس سے باخبر فرماتا، بیشک میں اس (قرآن کے اترنے) سے قبل (بھی) تمہارے اندر عمر (کا ایک حصہ) بسر کرچکا ہوں، سو کیا تم عقل نہیں رکھتے،\qt@no{16}}%
\qt@newcmd\qurantrans@ur@mccclxxxi{پس اس شخص سے بڑھ کر ظالم کون ہوگا جو اللہ پر جھوٹا بہتان باندھے یا اس کی آیتوں کو جھٹلا دے۔ بیشک مجرم لوگ فلاح نہیں پائیں گے،\qt@no{17}}%
\qt@newcmd\qurantrans@ur@mccclxxxii{اور (مشرکین) اللہ کے سوا ان (بتوں) کو پوجتے ہیں جو نہ انہیں نقصان پہنچا سکتے ہیں اور نہ انہیں نفع پہنچا سکتے ہیں اور (اپنی باطل پوجا کے جواز میں) کہتے ہیں کہ یہ (بت) اللہ کے حضور ہمارے سفارشی ہیں، فرما دیجئے: کیا تم اللہ کو اس (شفاعتِ اَصنام کے من گھڑت) مفروضہ سے آگاہ کر رہے ہو جس (کے وجود) کو وہ نہ آسمانوں میں جانتا ہے اور نہ زمین میں (یعنی اس کی بارگاہ میں کسی بت کا سفارش کرنا اس کے علم میں نہیں ہے)۔ اس کی ذات پاک ہے اور وہ ان سب چیزوں سے بلند و بالا ہے جنہیں یہ (اس کا) شریک گردانتے ہیں،\qt@no{18}}%
\qt@newcmd\qurantrans@ur@mccclxxxiii{اور سارے لوگ (ابتداء) میں ایک ہی جماعت تھے پھر(باہم اختلاف کر کے) جدا جدا ہو گئے، اور اگر آپ کے رب کی طرف سے ایک بات پہلے سے طے نہ ہوچکی ہوتی (کہ عذاب میں جلد بازی نہیں ہوگی) تو ان کے درمیان ان باتوں کے بارے میں فیصلہ کیا جا چکا ہوتا جن میں وہ اختلاف کرتے ہیں،\qt@no{19}}%
\qt@newcmd\qurantrans@ur@mccclxxxiv{اور وہ (اب اسی مہلت کی وجہ سے) کہتے ہیں کہ اس (رسول صلی اللہ علیہ وآلہ وسلم) پر ان کے رب کی طرف سے کوئی (فیصلہ کن) نشانی کیوں نازل نہیں کی گئی، آپ فرما دیجئے: غیب تو محض اللہ ہی کے لئے ہے، سو تم انتظار کرو میں بھی تمہارے ساتھ انتظار کرنے والوں میں سے ہوں،\qt@no{20}}%
\qt@newcmd\qurantrans@ur@mccclxxxv{اور جب ہم لوگوں کو تکلیف پہنچنے کے بعد (اپنی) رحمت سے لذت آشنا کرتے ہیں تو فوراً (ہمارے احسان کو بھول کر) ہماری نشانیوں میں ان کا مکر و فریب (شروع) ہو جاتا ہے۔ فرما دیجئے: اللہ مکر کی سزا جلد دینے والا ہے۔ بیشک ہمارے بھیجے ہوئے فرشتے، جو بھی فریب تم کر رہے ہو (اسے) لکھتے رہتے ہیں،\qt@no{21}}%
\qt@newcmd\qurantrans@ur@mccclxxxvi{وہی ہے جو تمہیں خشک زمین اور سمندر میں چلنے پھرنے (کی توفیق) دیتا ہے، یہاں تک کہ جب تم کشتیوں میں (سوار) ہوتے ہو اور وہ (کشتیاں) لوگوں کو لے کر موافق ہوا کے جھونکوں سے چلتی ہیں اور وہ اس سے خوش ہوتے ہیں تو (ناگہاں) ان (کشتیوں) کو تیز و تند ہوا کا جھونکا آلیتا ہے اور ہر طرف سے ان (سواروں) کو (جوش مارتی ہوئی) موجیں آگھیرتی ہیں اور وہ سمجھنے لگتے ہیں کہ (اب) وہ ان (لہروں) سے گھر گئے (تو اس وقت) وہ اللہ کو پکارتے ہیں (اس حال میں) کہ اپنے دین کو اسی کے لئے خالص کرنے والے ہیں (اور کہتے ہیں: اے اللہ!) اگر تو نے ہمیں اس (بَلا) سے نجات بخش دی تو ہم ضرور (تیرے) شکر گزار بندوں میں سے ہوجائیں گے،\qt@no{22}}%
\qt@newcmd\qurantrans@ur@mccclxxxvii{پھر جب اللہ نے انہیں نجات دے دی تو وہ فوراً ہی ملک میں (حسبِ سابق) ناحق سرکشی کرنے لگتے ہیں۔ اے (اللہ سے بغاوت کرنے والے) لوگو! بس تمہاری سرکشی و بغاوت (کا نقصان) تمہاری ہی جانوں پر ہے۔ دنیا کی زندگی کا کچھ فائدہ (اٹھالو)، بالآخر تمہیں ہماری ہی طرف پلٹنا ہے، اُس وقت ہم تمہیں ان اَعمال سے خوب آگاہ کر دیں گے جو تم کرتے رہے تھے،\qt@no{23}}%
\qt@newcmd\qurantrans@ur@mccclxxxviii{بس دنیا کی زندگی کی مثال تو اس پانی جیسی ہے جسے ہم نے آسمان سے اتارا پھر اس کی وجہ سے زمین کی پیداوار خوب گھنی ہو کر اُگی، جس میں سے انسان بھی کھاتے ہیں اور چوپائے بھی، یہاں تک کہ جب زمین نے اپنی (پوری پوری) رونق اور حسن لے لیا اور خوب آراستہ ہوگئی اور اس کے باشندوں نے سمجھ لیا کہ (اب) ہم اس پر پوری قدرت رکھتے ہیں تو (دفعۃً) اسے رات یا دن میں ہمارا حکمِ (عذاب) آپہنچا تو ہم نے اسے (یوں) جڑ سے کٹا ہوا بنا دیا گویا وہ کل یہاں تھی ہی نہیں، اسی طرح ہم ان لوگوں کے لئے نشانیاں کھول کر بیان کرتے ہیں جو تفکر سے کام لیتے ہیں،\qt@no{24}}%
\qt@newcmd\qurantrans@ur@mccclxxxix{اور اللہ سلامتی کے گھر (جنت) کی طرف بلاتا ہے، اور جسے چاہتا ہے سیدھی راہ کی طرف ہدایت فرماتا ہے،\qt@no{25}}%
\qt@newcmd\qurantrans@ur@mcccxc{ایسے لوگوں کے لئے جو نیک کام کرتے ہیں نیک جزا ہے بلکہ (اس پر) اضافہ بھی ہے، اور نہ ان کے چہروں پر (غبار اور) سیاہی چھائے گی اور نہ ذلت و رسوائی، یہی اہلِ جنت ہیں، وہ اس میں ہمیشہ رہنے والے ہیں،\qt@no{26}}%
\qt@newcmd\qurantrans@ur@mcccxci{اور جنہوں نے برائیاں کما رکھی ہیں (ان کے لئے) برائی کا بدلہ اسی کی مثل ہوگا، اور ان پر ذلت و رسوائی چھا جائے گی ان کے لئے اللہ (کے عذاب) سے کوئی بھی بچانے والا نہیں ہوگا (یوں لگے گا) گویا ان کے چہرے اندھیری رات کے ٹکڑوں سے ڈھانپ دیئے گئے ہیں۔ یہی اہلِ جہنم ہیں، وہ اس میں ہمیشہ رہنے والے ہیں،\qt@no{27}}%
\qt@newcmd\qurantrans@ur@mcccxcii{اورجس دن ہم ان سب کو جمع کریں گے پھر ہم مشرکوں سے کہیں گے: تم اور تمہارے شریک (بتانِ باطل) اپنی اپنی جگہ ٹھہرو۔ پھر ہم ان کے درمیان پھوٹ ڈال دیں گے۔ اور ان کے (اپنے گھڑے ہوئے) شریک (ان سے) کہیں گے کہ تم ہماری عبادت تو نہیں کرتے تھے،\qt@no{28}}%
\qt@newcmd\qurantrans@ur@mcccxciii{پس ہمارے اور تمہارے درمیان اللہ ہی گواہ کافی ہے کہ ہم تمہاری پرستش سے (یقیناً) بے خبر تھے،\qt@no{29}}%
\qt@newcmd\qurantrans@ur@mcccxciv{اس (دہشت ناک) مقام پر ہر شخص ان (اعمال کی حقیقت) کو جانچ لے گا جو اس نے آگے بھیجے تھے اور وہ اللہ کی جانب لوٹائے جائیں گے جو ان کا مالکِ حقیقی ہے اور ان سے وہ بہتان تراشی جاتی رہے گی جو وہ کیا کرتے تھے،\qt@no{30}}%
\qt@newcmd\qurantrans@ur@mcccxcv{آپ (ان سے) فرما دیجئے: تمہیں آسمان اور زمین (یعنی اوپر اور نیچے) سے رزق کون دیتا ہے، یا (تمہارے) کان اور آنکھوں (یعنی سماعت و بصارت) کا مالک کون ہے، اور زندہ کو مُردہ (یعنی جاندار کو بے جان) سے کون نکالتا ہے اور مُردہ کو زندہ (یعنی بے جان کو جاندار) سے کون نکالتا ہے، اور (نظام ہائے کائنات کی) تدبیر کون فرماتا ہے؟ سو وہ کہہ اٹھیں گے کہ اللہ، تو آپ فرمائیے: پھرکیا تم (اس سے) ڈرتے نہیں،\qt@no{31}}%
\qt@newcmd\qurantrans@ur@mcccxcvi{پس یہی (عظمت و قدرت والا) اللہ ہی تو تمہارا سچا رب ہے، پس (اس) حق کے بعد سوائے گمراہی کے اور کیا ہوسکتا ہے، سو تم کہاں پھرے جارہے ہو،\qt@no{32}}%
\qt@newcmd\qurantrans@ur@mcccxcvii{اسی طرح آپ کے رب کا حکم نافرمانوں پر ثابت ہوکر رہا کہ وہ ایمان نہیں لائیں گے،\qt@no{33}}%
\qt@newcmd\qurantrans@ur@mcccxcviii{آپ (ان سے دریافت) فرمائیے کہ کیا تمہارے (بنائے ہوئے) شریکوں میں سے کوئی ایسا ہے جو تخلیق کی ابتداء کرے پھر (زندگی کے معدوم ہوجانے کے بعد) اسے دوبارہ لوٹائے؟ آپ فرما دیجئے کہ اللہ ہی (حیات کو عدم سے وجود میں لاتے ہوئے) آفرینش کا آغاز فرماتا ہے پھر وہی اس کا اعادہ (بھی) فرمائے گا، پھر تم کہاں بھٹکتے پھرتے ہو،\qt@no{34}}%
\qt@newcmd\qurantrans@ur@mcccxcix{آپ (ان سے دریافت) فرمائیے: کیا تمہارے (بنائے ہوئے) شریکوں میں سے کوئی ایسا ہے جو حق کی طرف رہنمائی کرسکے، آپ فرما دیجئے کہ اللہ ہی (دینِ) حق کی ہدایت فرماتا ہے، تو کیا جو کوئی حق کی طرف ہدایت کرے وہ زیادہ حق دار ہے کہ اس کی فرمانبرداری کی جائے یا وہ جو خود ہی راستہ نہیں پاتا مگر یہ کہ اسے راستہ دکھایا جائے (یعنی اسے اٹھا کر ایک جگہ سے دوسری جگہ پہنچایا جائے جیسے کفار اپنے بتوں کو حسبِ ضرورت اٹھا کر لے جاتے)، سو تمہیں کیا ہو گیا ہے، تم کیسے فیصلے کرتے ہو،\qt@no{35}}%
\qt@newcmd\qurantrans@ur@mcd{ان میں سے اکثر لوگ صرف گمان کی پیروی کرتے ہیں، بیشک گمان حق سے معمولی سا بھی بے نیاز نہیں کرسکتا، یقیناً اللہ خوب جانتا ہے جو کچھ وہ کرتے ہیں،\qt@no{36}}%
\qt@newcmd\qurantrans@ur@mcdi{یہ قرآن ایسا نہیں ہے کہ اسے اللہ (کی وحی) کے بغیر گھڑ لیا گیا ہو لیکن (یہ) ان (کتابوں) کی تصدیق (کرنے والا) ہے جو اس سے پہلے (نازل ہوچکی) ہیں اور جو کچھ (اللہ نے لوح میں یا احکامِ شریعت میں) لکھا ہے اس کی تفصیل ہے، اس (کی حقانیت) میں ذرا بھی شک نہیں (یہ) تمام جہانوں کے رب کی طرف سے ہے،\qt@no{37}}%
\qt@newcmd\qurantrans@ur@mcdii{کیا وہ کہتے ہیں کہ اسے رسول (صلی اللہ علیہ وآلہ وسلم) نے خود گھڑ لیا ہے، آپ فرما دیجئے: پھر تم اس کی مثل کوئی (ایک) سورت لے آؤ (اور اپنی مدد کے لئے) اللہ کے سوا جنہیں تم بلاسکتے ہو بلا لو اگر تم سچے ہو،\qt@no{38}}%
\qt@newcmd\qurantrans@ur@mcdiii{بلکہ یہ اس (کلامِ الٰہی) کو جھٹلا رہے ہیں جس کے علم کا وہ احاطہ بھی نہیں کرسکے تھے اور ابھی اس کی حقیقت (بھی) ان کے سامنے کھل کر نہ آئی تھی۔ اسی طرح ان لوگوں نے بھی (حق کو) جھٹلایا تھا جو ان سے پہلے ہو گزرے ہیں سو آپ دیکھیں کہ ظالموں کا انجام کیسا ہوا،\qt@no{39}}%
\qt@newcmd\qurantrans@ur@mcdiv{ان میں سے کوئی تو اس پر ایمان لائے گا اور انہی میں سے کوئی اس پر ایمان نہ لائے گا، اور آپ کا رب فساد انگیزی کرنے والوں کو خوب جانتا ہے،\qt@no{40}}%
\qt@newcmd\qurantrans@ur@mcdv{اور اگر وہ آپ کو جھٹلائیں تو فرما دیجئے کہ میرا عمل میرے لئے ہے اور تمہارا عمل تمہارے لئے، تم اس عمل سے بری الذمہ ہو جو میں کرتا ہوں اور میں ان اَعمال سے بری الذمہ ہوں جو تم کرتے ہو،\qt@no{41}}%
\qt@newcmd\qurantrans@ur@mcdvi{اور ان میں سے بعض وہ ہیں جو (ظاہراً) آپ کی طرف کان لگاتے ہیں، تو کیا آپ بہروں کو سنا دیں گے خواہ وہ کچھ عقل بھی نہ رکھتے ہوں،\qt@no{42}}%
\qt@newcmd\qurantrans@ur@mcdvii{ان میں سے بعض وہ ہیں جو (ظاہراً) آپ کی طرف دیکھتے ہیں، کیا آپ اندھوں کو راہ دکھا دیں گے خواہ وہ کچھ بصارت بھی نہ رکھتے ہوں،\qt@no{43}}%
\qt@newcmd\qurantrans@ur@mcdviii{بیشک اللہ لوگوں پر ذرّہ برابر ظلم نہیں کرتا لیکن لوگ (خود ہی) اپنی جانوں پر ظلم کرتے ہیں،\qt@no{44}}%
\qt@newcmd\qurantrans@ur@mcdix{اور جس دن وہ انہیں جمع کرے گا (وہ محسوس کریں گے) گویا وہ دن کی ایک گھڑی کے سوا دنیا میں ٹھہرے ہی نہ تھے، وہ ایک دوسرے کو پہچانیں گے۔ بیشک وہ لوگ خسارے میں رہے جنہوں نے اللہ سے ملاقات کو جھٹلایا تھا اور وہ ہدایت یافتہ نہ ہوئے،\qt@no{45}}%
\qt@newcmd\qurantrans@ur@mcdx{اور خواہ ہم آپ کو اس (عذاب) کا کچھ حصہ (دنیا میں ہی) دکھا دیں جس کا ہم ان سے وعدہ کر رہے ہیں (اور ہم آپ کی حیاتِ مبارکہ میں ایسا کریں گے) یا (اس سے پہلے) ہم آپ کو وفات بخش دیں، تو انہیں (بہر صورت) ہماری ہی طرف لوٹنا ہے، پھر اللہ (خود) اس پر گواہ ہے جو کچھ وہ کر رہے ہیں،\qt@no{46}}%
\qt@newcmd\qurantrans@ur@mcdxi{اور ہر امت کے لئے ایک رسول آتا رہا ہے۔ پھر جب ان کا رسول (واضح نشانیوں کے ساتھ) آچکا (اور وہ پھر بھی نہ مانے) تو ان میں انصاف کے ساتھ فیصلہ کر دیا گیا، اور (قیامت کے دن بھی اسی طرح ہوگا) ان پر ظلم نہیں کیا جائے گا،\qt@no{47}}%
\qt@newcmd\qurantrans@ur@mcdxii{اور وہ (طعنہ زنی کے طور پر) کہتے ہیں کہ یہ وعدۂ (عذاب) کب (پورا) ہوگا (مسلمانو! بتاؤ) اگر تم سچے ہو،\qt@no{48}}%
\qt@newcmd\qurantrans@ur@mcdxiii{فرما دیجئے: میں اپنی ذات کے لئے نہ کسی نقصان کا مالک ہوں اور نہ نفع کا، مگر جس قدر اللہ چاہے۔ ہر امت کے لئے ایک میعاد (مقرر) ہے، جب ان کی (مقررہ) میعاد آپہنچتی ہے تو وہ نہ ایک گھڑی پیچھے ہٹ سکتے ہیں اور نہ آگے بڑھ سکتے ہیں،\qt@no{49}}%
\qt@newcmd\qurantrans@ur@mcdxiv{آپ فرما دیجئے: (اے کافرو!) ذرا غور تو کرو اگر تم پر اس کا عذاب (ناگہاں) راتوں رات یا دن دہاڑے آپہنچے (تو تم کیا کرلوگے؟) وہ کیا چیز ہے کہ مجرم لوگ اس سے جلدی چاہتے ہیں؟،\qt@no{50}}%
\qt@newcmd\qurantrans@ur@mcdxv{کیا جس وقت وہ (عذاب) واقع ہوجائے گا تو تم اس پر ایمان لے آؤ گے، (اس وقت تم سے کہا جائے گا:) اب (ایمان لا رہے ہو؟ اس وقت کوئی فائدہ نہیں) حالانکہ تم (استہزاءً) اسی (عذاب) میں جلدی چاہتے تھے،\qt@no{51}}%
\qt@newcmd\qurantrans@ur@mcdxvi{پھر (ان) ظالموں سے کہا جائے گا: تم دائمی عذاب کا مزہ چکھو، تمہیں (کچھ بھی اور) بدلہ نہیں دیا جائے گا، مگر انہی اعمال کا جو تم کماتے رہے تھے،\qt@no{52}}%
\qt@newcmd\qurantrans@ur@mcdxvii{اور وہ آپ سے دریافت کرتے ہیں کہ کیا (دائمی عذاب کی) وہ بات (واقعی) سچ ہے؟ فرما دیجئے: ہاں میرے رب کی قسم یقیناً وہ بالکل حق ہے۔ اور تم (اپنے انکار سے اللہ کو) عاجز نہیں کرسکتے،\qt@no{53}}%
\qt@newcmd\qurantrans@ur@mcdxviii{اگر ہر ظالم شخص کی ملکیت میں وہ (ساری دولت) ہو جو زمین میں ہے تو وہ یقیناً اسے (اپنی جان چھڑانے کے لئے) عذاب کے بدلہ میں دے ڈالے، اور (ایسے لوگ) جب عذاب کو دیکھیں گے تو اپنی ندامت چھپائے پھریں گے اور ان کے درمیان انصاف کے ساتھ فیصلہ کردیا جائے گا اور ان پر ظلم نہیں ہوگا،\qt@no{54}}%
\qt@newcmd\qurantrans@ur@mcdxix{جان لو! جو کچھ بھی آسمانوں اور زمین میں ہے (سب) اللہ ہی کا ہے۔ خبردار ہو جاؤ! بیشک اللہ کا وعدہ سچا ہے لیکن ان میں سے اکثر لوگ نہیں جانتے،\qt@no{55}}%
\qt@newcmd\qurantrans@ur@mcdxx{وہی جِلاتا اور مارتا ہے اور تم اسی کی طرف پلٹائے جاؤ گے،\qt@no{56}}%
\qt@newcmd\qurantrans@ur@mcdxxi{اے لوگو! بیشک تمہارے پاس تمہارے رب کی طرف سے نصیحت اور ان (بیماریوں) کی شفاء آگئی ہے جو سینوں میں (پوشیدہ) ہیں اور ہدایت اور اہلِ ایمان کے لئے رحمت (بھی)،\qt@no{57}}%
\qt@newcmd\qurantrans@ur@mcdxxii{فرما دیجئے: (یہ سب کچھ) اللہ کے فضل اور اس کی رحمت کے باعث ہے (جو بعثتِ محمدی صلی اللہ علیہ وآلہ وسلم کے ذریعے تم پر ہوا ہے) پس مسلمانوں کو چاہئے کہ اس پر خوشیاں منائیں، یہ اس (سارے مال و دولت) سے کہیں بہتر ہے جسے وہ جمع کرتے ہیں،\qt@no{58}}%
\qt@newcmd\qurantrans@ur@mcdxxiii{فرما دیجئے: ذرا بتاؤ تو سہی اللہ نے جو (پاکیزہ) رزق تمہارے لئے اتارا سو تم نے اس میں سے بعض (چیزوں) کو حرام اور (بعض کو) حلال قرار دے دیا۔ فرما دیں: کیا اللہ نے تمہیں (اس کی) اجازت دی تھی یا تم اللہ پر بہتان باندھ رہے ہو،\qt@no{59}}%
\qt@newcmd\qurantrans@ur@mcdxxiv{اور ایسے لوگوں کا روزِ قیامت کے بارے میں کیا خیال ہے جو اللہ پر جھوٹا بہتان باندھتے ہیں، بیشک اللہ لوگوں پر فضل فرمانے والا ہے لیکن ان میں سے اکثر (لوگ) شکر گزار نہیں ہیں،\qt@no{60}}%
\qt@newcmd\qurantrans@ur@mcdxxv{اور (اے حبیبِ مکرّم!) آپ جس حال میں بھی ہوں اور آپ اس کی طرف سے جس قدر بھی قرآن پڑھ کر سناتے ہیں اور (اے امتِ محمدیہ!) تم جو عمل بھی کرتے ہو مگر ہم (اس وقت) تم سب پر گواہ و نگہبان ہوتے ہیں جب تم اس میں مشغول ہوتے ہو، اور آپ کے رب (کے علم) سے ایک ذرّہ برابر بھی (کوئی چیز) نہ زمین میں پوشیدہ ہے اور نہ آسمان میں اور نہ اس (ذرہ) سے کوئی چھوٹی چیز ہے اور نہ بڑی مگر واضح کتاب (یعنی لوحِ محفوظ) میں (درج) ہے،\qt@no{61}}%
\qt@newcmd\qurantrans@ur@mcdxxvi{خبردار! بیشک اولیاء اللہ پر نہ کوئی خوف ہے اورنہ وہ رنجیدہ و غمگین ہوں گے،\qt@no{62}}%
\qt@newcmd\qurantrans@ur@mcdxxvii{وہ) ایسے لوگ ہیں جو ایمان لائے اور (ہمیشہ) تقوٰی شعار رہے،\qt@no{63}}%
\qt@newcmd\qurantrans@ur@mcdxxviii{ان کے لئے دنیا کی زندگی میں (بھی عزت و مقبولیت کی) بشارت ہے اور آخرت میں (بھی مغفرت و شفاعت کی/ یا دنیا میں بھی نیک خوابوں کی صورت میں پاکیزہ روحانی مشاہدات ہیں اور آخرت میں بھی حُسنِ مطلق کے جلوے اور دیدار)، اللہ کے فرمان بدلا نہیں کرتے، یہی وہ عظیم کامیابی ہے،\qt@no{64}}%
\qt@newcmd\qurantrans@ur@mcdxxix{اے حبیبِ مکرّم!) ان کی (عناد و عداوت پر مبنی) گفتگو آپ کو غمگین نہ کرے۔ بیشک ساری عزت و غلبہ اللہ ہی کے لئے ہے (جو جسے چاہتا ہے دیتا ہے)، وہ خوب سننے والا جاننے والا ہے،\qt@no{65}}%
\qt@newcmd\qurantrans@ur@mcdxxx{جان لو جو کوئی آسمانوں میں ہے اور جو کوئی زمین میں ہے سب اللہ ہی کے (مملوک) ہیں، اور جو لوگ اللہ کے سوا (بتوں) کی پرستش کرتے ہیں (درحقیقت اپنے گھڑے ہوئے) شریکوں کی پیروی (بھی) نہیں کرتے، بلکہ وہ صرف (اپنے) وہم و گمان کی پیروی کرتے ہیں اور وہ محض غلط اندازے لگاتے رہتے ہیں،\qt@no{66}}%
\qt@newcmd\qurantrans@ur@mcdxxxi{وہی ہے جس نے تمہارے لئے رات بنائی تاکہ تم اس میں آرام کرو اور دن کو روشن بنایا (تاکہ تم اس میں کام کاج کر سکو)۔ بیشک اس میں ان لوگوں کے لئے نشانیاں ہیں جو (غور سے) سنتے ہیں،\qt@no{67}}%
\qt@newcmd\qurantrans@ur@mcdxxxii{وہ کہتے ہیں: اللہ نے (اپنے لئے) بیٹا بنا لیا ہے (حالانکہ) وہ اس سے پاک ہے، وہ بے نیاز ہے۔ جو کچھ آسمانوں میں اور جو کچھ زمین میں ہے سب اسی کی مِلک ہے، تمہارے پاس اس (قولِ باطل) کی کوئی دلیل نہیں، کیا تم اللہ پر وہ (بات) کہتے ہو جسے تم (خود بھی) نہیں جانتے؟،\qt@no{68}}%
\qt@newcmd\qurantrans@ur@mcdxxxiii{فرما دیجئے: بیشک جو لوگ اللہ پرجھوٹا بہتان باندھتے ہیں وہ فلاح نہیں پائیں گے،\qt@no{69}}%
\qt@newcmd\qurantrans@ur@mcdxxxiv{دنیا میں (چند روزہ) لطف اندوزی ہے پھر انہیں ہماری ہی طرف پلٹنا ہے پھر ہم انہیں سخت عذاب کا مزہ چکھائیں گے اس کے بدلے میں جو وہ کفر کیا کرتے تھے،\qt@no{70}}%
\qt@newcmd\qurantrans@ur@mcdxxxv{اور ان پر نوح (علیہ السلام) کا قصہ بیان فرمائیے، جب انہوں نے اپنی قوم سے کہا: اے میری قوم (اولادِ قابیل!) اگر تم پر میرا قیام اور میرا اللہ کی آیتوں کے ساتھ نصیحت کرنا گراں گزر رہا ہے تو (جان لو کہ) میں نے تو صرف اللہ ہی پر توکل کرلیا ہے (اور تمہارا کوئی ڈر نہیں) سو تم اکٹھے ہوکر (میری مخالفت میں) اپنی تدبیر کو پختہ کرلو اور اپنے (گھڑے ہوئے) شریکوں کو بھی (ساتھ ملا لو اور اس قدر سوچ لو کہ) پھر تمہاری تدبیر (کا کوئی پہلو) تم پر مخفی نہ رہے، پھر میرے ساتھ (جو جی میں آئے) کر گزرو اور (مجھے) کوئی مہلت نہ دو،\qt@no{71}}%
\qt@newcmd\qurantrans@ur@mcdxxxvi{سو اگر تم نے (میری نصیحت سے) منہ پھیر لیا ہے تو میں نے تم سے کوئی معاوضہ تو نہیں مانگا، میرا اجر تو صرف اللہ (کے ذمۂ کرم) پر ہے اور مجھے یہ حکم دیا گیا ہے کہ میں (اس کے حکم کے سامنے) سرِ تسلیم خم کئے رکھوں،\qt@no{72}}%
\qt@newcmd\qurantrans@ur@mcdxxxvii{پھر آپ کی قوم نے آپ کو جھٹلایا پس ہم نے انہیں اور جو ان کے ساتھ کشتی میں تھے (عذابِ طوفان سے) نجات دی اور ہم نے انہیں (زمین میں) جانشین بنادیا اور ان لوگوں کو غرق کردیا جنہوں نے ہماری آیتوں کو جھٹلایا تھا، سو آپ دیکھئے کہ ان لوگوں کا انجام کیسا ہوا جو ڈرائے گئے تھے،\qt@no{73}}%
\qt@newcmd\qurantrans@ur@mcdxxxviii{پھر ہم نے ان کے بعد (کتنے ہی) رسولوں کو ان کی قوموں کی طرف بھیجا سو وہ ان کے پاس واضح نشانیاں لے کر آئے پس وہ لوگ (بھی) ایسے نہ ہوئے کہ اس (بات) پر ایمان لے آتے جسے وہ پہلے جھٹلا چکے تھے۔ اسی طرح ہم سرکشی کرنے والوں کے دلوں پر مُہر لگا دیا کرتے ہیں،\qt@no{74}}%
\qt@newcmd\qurantrans@ur@mcdxxxix{پھر ہم نے ان کے بعد موسٰی اور ہارون (علیھما السلام) کو فرعون اور اس کے سردارانِ قوم کی طرف نشانیوں کے ساتھ بھیجا تو انہوں نے تکبر کیا اور وہ مجرم لوگ تھے،\qt@no{75}}%
\qt@newcmd\qurantrans@ur@mcdxl{پھر جب ان کے پاس ہماری طرف سے حق آیا (تو) کہنے لگے: بیشک یہ تو کھلا جادو ہے،\qt@no{76}}%
\qt@newcmd\qurantrans@ur@mcdxli{موسٰی (علیہ السلام) نے کہا: کیا تم (ایسی بات) حق سے متعلق کہتے ہو جب وہ تمہارے پاس آچکا ہے، (عقل و شعور کی آنکھیں کھول کر دیکھو) کیا یہ جادو ہے؟ اور جادوگر (کبھی) فلاح نہیں پاسکیں گے،\qt@no{77}}%
\qt@newcmd\qurantrans@ur@mcdxlii{وہ کہنے لگے: (اے موسٰی!) کیا تم ہمارے پاس اس لئے آئے ہو کہ تم ہمیں اس (طریقہ) سے پھیر دو جس پر ہم نے اپنے باپ دادا کو (گامزن) پایا اور زمین (یعنی سرزمینِ مصر) میں تم دونوں کی بڑائی (قائم) رہے؟ اور ہم لوگ تم دونوں کو ماننے والے نہیں ہیں،\qt@no{78}}%
\qt@newcmd\qurantrans@ur@mcdxliii{اور فرعون کہنے لگا: میرے پاس ہر ماہر جادوگر کو لے آؤ،\qt@no{79}}%
\qt@newcmd\qurantrans@ur@mcdxliv{پھر جب جادوگر آگئے تو موسٰی (علیہ السلام) نے ان سے کہا: تم (وہ چیزیں میدان میں) ڈال دو جو تم ڈالنا چاہتے ہو،\qt@no{80}}%
\qt@newcmd\qurantrans@ur@mcdxlv{پھر جب انہوں نے (اپنی رسیاں اور لاٹھیاں) ڈال دیں تو موسٰی (علیہ السلام) نے کہا: جو کچھ تم لائے ہو (یہ) جادو ہے، بیشک اللہ ابھی اسے باطل کر دے گا، یقیناً اللہ مفسدوں کے کام کو درست نہیں کرتا،\qt@no{81}}%
\qt@newcmd\qurantrans@ur@mcdxlvi{اور اللہ اپنے کلمات سے حق کا حق ہونا ثابت فرما دیتا ہے اگرچہ مجرم لوگ اسے ناپسند ہی کرتے رہیں،\qt@no{82}}%
\qt@newcmd\qurantrans@ur@mcdxlvii{پس موسٰی (علیہ السلام) پر ان کی قوم کے چند جوانوں کے سوا (کوئی) ایمان نہ لایا، فرعون اور اپنے (قومی) سرداروں (وڈیروں) سے ڈرتے ہوئے کہ کہیں وہ انہیں (کسی) مصیبت میں مبتلا نہ کر دیں، اور بیشک فرعون سرزمینِ (مصر) میں بڑا جابر و سرکش تھا، اور وہ یقیناً (ظلم میں) حد سے بڑھ جانے والوں میں سے تھا،\qt@no{83}}%
\qt@newcmd\qurantrans@ur@mcdxlviii{اور موسٰی (علیہ السلام) نے کہا: اے میری قوم! اگر تم اللہ پر ایمان لائے ہو تو اسی پر توکل کرو، اگر تم (واقعی) مسلمان ہو،\qt@no{84}}%
\qt@newcmd\qurantrans@ur@mcdxlix{تو انہوں نے عرض کیا: ہم نے اللہ ہی پر توکل کیا ہے، اے ہمارے رب! تو ہمیں ظالم لوگوں کے لئے نشانہء ستم نہ بنا،\qt@no{85}}%
\qt@newcmd\qurantrans@ur@mcdl{اور تو ہمیں اپنی رحمت سے کافروں کی قوم (کے تسلّط) سے نجات بخش دے،\qt@no{86}}%
\qt@newcmd\qurantrans@ur@mcdli{اور ہم نے موسٰی (علیہ السلام) اور ان کے بھائی کی طرف وحی بھیجی کہ تم دونوں مصر (کے شہر) میں اپنی قوم کے لئے چند مکانات تیار کرو اور اپنے (ان) گھروں کو (نماز کی ادائیگی کے لئے) قبلہ رخ بناؤ اور (پھر) نماز قائم کرو، اور ایمان والوں کو (فتح و نصرت کی) خوشخبری سنا دو،\qt@no{87}}%
\qt@newcmd\qurantrans@ur@mcdlii{اور موسٰی (علیہ السلام) نے کہا: اے ہمارے رب! بیشک تو نے فرعون اور اس کے سرداروں کو دنیوی زندگی میں اسبابِ زینت اور مال و دولت (کی کثرت) دے رکھی ہے، اے ہمارے رب! (کیا تو نے انہیں یہ سب کچھ اس لئے دیا ہے) تاکہ وہ (لوگوں کو کبھی لالچ اور کبھی خوف دلا کر) تیری راہ سے بہکا دیں۔ اے ہمارے رب! تو ان کی دولتوں کو برباد کردے اور ان کے دلوں کو (اتنا) سخت کردے کہ وہ پھر بھی ایمان نہ لائیں حتٰی کہ وہ دردناک عذاب دیکھ لیں،\qt@no{88}}%
\qt@newcmd\qurantrans@ur@mcdliii{ارشاد ہوا: بیشک تم دونوں کی دعا قبول کرلی گئی، سو تم دونوں ثابت قدم رہنا اور ایسے لوگوں کے راستہ کی پیروی نہ کرنا جو علم نہیں رکھتے،\qt@no{89}}%
\qt@newcmd\qurantrans@ur@mcdliv{اور ہم بنی اسرائیل کو دریا کے پار لے گئے پس فرعون اوراس کے لشکر نے سرکشی اور ظلم و تعدّی سے ان کا تعاقب کیا، یہاں تک کہ جب اسے (یعنی فرعون کو) ڈوبنے نے آلیا وہ کہنے لگا: میں اس پر ایمان لے آیا کہ کوئی معبود نہیں سوائے اس (معبود) کے جس پر بنی اسرائیل ایمان لائے ہیں اور میں (اب) مسلمانوں میں سے ہوں،\qt@no{90}}%
\qt@newcmd\qurantrans@ur@mcdlv{جواب دیا گیا کہ) اب (ایمان لاتا ہے)؟ حالانکہ تو پہلے (مسلسل) نافرمانی کرتا رہا ہے اور تو فساد بپا کرنے والوں میں سے تھا،\qt@no{91}}%
\qt@newcmd\qurantrans@ur@mcdlvi{اے فرعون!) سو آج ہم تیرے (بے جان) جسم کو بچالیں گے تاکہ تو اپنے بعد والوں کے لئے (عبرت کا) نشان ہوسکے اور بیشک اکثر لوگ ہماری نشانیوں (کو سمجھنے) سے غافل ہیں،\qt@no{92}}%
\qt@newcmd\qurantrans@ur@mcdlvii{اور فی الواقع ہم نے بنی اسرائیل کو رہنے کے لئے عمدہ جگہ بخشی اور ہم نے انہیں پاکیزہ رزق عطا کیا تو انہوں نے کوئی اختلاف نہ کیا یہاں تک کہ ان کے پاس علم و دانش آپہنچی۔ بیشک آپ کا رب ان کے درمیان قیامت کے دن ان امور کا فیصلہ فرما دے گا جن میں وہ اختلاف کرتے تھے،\qt@no{93}}%
\qt@newcmd\qurantrans@ur@mcdlviii{اے سننے والے!) اگر تو اس (کتاب) کے بارے میں ذرا بھی شک میں مبتلا ہے جو ہم نے (اپنے رسول صلی اللہ علیہ وآلہ وسلم کی وساطت سے) تیری طرف اتاری ہے تو (اس کی حقانیت کی نسبت) ان لوگوں سے دریافت کرلے جو تجھ سے پہلے (اللہ کی) کتاب پڑھ رہے ہیں۔ بیشک تیری طرف تیرے رب کی جانب سے حق آگیا ہے، سو تُو شک کرنے والوں میں سے ہرگز نہ ہوجانا،\qt@no{94}}%
\qt@newcmd\qurantrans@ur@mcdlix{اور نہ ہرگز ان لوگوں میں سے ہوجانا جو اللہ کی آیتوں کو جھٹلاتے رہے ورنہ تُو خسارہ پانے والوں میں سے ہو جائے گا،\qt@no{95}}%
\qt@newcmd\qurantrans@ur@mcdlx{اے حبیبِ مکرّم!) بیشک جن لوگوں پر آپ کے رب کا فرمان صادق آچکا ہے وہ ایمان نہیں لائیں گے،\qt@no{96}}%
\qt@newcmd\qurantrans@ur@mcdlxi{اگرچہ ان کے پاس سب نشانیاں آجائیں یہاں تک کہ وہ دردناک عذاب (بھی) دیکھ لیں،\qt@no{97}}%
\qt@newcmd\qurantrans@ur@mcdlxii{پھر قومِ یونس (کی بستی) کے سوا کوئی اور ایسی بستی کیوں نہ ہوئی جو ایمان لائی ہو اور اسے اس کے ایمان لانے نے فائدہ دیا ہو۔ جب (قومِ یونس کے لوگ نزولِ عذاب سے قبل صرف اس کی نشانی دیکھ کر) ایمان لے آئے تو ہم نے ان سے دنیوی زندگی میں (ہی) رسوائی کا عذاب دور کردیا اور ہم نے انہیں ایک مدت تک منافع سے بہرہ مند رکھا،\qt@no{98}}%
\qt@newcmd\qurantrans@ur@mcdlxiii{اور اگر آپ کا رب چاہتا تو ضرور سب کے سب لوگ جو زمین میں آباد ہیں ایمان لے آتے، (جب رب نے انہیں جبراً مومن نہیں بنایا) تو کیا آپ لوگوں پر جبر کریں گے یہاں تک کہ وہ مومن ہوجائیں،\qt@no{99}}%
\qt@newcmd\qurantrans@ur@mcdlxiv{اور کسی شخص کو (اَز خود یہ) قدرت نہیں کہ وہ بغیر اِذنِ الٰہی کے ایمان لے آئے۔ وہ (یعنی اللہ تعالی) کفر کی گندگی انہی لوگوں پر ڈالتا ہے جو (حق کو سمجھنے کے لئے) عقل سے کام نہیں لیتے،\qt@no{100}}%
\qt@newcmd\qurantrans@ur@mcdlxv{فرما دیجئے: تم لوگ دیکھو تو (سہی) آسمانوں اور زمین (کی اس وسیع کائنات) میں قدرتِ الٰہیہ کی کیا کیا نشانیاں ہیں اور (یہ) نشانیاں اور (عذابِ الٰہی سے) ڈرانے والے (پیغمبر) ایسے لوگوں کو فائدہ نہیں پہنچا سکتے جو ایمان لانا ہی نہیں چاہتے،\qt@no{101}}%
\qt@newcmd\qurantrans@ur@mcdlxvi{سو کیا یہ لوگ انہی لوگوں (کے بُرے دنوں) جیسے دِنوں کا انتظار کر رہے ہیں جو ان سے پہلے گزر چکے ہیں؟ فرما دیجئے کہ تم (بھی) انتظار کرو میں (بھی) تمہارے ساتھ انتظار کرنے والوں میں سے ہوں،\qt@no{102}}%
\qt@newcmd\qurantrans@ur@mcdlxvii{پھر ہم اپنے رسولوں کو بچا لیتے ہیں اور ان لوگوں کو بھی جو اس طرح ایمان لے آتے ہیں، (یہ بات) ہمارے ذمۂ کرم پر ہے کہ ہم ایمان والوں کو بچا لیں،\qt@no{103}}%
\qt@newcmd\qurantrans@ur@mcdlxviii{فرما دیجئے: اے لوگو! اگر تم میرے دین (کی حقانیت کے بارے) میں ذرا بھی شک میں ہو تو (سن لو) کہ میں ان (بتوں) کی پرستش نہیں کرسکتا جن کی تم اللہ کے سوا پرستش کرتے ہو لیکن میں تو اس اللہ کی عبادت کرتا ہوں جو تمہیں موت سے ہمکنار کرتا ہے، اور مجھے حکم دیا گیا ہے کہ میں (ہمیشہ) اہلِ ایمان میں سے رہوں،\qt@no{104}}%
\qt@newcmd\qurantrans@ur@mcdlxix{اور یہ کہ آپ ہر باطل سے بچ کر (یک سُو ہو کر) اپنا رخ دین پر قائم رکھیں اور ہرگز شرک کرنے والوں میں سے نہ ہوں،\qt@no{105}}%
\qt@newcmd\qurantrans@ur@mcdlxx{یہ حکم رسول اﷲ صلی اللہ علیہ وآلہ وسلم کی وساطت سے امت کو دیا جارہا ہے:) اور نہ اللہ کے سوا ان (بتوں) کی عبادت کریں جو نہ تمہیں نفع پہنچا سکتے ہیں اور نہ تمہیں نقصان پہنچا سکتے ہیں، پھر اگر تم نے ایسا کیا تو بیشک تم اس وقت ظالموں میں سے ہو جاؤ گے،\qt@no{106}}%
\qt@newcmd\qurantrans@ur@mcdlxxi{اور اگر اللہ تمہیں کوئی تکلیف پہنچائے تو اس کے سوا کوئی اسے دور کرنے والا نہیں اور اگر وہ تمہارے ساتھ بھلائی کا ارادہ فرمائے تو کوئی اس کے فضل کو ردّ کرنے والا نہیں۔ وہ اپنے بندوں میں سے جسے چاہتا ہے اپنا فضل پہنچاتا ہے، اور وہ بڑا بخشنے والا نہایت مہربان ہے،\qt@no{107}}%
\qt@newcmd\qurantrans@ur@mcdlxxii{فرما دیجئے: اے لوگو! بیشک تمہارے پاس تمہارے رب کی جانب سے حق آگیا ہے، سو جس نے راہِ ہدایت اختیار کی بس وہ اپنے ہی فائدے کے لئے ہدایت اختیار کرتا ہے اور جو گمراہ ہوگیا بس وہ اپنی ہی ہلاکت کے لئے گمراہ ہوتا ہے اور میں تمہارے اوپر داروغہ نہیں ہوں (کہ تمہیں سختی سے راہِ ہدایت پر لے آؤں)،\qt@no{108}}%
\qt@newcmd\qurantrans@ur@mcdlxxiii{اے رسول!) آپ اسی کی اتباع کریں جو آپ کی طرف وحی کی جاتی ہے اور صبر کرتے رہیں یہاں تک کہ اللہ فیصلہ فرما دے، اور وہ سب سے بہتر فیصلہ فرمانے والا ہے،\qt@no{109}}%
\qt@newcmd\qurantrans@ur@mcdlxxiv{\basmalahur الف، لام، را (حقیقی معنی اﷲ اور رسول صلی اللہ علیہ وآلہ وسلم ہی بہتر جانتے ہیں، یہ وہ) کتاب ہے جس کی آیتیں مستحکم بنا دی گئی ہیں، پھر حکمت والے باخبر (رب) کی جانب سے وہ مفصل بیان کر دی گئی ہیں،\qt@no{1}}%
\qt@newcmd\qurantrans@ur@mcdlxxv{یہ کہ اللہ کے سوا تم کسی کی عبادت مت کرو، بیشک میں تمہارے لئے اس (اللہ) کی جانب سے ڈر سنانے والا اور بشارت دینے والا ہوں،\qt@no{2}}%
\qt@newcmd\qurantrans@ur@mcdlxxvi{اور یہ کہ تم اپنے رب سے مغفرت طلب کرو پھر تم اس کے حضور (صدقِ دل سے) توبہ کرو وہ تمہیں وقتِ معین تک اچھی متاع سے لطف اندوز رکھے گا اور ہر فضیلت والے کو اس کی فضیلت کی جزا دے گا (یعنی اس کے اَعمال و ریاضت کی کثرت کے مطابق اَجر و درجات عطا فرمائے گا)، اور اگر تم نے روگردانی کی تو میں تم پر بڑے دن کے عذاب کا خوف رکھتا ہوں،\qt@no{3}}%
\qt@newcmd\qurantrans@ur@mcdlxxvii{تمہیں اللہ ہی کی طرف لوٹنا ہے، اور وہ ہر چیز پر بڑا قادر ہے،\qt@no{4}}%
\qt@newcmd\qurantrans@ur@mcdlxxviii{جان لو! بیشک وہ (کفار) اپنے سینوں کو دُہرا کر لیتے ہیں تاکہ وہ اس (خدا) سے (اپنے دلوں کا حال) چھپا سکیں، خبردار! جس وقت وہ اپنے کپڑے (جسموں پر) اوڑھ لیتے ہیں (تو اس وقت بھی) وہ ان سب باتوں کو جانتا ہے جو وہ چھپاتے ہیں اور جو وہ آشکار کرتے ہیں، بیشک وہ سینوں کی (پوشیدہ) باتوں کو خوب جاننے والا ہے،\qt@no{5}}%
\qt@newcmd\qurantrans@ur@mcdlxxix{اور زمین میں کوئی چلنے پھرنے والا (جاندار) نہیں ہے مگر (یہ کہ) اس کا رزق اﷲ (کے ذمۂ کرم) پر ہے اور وہ اس کے ٹھہرنے کی جگہ کو اور اس کے امانت رکھے جانے کی جگہ کو (بھی) جانتا ہے، ہر بات کتابِ روشن (لوحِ محفوظ) میں (درج) ہے،\qt@no{6}}%
\qt@newcmd\qurantrans@ur@mcdlxxx{اور وہی (اﷲ) ہے جس نے آسمانوں اور زمین (کی بالائی و زیریں کائناتوں) کو چھ روز (یعنی تخلیق و اِرتقاء کے چھ اَدوار و مراحل) میں پیدا فرمایا اور (تخلیقِ اَرضی سے قبل) اس کا تختِ اقتدار پانی پر تھا (اور اس نے اس سے زندگی کے تمام آثار کو اور تمہیں پیدا کیا) تاکہ وہ تمہیں آزمائے کہ تم میں سے کون عمل کے اعتبار سے بہتر ہے؟ اور اگر آپ یہ فرمائیں کہ تم لوگ مرنے کے بعد (زندہ کر کے) اٹھائے جاؤ گے تو کافر یقینًا (یہ) کہیں گے کہ یہ تو صریح جادو کے سوا کچھ (اور) نہیں ہے،\qt@no{7}}%
\qt@newcmd\qurantrans@ur@mcdlxxxi{اور اگر ہم ان سے چند مقررہ دنوں تک عذاب کو مؤخر کردیں تو وہ یقینًا کہیں گے کہ اسے کس چیز نے روک رکھا ہے، خبردار! جس دن وہ (عذاب) ان پر آئے گا (تو) ان سے پھیرا نہ جائے گا اور وہ (عذاب) انہیں گھیر لے گا جس کا وہ مذاق اڑایا کرتے تھے،\qt@no{8}}%
\qt@newcmd\qurantrans@ur@mcdlxxxii{اور اگر ہم انسان کو اپنی جانب سے رحمت کا مزہ چکھاتے ہیں پھر ہم اسے (کسی وجہ سے) اس سے واپس لے لیتے ہیں تو وہ نہایت مایوس (اور) ناشکرگزار ہو جاتا ہے،\qt@no{9}}%
\qt@newcmd\qurantrans@ur@mcdlxxxiii{اور اگر ہم اسے (کوئی) نعمت چکھاتے ہیں اس تکلیف کے بعد جو اسے پہنچ چکی تھی تو ضرور کہہ اٹھتا ہے کہ مجھ سے ساری تکلیفیں جاتی رہیں، بیشک وہ بڑا خوش ہونے والا (اور) فخر کرنے والا (بن جاتا) ہے،\qt@no{10}}%
\qt@newcmd\qurantrans@ur@mcdlxxxiv{سوائے ان لوگوں کے جنہوں نے صبر کیا اور نیک عمل کرتے رہے، (تو) ایسے لوگوں کے لئے مغفرت اور بڑا اجر ہے،\qt@no{11}}%
\qt@newcmd\qurantrans@ur@mcdlxxxv{بھلا کیا یہ ممکن ہے کہ آپ اس میں سے کچھ چھوڑ دیں جو آپ کی طرف وحی کیا گیا ہے اور اس سے آپ کا سینہء (اَطہر) تنگ ہونے لگے (اس خیال سے) کہ کفار یہ کہتے ہیں کہ اس (رسول صلی اللہ علیہ وآلہ وسلم) پر کوئی خزانہ کیوں نہ اتارا گیا یا اس کے ساتھ کوئی فرشتہ کیوں نہیں آیا، (ایسا ہرگز ممکن نہیں۔ اے رسولِ معظم!) آپ تو صرف ڈر سنانے والے ہیں (کسی کو دنیوی لالچ یا سزا دینے والے نہیں)، اور اﷲ ہر چیز پر نگہبان ہے،\qt@no{12}}%
\qt@newcmd\qurantrans@ur@mcdlxxxvi{کیا کفار یہ کہتے ہیں کہ پیغمبر نے اس (قرآن) کو خود گھڑ لیا ہے، فرما دیجئے: تم (بھی) اس جیسی گھڑی ہوئی دس سورتیں لے آؤ اور اﷲ کے سوا (اپنی مدد کے لئے) جسے بھی بلا سکتے ہو بلا لو اگر تم سچے ہو،\qt@no{13}}%
\qt@newcmd\qurantrans@ur@mcdlxxxvii{اے مسلمانو!) سو اگر وہ تمہاری بات قبول نہ کریں تو یقین رکھو کہ قرآن فقط اﷲ کے علم سے اتارا گیا ہے اور یہ کہ اس کے سوا کوئی معبود نہیں، پس کیا (اب) تم اسلام پر (ثابت قدم) رہو گے،\qt@no{14}}%
\qt@newcmd\qurantrans@ur@mcdlxxxviii{جو لوگ (فقط) دنیوی زندگی اور اس کی زینت (و آرائش) کے طالب ہیں ہم ان کے اعمال کا پورا پورا بدلہ اسی دنیا میں دے دیتے ہیں اور انہیں اس (دنیا کے صلہ) میں کوئی کمی نہیں دی جاتی،\qt@no{15}}%
\qt@newcmd\qurantrans@ur@mcdlxxxix{یہ وہ لوگ ہیں جن کے لئے آخرت میں کچھ (حصہ) نہیں سوائے آتشِ (دوزخ) کے، اور وہ سب (اَعمال اپنے اُخروی اَجر کے حساب سے) اکارت ہوگئے جو انہوں نے دنیا میں انجام دیئے تھے اور وہ (سب کچھ) باطل و بے کار ہوگیا جو وہ کرتے رہے تھے (کیونکہ ان کا حساب پورے اجر کے ساتھ دنیا میں ہی چکا دیا گیا ہے اور آخرت کے لئے کچھ نہیں بچا)،\qt@no{16}}%
\qt@newcmd\qurantrans@ur@mcdxc{وہ شخص جو اپنے رب کی طرف سے روشن دلیل پر ہے اور اﷲ کی جانب سے ایک گواہ (قرآن) بھی اس شخص کی تائید و تقویت کے لئے آگیا ہے اور اس سے قبل موسٰی (علیہ السلام) کی کتاب (تورات) بھی جو رہنما اور رحمت تھی (آچکی ہو) یہی لوگ اس (قرآن) پر ایمان لاتے ہیں، کیا (یہ) اور (کافر) فرقوں میں سے وہ شخص جو اس (قرآن) کا منکر ہے (برابر ہوسکتے ہیں) جبکہ آتشِ دوزخ اس کا ٹھکانا ہے، سو (اے سننے والے!) تجھے چاہئے کہ تو اس سے متعلق ذرا بھی شک میں نہ رہے، بیشک یہ (قرآن) تیرے رب کی طرف سے حق ہے لیکن اکثر لوگ ایمان نہیں لاتے،\qt@no{17}}%
\qt@newcmd\qurantrans@ur@mcdxci{اور اس سے بڑھ کر ظالم کون ہو سکتا ہے جو اﷲ پر جھوٹا بہتان باندھتا ہے، ایسے ہی لوگ اپنے رب کے حضور پیش کئے جائیں گے اور گواہ کہیں گے: یہی وہ لوگ ہیں جنہوں نے اپنے رب پر جھوٹ بولا تھا، جان لو کہ ظالموں پر اﷲ کی لعنت ہے،\qt@no{18}}%
\qt@newcmd\qurantrans@ur@mcdxcii{جو لوگ (دوسروں کو) اﷲ کی راہ سے روکتے ہیں اور اس میں کجی تلاش کرتے ہیں، اور وہی لوگ آخرت کے منکر ہیں،\qt@no{19}}%
\qt@newcmd\qurantrans@ur@mcdxciii{یہ لوگ (اﷲ کو) زمین میں عاجز کر سکنے والے نہیں اور نہ ہی ان کے لئے اﷲ کے سوا کوئی مددگار ہیں۔ ان کے لئے عذاب دوگنا کر دیا جائے گا (کیونکہ) نہ وہ (حق بات) سننے کی طاقت رکھتے تھے اور نہ (حق کو) دیکھ ہی سکتے تھے،\qt@no{20}}%
\qt@newcmd\qurantrans@ur@mcdxciv{یہی لوگ ہیں جنہوں نے اپنی جانوں کو نقصان پہنچایا اور جو بہتان وہ باندھتے تھے وہ (سب) ان سے جاتے رہے،\qt@no{21}}%
\qt@newcmd\qurantrans@ur@mcdxcv{یہ بالکل حق ہے کہ یقینًا وہی لوگ آخرت میں سب سے زیادہ خسارہ اٹھانے والے ہیں،\qt@no{22}}%
\qt@newcmd\qurantrans@ur@mcdxcvi{بیشک جو لوگ ایمان لائے اور نیک عمل کرتے رہے اور اپنے رب کے حضور عاجزی کرتے رہے یہی لوگ اہلِ جنت ہیں وہ اس میں ہمیشہ رہنے والے ہیں،\qt@no{23}}%
\qt@newcmd\qurantrans@ur@mcdxcvii{کافر و مسلم) دونوں فریقوں کی مثال اندھے اور بہرے اور (اس کے برعکس) دیکھنے والے اور سننے والے کی سی ہے۔ کیا دونوں کا حال برابر ہے؟ کیا تم پھر (بھی) نصیحت قبول نہیں کرتے،\qt@no{24}}%
\qt@newcmd\qurantrans@ur@mcdxcviii{اور بیشک ہم نے نوح (علیہ السلام) کو ان کی قوم کی طرف بھیجا، (انہوں نے ان سے کہا:) میں تمہارے لئے کھلا ڈر سنانے والا (بن کر آیا) ہوں،\qt@no{25}}%
\qt@newcmd\qurantrans@ur@mcdxcix{کہ تم اﷲ کے سوا کسی کی عبادت نہ کرو، میں تم پر دردناک دن کے عذاب (کی آمد) کا خوف رکھتا ہوں،\qt@no{26}}%
\qt@newcmd\qurantrans@ur@md{سو ان کی قوم کے کفر کرنے والے سرداروں اور وڈیروں نے کہا: ہمیں تو تم ہمارے اپنے ہی جیسا ایک بشر دکھائی دیتے ہو اور ہم نے کسی (معزز شخص) کو تمہاری پیروی کرتے ہوئے نہیں دیکھا سوائے ہمارے (معاشرے کے) سطحی رائے رکھنے والے پست و حقیر لوگوں کے (جو بے سوچے سمجھے تمہارے پیچھے لگ گئے ہیں)، اور ہم تمہارے اندر اپنے اوپر کوئی فضیلت و برتری (یعنی طاقت و اقتدار، مال و دولت یا تمہاری جماعت میں بڑے لوگوں کی شمولیت الغرض ایسا کوئی نمایاں پہلو) بھی نہیں دیکھتے بلکہ ہم تو تمہیں جھوٹا سمجھتے ہیں،\qt@no{27}}%
\qt@newcmd\qurantrans@ur@mdi{نوح علیہ السلام نے) کہا: اے میری قوم! بتاؤ تو سہی اگر میں اپنے رب کی طرف سے روشن دلیل پر بھی ہوں اور اس نے مجھے اپنے حضور سے (خاص) رحمت بھی بخشی ہو مگر وہ تمہارے اوپر (اندھوں کی طرح) پوشیدہ کر دی گئی ہو، تو کیا ہم اسے تم پر جبراً مسلّط کر سکتے ہیں درآنحالیکہ تم اسے ناپسند کرتے ہو،\qt@no{28}}%
\qt@newcmd\qurantrans@ur@mdii{اور اے میری قوم! میں تم سے اس (دعوت و تبلیغ) پر کوئی مال و دولت (بھی) طلب نہیں کرتا، میرا اجر تو صرف اﷲ (کے ذمۂ کرم) پر ہے اور میں (تمہاری خاطر) ان (غریب اور پسماندہ) لوگوں کو جو ایمان لے آئے ہیں دھتکارنے والا بھی نہیں ہوں (تم انہیں حقیر مت سمجھو یہی حقیقت میں معزز ہیں)۔ بیشک یہ لوگ اپنے رب کی ملاقات سے بہرہ یاب ہونے والے ہیں اور میں تو درحقیقت تمہیں جاہل (و بے فہم) قوم دیکھ رہا ہوں،\qt@no{29}}%
\qt@newcmd\qurantrans@ur@mdiii{اور اے میری قوم! اگر میں ان کو دھتکار دوں تو اﷲ (کے غضب) سے (بچانے میں) میری مدد کون کر سکتا ہے، کیا تم غور نہیں کرتے،\qt@no{30}}%
\qt@newcmd\qurantrans@ur@mdiv{اور میں تم سے (یہ) نہیں کہتا کہ میرے پاس اﷲ کے خزانے ہیں (یعنی میں بے حد دولت مند ہوں) اور نہ (یہ کہ) میں (اﷲ کے بتائے بغیر) خود غیب جانتا ہوں اور نہ میں یہ کہتا ہوں کہ میں (انسان نہیں) فرشتہ ہوں (میری دعوت کرشماتی دعوؤں پر مبنی نہیں ہے) اور نہ ان لوگوں کی نسبت جنہیں تمہاری نگاہیں حقیر جان رہی ہیں یہ کہتا ہوں کہ اﷲ انہیں ہرگز کوئی بھلائی نہ دے گا (یہ اﷲ کا امر اور ہر شخص کا نصیب ہے)، اﷲ بہتر جانتا ہے جو کچھ ان کے دلوں میں ہے، (اگر ایسا کہوں تو) بیشک میں اسی وقت ظالموں میں سے ہو جاؤں گا،\qt@no{31}}%
\qt@newcmd\qurantrans@ur@mdv{وہ کہنے لگے: اے نوح! بیشک تم ہم سے جھگڑ چکے سو تم نے ہم سے بہت جھگڑا کر لیا، بس اب ہمارے پاس وہ (عذاب) لے آؤ جس کا تم ہم سے وعدہ کرتے ہو اگر تم (واقعی) سچے ہو،\qt@no{32}}%
\qt@newcmd\qurantrans@ur@mdvi{نوح علیہ السلام نے) کہا: وہ (عذاب) تو بس اﷲ ہی تم پر لائے گا اگر اس نے چاہا اور تم (اسے) عاجز نہیں کرسکتے،\qt@no{33}}%
\qt@newcmd\qurantrans@ur@mdvii{اور میری نصیحت (بھی) تمہیں نفع نہ دے گی خواہ میں تمہیں نصیحت کرنے کا ارادہ کروں اگر اﷲ نے تمہیں گمراہ کرنے کا ارادہ فرما لیا ہو، وہ تمہارا رب ہے اور تم اسی کی طرف لوٹائے جاؤ گے،\qt@no{34}}%
\qt@newcmd\qurantrans@ur@mdviii{اے حبیبِ مکرّم!) کیا یہ لوگ کہتے ہیں کہ پیغمبر نے اس (قرآن) کو خود گھڑ لیا ہے، فرما دیجئے: اگر میں نے اسے گھڑ لیا ہے تو میرے جرم (کا وبال) مجھ پر ہوگا اور میں اس سے بری ہوں جو جرم تم کر رہے ہو،\qt@no{35}}%
\qt@newcmd\qurantrans@ur@mdix{اور نوح (علیہ السلام) کی طرف وحی کی گئی کہ (اب) ہرگز تمہاری قوم میں سے (مزید) کوئی ایمان نہیں لائے گا سوائے ان کے جو (اس وقت تک) ایمان لا چکے ہیں، سو آپ ان کے (تکذیب و استہزا کے) کاموں سے رنجیدہ نہ ہوں،\qt@no{36}}%
\qt@newcmd\qurantrans@ur@mdx{اور تم ہمارے حکم کے مطابق ہمارے سامنے ایک کشتی بناؤ اور ظالموں کے بارے میں مجھ سے (کوئی) بات نہ کرنا، وہ ضرور غرق کئے جائیں گے،\qt@no{37}}%
\qt@newcmd\qurantrans@ur@mdxi{اور نوح (علیہ السلام) کشتی بناتے رہے اور جب بھی ان کی قوم کے سردار اُن کے پاس سے گزرتے ان کا مذاق اڑاتے۔ نوح (علیہ السلام انہیں جوابًا) کہتے: اگر (آج) تم ہم سے تمسخر کرتے ہو تو (کل) ہم بھی تم سے تمسخر کریں گے جیسے تم تمسخر کر رہے ہو،\qt@no{38}}%
\qt@newcmd\qurantrans@ur@mdxii{سو تم عنقریب جان لوگے کہ کس پر (دنیا میں ہی) عذاب آتا ہے جو اسے ذلیل و رسوا کر دے گا اور (پھر آخرت میں بھی کس پر) ہمیشہ قائم رہنے والا عذاب اترتا ہے،\qt@no{39}}%
\qt@newcmd\qurantrans@ur@mdxiii{یہاں تک کہ جب ہمارا حکمِ (عذاب) آپہنچا اور تنور (پانی کے چشموں کی طرح) جوش سے ابلنے لگا (تو) ہم نے فرمایا: (اے نوح!) اس کشتی میں ہر جنس میں سے (نر اور مادہ) دو عدد پر مشتمل جوڑا سوار کر لو اور اپنے گھر والوں کو بھی (لے لو) سوائے ان کے جن پر (ہلاکت کا) فرمان پہلے صادر ہو چکا ہے اور جو کوئی ایمان لے آیا ہے (اسے بھی ساتھ لے لو)، اور چند (لوگوں) کے سوا ان کے ساتھ کوئی ایمان نہیں لایا تھا،\qt@no{40}}%
\qt@newcmd\qurantrans@ur@mdxiv{اور نوح (علیہ السلام) نے کہا: تم لوگ اس میں سوار ہو جاؤ اﷲ ہی کے نام سے اس کا چلنا اور اس کا ٹھہرنا ہے۔ بیشک میرا رب بڑا ہی بخشنے والا نہایت مہربان ہے،\qt@no{41}}%
\qt@newcmd\qurantrans@ur@mdxv{اور وہ کشتی پہاڑوں جیسی (طوفانی) لہروں میں انہیں لئے چلتی جا رہی تھی کہ نوح (علیہ السلام) نے اپنے بیٹے کو پکارا اور وہ ان سے الگ (کافروں کے ساتھ کھڑا) تھا: اے میرے بیٹے! ہمارے ساتھ سوار ہوجا اور کافروں کے ساتھ نہ رہ،\qt@no{42}}%
\qt@newcmd\qurantrans@ur@mdxvi{وہ بولا: میں (کشتی میں سوار ہونے کے بجائے) ابھی کسی پہاڑ کی پناہ لے لیتا ہوں وہ مجھے پانی سے بچا لے گا۔ نوح (علیہ السلام) نے کہا: آج اﷲ کے عذاب سے کوئی بچانے والا نہیں ہے مگر اس شخص کو جس پر وہی (اﷲ) رحم فرما دے، اسی اثنا میں دونوں (یعنی باپ بیٹے) کے درمیان (طوفانی) موج حائل ہوگئی سو وہ ڈوبنے والوں میں ہوگیا،\qt@no{43}}%
\qt@newcmd\qurantrans@ur@mdxvii{اور (جب سفینۂ نوح کے سوا سب ڈوب کر ہلاک ہو چکے تو) حکم دیا گیا: اے زمین! اپنا پانی نگل جا اور اے آسمان! تو تھم جا، اور پانی خشک کر دیا گیا اور کام تمام کر دیا گیا اور کشتی جودی پہاڑ پر جا ٹھہری، اور فرما دیا گیا کہ ظالموں کے لئے (رحمت سے) دوری ہے،\qt@no{44}}%
\qt@newcmd\qurantrans@ur@mdxviii{اور نوح (علیہ السلام) نے اپنے رب کو پکارا اور عرض کیا: اے میرے رب! بیشک میرا لڑکا (بھی) تو میرے گھر والوں میں داخل تھا اور یقینًا تیرا وعدہ سچا ہے اور تو سب سے بڑا حاکم ہے،\qt@no{45}}%
\qt@newcmd\qurantrans@ur@mdxix{ارشاد ہو: اے نوح! بیشک وہ تیرے گھر والوں میں شامل نہیں کیونکہ اس کے عمل اچھے نہ تھے، پس مجھ سے وہ سوال نہ کیا کرو جس کا تمہیں علم نہ ہو، میں تمہیں نصیحت کئے دیتا ہوں کہ کہیں تم نادانوں میں سے (نہ) ہو جانا،\qt@no{46}}%
\qt@newcmd\qurantrans@ur@mdxx{نوح علیہ السلام نے) عرض کیا: اے میرے رب! میں اس بات سے تیری پناہ چاہتا ہوں کہ تجھ سے وہ سوال کروں جس کا مجھے کچھ علم نہ ہو، اور اگر تو مجھے نہ بخشے گا اور مجھ پر رحم (نہ) فرمائے گا (تو) میں نقصان اٹھانے والوں میں سے ہو جاؤں گا،\qt@no{47}}%
\qt@newcmd\qurantrans@ur@mdxxi{فرمایا گیا: اے نوح! ہماری طرف سے سلامتی اور برکتوں کے ساتھ (کشتی سے) اتر جاؤ جو تم پر ہیں اور ان طبقات پر ہیں جو تمہارے ساتھ ہیں، اور (آئندہ پھر) کچھ طبقے ایسے ہوں گے جنہیں ہم (دنیوی نعمتوں سے) بہرہ یاب فرمائیں گے پھر انہیں ہماری طرف سے دردناک عذاب آپہنچے گا،\qt@no{48}}%
\qt@newcmd\qurantrans@ur@mdxxii{یہ (بیان ان) غیب کی خبروں میں سے ہے جو ہم آپ کی طرف وحی کرتے ہیں، اس سے قبل نہ آپ انہیں جانتے تھے اور نہ آپ کی قوم، پس آپ صبر کریں۔ بیشک بہتر انجام پرہیزگاروں ہی کے لئے ہے،\qt@no{49}}%
\qt@newcmd\qurantrans@ur@mdxxiii{اور (ہم نے) قومِ عاد کی طرف ان کے بھائی ہود (علیہ السلام) کو (بھیجا)، انہوں نے کہا: اے میری قوم اﷲ کی عبادت کرو اس کے سوا تمہارے لئے کوئی معبود نہیں، تم اﷲ پر (شریک رکھنے کا) محض بہتان باندھنے والے ہو،\qt@no{50}}%
\qt@newcmd\qurantrans@ur@mdxxiv{اے میری قوم! میں اس (دعوت و تبلیغ) پر تم سے کوئی اجر نہیں مانگتا، میرا اجر فقط اس (کے ذمۂ کرم) پر ہے جس نے مجھے پیدا فرمایا ہے، کیا تم عقل سے کام نہیں لیتے،\qt@no{51}}%
\qt@newcmd\qurantrans@ur@mdxxv{اور اے لوگو! تم اپنے رب سے (گناہوں کی) بخشش مانگو پھر اس کی جناب میں (صدقِ دل سے) رجوع کرو، وہ تم پر آسمان سے موسلادھار بارش بھیجے گا اور تمہاری قوت پر قوت بڑھائے گا اور تم مجرم بنتے ہوئے اس سے روگردانی نہ کرنا،\qt@no{52}}%
\qt@newcmd\qurantrans@ur@mdxxvi{وہ بولے: اے ہود! تم ہمارے پاس کوئی واضح دلیل لیکر نہیں آئے ہو اور نہ ہم تمہارے کہنے سے اپنے معبودوں کو چھوڑنے والے ہیں اور نہ ہی ہم تم پر ایمان لانے والے ہیں،\qt@no{53}}%
\qt@newcmd\qurantrans@ur@mdxxvii{ہم اس کے سوا (کچھ) نہیں کہہ سکتے کہ ہمارے معبودوں میں سے کسی نے تمہیں (دماغی خلل کی) بیماری میں مبتلا کر دیا ہے۔ ہود (علیہ السلام)نے کہا: بیشک میں اﷲ کو گواہ بناتا ہوں اور تم بھی گواہ رہو کہ میں ان سے لاتعلق ہوں جنہیں تم شریک گردانتے ہو،\qt@no{54}}%
\qt@newcmd\qurantrans@ur@mdxxviii{اس (اﷲ) کے سوا تم سب (بشمول تمہارے معبودانِ باطلہ) مل کر میرے خلاف (کوئی) تدبیر کرلو پھر مجھے مہلت بھی نہ دو،\qt@no{55}}%
\qt@newcmd\qurantrans@ur@mdxxix{بیشک میں نے اﷲ پر توکل کر لیا ہے جو میرا (بھی) رب ہے اور تمہارا (بھی) رب ہے، کوئی چلنے والا (جاندار) ایسا نہیں مگر وہ اسے اس کی چوٹی سے پکڑے ہوئے ہے (یعنی مکمل طور پر اس کے قبضۂ قدرت میں ہے)۔ بیشک میرا رب (حق و عدل میں) سیدھی راہ پر (چلنے سے ملتا) ہے،\qt@no{56}}%
\qt@newcmd\qurantrans@ur@mdxxx{پھر بھی اگر تم روگردانی کرو تو میں نے واقعۃً وہ (تمام احکام) تمہیں پہنچا دیئے ہیں جنہیں لے کر میں تمہارے پاس بھیجا گیا ہوں، اور میرا رب تمہاری جگہ کسی اور قوم کو قائم مقام بنا دے گا، اور تم اس کا کچھ بھی بگاڑ نہ سکو گے۔ بیشک میرا رب ہر چیز پر نگہبان ہے،\qt@no{57}}%
\qt@newcmd\qurantrans@ur@mdxxxi{اور جب ہمارا حکمِ (عذاب) آپہنچا (تو) ہم نے ہود (علیہ السلام) کو اور ان کے ساتھ ایمان والوں کو اپنی رحمت کے باعث بچا لیا، اور ہم نے انہیں سخت عذاب سے نجات بخشی،\qt@no{58}}%
\qt@newcmd\qurantrans@ur@mdxxxii{اور یہ (قومِ) عاد ہے جنہوں نے اپنے رب کی آیتوں کا انکار کیا اور اپنے رسولوں کی نافرمانی کی اور ہر جابر (و متکبر) دشمنِ حق کے حکم کی پیروی کی،\qt@no{59}}%
\qt@newcmd\qurantrans@ur@mdxxxiii{اور اس دنیا میں (بھی) ان کے پیچھے لعنت لگا دی گئی اور قیامت کے دن (بھی لگے گی)۔ یاد رکھو کہ (قومِ) عاد نے اپنے رب کے ساتھ کفر کیا تھا۔ خبردار! ہود (علیہ السلام) کی قومِ عاد کے لئے (رحمت سے) دوری ہے،\qt@no{60}}%
\qt@newcmd\qurantrans@ur@mdxxxiv{اور (ہم نے قومِ) ثمود کی طرف ان کے بھائی صالح (علیہ السلام) کو (بھیجا)۔ انہوں نے کہا: اے میری قوم! اﷲ کی عبادت کرو تمہارے لئے اس کے سوا کوئی معبود نہیں، اسی نے تمہیں زمین سے پیدا فرمایا اور اس میں تمہیں آباد فرمایا سو تم اس سے معافی مانگو پھر اس کے حضور توبہ کرو۔ بیشک میرا رب قریب ہے دعائیں قبول فرمانے والا ہے،\qt@no{61}}%
\qt@newcmd\qurantrans@ur@mdxxxv{وہ بولے: اے صالح! اس سے قبل ہماری قوم میں تم ہی امیدوں کا مرکز تھے، کیا تم ہمیں ان (بتوں) کی پرستش کرنے سے روک رہے ہو جن کی ہمارے باپ دادا پرستش کرتے رہے ہیں؟ اور جس (توحید) کی طرف تم ہمیں بلا رہے ہو یقینًا ہم اس کے بارے میں بڑے اضطراب انگیز شک میں مبتلا ہیں،\qt@no{62}}%
\qt@newcmd\qurantrans@ur@mdxxxvi{صالح (علیہ السلام) نے کہا: اے میری قوم! ذرا سوچو تو سہی اگر میں اپنے رب کی طرف سے روشن دلیل پر (قائم) ہوں اور مجھے اس کی جانب سے (خاص) رحمت نصیب ہوئی ہے، (اس کے بعد اس کے احکام تم تک نہ پہنچا کر) اگر میں اس کی نافرمانی کر بیٹھوں تو کون شخص ہے جو اﷲ (کے عذاب) سے بچانے میں میری مدد کرسکتا ہے؟ پس سوائے نقصان پہنچانے کے تم میرا (اور) کچھ نہیں بڑھا سکتے،\qt@no{63}}%
\qt@newcmd\qurantrans@ur@mdxxxvii{اور اے میری قوم! یہ اﷲ کی (خاص طریقہ سے پیدا کردہ) اونٹنی ہے (جو) تمہارے لئے نشانی ہے سو اسے چھوڑے رکھو (یہ) اﷲ کی زمین میں کھاتی پھرے اور اسے کوئی تکلیف نہ پہنچانا ورنہ تمہیں قریب (واقع ہونے والا) عذاب آپکڑے گا،\qt@no{64}}%
\qt@newcmd\qurantrans@ur@mdxxxviii{پھر انہوں نے اسے (کونچیں کاٹ کر) ذبح کر ڈالا، صالح (علیہ السلام) نے کہا: (اب) تم اپنے گھروں میں (صرف) تین دن (تک) عیش کرلو، یہ وعدہ ہے جو (کبھی) جھوٹا نہ ہوگا،\qt@no{65}}%
\qt@newcmd\qurantrans@ur@mdxxxix{پھر جب ہمارا حکمِ (عذاب) آپہنچا (تو) ہم نے صالح (علیہ السلام) کو اور جو ان کے ساتھ ایمان والے تھے اپنی رحمت کے سبب سے بچا لیا اور اس دن کی رسوائی سے (بھی نجات بخشی)۔ بیشک آپ کا رب ہی طاقتور غالب ہے،\qt@no{66}}%
\qt@newcmd\qurantrans@ur@mdxl{اور ظالم لوگوں کو ہولناک آواز نے آپکڑا، سو انہوں نے صبح اس طرح کی کہ اپنے گھروں میں (مُردہ حالت میں) اوندھے پڑے رہ گئے،\qt@no{67}}%
\qt@newcmd\qurantrans@ur@mdxli{گویا وہ کبھی ان میں بسے ہی نہ تھے، یاد رکھو! (قومِ) ثمود نے اپنے رب سے کفر کیا تھا۔ خبردار! (قومِ) ثمود کے لئے (رحمت سے) دوری ہے،\qt@no{68}}%
\qt@newcmd\qurantrans@ur@mdxlii{اور بیشک ہمارے فرستادہ فرشتے ابراہیم (علیہ السلام) کے پاس خوشخبری لے کر آئے، انہوں نے سلام کہا، ابراہیم (علیہ السلام) نے بھی (جوابًا) سلام کہا، پھر (آپ علیہ السلام نے) دیر نہ کی یہاں تک کہ (ان کی میزبانی کے لئے) ایک بھنا ہوا بچھڑا لے آئے،\qt@no{69}}%
\qt@newcmd\qurantrans@ur@mdxliii{پھر جب (ابراہیم علیہ السلام نے) دیکھا کہ ان کے ہاتھ اس (کھانے) کی طرف نہیں بڑھ رہے تو انہیں اجنبی سمجھا اور (اپنے) دل میں ان سے کچھ خوف محسوس کرنے لگے، انہوں نے کہا: آپ مت ڈریئے! ہم قومِ لوط کی طرف بھیجے گئے ہیں،\qt@no{70}}%
\qt@newcmd\qurantrans@ur@mdxliv{اور ان کی اہلیہ (سارہ پاس ہی) کھڑی تھیں تو وہ ہنس پڑیں، سو ہم نے ان (کی زوجہ) کو اسحاق (علیہ السلام) کی اور اسحاق (علیہ السلام) کے بعد یعقوب (علیہ السلام) کی بشارت دی،\qt@no{71}}%
\qt@newcmd\qurantrans@ur@mdxlv{وہ کہنے لگیں: وائے حیرانی! کیا میں بچہ جنوں گی حالانکہ میں بوڑھی (ہو چکی) ہوں اور میرے یہ شوہر (بھی) بوڑھے ہیں؟ بیشک یہ تو بڑی عجیب چیز ہے،\qt@no{72}}%
\qt@newcmd\qurantrans@ur@mdxlvi{فرشتوں نے کہا: کیا تم اﷲ کے حکم پر تعجب کر رہی ہو؟ اے گھر والو! تم پر اﷲ کی رحمت اور اس کی برکتیں ہیں، بیشک وہ قابلِ ستائش (ہے) بزرگی والا ہے،\qt@no{73}}%
\qt@newcmd\qurantrans@ur@mdxlvii{پھر جب ابراہیم (علیہ السلام) سے خوف جاتا رہا اور ان کے پاس بشارت آچکی تو ہمارے (فرشتوں کے) ساتھ قومِ لوط کے بارے میں جھگڑنے لگے،\qt@no{74}}%
\qt@newcmd\qurantrans@ur@mdxlviii{بیشک ابراہیم (علیہ السلام) بڑے متحمل مزاج، آہ و زاری کرنے والے ہر حال میں ہماری طرف رجوع کر نے والے تھے،\qt@no{75}}%
\qt@newcmd\qurantrans@ur@mdxlix{فرشتوں نے کہا:) اے ابراہیم! اس (بات) سے درگزر کیجئے، بیشک اب تو آپ کے رب کا حکمِ (عذاب) آچکا ہے، اور انہیں عذاب پہنچنے ہی والا ہے جو پلٹایا نہیں جا سکتا،\qt@no{76}}%
\qt@newcmd\qurantrans@ur@mdl{اور جب ہمارے فرستادہ فرشتے لوط (علیہ السلام) کے پاس آئے (تو) وہ ان کے آنے سے پریشان ہوئے اور ان کے باعث (ان کی) طاقت کمزور پڑ گئی اور کہنے لگے: یہ بہت سخت دن ہے (فرشتے نہایت خوب رُو تھے اور حضرت لوط علیہ السلام کو اپنی قوم کی بری عادت کا علم تھا سو ممکنہ فتنہ کے اندیشہ سے پریشان ہوئے)،\qt@no{77}}%
\qt@newcmd\qurantrans@ur@mdli{سو وہی ہوا جس کا انہیں اندیشہ تھا) اور لوط (علیہ السلام) کی قوم (مہمانوں کی خبر سنتے ہی) ان کے پاس دوڑتی ہوئی آگئی، اور وہ پہلے ہی برے کام کیا کرتے تھے۔ لوط (علیہ السلام) نے کہا: اے میری (نافرمان) قوم! یہ میری (قوم کی) بیٹیاں ہیں یہ تمہارے لئے (بطریقِ نکاح) پاکیزہ و حلال ہیں سو تم اﷲ سے ڈرو اور میرے مہمانوں میں (اپنی بے حیائی کے باعث) مجھے رسوا نہ کرو! کیا تم میں سے کوئی بھی نیک سیرت آدمی نہیں ہے،\qt@no{78}}%
\qt@newcmd\qurantrans@ur@mdlii{وہ بولے: تم خوب جانتے ہو کہ ہمیں تمہاری (قوم کی) بیٹیوں سے کوئی غرض نہیں، اور تم یقینًا جانتے ہو جو کچھ ہم چاہتے ہیں،\qt@no{79}}%
\qt@newcmd\qurantrans@ur@mdliii{لوط (علیہ السلام) نے کہا: کاش! مجھ میں تمہارے مقابلہ کی ہمت ہوتی یا میں (آج) کسی مضبوط قلعہ میں پناہ لے سکتا،\qt@no{80}}%
\qt@newcmd\qurantrans@ur@mdliv{تب فرشتے) کہنے لگے: اے لوط! ہم آپ کے رب کے بھیجے ہوئے ہیں۔ یہ لوگ تم تک ہرگز نہ پہنچ سکیں گے، پس آپ اپنے گھر والوں کو رات کے کچھ حصہ میں لے کر نکل جائیں اور تم میں سے کوئی مڑ کر (پیچھے) نہ دیکھے مگر اپنی عورت کو (ساتھ نہ لینا)، یقینًا اسے (بھی) وہی (عذاب) پہنچنے والا ہے جو انہیں پہنچے گا۔ بیشک ان (کے عذاب) کا مقررہ وقت صبح (کا) ہے، کیا صبح قریب نہیں ہے،\qt@no{81}}%
\qt@newcmd\qurantrans@ur@mdlv{پھر جب ہمارا حکمِ (عذاب) آپہنچا تو ہم نے (الٹ کر) اس بستی کے اوپر کے حصہ کو نچلا حصہ کر دیا اور ہم نے اس پر پتھر اور پکی ہوئی مٹی کے کنکر برسائے جو پے در پے (اور تہ بہ تہ) گرتے رہے،\qt@no{82}}%
\qt@newcmd\qurantrans@ur@mdlvi{جو آپ کے رب کی طرف سے نشان کئے ہوئے تھے، اور یہ (سنگ ریزوں کا عذاب) ظالموں سے (اب بھی) کچھ دور نہیں ہے،\qt@no{83}}%
\qt@newcmd\qurantrans@ur@mdlvii{اور (ہم نے اہلِ) مدین کی طرف ان کے بھائی شعیب (علیہ السلام کو بھیجا)، انہوں نے کہا: اے میری قوم! اﷲ کی عبادت کرو تمہارے لئے اس کے سوا کوئی معبود نہیں ہے، اور ناپ اور تول میں کمی مت کیا کرو بیشک میں تمہیں آسودہ حال دیکھتا ہوں اور میں تم پر ایسے دن کے عذاب کا خوف (محسوس) کرتا ہوں جو (تمہیں) گھیر لینے والا ہے،\qt@no{84}}%
\qt@newcmd\qurantrans@ur@mdlviii{اور اے میری قوم! تم ناپ اور تول انصاف کے ساتھ پورے کیا کرو اور لوگوں کو ان کی چیزیں گھٹا کر نہ دیا کرو اور فساد کرنے والے بن کر ملک میں تباہی مت مچاتے پھرو،\qt@no{85}}%
\qt@newcmd\qurantrans@ur@mdlix{جو اﷲ کے دیئے میں بچ رہے (وہی) تمہارے لئے بہتر ہے اگر تم ایمان والے ہو، اور میں تم پر نگہبان نہیں ہوں،\qt@no{86}}%
\qt@newcmd\qurantrans@ur@mdlx{وہ بولے! اے شعیب! کیا تمہاری نماز تمہیں یہی حکم دیتی ہے کہ ہم ان (معبودوں) کو چھوڑ دیں جن کی پرستش ہمارے باپ دادا کرتے رہے ہیں یا یہ کہ ہم جو کچھ اپنے اموال کے بارے میں چاہیں (نہ) کریں؟ بیشک تم ہی (ایک) بڑے تحمل والے ہدایت یافتہ (رہ گئے) ہو،\qt@no{87}}%
\qt@newcmd\qurantrans@ur@mdlxi{شعیب (علیہ السلام) نے کہا: اے میری قوم! ذرا بتاؤ کہ اگر میں اپنے رب کی طرف سے روشن دلیل پر ہوں اور اس نے مجھے اپنی بارگاہ سے عمدہ رزق (بھی) عطا فرمایا (تو پھر حق کی تبلیغ کیوں نہ کروں؟)، اور میں یہ (بھی) نہیں چاہتا کہ تمہارے پیچھے لگ کر (حق کے خلاف) خود وہی کچھ کرنے لگوں جس سے میں تمہیں منع کر رہا ہوں، میں تو جہاں تک مجھ سے ہو سکتا ہے (تمہاری) اصلاح ہی چاہتا ہوں، اور میری توفیق اﷲ ہی (کی مدد) سے ہے، میں نے اسی پر بھروسہ کیا ہے اور اسی کی طرف رجوع کرتا ہوں،\qt@no{88}}%
\qt@newcmd\qurantrans@ur@mdlxii{اور اے میری قوم! مجھ سے دشمنی و مخالفت تمہیں یہاں تک نہ ابھار دے کہ (جس کے باعث) تم پر وہ (عذاب) آپہنچے جیسا (عذاب) قومِ نوح یا قومِ ہود یا قومِ صالح کو پہنچا تھا، اور قومِ لوط (کا زمانہ تو) تم سے کچھ دور نہیں (گزرا)،\qt@no{89}}%
\qt@newcmd\qurantrans@ur@mdlxiii{اور تم اپنے رب سے مغفرت مانگو پھر اس کے حضور (صدقِ دل سے) توبہ کرو، بیشک میرا رب نہایت مہربان محبت فرمانے والا ہے،\qt@no{90}}%
\qt@newcmd\qurantrans@ur@mdlxiv{وہ بولے: اے شعیب! تمہاری اکثر باتیں ہماری سمجھ میں نہیں آتیں اور ہم تمہیں اپنے معاشرے میں ایک کمزور شخص جانتے ہیں، اور اگر تمہارا کنبہ نہ ہوتا تو ہم تمہیں سنگ سار کر دیتے اور (ہمیں اسی کا لحاظ ہے ورنہ) تم ہماری نگاہ میں کوئی عزت والے نہیں ہو،\qt@no{91}}%
\qt@newcmd\qurantrans@ur@mdlxv{شعیب (علیہ السلام) نے کہا: اے میری قوم! کیا میرا کنبہ تمہارے نزدیک اﷲ سے زیادہ معزز ہے، اور تم نے اسے (یعنی اللہ تعالیٰ کو گویا) اپنے پس پشت ڈال رکھا ہے۔ بیشک میرا رب تمہارے (سب) کاموں کو احاطہ میں لئے ہوئے ہے،\qt@no{92}}%
\qt@newcmd\qurantrans@ur@mdlxvi{اور اے میری قوم! تم اپنی جگہ کام کرتے رہو میں اپنا کام کر رہا ہوں۔ تم عنقریب جان لوگے کہ کس پر وہ عذاب آپہنچتا ہے جو رسوا کر ڈالے گا اور کون ہے جو جھوٹا ہے، اور تم بھی انتظار کرتے رہو اور میں (بھی) تمہارے ساتھ منتظر ہوں،\qt@no{93}}%
\qt@newcmd\qurantrans@ur@mdlxvii{اور جب ہمارا حکمِ (عذاب) آپہنچا تو ہم نے شعیب (علیہ السلام) کو اور ان کے ساتھ ایمان والوں کو اپنی رحمت کے باعث بچالیا اور ظالموں کو خوفناک آواز نے آپکڑا، سو انہوں نے صبح اس حال میں کی کہ اپنے گھروں میں (مردہ حالت) میں اوندھے پڑے رہ گئے،\qt@no{94}}%
\qt@newcmd\qurantrans@ur@mdlxviii{گویا وہ ان میں کبھی بسے ہی نہ تھی۔ سنو! (اہلِ) مدین کے لئے ہلاکت ہے جیسے (قومِ) ثمود ہلاک ہوئی تھی،\qt@no{95}}%
\qt@newcmd\qurantrans@ur@mdlxix{اور بیشک ہم نے موسٰی (علیہ السلام) کو (بھی) اپنی نشانیوں اور روشن برہان کے ساتھ بھیجا،\qt@no{96}}%
\qt@newcmd\qurantrans@ur@mdlxx{فرعون اور اس کے سرداروں کے پاس، تو (قوم کے) سرداروں نے فرعون کے حکم کی پیروی کی حالانکہ فرعون کا حکم درست نہ تھا،\qt@no{97}}%
\qt@newcmd\qurantrans@ur@mdlxxi{وہ قیامت کے دن اپنی قوم کے آگے آگے چلے گا بالآخر انہیں آتشِ دوزخ میں لا گرائے گا، اور وہ داخل کئے جانے کی کتنی بری جگہ ہے،\qt@no{98}}%
\qt@newcmd\qurantrans@ur@mdlxxii{اور اس دنیا میں (بھی) لعنت ان کے پیچھے لگا دی گئی اور قیامت کے دن (بھی ان کے پیچھے رہے گی)، کتنا برا عطیہ ہے جو انہیں دیا گیا ہے،\qt@no{99}}%
\qt@newcmd\qurantrans@ur@mdlxxiii{اے رسولِ معظم!) یہ (ان) بستیوں کے کچھ حالات ہیں جو ہم آپ کو سنا رہے ہیں ان میں سے کچھ برقرار ہیں اور (کچھ) نیست و نابود ہوگئیں،\qt@no{100}}%
\qt@newcmd\qurantrans@ur@mdlxxiv{اور ہم نے ان پر ظلم نہیں کیا تھا لیکن انہوں نے (خود ہی) اپنی جانوں پر ظلم کیا، سو ان کے وہ جھوٹے معبود جنہیں وہ اﷲ کے سوا پوجتے تھے ان کے کچھ کام نہ آئے، جب آپ کے رب کا حکمِ (عذاب) آیا، اور وہ (دیوتا) تو صرف ان کی ہلاکت و بربادی میں ہی اضافہ کر سکے،\qt@no{101}}%
\qt@newcmd\qurantrans@ur@mdlxxv{اور اسی طرح آپ کے رب کی پکڑ ہوا کرتی ہے جب وہ بستیوں کی اس حال میں گرفت فرماتا ہے کہ وہ ظالم (بن چکی) ہوتی ہیں۔ بیشک اس کی گرفت دردناک (اور) سخت ہوتی ہے،\qt@no{102}}%
\qt@newcmd\qurantrans@ur@mdlxxvi{بیشک ان (واقعات) میں اس شخص کے لئے عبرت ہے جو آخرت کے عذاب سے ڈرتا ہے۔ یہ (روزِ قیامت) وہ دن ہے جس کے لئے سارے لوگ جمع کئے جائیں گے اور یہی وہ دن ہے جب سب کو حاضر کیا جائے گا،\qt@no{103}}%
\qt@newcmd\qurantrans@ur@mdlxxvii{اور ہم اسے مؤخر نہیں کر رہے ہیں مگر مقررہ مدت کے لئے (جو پہلے سے طے ہے)،\qt@no{104}}%
\qt@newcmd\qurantrans@ur@mdlxxviii{جب وہ دن آئے گا کوئی شخص (بھی) اس کی اجازت کے بغیر کلام نہیں کر سکے گا، پھر ان میں بعض بدبخت ہوں گے اور بعض نیک بخت،\qt@no{105}}%
\qt@newcmd\qurantrans@ur@mdlxxix{سو جو لوگ بدبخت ہوں گے (وہ) دوزخ میں (پڑے) ہوں گے ان کے مقدر میں وہاں چیخنا اور چلّانا ہوگا،\qt@no{106}}%
\qt@newcmd\qurantrans@ur@mdlxxx{وہ اس میں ہمیشہ رہیں گے جب تک آسمان اور زمین (جو اس وقت ہوں گے) قائم رہیں مگر یہ کہ جو آپ کا رب چاہے۔ بیشک آپ کا رب جو ارادہ فرماتا ہے کر گزرتا ہے،\qt@no{107}}%
\qt@newcmd\qurantrans@ur@mdlxxxi{اور جو لوگ نیک بخت ہوں گے (وہ) جنت میں ہوں گے وہ اس میں ہمیشہ رہیں گے جب تک آسمان اور زمین (جو اس وقت ہوں گے) قائم رہیں مگر یہ کہ جو آپ کا رب چاہے، یہ وہ عطا ہوگی جو کبھی منقطع نہ ہوگی،\qt@no{108}}%
\qt@newcmd\qurantrans@ur@mdlxxxii{پس (اے سننے والے!) تو ان کے بارے میں کسی (بھی) شک میں مبتلا نہ ہو جن کی یہ لوگ پوجا کرتے ہیں۔ یہ لوگ (کسی دلیل و بصیرت کی بنا پر) پرستش نہیں کرتے مگر (صرف اس طرح کرتے ہیں) جیسے ان سے قبل ان کے باپ دادا پرستش کرتے چلے آرہے ہیں۔ اور بیشک ہم انہیں یقیناً ان کا پورا حصۂ (عذاب) دیں گے جس میں کوئی کمی نہیں کی جائے گی،\qt@no{109}}%
\qt@newcmd\qurantrans@ur@mdlxxxiii{اور بیشک ہم نے موسٰی (علیہ السلام) کو کتاب دی پھر اس میں اختلاف کیا جانے لگا، اور اگر آپ کے رب کی طرف سے ایک بات پہلے صادر نہ ہو چکی ہوتی تو ان کے درمیان ضرور فیصلہ کر دیا گیا ہوتا، اور وہ یقینًا اس (قرآن) کے بارے میں اضطراب انگیز شک میں مبتلا ہیں،\qt@no{110}}%
\qt@newcmd\qurantrans@ur@mdlxxxiv{بیشک آپ کا رب ان سب کو ان کے اَعمال کا پورا پورا بدلہ دے گا، وہ جو کچھ کر رہے ہیں یقینًا وہ اس سے خوب آگاہ ہے،\qt@no{111}}%
\qt@newcmd\qurantrans@ur@mdlxxxv{پس آپ ثابت قدم رہئے جیسا کہ آپ کو حکم دیا گیا ہے اور وہ بھی (ثابت قدم رہے) جس نے آپ کی معیت میں (اﷲ کی طرف) رجوع کیا ہے، اور (اے لوگو!) تم سرکشی نہ کرنا، بیشک تم جو کچھ کرتے ہو وہ اسے خوب دیکھ رہا ہے،\qt@no{112}}%
\qt@newcmd\qurantrans@ur@mdlxxxvi{اور تم ایسے لوگوں کی طرف مت جھکنا جو ظلم کر رہے ہیں ورنہ تمہیں آتشِ (دوزخ) آچھوئے گی اور تمہارے لئے اﷲ کے سوا کوئی مددگار نہ ہوگا پھر تمہاری مدد (بھی) نہیں کی جائے گی،\qt@no{113}}%
\qt@newcmd\qurantrans@ur@mdlxxxvii{اور آپ دن کے دونوں کناروں میں اور رات کے کچھ حصوں میں نماز قائم کیجئے۔ بیشک نیکیاں برائیوں کو مٹا دیتی ہیں۔ یہ نصیحت قبول کرنے والوں کے لئے نصیحت ہے،\qt@no{114}}%
\qt@newcmd\qurantrans@ur@mdlxxxviii{اور آپ صبر کریں بیشک اﷲ نیکوکاروں کا اجر ضائع نہیں فرماتا،\qt@no{115}}%
\qt@newcmd\qurantrans@ur@mdlxxxix{سو تم سے پہلے کی امتوں میں ایسے صاحبانِ فضل و خرد کیوں نہ ہوئے جو لوگوں کو زمین میں فساد انگیزی سے روکتے بجز ان میں سے تھوڑے سے لوگوں کے جنہیں ہم نے نجات دے دی، اور ظالموں نے عیش و عشرت (کے اسی راستے) کی پیروی کی جس میں وہ پڑے ہوئے تھے اور وہ (عادی) مجرم تھے،\qt@no{116}}%
\qt@newcmd\qurantrans@ur@mdxc{اور آپ کا رب ایسا نہیں کہ وہ بستیوں کو ظلمًا ہلاک کر ڈالے درآنحالیکہ اس کے باشندے نیکوکار ہوں،\qt@no{117}}%
\qt@newcmd\qurantrans@ur@mdxci{اور اگر آپ کا رب چاہتا تو تمام لوگوں کو ایک ہی امت بنا دیتا (مگر اس نے جبراً ایسا نہ کیا بلکہ سب کو مذہب کے اختیار کرنے میں آزادی دی) اور (اب) یہ لوگ ہمیشہ اختلاف کرتے رہیں گے،\qt@no{118}}%
\qt@newcmd\qurantrans@ur@mdxcii{سوائے اس شخص کے جس پر آپ کا رب رحم فرمائے، اور اسی لئے اس نے انہیں پیدا فرمایا ہے، اور آپ کے رب کا فرمان پورا ہو چکا بیشک میں دوزخ کو جِنّوں اور انسانوں میں سے سب (اہلِ باطل) سے ضرور بھر دوں گا،\qt@no{119}}%
\qt@newcmd\qurantrans@ur@mdxciii{اور ہم رسولوں کی خبروں میں سے سب حالات آپ کو سنا رہے ہیں جس سے ہم آپ کے قلبِ (اَطہر) کو تقویت دیتے ہیں، اور آپ کے پاس اس (سورت) میں حق اور نصیحت آئی ہے اور اہلِ ایمان کے لئے عبرت (و یاددہانی بھی)،\qt@no{120}}%
\qt@newcmd\qurantrans@ur@mdxciv{اور آپ ان لوگوں سے جو ایمان نہیں لاتے فرما دیں: تم اپنی جگہ عمل کرتے رہو (اور) ہم (اپنے مقام پر) عمل پیرا ہیں،\qt@no{121}}%
\qt@newcmd\qurantrans@ur@mdxcv{اور تم (بھی) انتظار کرو ہم (بھی) منتظر ہیں،\qt@no{122}}%
\qt@newcmd\qurantrans@ur@mdxcvi{اور آسمانوں اور زمین کا (سب) غیب اﷲ ہی کے لئے ہے اور اسی کی طرف ہر ایک کام لوٹایا جاتا ہے سو اس کی عبادت کرتے رہیں اور اسی پر توکل کئے رکھیں، اور تمہارا رب تم سب لوگوں کے اعمال سے غافل نہیں ہے،\qt@no{123}}%
\qt@newcmd\qurantrans@ur@mdxcvii{\basmalahur الف، لام، را (حقیقی معنی اﷲ اور رسول صلی اللہ علیہ وآلہ وسلم ہی بہتر جانتے ہیں)، یہ روشن کتاب کی آیتیں ہیں،\qt@no{1}}%
\qt@newcmd\qurantrans@ur@mdxcviii{بیشک ہم نے اس کتاب کو قرآن کی صورت میں بزبانِ عربی اتارا تاکہ تم (اسے براہِ راست) سمجھ سکو،\qt@no{2}}%
\qt@newcmd\qurantrans@ur@mdxcix{اے حبیب!) ہم آپ سے ایک بہترین قصہ بیان کرتے ہیں اس قرآن کے ذریعہ جسے ہم نے آپ کی طرف وحی کیا ہے، اگرچہ آپ اس سے قبل (اس قصہ سے) بے خبر تھے،\qt@no{3}}%
\qt@newcmd\qurantrans@ur@mdc{وہ قصّہ یوں ہے) جب یوسف (علیہ السلام) نے اپنے باپ سے کہا: اے میرے والد گرامی! میں نے (خواب میں) گیارہ ستاروں کو اور سورج اور چاند کو دیکھا ہے، میں نے انہیں اپنے لئے سجدہ کرتے ہوئے دیکھا ہے،\qt@no{4}}%
\qt@newcmd\qurantrans@ur@mdci{انہوں نے کہا: اے میرے بیٹے! اپنا یہ خواب اپنے بھائیوں سے بیان نہ کرنا، ورنہ وہ تمہارے خلاف کوئی پُر فریب چال چلیں گے۔ بیشک شیطان انسان کا کھلا دشمن ہے،\qt@no{5}}%
\qt@newcmd\qurantrans@ur@mdcii{اسی طرح تمہارا رب تمہیں (بزرگی کے لئے) منتخب فرما لے گا اور تمہیں باتوں کے انجام تک پہنچنا (یعنی خوابوں کی تعبیر کا علم) سکھائے گا اور تم پر اور اولادِ یعقوب پر اپنی نعمت تمام فرمائے گا جیسا کہ اس نے اس سے قبل تمہارے دونوں باپ (یعنی پردادا اور دادا) ابراہیم اور اسحاق (علیھما السلام) پر تمام فرمائی تھی۔ بیشک تمہارا رب خوب جاننے والا بڑی حکمت والا ہے،\qt@no{6}}%
\qt@newcmd\qurantrans@ur@mdciii{بیشک یوسف (علیہ السلام) اور ان کے بھائیوں (کے واقعہ) میں پوچھنے والوں کے لئے (بہت سی) نشانیاں ہیں،\qt@no{7}}%
\qt@newcmd\qurantrans@ur@mdciv{وہ وقت یاد کیجئے) جب یوسف (علیہ السلام) کے بھائیوں نے کہا کہ واقعی یوسف (علیہ السلام) اور اس کا بھائی ہمارے باپ کو ہم سے زیادہ محبوب ہیں حالانکہ ہم (دس افراد پر مشتمل) زیادہ قوی جماعت ہیں۔ بیشک ہمارے والد (ان کی محبت کی) کھلی وارفتگی میں گم ہیں،\qt@no{8}}%
\qt@newcmd\qurantrans@ur@mdcv{اب یہی حل ہے کہ) تم یوسف (علیہ السلام) کو قتل کر ڈالو یا دور کسی غیر معلوم علاقہ میں پھینک آؤ (اس طرح) تمہارے باپ کی توجہ خالصتًا تمہاری طرف ہو جائے گی اور اس کے بعد تم (توبہ کر کے) صالحین کی جماعت بن جانا،\qt@no{9}}%
\qt@newcmd\qurantrans@ur@mdcvi{ان میں سے ایک کہنے والے نے کہا: یوسف (علیہ السلام) کو قتل مت کرو اور اسے کسی تاریک کنویں کی گہرائی میں ڈال دو اسے کوئی راہ گیر مسافر اٹھا لے جائے گا اگر تم (کچھ) کرنے والے ہو (تو یہ کرو)،\qt@no{10}}%
\qt@newcmd\qurantrans@ur@mdcvii{انہوں نے کہا: اے ہمارے باپ! آپ کو کیا ہوگیا ہے آپ یوسف (علیہ السلام) کے بارے میں ہم پر اعتبار نہیں کرتے حالانکہ ہم یقینی طور پر اس کے خیر خواہ ہیں،\qt@no{11}}%
\qt@newcmd\qurantrans@ur@mdcviii{آپ اسے کل ہمارے ساتھ بھیج دیجئے وہ خوب کھائے اور کھیلے اور بیشک ہم اس کے محافظ ہیں،\qt@no{12}}%
\qt@newcmd\qurantrans@ur@mdcix{انہوں نے کہا: بیشک مجھے یہ خیال مغموم کرتا ہے کہ تم اسے لے جاؤ اور میں (اس خیال سے بھی) خوف زدہ ہوں کہ اسے بھیڑیا کھا جائے اور تم اس (کی حفاظت) سے غافل رہو،\qt@no{13}}%
\qt@newcmd\qurantrans@ur@mdcx{وہ بولے: اگر اسے بھیڑیا کھا جائے حالانکہ ہم ایک قوی جماعت بھی (موجود) ہوں تو ہم تو بالکل ناکارہ ہوئے،\qt@no{14}}%
\qt@newcmd\qurantrans@ur@mdcxi{پھر جب وہ اسے لے گئے اور سب اس پر متفق ہوگئے کہ اسے تاریک کنویں کی گہرائی میں ڈال دیں تب ہم نے اس کی طرف وحی بھیجی: (اے یوسف! پریشان نہ ہونا ایک وقت آئے گا) کہ تم یقینًا انہیں ان کا یہ کام جتلاؤ گے اور انہیں (تمہارے بلند رتبہ کا) شعور نہیں ہوگا،\qt@no{15}}%
\qt@newcmd\qurantrans@ur@mdcxii{اور وہ (یوسف علیہ السلام کو کنویں میں پھینک کر) اپنے باپ کے پاس رات کے وقت (مکاری کا رونا) روتے ہوئے آئے،\qt@no{16}}%
\qt@newcmd\qurantrans@ur@mdcxiii{کہنے لگے: اے ہمارے باپ! ہم لوگ دوڑ میں مقابلہ کرنے چلے گئے اور ہم نے یوسف (علیہ السلام) کو اپنے سامان کے پاس چھوڑ دیا تو اسے بھیڑئیے نے کھا لیا، اور آپ (تو) ہماری بات کا یقین (بھی) نہیں کریں گے اگرچہ ہم سچے ہی ہوں،\qt@no{17}}%
\qt@newcmd\qurantrans@ur@mdcxiv{اور وہ اس کے قمیض پر جھوٹا خون (بھی) لگا کر لے آئے، (یعقوب علیہ السلام نے) کہا: (حقیقت یہ نہیں ہے) بلکہ تمہارے (حاسد) نفسوں نے ایک (بہت بڑا) کام تمہارے لئے آسان اور خوشگوار بنا دیا (جو تم نے کر ڈالا)، پس (اس حادثہ پر) صبر ہی بہتر ہے، اور اﷲ ہی سے مدد چاہتا ہوں اس پر جو کچھ تم بیان کر رہے ہو،\qt@no{18}}%
\qt@newcmd\qurantrans@ur@mdcxv{اور (ادھر) راہ گیروں کا ایک قافلہ آپہنچا تو انہوں نے اپنا پانی بھرنے والا بھیجا سو اس نے اپنا ڈول (اس کنویں میں) لٹکایا، وہ بول اٹھا: خوشخبری ہو یہ ایک لڑکا ہے، اور انہوں نے اسے قیمتی سامانِ تجارت سمجھتے ہوئے چھپا لیا، اور اﷲ ان کاموں کو جو وہ کر رہے تھے خوب جاننے والا ہے،\qt@no{19}}%
\qt@newcmd\qurantrans@ur@mdcxvi{اور یوسف (علیہ السلام) کے بھائیوں نے (جو موقع پر آگئے تھے اسے اپنا بھگوڑا غلام کہہ کر انہی کے ہاتھوں) بہت کم قیمت گنتی کے چند درہموں کے عوض بیچ ڈالا کیونکہ وہ راہ گیر اس (یوسف علیہ السلام کے خریدنے) کے بارے میں (پہلے ہی) بے رغبت تھے (پھر راہ گیروں نے اسے مصر لے جا کر بیچ دیا)،\qt@no{20}}%
\qt@newcmd\qurantrans@ur@mdcxvii{اور مصر کے جس شخص نے اسے خریدا تھا (اس کا نام قطفیر تھا اور وہ بادشاہِ مصر ریان بن ولید کا وزیر خزانہ تھا اسے عرف عام میں عزیزِ مصر کہتے تھے) اس نے اپنی بیوی (زلیخا) سے کہا: اسے عزت و اکرام سے ٹھہراؤ! شاید یہ ہمیں نفع پہنچائے یا ہم اسے بیٹا بنا لیں، اور اس طرح ہم نے یوسف (علیہ السلام) کو زمین (مصر) میں استحکام بخشا اور یہ اس لئے کہ ہم اسے باتوں کے انجام تک پہنچنا (یعنی علمِ تعبیرِ رؤیا) سکھائیں، اور اﷲ اپنے کام پر غالب ہے لیکن اکثر لوگ نہیں جانتے،\qt@no{21}}%
\qt@newcmd\qurantrans@ur@mdcxviii{اور جب وہ اپنے کمالِ شباب کو پہنچ گیا (تو) ہم نے اسے حکمِ (نبوت) اور علمِ (تعبیر) عطا فرمایا، اور اسی طرح ہم نیکوکاروں کو صلہ بخشا کرتے ہیں،\qt@no{22}}%
\qt@newcmd\qurantrans@ur@mdcxix{اور اس عورت (زلیخا) نے جس کے گھر وہ رہتے تھے آپ سے آپ کی ذات کی شدید خواہش کی اور اس نے دروازے (بھی) بند کر دیئے اور کہنے لگی: جلدی آجاؤ (میں تم سے کہتی ہوں)۔ یوسف (علیہ السلام) نے کہا: اﷲ کی پناہ! بیشک وہ (جو تمہارا شوہر ہے) میرا مربّی ہے اس نے مجھے بڑی عزت سے رکھا ہے۔ بیشک ظالم لوگ فلاح نہیں پائیں گے،\qt@no{23}}%
\qt@newcmd\qurantrans@ur@mdcxx{یوسف علیہ السلام نے انکار کر دیا) اور بیشک اس (زلیخا) نے (تو) ان کا ارادہ کر (ہی) لیا تھا، (شاید) وہ بھی اس کا قصد کر لیتے اگر انہوں نے اپنے رب کی روشن دلیل کو نہ دیکھا ہوتا۔٭ اس طرح (اس لئے کیا گیا) کہ ہم ان سے تکلیف اور بے حیائی (دونوں) کو دور رکھیں، بیشک وہ ہمارے چنے ہوئے (برگزیدہ) بندوں میں سے تھے، ٭ (یا انہوں نے بھی اس کو طاقت سے دور کرنے کا قصد کر لیا تھا۔ اگر وہ اپنے رب کی روشن دلیل کو نہ دیکھ لیتے تو اپنے دفاع میں سختی کر گزرتے اور ممکن ہے اس دوران ان کا قمیض آگے سے پھٹ جاتا جو بعد ازاں ان کے خلاف شہادت اور وجہ تکلیف بنتا، سو اﷲ کی نشانی نے انہیں سختی کرنے سے روک دیا۔)\qt@no{24}}%
\qt@newcmd\qurantrans@ur@mdcxxi{اور دونوں دروازے کی طرف (آگے پیچھے) دوڑے اور اس (زلیخا) نے ان کا قمیض پیچھے سے پھاڑ ڈالا اور دونوں نے اس کے خاوند (عزیزِ مصر) کو دروازے کے قریب پا لیا وہ (فورًا) بول اٹھی کہ اس شخص کی سزا جو تمہاری بیوی کے ساتھ برائی کا ارادہ کرے اور کیا ہو سکتی ہے سوائے اس کے کہ وہ قید کر دیا جائے یا (اسے) درد ناک عذاب (دیا جائے)،\qt@no{25}}%
\qt@newcmd\qurantrans@ur@mdcxxii{یوسف (علیہ السلام) نے کہا: (نہیں بلکہ) اس نے خود مجھ سے مطلب براری کے لئے مجھے پھسلانا چاہا اور (اتنے میں خود) اس کے گھر والوں میں سے ایک گواہ نے (جو شیر خوار بچہ تھا) گواہی دی کہ اگر اس کا قمیض آگے سے پھٹا ہوا ہے تو یہ سچی ہے اور وہ جھوٹوں میں سے ہے،\qt@no{26}}%
\qt@newcmd\qurantrans@ur@mdcxxiii{اور اگر اس کا قمیض پیچھے سے پھٹا ہوا ہے تو یہ جھوٹی ہے اور وہ سچوں میں سے ہے،\qt@no{27}}%
\qt@newcmd\qurantrans@ur@mdcxxiv{پھر جب اس (عزیزِ مصر) نے ان کا قمیض دیکھا (کہ) وہ پیچھے سے پھٹا ہوا تھا تو اس نے کہا: بیشک یہ تم عورتوں کا فریب ہے۔ یقیناً تم عورتوں کا فریب بڑا (خطرناک) ہوتا ہے،\qt@no{28}}%
\qt@newcmd\qurantrans@ur@mdcxxv{اے یوسف! تم اس بات سے درگزر کرو اور (اے زلیخا!) تو اپنے گناہ کی معافی مانگ، بیشک تو ہی خطاکاروں میں سے تھی،\qt@no{29}}%
\qt@newcmd\qurantrans@ur@mdcxxvi{اور شہر میں (اُمراء کی) کچھ عورتوں نے کہنا (شروع) کر دیا کہ عزیز کی بیوی اپنے غلام کو اس سے مطلب براری کے لئے پھسلاتی ہے، اس (غلام) کی محبت اس کے دل میں گھر کر گئی ہے، بیشک ہم اسے کھلی گمراہی میں دیکھ رہی ہیں،\qt@no{30}}%
\qt@newcmd\qurantrans@ur@mdcxxvii{پس جب اس (زلیخا) نے ان کی مکارانہ باتیں سنیں (تو) انہیں بلوا بھیجا اور ان کے لئے مجلس آراستہ کی (پھر ان کے سامنے پھل رکھ دیئے) اور ان میں سے ہر ایک کو ایک ایک چھری دے دی اور (یوسف علیہ السلام سے) درخواست کی کہ ذرا ان کے سامنے سے (ہوکر) نکل جاؤ (تاکہ انہیں بھی میری کیفیت کا سبب معلوم ہو جائے)، سو جب انہوں نے یوسف (علیہ السلام کے حسنِ زیبا) کو دیکھا تو اس (کے جلوۂ جمال) کی بڑائی کرنے لگیں اور وہ (مدہوشی کے عالم میں پھل کاٹنے کے بجائے) اپنے ہاتھ کاٹ بیٹھیں اور (دیکھ لینے کے بعد بے ساختہ) بول اٹھیں: اﷲ کی پناہ! یہ تو بشر نہیں ہے، یہ تو بس کوئی برگزیدہ فرشتہ (یعنی عالمِ بالا سے اترا ہوا نور کا پیکر) ہے،\qt@no{31}}%
\qt@newcmd\qurantrans@ur@mdcxxviii{زلیخا کی تدبیر کامیاب ہوگئی تب) وہ بولی: یہی وہ (پیکرِ نور) ہے جس کے بارے میں تم مجھے ملامت کرتی تھیں اور بیشک میں نے ہی (اپنی خواہش کی شدت میں) اسے پھسلانے کی کوشش کی مگر وہ سراپا عصمت ہی رہا، اور اگر (اب بھی) اس نے وہ نہ کیا جو میں اسے کہتی ہوں تو وہ ضرور قید کیا جائے گا اور وہ یقینًا بے آبرو کیا جائے گا،\qt@no{32}}%
\qt@newcmd\qurantrans@ur@mdcxxix{اب زنانِ مصر بھی زلیخا کی ہم نوا بن گئی تھیں) یوسف (علیہ السلام) نے (سب کی باتیں سن کر) عرض کیا: اے میرے رب! مجھے قید خانہ اس کام سے کہیں زیادہ محبوب ہے جس کی طرف یہ مجھے بلاتی ہیں اور اگر تو نے ان کے مکر کو مجھ سے نہ پھیرا تو میں ان کی (باتوں کی) طرف مائل ہو جاؤں گا اور میں نادانوں میں سے ہو جاؤں گا،\qt@no{33}}%
\qt@newcmd\qurantrans@ur@mdcxxx{سو ان کے رب نے ان کی دعا قبول فرما لی اور عورتوں کے مکر و فریب کو ان سے دور کر دیا۔ بیشک وہی خوب سننے والا خوب جاننے والا ہے،\qt@no{34}}%
\qt@newcmd\qurantrans@ur@mdcxxxi{پھر انہیں (یوسف علیہ السلام کی پاک بازی کی) نشانیاں دیکھ لینے کے بعد بھی یہی مناسب معلوم ہوا کہ اسے ایک مدت تک قید کر دیں (تاکہ عوام میں اس واقعہ کا چرچا ختم ہو جائے)،\qt@no{35}}%
\qt@newcmd\qurantrans@ur@mdcxxxii{اور ان کے ساتھ دو جوان بھی قید خانہ میں داخل ہوئے۔ ان میں سے ایک نے کہا: میں نے اپنے آپ کو (خواب میں) دیکھا ہے کہ میں (انگور سے) شراب نچوڑ رہا ہوں، اور دوسرے نے کہا: میں نے اپنے آپ کو (خواب میں) دیکھا ہے کہ میں اپنے سر پر روٹیاں اٹھائے ہوئے ہوں، اس میں سے پرندے کھا رہے ہیں۔ (اے یوسف!) ہمیں اس کی تعبیر بتائیے، بیشک ہم آپ کو نیک لوگوں میں سے دیکھ رہے ہیں،\qt@no{36}}%
\qt@newcmd\qurantrans@ur@mdcxxxiii{یوسف (علیہ السلام) نے کہا: جو کھانا (روز) تمہیں کھلایا جاتا ہے وہ تمہارے پاس آنے بھی نہ پائے گا کہ میں تم دونوں کو اس کی تعبیر تمہارے پاس اس کے آنے سے قبل بتا دوں گا، یہ (تعبیر) ان علوم میں سے ہے جو میرے رب نے مجھے سکھائے ہیں۔ بیشک میں نے اس قوم کا مذہب (شروع ہی سے) چھوڑ رکھا ہے جو اﷲ پر ایمان نہیں لاتے اور وہ آخرت کے بھی منکر ہیں،\qt@no{37}}%
\qt@newcmd\qurantrans@ur@mdcxxxiv{اور میں نے تو اپنے باپ دادا، ابراہیم اور اسحاق اور یعقوب (علیھم السلام) کے دین کی پیروی کر رکھی ہے، ہمیں کوئی حق نہیں کہ ہم کسی چیز کو بھی اﷲ کے ساتھ شریک ٹھہرائیں، یہ (توحید) ہم پر اور لوگوں پر اﷲ کا (خاص) فضل ہے لیکن اکثر لوگ شکر ادا نہیں کرتے،\qt@no{38}}%
\qt@newcmd\qurantrans@ur@mdcxxxv{اے میرے قید خانہ کے دونوں ساتھیو! (بتاؤ) کیا الگ الگ بہت سے معبود بہتر ہیں یا ایک اﷲ جو سب پر غالب ہے،\qt@no{39}}%
\qt@newcmd\qurantrans@ur@mdcxxxvi{تم (حقیقت میں) اﷲ کے سوا کسی کی عبادت نہیں کرتے ہو مگر چند ناموں کی جو خود تم نے اور تمہارے باپ دادا نے (اپنے پاس سے) رکھ لئے ہیں، اﷲ نے ان کی کوئی سند نہیں اتاری۔ حکم کا اختیار صرف اﷲ کو ہے، اسی نے حکم فرمایا ہے کہ تم اس کے سوا کسی کی عبادت نہ کرو، یہی سیدھا راستہ (درست دین) ہے لیکن اکثر لوگ نہیں جانتے،\qt@no{40}}%
\qt@newcmd\qurantrans@ur@mdcxxxvii{اے میرے قید خانہ کے دونوں ساتھیو! تم میں سے ایک (کے خواب کی تعبیر یہ ہے کہ وہ) اپنے مربّی (یعنی بادشاہ) کو شراب پلایا کرے گا، اور رہا دوسرا (جس نے سر پر روٹیاں دیکھی ہیں) تو وہ پھانسی دیا جائے گا پھر پرندے اس کے سر سے (گوشت نوچ کر) کھائیں گے، (قطعی) فیصلہ کر دیا گیا جس کے بارے میں تم دریافت کرتے ہو،\qt@no{41}}%
\qt@newcmd\qurantrans@ur@mdcxxxviii{اور یوسف (علیہ السلام) نے اس شخص سے کہا جسے ان دونوں میں سے رہائی پانے والا سمجھا کہ اپنے بادشاہ کے پاس میرا ذکر کر دینا (شاید اسے یاد آجائے کہ ایک اور بے گناہ بھی قید میں ہے) مگر شیطان نے اسے اپنے بادشاہ کے پاس (وہ) ذکر کرنا بھلا دیا نتیجۃً یوسف (علیہ السلام) کئی سال تک قید خانہ میں ٹھہرے رہے،\qt@no{42}}%
\qt@newcmd\qurantrans@ur@mdcxxxix{اور (ایک روز) بادشاہ نے کہا: میں نے (خواب میں) سات موٹی تازی گائیں دیکھی ہیں، انہیں سات دبلی پتلی گائیں کھا رہی ہیں اور سات سبز خوشے (دیکھے) ہیں اور دوسرے (سات ہی) خشک، اے درباریو! مجھے میرے خواب کا جواب بیان کرو اگر تم خواب کی تعبیر جانتے ہو،\qt@no{43}}%
\qt@newcmd\qurantrans@ur@mdcxl{انہوں نے کہا: (یہ) پریشاں خوابیں ہیں، اور ہم پریشاں خوابوں کی تعبیر نہیں جانتے،\qt@no{44}}%
\qt@newcmd\qurantrans@ur@mdcxli{اور وہ شخص جو ان دونوں میں سے رہائی پا چکا تھا بولا، اور (اب) اسے ایک مدت کے بعد (یوسف علیہ السلام کے ساتھ کیا ہوا وعدہ) یاد آگیا: میں تمہیں اس کی تعبیر بتاؤں گا سو تم مجھے (یوسف علیہ السلام کے پاس) بھیجو،\qt@no{45}}%
\qt@newcmd\qurantrans@ur@mdcxlii{وہ قید خانہ میں پہنچ کر کہنے لگا:) اے یوسف، اے صدقِ مجسّم! آپ ہمیں (اس خواب کی) تعبیر بتا دیں کہ سات فربہ گائیں ہیں جنہیں سات دبلی گائیں کھا رہی ہیں اور سات سبز خوشے ہیں اور دوسرے سات خشک؛ تاکہ میں (یہ تعبیر لے کر) واپس لوگوں کے پاس جاؤں شاید انہیں (آپ کی قدر و منزلت) معلوم ہو جائے،\qt@no{46}}%
\qt@newcmd\qurantrans@ur@mdcxliii{یوسف (علیہ السلام) نے کہا: تم لوگ دائمی عادت کے مطابق مسلسل سات برس تک کاشت کرو گے سو جو کھیتی تم کاٹا کرو گے اسے اس کے خوشوں (ہی) میں (ذخیرہ کے طور پر) رکھتے رہنا مگر تھوڑا سا (نکال لینا) جسے تم (ہر سال) کھا لو،\qt@no{47}}%
\qt@newcmd\qurantrans@ur@mdcxliv{پھر اس کے بعد سات (سال) بہت سخت (خشک سالی کے) آئیں گے وہ اس (ذخیرہ) کو کھا جائیں گے جو تم ان کے لئے پہلے جمع کرتے رہے تھے مگر تھوڑا سا (بچ جائے گا) جو تم محفوظ کر لوگے،\qt@no{48}}%
\qt@newcmd\qurantrans@ur@mdcxlv{پھر اس کے بعد ایک سال ایسا آئے گا جس میں لوگوں کو (خوب) بارش دی جائے گی اور (اس سال اس قدر پھل ہوں گے کہ) لوگ اس میں (پھلوں کا) رس نچوڑیں گے،\qt@no{49}}%
\qt@newcmd\qurantrans@ur@mdcxlvi{اور (یہ تعبیر سنتے ہی) بادشاہ نے کہا: یوسف (علیہ السلام) کو (فورًا) میرے پاس لے آؤ، پس جب یوسف (علیہ السلام) کے پاس قاصد آیا تو انہوں نے کہا: اپنے بادشاہ کے پاس لوٹ جا اور اس سے (یہ) پوچھ (کہ) ان عورتوں کا (اب) کیا حال ہے جنہوں نے اپنے ہاتھ کاٹ ڈالے تھے؟ بیشک میرا رب ان کے مکر و فریب کو خوب جاننے والا ہے،\qt@no{50}}%
\qt@newcmd\qurantrans@ur@mdcxlvii{بادشاہ نے (زلیخا سمیت عورتوں کو بلا کر) پوچھا: تم پر کیا بیتا تھا جب تم (سب) نے یوسف (علیہ السلام) کو ان کی راست روی سے بہکانا چاہا تھا (بتاؤ وہ معاملہ کیا تھا)؟ وہ سب (بہ یک زبان) بولیں: اﷲ کی پناہ! ہم نے (تو) یوسف (علیہ السلام) میں کوئی برائی نہیں پائی۔ عزیزِ مصر کی بیوی (زلیخا بھی) بول اٹھی: اب تو حق آشکار ہو چکا ہے (حقیقت یہ ہے کہ) میں نے ہی انہیں اپنی مطلب براری کے لئے پھسلانا چاہا تھا اور بیشک وہی سچے ہیں،\qt@no{51}}%
\qt@newcmd\qurantrans@ur@mdcxlviii{یوسف علیہ السلام نے کہا: میں نے) یہ اس لئے (کیا ہے) کہ وہ (عزیزِ مصر جو میرا محسن و مربّی تھا) جان لے کہ میں نے اس کی غیابت میں (پشت پیچھے) اس کی کوئی خیانت نہیں کی اور بیشک اﷲ خیانت کرنے والوں کے مکر و فریب کو کامیاب نہیں ہونے دیتا،\qt@no{52}}%
\qt@newcmd\qurantrans@ur@mdcxlix{اور میں اپنے نفس کی برات (کا دعوٰی) نہیں کرتا، بیشک نفس تو برائی کا بہت ہی حکم دینے والا ہے سوائے اس کے جس پر میرا رب رحم فرما دے۔ بیشک میرا رب بڑا بخشنے والا نہایت مہربان ہے،\qt@no{53}}%
\qt@newcmd\qurantrans@ur@mdcl{اور بادشاہ نے کہا: انہیں میرے پاس لے آؤ کہ میں انہیں اپنے لئے (مشیرِ) خاص کر لوں، سو جب بادشاہ نے آپ سے (بالمشافہ) گفتگو کی (تو نہایت متاثر ہوا اور) کہنے لگا: (اے یوسف!) بیشک آپ آج سے ہمارے ہاں مقتدر (اور) معتمد ہیں (یعنی آپ کو اقتدار میں شریک کر لیا گیا ہے)،\qt@no{54}}%
\qt@newcmd\qurantrans@ur@mdcli{یوسف (علیہ السلام) نے فرمایا: (اگر تم نے واقعی مجھ سے کوئی خاص کام لینا ہے تو) مجھے سرزمینِ (مصر) کے خزانوں پر (وزیر اور امین) مقرر کر دو، بیشک میں (ان کی) خوب حفاظت کرنے والا (اور اقتصادی امور کا) خوب جاننے والا ہوں،\qt@no{55}}%
\qt@newcmd\qurantrans@ur@mdclii{اور اس طرح ہم نے یوسف (علیہ السلام) کو ملک (مصر) میں اقتدار بخشا (تاکہ) اس میں جہاں چاہیں رہیں۔ ہم جسے چاہتے ہیں اپنی رحمت سے سرفراز فرماتے ہیں اور نیکوکاروں کا اجر ضائع نہیں کرتے،\qt@no{56}}%
\qt@newcmd\qurantrans@ur@mdcliii{اور یقیناً آخرت کا اجر ان لوگوں کے لئے بہتر ہے جو ایمان لائے اور روشِ تقوٰی پر گامزن رہے،\qt@no{57}}%
\qt@newcmd\qurantrans@ur@mdcliv{اور (قحط کے زمانہ میں) یوسف (علیہ السلام) کے بھائی (غلہ لینے کے لئے مصر) آئے تو ان کے پاس حاضر ہوئے پس یوسف (علیہ السلام) نے انہیں پہچان لیا اور وہ انہیں نہ پہچان سکے،\qt@no{58}}%
\qt@newcmd\qurantrans@ur@mdclv{اور جب یوسف (علیہ السلام) نے ان کا سامان (زاد و متاع) انہیں مہیا کر دیا (تو) فرمایا: اپنے پدری بھائی (بنیامین) کو میرے پاس لے آؤ، کیا تم نہیں دیکھتے کہ میں (کس قدر) پورا ناپتا ہوں اور میں بہترین مہمان نواز (بھی) ہوں،\qt@no{59}}%
\qt@newcmd\qurantrans@ur@mdclvi{پس اگر تم اسے میرے پاس نہ لائے تو (آئندہ) تمہارے لئے میرے پاس (غلہ کا) کوئی پیمانہ نہ ہوگا اور نہ (ہی) تم میرے قریب آسکو گے،\qt@no{60}}%
\qt@newcmd\qurantrans@ur@mdclvii{وہ بولے: ہم اس کے بھیجنے سے متعلق اس کے باپ سے ضرور تقاضا کریں گے اور ہم یقیناً (ایسا) کریں گے،\qt@no{61}}%
\qt@newcmd\qurantrans@ur@mdclviii{اور یوسف (علیہ السلام) نے اپنے غلاموں سے فرمایا: ان کی رقم (جو انہوں نے غلہ کے عوض اد اکی تھی واپس) ان کی بوریوں میں رکھ دو تاکہ جب وہ اپنے گھر والوں کی طرف لوٹیں تو اسے پہچان لیں (کہ یہ رقم تو واپس آگئی ہے) شاید وہ (اسی سبب سے) لوٹ کر آجائیں،\qt@no{62}}%
\qt@newcmd\qurantrans@ur@mdclix{سو جب وہ اپنے والد کی طرف لوٹے (تو) کہنے لگے: اے ہمارے باپ! (آئندہ کے لئے) ہم پر غلہ بند کر دیا گیا ہے (سوائے اس کے کہ بنیامین ہمارے ساتھ جائے) پس ہمارے بھائی (بنیامین) کو ہمارے ساتھ بھیج دیں (تاکہ) ہم (مزید) غلہ لے آئیں اور ہم یقیناً اس کے محافظ ہوں گے،\qt@no{63}}%
\qt@newcmd\qurantrans@ur@mdclx{یعقوب (علیہ السلام) نے فرمایا: کیا میں اس کے بارے میں (بھی) تم پر اسی طرح اعتماد کر لوں جیسے اس سے قبل میں نے اس کے بھائی (یوسف علیہ السلام) کے بارے میں تم پر اعتماد کر لیا تھا؟ تو اﷲ ہی بہتر حفاظت فرمانے والا ہے اور وہی سب مہربانوں سے زیادہ مہربان ہے،\qt@no{64}}%
\qt@newcmd\qurantrans@ur@mdclxi{جب انہوں نے اپنا سامان کھولا (تو اس میں) اپنی رقم پائی (جو) انہیں لوٹا دی گئی تھی، وہ کہنے لگے: اے ہمارے والد گرامی! ہمیں اور کیا چاہئے؟ یہ ہماری رقم (بھی) ہماری طرف لوٹا دی گئی ہے اور (اب تو) ہم اپنے گھر والوں کے لئے (ضرور ہی) غلہ لائیں گے اور ہم اپنے بھائی کی حفاظت کریں گے اور ایک اونٹ کا بوجھ اور زیادہ لائیں گے، اور یہ (غلہ جو ہم پہلے لائے ہیں) تھوڑی مقدار (میں) ہے،\qt@no{65}}%
\qt@newcmd\qurantrans@ur@mdclxii{یعقوب (علیہ السلام) نے فرمایا: میں اسے ہرگز تمہارے ساتھ نہیں بھیجوں گا یہاں تک کہ تم اﷲ کی قسم کھا کر مجھے پختہ وعدہ دو کہ تم اسے ضرور میرے پاس (واپس) لے آؤ گے سوائے اس کے کہ تم (سب) کو (کہیں) گھیر لیا جائے (یا ہلاک کر دیا جائے)، پھر جب انہوں نے یعقوب (علیہ السلام) کو اپنا پختہ عہد دے دیا تو یعقوب (علیہ السلام) نے فرمایا: جو کچھ ہم کہہ رہے ہیں اس پر اﷲ نگہبان ہے،\qt@no{66}}%
\qt@newcmd\qurantrans@ur@mdclxiii{اور فرمایا: اے میرے بیٹو! (شہر میں) ایک دروازے سے داخل نہ ہونا بلکہ مختلف دروازوں سے (تقسیم ہو کر) داخل ہونا، اور میں تمہیں اﷲ (کے اَمر) سے کچھ نہیں بچا سکتا کہ حکم (تقدیر) صرف اﷲ ہی کے لئے ہے۔ میں نے اسی پر بھروسہ کیا ہے اور بھروسہ کرنے والوں کو اسی پر بھروسہ کرنا چاہئے،\qt@no{67}}%
\qt@newcmd\qurantrans@ur@mdclxiv{اور جب وہ (مصر میں) داخل ہوئے جس طرح ان کے باپ نے انہیں حکم دیا تھا، وہ (حکم) انہیں اﷲ (کی تقدیر) سے کچھ نہیں بچا سکتا تھا مگر یہ یعقوب (علیہ السلام) کے دل کی ایک خواہش تھی جسے اس نے پورا کیا، اور (اس خواہش و تدبیر کو لغو بھی نہ سمجھنا، تمہیں کیا خبر!) بیشک یعقوب (علیہ السلام) صاحبِ علم تھے اس وجہ سے کہ ہم نے انہیں علمِ (خاص) سے نوازا تھا مگر اکثر لوگ (ان حقیقتوں کو) نہیں جانتے،\qt@no{68}}%
\qt@newcmd\qurantrans@ur@mdclxv{اور جب وہ یوسف (علیہ السلام) کے پاس حاضر ہوئے تو یوسف (علیہ السلام) نے اپنے بھائی (بنیامین) کو اپنے پاس جگہ دی (اسے آہستہ سے) کہا: بیشک میں ہی تیرا بھائی (یوسف) ہوں پس تو غمزدہ نہ ہو ان کاموں پر جو یہ کرتے رہے ہیں،\qt@no{69}}%
\qt@newcmd\qurantrans@ur@mdclxvi{پھر جب (یوسف علیہ السلام نے) ان کا سامان انہیں مہیا کر دیا تو (شاہی) پیالہ اپنے بھائی (بنیامین) کی بوری میں رکھ دیا بعد ازاں پکارنے والے نے آواز دی: اے قافلہ والو! (ٹھہرو) یقیناً تم لوگ ہی چور (معلوم ہوتے) ہو،\qt@no{70}}%
\qt@newcmd\qurantrans@ur@mdclxvii{وہ ان کی طرف متوجہ ہو کر کہنے لگے: تمہاری کیا چیز گم ہوگئی ہے،\qt@no{71}}%
\qt@newcmd\qurantrans@ur@mdclxviii{وہ (درباری ملازم) بولے: ہمیں بادشاہ کا پیالہ نہیں مل رہا اور جو کوئی اسے (ڈھونڈ کر) لے آئے اس کے لئے ایک اونٹ کا غلہ (انعام) ہے اور میں اس کا ذمہ دار ہوں،\qt@no{72}}%
\qt@newcmd\qurantrans@ur@mdclxix{وہ کہنے لگے: اﷲ کی قسم! بیشک تم جان گئے ہو (گے) ہم اس لئے نہیں آئے تھے کہ (جرم کا ارتکاب کر کے) زمین میں فساد بپا کریں اور نہ ہی ہم چور ہیں،\qt@no{73}}%
\qt@newcmd\qurantrans@ur@mdclxx{وہ (ملازم) بولے: (تم خود ہی بتاؤ) کہ اس (چور) کی کیا سزا ہوگی اگر تم جھوٹے نکلے،\qt@no{74}}%
\qt@newcmd\qurantrans@ur@mdclxxi{انہوں نے کہا: اس کی سزا یہ ہے کہ جس کے سامان میں سے وہ (پیالہ) برآمد ہو وہ خود ہی اس کا بدلہ ہے (یعنی اسی کو اس کے بدلہ میں رکھ لیا جائے)، ہم ظالموں کو اسی طرح سزا دیتے ہیں،\qt@no{75}}%
\qt@newcmd\qurantrans@ur@mdclxxii{پس یوسف (علیہ السلام) نے اپنے بھائی کی بوری سے پہلے ان کی بوریوں کی تلاشی شروع کی پھر (بالآخر) اس (پیالے) کو اپنے (سگے) بھائی (بنیامین) کی بوری سے نکال لیا۔ یوں ہم نے یوسف (علیہ السلام) کو تدبیر بتائی۔ وہ اپنے بھائی کو بادشاہِ (مصر) کے قانون کی رو سے (اسیر بنا کر) نہیں رکھ سکتے تھے مگر یہ کہ (جیسے) اﷲ چاہے۔ ہم جس کے چاہتے ہیں درجات بلند کر دیتے ہیں، اور ہر صاحبِ علم سے اوپر (بھی) ایک علم والا ہوتا ہے،\qt@no{76}}%
\qt@newcmd\qurantrans@ur@mdclxxiii{انہوں نے کہا: اگر اس نے چوری کی ہے (تو کوئی تعجب نہیں) بیشک اس کا بھائی (یوسف) بھی اس سے پہلے چوری کر چکا ہے، سو یوسف (علیہ السلام) نے یہ بات اپنے دل میں (چھپائی) رکھی اور اسے ان پر ظاہر نہ کیا، (دل میں ہی) کہا: تمہارا حال نہایت برا ہے، اور اﷲ خوب جانتا ہے جو کچھ تم بیان کر رہے ہو،\qt@no{77}}%
\qt@newcmd\qurantrans@ur@mdclxxiv{وہ بولے: اے عزیزِ مصر! اس کے والد بڑے معمر بزرگ ہیں، آپ اس کی جگہ ہم میں سے کسی کو پکڑ لیں، بیشک ہم آپ کو احسان کرنے والوں میں پاتے ہیں،\qt@no{78}}%
\qt@newcmd\qurantrans@ur@mdclxxv{یوسف (علیہ السلام) نے کہا: اﷲ کی پناہ کہ ہم نے جس کے پاس اپنا سامان پایا اس کے سوا کسی (اور) کو پکڑ لیں تب تو ہم ظالموں میں سے ہو جائیں گے،\qt@no{79}}%
\qt@newcmd\qurantrans@ur@mdclxxvi{پھر جب وہ یوسف (علیہ السلام) سے مایوس ہوگئے تو علیحدگی میں (باہم) سرگوشی کرنے لگے، ان کے بڑے (بھائی) نے کہا: کیا تم نہیں جانتے کہ تمہارے باپ نے تم سے اﷲ کی قسم اٹھوا کر پختہ وعدہ لیا تھا اور اس سے پہلے تم یوسف کے حق میں جو زیادتیاں کر چکے ہو (تمہیں وہ بھی معلوم ہیں)، سو میں اس سرزمین سے ہرگز نہیں جاؤں گا جب تک مجھے میرا باپ اجازت (نہ) دے یا میرے لئے اﷲ کوئی فیصلہ فرما دے، اور وہ سب سے بہتر فیصلہ فرمانے والا ہے،\qt@no{80}}%
\qt@newcmd\qurantrans@ur@mdclxxvii{تم اپنے باپ کی طرف لوٹ جاؤ پھر (جا کر) کہو: اے ہمارے باپ! بیشک آپ کے بیٹے نے چوری کی ہے (اس لئے وہ گرفتار کر لیا گیا) اور ہم نے فقط اسی بات کی گواہی دی تھی جس کا ہمیں علم تھا اور ہم غیب کے نگہبان نہ تھے،\qt@no{81}}%
\qt@newcmd\qurantrans@ur@mdclxxviii{اور (اگر آپ کو اعتبار نہ آئے تو) اس بستی (والوں) سے پوچھ لیں جس میں ہم تھے اور اس قافلہ (والوں) سے (معلوم کر لیں) جس میں ہم آئے ہیں، اور بیشک ہم (اپنے قول میں) یقیناً سچے ہیں،\qt@no{82}}%
\qt@newcmd\qurantrans@ur@mdclxxix{یعقوب (علیہ السلام) نے فرمایا: (ایسا نہیں) بلکہ تمہارے نفسوں نے یہ بات تمہارے لئے مرغوب بنا دی ہے، اب صبر (ہی) اچھا ہے، قریب ہے کہ اﷲ ان سب کو میرے پاس لے آئے، بیشک وہ بڑا علم والا بڑی حکمت والا ہے،\qt@no{83}}%
\qt@newcmd\qurantrans@ur@mdclxxx{اور یعقوب (علیہ السلام) نے ان سے منہ پھیر لیا اور کہا: ہائے افسوس! یوسف (علیہ السلام کی جدائی) پر اور ان کی آنکھیں غم سے سفید ہوگئیں سو وہ غم کو ضبط کئے ہوئے تھے،\qt@no{84}}%
\qt@newcmd\qurantrans@ur@mdclxxxi{وہ بولے: اﷲ کی قسم! آپ ہمیشہ یوسف (ہی) کو یاد کرتے رہیں گے یہاں تک کہ آپ قریب مرگ ہو جائیں گے یا آپ وفات پا جائیں گے،\qt@no{85}}%
\qt@newcmd\qurantrans@ur@mdclxxxii{انہوں نے فرمایا: میں تو اپنی پریشانی اور غم کی فریاد صرف اﷲ کے حضور کرتا ہوں اور میں اﷲ کی طرف سے وہ کچھ جانتا ہوں جو تم نہیں جانتے،\qt@no{86}}%
\qt@newcmd\qurantrans@ur@mdclxxxiii{اے میرے بیٹو! جاؤ (کہیں سے) یوسف (علیہ السلام) اور اس کے بھائی کی خبر لے آؤ اور اﷲ کی رحمت سے مایوس نہ ہو، بیشک اﷲ کی رحمت سے صرف وہی لوگ مایوس ہوتے ہیں جو کافر ہیں،\qt@no{87}}%
\qt@newcmd\qurantrans@ur@mdclxxxiv{سو جب وہ (دوبارہ) یوسف (علیہ السلام) کے پاس حاضر ہوئے تو کہنے لگے: اے عزیزِ مصر! ہم پر اور ہمارے گھر والوں پر مصیبت آن پڑی ہے (ہم شدید قحط میں مبتلا ہیں) اور ہم (یہ) تھوڑی سی رقم لے کر آئے ہیں سو (اس کے بدلے) ہمیں (غلہ کا) پورا پورا ناپ دے دیں اور (اس کے علاوہ) ہم پر (کچھ) صدقہ (بھی) کر دیں۔ بیشک اﷲ خیرات کرنے والوں کو جزا دیتا ہے،\qt@no{88}}%
\qt@newcmd\qurantrans@ur@mdclxxxv{یوسف (علیہ السلام) نے فرمایا: کیا تمہیں معلوم ہے کہ تم نے یوسف اور اس کے بھائی کے ساتھ کیا (سلوک) کیا تھا کیا تم (اس وقت) نادان تھے،\qt@no{89}}%
\qt@newcmd\qurantrans@ur@mdclxxxvi{وہ بولے: کیا واقعی تم ہی یوسف ہو؟ انہوں نے فرمایا: (ہاں) میں یوسف ہوں اور یہ میرا بھائی ہے بیشک اﷲ نے ہم پر احسان فرمایا ہے، یقیناً جو شخص اﷲ سے ڈرتا اور صبر کرتا ہے تو بیشک اﷲ نیکوکاروں کا اجر ضائع نہیں کرتا،\qt@no{90}}%
\qt@newcmd\qurantrans@ur@mdclxxxvii{وہ بول اٹھے: اﷲ کی قسم! بیشک اﷲ نے آپ کو ہم پر فضیلت دی ہے اور یقیناً ہم ہی خطاکار تھے،\qt@no{91}}%
\qt@newcmd\qurantrans@ur@mdclxxxviii{یوسف (علیہ السلام) نے فرمایا: آج کے دن تم پر کوئی ملامت (اور گرفت) نہیں ہے، اﷲ تمہیں معاف فرما دے اور وہ سب مہربانوں سے زیادہ مہربان ہے،\qt@no{92}}%
\qt@newcmd\qurantrans@ur@mdclxxxix{میرا یہ قمیض لے جاؤ، سو اسے میرے باپ کے چہرے پر ڈال دینا، وہ بینا ہو جائیں گے، اور (پھر) اپنے سب گھر والوں کو میرے پاس لے آؤ،\qt@no{93}}%
\qt@newcmd\qurantrans@ur@mdcxc{اور جب قافلہ (مصر سے) روانہ ہوا ان کے والد (یعقوب علیہ السلام) نے (کنعان میں بیٹھے ہی) فرما دیا: بیشک میں یوسف کی خوشبو پا رہا ہوں اگر تم مجھے بڑھاپے کے باعث بہکا ہوا خیال نہ کرو،\qt@no{94}}%
\qt@newcmd\qurantrans@ur@mdcxci{وہ بولے: اﷲ کی قسم یقیناً آپ اپنی (اسی) پرانی محبت کی خود رفتگی میں ہیں،\qt@no{95}}%
\qt@newcmd\qurantrans@ur@mdcxcii{پھر جب خوشخبری سنانے والا آپہنچا اس نے وہ قمیض یعقوب (علیہ السلام) کے چہرے پر ڈال دیا تو اسی وقت ان کی بینائی لوٹ آئی، یعقوب (علیہ السلام) نے فرمایا: کیا میں تم سے نہیں کہتا تھا کہ بیشک میں اﷲ کی طرف سے وہ کچھ جانتا ہوں جو تم نہیں جانتے،\qt@no{96}}%
\qt@newcmd\qurantrans@ur@mdcxciii{وہ بولے: اے ہمارے باپ! ہمارے لئے (اﷲ سے) ہمارے گناہوں کی مغفرت طلب کیجئے، بیشک ہم ہی خطاکار تھے،\qt@no{97}}%
\qt@newcmd\qurantrans@ur@mdcxciv{یعقوب (علیہ السلام) نے فرمایا: میں عنقریب تمہارے لئے اپنے رب سے بخشش طلب کروں گا، بیشک وہی بڑا بخشنے والا نہایت مہربان ہے،\qt@no{98}}%
\qt@newcmd\qurantrans@ur@mdcxcv{پھر جب وہ (سب اَفرادِ خانہ) یوسف (علیہ السلام) کے پاس آئے (تو) یوسف (علیہ السلام) نے (شہر سے باہر آکر ہزارہا سواریوں، فوجیوں اور لوگوں کے ہمراہ شاہی جلوس کی صورت میں ان کا استقبال کیا اور) اپنے ماں باپ کو تعظیماً اپنے قریب جگہ دی (یا انہیں اپنے گلے سے لگا لیا) اور (خوش آمدید کہتے ہوئے) فرمایا: آپ مصر میں داخل ہو جائیں اگر اﷲ نے چاہا (تو) امن و عافیت کے ساتھ (یہیں قیام کریں)،\qt@no{99}}%
\qt@newcmd\qurantrans@ur@mdcxcvi{اور یوسف (علیہ السلام) نے اپنے والدین کو اوپر تخت پر بٹھا لیا اور وہ (سب) یوسف (علیہ السلام) کے لئے سجدہ میں گر پڑے، اور یوسف (علیہ السلام) نے کہا: اے ابا جان! یہ میرے (اس) خواب کی تعبیر ہے جو (بہت) پہلے آیا تھا (اکثر مفسرین کے نزدیک اسے چالیس سال کا عرصہ گزر گیا تھا) اور بیشک میرے رب نے اسے سچ کر دکھایا ہے، اور بیشک اس نے مجھ پر (بڑا) احسان فرمایا جب مجھے جیل سے نکالا اور آپ سب کو صحرا سے (یہاں) لے آیا اس کے بعد کہ شیطان نے میرے اور میرے بھائیوں کے درمیان فساد پیدا کر دیا تھا، اور بیشک میرا رب جس چیز کو چاہے (اپنی) تدبیر سے آسان فرما دے، بیشک وہی خوب جاننے والا بڑی حکمت والا ہے،\qt@no{100}}%
\qt@newcmd\qurantrans@ur@mdcxcvii{اے میرے رب! بیشک تو نے مجھے سلطنت عطا فرمائی اور تو نے مجھے خوابوں کی تعبیر کے علم سے نوازا، اے آسمانوں اور زمین کے پیدا فرمانے والے! تو دنیا میں (بھی) میرا کارساز ہے اور آخرت میں (بھی)، مجھے حالتِ اسلام پر موت دینا اور مجھے صالح لوگوں کے ساتھ ملا دے،\qt@no{101}}%
\qt@newcmd\qurantrans@ur@mdcxcviii{اے حبیبِ مکرّم!) یہ (قصّہ) غیب کی خبروں میں سے ہے جسے ہم آپ کی طرف وحی فرما رہے ہیں، اور آپ (کوئی) ان کے پاس موجود نہ تھے جب وہ (برادرانِ یوسف) اپنی سازشی تدبیر پر جمع ہو رہے تھے اور وہ مکر و فریب کر رہے تھے،\qt@no{102}}%
\qt@newcmd\qurantrans@ur@mdcxcix{اور اکثر لوگ ایمان لانے والے نہیں ہیں اگرچہ آپ (کتنی ہی) خواہش کریں،\qt@no{103}}%
\qt@newcmd\qurantrans@ur@mdcc{اور آپ ان سے اس (دعوت و تبلیغ) پر کوئی صلہ تو نہیں مانگتے، یہ قرآن جملہ جہان والوں کے لئے نصیحت ہی تو ہے،\qt@no{104}}%
\qt@newcmd\qurantrans@ur@mdcci{اور آسمانوں اور زمین میں کتنی ہی نشانیاں ہیں جن پر ان لوگوں کا گزر ہوتا رہتا ہے اور وہ ان سے صرفِ نظر کئے ہوئے ہیں،\qt@no{105}}%
\qt@newcmd\qurantrans@ur@mdccii{اور ان میں سے اکثر لوگ اﷲ پر ایمان نہیں رکھتے مگر یہ کہ وہ مشرک ہیں،\qt@no{106}}%
\qt@newcmd\qurantrans@ur@mdcciii{کیا وہ اس بات سے بے خوف ہو گئے ہیں کہ ان پر اﷲ کے عذاب کی چھا جانے والی آفت آجائے یا ان پر اچانک قیامت آجائے اور انہیں خبر بھی نہ ہو،\qt@no{107}}%
\qt@newcmd\qurantrans@ur@mdcciv{اے حبیبِ مکرّم!) فرما دیجئے: یہی میری راہ ہے، میں اﷲ کی طرف بلاتا ہوں، پوری بصیرت پر (قائم) ہوں، میں (بھی) اور وہ شخص بھی جس نے میری اتباع کی، اور اﷲ پاک ہے اور میں مشرکوں میں سے نہیں ہوں،\qt@no{108}}%
\qt@newcmd\qurantrans@ur@mdccv{اور ہم نے آپ سے پہلے بھی (مختلف) بستیوں والوں میں سے مَردوں ہی کو بھیجا تھا جن کی طرف ہم وحی فرماتے تھے، کیا ان لوگوں نے زمین میں سیر نہیں کی کہ وہ (خود) دیکھ لیتے کہ ان سے پہلے لوگوں کا انجام کیا ہوا، اور بیشک آخرت کا گھر پرہیزگاری اختیار کرنے والوں کے لئے بہتر ہے، کیا تم عقل نہیں رکھتے،\qt@no{109}}%
\qt@newcmd\qurantrans@ur@mdccvi{یہاں تک کہ جب پیغمبر (اپنی نافرمان قوموں سے) مایوس ہوگئے اور ان منکر قوموں نے گمان کر لیا کہ ان سے جھوٹ بولا گیا ہے (یعنی ان پر کوئی عذاب نہیں آئے گا) تو ان رسولوں کو ہماری مدد آپہنچی پھر ہم نے جسے چاہا (اسے) نجات بخش دی، اور ہمارا عذاب مجرم قوم سے پھیرا نہیں جاتا،\qt@no{110}}%
\qt@newcmd\qurantrans@ur@mdccvii{بیشک ان کے قصوں میں سمجھ داروں کے لئے عبرت ہے، یہ (قرآن) ایسا کلام نہیں جو گھڑ لیا جائے بلکہ (یہ تو) ان (آسمانی کتابوں) کی تصدیق ہے جو اس سے پہلے (نازل ہوئی) ہیں اور ہر چیز کی تفصیل ہے اور ہدایت ہے اور رحمت ہے اس قوم کے لئے جو ایمان لے آئے،\qt@no{111}}%
\qt@newcmd\qurantrans@ur@mdccviii{\basmalahur الف، لام، میم، را (حقیقی معنی اﷲ اور رسول صلی اللہ علیہ وآلہ وسلم ہی بہتر جانتے ہیں)، یہ کتابِ الٰہی کی آیتیں ہیں، اور جو کچھ آپ کے رب کی طرف سے آپ کی جانب نازل کیا گیا ہے (وہ) حق ہے لیکن اکثر لوگ ایمان نہیں لاتے،\qt@no{1}}%
\qt@newcmd\qurantrans@ur@mdccix{اور اﷲ وہ ہے جس نے آسمانوں کو بغیر ستون کے (خلا میں) بلند فرمایا (جیسا کہ) تم دیکھ رہے ہو پھر (پوری کائنات پر محیط اپنے) تختِ اقتدار پر متمکن ہوا اور اس نے سورج اور چاند کو نظام کا پابند بنا دیا، ہر ایک اپنی مقررہ میعاد (میں مسافت مکمل کرنے) کے لئے (اپنے اپنے مدار میں) چلتا ہے۔ وہی (ساری کائنات کے) پورے نظام کی تدبیر فرماتا ہے، (سب) نشانیوں (یا قوانینِ فطرت) کو تفصیلاً واضح فرماتا ہے تاکہ تم اپنے رب کے روبرو حاضر ہونے کا یقین کر لو،\qt@no{2}}%
\qt@newcmd\qurantrans@ur@mdccx{اور وہی ہے جس نے (گولائی کے باوجود) زمین کو پھیلایا اور اس میں پہاڑ اور دریا بنائے، اور ہر قسم کے پھلوں میں (بھی) اس نے دو دو (جنسوں کے) جوڑے بنائے (وہی) رات سے دن کو ڈھانک لیتا ہے، بیشک اس میں تفکر کرنے والوں کے لئے (بہت) نشانیاں ہیں،\qt@no{3}}%
\qt@newcmd\qurantrans@ur@mdccxi{اور زمین میں (مختلف قسم کے) قطعات ہیں جو ایک دوسرے کے قریب ہیں اور انگوروں کے باغات ہیں اور کھیتیاں ہیں اور کھجور کے درخت ہیں، جھنڈدار اور بغیر جھنڈ کے، ان (سب) کو ایک ہی پانی سے سیراب کیا جاتا ہے، اور (اس کے باوجود) ہم ذائقہ میں بعض کو بعض پر فضیلت بخشتے ہیں، بیشک اس میں عقل مندوں کے لئے (بڑی) نشانیاں ہیں،\qt@no{4}}%
\qt@newcmd\qurantrans@ur@mdccxii{اور اگر آپ (کفار کے انکار پر) تعجب کریں تو ان کا (یہ) کہنا عجیب (تر) ہے کہ کیا جب ہم (مر کر) خاک ہو جائیں گے تو کیا ہم اَز سرِ نو تخلیق کئے جائیں گے؟ یہی وہ لوگ ہیں جنہوں نے اپنے رب کا انکار کیا، اور انہی لوگوں کی گردنوں میں طوق (پڑے) ہوں گے اور یہی لوگ اہلِ جہنم ہیں، وہ اس میں ہمیشہ رہنے والے ہیں،\qt@no{5}}%
\qt@newcmd\qurantrans@ur@mdccxiii{اور یہ لوگ رحمت سے پہلے آپ سے عذاب طلب کرنے میں جلدی کرتے ہیں، حالانکہ ان سے پہلے کئی عذاب گزر چکے ہیں، اور (اے حبیب!) بیشک آپ کا رب لوگوں کے لئے ان کے ظلم کے باوجود بخشش والا ہے اور یقیناً آپ کا رب سخت عذاب دینے والا (بھی) ہے،\qt@no{6}}%
\qt@newcmd\qurantrans@ur@mdccxiv{اور کافر لوگ کہتے ہیں کہ اس (رسول) پر ان کے رب کی طرف سے کوئی نشانی کیوں نہیں اتاری گئی؟ (اے رسولِ مکرّم!) آپ تو فقط (نافرمانوں کو انجامِ بد سے) ڈرانے والے اور (دنیا کی) ہر قوم کے لئے ہدایت بہم پہنچانے والے ہیں،\qt@no{7}}%
\qt@newcmd\qurantrans@ur@mdccxv{اﷲ جانتا ہے جو کچھ ہر مادہ اپنے پیٹ میں اٹھاتی ہے اور رحم جس قدر سکڑتے اور جس قدر بڑھتے ہیں، اور ہر چیز اس کے ہاں مقرر حد کے ساتھ ہے،\qt@no{8}}%
\qt@newcmd\qurantrans@ur@mdccxvi{وہ ہر نہاں اور عیاں کو جاننے والا ہے سب سے برتر (اور) اعلیٰ رتبہ والا ہے،\qt@no{9}}%
\qt@newcmd\qurantrans@ur@mdccxvii{تم میں سے جو شخص آہستہ بات کرے اور جو بلند آواز سے کرے اور جو رات (کی تاریکی) میں چھپا ہو اور جو دن (کی روشنی) میں چلتا پھرتا ہو (اس کے لئے) سب برابر ہیں،\qt@no{10}}%
\qt@newcmd\qurantrans@ur@mdccxviii{ہر) انسان کے لئے یکے بعد دیگرے آنے والے (فرشتے) ہیں جو اس کے آگے اور اس کے پیچھے اﷲ کے حکم سے اس کی نگہبانی کرتے ہیں۔ بیشک اﷲ کسی قوم کی حالت کو نہیں بدلتا یہاں تک کہ وہ لوگ اپنے آپ میں خود تبدیلی پیدا کر ڈالیں، اور جب اﷲ کسی قوم کے ساتھ (اس کی اپنی بداعمالیوں کی وجہ سے) عذاب کا ارادہ فرما لیتا ہے تو اسے کوئی ٹال نہیں سکتا، اور نہ ہی ان کے لئے اﷲ کے مقابلہ میں کوئی مددگار ہوتا ہے،\qt@no{11}}%
\qt@newcmd\qurantrans@ur@mdccxix{وہی ہے جو تمہیں (کبھی) ڈرانے اور (کبھی) امید دلانے کے لئے بجلی دکھاتا ہے اور (کبھی) بھاری (گھنے) بادلوں کو اٹھاتا ہے،\qt@no{12}}%
\qt@newcmd\qurantrans@ur@mdccxx{بجلیوں اور بادلوں کی) گرج (یا اس پر متعین فرشتہ) اور تمام فرشتے اس کے خوف سے اس کی حمد کے ساتھ تسبیح کرتے ہیں، اور وہ کڑکتی بجلیاں بھیجتا ہے پھر جس پر چاہتا ہے اسے گرا دیتا ہے، اور وہ (کفار قدرت کی ان نشانیوں کے باوجود) اﷲ کے بارے میں جھگڑا کرتے ہیں، اور وہ سخت تدبیر و گرفت والا ہے،\qt@no{13}}%
\qt@newcmd\qurantrans@ur@mdccxxi{اسی کے لئے حق (یعنی توحید) کی دعوت ہے، اور وہ (کافر) لوگ جو اس کے سوا (معبودانِ باطلہ یعنی بتوں) کی عبادت کرتے ہیں، وہ انہیں کسی چیز کا جواب بھی نہیں دے سکتے۔ ان کی مثال تو صرف اس شخص جیسی ہے جو اپنی دونوں ہتھیلیاں پانی کی طرف پھیلائے (بیٹھا) ہو کہ پانی (خود) اس کے منہ تک پہنچ جائے اور (یوں تو) وہ (پانی) اس تک پہنچنے والا نہیں، اور (اسی طرح) کافروں کا (بتوں کی عبادت اور ان سے) دعا کرنا گمراہی میں بھٹکنے کے سوا کچھ نہیں،\qt@no{14}}%
\qt@newcmd\qurantrans@ur@mdccxxii{اور جو کوئی (بھی) آسمانوں اور زمین میں ہے وہ تو اﷲ ہی کے لئے سجدہ کرتا ہے (بعض) خوشی سے اور (بعض) مجبوراً اور ان کے سائے (بھی) صبح و شام (اسی کو سجدہ کرتے ہیں، تو پھر ان کافروں نے اﷲ کو چھوڑ کر بتوں کی سجدہ ریزی کیوں شروع کر لی ہے؟)،\qt@no{15}}%
\qt@newcmd\qurantrans@ur@mdccxxiii{ان کافروں کے سامنے) فرمایئے کہ آسمانوں اور زمین کا رب کون ہے؟ آپ (خود ہی) فرما دیجئے: اﷲ ہے۔ (پھر) آپ (ان سے دریافت) فرمایئے: کیا تم نے اس کے سوا (ان بتوں) کو کارساز بنا لیا ہے جو نہ اپنی ذاتوں کے لئے کسی نفع کے مالک ہیں اور نہ کسی نقصان کے۔ آپ فرما دیجئے: کیا اندھا اور بینا برابر ہو سکتے ہیں یا کیا تاریکیاں اور روشنی برابر ہو سکتی ہیں۔ کیا انہوں نے اﷲ کے لئے ایسے شریک بنائے ہیں جنہوں نے اﷲ کی مخلوق کی طرح (کچھ مخلوق) خود (بھی) پیدا کی ہو، سو (ان بتوں کی پیدا کردہ) اس مخلوق سے ان کو تشابُہ (یعنی مغالطہ) ہو گیا ہو، فرما دیجئے: اﷲ ہی ہر چیز کا خالق ہے اور وہ ایک ہے، وہ سب پر غالب ہے،\qt@no{16}}%
\qt@newcmd\qurantrans@ur@mdccxxiv{اس نے آسمان کی جانب سے پانی اتارا تو وادیاں اپنی (اپنی) گنجائش کے مطابق بہہ نکلیں، پھر سیلاب کی رَو نے ابھرا ہوا جھاگ اٹھا لیا، اور جن چیزوں کو آگ میں تپاتے ہیں، زیور یا دوسرا سامان بنانے کے لئے اس پر بھی ویسا ہی جھاگ اٹھتا ہے، اس طرح اﷲ حق اور باطل کی مثالیں بیان فرماتا ہے، سو جھاگ تو (پانی والا ہو یا آگ والا سب) بے کار ہو کر رہ جاتا ہے اور البتہ جو کچھ لوگوں کے لئے نفع بخش ہوتا ہے وہ زمین میں باقی رہتا ہے، اﷲ اس طرح مثالیں بیان فرماتا ہے،\qt@no{17}}%
\qt@newcmd\qurantrans@ur@mdccxxv{ایسے لوگوں کے لئے جنہوں نے اپنے رب کا حکم قبول کیا بھلائی ہے، اور جنہوں نے اس کا حکم قبول نہیں کیا اگر ان کے پاس وہ سب کچھ ہو جو زمین میں ہے اور اس کے ساتھ اتنا اور بھی ہو سو وہ اسے (عذاب سے نجات کے لئے) فدیہ دے ڈالیں (تب بھی) انہی لوگوں کا حساب برا ہوگا، اور ان کا ٹھکانا دوزخ ہے، اور وہ نہایت برا ٹھکانا ہے،\qt@no{18}}%
\qt@newcmd\qurantrans@ur@mdccxxvi{بھلا وہ شخص جو یہ جانتا ہے کہ جو کچھ آپ کی طرف آپ کے رب کی جانب سے نازل کیا گیا ہے حق ہے، اس شخص کے مانند ہو سکتا ہے جو اندھا ہے، بات یہی ہے کہ نصیحت عقل مند ہی قبول کرتے ہیں،\qt@no{19}}%
\qt@newcmd\qurantrans@ur@mdccxxvii{جو لوگ اﷲ کے عہد کو پورا کرتے ہیں اور قول و قرار کو نہیں توڑتے،\qt@no{20}}%
\qt@newcmd\qurantrans@ur@mdccxxviii{اور جو لوگ ان سب (حقوق اﷲ، حقوق الرسول، حقوق العباد اور اپنے حقوقِ قرابت) کو جوڑے رکھتے ہیں، جن کے جوڑے رکھنے کا اﷲ نے حکم فرمایا ہے اور اپنے رب کی خشیّت میں رہتے ہیں اور برے حساب سے خائف رہتے ہیں،\qt@no{21}}%
\qt@newcmd\qurantrans@ur@mdccxxix{اور جو لوگ اپنے رب کی رضاجوئی کے لئے صبر کرتے ہیں اور نماز قائم رکھتے ہیں اور جو رزق ہم نے انہیں دیا ہے اس میں سے پوشیدہ اور اعلانیہ (دونوں طرح) خرچ کرتے ہیں اور نیکی کے ذریعہ برائی کو دور کرتے رہتے ہیں یہی وہ لوگ ہیں جن کے لئے آخرت کا (حسین) گھر ہے،\qt@no{22}}%
\qt@newcmd\qurantrans@ur@mdccxxx{جہاں) سدا بہار باغات ہیں ان میں وہ لوگ داخل ہوں گے اور ان کے آباء و اجداد اور ان کی بیویوں اور ان کی اولاد میں سے جو بھی نیکوکار ہوگا اور فرشتے ان کے پاس (جنت کے) ہر دروازے سے آئیں گے،\qt@no{23}}%
\qt@newcmd\qurantrans@ur@mdccxxxi{انہیں خوش آمدید کہتے اور مبارک باد دیتے ہوئے کہیں گے:) تم پر سلامتی ہو تمہارے صبر کرنے کے صلہ میں، پس (اب دیکھو) آخرت کا گھر کیا خوب ہے،\qt@no{24}}%
\qt@newcmd\qurantrans@ur@mdccxxxii{اور جو لوگ اﷲ کا عہد اس کے مضبوط کرنے کے بعد توڑ دیتے ہیں اور ان تمام (رشتوں اور حقوق) کو قطع کر دیتے ہیں جن کے جوڑے رکھنے کا اﷲ نے حکم فرمایا ہے اور زمین میں فساد انگیزی کرتے ہیں انہی لوگوں کے لئے لعنت ہے اور ان کے لئے برا گھر ہے،\qt@no{25}}%
\qt@newcmd\qurantrans@ur@mdccxxxiii{اﷲ جس کے لئے چاہتا ہے رزق کشادہ فرما دیتا ہے اور (جس کے لئے چاہتا ہے) تنگ کر دیتا ہے، اور وہ (کافر) دنیا کی زندگی سے بہت مسرور ہیں، حالانکہ دنیوی زندگی آخرت کے مقابلہ میں ایک حقیر متاع کے سوا کچھ بھی نہیں،\qt@no{26}}%
\qt@newcmd\qurantrans@ur@mdccxxxiv{اور کافر لوگ یہ کہتے ہیں کہ اس (رسول) پر اس کے رب کی جانب سے کوئی نشانی کیوں نہیں اتری، فرما دیجئے: بیشک اﷲ جسے چاہتا ہے (نشانیوں کے باوجود) گمراہ ٹھہرا دیتا ہے اور جو اس کی طرف رجوع کرتا ہے اسے اپنی جانب رہنمائی فرما دیتا ہے،\qt@no{27}}%
\qt@newcmd\qurantrans@ur@mdccxxxv{جو لوگ ایمان لائے اور ان کے دل اﷲ کے ذکر سے مطمئن ہوتے ہیں، جان لو کہ اﷲ ہی کے ذکر سے دلوں کو اطمینان نصیب ہوتا ہے،\qt@no{28}}%
\qt@newcmd\qurantrans@ur@mdccxxxvi{جو لوگ ایمان لائے اور نیک عمل کرتے رہے ان کے لئے (آخرت میں) عیش و مسرت ہے اور عمدہ ٹھکانا ہے،\qt@no{29}}%
\qt@newcmd\qurantrans@ur@mdccxxxvii{اے حبیب!) اسی طرح ہم نے آپ کو ایسی امت میں (رسول بنا کر) بھیجا ہے کہ جس سے پہلے حقیقت میں (ساری) امتیں گزر چکی ہیں (اب یہ سب سے آخری امت ہے) تاکہ آپ ان پر وہ (کتاب) پڑھ کر سنا دیں جو ہم نے آپ کی طرف وحی کی ہے اور وہ رحمان کا انکار کر رہے ہیں، آپ فرما دیجئے: وہ میرا رب ہے اس کے سوا کوئی معبود نہیں، اس پر میں نے بھروسہ کیا ہے اور اسی کی طرف میرا رجوع ہے،\qt@no{30}}%
\qt@newcmd\qurantrans@ur@mdccxxxviii{اور اگر کوئی ایسا قرآن ہوتا جس کے ذریعے پہاڑ چلا دیئے جاتے یا اس سے زمین پھاڑ دی جاتی یا اس کے ذریعے مُردوں سے بات کرا دی جاتی (تب بھی وہ ایمان نہ لاتے)، بلکہ سب کام اﷲ ہی کے اختیار میں ہیں، تو کیا ایمان والوں کو (یہ) معلوم نہیں کہ اگر اﷲ چاہتا تو سب لوگوں کو ہدایت فرما دیتا، اور ہمیشہ کافر لوگوں کو ان کے کرتوتوں کے باعث کوئی (نہ کوئی) مصیبت پہنچتی رہے گی یا ان کے گھروں (یعنی بستیوں) کے آس پاس اترتی رہے گی یہاں تک کہ اﷲ کا وعدۂ (عذاب) آپہنچے، بیشک اﷲ وعدہ خلافی نہیں کرتا،\qt@no{31}}%
\qt@newcmd\qurantrans@ur@mdccxxxix{اور بیشک آپ سے قبل (بھی کفار کی جانب سے) رسولوں کے ساتھ مذاق کیا جاتا رہا سو میں نے کافروں کو مہلت دی پھر میں نے انہیں (عذاب کی) گرفت میں لے لیا۔ پھر (دیکھئے) میرا عذاب کیسا تھا،\qt@no{32}}%
\qt@newcmd\qurantrans@ur@mdccxl{کیا وہ (اﷲ) جو ہر جان پر اس کے اعمال کی نگہبانی فرما رہا ہے اور (وہ بت جو کافر) لوگوں نے اﷲ کے شریک بنا لئے (ایک جیسے ہو سکتے ہیں؟ ہرگز نہیں)۔ آپ فرما دیجئے کہ ان کے نام (تو) بتاؤ۔ (نادانو!) کیا تم اس (اﷲ) کو اس چیز کی خبر دیتے ہو جس (کے وجود) کو وہ ساری زمین میں نہیں جانتا یا (یہ صرف) ظاہری باتیں ہی ہیں (جن کا حقیقت سے کوئی تعلق نہیں) بلکہ (حقیقت یہ ہے کہ) کافروں کے لئے ان کا فریب خوش نما بنا دیا گیا ہے اور وہ (سیدھی) راہ سے روک دیئے گئے ہیں، اور جسے اﷲ گمراہ ٹھہرا دے تو اس کے لئے کوئی ہادی نہیں ہو سکتا،\qt@no{33}}%
\qt@newcmd\qurantrans@ur@mdccxli{ان کے لئے دنیوی زندگی میں (بھی) عذاب ہے اور یقیناً آخرت کا عذاب زیادہ سخت ہے، اور انہیں اﷲ (کے عذاب) سے کوئی بچانے والا نہیں،\qt@no{34}}%
\qt@newcmd\qurantrans@ur@mdccxlii{اس جنت کا حال جس کا پرہیزگاروں سے وعدہ کیا گیا ہے (یہ ہے) کہ اس کے نیچے سے نہریں بہہ رہی ہیں، اس کا پھل بھی ہمیشہ رہنے والا ہے اور اس کا سایہ (بھی)، یہ ان لوگوں کا (حسنِ) انجام ہے جنہوں نے تقوٰی اختیار کیا، اور کافروں کا انجام آتشِ دوزخ ہے،\qt@no{35}}%
\qt@newcmd\qurantrans@ur@mdccxliii{اور جن لوگوں کو ہم کتاب (تورات) دے چکے ہیں (اگر وہ صحیح مومن ہیں تو) وہ اس (قرآن) سے خوش ہوتے ہیں جو آپ کی طرف نازل کیا گیا ہے اور ان (ہی کے) فرقوں میں سے بعض ایسے بھی ہیں جو اس کے کچھ حصہ کا انکار کرتے ہیں، فرما دیجئے کہ بس مجھے تو یہی حکم دیا گیا ہے کہ میں اﷲ کی عبادت کروں اور اس کے ساتھ (کسی کو) شریک نہ ٹھہراؤں، اسی کی طرف میں بلاتا ہوں اور اسی کی طرف مجھے لوٹ کر جانا ہے،\qt@no{36}}%
\qt@newcmd\qurantrans@ur@mdccxliv{اور اسی طرح ہم نے اس (قرآن) کو حکم بنا کر عربی زبان میں اتارا ہے، اور (اے سننے والے!) اگر تو نے ان (کافروں) کی خواہشات کی پیروی کی اس کے بعد کہ تیرے پاس (قطعی) علم آچکا ہے تو تیرے لئے اﷲ کے مقابلہ میں نہ کوئی مددگار ہوگا اور نہ کوئی محافظ،\qt@no{37}}%
\qt@newcmd\qurantrans@ur@mdccxlv{اور (اے رسول!) بیشک ہم نے آپ سے پہلے (بہت سے) پیغمبروں کو بھیجا اور ہم نے ان کے لئے بیویاں (بھی) بنائیں اور اولاد (بھی)، اور کسی رسول کا یہ کام نہیں کہ وہ نشانی لے آئے مگر اﷲ کے حکم سے، ہر ایک میعاد کے لئے ایک نوشتہ ہے،\qt@no{38}}%
\qt@newcmd\qurantrans@ur@mdccxlvi{اﷲ جس (لکھے ہوئے) کو چاہتا ہے مٹا دیتا ہے اور (جسے چاہتا ہے) ثبت فرما دیتا ہے، اور اسی کے پاس اصل کتاب (لوحِ محفوظ) ہے،\qt@no{39}}%
\qt@newcmd\qurantrans@ur@mdccxlvii{اور اگر ہم (اس عذاب کا) کچھ حصہ جس کا ہم نے ان (کافروں) سے وعدہ کیا ہے آپ کو (حیاتِ ظاہری میں ہی) دکھا دیں یا ہم آپ کو (اس سے قبل) اٹھا لیں (یہ دونوں چیزیں ہماری مرضی پر منحصر ہیں) آپ پر تو صرف (احکام کے) پہنچا دینے کی ذمہ داری ہے اور حساب لینا ہمارا کام ہے،\qt@no{40}}%
\qt@newcmd\qurantrans@ur@mdccxlviii{کیا وہ نہیں دیکھ رہے کہ ہم (ان کے زیرِ تسلّط) زمین کو ہر طرف سے گھٹاتے چلے جا رہے ہیں (اور ان کے بیشتر علاقے رفتہ رفتہ اسلام کے تابع ہوتے جا رہے ہیں)، اور اﷲ ہی حکم فرماتا ہے کوئی بھی اس کے حکم کو ردّ کرنے والا نہیں، اور وہ حساب جلد لینے والا ہے،\qt@no{41}}%
\qt@newcmd\qurantrans@ur@mdccxlix{اور بیشک ان لوگوں نے بھی مکر و فریب کیا تھا جو ان سے پہلے ہو گزرے ہیں سو ان سب تدبیروں کو توڑنا (بھی) اﷲ کے اختیار میں ہے۔ وہ خوب جانتا ہے جو کچھ ہر شخص کما رہا ہے، اور کفّار جلد ہی جان لیں گے کہ آخرت کا گھر کس کے لئے ہے،\qt@no{42}}%
\qt@newcmd\qurantrans@ur@mdccl{اور کافر لوگ کہتے ہیں کہ آپ پیغمبر نہیں ہیں، فرما دیجئے: (میری رسالت پر) میرے اور تمہارے درمیان اﷲ بطورِ گواہ کافی ہے اور وہ شخص بھی جس کے پاس (صحیح طور پر آسمانی) کتاب کا علم ہے،\qt@no{43}}%
\qt@newcmd\qurantrans@ur@mdccli{\basmalahur الف، لام، را (حقیقی معنی اﷲ اور رسول صلی اللہ علیہ وآلہ وسلم ہی بہتر جانتے ہیں)، یہ (عظیم) کتاب ہے جسے ہم نے آپ کی طرف اتارا ہے تاکہ آپ لوگوں کو (کفر کی) تاریکیوں سے نکال کر (ایمان کے) نور کی جانب لے آئیں (مزید یہ کہ) ان کے رب کے حکم سے اس کی راہ کی طرف (لائیں) جو غلبہ والا سب خوبیوں والا ہے،\qt@no{1}}%
\qt@newcmd\qurantrans@ur@mdcclii{وہ اﷲ کہ جو کچھ آسمانوں میں اور جو کچھ زمین میں ہے (سب) اسی کا ہے، اور کفّار کے لئے سخت عذاب کے باعث بربادی ہے،\qt@no{2}}%
\qt@newcmd\qurantrans@ur@mdccliii{یہ) وہ لوگ ہیں جو دنیوی زندگی کو آخرت کے مقابلہ میں زیادہ پسند کرتے ہیں اور (لوگوں کو) اﷲ کی راہ سے روکتے ہیں اور اس (دینِ حق) میں کجی تلاش کرتے ہیں۔ یہ لوگ دور کی گمراہی میں (پڑ چکے) ہیں،\qt@no{3}}%
\qt@newcmd\qurantrans@ur@mdccliv{اور ہم نے کسی رسول کو نہیں بھیجا مگر اپنی قوم کی زبان کے ساتھ تاکہ وہ ان کے لئے (پیغامِ حق) خوب واضح کر سکے، پھر اﷲ جسے چاہتا ہے گمراہ ٹھہرا دیتا ہے اور جسے چاہتا ہے ہدایت بخشتا ہے، اور وہ غالب حکمت والا ہے،\qt@no{4}}%
\qt@newcmd\qurantrans@ur@mdcclv{اور بیشک ہم نے موسٰی (علیہ السلام) کو اپنی نشانیوں کے ساتھ بھیجا کہ (اے موسٰی!) تم اپنی قوم کو اندھیروں سے نکال کر نور کی طرف لے جاؤ اور انہیں اﷲ کے دنوں کی یاد دلاؤ (جو ان پر اور پہلی امتوں پر آچکے تھے)۔ بیشک اس میں ہر زیادہ صبر کرنے والے (اور) خوب شکر بجا لانے والے کے لئے نشانیاں ہیں،\qt@no{5}}%
\qt@newcmd\qurantrans@ur@mdcclvi{اور (وہ وقت یاد کیجئے) جب موسٰی (علیہ السلام) نے اپنی قوم سے کہا: تم اپنے اوپر اللہ کے (اس) انعام کو یاد کرو جب اس نے تمہیں آلِ فرعون سے نجات دی جو تمہیں سخت عذاب پہنچاتے تھے اور تمہارے لڑکوں کو ذبح کر ڈالتے تھے اور تمہاری عورتوں کو زندہ چھوڑ دیتے تھے، اور اس میں تمہارے رب کی جانب سے بڑی بھاری آزمائش تھی،\qt@no{6}}%
\qt@newcmd\qurantrans@ur@mdcclvii{اور (یاد کرو) جب تمہارے رب نے آگاہ فرمایا کہ اگر تم شکر ادا کرو گے تو میں تم پر (نعمتوں میں) ضرور اضافہ کروں گا اور اگر تم ناشکری کرو گے تو میرا عذاب یقیناً سخت ہے،\qt@no{7}}%
\qt@newcmd\qurantrans@ur@mdcclviii{اور موسٰی (علیہ السلام) نے کہا: اگر تم اور وہ سب کے سب لوگ جو زمین میں ہیں کفر کرنے لگیں تو بیشک اللہ (ان سب سے) یقیناً بے نیاز لائقِ حمد و ثنا ہے،\qt@no{8}}%
\qt@newcmd\qurantrans@ur@mdcclix{کیا تمہیں ان لوگوں کی خبر نہیں پہنچی جو تم سے پہلے ہو گزرے ہیں، (وہ) قومِ نوح اور عاد اور ثمود (کی قوموں کے لوگ) تھے اور (کچھ) لوگ جو ان کے بعد ہوئے، انہیں اللہ کے سوا کوئی نہیں جانتا (کیونکہ وہ صفحۂ ہستی سے بالکل نیست و نابود ہو چکے ہیں)، ان کے پاس ان کے رسول واضح نشانیوں کے ساتھ آئے تھے پس انہوں نے (اَز راہِ تمسخر و عناد) اپنے ہاتھ اپنے مونہوں میں ڈال لئے اور (بڑی جسارت کے ساتھ) کہنے لگے: ہم نے اس (دین) کا انکار کر دیا جس کے ساتھ تم بھیجے گئے ہو اور یقیناً ہم اس چیز کی نسبت اضطراب انگیز شک میں مبتلا ہیں جس کی طرف تم ہمیں دعوت دیتے ہو،\qt@no{9}}%
\qt@newcmd\qurantrans@ur@mdcclx{ان کے پیغمبروں نے کہا: کیا اللہ کے بارے میں شک ہے جو آسمانوں اور زمین کا پیدا فرمانے والا ہے، (جو) تمہیں بلاتا ہے کہ تمہارے گناہوں کو تمہاری خاطر بخش دے اور (تمہاری نافرمانیوں کے باوجود) تمہیں ایک مقرر میعاد تک مہلت دیئے رکھتا ہے۔ وہ (کافر) بو لے: تم تو صرف ہمارے جیسے بشر ہی ہو، تم یہ چاہتے ہو کہ ہمیں ان (بتوں) سے روک دو جن کی پرستش ہمارے باپ دادا کیا کرتے تھے، سو تم ہمارے پاس کوئی روشن دلیل لاؤ،\qt@no{10}}%
\qt@newcmd\qurantrans@ur@mdcclxi{ان کے رسولوں نے ان سے کہا: اگرچہ ہم (نفسِ بشریت میں) تمہاری طرح انسان ہی ہیں لیکن (اس فرق پر بھی غور کرو کہ) اللہ اپنے بندوں میں سے جس پر چاہتا ہے احسان فرماتا ہے (پھر برابری کیسی؟)، اور (رہ گئی روشن دلیل کی بات) یہ ہمارا کام نہیں کہ ہم اللہ کے حکم کے بغیر تمہارے پاس کوئی دلیل لے آئیں، اور اللہ ہی پر مومنوں کو بھروسہ کرنا چاہئے،\qt@no{11}}%
\qt@newcmd\qurantrans@ur@mdcclxii{اور ہمیں کیا ہے کہ ہم اللہ پر بھروسہ نہ کریں درآنحالیکہ اسی نے ہمیں (ہدایت و کامیابی کی) راہیں دکھائی ہیں، اور ہم ضرور تمہاری اذیت رسانیوں پر صبر کریں گے اور اہلِ توکل کو اللہ ہی پر توکل کرنا چاہیے،\qt@no{12}}%
\qt@newcmd\qurantrans@ur@mdcclxiii{اور کافر لوگ اپنے پیغمبروں سے کہنے لگے: ہم بہرصورت تمہیں اپنے ملک سے نکال دیں گے یا تمہیں ضرور ہمارے مذہب میں لوٹ آنا ہوگا، تو ان کے رب نے ان کی طرف وحی بھیجی کہ ہم ظالموں کو ضرور ہلاک کر دیں گے،\qt@no{13}}%
\qt@newcmd\qurantrans@ur@mdcclxiv{اور ان کے بعد ہم تمہیں ضرور (اسی) ملک میں آباد فرمائیں گے۔ یہ (وعدہ) ہر اس شخص کے لئے ہے جو میرے حضور کھڑا ہونے سے ڈرا اور میرے وعدۂ (عذاب) سے خائف ہوا،\qt@no{14}}%
\qt@newcmd\qurantrans@ur@mdcclxv{اور (بالآخر) رسولوں نے (اللہ سے) فتح مانگی اور ہر سرکش ضدی نامراد ہوگیا،\qt@no{15}}%
\qt@newcmd\qurantrans@ur@mdcclxvi{اس (بربادی) کے پیچھے (پھر) جہنم ہے اور اسے پیپ کا پانی پلایا جائے گا،\qt@no{16}}%
\qt@newcmd\qurantrans@ur@mdcclxvii{جسے وہ بمشکل ایک ایک گھونٹ پیئے گا اور اسے حلق سے نیچے اتار نہ سکے گا، اور اسے ہر طرف سے موت آگھیرے گی اور وہ مر (بھی) نہ سے گا، اور (پھر) اس کے پیچھے (ایک اور) بڑا ہی سخت عذاب ہوگا،\qt@no{17}}%
\qt@newcmd\qurantrans@ur@mdcclxviii{جن لوگوں نے اپنے رب سے کفر کیا ہے، ان کی مثال یہ ہے کہ ان کے اعمال (اس) راکھ کی مانند ہیں جس پر تیز آندھی کے دن سخت ہوا کا جھونکا آگیا، وہ ان (اَعمال) میں سے جو انہوں نے کمائے تھے کسی چیز پر قابو نہیں پاسکیں گے۔ یہی بہت دور کی گمراہی ہے،\qt@no{18}}%
\qt@newcmd\qurantrans@ur@mdcclxix{اے سننے والے!) کیا تو نے نہیں دیکھا کہ بیشک اللہ نے آسمانوں اور زمین کو حق (پر مبنی حکمت) کے ساتھ پیدا فرمایا۔ اگر وہ چاہے (تو) تمہیں نیست و نابود فرما دے اور (تمہاری جگہ) نئی مخلوق لے آئے،\qt@no{19}}%
\qt@newcmd\qurantrans@ur@mdcclxx{اور یہ (کام) اللہ پر (کچھ بھی) دشوار نہیں ہے،\qt@no{20}}%
\qt@newcmd\qurantrans@ur@mdcclxxi{اور (روزِ محشر) اللہ کے سامنے سب (چھوٹے بڑے) حاضر ہوں گے تو (پیروی کرنے والے) کمزور لوگ (طاقتور) متکبروں سے کہیں گے: ہم تو (عمر بھر) تمہارے تابع رہے تو کیا تم اللہ کے عذاب سے بھی ہمیں کسی قدر بچا سکتے ہو؟ وہ (اُمراء اپنے پیچھے لگنے والے غریبوں سے) کہیں گے: اگر اللہ ہمیں ہدایت کرتا تو ہم تمہیں بھی ضرور ہدایت کی راہ دکھاتے (ہم خود بھی گمراہ تھے سو تمہیں بھی گمراہ کرتے رہے)۔ ہم پر برابر ہے خواہ (آج) ہم آہ و زاری کریں یا صبر کریں ہمارے لئے کوئی راہِ فرار نہیں ہے،\qt@no{21}}%
\qt@newcmd\qurantrans@ur@mdcclxxii{اور شیطان کہے گا جبکہ فیصلہ ہو چکے گا کہ بیشک اللہ نے تم سے سچا وعدہ کیا تھا اور میں نے (بھی) تم سے وعدہ کیا تھا، سو میں نے تم سے وعدہ خلافی کی ہے، اور مجھے (دنیا میں) تم پر کسی قسم کا زور نہیں تھا سوائے اس کے کہ میں نے تمہیں (باطل کی طرف) بلایا سو تم نے (اپنے مفاد کی خاطر) میری دعوت قبول کی، اب تم مجھے ملامت نہ کرو بلکہ (خود) اپنے آپ کو ملامت کرو۔ نہ میں (آج) تمہاری فریاد رسی کرسکتا ہوں اور نہ تم میری فریاد رسی کر سکتے ہو۔ اس سے پہلے جو تم مجھے (اللہ کا) شریک ٹھہراتے رہے ہو بیشک میں (آج) اس سے انکار کرتا ہوں۔ یقیناً ظالموں کے لئے دردناک عذاب ہے،\qt@no{22}}%
\qt@newcmd\qurantrans@ur@mdcclxxiii{اور جو لوگ ایمان لائے اور نیک عمل کرتے رہے وہ جنتوں میں داخل کئے جائیں گے جن کے نیچے سے نہریں بہہ رہی ہیں (وہ) ان میں اپنے رب کے حکم سے ہمیشہ رہیں گے، (ملاقات کے وقت) اس میں ان کا دعائیہ کلمہ ”سلام“ ہوگا،\qt@no{23}}%
\qt@newcmd\qurantrans@ur@mdcclxxiv{کیا آپ نے نہیں دیکھا، اللہ نے کیسی مثال بیان فرمائی ہے کہ پاکیزہ بات اس پاکیزہ درخت کی مانند ہے جس کی جڑ (زمین میں) مضبوط ہے اور اس کی شاخیں آسمان میں ہیں،\qt@no{24}}%
\qt@newcmd\qurantrans@ur@mdcclxxv{وہ (درخت) اپنے رب کے حکم سے ہر وقت پھل دے رہا ہے، اور اللہ لوگوں کے لئے مثالیں بیان فرماتا ہے تاکہ وہ نصیحت حاصل کریں،\qt@no{25}}%
\qt@newcmd\qurantrans@ur@mdcclxxvi{اور ناپاک بات کی مثال اس ناپاک درخت کی سی ہے جسے زمین کے اوپر ہی سے اکھاڑ لیا جائے، اسے ذرا بھی قرار (و بقا) نہ ہو،\qt@no{26}}%
\qt@newcmd\qurantrans@ur@mdcclxxvii{اللہ ایمان والوں کو (اس) مضبوط بات (کی برکت) سے دنیوی زندگی میں بھی ثابت قدم رکھتا ہے اور آخرت میں (بھی)۔ اور اللہ ظالموں کو گمراہ ٹھہرا دیتا ہے۔ اور اللہ جو چاہتا ہے کر ڈالتا ہے،\qt@no{27}}%
\qt@newcmd\qurantrans@ur@mdcclxxviii{کیا آپ نے ان لوگوں کو نہیں دیکھا جنہوں نے اللہ کی نعمتِ (ایمان) کو کفر سے بدل ڈالا اور انہوں نے اپنی قوم کو تباہی کے گھر میں اتار دیا،\qt@no{28}}%
\qt@newcmd\qurantrans@ur@mdcclxxix{وہ) دوزخ ہے جس میں جھونکے جائیں گے، اور وہ برا ٹھکانا ہے،\qt@no{29}}%
\qt@newcmd\qurantrans@ur@mdcclxxx{اور انہوں نے اللہ کے لئے شریک بنا ڈالے تاکہ وہ (لوگوں کو) اس کی راہ سے بہکائیں۔ فرما دیجئے: تم (چند روزہ) فائدہ اٹھا لو بیشک تمہارا انجام آگ ہی کی طرف (جانا) ہے،\qt@no{30}}%
\qt@newcmd\qurantrans@ur@mdcclxxxi{آپ میرے مومن بندوں سے فرما دیں کہ وہ نماز قائم رکھیں اور جو رزق ہم نے انہیں دیا ہے اس میں سے پوشیدہ اور اعلانیہ (ہماری راہ میں) خرچ کرتے رہیں اس دن کے آنے سے پہلے جس دن میں نہ کوئی خرید و فروخت ہوگی اور نہ ہی کوئی (دنیاوی) دوستی (کام آئے گی)،\qt@no{31}}%
\qt@newcmd\qurantrans@ur@mdcclxxxii{اللہ وہ ہے جس نے آسمانوں اور زمین کو پیدا فرمایا اور آسمان کی جانب سے پانی اتارا پھر اس پانی کے ذریعہ سے تمہارے رزق کے طور پر پھل پیدا کئے، اور اس نے تمہارے لئے کشتیوں کو مسخر کر دیا تاکہ اس کے حکم سے سمندر میں چلتی رہیں اور اس نے تمہارے لئے دریاؤں کو (بھی) مسخر کر دیا،\qt@no{32}}%
\qt@newcmd\qurantrans@ur@mdcclxxxiii{اور اس نے تمہارے فائدہ کے لئے سورج اور چاند کو (باقاعدہ ایک نظام کا) مطیع بنا دیا جو ہمیشہ (اپنے اپنے مدار میں) گردش کرتے رہتے ہیں، اور تمہارے (نظامِ حیات کے) لئے رات اور دن کو بھی (ایک نظام کے) تابع کر دیا،\qt@no{33}}%
\qt@newcmd\qurantrans@ur@mdcclxxxiv{اور اس نے تمہیں ہر وہ چیز عطا فرما دی جو تم نے اس سے مانگی، اور اگر تم اللہ کی نعمتوں کو شمار کرنا چاہو (تو) پورا شمار نہ کر سکو گے، بیشک انسان بڑا ہی ظالم بڑا ہی ناشکرگزار ہے،\qt@no{34}}%
\qt@newcmd\qurantrans@ur@mdcclxxxv{اور (یاد کیجئے) جب ابراہیم (علیہ السلام) نے عرض کیا: اے میرے رب! اس شہر (مکہ) کو جائے امن بنا دے اور مجھے اور میرے بچوں کو اس (بات) سے بچا لے کہ ہم بتوں کی پرستش کریں،\qt@no{35}}%
\qt@newcmd\qurantrans@ur@mdcclxxxvi{اے میرے رب! ان (بتوں) نے بہت سے لوگوں کو گمراہ کر ڈالا ہے۔ پس جس نے میری پیروی کی وہ تو میرا ہوگا اور جس نے میری نافرمانی کی تو بیشک تُو بڑا بخشنے والا نہایت مہربان ہے،\qt@no{36}}%
\qt@newcmd\qurantrans@ur@mdcclxxxvii{اے ہمارے رب! بیشک میں نے اپنی اولاد (اسماعیل علیہ السلام) کو (مکہ کی) بے آب و گیاہ وادی میں تیرے حرمت والے گھر کے پاس بسا دیا ہے، اے ہمارے رب! تاکہ وہ نماز قائم رکھیں پس تو لوگوں کے دلوں کو ایسا کر دے کہ وہ شوق و محبت کے ساتھ ان کی طرف مائل رہیں اور انہیں (ہر طرح کے) پھلوں کا رزق عطا فرما، تاکہ وہ شکر بجا لاتے رہیں،\qt@no{37}}%
\qt@newcmd\qurantrans@ur@mdcclxxxviii{اے ہمارے رب! بیشک تو وہ (سب کچھ) جانتا ہے جو ہم چھپاتے ہیں اور جو ہم ظاہر کرتے ہیں، اور اللہ پر کوئی بھی چیز نہ زمین میں پوشیدہ ہے اور نہ ہی آسمان میں (مخفی ہے)،\qt@no{38}}%
\qt@newcmd\qurantrans@ur@mdcclxxxix{سب تعریفیں اللہ کے لئے ہیں جس نے مجھے بڑھاپے میں اسماعیل اور اسحاق (علیھما السلام دو فرزند) عطا فرمائے، بیشک میرا رب دعا خوب سننے والا ہے،\qt@no{39}}%
\qt@newcmd\qurantrans@ur@mdccxc{اے میرے رب! مجھے اور میری اولاد کو نماز قائم رکھنے والا بنا دے، اے ہمارے رب! اور تو میری دعا قبول فرما لے،\qt@no{40}}%
\qt@newcmd\qurantrans@ur@mdccxci{اے ہمارے رب! مجھے بخش دے اور میرے والدین کو (بخش دے)٭اور دیگر سب مومنوں کو بھی، جس دن حساب قائم ہوگا، ٭ (یہاں حضرت ابراہیم علیہ السلام کے حقیقی والد تارخ کی طرف اشارہ ہے، یہ کافر و مشرک نہ تھے بلکہ دینِ حق پر تھے۔ آزر دراصل آپ کا چچا تھا، اس نے آپ علیہ السلام کو آپ علیہ السلام کے والد کی وفات کے بعد پالا تھا، اس لئے اسے عرفاً باپ کہا گیا ہے، وہ مشرک تھا اور آپ کو اس کے لئے دعائے مغفرت سے روک دیا گیا تھا جبکہ یہاں حقیقی والدین کے لئے دعائے مغفرت کی جا رہی ہے۔ یہ دعا اللہ تعالیٰ کو اس قدر پسند آئی کہ اسے امتِ محمدی (صلی اللہ علیہ وآلہ وسلم) کی نمازوں میں بھی برقرار رکھ دیا گیا۔)\qt@no{41}}%
\qt@newcmd\qurantrans@ur@mdccxcii{اور اللہ کو ان کاموں سے ہرگز بے خبر نہ سمجھنا جو ظالم انجام دے رہے ہیں، بس وہ تو ان (ظالموں) کو فقط اس دن کے لئے مہلت دے رہا ہے جس میں (خوف کے مارے) آنکھیں پھٹی رہ جائیں گی،\qt@no{42}}%
\qt@newcmd\qurantrans@ur@mdccxciii{وہ لوگ (میدانِ حشر کی طرف) اپنے سر اوپر اٹھائے دوڑتے جا رہے ہوں گے اس حال میں کہ ان کی پلکیں بھی نہ جھپکتی ہوں گی اور ان کے دل سکت سے خالی ہو رہے ہوں گے،\qt@no{43}}%
\qt@newcmd\qurantrans@ur@mdccxciv{اور آپ لوگوں کو اس دن سے ڈرائیں جب ان پر عذاب آپہنچے گا تو وہ لوگ جو ظلم کرتے رہے ہوں گے کہیں گے: اے ہمارے رب! ہمیں تھوڑی دیر کے لئے مہلت دے دے کہ ہم تیری دعوت کو قبول کر لیں اور رسولوں کی پیروی کر لیں۔ (ان سے کہا جائے گا) کہ کیا تم ہی لوگ پہلے قسمیں نہیں کھاتے رہے کہ تمہیں کبھی زوال نہیں آئے گا،\qt@no{44}}%
\qt@newcmd\qurantrans@ur@mdccxcv{اور تم (اپنی باری پر) انہی لوگوں کے (چھوڑے ہوئے) محلات میں رہتے تھے (جنہوں نے اپنے اپنے دور میں) اپنی جانوں پر ظلم کیا تھا حالانکہ تم پر عیاں ہو چکا تھا کہ ہم نے ان کے ساتھ کیا معاملہ کیا تھا اور ہم نے تمہارے (فہم کے) لئے مثالیں بھی بیان کی تھیں،\qt@no{45}}%
\qt@newcmd\qurantrans@ur@mdccxcvi{اور انہوں نے (دولت و اقتدار کے نشہ میں بدمست ہو کر) اپنی طرف سے بڑی فریب کاریاں کیں جبکہ اللہ کے پاس ان کے ہر فریب کا توڑ تھا، اگرچہ ان کی مکّارانہ تدبیریں ایسی تھیں کہ ان سے پہاڑ بھی اکھڑ جائیں،\qt@no{46}}%
\qt@newcmd\qurantrans@ur@mdccxcvii{سو اللہ کو ہرگز اپنے رسولوں سے وعدہ خلافی کرنے والا نہ سمجھنا! بیشک اللہ غالب، بدلہ لینے والا ہے،\qt@no{47}}%
\qt@newcmd\qurantrans@ur@mdccxcviii{جس دن (یہ) زمین دوسری زمین سے بدل دی جائے گی اور جملہ آسمان بھی بدل دیئے جائیں گے اور سب لوگ اللہ کے رُوبرو حاضر ہوں گے جو ایک ہے سب پر غالب ہے،\qt@no{48}}%
\qt@newcmd\qurantrans@ur@mdccxcix{اور اس دن آپ مجرموں کو زنجیروں میں جکڑے ہوئے دیکھیں گے،\qt@no{49}}%
\qt@newcmd\qurantrans@ur@mdccc{ان کے لباس گندھک (یا ایسے روغن) کے ہوں گے (جو آگ کو خوب بھڑکاتا ہے) اور ان کے چہروں کو آگ ڈھانپ رہی ہوگی،\qt@no{50}}%
\qt@newcmd\qurantrans@ur@mdccci{تاکہ اللہ ہر شخص کو ان (اَعمال) کابدلہ دے دے جو اس نے کما رکھے ہیں۔ بیشک اللہ حساب میں جلدی فرمانے والا ہے،\qt@no{51}}%
\qt@newcmd\qurantrans@ur@mdcccii{یہ (قرآن) لوگوں کے لئے کاملاً پیغام کا پہنچا دینا ہے، تاکہ انہیں اس کے ذریعہ ڈرایا جائے اور یہ کہ وہ خوب جان لیں کہ بس وہی (اللہ) معبودِ یکتا ہے اور یہ کہ دانش مند لوگ نصیحت حاصل کریں،\qt@no{52}}%
\qt@newcmd\qurantrans@ur@mdccciii{\basmalahur الف، لام، را (حقیقی معنی اﷲ اور رسول صلی اللہ علیہ وآلہ وسلم ہی بہتر جانتے ہیں)، یہ (برگزیدہ) کتاب اور روشن قرآن کی آیتیں ہیں،\qt@no{1}}%
\qt@newcmd\qurantrans@ur@mdccciv{کفار (آخرت میں مومنوں پر اللہ کی رحمت کے مناظر دیکھ کر) بار بار آرزو کریں گے کہ کاش! وہ مسلمان ہوتے،\qt@no{2}}%
\qt@newcmd\qurantrans@ur@mdcccv{آپ (غمگین نہ ہوں) انہیں چھوڑ دیجئے وہ کھاتے (پیتے) رہیں اور عیش کرتے رہیں اور (ان کی) جھوٹی امیدیں انہیں (آخرت سے) غافل رکھیں پھر وہ عنقریب (اپنا انجام) جان لیں گے،\qt@no{3}}%
\qt@newcmd\qurantrans@ur@mdcccvi{اور ہم نے کوئی بھی بستی ہلاک نہیں کی مگر یہ کہ اُس کے لئے ایک معلوم نوشتۂ (قانون) تھا (جس کی انہوں نے خلاف ورزی کی اور اپنے انجام کو جا پہنچے)،\qt@no{4}}%
\qt@newcmd\qurantrans@ur@mdcccvii{کوئی بھی قوم (قانونِ عروج و زوال کی) اپنی مقررہ مدت سے نہ آگے بڑھ سکتی ہے اور نہ پیچھے ہٹ سکتی ہے،\qt@no{5}}%
\qt@newcmd\qurantrans@ur@mdcccviii{اور (کفار گستاخی کرتے ہوئے) کہتے ہیں: اے وہ شخص جس پر قرآن اتارا گیا ہے! بیشک تم دیوانے ہو،\qt@no{6}}%
\qt@newcmd\qurantrans@ur@mdcccix{تم ہمارے پاس فرشتوں کو کیوں نہیں لے آتے اگر تم سچے ہو،\qt@no{7}}%
\qt@newcmd\qurantrans@ur@mdcccx{ہم فرشتوں کو نہیں اتارا کرتے مگر (فیصلۂ) حق کے ساتھ (یعنی جب عذاب کی گھڑی آپہنچے تو اس کے نفاذ کے لئے اتارتے ہیں) اور اس وقت انہیں مہلت نہیں دی جاتی،\qt@no{8}}%
\qt@newcmd\qurantrans@ur@mdcccxi{بیشک یہ ذکرِ عظیم (قرآن) ہم نے ہی اتارا ہے اور یقیناً ہم ہی اس کی حفاظت کریں گے،\qt@no{9}}%
\qt@newcmd\qurantrans@ur@mdcccxii{اور بیشک ہم نے آپ سے قبل پہلی امتوں میں بھی رسول بھیجے تھے،\qt@no{10}}%
\qt@newcmd\qurantrans@ur@mdcccxiii{اور ان کے پاس کوئی رسول نہیں آتا تھا مگر یہ کہ وہ اس کے ساتھ مذاق کیا کرتے تھے،\qt@no{11}}%
\qt@newcmd\qurantrans@ur@mdcccxiv{اسی طرح ہم اس (تمسخر اور استہزاء) کو مجرموں کے دلوں میں داخل کر دیتے ہیں،\qt@no{12}}%
\qt@newcmd\qurantrans@ur@mdcccxv{یہ لوگ اِس (قرآن) پر ایمان نہیں لائیں گے اور بیشک پہلوں کی (یہی) روش گزر چکی ہے،\qt@no{13}}%
\qt@newcmd\qurantrans@ur@mdcccxvi{اور اگر ہم ان پر آسمان کا کوئی دروازہ (بھی) کھول دیں (اور ان کے لئے یہ بھی ممکن بنا دیں کہ) وہ سارا دن اس میں (سے) اوپر چڑھتے رہیں،\qt@no{14}}%
\qt@newcmd\qurantrans@ur@mdcccxvii{تب بھی) یہ لوگ یقیناً (یہ) کہیں گے کہ ہماری آنکھیں (کسی حیلہ و فریب کے ذریعے) باندھ دی گئی ہیں بلکہ ہم لوگوں پر جادو کر دیا گیا ہے،\qt@no{15}}%
\qt@newcmd\qurantrans@ur@mdcccxviii{اور بیشک ہم نے آسمان میں (کہکشاؤں کی صورت میں ستاروں کی حفاطت کے لئے) قلعے بنائے اور ہم نے اس (خلائی کائنات) کو دیکھنے والوں کے لئے آراستہ کر دیا،\qt@no{16}}%
\qt@newcmd\qurantrans@ur@mdcccxix{اور ہم نے اس (آسمانی کائنات کے نظام) کو ہر مردود شیطان (یعنی ہر سرکش قوت کے شرانگیز عمل) سے محفوظ کر دیا،\qt@no{17}}%
\qt@newcmd\qurantrans@ur@mdcccxx{مگر جو کوئی بھی چوری چھپے سننے کے لئے آگھسا تو اس کے پیچھے ایک (جلتا) چمکتا شہاب ہو جاتا ہے،\qt@no{18}}%
\qt@newcmd\qurantrans@ur@mdcccxxi{اور زمین کو ہم نے (گولائی کے باوجود) پھیلا دیا اور ہم نے اس میں (مختلف مادوں کو باہم ملا کر) مضبوط پہاڑ بنا دیئے اور ہم نے اس میں ہر جنس کو (مطلوبہ) توازن کے مطابق نشو و نما دی،\qt@no{19}}%
\qt@newcmd\qurantrans@ur@mdcccxxii{اور ہم نے اس میں تمہارے لئے اسبابِ معیشت پیدا کئے اور ان (انسانوں، جانوروں اور پرندوں) کے لئے بھی جنہیں تم رزق مہیا نہیں کرتے،\qt@no{20}}%
\qt@newcmd\qurantrans@ur@mdcccxxiii{اور (کائنات) کی کوئی بھی چیز ایسی نہیں ہے مگر یہ کہ ہمارے پاس اس کے خزانے ہیں اور ہم اسے صرف معیّن مقدار کے مطابق ہی اتارتے رہتے ہیں،\qt@no{21}}%
\qt@newcmd\qurantrans@ur@mdcccxxiv{اور ہم ہواؤں کو بادلوں کا بوجھ اٹھائے ہوئے بھیجتے ہیں پھر ہم آسمان کی جانب سے پانی اتارتے ہیں پھر ہم اسے تم ہی کو پلاتے ہیں اور تم اس کے خزانے رکھنے والے نہیں ہو،\qt@no{22}}%
\qt@newcmd\qurantrans@ur@mdcccxxv{اور بیشک ہم ہی جلاتے ہیں اور مارتے ہیں اور ہم ہی (سب کے) وارث (و مالک) ہیں،\qt@no{23}}%
\qt@newcmd\qurantrans@ur@mdcccxxvi{اور بیشک ہم اُن کو بھی جانتے ہیں جو تم سے پہلے گزر چکے اور بیشک ہم بعد میں آنے والوں کو بھی جانتے ہیں،\qt@no{24}}%
\qt@newcmd\qurantrans@ur@mdcccxxvii{اور بیشک آپ کا رب ہی تو انہیں (روزِ قیامت) جمع فرمائے گا۔ بیشک وہ بڑی حکمت والا خوب جاننے والا ہے،\qt@no{25}}%
\qt@newcmd\qurantrans@ur@mdcccxxviii{اور بیشک ہم نے انسان کی (کیمیائی) تخلیق ایسے خشک بجنے والے گارے سے کی جو (پہلے) سِن رسیدہ (اور دھوپ اور دیگر طبیعیاتی اور کیمیائی اثرات کے باعث تغیر پذیر ہو کر) سیاہ بو دار ہو چکا تھا،\qt@no{26}}%
\qt@newcmd\qurantrans@ur@mdcccxxix{اور اِس سے پہلے ہم نے جنّوں کو شدید جلا دینے والی آگ سے پیدا کیا جس میں دھواں نہیں تھا،\qt@no{27}}%
\qt@newcmd\qurantrans@ur@mdcccxxx{اور (وہ واقعہ یاد کیجئے) جب آپ کے رب نے فرشتوں سے فرمایا کہ میں سِن رسیدہ (اور) سیاہ بودار، بجنے والے گارے سے ایک بشری پیکر پیدا کرنے والا ہوں،\qt@no{28}}%
\qt@newcmd\qurantrans@ur@mdcccxxxi{پھر جب میں اس کی (ظاہری) تشکیل کو کامل طور پر درست حالت میں لا چکوں اور اس پیکرِ (بشری کے باطن) میں اپنی (نورانی) روح پھونک دوں تو تم اس کے لئے سجدہ میں گر پڑنا،\qt@no{29}}%
\qt@newcmd\qurantrans@ur@mdcccxxxii{پس (اس پیکرِ بشری کے اندر نورِ ربانی کا چراغ جلتے ہی) سارے کے سارے فرشتوں نے سجدہ کیا،\qt@no{30}}%
\qt@newcmd\qurantrans@ur@mdcccxxxiii{سوائے ابلیس کے، اس نے سجدہ کرنے والوں کے ساتھ ہونے سے انکار کر دیا،\qt@no{31}}%
\qt@newcmd\qurantrans@ur@mdcccxxxiv{اللہ نے) ارشاد فرمایا: اے ابلیس! تجھے کیا ہو گیا ہے کہ تو سجدہ کرنے والوں کے ساتھ نہ ہوا،\qt@no{32}}%
\qt@newcmd\qurantrans@ur@mdcccxxxv{ابلیس نے) کہا: میں ہر گز ایسا نہیں (ہو سکتا) کہ بشر کو سجدہ کروں جسے تو نے سِن رسیدہ (اور) سیاہ بودار، بجنے والے گارے سے تخلیق کیا ہے،\qt@no{33}}%
\qt@newcmd\qurantrans@ur@mdcccxxxvi{اللہ نے) فرمایا: تو یہاں سے نکل جا پس بیشک تو مردود (راندۂ درگاہ) ہے،\qt@no{34}}%
\qt@newcmd\qurantrans@ur@mdcccxxxvii{اور بیشک تجھ پر روزِ جزا تک لعنت (پڑتی) رہے گی،\qt@no{35}}%
\qt@newcmd\qurantrans@ur@mdcccxxxviii{اُس نے کہا: اے پروردگار! پس تو مجھے اُس دن تک مہلت دے دے (جس دن) لوگ (دوبارہ) اٹھائے جائیں گے،\qt@no{36}}%
\qt@newcmd\qurantrans@ur@mdcccxxxix{اللہ نے فرمایا: سو بیشک تو مہلت یافتہ لوگوں میں سے ہے،\qt@no{37}}%
\qt@newcmd\qurantrans@ur@mdcccxl{وقتِ مقررہ کے دن (قیامت) تک،\qt@no{38}}%
\qt@newcmd\qurantrans@ur@mdcccxli{ابلیس نے کہا: اے پروردگار! اس سبب سے جو تو نے مجھے گمراہ کیا میں (بھی) یقیناً ان کے لئے زمین میں (گناہوں اور نافرمانیوں کو) خوب آراستہ و خوش نما بنا دوں گا اور ان سب کو ضرور گمراہ کر کے رہوں گا،\qt@no{39}}%
\qt@newcmd\qurantrans@ur@mdcccxlii{سوائے تیرے ان برگزیدہ بندوں کے جو (میرے اور نفس کے فریبوں سے) خلاصی پا چکے ہیں،\qt@no{40}}%
\qt@newcmd\qurantrans@ur@mdcccxliii{اللہ نے ارشاد فرمایا: یہ (اخلاص ہی) راستہ ہے جو سیدھا میرے در پر آتا ہے،\qt@no{41}}%
\qt@newcmd\qurantrans@ur@mdcccxliv{بیشک میرے (اخلاص یافتہ) بندوں پر تیرا کوئی زور نہیں چلے گا سوائے ان بھٹکے ہوؤں کے جنہوں نے تیری راہ اختیار کی،\qt@no{42}}%
\qt@newcmd\qurantrans@ur@mdcccxlv{اور بیشک ان سب کے لئے وعدہ کی جگہ جہنم ہے،\qt@no{43}}%
\qt@newcmd\qurantrans@ur@mdcccxlvi{جس کے سات دروازے ہیں، ہر دروازے کے لئے ان میں سے الگ حصہ مخصوص کیا گیا ہے،\qt@no{44}}%
\qt@newcmd\qurantrans@ur@mdcccxlvii{بیشک متقی لوگ باغوں اور چشموں میں رہیں گے،\qt@no{45}}%
\qt@newcmd\qurantrans@ur@mdcccxlviii{ان سے کہا جائے گا:) ان میں سلامتی کے ساتھ بے خوف ہو کر داخل ہو جاؤ،\qt@no{46}}%
\qt@newcmd\qurantrans@ur@mdcccxlix{اور ہم وہ ساری کدورت باہر کھینچ لیں گے جو (دنیا میں) ان کے سینوں میں (مغالطہ کے باعث ایک دوسرے سے) تھی، وہ (جنت میں) بھائی بھائی بن کر آمنے سامنے بیٹھے ہوں گے،\qt@no{47}}%
\qt@newcmd\qurantrans@ur@mdcccl{انہیں وہاں کوئی تکلیف نہ پہنچے گی اور نہ ہی وہ وہاں سے نکالے جائیں گے،\qt@no{48}}%
\qt@newcmd\qurantrans@ur@mdcccli{اے حبیب!) آپ میرے بندوں کو بتا دیجئے کہ میں ہی بیشک بڑا بخشنے والا نہایت مہربان ہوں،\qt@no{49}}%
\qt@newcmd\qurantrans@ur@mdccclii{اور (اس بات سے بھی آگاہ کر دیجئے) کہ میرا ہی عذاب بڑا دردناک عذاب ہے،\qt@no{50}}%
\qt@newcmd\qurantrans@ur@mdcccliii{اور انہیں ابراہیم (علیہ السلام) کے مہمانوں کی خبر (بھی) سنائیے،\qt@no{51}}%
\qt@newcmd\qurantrans@ur@mdcccliv{جب وہ ابراہیم (علیہ السلام) کے پاس آئے تو انہوں نے (آپ کو) سلام کہا۔ ابراہیم (علیہ السلام) نے کہا کہ ہم آپ سے کچھ ڈر محسوس کر رہے ہیں،\qt@no{52}}%
\qt@newcmd\qurantrans@ur@mdccclv{مہمان فرشتوں نے) کہا: آپ خائف نہ ہوں ہم آپ کو ایک دانش مند لڑکے (کی پیدائش) کی خوشخبری سناتے ہیں،\qt@no{53}}%
\qt@newcmd\qurantrans@ur@mdccclvi{ابراہیم (علیہ السلام) نے کہا: تم مجھے اس حال میں خوشخبری سنا رہے ہو جبکہ مجھے بڑھاپا لاحق ہو چکا ہے سو اب تم کس چیز کی خوشخبری سناتے ہو؟،\qt@no{54}}%
\qt@newcmd\qurantrans@ur@mdccclvii{انہوں نے کہا: ہم آپ کو سچی بشارت دے رہے ہیں سو آپ نا امید نہ ہوں،\qt@no{55}}%
\qt@newcmd\qurantrans@ur@mdccclviii{ابراہیم (علیہ السلام) نے کہا: اپنے رب کی رحمت سے گمراہوں کے سوا اور کون مایوس ہو سکتا ہے،\qt@no{56}}%
\qt@newcmd\qurantrans@ur@mdccclix{ابراہیم (علیہ السلام) نے دریافت کیا: اے (اللہ کے) بھیجے ہوئے فرشتو! (اس بشارت کے علاوہ) اور تمہارا کیا کام ہے (جس کے لئے آئے ہو)،\qt@no{57}}%
\qt@newcmd\qurantrans@ur@mdccclx{انہوں نے کہا: ہم ایک مجرم قوم کی طرف بھیجے گئے ہیں،\qt@no{58}}%
\qt@newcmd\qurantrans@ur@mdccclxi{سوائے لوط (علیہ السلام) کے گھرانے کے، بیشک ہم ان سب کو ضرور بچا لیں گے،\qt@no{59}}%
\qt@newcmd\qurantrans@ur@mdccclxii{بجز ان کی بیوی کے، ہم (یہ) طے کر چکے ہیں کہ وہ ضرور (عذاب کے لئے) پیچھے رہ جانے والوں میں سے ہے،\qt@no{60}}%
\qt@newcmd\qurantrans@ur@mdccclxiii{پھر جب لوط (علیہ السلام) کے خاندان کے پاس وہ فرستادہ (فرشتے) آئے،\qt@no{61}}%
\qt@newcmd\qurantrans@ur@mdccclxiv{لوط (علیہ السلام) نے کہا: بیشک تم اجنبی لوگ (معلوم ہوتے) ہو،\qt@no{62}}%
\qt@newcmd\qurantrans@ur@mdccclxv{انہوں نے کہا: (ایسا نہیں) بلکہ ہم آپ کے پاس وہ (عذاب) لے کر آئے ہیں جس میں یہ لوگ شک کرتے رہے ہیں،\qt@no{63}}%
\qt@newcmd\qurantrans@ur@mdccclxvi{اور ہم آپ کے پاس حق (کا فیصلہ) لے کر آئے ہیں اور ہم یقیناً سچے ہیں،\qt@no{64}}%
\qt@newcmd\qurantrans@ur@mdccclxvii{پس آپ اپنے اہلِ خانہ کو رات کے کسی حصہ میں لے کر نکل جائیے اور آپ خود ان کے پیچھے پیچھے چلئے اور آپ میں سے کوئی مڑ کر (بھی) پیچھے نہ دیکھے اور آپ کو جہاں جانے کا حکم دیا گیا ہے (وہاں) چلے جائیے،\qt@no{65}}%
\qt@newcmd\qurantrans@ur@mdccclxviii{اور ہم نے لوط (علیہ السلام) کو اس فیصلہ سے بذریعہ وحی آگاہ کر دیا کہ بیشک اُن کے صبح کرتے ہی اُن لوگوں کی جڑ کٹ جائے گی،\qt@no{66}}%
\qt@newcmd\qurantrans@ur@mdccclxix{اور اہلِ شہر (اپنی بد مستی میں) خوشیاں مناتے ہوئے (لوط علیہ السلام کے پاس) آپہنچے،\qt@no{67}}%
\qt@newcmd\qurantrans@ur@mdccclxx{لوط (علیہ السلام) نے کہا: بیشک یہ لوگ میرے مہمان ہیں پس تم مجھے (اِن کے بارے میں) شرم سار نہ کرو،\qt@no{68}}%
\qt@newcmd\qurantrans@ur@mdccclxxi{اور اللہ (کے غضب) سے ڈرو اور مجھے رسوا نہ کرو،\qt@no{69}}%
\qt@newcmd\qurantrans@ur@mdccclxxii{وہ (بد مست لوگ) بولے: (اے لوط!) کیا ہم نے تمہیں دنیا بھر کے لوگوں (کی حمایت) سے منع نہیں کیا تھا،\qt@no{70}}%
\qt@newcmd\qurantrans@ur@mdccclxxiii{لوط (علیہ السلام) نے کہا: یہ میری (قوم کی) بیٹیاں ہیں اگر تم کچھ کرنا چاہتے ہو (تو بجائے بدکرداری کے ان سے نکاح کر لو)،\qt@no{71}}%
\qt@newcmd\qurantrans@ur@mdccclxxiv{اے حبیبِ مکرّم!) آپ کی عمرِ مبارک کی قَسم، بیشک یہ لوگ (بھی قومِ لوط کی طرح) اپنی بدمستی میں سرگرداں پھر رہے ہیں،\qt@no{72}}%
\qt@newcmd\qurantrans@ur@mdccclxxv{پس انہیں طلوعِ آفتاب کے ساتھ ہی سخت آتشیں کڑک نے آلیا،\qt@no{73}}%
\qt@newcmd\qurantrans@ur@mdccclxxvi{سو ہم نے ان کی بستی کو زِیر و زَبر کر دیا اور ہم نے ان پر پتھر کی طرح سخت مٹی کے کنکر برسائے،\qt@no{74}}%
\qt@newcmd\qurantrans@ur@mdccclxxvii{بیشک اس (واقعہ) میں اہلِ فراست کے لئے نشانیاں ہیں،\qt@no{75}}%
\qt@newcmd\qurantrans@ur@mdccclxxviii{اور بیشک وہ بستی ایک آباد راستہ پر واقع ہے،\qt@no{76}}%
\qt@newcmd\qurantrans@ur@mdccclxxix{بیشک اس (واقعۂ قومِ لوط) میں اہلِ ایمان کے لئے نشانی (عبرت) ہے،\qt@no{77}}%
\qt@newcmd\qurantrans@ur@mdccclxxx{اور بیشک باشندگانِ اَیکہ (یعنی گھنی جھاڑیوں کے رہنے والے) بھی بڑے ظالم تھے،\qt@no{78}}%
\qt@newcmd\qurantrans@ur@mdccclxxxi{پس ہم نے ان سے (بھی) انتقام لیا، اور یہ دونوں (بستیاں) کھلے راستہ پر (موجود) ہیں،\qt@no{79}}%
\qt@newcmd\qurantrans@ur@mdccclxxxii{اور بیشک وادئ حجر کے باشندوں نے بھی رسولوں کو جھٹلایا،\qt@no{80}}%
\qt@newcmd\qurantrans@ur@mdccclxxxiii{اور ہم نے انہیں (بھی) اپنی نشانیاں دیں مگر وہ ان سے رُوگردانی کرتے رہے،\qt@no{81}}%
\qt@newcmd\qurantrans@ur@mdccclxxxiv{اور وہ لوگ بے خوف و خطر پہاڑوں میں گھر تراشتے تھے،\qt@no{82}}%
\qt@newcmd\qurantrans@ur@mdccclxxxv{تو انہیں (بھی) صبح کرتے ہی خوفناک کڑک نے آپکڑا،\qt@no{83}}%
\qt@newcmd\qurantrans@ur@mdccclxxxvi{سو جو (مال) وہ کمایا کرتے تھے وہ ان سے (اللہ کے عذاب) کو دفع نہ کر سکا،\qt@no{84}}%
\qt@newcmd\qurantrans@ur@mdccclxxxvii{اور ہم نے آسمانوں اور زمین کو اور جو کچھ ان دونوں کے درمیان ہے عبث پیدا نہیں کیا، اور یقیناً قیامت کی گھڑی آنے والی ہے، سو (اے اخلاقِ مجسّم!) آپ بڑے حسن و خوبی کے ساتھ درگزر کرتے رہئے،\qt@no{85}}%
\qt@newcmd\qurantrans@ur@mdccclxxxviii{بیشک آپ کا رب ہی سب کو پیدا فرمانے والا خوب جاننے والا ہے،\qt@no{86}}%
\qt@newcmd\qurantrans@ur@mdccclxxxix{اور بیشک ہم نے آپ کو بار بار دہرائی جانے والی سات آیتیں (یعنی سورۂ فاتحہ) اور بڑی عظمت والا قرآن عطا فرمایا ہے،\qt@no{87}}%
\qt@newcmd\qurantrans@ur@mdcccxc{آپ ان چیزوں کی طرف نگاہ اٹھا کر بھی نہ دیکھئے جن سے ہم نے کافروں کے گروہوں کو (چند روزہ) عیش کے لئے بہرہ مند کیا ہے، اور ان (کی گمراہی) پر رنجیدہ خاطر بھی نہ ہوں اور اہلِ ایمان (کی دل جوئی) کے لئے اپنے (شفقت و التفات کے) بازو جھکائے رکھئے،\qt@no{88}}%
\qt@newcmd\qurantrans@ur@mdcccxci{اور فرما دیجئے کہ بیشک (اب) میں ہی (عذابِ الٰہی کا) واضح و صریح ڈر سنانے والا ہوں،\qt@no{89}}%
\qt@newcmd\qurantrans@ur@mdcccxcii{جیسا (عذاب) کہ ہم نے تقسیم کرنے والوں (یعنی یہود و نصارٰی) پر اتارا تھا،\qt@no{90}}%
\qt@newcmd\qurantrans@ur@mdcccxciii{جنہوں نے قرآن کو ٹکڑے ٹکڑے (کر کے تقسیم) کر ڈالا (یعنی موافق آیتوں کو مان لیا اور غیر موافق کو نہ مانا)،\qt@no{91}}%
\qt@newcmd\qurantrans@ur@mdcccxciv{سو آپ کے رب کی قسم! ہم ان سب سے ضرور پرسش کریں گے،\qt@no{92}}%
\qt@newcmd\qurantrans@ur@mdcccxcv{ان اعمال سے متعلق جو وہ کرتے رہے تھے،\qt@no{93}}%
\qt@newcmd\qurantrans@ur@mdcccxcvi{پس آپ وہ (باتیں) اعلانیہ کہہ ڈالیں جن کا آپ کو حکم دیا گیا ہے اور آپ مشرکوں سے منہ پھیر لیجئے،\qt@no{94}}%
\qt@newcmd\qurantrans@ur@mdcccxcvii{بیشک مذاق کرنے والوں (کو انجام تک پہنچانے) کے لئے ہم آپ کو کافی ہیں،\qt@no{95}}%
\qt@newcmd\qurantrans@ur@mdcccxcviii{جو اللہ کے ساتھ دوسرا معبود بناتے ہیں سو وہ عنقریب (اپنا انجام) جان لیں گے،\qt@no{96}}%
\qt@newcmd\qurantrans@ur@mdcccxcix{اور بیشک ہم جانتے ہیں کہ آپ کا سینۂ (اقدس) ان باتوں سے تنگ ہوتا ہے جو وہ کہتے ہیں،\qt@no{97}}%
\qt@newcmd\qurantrans@ur@mcm{سو آپ حمد کے ساتھ اپنے رب کی تسبیح کیا کریں اور سجود کرنے والوں میں (شامل) رہا کریں،\qt@no{98}}%
\qt@newcmd\qurantrans@ur@mcmi{اور اپنے رب کی عبادت کرتے رہیں یہاں تک کہ آپ کو (آپ کی شان کے لائق) مقامِ یقین مل جائے (یعنی انشراحِ کامل نصیب ہو جائے یا لمحۂ وصالِ حق)،\qt@no{99}}%
\qt@newcmd\qurantrans@ur@mcmii{\basmalahur اللہ کا وعدہ (قریب) آپہنچا سو تم اس کے چاہنے میں عجلت نہ کرو۔ وہ پاک ہے اور وہ ان چیزوں سے برتر ہے جنہیں کفار (اس کا) شریک ٹھہراتے ہیں،\qt@no{1}}%
\qt@newcmd\qurantrans@ur@mcmiii{وہی فرشتوں کو وحی کے ساتھ (جو جملہ تعلیماتِ دین کی روح اور جان ہے) اپنے حکم سے اپنے بندوں میں سے جس پر چاہتا ہے نازل فرماتا ہے کہ (لوگوں کو) ڈر سناؤ کہ میرے سوا کوئی معبود نہیں سو میری پرہیزگاری اختیار کرو،\qt@no{2}}%
\qt@newcmd\qurantrans@ur@mcmiv{اُسی نے آسمانوں اور زمین کو درست تدبیر کے ساتھ پیدا فرمایا، وہ ان چیزوں سے برتر ہے جنہیں کفار (اس کا) شریک گردانتے ہیں،\qt@no{3}}%
\qt@newcmd\qurantrans@ur@mcmv{اُسی نے انسان کو ایک تولیدی قطرہ سے پیدا فرمایا، پھر بھی وہ (اللہ کے حضور مطیع ہونے کی بجائے) کھلا جھگڑالو بن گیا،\qt@no{4}}%
\qt@newcmd\qurantrans@ur@mcmvi{اور اُسی نے تمہارے لئے چوپائے پیدا فرمائے، ان میں تمہارے لئے گرم لباس ہے اور (دوسرے) فوائد ہیں اور ان میں سے بعض کو تم کھاتے (بھی) ہو،\qt@no{5}}%
\qt@newcmd\qurantrans@ur@mcmvii{اور ان میں تمہارے لئے رونق (اور دل کشی بھی) ہے جب تم شام کو چراگاہ سے (واپس) لاتے ہو اور جب تم صبح کو (چرانے کے لئے) لے جاتے ہو،\qt@no{6}}%
\qt@newcmd\qurantrans@ur@mcmviii{اور یہ (جانور) تمہارے بوجھ (بھی) ان شہروں تک اٹھا لے جاتے ہیں جہاں تم بغیر جانکاہ مشقت کے نہیں پہنچ سکتے تھے، بیشک تمہارا رب نہایت شفقت والا نہایت مہربان ہے،\qt@no{7}}%
\qt@newcmd\qurantrans@ur@mcmix{اور (اُسی نے) گھوڑوں اور خچروں اور گدھوں کو (پیدا کیا) تاکہ تم ان پر سواری کر سکو اور وہ (تمہارے لئے) باعثِ زینت بھی ہوں، اور وہ (مزید ایسی بازینت سواریوں کو بھی) پیدا فرمائے گا جنہیں تم (آج) نہیں جانتے،\qt@no{8}}%
\qt@newcmd\qurantrans@ur@mcmx{اور درمیانی راہ اللہ (کے دروازے) پر جا پہنچتی ہے اور اس میں سے کئی ٹیڑھی راہیں بھی (نکلتی) ہیں، اور اگر وہ چاہتا تو تم سب ہی کو ہدایت فرما دیتا،\qt@no{9}}%
\qt@newcmd\qurantrans@ur@mcmxi{وہی ہے جس نے تمہارے لئے آسمان کی جانب سے پانی اتارا، اس میں سے (کچھ) پینے کا ہے اور اسی میں سے (کچھ) شجر کاری کا ہے (جس سے نباتات، سبزے اور چراگاہیں اُگتی ہیں) جن میں تم (اپنے مویشی) چراتے ہو،\qt@no{10}}%
\qt@newcmd\qurantrans@ur@mcmxii{اُسی پانی سے تمہارے لئے کھیت اور زیتون اور کھجور اور انگور اور ہر قسم کے پھل (اور میوے) اگاتا ہے، بیشک اِس میں غور و فکر کرنے والے لوگوں کے لئے نشانی ہے،\qt@no{11}}%
\qt@newcmd\qurantrans@ur@mcmxiii{اور اُسی نے تمہارے لئے رات اور دن کو اور سورج اور چاند کو مسخر کر دیا، اور تمام ستارے بھی اُسی کی تدبیر (سے نظام) کے پابند ہیں، بیشک اس میں عقل رکھنے والے لوگوں کے لئے نشانیاں ہیں،\qt@no{12}}%
\qt@newcmd\qurantrans@ur@mcmxiv{اور (حیوانات، نباتات اور معدنیات وغیرہ میں سے بقیہ) جو کچھ بھی اس نے تمہارے لئے زمین میں پیدا فرمایا ہے جن کے رنگ (یعنی جنسیں، نوعیں، قسمیں، خواص اور منافع) الگ الگ ہیں (سب تمہارے لئے مسخر ہیں)، بیشک اس میں نصیحت قبول کرنے والے لوگوں کے لئے نشانی ہے،\qt@no{13}}%
\qt@newcmd\qurantrans@ur@mcmxv{اور وہی ہے جس نے (فضا و بر کے علاوہ) بحر (یعنی دریاؤں اور سمندروں) کو بھی مسخر فرما دیا تاکہ تم اس میں سے تازہ (و پسندیدہ) گوشت کھاؤ اور تم اس میں سے موتی (وغیرہ) نکالو جنہیں تم زیبائش کے لئے پہنتے ہو، اور (اے انسان!) تُو کشتیوں (اور جہازوں) کو دیکھتا ہے جو (دریاؤں اور سمندروں کا) پانی چیرتے ہوئے اس میں چلے جاتے ہیں، اور (یہ سب کچھ اس لئے کیا) تاکہ تم (دور دور تک) اس کا فضل (یعنی رزق) تلاش کرو اور یہ کہ تم شکر گزار بن جاؤ،\qt@no{14}}%
\qt@newcmd\qurantrans@ur@mcmxvi{اور اسی نے زمین میں (مختلف مادوں کو باہم ملا کر) بھاری پہاڑ بنا دیئے تاکہ ایسا نہ ہو کہ کہیں وہ (اپنے مدار میں حرکت کرتے ہوئے) تمہیں لے کر کانپنے لگے اور نہریں اور (قدرتی) راستے (بھی) بنائے تاکہ تم (منزلوں تک پہنچنے کے لئے) راہ پا سکو،\qt@no{15}}%
\qt@newcmd\qurantrans@ur@mcmxvii{اور (دن کو راہ تلاش کرنے کے لئے) علامتیں بنائیں، اور (رات کو) لوگ ستاروں کے ذریعہ (بھی) راہ پاتے ہیں،\qt@no{16}}%
\qt@newcmd\qurantrans@ur@mcmxviii{کیا وہ خالق جو (اتنا کچھ) پیدا فرمائے اس کے مثل ہو سکتا ہے جو (کچھ بھی) پیدا نہ کر سکے، کیا تم لوگ نصیحت قبول نہیں کرتے،\qt@no{17}}%
\qt@newcmd\qurantrans@ur@mcmxix{اور اگر تم اللہ کی نعمتوں کو شمار کرنا چاہو تو انہیں پورا شمار نہ کر سکو گے، بیشک اللہ بڑا بخشنے والا نہایت مہربان ہے،\qt@no{18}}%
\qt@newcmd\qurantrans@ur@mcmxx{اور اللہ جانتا ہے جو کچھ تم چھپاتے ہو اور جو کچھ تم ظاہر کرتے ہو،\qt@no{19}}%
\qt@newcmd\qurantrans@ur@mcmxxi{اور یہ (مشرک) لوگ جن (بتوں) کو اللہ کے سوا پوجتے ہیں وہ کچھ بھی پیدا نہیں کر سکتے بلکہ وہ خود پیدا کئے گئے ہیں،\qt@no{20}}%
\qt@newcmd\qurantrans@ur@mcmxxii{وہ) مُردے ہیں زندہ نہیں، اور (انہیں اتنا بھی) شعور نہیں کہ (لوگ) کب اٹھائے جائیں گے،\qt@no{21}}%
\qt@newcmd\qurantrans@ur@mcmxxiii{تمہارا معبود، معبودِ یکتا ہے، پس جو لوگ آخرت پر ایمان نہیں رکھتے ان کے دل منکر ہیں اور وہ سرکش و متکبّر ہیں،\qt@no{22}}%
\qt@newcmd\qurantrans@ur@mcmxxiv{یہ بات حق و ثابت ہے کہ اللہ جانتا ہے جو کچھ وہ چھپاتے ہیں اور جو کچھ وہ ظاہر کرتے ہیں، بیشک وہ سرکشوں متکبّروں کو پسند نہیں کرتا،\qt@no{23}}%
\qt@newcmd\qurantrans@ur@mcmxxv{اور جب اُن سے پوچھا جاتا ہے کہ تمہارے رب نے کیا نازل فرمایا ہے؟ (تو) وہ کہتے ہیں: اگلی قوموں کے جھوٹے قصے (اتارے ہیں)،\qt@no{24}}%
\qt@newcmd\qurantrans@ur@mcmxxvi{یہ سب کچھ اس لئے کہہ رہے ہیں) تاکہ روزِ قیامت وہ اپنے (اعمالِ بد کے) پورے پورے بوجھ اٹھائیں اور کچھ بوجھ اُن لوگوں کے بھی (اٹھائیں) جنہیں (اپنی) جہالت کے ذریعہ گمراہ کئے جا رہے ہیں، جان لو! بہت بُرا بوجھ ہے جو یہ اٹھا رہے ہیں،\qt@no{25}}%
\qt@newcmd\qurantrans@ur@mcmxxvii{بیشک اُن لوگوں نے (بھی) فریب کیا جو اِن سے پہلے تھے تو اللہ نے اُن (کے مکر و فریب) کی عمارت کو بنیادوں سے اکھاڑ دیا تو ان کے اوپر سے ان پر چھت گر پڑی اور ان پر اس طرف سے عذاب آپہنچا جس کا اُنہیں کچھ خیال بھی نہ تھا،\qt@no{26}}%
\qt@newcmd\qurantrans@ur@mcmxxviii{پھر وہ اُنہیں قیامت کے دن رسوا کرے گا اور ارشاد فرمائے گا: میرے وہ شریک کہاں ہیں جن کے حق میں تم (مومنوں سے) جھگڑا کرتے تھے؟ وہ لوگ جنہیں علم دیا گیا ہے کہیں گے: بیشک آج کافروں پر (ہر قسم کی) رسوائی اور بربادی ہے،\qt@no{27}}%
\qt@newcmd\qurantrans@ur@mcmxxix{جن کی روحیں فرشتے اس حال میں قبض کرتے ہیں کہ وہ اپنی جانوں پر (بدستور) ظلم کئے جا رہے ہوں، سو وہ (روزِ قیامت) اطاعت و فرمانبرداری کا اظہار کریں گے (اور کہیں گے:) ہم (دنیا میں) کوئی برائی نہیں کیا کرتے تھے، کیوں نہیں بیشک اللہ خوب جانتا ہے جو کچھ تم کیا کرتے تھے،\qt@no{28}}%
\qt@newcmd\qurantrans@ur@mcmxxx{پس تم دوزخ کے دروازوں سے داخل ہو جاؤ، تم اس میں ہمیشہ رہنے والے ہو، سو تکبّر کرنے والوں کا کیا ہی برا ٹھکانا ہے،\qt@no{29}}%
\qt@newcmd\qurantrans@ur@mcmxxxi{اور پرہیزگار لوگوں سے کہا جائے کہ تمہارے رب نے کیا نازل فرمایا ہے؟ وہ کہتے ہیں: (دنیا و آخرت کی) بھلائی (اتاری ہے)، ان لوگوں کے لئے جو نیکی کرتے رہے اس دنیا میں (بھی) بھلائی ہے، اور آخرت کا گھر تو ضرور ہی بہتر ہے، اور پرہیزگاروں کا گھر کیا ہی خوب ہے،\qt@no{30}}%
\qt@newcmd\qurantrans@ur@mcmxxxii{سدا بہار باغات ہیں جن میں وہ داخل ہوں گے جن کے نیچے سے نہریں بہہ رہی ہوں گی، اِن میں اُن کے لئے جو کچھ وہ چاہیں گے (میسّر) ہوگا، اس طرح اللہ پرہیزگاروں کو صلہ عطا فرماتا ہے،\qt@no{31}}%
\qt@newcmd\qurantrans@ur@mcmxxxiii{جن کی روحیں فرشتے اس حال میں قبض کرتے ہیں کہ وہ (نیکی و طاعت کے باعث) پاکیزہ اور خوش و خرم ہوں، (ان سے فرشتے قبضِ روح کے وقت ہی کہہ دیتے ہیں:) تم پر سلامتی ہو، تم جنت میں داخل ہو جاؤ ان (اَعمالِ صالحہ) کے باعث جو تم کیا کرتے تھے،\qt@no{32}}%
\qt@newcmd\qurantrans@ur@mcmxxxiv{یہ اور کس چیز کا انتظار کر رہے ہیں سوائے اِس کے کہ ِان کے پاس فرشتے آجائیں یا آپ کے رب کا حکمِ (عذاب) آپہنچے، یہی کچھ ان لوگوں نے (بھی) کیا تھا جو اِن سے پہلے تھے، اور اللہ نے اُن پر ظلم نہیں کیا تھا لیکن وہ خود ہی اپنی جانوں پر ظلم کیا کرتے تھے،\qt@no{33}}%
\qt@newcmd\qurantrans@ur@mcmxxxv{سو جو اَعمال انہوں نے کئے تھے انہی کی سزائیں ان کو پہنچیں اور اسی (عذاب) نے انہیں آگھیرا جس کا وہ مذاق اڑایا کرتے تھے،\qt@no{34}}%
\qt@newcmd\qurantrans@ur@mcmxxxvi{اور مشرک لوگ کہتے ہیں: اگر اللہ چاہتا تو ہم اس کے سوا کسی بھی چیز کی پرستش نہ کرتے، نہ ہی ہم اور نہ ہمارے باپ دادا، اور نہ ہم اس کے (حکم کے) بغیر کسی چیز کو حرام قرار دیتے، یہی کچھ ان لوگوں نے (بھی) کیا تھا جو اِن سے پہلے تھے، تو کیا رسولوں کے ذمہ (اللہ کے پیغام اور احکام) واضح طور پر پہنچا دینے کے علاوہ بھی کچھ ہے،\qt@no{35}}%
\qt@newcmd\qurantrans@ur@mcmxxxvii{اور بیشک ہم نے ہر امت میں ایک رسول بھیجا کہ (لوگو) تم اللہ کی عبادت کرو اور طاغوت (یعنی شیطان اور بتوں کی اطاعت و پرستش) سے اجتناب کرو، سو اُن میں بعض وہ ہوئے جنہیں اللہ نے ہدایت فرما دی اور اُن میں بعض وہ ہوئے جن پر گمراہی (ٹھیک) ثابت ہوئی، سو تم لوگ زمین میں سیر و سیاحت کرو اور دیکھو کہ جھٹلانے والوں کا کیا انجام ہوا،\qt@no{36}}%
\qt@newcmd\qurantrans@ur@mcmxxxviii{اگر آپ ان کے ہدایت پر آجانے کی شدید طلب رکھتے ہیں تو (آپ اپنی طبیعتِ مطہرہ پر اس قدر بوجھ نہ لائیں) بیشک اللہ جسے گمراہ ٹھہرا دیتا ہے اسے ہدایت نہیں فرماتا اور ان کے لئے کوئی مددگار نہیں ہوتا،\qt@no{37}}%
\qt@newcmd\qurantrans@ur@mcmxxxix{اور یہ لوگ بڑی شدّ و مد سے اللہ کی قَسمیں کھاتے ہیں کہ جو مَر جائے اللہ اسے (دوبارہ) نہیں اٹھائے گا، کیوں نہیں اس کے ذمۂ کرم پر سچا وعدہ ہے لیکن اکثر لوگ نہیں جانتے،\qt@no{38}}%
\qt@newcmd\qurantrans@ur@mcmxl{مُردوں کا اٹھایا جانا اس لئے ہے) تاکہ ان کے لئے وہ (حق) بات واضح کر دے جس میں وہ لوگ اختلاف کرتے ہیں اور یہ کہ کافر لوگ جان لیں کہ حقیقت میں وہی جھوٹے ہیں،\qt@no{39}}%
\qt@newcmd\qurantrans@ur@mcmxli{ہمارا فرمان تو کسی چیز کے لئے صرف اِسی قدر ہوتا ہے کہ جب ہم اُس (کو وجود میں لانے) کا ارادہ کرتے ہیں تو ہم اُسے فرماتے ہیں: ”ہو جا“ پس وہ ہو جاتی ہے،\qt@no{40}}%
\qt@newcmd\qurantrans@ur@mcmxlii{اور جنہوں نے اللہ کی راہ میں ہجرت کی اس کے بعد کہ ان پر (طرح طرح کے) ظلم توڑے گئے تو ہم ضرور انہیں دنیا (ہی) میں بہتر ٹھکانا دیں گے، اور آخرت کا اجر تو یقیناً بہت بڑا ہے، کاش! وہ (اس راز کو) جانتے ہوتے،\qt@no{41}}%
\qt@newcmd\qurantrans@ur@mcmxliii{جن لوگوں نے صبر کیا اور اپنے رب پر توکل کئے رکھتے ہیں،\qt@no{42}}%
\qt@newcmd\qurantrans@ur@mcmxliv{اور ہم نے آپ سے پہلے بھی مَردوں ہی کو رسول بنا کر بھیجا جن کی طرف ہم وحی بھیجتے تھے سو تم اہلِ ذکر سے پوچھ لیا کرو اگر تمہیں خود (کچھ) معلوم نہ ہو،\qt@no{43}}%
\qt@newcmd\qurantrans@ur@mcmxlv{انہیں بھی) واضح دلائل اور کتابوں کے ساتھ (بھیجا تھا)، اور (اے نبیِ مکرّم!) ہم نے آپ کی طرف ذکرِ عظیم (قرآن) نازل فرمایا ہے تاکہ آپ لوگوں کے لئے وہ (پیغام اور احکام) خوب واضح کر دیں جو ان کی طرف اتارے گئے ہیں اور تاکہ وہ غور و فکر کریں،\qt@no{44}}%
\qt@newcmd\qurantrans@ur@mcmxlvi{کیا وہ بُرے مکر و فریب کرنے والے لوگ اس بات سے بے خوف ہو گئے ہیں کہ اللہ انہیں زمین میں دھنسا دے یا (کسی) ایسی جگہ سے ان پر عذاب بھیج دے جس کا انہیں کوئی خیال بھی نہ ہو،\qt@no{45}}%
\qt@newcmd\qurantrans@ur@mcmxlvii{یا ان کی نقل و حرکت (سفر اور شغلِ تجارت) کے دوران ہی انہیں پکڑ لے سو وہ اللہ کو عاجز نہیں کر سکتے،\qt@no{46}}%
\qt@newcmd\qurantrans@ur@mcmxlviii{یا انہیں ان کے خوف زدہ ہونے پر پکڑ لے، تو بیشک تمہارا رب بڑا شفیق نہایت مہربان ہے،\qt@no{47}}%
\qt@newcmd\qurantrans@ur@mcmxlix{کیا انہوں نے ان (سایہ دار) چیزوں کی طرف نہیں دیکھا جو اللہ نے پیدا فرمائی ہیں (کہ) ان کے سائے دائیں اور بائیں اَطراف سے اللہ کے لئے سجدہ کرتے ہوئے پھرتے رہتے ہیں اور وہ (درحقیقت) طاعت و عاجزی کا اظہار کرتے ہیں،\qt@no{48}}%
\qt@newcmd\qurantrans@ur@mcml{اور جو کچھ آسمانوں میں اور جو کچھ زمین میں ہے جملہ جاندار اور فرشتے، اللہ (ہی) کو سجدہ کرتے ہیں اور وہ (ذرا بھی) غرور و تکبر نہیں کرتے،\qt@no{49}}%
\qt@newcmd\qurantrans@ur@mcmli{وہ اپنے رب سے جو ان کے اوپر ہے ڈرتے رہتے ہیں اور جو حکم انہیں دیا جاتا ہے (اسے) بجا لاتے ہیں،\qt@no{50}}%
\qt@newcmd\qurantrans@ur@mcmlii{اور اللہ نے فرمایا ہے: تم دو معبود مت بناؤ، بیشک وہی (اللہ) معبودِ یکتا ہے، اور تم مجھ ہی سے ڈرتے رہو،\qt@no{51}}%
\qt@newcmd\qurantrans@ur@mcmliii{اور جو کچھ آسمانوں اور زمین میں ہے (سب) اسی کا ہے اور (سب کے لئے) اسی کی فرمانبرداری واجب ہے۔ تو کیا تم غیر اَز خدا (کسی) سے ڈرتے ہو،\qt@no{52}}%
\qt@newcmd\qurantrans@ur@mcmliv{اور تمہیں جو نعمت بھی حاصل ہے سو وہ اللہ ہی کی جانب سے ہے، پھر جب تمہیں تکلیف پہنچتی ہے تو تم اسی کے آگے گریہ و زاری کرتے ہو،\qt@no{53}}%
\qt@newcmd\qurantrans@ur@mcmlv{پھر جب اللہ اس تکلیف کو تم سے دور فرما دیتا ہے تو تم میں سے ایک گروہ اس وقت اپنے رب سے شرک کرنے لگتا ہے،\qt@no{54}}%
\qt@newcmd\qurantrans@ur@mcmlvi{یہ کفر و شرک اس لئے) تاکہ وہ ان (نعمتوں) کی ناشکری کریں جو ہم نے انہیں عطا کر رکھی ہیں، پس (اے مشرکو! چند روزہ) فائدہ اٹھا لو پھر تم عنقریب (اپنے انجام کو) جان لو گے،\qt@no{55}}%
\qt@newcmd\qurantrans@ur@mcmlvii{اور یہ ان (بتوں) کے لئے جن (کی حقیقت) کو وہ خود بھی نہیں جانتے اس رزق میں سے حصہ مقرر کرتے ہیں جو ہم نے انہیں عطا کر رکھا ہے۔ اللہ کی قسم! تم سے اس بہتان کی نسبت ضرور پوچھ گچھ کی جائے گی جو تم باندھا کرتے ہو،\qt@no{56}}%
\qt@newcmd\qurantrans@ur@mcmlviii{اور یہ (کفار و مشرکین) اللہ کے لئے بیٹیاں مقرر کرتے ہیں وہ (اس سے) پاک ہے اور اپنے لئے وہ کچھ (یعنی بیٹے) جن کی وہ خواہش کرتے ہیں،\qt@no{57}}%
\qt@newcmd\qurantrans@ur@mcmlix{اور جب ان میں سے کسی کو لڑکی (کی پیدائش) کی خبر سنائی جاتی ہے تو اس کا چہرہ سیاہ ہو جاتا ہے اور وہ غصہ سے بھر جاتا ہے،\qt@no{58}}%
\qt@newcmd\qurantrans@ur@mcmlx{وہ لوگوں سے چُھپا پھرتا ہے (بزعمِ خویش) اس بری خبر کی وجہ سے جو اسے سنائی گئی ہے، (اب یہ سوچنے لگتا ہے کہ) آیا اسے ذلت و رسوائی کے ساتھ (زندہ) رکھے یا اسے مٹی میں دبا دے (یعنی زندہ درگور کر دے)، خبردار! کتنا برا فیصلہ ہے جو وہ کرتے ہیں،\qt@no{59}}%
\qt@newcmd\qurantrans@ur@mcmlxi{ان لوگوں کی جو آخرت پر ایمان نہیں رکھتے (یہ) نہایت بری صفت ہے، اور بلند تر صفت اللہ ہی کی ہے اور وہ غالب حکمت والا ہے،\qt@no{60}}%
\qt@newcmd\qurantrans@ur@mcmlxii{اور اگر اللہ لوگوں کو ان کے ظلم کے عوض (فوراً) پکڑ لیا کرتا تو اس (زمین) پر کسی جاندار کو نہ چھوڑتا لیکن وہ انہیں مقررہ میعاد تک مہلت دیتا ہے، پھر جب ان کا مقرر وقت آپہنچتا ہے تو وہ نہ ایک گھڑی پیچھے ہو سکتے ہیں اور نہ آگے بڑھ سکتے ہیں،\qt@no{61}}%
\qt@newcmd\qurantrans@ur@mcmlxiii{اور وہ اللہ کے لئے وہ کچھ مقرر کرتے ہیں جو (اپنے لئے) ناپسند کرتے ہیں اور ان کی زبانیں جھوٹ بولتی ہیں کہ ان کے لئے بھلائی ہے، (ہرگز نہیں!) حقیقت یہ ہے کہ ان کے لئے دوزخ ہے اور یہ (دوزخ میں) سب سے پہلے بھیجے جائیں گے (اور اس میں ہمیشہ کے لئے چھوڑ دیئے جائیں گے)،\qt@no{62}}%
\qt@newcmd\qurantrans@ur@mcmlxiv{اللہ کی قسم! یقیناً ہم نے آپ سے پہلے (بھی بہت سی) امتوں کی طرف رسول بھیجے تو شیطان نے ان (امتوں) کے لئے ان کے (برے) اعمال آراستہ و خوش نما کر دکھائے، سو وہی (شیطان) آج ان کا دوست ہے اور ان کے لئے دردناک عذاب ہے،\qt@no{63}}%
\qt@newcmd\qurantrans@ur@mcmlxv{اور ہم نے آپ کی طرف کتاب نہیں اتاری مگر اس لئے کہ آپ ان پر وہ (اُمور) واضح کر دیں جن میں وہ اختلاف کرتے ہیں اور (اس لئے کہ یہ کتاب) ہدایت اور رحمت ہے اس قوم کے لئے جو ایمان لے آئی ہے،\qt@no{64}}%
\qt@newcmd\qurantrans@ur@mcmlxvi{اور اللہ نے آسمان کی جانب سے پانی اتارا اور اس کے ذریعہ زمین کو اس کے مردہ (یعنی بنجر) ہونے کے بعد زندہ (یعنی سرسبز و شاداب) کر دیا۔ بیشک اس میں (نصیحت) سننے والوں کے لئے نشانی ہے،\qt@no{65}}%
\qt@newcmd\qurantrans@ur@mcmlxvii{اور بیشک تمہارے لئے مویشیوں میں (بھی) مقامِ غور ہے، ہم ان کے جسموں کے اندر کی اس چیز سے جو آنتوں کے (بعض) مشمولات اور خون کے اختلاط سے (وجود میں آتی ہے) خالص دودھ نکال کر تمہیں پلاتے ہیں (جو) پینے والوں کے لئے فرحت بخش ہوتا ہے،\qt@no{66}}%
\qt@newcmd\qurantrans@ur@mcmlxviii{اور کھجور اور انگور کے پھلوں سے تم شکّر اور (دیگر) عمدہ غذائیں بناتے ہو، بیشک اس میں اہلِ عقل کے لئے نشانی ہے،\qt@no{67}}%
\qt@newcmd\qurantrans@ur@mcmlxix{اور آپ کے رب نے شہد کی مکھی کے دل میں (خیال) ڈال دیا کہ تو بعض پہاڑوں میں اپنے گھر بنا اور بعض درختوں میں اور بعض چھپروں میں (بھی) جنہیں لوگ (چھت کی طرح) اونچا بناتے ہیں،\qt@no{68}}%
\qt@newcmd\qurantrans@ur@mcmlxx{پس تو ہر قسم کے پھلوں سے رس چوسا کر پھر اپنے رب کے (سمجھائے ہوئے) راستوں پر (جو ان پھلوں اور پھولوں تک جاتے ہیں جن سے تو نے رس چوسنا ہے، دوسری مکھیوں کے لئے بھی) آسانی فراہم کرتے ہوئے چلا کر، ان کے شکموں سے ایک پینے کی چیز نکلتی ہے (وہ شہد ہے) جس کے رنگ جداگانہ ہوتے ہیں، اس میں لوگوں کے لئے شفا ہے، بیشک اس میں غور و فکر کرنے والوں کے لئے نشانی ہے،\qt@no{69}}%
\qt@newcmd\qurantrans@ur@mcmlxxi{اور اللہ نے تمہیں پیدا فرمایا ہے پھر وہ تمہیں وفات دیتا (یعنی تمہاری روح قبض کرتا) ہے۔ اور تم میں سے کسی کو ناقص ترین عمر (بڑھاپا) کی طرف پھیر دیا جاتا ہے تاکہ (زندگی میں بہت کچھ) جان لینے کے بعد اب کچھ بھی نہ جانے (یعنی انسان مرنے سے پہلے اپنی بے بسی و کم مائیگی کا منظر بھی دیکھ لے)، بیشک اللہ خوب جاننے والا بڑی قدرت والا ہے،\qt@no{70}}%
\qt@newcmd\qurantrans@ur@mcmlxxii{اور اللہ نے تم میں سے بعض کو بعض پر رزق (کے درجات) میں فضیلت دی ہے (تاکہ وہ تمہیں حکمِ انفاق کے ذریعے آزمائے)، مگر جن لوگوں کو فضیلت دی گئی ہے وہ اپنی دولت (کے کچھ حصہ کو بھی) اپنے زیردست لوگوں پر نہیں لوٹاتے (یعنی خرچ نہیں کرتے) حالانکہ وہ سب اس میں (بنیادی ضروریات کی حد تک) برابر ہیں، تو کیا وہ اللہ کی نعمتوں کا انکار کرتے ہیں،\qt@no{71}}%
\qt@newcmd\qurantrans@ur@mcmlxxiii{اور اللہ نے تم ہی میں سے تمہارے لئے جوڑے پیدا فرمائے اور تمہارے جوڑوں (یعنی بیویوں) سے تمہارے لئے بیٹے اور پوتے/ نواسے پیدا فرمائے اور تمہیں پاکیزہ رزق عطا فرمایا، تو کیا پھر بھی وہ (حق کو چھوڑ کر) باطل پر ایمان رکھتے ہیں اور اللہ کی نعمت سے وہ ناشکری کرتے ہیں،\qt@no{72}}%
\qt@newcmd\qurantrans@ur@mcmlxxiv{اور اللہ کے سوا ان (بتوں) کی پرستش کرتے ہیں جو آسمانوں اور زمین سے ان کے لئے کسی قدر رزق دینے کے بھی مالک نہیں ہیں اور نہ ہی کچھ قدرت رکھتے ہیں،\qt@no{73}}%
\qt@newcmd\qurantrans@ur@mcmlxxv{پس تم اللہ کے لئے مثل نہ ٹھہرایا کرو، بیشک اللہ جانتا ہے اور تم نہیں جانتے،\qt@no{74}}%
\qt@newcmd\qurantrans@ur@mcmlxxvi{اللہ نے ایک مثال بیان فرمائی ہے (کہ) ایک غلام ہے (جو کسی کی) ملکیت میں ہے (خود) کسی چیز پر قدرت نہیں رکھتا اور (دوسرا) وہ شخص ہے جسے ہم نے اپنی طرف سے عمدہ روزی عطا فرمائی ہے سو وہ اس میں سے پوشیدہ اور ظاہر خرچ کرتا ہے، کیا وہ برابر ہو سکتے ہیں، سب تعریفیں اللہ کے لئے ہیں، بلکہ ان میں سے اکثر (بنیادی حقیقت کو بھی) نہیں جانتے،\qt@no{75}}%
\qt@newcmd\qurantrans@ur@mcmlxxvii{اور اللہ نے دو (ایسے) آدمیوں کی مثال بیان فرمائی ہے جن میں سے ایک گونگا ہے وہ کسی چیز پر قدرت نہیں رکھتا اور وہ اپنے مالک پر بوجھ ہے وہ (مالک) اسے جدھر بھی بھیجتا ہے کوئی بھلائی لے کر نہیں آتا، کیا وہ (گونگا) اور (دوسرا) وہ شخص جو (اس منصب کا حامل ہے کہ) لوگوں کو عدل و انصاف کا حکم دیتا ہے اور وہ خود بھی سیدھی راہ پر گامزن ہے (دونوں) برابر ہو سکتے ہیں،\qt@no{76}}%
\qt@newcmd\qurantrans@ur@mcmlxxviii{اور آسمانوں اور زمین کا (سب) غیب اللہ ہی کے لئے ہے، اور قیامت کے بپا ہونے کا واقعہ اس قدر تیزی سے ہوگا جیسے آنکھ کا جھپکنا یا ا س سے بھی تیز تر، بیشک اللہ ہر چیز پر بڑا قادر ہے،\qt@no{77}}%
\qt@newcmd\qurantrans@ur@mcmlxxix{اور اللہ نے تمہیں تمہاری ماؤں کے پیٹ سے (اس حالت میں) باہر نکالا کہ تم کچھ نہ جانتے تھے اور اس نے تمہارے لئے کان اور آنکھیں اور دل بنائے تاکہ تم شکر بجا لاؤ،\qt@no{78}}%
\qt@newcmd\qurantrans@ur@mcmlxxx{کیا انہوں نے پرندوں کو نہیں دیکھا جو آسمان کی ہوا میں (قانونِ حرکت و پرواز کے) پابند (ہو کر اڑتے رہتے) ہیں، انہیں اللہ کے (قانون کے) سوا کوئی چیز تھامے ہوئے نہیں ہے۔ بیشک اس (پرواز کے اصول) میں ایمان والوں کے لئے نشانیاں ہیں،\qt@no{79}}%
\qt@newcmd\qurantrans@ur@mcmlxxxi{اور اللہ نے تمہارے لئے تمہارے گھروں کو (مستقل) سکونت کی جگہ بنایا اور تمہارے لئے چوپایوں کی کھالوں سے (عارضی) گھر (یعنی خیمے) بنائے جنہیں تم اپنے سفر کے وقت اور (دورانِ سفر منزلوں پر) اپنے ٹھہرنے کے وقت ہلکا پھلکا پاتے ہو اور (اسی اللہ نے تمہارے لئے) بھیڑوں اور دنبوں کی اون اور اونٹوں کی پشم اور بکریوں کے بالوں سے گھریلو استعمال اور (معیشت و تجارت میں) فائدہ اٹھانے کے اسباب بنائے (جو) مقررہ مدت تک (ہیں)،\qt@no{80}}%
\qt@newcmd\qurantrans@ur@mcmlxxxii{اور اللہ ہی نے تمہارے لئے اپنی پیدا کردہ کئی چیزوں کے سائے بنائے اور اس نے تمہارے لئے پہاڑوں میں پناہ گاہیں بنائیں اور اس نے تمہارے لئے (کچھ) ایسے لباس بنائے جو تمہیں گرمی سے بچاتے ہیں اور (کچھ) ایسے لباس جو تمہیں شدید جنگ میں (دشمن کے وار سے) بچاتے ہیں، اس طرح اللہ تم پر اپنی نعمتِ (کفالت و حفاظت) پوری فرماتا ہے تاکہ تم (اس کے حضور) سرِ نیاز خم کر دو،\qt@no{81}}%
\qt@newcmd\qurantrans@ur@mcmlxxxiii{سو اگر (پھر بھی) وہ رُوگردانی کریں تو (اے نبئ معظم!) آپ کے ذمہ تو صرف (میرے پیغام اور احکام کو) صاف صاف پہنچا دینا ہے،\qt@no{82}}%
\qt@newcmd\qurantrans@ur@mcmlxxxiv{یہ لوگ اللہ کی نعمت کو پہچانتے ہیں پھر اس کا انکار کرتے ہیں اور ان میں سے اکثر کافر ہیں،\qt@no{83}}%
\qt@newcmd\qurantrans@ur@mcmlxxxv{اور جس دن ہم ہر اُمت سے (اس کے رسول کو اس کے اعمال پر) گواہ بنا کر اٹھائیں گے پھر کافر لوگوں کو (کوئی عذر پیش کرنے کی) اجازت نہیں دی جائے گی اور نہ (اس وقت) ان سے توبہ و رجوع کا مطالبہ کیا جائے گا،\qt@no{84}}%
\qt@newcmd\qurantrans@ur@mcmlxxxvi{اور جب ظالم لوگ عذاب دیکھ لیں گے تو نہ ان سے (اس عذاب کی) تخفیف کی جائے گی اور نہ ہی انہیں مہلت دی جائے گی،\qt@no{85}}%
\qt@newcmd\qurantrans@ur@mcmlxxxvii{اور جب مشرک لوگ اپنے (خود ساختہ) شریکوں کو دیکھیں گے تو کہیں گے: اے ہمارے رب! یہی ہمارے شریک تھے جن کی ہم تجھے چھوڑ کر پرستش کرتے تھے، پس وہ (شرکاء) انہیں (جواباً) پیغام بھیجیں گے کہ بیشک تم جھوٹے ہو،\qt@no{86}}%
\qt@newcmd\qurantrans@ur@mcmlxxxviii{اور یہ (مشرکین) اس دن اللہ کے حضور عاجزی و فرمانبرداری ظاہر کریں گے اور ان سے وہ سارا بہتان جاتا رہے گا جو یہ باندھا کرتے تھے،\qt@no{87}}%
\qt@newcmd\qurantrans@ur@mcmlxxxix{جن لوگوں نے کفر کیا اور (دوسروں کو) اللہ کی راہ سے روکتے رہے ہم ان کے عذاب پر عذاب کا اضافہ کریں گے اس وجہ سے کہ وہ فساد انگیزی کرتے تھے،\qt@no{88}}%
\qt@newcmd\qurantrans@ur@mcmxc{اور (یہ) وہ دن ہوگا (جب) ہم ہر امت میں انہی میں سے خود ان پر ایک گواہ اٹھائیں گے اور (اے حبیبِ مکرّم!) ہم آپ کو ان سب (امتوں اور پیغمبروں) پر گواہ بنا کر لائیں گے، اور ہم نے آپ پر وہ عظیم کتاب نازل فرمائی ہے جو ہر چیز کا بڑا واضح بیان ہے اور مسلمانوں کے لئے ہدایت اور رحمت اور بشارت ہے،\qt@no{89}}%
\qt@newcmd\qurantrans@ur@mcmxci{بیشک اللہ (ہر ایک کے ساتھ) عدل اور احسان کا حکم فرماتا ہے اور قرابت داروں کو دیتے رہنے کا اور بے حیائی اور برے کاموں اور سرکشی و نافرمانی سے منع فرماتا ہے، وہ تمہیں نصیحت فرماتا ہے تاکہ تم خوب یاد رکھو،\qt@no{90}}%
\qt@newcmd\qurantrans@ur@mcmxcii{اور تم اللہ کا عہد پورا کر دیا کرو جب تم عہد کرو اور قسموں کو پختہ کر لینے کے بعد انہیں مت توڑا کرو حالانکہ تم اللہ کو اپنے آپ پر ضامن بنا چکے ہو، بیشک اللہ خوب جانتا ہے جو کچھ تم کرتے ہو،\qt@no{91}}%
\qt@newcmd\qurantrans@ur@mcmxciii{اور اس عورت کی طرح نہ ہو جاؤ جس نے اپنا سوت مضبوط کات لینے کے بعد توڑ کر ٹکڑے ٹکڑے کر ڈالا، تم اپنی قَسموں کو اپنے درمیان فریب کاری کا ذریعہ بناتے ہو تاکہ (اس طرح) ایک گروہ دوسرے گروہ سے زیادہ فائدہ اٹھانے والا ہو جائے، بات یہ ہے کہ اللہ (بھی) تمہیں اسی کے ذریعہ آزماتا ہے، اور وہ تمہارے لئے قیامت کے دن ان باتوں کو ضرور واضح فرما دے گا جن میں تم اختلاف کیا کرتے تھے،\qt@no{92}}%
\qt@newcmd\qurantrans@ur@mcmxciv{اور اگر اللہ چاہتا تو تم (سب) کو ایک ہی امت بنا دیتا لیکن وہ جسے چاہتا ہے گمراہ ٹھہرا دیتا ہے اور جسے چاہتا ہے ہدایت فرما دیتا ہے، اور تم سے ان کاموں کی نسبت ضرور پوچھا جائے گا جو تم انجام دیا کرتے تھے،\qt@no{93}}%
\qt@newcmd\qurantrans@ur@mcmxcv{اور تم اپنی قَسموں کو آپس میں فریب کاری کا ذریعہ نہ بنایا کرو ورنہ قدم (اسلام پر) جم جانے کے بعد لڑکھڑا جائے گا اور تم اس وجہ سے کہ اللہ کی راہ سے روکتے تھے برے انجام کا مزہ چکھو گے، اور تمہارے لئے زبردست عذاب ہے،\qt@no{94}}%
\qt@newcmd\qurantrans@ur@mcmxcvi{اور اللہ کے عہد حقیر سی قیمت (یعنی دنیوی مال و دولت) کے عوض مت بیچ ڈالا کرو، بیشک جو (اجر) اللہ کے پاس ہے وہ تمہارے لئے بہتر ہے اگر تم (اس راز کو) جانتے ہو،\qt@no{95}}%
\qt@newcmd\qurantrans@ur@mcmxcvii{جو (مال و زر) تمہارے پاس ہے فنا ہو جائے گا اور جو اللہ کے پاس ہے باقی رہنے والا ہے، اور ہم ان لوگوں کو جنہوں نے صبر کیا ضرور ان کا اجر عطا فرمائیں گے ان کے اچھے اعمال کے عوض جو وہ انجام دیتے رہے تھے،\qt@no{96}}%
\qt@newcmd\qurantrans@ur@mcmxcviii{جو کوئی نیک عمل کرے (خواہ) مرد ہو یا عورت جبکہ وہ مومن ہو تو ہم اسے ضرور پاکیزہ زندگی کے ساتھ زندہ رکھیں گے، اور انہیں ضرور ان کا اجر (بھی) عطا فرمائیں گے ان اچھے اعمال کے عوض جو وہ انجام دیتے تھے،\qt@no{97}}%
\qt@newcmd\qurantrans@ur@mcmxcix{سو جب آپ قرآن پڑھنے لگیں تو شیطان مردود (کی وسوسہ اندازیوں) سے اللہ کی پناہ مانگ لیا کریں،\qt@no{98}}%
\qt@newcmd\qurantrans@ur@mm{بیشک اسے ان لوگوں پر کچھ (بھی) غلبہ حاصل نہیں ہے جو ایمان لائے اور اپنے رب پر توکل کرتے ہیں،\qt@no{99}}%
\qt@newcmd\qurantrans@ur@mmi{بس اس کا غلبہ صرف انہی لوگوں پر ہے جو اسے دوست بناتے ہیں اور جو اللہ کے ساتھ شرک کرنے والے ہیں،\qt@no{100}}%
\qt@newcmd\qurantrans@ur@mmii{اور جب ہم کسی آیت کی جگہ دوسری آیت بدل دیتے ہیں اور اللہ (ہی) بہتر جانتا ہے جو (کچھ) وہ نازل فرماتا ہے (تو) کفار کہتے ہیں کہ آپ تو بس اپنی طرف سے گھڑنے والے ہیں، بلکہ ان میں سے اکثر لوگ (آیتوں کے اتارنے اور بدلنے کی حکمت) نہیں جانتے،\qt@no{101}}%
\qt@newcmd\qurantrans@ur@mmiii{فرما دیجئے: اس (قرآن) کو روحُ القدس (جبرئیل علیہ السلام) نے آپ کے رب کی طرف سے سچائی کے ساتھ اتارا ہے تاکہ ایمان والوں کو ثابت قدم رکھے اور (یہ) مسلمانوں کے لئے ہدایت اور بشارت ہے،\qt@no{102}}%
\qt@newcmd\qurantrans@ur@mmiv{اور بیشک ہم جانتے ہیں کہ وہ (کفار و مشرکین) کہتے ہیں کہ انہیں یہ (قرآن) محض کوئی آدمی ہی سکھاتا ہے، جس شخص کی طرف وہ بات کو حق سے ہٹاتے ہوئے منسوب کرتے ہیں اس کی زبان عجمی ہے اور یہ قرآن واضح و روشن عربی زبان (میں) ہے،\qt@no{103}}%
\qt@newcmd\qurantrans@ur@mmv{بیشک جو لوگ اللہ کی آیتوں پر ایمان نہیں لاتے اللہ انہیں ہدایت (یعنی صحیح فہم و بصیرت کی توفیق بھی) نہیں دیتا اور ان کے لئے دردناک عذاب ہے،\qt@no{104}}%
\qt@newcmd\qurantrans@ur@mmvi{بیشک جھوٹی افترا پردازی (بھی) وہی لوگ کرتے ہیں جو اللہ کی آیتوں پر ایمان نہیں لاتے اور وہی لوگ جھوٹے ہیں،\qt@no{105}}%
\qt@newcmd\qurantrans@ur@mmvii{جو شخص اپنے ایمان لانے کے بعد کفر کرے، سوائے اس کے جسے انتہائی مجبور کر دیا گیا مگر اس کا دل (بدستور) ایمان سے مطمئن ہے، لیکن (ہاں) وہ شخص جس نے (دوبارہ) شرحِ صدر کے ساتھ کفر (اختیار) کیا سو ان پر اللہ کی طرف سے غضب ہے اور ان کے لئے زبردست عذاب ہے،\qt@no{106}}%
\qt@newcmd\qurantrans@ur@mmviii{یہ اس وجہ سے کہ انہوں نے دنیوی زندگی کو آخرت پر عزیز رکھا اور اس لئے کہ اللہ کافروں کی قوم کو ہدایت نہیں فرماتا،\qt@no{107}}%
\qt@newcmd\qurantrans@ur@mmix{یہ وہ لوگ ہیں کہ اللہ نے ان کے دلوں پر اور ان کے کانوں پر اور ان کی آنکھوں پر مُہر لگا دی ہے اور یہی لوگ ہی (آخرت کے انجام سے) غافل ہیں،\qt@no{108}}%
\qt@newcmd\qurantrans@ur@mmx{یہ حقیقت ہے کہ بیشک یہی لوگ آخرت میں خسارہ اٹھانے والے ہیں،\qt@no{109}}%
\qt@newcmd\qurantrans@ur@mmxi{پھر آپ کا رب ان لوگوں کے لئے جنہوں نے آزمائشوں (اور تکلیفوں) میں مبتلا کئے جانے کے بعد ہجرت کی (یعنی اللہ کے لئے اپنے وطن چھوڑ دیئے) پھر جہاد کئے اور (پریشانیوں پر) صبر کئے تو (اے حبیبِ مکرّم!) آپ کا رب اس کے بعد بڑا بخشنے والا نہایت مہربان ہے،\qt@no{110}}%
\qt@newcmd\qurantrans@ur@mmxii{وہ دن (یاد کریں) جب ہر شخص محض اپنی جان کی طرف سے (دفاع کے لئے) جھگڑتا ہوا حاضر ہوگا اور ہر جان کو جو کچھ اس نے کیا ہوگا اس کا پورا پورا بدلہ دیا جائے گا اور ان پر کوئی ظلم نہیں کیا جائے گا،\qt@no{111}}%
\qt@newcmd\qurantrans@ur@mmxiii{اور اللہ نے ایک ایسی بستی کی مثال بیان فرمائی ہے جو (بڑے) امن اور اطمینان سے (آباد) تھی اس کا رزق اس کے (مکینوں کے) پاس ہر طرف سے بڑی وسعت و فراغت کے ساتھ آتا تھا پھر اس بستی (والوں) نے اللہ کی نعمتوں کی ناشکری کی تو اللہ نے اسے بھوک اور خوف کے عذاب کا لباس پہنا دیا ان اعمال کے سبب سے جو وہ کرتے تھے،\qt@no{112}}%
\qt@newcmd\qurantrans@ur@mmxiv{اور بیشک ان کے پاس انہی میں سے ایک رسول آیا تو انہوں نے اسے جھٹلایا پس انہیں عذاب نے آپکڑا اور وہ ظالم ہی تھے،\qt@no{113}}%
\qt@newcmd\qurantrans@ur@mmxv{پس جو حلال اور پاکیزہ رزق تمہیں اللہ نے بخشا ہے، تم اس میں سے کھایا کرو اور اللہ کی نعمت کا شکر بجا لاتے رہو اگر تم اسی کی عبادت کرتے ہو،\qt@no{114}}%
\qt@newcmd\qurantrans@ur@mmxvi{اس نے تم پر صرف مردار اور خون اور خنزیر کا گوشت اور وہ (جانور) جس پر ذبح کرتے وقت غیر اللہ کا نام پکارا گیا ہو، حرام کیا ہے، پھر جو شخص حالتِ اضطرار (یعنی انتہائی مجبوری کی حالت) میں ہو، نہ (طلبِ لذت میں احکامِ الٰہی سے) سرکشی کرنے والا ہو اور نہ (مجبوری کی حد سے) تجاوز کرنے والا ہو، تو بیشک اللہ بڑا بخشنے والا نہایت مہربان ہے،\qt@no{115}}%
\qt@newcmd\qurantrans@ur@mmxvii{اور وہ جھوٹ مت کہا کرو جو تمہاری زبانیں بیان کرتی رہتی ہیں کہ یہ حلال ہے اور یہ حرام ہے اس طرح کہ تم اللہ پر جھوٹا بہتان باندھو، بیشک جو لوگ اللہ پر جھوٹا بہتان باندھتے ہیں وہ (کبھی) فلاح نہیں پائیں گے،\qt@no{116}}%
\qt@newcmd\qurantrans@ur@mmxviii{فائدہ تھوڑا ہے مگر ان کے لئے عذاب (بڑا) دردناک ہے،\qt@no{117}}%
\qt@newcmd\qurantrans@ur@mmxix{اور یہود پر ہم نے وہی چیزیں حرام کی تھیں جو ہم پہلے آپ سے بیان کر چکے ہیں اور ہم نے ان پر ظلم نہیں کیا تھا لیکن وہ خود اپنی جانوں پر ظلم کیا کرتے تھے،\qt@no{118}}%
\qt@newcmd\qurantrans@ur@mmxx{پھر بیشک آپ کا رب ان لوگوں کے لئے جنہوں نے نادانی سے غلطیاں کیں پھر اس کے بعد تائب ہوگئے اور (اپنی) حالت درست کرلی تو بیشک آپ کا رب اس کے بعد بڑا بخشنے والا نہایت مہربان ہے،\qt@no{119}}%
\qt@newcmd\qurantrans@ur@mmxxi{بیشک ابراہیم (علیہ السلام تنہا ذات میں) ایک اُمت تھے، اللہ کے بڑے فرمانبردار تھے، ہر باطل سے کنارہ کش (صرف اسی کی طرف یک سُو) تھے، اور مشرکوں میں سے نہ تھے،\qt@no{120}}%
\qt@newcmd\qurantrans@ur@mmxxii{اس (اللہ) کی نعمتوں پر شاکر تھے، اللہ نے انہیں چن (کر اپنی بارگاہ میں خاص برگزیدہ بنا) لیا اور انہیں سیدھی راہ کی طرف ہدایت فرما دی،\qt@no{121}}%
\qt@newcmd\qurantrans@ur@mmxxiii{اور ہم نے اسے دنیا میں (بھی) بھلائی عطا فرمائی، اور بیشک وہ آخرت میں (بھی) صالحین میں سے ہوں گے،\qt@no{122}}%
\qt@newcmd\qurantrans@ur@mmxxiv{پھر (اے حبیبِ مکرّم!) ہم نے آپ کی طرف وحی بھیجی کہ آپ ابراہیم (علیہ السلام) کے دین کی پیروی کریں جو ہر باطل سے جدا تھے، اور وہ مشرکوں میں سے نہ تھے،\qt@no{123}}%
\qt@newcmd\qurantrans@ur@mmxxv{ہفتہ کا دن صرف انہی لوگوں پر مقرر کیا گیا تھا جنہوں نے اس میں اختلاف کیا، اور بیشک آپ کا رب قیامت کے دن اُن کے درمیان اُن (باتوں) کا فیصلہ فرما دے گا جن میں وہ اختلاف کیا کرتے تھے،\qt@no{124}}%
\qt@newcmd\qurantrans@ur@mmxxvi{اے رسولِ معظّم!) آپ اپنے رب کی راہ کی طرف حکمت اور عمدہ نصیحت کے ساتھ بلائیے اور ان سے بحث (بھی) ایسے انداز سے کیجئے جو نہایت حسین ہو، بیشک آپ کا رب اس شخص کو (بھی) خوب جانتا ہے جو اس کی راہ سے بھٹک گیا اور وہ ہدایت یافتہ لوگوں کو (بھی) خوب جانتا ہے،\qt@no{125}}%
\qt@newcmd\qurantrans@ur@mmxxvii{اور اگر تم سزا دینا چاہو تو اتنی ہی سزا دو جس قدر تکلیف تمہیں دی گئی تھی، اور اگر تم صبر کرو تو یقیناً وہ صبر کرنے والوں کے لئے بہتر ہے،\qt@no{126}}%
\qt@newcmd\qurantrans@ur@mmxxviii{اور (اے حبیبِ مکرّم!) صبر کیجئے اور آپ کا صبر کرنا اللہ ہی کے ساتھ ہے اور آپ ان (کی سرکشی) پر رنجیدہ خاطر نہ ہوا کریں اور آپ ان کی فریب کاریوں سے (اپنے کشادہ سینہ میں) تنگی (بھی) محسوس نہ کیا کریں،\qt@no{127}}%
\qt@newcmd\qurantrans@ur@mmxxix{بیشک اللہ اُن لوگوں کو اپنی معیتِ (خاص) سے نوازتا ہے جو صاحبانِ تقوٰی ہوں اور وہ لوگ جو صاحبانِ اِحسان (بھی) ہوں،\qt@no{128}}%
\qt@newcmd\qurantrans@ur@mmxxx{\basmalahur وہ ذات (ہر نقص اور کمزوری سے) پاک ہے جو رات کے تھوڑے سے حصہ میں اپنے (محبوب اور مقرّب) بندے کو مسجدِ حرام سے (اس) مسجدِ اقصٰی تک لے گئی جس کے گرد و نواح کو ہم نے بابرکت بنا دیا ہے تاکہ ہم اس (بندۂ کامل) کو اپنی نشانیاں دکھائیں، بیشک وہی خوب سننے والا خوب دیکھنے والا ہے،\qt@no{1}}%
\qt@newcmd\qurantrans@ur@mmxxxi{اور ہم نے موسٰی (علیہ السلام) کو کتاب (تورات) عطا کی اور ہم نے اسے بنی اسرائیل کے لئے ہدایت بنایا (اور انہیں حکم دیا) کہ تم میرے سوا کسی کو کار ساز نہ ٹھہراؤ،\qt@no{2}}%
\qt@newcmd\qurantrans@ur@mmxxxii{اے) ان لوگوں کی اولاد جنہیں ہم نے نوح (علیہ السلام) کے ساتھ (کشتی میں) اٹھا لیا تھا، بیشک نوح (علیہ السلام) بڑے شکر گزار بندے تھے،\qt@no{3}}%
\qt@newcmd\qurantrans@ur@mmxxxiii{اور ہم نے کتاب میں بنی اسرائیل کو قطعی طور پر بتا دیا تھا کہ تم زمین میں ضرور دو مرتبہ فساد کرو گے اور (اطاعتِ الٰہی سے) بڑی سرکشی برتو گے،\qt@no{4}}%
\qt@newcmd\qurantrans@ur@mmxxxiv{پھر جب ان دونوں میں سے پہلی مرتبہ کا وعدہ آپہنچا تو ہم نے تم پر اپنے ایسے بندے مسلّط کر دیئے جو سخت جنگ جُو تھے پھر وہ (تمہاری) تلاش میں (تمہارے) گھروں تک جا گھسے، اور (یہ) وعدہ ضرور پورا ہونا ہی تھا،\qt@no{5}}%
\qt@newcmd\qurantrans@ur@mmxxxv{پھر ہم نے ان کے اوپر غلبہ کو تمہارے حق میں پلٹا دیا اور ہم نے اموال و اولاد (کی کثرت) کے ذریعے تمہاری مدد فرمائی اور ہم نے تمہیں افرادی قوت میں (بھی) بڑھا دیا،\qt@no{6}}%
\qt@newcmd\qurantrans@ur@mmxxxvi{اگر تم بھلائی کرو گے تو اپنے (ہی) لئے بھلائی کرو گے، اور اگر تم برائی کرو گے تو اپنی (ہی) جان کے لئے، پھر جب دوسرے وعدہ کی گھڑی آئی (تو اور ظالموں کو تم پر مسلّط کر دیا) تاکہ (مار مار کر) تمہارے چہرے بگاڑ دیں اور تاکہ مسجدِ اقصٰی میں (اسی طرح) داخل ہوں جیسے اس میں (حملہ آور لوگ) پہلی مرتبہ داخل ہوئے تھے اور تاکہ جس (مقام) پر غلبہ پائیں اسے تباہ و برباد کر ڈالیں،\qt@no{7}}%
\qt@newcmd\qurantrans@ur@mmxxxvii{امید ہے (اس کے بعد) تمہارا رب تم پر رحم فرمائے گا اور اگر تم نے پھر وہی (سرکشی کا طرزِ عمل اختیار) کیا تو ہم بھی وہی (عذاب دوبارہ) کریں گے، اور ہم نے دوزخ کو کافروں کے لئے قید خانہ بنا دیا ہے،\qt@no{8}}%
\qt@newcmd\qurantrans@ur@mmxxxviii{بیشک یہ قرآن اس (منزل) کی طرف رہنمائی کرتا ہے جو سب سے درست ہے اور ان مومنوں کو جو نیک عمل کرتے ہیں اس بات کی خوشخبری سناتا ہے کہ ان کے لئے بڑا اجر ہے،\qt@no{9}}%
\qt@newcmd\qurantrans@ur@mmxxxix{اور یہ کہ جو لوگ آخرت پر ایمان نہیں رکھتے ہم نے ان کے لئے دردناک عذاب تیار کر رکھا ہے،\qt@no{10}}%
\qt@newcmd\qurantrans@ur@mmxl{اور انسان (کبھی تنگ دل اور پریشان ہو کر) برائی کی دعا مانگنے لگتا ہے جس طرح (اپنے لئے) بھلائی کی دعا مانگتا ہے، اور انسان بڑا ہی جلد باز واقع ہوا ہے،\qt@no{11}}%
\qt@newcmd\qurantrans@ur@mmxli{اور ہم نے رات اور دن کو (اپنی قدرت کی) دو نشانیاں بنایا پھر ہم نے رات کی نشانی کو تاریک بنایا اور ہم نے دن کی نشانی کو روشن بنایا تاکہ تم اپنے رب کا فضل (رزق) تلاش کر سکو اور تاکہ تم برسوں کا شمار اور حساب معلوم کر سکو، اور ہم نے ہر چیز کو پوری تفصیل سے واضح کر دیا ہے،\qt@no{12}}%
\qt@newcmd\qurantrans@ur@mmxlii{اور ہم نے ہر انسان کے اعمال کا نوشتہ اس کی گردن میں لٹکا دیا ہے، اور ہم اس کے لئے قیامت کے دن (یہ) نامۂ اعمال نکالیں گے جسے وہ (اپنے سامنے) کھلا ہوا پائے گا،\qt@no{13}}%
\qt@newcmd\qurantrans@ur@mmxliii{اس سے کہا جائے گا:) اپنی کتابِ (اَعمال) پڑھ لے، آج تو اپنا حساب جانچنے کے لئے خود ہی کافی ہے،\qt@no{14}}%
\qt@newcmd\qurantrans@ur@mmxliv{جو کوئی راہِ ہدایت اختیار کرتا ہے تو وہ اپنے فائدہ کے لئے ہدایت پر چلتا ہے اور جو شخص گمراہ ہوتا ہے تو اس کی گمراہی کا وبال (بھی) اسی پر ہے، اور کوئی بوجھ اٹھانے والا کسی دوسرے (کے گناہوں) کا بوجھ نہیں اٹھائے گا، اور ہم ہرگز عذاب دینے والے نہیں ہیں یہاں تک کہ ہم (اس قوم میں) کسی رسول کو بھیج لیں،\qt@no{15}}%
\qt@newcmd\qurantrans@ur@mmxlv{اور جب ہم کسی بستی کو ہلاک کرنے کا ارادہ کرتے ہیں تو ہم وہاں کے امراء اور خوشحال لوگوں کو (کوئی) حکم دیتے ہیں (تاکہ ان کے ذریعہ عوام اور غرباء بھی درست ہو جائیں) تو وہ اس (بستی) میں نافرمانی کرتے ہیں پس اس پر ہمارا فرمانِ (عذاب) واجب ہو جاتا ہے پھر ہم اس بستی کو بالکل ہی مسمار کر دیتے ہیں،\qt@no{16}}%
\qt@newcmd\qurantrans@ur@mmxlvi{اور ہم نے نوح (علیہ السلام) کے بعد کتنی ہی قوموں کو ہلاک کر ڈالا، اور آپ کا رب کافی ہے (وہ) اپنے بندوں کے گناہوں سے خوب خبردار خوب دیکھنے والا ہے،\qt@no{17}}%
\qt@newcmd\qurantrans@ur@mmxlvii{جو کوئی صرف دنیا کی خوشحالی (کی صورت میں اپنی محنت کا جلدی بدلہ) چاہتا ہے تو ہم اسی دنیا میں جسے چاہتے ہیں جتنا چاہتے ہیں جلدی دے دیتے ہیں پھر ہم نے اس کے لئے دوزخ بنا دی ہے جس میں وہ ملامت سنتا ہوا (رب کی رحمت سے) دھتکارا ہوا داخل ہوگا،\qt@no{18}}%
\qt@newcmd\qurantrans@ur@mmxlviii{اور جو شخص آخرت کا خواہش مند ہوا اور اس نے اس کے لئے اس کے لائق کوشش کی اور وہ مومن (بھی) ہے تو ایسے ہی لوگوں کی کوشش مقبولیت پائے گی،\qt@no{19}}%
\qt@newcmd\qurantrans@ur@mmxlix{ہم ہر ایک کی مدد کرتے ہیں ان (طالبانِ دنیا) کی بھی اور ان (طالبانِ آخرت) کی بھی (اے حبیبِ مکرّم! یہ سب کچھ) آپ کے رب کی عطا سے ہے، اور آپ کے رب کی عطا (کسی کے لئے) ممنوع اور بند نہیں ہے،\qt@no{20}}%
\qt@newcmd\qurantrans@ur@mml{دیکھئے ہم نے ان میں سے بعض کو بعض پر کس طرح فضیلت دے رکھی ہے، اور یقینًا آخرت (دنیا کے مقابلہ میں) درجات کے لحاظ سے (بھی) بہت بڑی ہے اور فضیلت کے لحاظ سے (بھی) بہت بڑی ہے،\qt@no{21}}%
\qt@newcmd\qurantrans@ur@mmli{اے سننے والے!) اﷲ کے ساتھ دوسرا معبود نہ بنا (ورنہ) تو ملامت زدہ (اور) بے یار و مددگار ہو کر بیٹھا رہ جائے گا،\qt@no{22}}%
\qt@newcmd\qurantrans@ur@mmlii{اور آپ کے رب نے حکم فرما دیا ہے کہ تم اﷲ کے سوا کسی کی عبادت مت کرو اور والدین کے ساتھ حسنِ سلوک کیا کرو، اگر تمہارے سامنے دونوں میں سے کوئی ایک یا دونوں بڑھاپے کو پہنچ جائیں تو انہیں ”اُف“ بھی نہ کہنا اور انہیں جھڑکنا بھی نہیں اور ان دونوں کے ساتھ بڑے ادب سے بات کیا کرو،\qt@no{23}}%
\qt@newcmd\qurantrans@ur@mmliii{اور ان دونوں کے لئے نرم دلی سے عجز و انکساری کے بازو جھکائے رکھو اور (اﷲ کے حضور) عرض کرتے رہو: اے میرے رب! ان دونوں پر رحم فرما جیسا کہ انہوں نے بچپن میں مجھے (رحمت و شفقت سے) پالا تھا،\qt@no{24}}%
\qt@newcmd\qurantrans@ur@mmliv{تمہارا رب ان (باتوں) سے خوب آگاہ ہے جو تمہارے دلوں میں ہیں، اگر تم نیک سیرت ہو جاؤ تو بیشک وہ (اﷲ اپنی طرف) رجوع کرنے والوں کو بہت بخشنے والا ہے،\qt@no{25}}%
\qt@newcmd\qurantrans@ur@mmlv{اور قرابت داروں کو ان کا حق ادا کرو اور محتاجوں اور مسافروں کو بھی (دو) اور (اپنا مال) فضول خرچی سے مت اڑاؤ،\qt@no{26}}%
\qt@newcmd\qurantrans@ur@mmlvi{بیشک فضول خرچی کرنے والے شیطان کے بھائی ہیں، اور شیطان اپنے رب کا بڑا ہی ناشکرا ہے،\qt@no{27}}%
\qt@newcmd\qurantrans@ur@mmlvii{اور اگر تم (اپنی تنگ دستی کے باعث) ان (مستحقین) سے گریز کرنا چاہتے ہو اپنے رب کی جانب سے رحمت (خوش حالی) کے انتظار میں جس کی تم توقع رکھتے ہو تو ان سے نرمی کی بات کہہ دیا کرو،\qt@no{28}}%
\qt@newcmd\qurantrans@ur@mmlviii{اور نہ اپنا ہاتھ اپنی گردن سے باندھا ہوا رکھو (کہ کسی کو کچھ نہ دو) اور نہ ہی اسے سارا کا سارا کھول دو (کہ سب کچھ ہی دے ڈالو) کہ پھر تمہیں خود ملامت زدہ (اور) تھکا ہارا بن کر بیٹھنا پڑے،\qt@no{29}}%
\qt@newcmd\qurantrans@ur@mmlix{بیشک آپ کا رب جس کے لئے چاہتاہے رزق کشادہ فرما دیتا ہے اور (جس کے لئے چاہتا ہے) تنگ کر دیتا ہے، بیشک وہ اپنے بندوں (کے اعمال و احوال) کی خوب خبر رکھنے والا خوب دیکھنے والا ہے،\qt@no{30}}%
\qt@newcmd\qurantrans@ur@mmlx{اور تم اپنی اولاد کو مفلسی کے خوف سے قتل مت کرو، ہم ہی انہیں (بھی) روزی دیتے ہیں اور تمہیں بھی، بیشک ان کو قتل کرنا بہت بڑا گناہ ہے،\qt@no{31}}%
\qt@newcmd\qurantrans@ur@mmlxi{اور تم زنا (بدکاری) کے قریب بھی مت جانا بیشک یہ بے حیائی کا کام ہے، اور بہت ہی بری راہ ہے،\qt@no{32}}%
\qt@newcmd\qurantrans@ur@mmlxii{اور تم کسی جان کو قتل مت کرنا جسے (قتل کرنا) اﷲ نے حرام قرار دیا ہے سوائے اس کے کہ (اس کا قتل کرنا شریعت کی رُو سے) حق ہو، اور جو شخص ظلماً قتل کردیا گیا تو بیشک ہم نے اس کے وارث کے لئے (قصاص کا) حق مقرر کر دیا ہے سو وہ بھی (قصاص کے طور پر بدلہ کے) قتل میں حد سے تجاوز نہ کرے، بیشک وہ (اﷲ کی طرف سے) مدد یافتہ ہے (سو اس کی مدد و حمایت کی ذمہ داری حکومت پر ہوگی)،\qt@no{33}}%
\qt@newcmd\qurantrans@ur@mmlxiii{اور تم یتیم کے مال کے (بھی) قریب تک نہ جانا مگر ایسے طریقہ سے جو (یتیم کے لئے) بہتر ہو یہاں تک کہ وہ اپنی جوانی کو پہنچ جائے، اور وعدہ پورا کیا کرو، بیشک وعدہ کی ضرور پوچھ گچھ ہوگی،\qt@no{34}}%
\qt@newcmd\qurantrans@ur@mmlxiv{اور ناپ پورا رکھا کرو جب (بھی) تم (کوئی چیز) ناپو اور (جب تولنے لگو تو) سیدھے ترازو سے تولا کرو، یہ (دیانت داری) بہتر ہے اور انجام کے اعتبار سے (بھی) خوب تر ہے،\qt@no{35}}%
\qt@newcmd\qurantrans@ur@mmlxv{اور (اے انسان!) تو اس بات کی پیروی نہ کر جس کا تجھے (صحیح) علم نہیں، بیشک کان اور آنکھ اور دل ان میں سے ہر ایک سے باز پرس ہوگی،\qt@no{36}}%
\qt@newcmd\qurantrans@ur@mmlxvi{اور زمین میں اکڑ کر مت چل، بیشک تو زمین کو (اپنی رعونت کے زور سے) ہرگز چیر نہیں سکتا اور نہ ہی ہرگز تو بلندی میں پہاڑوں کو پہنچ سکتا ہے (تو جو کچھ ہے وہی رہے گا)،\qt@no{37}}%
\qt@newcmd\qurantrans@ur@mmlxvii{ان سب (مذکورہ) باتوں کی برائی تیرے رب کو بڑی ناپسند ہے،\qt@no{38}}%
\qt@newcmd\qurantrans@ur@mmlxviii{یہ حکمت و دانائی کی ان باتوں میں سے ہے جو آپ کے رب نے آپ کی طرف وحی فرمائی ہیں، اور (اے انسان!) اﷲ کے ساتھ کوئی دوسرا معبود نہ ٹھہرا (ورنہ) تو ملامت زدہ (اور اﷲ کی رحمت سے) دھتکارا ہوا ہو کر دوزخ میں جھونک دیا جائے گا،\qt@no{39}}%
\qt@newcmd\qurantrans@ur@mmlxix{اے مشرکو! خود سوچو!) بھلا تمہیں تو تمہارے رب نے بیٹوں کے لئے چن لیا ہے اور (اپنے لئے) اس نے فرشتوں کو بیٹیاں بنا لیا ہے، بیشک تم (اپنے ہی گھڑے ہوئے خیالات کے پیمانہ پر) بڑی سخت بات کہتے ہو،\qt@no{40}}%
\qt@newcmd\qurantrans@ur@mmlxx{اور بیشک ہم نے اس قرآن میں (حقائق اور نصائح کو) انداز بدل کر بار بار بیان کیا ہے تاکہ لوگ نصیحت حاصل کریں، مگر (منکرین کا عالم یہ ہے کہ) اس سے ان کی نفرت ہی مزید بڑھتی جاتی ہے،\qt@no{41}}%
\qt@newcmd\qurantrans@ur@mmlxxi{فرما دیجئے: اگر اس کے ساتھ کچھ اور بھی معبود ہوتے جیسا کہ وہ (کفار و مشرکین) کہتے ہیں تو وہ (مل کر) مالکِ عرش تک پہنچنے (یعنی اس کے نظامِ اقتدار میں دخل اندازی کرنے) کا کوئی راستہ ضرور تلاش کرلیتے،\qt@no{42}}%
\qt@newcmd\qurantrans@ur@mmlxxii{وہ پاک ہے اور ان باتوں سے جو وہ کہتے رہتے ہیں بہت ہی بلند و برتر ہے،\qt@no{43}}%
\qt@newcmd\qurantrans@ur@mmlxxiii{ساتوں آسمان اور زمین اور وہ سارے موجودات جو ان میں ہیں اﷲ کی تسبیح کرتے رہتے ہیں، اور (جملہ کائنات میں) کوئی بھی چیز ایسی نہیں جو اس کی حمد کے ساتھ تسبیح نہ کرتی ہو لیکن تم ان کی تسبیح (کی کیفیت) کو سمجھ نہیں سکتے، بیشک وہ بڑا بُردبار بڑا بخشنے والا ہے،\qt@no{44}}%
\qt@newcmd\qurantrans@ur@mmlxxiv{اور جب آپ قرآن پڑھتے ہیں (تو) ہم آپ کے اور ان لوگوں کے درمیان جو آخرت پر ایمان نہیں رکھتے ایک پوشیدہ پردہ حائل کر دیتے ہیں،\qt@no{45}}%
\qt@newcmd\qurantrans@ur@mmlxxv{اور ہم ان کے دلوں پر (بھی) پردے ڈال دیتے ہیں تاکہ وہ اسے سمجھ (نہ) سکیں اور ان کے کانوں میں بوجھ پیدا کر دیتے ہیں (تاکہ اسے سن نہ سکیں)، اور جب آپ قرآن میں اپنے رب کا تنہا ذکر کرتے ہیں (ان کے بتوں کا نام نہیں آتا) تو وہ نفرت کرتے ہوئے پیٹھ پھیر کر بھاگ کھڑے ہوتے ہیں،\qt@no{46}}%
\qt@newcmd\qurantrans@ur@mmlxxvi{ہم خوب جانتے ہیں یہ جس مقصد کے لئے دھیان سے سنتے ہیں جب یہ آپ کی طرف کان لگاتے ہیں اور جب یہ سرگوشیاں کرتے ہیں جب یہ ظالم لوگ (مسلمانوں سے) کہتے ہیں کہ تم تو محض ایک ایسے شخص کی پیروی کر رہے ہو جو سحر زدہ ہے (یعنی اس پر جادو کردیا گیا ہے تو ہم یہ سب کچھ دیکھ اور سن رہے ہوتے ہیں)،\qt@no{47}}%
\qt@newcmd\qurantrans@ur@mmlxxvii{اے حبیب!) دیکھئے (یہ لوگ) آپ کے لئے کیسی (کیسی) تشبیہیں دیتے ہیں پس یہ گمراہ ہو چکے، اب راہِ راست پر نہیں آسکتے،\qt@no{48}}%
\qt@newcmd\qurantrans@ur@mmlxxviii{اور کہتے ہیں: جب ہم (مَر کر بوسیدہ) ہڈیاں اور ریزہ ریزہ ہو جائیں گے تو کیا ہمیں اَز سرِ نو پیدا کر کے اٹھایا جائے گا،\qt@no{49}}%
\qt@newcmd\qurantrans@ur@mmlxxix{فرما دیجئے: تم پتھر ہو جاؤ یا لوہا،\qt@no{50}}%
\qt@newcmd\qurantrans@ur@mmlxxx{یا کوئی ایسی مخلوق جو تمہارے خیال میں (ان چیزوں سے بھی) زیادہ سخت ہو (کہ اس میں زندگی پانے کی بالکل صلاحیت ہی نہ ہو)، پھر وہ (اس حال میں) کہیں گے کہ ہمیں کون دوبارہ زندہ کرے گا؟ فرما دیجئے: وہی جس نے تمہیں پہلی بار پیدا فرمایا تھا، پھر وہ (تعجب اور تمسخر کے طور پر) آپ کے سامنے اپنے سر ہلا دیں گے اور کہیں گے: یہ کب ہوگا؟ فرما دیجئے: امید ہے جلد ہی ہو جائے گا،\qt@no{51}}%
\qt@newcmd\qurantrans@ur@mmlxxxi{جس دن وہ تمہیں پکارے گا تو تم اس کی حمد کے ساتھ جواب دو گے اور خیال کرتے ہوگے کہ تم (دنیا میں) بہت تھوڑا عرصہ ٹھہرے ہو،\qt@no{52}}%
\qt@newcmd\qurantrans@ur@mmlxxxii{اور آپ میرے بندوں سے فرما دیں کہ وہ ایسی باتیں کیا کریں جو بہتر ہوں، بیشک شیطان لوگوں کے درمیان فساد بپا کرتا ہے، یقینا شیطان انسان کا کھلا دشمن ہے،\qt@no{53}}%
\qt@newcmd\qurantrans@ur@mmlxxxiii{تمہارا رب تمہارے حال سے بہتر واقف ہے، اگر چاہے تم پر رحم فرما دے یا اگر چاہے تم پر عذاب کرے، اور ہم نے آپ کو ان پر (ان کے امور کا) ذمہ دار بنا کر نہیں بھیجا،\qt@no{54}}%
\qt@newcmd\qurantrans@ur@mmlxxxiv{اور آپ کا رب ان کو خوب جانتا ہے جو آسمانوں اور زمین میں (آباد) ہیں، اور بیشک ہم نے بعض انبیاء کو بعض پر فضیلت بخشی اور ہم نے داؤد (علیہ السلام) کو زبور عطا کی،\qt@no{55}}%
\qt@newcmd\qurantrans@ur@mmlxxxv{فرما دیجئے: تم ان سب کو بلا لو جنہیں تم اﷲ کے سوا (معبود) گمان کرتے ہو وہ تم سے تکلیف دور کرنے پر قادر نہیں ہیں اور نہ (اسے دوسروں کی طرف) پھیر دینے کا (اختیار رکھتے ہیں)،\qt@no{56}}%
\qt@newcmd\qurantrans@ur@mmlxxxvi{یہ لوگ جن کی عبادت کرتے ہیں (یعنی ملائکہ، جنّات، عیسٰی اور عزیر علیہما السلام وغیرھم کے بت اور تصویریں بنا کر انہیں پوجتے ہیں) وہ (تو خود ہی) اپنے رب کی طرف وسیلہ تلاش کرتے ہیں کہ ان میں سے (بارگاہِ الٰہی میں) زیادہ مقرّب کون ہے اور (وہ خود) اس کی رحمت کے امیدوار ہیں اور (وہ خود ہی) اس کے عذاب سے ڈرتے رہتے ہیں، (اب تم ہی بتاؤ کہ وہ معبود کیسے ہو سکتے ہیں وہ تو خود معبودِ برحق کے سامنے جھک رہے ہیں)، بیشک آپ کے رب کا عذاب ڈرنے کی چیز ہے،\qt@no{57}}%
\qt@newcmd\qurantrans@ur@mmlxxxvii{اور (کفر و سرکشی کرنے والوں کی) کوئی بستی ایسی نہیں مگر ہم اسے روزِ قیامت سے قبل ہی تباہ کر دیں گے یا اسے نہایت ہی سخت عذاب دیں گے، یہ (امر) کتاب (لوحِ محفوظ) میں لکھا ہوا ہے،\qt@no{58}}%
\qt@newcmd\qurantrans@ur@mmlxxxviii{اور ہم کو (اب بھی ان کے مطالبہ پر) نشانیاں بھیجنے سے (کسی چیز نے) منع نہیں کیا سوائے اس کے کہ ان ہی (نشانیوں) کو پہلے لوگوں نے جھٹلا دیا تھا (سو اس کے بعد وہ فوراً تباہ و برباد کر دیئے گئے اور کوئی مہلت باقی نہ رہی، اے حبیب! ہم آپ کی بِعثت کے بعد آپ کی قوم سے یہ معاملہ نہیں کرنا چاہتے)، اور ہم نے قومِ ثمود کو (صالح علیہ السلام کی) اونٹنی (کی) کھلی نشانی دی تھی تو انہوں نے اس پر ظلم کیا، اور ہم نشانیاں نہیں بھیجا کرتے مگر (عذاب کی آمد سے قبل آخری بار) خوفزدہ کرنے کے لئے (پھر جب اس نشانی کا انکار ہو جاتا ہے تو اسی وقت تباہ کن عذاب بھیج دیا جاتا ہے)،\qt@no{59}}%
\qt@newcmd\qurantrans@ur@mmlxxxix{اور (یاد کیجئے) جب ہم نے آپ سے فرمایا کہ بیشک آپ کے رب نے (سب) لوگوں کو (اپنے علم و قدرت کے) احاطہ میں لے رکھا ہے، اور ہم نے تو (شبِ معراج کے) اس نظّارہ کو جو ہم نے آپ کو دکھایا لوگوں کے لئے صرف ایک آزمائش بنایا ہے (ایمان والے مان گئے اور ظاہر بین الجھ گئے) اور اس درخت (شجرۃ الزقوم) کو بھی جس پر قرآن میں لعنت کی گئی ہے، اور ہم انہیں ڈراتے ہیں مگر یہ (ڈرانا بھی) ان میں کوئی اضافہ نہیں کرتا سوائے اور بڑی سرکشی کے،\qt@no{60}}%
\qt@newcmd\qurantrans@ur@mmxc{اور (وہ وقت یاد کیجئے) جب ہم نے فرشتوں سے فرمایا کہ تم آدم (علیہ السلام) کو سجدہ کرو تو ابلیس کے سوا سب نے سجدہ کیا، اس نے کہا: کیا میں اسے سجدہ کروں جسے تو نے مٹی سے پیدا کیا ہے،\qt@no{61}}%
\qt@newcmd\qurantrans@ur@mmxci{اور شیطان یہ بھی) کہنے لگا: مجھے بتا تو سہی کہ یہ وہ شخص ہے جسے تو نے مجھ پر فضیلت دی ہے (آخر اس کی کیا وجہ ہے؟) اگر تو مجھے قیامت کے دن تک مہلت دے دے تو میں اس کی اولاد کو سوائے چند افراد کے (اپنے قبضہ میں لے کر) جڑ سے اکھاڑ دوں گا،\qt@no{62}}%
\qt@newcmd\qurantrans@ur@mmxcii{اﷲ نے فرمایا: جا (تجھے مہلت ہے) پس ان میں سے جو بھی تیری پیروی کرے گا تو بیشک دوزخ (ہی) تم سب کی پوری پوری سزا ہے،\qt@no{63}}%
\qt@newcmd\qurantrans@ur@mmxciii{اور جس پر بھی تیرا بس چل سکتا ہے تو (اسے) اپنی آواز سے ڈگمگا لے اور ان پر اپنی (فوج کے) سوار اور پیادہ دستوں کو چڑھا دے اور ان کے مال و اولاد میں ان کا شریک بن جا اور ان سے (جھوٹے) وعدے کر، اور ان سے شیطان دھوکہ و فریب کے سوا (کوئی) وعدہ نہیں کرتا،\qt@no{64}}%
\qt@newcmd\qurantrans@ur@mmxciv{بیشک جو میرے بندے ہیں ان پر تیرا تسلط نہیں ہو سکے گا، اور تیرا رب ان (اﷲ والوں) کی کارسازی کے لئے کافی ہے،\qt@no{65}}%
\qt@newcmd\qurantrans@ur@mmxcv{تمہارا رب وہ ہے جو سمندر (اور دریا) میں تمہارے لئے (جہاز اور) کشتیاں رواں فرماتا ہے تاکہ تم (اندرونی و بیرونی تجارت کے ذریعہ) اس کا فضل (یعنی رزق) تلاش کرو، بیشک وہ تم پر بڑا مہربان ہے،\qt@no{66}}%
\qt@newcmd\qurantrans@ur@mmxcvi{اور جب سمندر میں تمہیں کوئی مصیبت لاحق ہوتی ہے تو وہ (سب بت تمہارے ذہنوں سے) گم ہو جاتے ہیں جن کی تم پرستش کرتے رہتے ہو سوائے اسی (اﷲ) کے (جسے تم اس وقت یاد کرتے ہو)، پھر جب وہ (اﷲ) تمہیں بچا کر خشکی کی طرف لے جاتا ہے (تو پھر اس سے) رُوگردانی کرنے لگتے ہو، اور انسان بڑا ناشکرا واقع ہوا ہے،\qt@no{67}}%
\qt@newcmd\qurantrans@ur@mmxcvii{کیا تم اس بات سے بے خوف ہو گئے ہو کہ وہ تمہیں خشکی کے کنارے پر ہی (زمین میں) دھنسا دے یا تم پر پتھر برسانے والی آندھی بھیج دے پھر تم اپنے لئے کوئی کارساز نہ پاسکو گے،\qt@no{68}}%
\qt@newcmd\qurantrans@ur@mmxcviii{یا تم اس بات سے بے خوف ہوگئے ہو کہ وہ تمہیں دوبارہ اس (سمندر) میں پلٹا کر لے جائے اور تم پر کشتیاں توڑ دینے والی آندھی بھیج دے پھر تمہیں اس کفر کے باعث جو تم کرتے تھے (سمندر میں) غرق کر دے پھر تم اپنے لئے اس (ڈبونے) پر ہم سے مؤاخذہ کرنے والا کوئی نہیں پاؤ گے،\qt@no{69}}%
\qt@newcmd\qurantrans@ur@mmxcix{اور بیشک ہم نے بنی آدم کو عزت بخشی اور ہم نے ان کو خشکی اور تری (یعنی شہروں اور صحراؤں اور سمندروں اور دریاؤں) میں (مختلف سواریوں پر) سوار کیا اور ہم نے انہیں پاکیزہ چیزوں سے رزق عطا کیا اور ہم نے انہیں اکثر مخلوقات پر جنہیں ہم نے پیدا کیا ہے فضیلت دے کر برتر بنا دیا،\qt@no{70}}%
\qt@newcmd\qurantrans@ur@mmc{وہ دن (یاد کریں) جب ہم لوگوں کے ہر طبقہ کو ان کے پیشوا کے ساتھ بلائیں گے، سو جسے اس کا نوشتۂ اَعمال اس کے دائیں ہاتھ میں دیا جائے گا پس یہ لوگ اپنا نامۂ اعمال (مسرت و شادمانی سے) پڑھیں گے اور ان پر دھاگے برابر بھی ظلم نہیں کیا جائے گا،\qt@no{71}}%
\qt@newcmd\qurantrans@ur@mmci{اور جو شخص اس (دنیا) میں (حق سے) اندھا رہا سو وہ آخرت میں بھی اندھا اور راہِ (نجات) سے بھٹکا رہے گا،\qt@no{72}}%
\qt@newcmd\qurantrans@ur@mmcii{اور کفار تو یہی چاہتے تھے کہ آپ کو اس (حکمِ الٰہی) سے پھیر دیں جس کی ہم نے آپ کی طرف وحی فرمائی ہے تاکہ آپ اس (وحی) کے سوا ہم پر کچھ اور (باتوں) کو منسوب کر دیں اور تب آپ کو اپنا دوست بنا لیں،\qt@no{73}}%
\qt@newcmd\qurantrans@ur@mmciii{اور اگر ہم نے آپ کو (پہلے ہی سے عصمتِ نبوت کے ذریعہ) ثابت قدم نہ بنایا ہوتا تو تب بھی آپ ان کی طرف (اپنے پاکیزہ نفس اور طبعی استعداد کے باعث) بہت ہی معمولی سے جھکاؤ کے قریب جاتے۔(ان کی طرف پھر بھی زیادہ مائل نہ ہوتے اور وہ ناکام رہتے مگر اﷲ نے آپ کو عصمتِ نبوت کے ذریعہ اس معمولی سے میلان کے قریب جانے سے بھی محفوظ فرما لیا ہے)،\qt@no{74}}%
\qt@newcmd\qurantrans@ur@mmciv{اگر بالفرض آپ مائل ہو جاتے تو) اس وقت ہم آپ کو دوگنا مزہ زندگی میں اور دوگنا موت میں چکھاتے پھر آپ اپنے لئے (بھی) ہم پر کوئی مدد گار نہ پاتے،\qt@no{75}}%
\qt@newcmd\qurantrans@ur@mmcv{اور کفار یہ بھی چاہتے تھے کہ آپ کے قدم سرزمینِ (مکّہ) سے اکھاڑ دیں تاکہ وہ آپ کو یہاں سے نکال سکیں اور (اگر بالفرض ایسا ہو جاتا تو) اس وقت وہ (خود بھی) آپ کے پیچھے تھوڑی سی مدت کے سوا ٹھہر نہ سکتے،\qt@no{76}}%
\qt@newcmd\qurantrans@ur@mmcvi{ان سب رسولوں (کے لئے اﷲ) کا دستور (یہی رہا ہے) جنہیں ہم نے آپ سے پہلے بھیجا تھا اور آپ ہمارے دستور میں کوئی تبدیلی نہیں پائیں گے،\qt@no{77}}%
\qt@newcmd\qurantrans@ur@mmcvii{آپ سورج ڈھلنے سے لے کر رات کی تاریکی تک (ظہر، عصر، مغرب اور عشاء کی) نماز قائم فرمایا کریں اور نمازِ فجر کا قرآن پڑھنا بھی (لازم کر لیں)، بیشک نمازِ فجر کے قرآن میں (فرشتوں کی) حاضری ہوتی ہے (اور حضوری بھی نصیب ہوتی ہے)،\qt@no{78}}%
\qt@newcmd\qurantrans@ur@mmcviii{اور رات کے کچھ حصہ میں (بھی قرآن کے ساتھ شب خیزی کرتے ہوئے) نماز تہجد پڑھا کریں یہ خاص آپ کے لئے زیادہ (کی گئی) ہے، یقیناً آپ کا رب آپ کو مقامِ محمود پر فائز فرمائے گا (یعنی وہ مقامِ شفاعتِ عظمٰی جہاں جملہ اوّلین و آخرین آپ کی طرف رجوع اور آپ کی حمد کریں گے)،\qt@no{79}}%
\qt@newcmd\qurantrans@ur@mmcix{اور آپ (اپنے رب کے حضور یہ) عرض کرتے رہیں: اے میرے رب! مجھے سچائی (خوشنودی) کے ساتھ داخل فرما (جہاں بھی داخل فرمانا ہو) اور مجھے سچائی (و خوشنودی) کے ساتھ باہر لے آ(جہاں سے بھی لانا ہو) اور مجھے اپنی جانب سے مددگار غلبہ و قوت عطا فرما دے،\qt@no{80}}%
\qt@newcmd\qurantrans@ur@mmcx{اور فرما دیجئے: حق آگیا اور باطل بھاگ گیا، بیشک باطل نے زائل و نابود ہی ہو جانا ہے،\qt@no{81}}%
\qt@newcmd\qurantrans@ur@mmcxi{اور ہم قرآن میں وہ چیز نازل فرما رہے ہیں جو ایمان والوں کے لئے شفاء اور رحمت ہے اور ظالموں کے لئے تو صرف نقصان ہی میں اضافہ کر رہا ہے،\qt@no{82}}%
\qt@newcmd\qurantrans@ur@mmcxii{اور جب ہم انسان پر (کوئی) انعام فرماتے ہیں تو وہ (شکر سے) گریز کرتا اور پہلو تہی کر جاتا ہے اور جب اسے کوئی تکلیف پہنچ جاتی ہے تو مایوس ہو جاتا ہے (گویا نہ شاکر ہے نہ صابر)،\qt@no{83}}%
\qt@newcmd\qurantrans@ur@mmcxiii{فرما دیجئے: ہر کوئی (اپنے) اپنے طریقہ و فطرت پر عمل پیرا ہے، اور آپ کا رب خوب جانتا ہے کہ سب سے زیادہ سیدھی راہ پر کون ہے،\qt@no{84}}%
\qt@newcmd\qurantrans@ur@mmcxiv{اور یہ (کفّار) آپ سے روح کے متعلق سوال کرتے ہیں، فرما دیجئے: روح میرے رب کے اَمر سے ہے اور تمہیں بہت ہی تھوڑا سا علم دیا گیا ہے،\qt@no{85}}%
\qt@newcmd\qurantrans@ur@mmcxv{اور اگر ہم چاہیں تو اس (کتاب) کو جو ہم نے آپ کی طرف وحی فرمائی ہے (لوگوں کے دلوں اور تحریری نسخوں سے) محو فرما دیں پھر آپ اپنے لئے اس (وحی) کے لے جانے پر ہماری بارگاہ میں کوئی وکالت کرنے والا بھی نہ پائیں گے،\qt@no{86}}%
\qt@newcmd\qurantrans@ur@mmcxvi{مگر یہ کہ آپ کے رب کی رحمت سے (ہم نے اسے قائم رکھا ہے)، بیشک (یہ) آپ پر (اور آپ کے وسیلہ سے آپ کی امّت پر)اس کا بہت بڑا فضل ہے،\qt@no{87}}%
\qt@newcmd\qurantrans@ur@mmcxvii{فرما دیجئے: اگر تمام انسان اور جنّات اس بات پر جمع ہو جائیں کہ وہ اس قرآن کے مثل (کوئی دوسرا کلام بنا) لائیں گے تو (بھی) وہ اس کی مثل نہیں لاسکتے اگرچہ وہ ایک دوسرے کے مددگار بن جائیں،\qt@no{88}}%
\qt@newcmd\qurantrans@ur@mmcxviii{اور بیشک ہم نے اس قرآن میں لوگوں کے لئے ہر طرح کی مثال (مختلف طریقوں سے) بار بار بیان کی ہے مگر اکثر لوگوں نے (اسے) قبول نہ کیا (یہ) سوائے ناشکری کے (اور کچھ نہیں)،\qt@no{89}}%
\qt@newcmd\qurantrans@ur@mmcxix{اور وہ (کفّارِ مکّہ) کہتے ہیں کہ ہم آپ پر ہرگز ایمان نہیں لائیں گے یہاں تک کہ آپ ہمارے لئے زمین سے کوئی چشمہ جاری کر دیں،\qt@no{90}}%
\qt@newcmd\qurantrans@ur@mmcxx{یا آپ کے پاس کھجوروں اور انگوروں کا کوئی باغ ہو تو آپ اس کے اندر بہتی ہوئی نہریں جاری کردیں،\qt@no{91}}%
\qt@newcmd\qurantrans@ur@mmcxxi{یا جیسا کہ آپ کا خیال ہے ہم پر (ابھی) آسمان کے چند ٹکڑے گرا دیں یا آپ اﷲ کو اور فرشتوں کو ہمارے سامنے لے آئیں،\qt@no{92}}%
\qt@newcmd\qurantrans@ur@mmcxxii{یا آپ کا کوئی سونے کا گھر ہو (جس میں آپ خوب عیش سے رہیں) یا آپ آسمان پر چڑھ جائیں، پھر بھی ہم آپ کے (آسمان میں) چڑھ جانے پر ہرگز ایمان نہیں لائیں گے یہاں تک کہ آپ (وہاں سے) ہمارے اوپر کوئی کتاب اتار لائیں جسے ہم (خود) پڑھ سکیں، فرما دیجئے: میرا رب (ان خرافات میں الجھنے سے) پاک ہے میں تو ایک انسان (اور) اﷲ کا بھیجا ہوا (رسول) ہوں،\qt@no{93}}%
\qt@newcmd\qurantrans@ur@mmcxxiii{اور (ان) لوگوں کو ایمان لانے سے اور کوئی چیز مانع نہ ہوئی جبکہ ان کے پاس ہدایت (بھی) آچکی تھی سوائے اس کے کہ وہ کہنے لگے: کیا اﷲ نے (ایک) بشر کو رسول بنا کر بھیجا ہے،\qt@no{94}}%
\qt@newcmd\qurantrans@ur@mmcxxiv{فرما دیجئے: اگر زمین میں (انسانوں کی بجائے) فرشتے چلتے پھرتے سکونت پذیر ہوتے تو یقیناً ہم (بھی) ان پر آسمان سے کسی فرشتہ کو رسول بنا کر اتارتے،\qt@no{95}}%
\qt@newcmd\qurantrans@ur@mmcxxv{فرما دیجئے: میرے اور تمہارے درمیان اﷲ ہی گواہ کے طور پر کافی ہے، بیشک وہ اپنے بندوں سے خوب آگاہ خوب دیکھنے والا ہے،\qt@no{96}}%
\qt@newcmd\qurantrans@ur@mmcxxvi{اور اﷲ جسے ہدایت فرما دے تو وہی ہدایت یافتہ ہے، اور جسے وہ گمراہ ٹھہرا دے تو آپ ان کے لئے اس کے سوا مددگار نہیں پائیں گے، اور ہم انہیں قیامت کے دن اوندھے منہ اٹھائیں گے اس حال میں کہ وہ اندھے، گونگے اور بہرے ہوں گے، ان کا ٹھکانا دوزخ ہے، جب بھی وہ بجھنے لگے گی ہم انہیں (عذاب دینے کے لئے) اور زیادہ بھڑکا دیں گے،\qt@no{97}}%
\qt@newcmd\qurantrans@ur@mmcxxvii{یہ ان لوگوں کی سزا ہے اس وجہ سے کہ انہوں نے ہماری آیتوں سے کفر کیا اور یہ کہتے رہے کہ کیا جب ہم (مَر کر بوسیدہ) ہڈیاں اور ریزہ ریزہ ہو جائیں گے تو کیا ہم اَز سرِ نو پیدا کر کے اٹھائے جائیں گے؟،\qt@no{98}}%
\qt@newcmd\qurantrans@ur@mmcxxviii{کیا انہوں نے نہیں دیکھا کہ جس اﷲ نے آسمانوں اور زمین کو پیدا فرمایا ہے (وہ) اس بات پر (بھی) قادر ہے کہ وہ ان لوگوں کی مثل (دوبارہ) پیدا فرما دے اور اس نے ان کے لئے ایک وقت مقرر فرما دیا ہے جس میں کوئی شک نہیں، پھر بھی ظالموں نے انکار کردیا ہے مگر (یہ) ناشکری ہے،\qt@no{99}}%
\qt@newcmd\qurantrans@ur@mmcxxix{فرما دیجئے: اگر تم میرے رب کی رحمت کے خزانوں کے مالک ہوتے تو تب بھی (سب) خرچ ہوجانے کے خوف سے تم (اپنے ہاتھ) روکے رکھتے، اور انسان بہت ہی تنگ دل اور بخیل واقع ہوا ہے،\qt@no{100}}%
\qt@newcmd\qurantrans@ur@mmcxxx{اور بیشک ہم نے موسٰی (علیہ السلام) کو نو روشن نشانیاں دیں تو آپ بنی اسرائیل سے پوچھیئے جب (موسٰی علیہ السلام) ان کے پاس آئے تو فرعون نے ان سے کہا: میں تو یہی خیال کرتا ہوں کہ اے موسٰی! تم سحر زدہ ہو (تمہیں جادو کر دیا گیا ہے)،\qt@no{101}}%
\qt@newcmd\qurantrans@ur@mmcxxxi{موسٰی (علیہ السلام) نے فرمایا: تو (دل سے) جانتا ہے کہ ان نشانیوں کو کسی اور نے نہیں اتارا مگر آسمانوں اور زمین کے رب نے عبرت و بصیرت بنا کر، اور میں تو یہی خیال کرتا ہوں کہ اے فرعون! تم ہلاک زدہ ہو (تو جلدی ہلاک ہوا چاہتا ہے)،\qt@no{102}}%
\qt@newcmd\qurantrans@ur@mmcxxxii{پھر (فرعون نے) ارادہ کیا کہ ان کو (یعنی موسٰی علیہ السلام اور ان کی قوم کو) سر زمینِ (مصر) سے اکھاڑ کر پھینک دے پس ہم نے اسے اور جو اس کے ساتھ تھے سب کو غرق کردیا،\qt@no{103}}%
\qt@newcmd\qurantrans@ur@mmcxxxiii{اور ہم نے اس کے بعد بنی اسرائیل سے فرمایا: تم اس ملک میں آباد ہو جاؤ پھر جب آخرت کا وعدہ آجائے گا (تو) ہم تم سب کو اکٹھا سمیٹ کر لے جائیں گے،\qt@no{104}}%
\qt@newcmd\qurantrans@ur@mmcxxxiv{اور حق کے ساتھ ہی ہم نے اس (قرآن) کو اتارا ہے اور حق ہی کے ساتھ وہ اترا ہے، اور (اے حبیبِ مکرّم!) ہم نے آپ کو خوشخبری سنانے والا اور ڈر سنانے والا ہی بنا کر بھیجا ہے،\qt@no{105}}%
\qt@newcmd\qurantrans@ur@mmcxxxv{اور قرآن کو ہم نے جدا جدا کر کے اتارا تاکہ آپ اسے لوگوں پر ٹھہر ٹھہر کر پڑھیں اور ہم نے اسے رفتہ رفتہ (حالات اور مصالح کے مطابق) تدریجاً اتارا ہے،\qt@no{106}}%
\qt@newcmd\qurantrans@ur@mmcxxxvi{فرما دیجئے: تم اس پر ایمان لاؤ یا ایمان نہ لاؤ، بیشک جن لوگوں کو اس سے قبل علمِ (کتاب) عطا کیا گیا تھا جب یہ (قرآن) انہیں پڑھ کر سنایا جاتا ہے وہ ٹھوڑیوں کے بل سجدہ میں گر پڑتے ہیں،\qt@no{107}}%
\qt@newcmd\qurantrans@ur@mmcxxxvii{اور کہتے ہیں: ہمارا رب پاک ہے، بیشک ہمارے رب کا وعدہ پورا ہو کر ہی رہنا تھا،\qt@no{108}}%
\qt@newcmd\qurantrans@ur@mmcxxxviii{اور ٹھوڑیوں کے بل گریہ و زاری کرتے ہوئے گر جاتے ہیں، اور یہ (قرآن) ان کے خشوع و خضوع میں مزید اضافہ کرتا چلا جاتا ہے،\qt@no{109}}%
\qt@newcmd\qurantrans@ur@mmcxxxix{فرما دیجئے کہ اﷲ کو پکارو یا رحمان کو پکارو، جس نام سے بھی پکارتے ہو (سب) اچھے نام اسی کے ہیں، اور نہ اپنی نماز (میں قرات) بلند آواز سے کریں اور نہ بالکل آہستہ پڑھیں اور دونوں کے درمیان (معتدل) راستہ اختیار فرمائیں،\qt@no{110}}%
\qt@newcmd\qurantrans@ur@mmcxl{اور فرمائیے کہ سب تعریفیں اﷲ ہی کے لئے ہیں جس نے نہ تو (اپنے لئے) کوئی بیٹا بنایا اور نہ ہی (اس کی) سلطنت و فرمانروائی میں کوئی شریک ہے اور نہ کمزوری کے باعث اس کا کوئی مددگار ہے (اے حبیب!) آپ اسی کو بزرگ تر جان کر اس کی خوب بڑائی (بیان) کرتے رہئے،\qt@no{111}}%
\qt@newcmd\qurantrans@ur@mmcxli{\basmalahur تمام تعریفیں اﷲ ہی کے لئے ہیں جس نے اپنے (محبوب و مقرّب) بندے پر کتابِ (عظیم) نازل فرمائی اور اس میں کوئی کجی نہ رکھی،\qt@no{1}}%
\qt@newcmd\qurantrans@ur@mmcxlii{اسے) سیدھا اور معتدل (بنایا) تاکہ وہ (منکرین کو) اﷲ کی طرف سے (آنے والے) شدید عذاب سے ڈرائے اور مومنین کو جو نیک اعمال کرتے ہیں خوشخبری سنائے کہ ان کے لئے بہتر اجر (جنت) ہے،\qt@no{2}}%
\qt@newcmd\qurantrans@ur@mmcxliii{جس میں وہ ہمیشہ رہیں گے،\qt@no{3}}%
\qt@newcmd\qurantrans@ur@mmcxliv{اور (نیز) ان لوگوں کو ڈرائے جو کہتے ہیں کہ اﷲ نے (اپنے لئے) لڑکا بنا رکھا ہے،\qt@no{4}}%
\qt@newcmd\qurantrans@ur@mmcxlv{نہ اس کا کوئی علم انہیں ہے اور نہ ان کے باپ دادا کو تھا، (یہ) کتنا بڑا بول ہے جو ان کے منہ سے نکل رہا ہے، وہ (سراسر) جھوٹ کے سوا کچھ کہتے ہی نہیں،\qt@no{5}}%
\qt@newcmd\qurantrans@ur@mmcxlvi{اے حبیبِ مکرّم!) تو کیا آپ ان کے پیچھے شدتِ غم میں اپنی جانِ (عزیز بھی) گھلا دیں گے اگر وہ اس کلامِ (ربّانی) پر ایمان نہ لائے،\qt@no{6}}%
\qt@newcmd\qurantrans@ur@mmcxlvii{اور بیشک ہم نے اُن تمام چیزوں کو جو زمین پر ہیں اس کے لئے باعثِ زینت (و آرائش) بنایا تاکہ ہم ان لوگوں کو (جو زمین کے باسی ہیں) آزمائیں کہ ان میں سے بہ اِعتبارِ عمل کون بہتر ہے،\qt@no{7}}%
\qt@newcmd\qurantrans@ur@mmcxlviii{اور بیشک ہم اِن (تمام) چیزوں کو جو اس (روئے زمین) پر ہیں (نابود کر کے) بنجر میدان بنا دینے والے ہیں،\qt@no{8}}%
\qt@newcmd\qurantrans@ur@mmcxlix{کیا آپ نے یہ خیال کیا ہے کہ کہف و رقیم (یعنی غار اور لوحِ غار یا وادئ رقیم) والے ہماری (قدرت کی) نشانیوں میں سے (کتنی) عجیب نشانی تھے؟،\qt@no{9}}%
\qt@newcmd\qurantrans@ur@mmcl{وہ وقت یاد کیجئے) جب چند نوجوان غار میں پناہ گزیں ہوئے تو انہوں نے کہا: اے ہمارے رب! ہمیں اپنی بارگاہ سے رحمت عطا فرما اور ہمارے کام میں راہ یابی (کے اسباب) مہیا فرما،\qt@no{10}}%
\qt@newcmd\qurantrans@ur@mmcli{پس ہم نے اس غار میں گنتی کے چند سال ان کے کانوں پر تھپکی دے کر (انہیں سلا دیا)،\qt@no{11}}%
\qt@newcmd\qurantrans@ur@mmclii{پھر ہم نے انہیں اٹھا دیا کہ دیکھیں دونوں گروہوں میں سے کون اس (مدّت) کو صحیح شمار کرنے والا ہے جو وہ (غار میں) ٹھہرے رہے،\qt@no{12}}%
\qt@newcmd\qurantrans@ur@mmcliii{اب) ہم آپ کو ان کا حال صحیح صحیح سناتے ہیں، بیشک وہ (چند) نوجوان تھے جو اپنے رب پر ایمان لائے اور ہم نے ان کے لئے (نورِ) ہدایت میں اور اضافہ فرما دیا،\qt@no{13}}%
\qt@newcmd\qurantrans@ur@mmcliv{اور ہم نے ان کے دلوں کو (اپنے ربط و نسبت سے) مضبوط و مستحکم فرما دیا، جب وہ (اپنے بادشاہ کے سامنے) کھڑے ہوئے تو کہنے لگے: ہمارا رب تو آسمانوں اور زمین کا رب ہے ہم اس کے سوا ہرگز کسی (جھوٹے) معبود کی پرستش نہیں کریں گے (اگر ایسا کریں تو) اس وقت ہم ضرور حق سے ہٹی ہوئی بات کریں گے،\qt@no{14}}%
\qt@newcmd\qurantrans@ur@mmclv{یہ ہماری قوم کے لوگ ہیں جنہوں نے اس کے سوا کئی معبود بنا لئے ہیں، تو یہ ان (کے معبود ہونے) پر کوئی واضح سند کیوں نہیں لاتے؟ سو اُس سے بڑھ کر ظالم کون ہوگا جو اللہ پر جھوٹا بہتان باندھتا ہے،\qt@no{15}}%
\qt@newcmd\qurantrans@ur@mmclvi{اور (ان نوجوانوں نے آپس میں کہا:) جب تم ان سے اور ان (جھوٹے معبودوں) سے جنہیں یہ اﷲ کے سوا پوجتے ہیں کنارہ کش ہو گئے ہو تو تم (اس) غار میں پناہ لے لو، تمہارا رب تمہارے لئے اپنی رحمت کشادہ فرما دے گا اور تمہارے لئے تمہارے کام میں سہولت مہیا فرما دے گا،\qt@no{16}}%
\qt@newcmd\qurantrans@ur@mmclvii{اور آپ دیکھتے ہیں جب سورج طلوع ہوتا ہے تو ان کے غار سے دائیں جانب ہٹ جاتا ہے اور جب غروب ہونے لگتا ہے تو ان سے بائیں جانب کترا جاتا ہے اور وہ اس غار کے کشادہ میدان میں (لیٹے) ہیں، یہ (سورج کا اپنے راستے کو بدل لینا) اﷲ کی (قدرت کی بڑی) نشانیوں میں سے ہے، جسے اﷲ ہدایت فرما دے سو وہی ہدایت یافتہ ہے، اور جسے وہ گمراہ ٹھہرا دے تو آپ اس کے لئے کوئی ولی مرشد (یعنی راہ دکھانے والا مددگار) نہیں پائیں گے،\qt@no{17}}%
\qt@newcmd\qurantrans@ur@mmclviii{اور (اے سننے والے!) تو انہیں (دیکھے تو) بیدار خیال کرے گا حالانکہ وہ سوئے ہوئے ہیں اور ہم (وقفوں کے ساتھ) انہیں دائیں جانب اور بائیں جانب کروٹیں بدلاتے رہتے ہیں، اور ان کا کتا (ان کی) چوکھٹ پر اپنے دونوں بازو پھیلائے (بیٹھا) ہے، اگر تو انہیں جھانک کر دیکھ لیتا تو ان سے پیٹھ پھیر کر بھاگ جاتا اور تیرے دل میں ان کی دہشت بھر جاتی،\qt@no{18}}%
\qt@newcmd\qurantrans@ur@mmclix{اور اسی طرح ہم نے انہیں اٹھا دیا تاکہ وہ آپس میں دریافت کریں، (چنانچہ) ان میں سے ایک کہنے والے نے کہا: تم (یہاں) کتنا عرصہ ٹھہرے ہو؟ انہوں نے کہا: ہم (یہاں) ایک دن یا اس کا (بھی) کچھ حصہ ٹھہرے ہیں، (بالآخر) کہنے لگے: تمہارا رب ہی بہتر جانتا ہے کہ تم (یہاں) کتنا عرصہ ٹھہرے ہو، سو تم اپنے میں سے کسی ایک کو اپنا یہ سکہ دے کر شہر کی طرف بھیجو پھر وہ دیکھے کہ کون سا کھانا زیادہ حلال اور پاکیزہ ہے تو اس میں سے کچھ کھانا تمہارے پاس لے آئے اور اسے چاہئے کہ (آنے جانے اور خریدنے میں) آہستگی اور نرمی سے کام لے اور کسی ایک شخص کو (بھی) تمہاری خبر نہ ہونے دے،\qt@no{19}}%
\qt@newcmd\qurantrans@ur@mmclx{بیشک اگر انہوں نے تم (سے آگاہ ہو کر تم) پر دسترس پالی تو تمہیں سنگسار کر ڈالیں گے یا تمہیں (جبرًا) اپنے مذہب میں پلٹا لیں گے اور (اگر ایسا ہو گیا تو) تب تم ہرگز کبھی بھی فلاح نہیں پاؤ گے،\qt@no{20}}%
\qt@newcmd\qurantrans@ur@mmclxi{اور اس طرح ہم نے ان (کے حال) پر ان لوگوں کو (جو چند صدیاں بعد کے تھے) مطلع کردیا تاکہ وہ جان لیں کہ اﷲ کا وعدہ سچا ہے اور یہ (بھی) کہ قیامت کے آنے میں کوئی شک نہیں ہے۔ جب وہ (بستی والے) آپس میں ان کے معاملہ میں جھگڑا کرنے لگے (جب اصحابِ کہف وفات پاگئے) تو انہوں نے کہا کہ ان (کے غار) پر ایک عمارت (بطور یادگار) بنا دو، ان کا رب ان (کے حال) سے خوب واقف ہے، ان (ایمان والوں) نے کہا جنہیں ان کے معاملہ پر غلبہ حاصل تھا کہ ہم ان (کے دروازہ) پر ضرور ایک مسجد بنائیں گے (تاکہ مسلمان اس میں نماز پڑھیں اور ان کی قربت سے خصوصی برکت حاصل کریں)،\qt@no{21}}%
\qt@newcmd\qurantrans@ur@mmclxii{اب) کچھ لوگ کہیں گے: (اصحابِ کہف) تین تھے ان میں سے چوتھا ان کا کتا تھا، اور بعض کہیں گے: پانچ تھے ان میں سے چھٹا ان کا کتا تھا، یہ بِن دیکھے اندازے ہیں، اور بعض کہیں گے: (وہ) سات تھے اور ان میں سے آٹھواں ان کا کتا تھا۔ فرما دیجئے: میرا رب ہی ان کی تعداد کو خوب جانتا ہے اور سوائے چند لوگوں کے ان (کی صحیح تعداد) کا علم کسی کو نہیں، سو آپ کسی سے ان کے بارے میں بحث نہ کیا کریں سوائے اس قدر وضاحت کے جو ظاہر ہو چکی ہے اور نہ ان میں سے کسی سے ان (اصحابِ کہف) کے بارے میں کچھ دریافت کریں،\qt@no{22}}%
\qt@newcmd\qurantrans@ur@mmclxiii{اورکسی بھی چیز کی نسبت یہ ہرگز نہ کہا کریں کہ میں اس کام کو کل کرنے والا ہوں،\qt@no{23}}%
\qt@newcmd\qurantrans@ur@mmclxiv{مگر یہ کہ اگر اﷲ چاہے (یعنی اِن شاء اﷲ کہہ کر) اور اپنے رب کا ذکر کیا کریں جب آپ بھول جائیں اور کہیں: امید ہے میرا رب مجھے اس سے (بھی) قریب تر ہدایت کی راہ دکھا دے گا،\qt@no{24}}%
\qt@newcmd\qurantrans@ur@mmclxv{اور وہ (اصحابِ کہف) اپنی غار میں تین سو برس ٹھہرے رہے اور انہوں نے (اس پر) نو (سال) اور بڑھا دیئے،\qt@no{25}}%
\qt@newcmd\qurantrans@ur@mmclxvi{فرما دیجئے: اﷲ ہی بہتر جانتا ہے کہ وہ کتنی مدت (وہاں) ٹھہرے رہے، آسمانوں اور زمین کی (سب) پوشیدہ باتیں اسی کے علم میں ہیں، کیا خوب دیکھنے والا اور کیاخوب سننے والا ہے، اس کے سوا ان کا نہ کوئی کارساز ہے اور نہ وہ اپنے حکم میں کسی کو شریک فرماتا ہے،\qt@no{26}}%
\qt@newcmd\qurantrans@ur@mmclxvii{اور آپ وہ (کلام) پڑھ کر سنائیں جو آپ کے رب کی کتاب میں سے آپ کی طرف وحی کیا گیا ہے، اس کے کلام کو کوئی بدلنے والا نہیں اور آپ اس کے سوا ہرگز کوئی جائے پناہ نہیں پائیں گے،\qt@no{27}}%
\qt@newcmd\qurantrans@ur@mmclxviii{اے میرے بندے!) تو اپنے آپ کو ان لوگوں کی سنگت میں جمائے رکھا کر جو صبح و شام اپنے رب کو یاد کرتے ہیں اس کی رضا کے طلب گار رہتے ہیں (اس کی دید کے متمنی اور اس کا مکھڑا تکنے کے آرزو مند ہیں) تیری (محبت اور توجہ کی) نگاہیں ان سے نہ ہٹیں، کیا تو (ان فقیروں سے دھیان ہٹا کر) دنیوی زندگی کی آرائش چاہتا ہے، اور تو اس شخص کی اطاعت (بھی) نہ کر جس کے دل کو ہم نے اپنے ذکر سے غافل کردیا ہے اور وہ اپنی ہوائے نفس کی پیروی کرتا ہے اور اس کا حال حد سے گزر گیا ہے،\qt@no{28}}%
\qt@newcmd\qurantrans@ur@mmclxix{اور فرما دیجئے کہ (یہ) حق تمہارے رب کی طرف سے ہے، پس جو چاہے ایمان لے آئے اور جو چاہے انکار کردے، بیشک ہم نے ظالموں کے لئے (دوزخ کی) آگ تیار کر رکھی ہے جس کی دیواریں انہیں گھیر لیں گی، اور اگر وہ (پیاس اور تکلیف کے باعث) فریاد کریں گے تو ان کی فریاد رسی ایسے پانی سے کی جائے گی جو پگھلے ہوئے تانبے کی طرح ہوگا جو ان کے چہروں کو بھون دے گا، کتنا برا مشروب ہے، اور کتنی بری آرام گاہ ہے،\qt@no{29}}%
\qt@newcmd\qurantrans@ur@mmclxx{بیشک جو لوگ ایمان لائے اور نیک عمل کئے یقیناً ہم اس شخص کا اجر ضائع نہیں کرتے جو نیک عمل کرتا ہے،\qt@no{30}}%
\qt@newcmd\qurantrans@ur@mmclxxi{ان لوگوں کے لئے ہمیشہ (آباد) رہنے والے باغات ہیں (جن میں) ان (کے محلات) کے نیچے نہریں جاری ہیں انہیں ان جنتوں میں سونے کے کنگن پہنائے جائیں گے اور وہ باریک دیبا اور بھاری اطلس کے (ریشمی) سبز لباس پہنیں گے اور پر تکلف تختوں پر تکئے لگائے بیٹھے ہوں گے، کیا خوب ثواب ہے اور کتنی حسین آرام گاہ ہے،\qt@no{31}}%
\qt@newcmd\qurantrans@ur@mmclxxii{اور آپ ان سے ان دو شخصوں کی مثال بیان کریں جن میں سے ایک کے لئے ہم نے انگور کے دو باغات بنائے اور ہم نے ان دونوں کو تمام اَطراف سے کھجور کے درختوں کے ساتھ ڈھانپ دیا اور ہم نے ان کے درمیان (سرسبز و شاداب) کھیتیاں اگا دیں،\qt@no{32}}%
\qt@newcmd\qurantrans@ur@mmclxxiii{یہ دونوں باغ (کثرت سے) اپنے پھل لائے اور ان کی (پیداوار) میں کوئی کمی نہ رہی اور ہم نے ان دونوں (میں سے ہر ایک) کے درمیان ایک نہر (بھی) جاری کر دی،\qt@no{33}}%
\qt@newcmd\qurantrans@ur@mmclxxiv{اور اس شخص کے پاس (اس کے سوا بھی) بہت سے پھل (یعنی وسائل) تھے، تو اس نے اپنے ساتھی سے کہا اور وہ اس سے تبادلہ خیال کر رہا تھا کہ میں تجھ سے مال و دولت میں کہیں زیادہ ہوں اور قبیلہ و خاندان کے لحاظ سے (بھی) زیادہ باعزت ہوں،\qt@no{34}}%
\qt@newcmd\qurantrans@ur@mmclxxv{اور وہ (اسے لے کر) اپنے باغ میں داخل ہوا (تکبّر کی صورت میں) اپنی جان پر ظلم کرتے ہوئے کہنے لگا: میں یہ گمان (ہی) نہیں کرتا کہ یہ باغ تباہ ہوگا،\qt@no{35}}%
\qt@newcmd\qurantrans@ur@mmclxxvi{اور نہ ہی یہ گمان کرتا ہوں کہ قیامت قائم ہوگی اور اگر (بالفرض) میں اپنے رب کی طرف لوٹایا بھی گیا تو بھی یقیناً میں ان باغات سے بہتر پلٹنے کی جگہ پاؤں گا،\qt@no{36}}%
\qt@newcmd\qurantrans@ur@mmclxxvii{اس کے ساتھی نے اس سے کہا اور وہ اس سے تبادلہء خیال کر رہا تھا: کیا تو نے اس (رب) کا انکار کیا ہے جس نے تجھے (اوّلاً) مٹی سے پیدا کیا پھر ایک تولیدی قطرہ سے پھر تجھے (جسمانی طور پر) پورا مرد بنا دیا؟،\qt@no{37}}%
\qt@newcmd\qurantrans@ur@mmclxxviii{لیکن میں (تو یہ کہتا ہوں) کہ وہی اﷲ میرا رب ہے اور میں اپنے رب کے ساتھ کسی کو شریک نہیں گردانتا،\qt@no{38}}%
\qt@newcmd\qurantrans@ur@mmclxxix{اور جب تو اپنے باغ میں داخل ہوا تو تو نے کیوں نہیں کہا: ”ما شاء اﷲ لا قوۃ اِلا باﷲ“ (وہی ہونا ہے جو اﷲ چاہے کسی کو کچھ طاقت نہیں مگر اﷲ کی مدد سے)، اگر تو (اِس وقت) مجھے مال و اولاد میں اپنے سے کم تر دیکھتا ہے (تو کیا ہوا)،\qt@no{39}}%
\qt@newcmd\qurantrans@ur@mmclxxx{کچھ بعید نہیں کہ میرا رب مجھے تیرے باغ سے بہتر عطا فرمائے اور اس (باغ) پر آسمان سے کوئی عذاب بھیج دے پھر وہ چٹیل چکنی زمین بن جائے،\qt@no{40}}%
\qt@newcmd\qurantrans@ur@mmclxxxi{یا اس کا پانی زمین کی گہرائی میں چلا جائے پھر تو اسے حاصل کرنے کی طاقت بھی نہ پا سکے،\qt@no{41}}%
\qt@newcmd\qurantrans@ur@mmclxxxii{اور (اس تکبّر کے باعث) اس کے (سارے) پھل (تباہی میں) گھیر لئے گئے تو صبح کو وہ اس پونجی پر جو اس نے اس (باغ کے لگانے) میں خرچ کی تھی کفِ افسوس ملتا رہ گیا اور وہ باغ اپنے چھپروں پر گرا پڑا تھا اور وہ (سراپا حسرت و یاس بن کر) کہہ رہا تھا: ہائے کاش! میں نے اپنے رب کے ساتھ کسی کو شریک نہ ٹھہرایا ہوتا (اور اپنے اوپر گھمنڈ نہ کیا ہوتا)،\qt@no{42}}%
\qt@newcmd\qurantrans@ur@mmclxxxiii{اور اس کے لئے کوئی گروہ (بھی) ایسا نہ تھا جو اﷲ کے مقابلہ میں اس کی مدد کرتے اور نہ وہ خود (ہی اس تباہی کا) بدلہ لینے کے قابل تھا،\qt@no{43}}%
\qt@newcmd\qurantrans@ur@mmclxxxiv{یہاں (پتہ چلتا ہے) کہ سب اختیار اﷲ ہی کا ہے (جو) حق ہے، وہی بہتر ہے انعام دینے میں اور وہی بہتر ہے انجام کرنے میں،\qt@no{44}}%
\qt@newcmd\qurantrans@ur@mmclxxxv{اور آپ انہیں دنیوی زندگی کی مثال (بھی) بیان کیجئے (جو) اس پانی جیسی ہے جسے ہم نے آسمان کی طرف سے اتارا تو اس کے باعث زمین کا سبزہ خوب گھنا ہوگیا پھر وہ سوکھی گھاس کا چورا بن گیا جسے ہوائیں اڑا لے جاتی ہیں، اور اﷲ ہر چیز پر کامل قدرت والا ہے،\qt@no{45}}%
\qt@newcmd\qurantrans@ur@mmclxxxvi{مال اور اولاد (تو صرف) دنیاوی زندگی کی زینت ہیں اور (حقیقت میں) باقی رہنے والی (تو) نیکیاں (ہیں جو) آپ کے رب کے نزدیک ثواب کے لحاظ سے (بھی) بہتر ہیں اور آرزو کے لحاظ سے (بھی) خوب تر ہیں،\qt@no{46}}%
\qt@newcmd\qurantrans@ur@mmclxxxvii{وہ دن (قیامت کا) ہوگا جب ہم پہاڑوں کو (ریزہ ریزہ کر کے فضا میں) چلائیں گے اور آپ زمین کو صاف میدان دیکھیں گے (اس پر شجر، حجر اور حیوانات و نباتات میں سے کچھ بھی نہ ہوگا) اور ہم سب انسانوں کو جمع فرمائیں گے اور ان میں سے کسی کو (بھی) نہیں چھوڑیں گے،\qt@no{47}}%
\qt@newcmd\qurantrans@ur@mmclxxxviii{اور (سب لوگ) آپ کے رب کے حضور قطار در قطار پیش کئے جائیں گے، (ان سے کہا جائے گا:) بیشک تم ہمارے پاس (آج اسی طرح) آئے ہو جیسا کہ ہم نے تمہیں پہلی بار پیدا کیا تھا بلکہ تم یہ گمان کرتے تھے کہ ہم تمہارے لئے ہرگز وعدہ کا وقت مقرر ہی نہیں کریں گے،\qt@no{48}}%
\qt@newcmd\qurantrans@ur@mmclxxxix{اور (ہر ایک کے سامنے) اَعمال نامہ رکھ دیا جائے گا سو آپ مجرموں کو دیکھیں گے (وہ) ان (گناہوں اور جرموں) سے خوفزدہ ہوں گے جو اس (اَعمال نامہ) میں درج ہوں گے اور کہیں گے: ہائے ہلاکت! اس اَعمال نامہ کو کیا ہوا ہے اس نے نہ کوئی چھوٹی (بات) چھوڑی ہے اور نہ کوئی بڑی (بات)، مگر اس نے (ہر ہر بات کو) شمار کر لیا ہے اور وہ جو کچھ کرتے رہے تھے (اپنے سامنے) حاضر پائیں گے، اور آپ کا رب کسی پر ظلم نہ فرمائے گا،\qt@no{49}}%
\qt@newcmd\qurantrans@ur@mmcxc{اور (وہ وقت یاد کیجئے) جب ہم نے فرشتوں سے فرمایا کہ تم آدم (علیہ السلام) کو سجدۂ (تعظیم) کرو سو ان (سب) نے سجدہ کیا سوائے ابلیس کے، وہ (ابلیس) جنّات میں سے تھا تو وہ اپنے رب کی طاعت سے باہر نکل گیا، کیا تم اس کو اور اس کی اولاد کو مجھے چھوڑ کر دوست بنا رہے ہو حالانکہ وہ تمہارے دشمن ہیں، یہ ظالموں کے لئے کیا ہی برا بدل ہے (جو انہوں نے میری جگہ منتخب کیا ہے)،\qt@no{50}}%
\qt@newcmd\qurantrans@ur@mmcxci{میں نے نہ (تو) انہیں آسمانوں اور زمین کی تخلیق پر (معاونت یا گواہی کے لئے) بلایا تھا اور نہ خود ان کی اپنی تخلیق (کے وقت)، اور نہ (ہی) میں ایسا تھا کہ گمراہ کرنے والوں کو (اپنا) دست و بازو بناتا،\qt@no{51}}%
\qt@newcmd\qurantrans@ur@mmcxcii{اور اُس دن (کو یاد کرو جب) اﷲ فرمائے گا: انہیں پکارو جنہیں تم میرا شریک گمان کرتے تھے، سو وہ انہیں بلائیں گے مگر وہ انہیں کوئی جواب نہ دیں گے اور ہم ان کے درمیان (ایک وادئ جہنم کو) ہلاکت کی جگہ بنا دیں گے،\qt@no{52}}%
\qt@newcmd\qurantrans@ur@mmcxciii{اور مجرم لوگ آتشِ دوزخ کو دیکھیں گے تو جان لیں گے کہ وہ یقیناً اسی میں گرنے والے ہیں اور وہ اس سے گریز کی کوئی جگہ نہ پاسکیں گے،\qt@no{53}}%
\qt@newcmd\qurantrans@ur@mmcxciv{اور بیشک ہم نے اس قرآن میں لوگوں کے لئے ہر طرح کی مثال کو (انداز بدل بدل کر) بار بار بیان کیا ہے، اور انسان جھگڑنے میں ہر چیز سے بڑھ کر ہے،\qt@no{54}}%
\qt@newcmd\qurantrans@ur@mmcxcv{اور لوگوں کو جبکہ ان کے پاس ہدایت آچکی تھی کسی نے (اس بات سے) منع نہیں کیا تھا کہ وہ ایمان لائیں اور اپنے رب سے مغفرت طلب کریں سوائے اس (انتظار) کے کہ انہیں اگلے لوگوں کا طریقہ (ہلاکت) پیش آئے یا عذاب ان کے سامنے آجائے،\qt@no{55}}%
\qt@newcmd\qurantrans@ur@mmcxcvi{اور ہم رسولوں کو نہیں بھیجا کرتے مگر (لوگوں کو) خوشخبری سنانے والے اور ڈر سنانے والے (بنا کر)، اور کافر لوگ (ان رسولوں سے) بیہودہ باتوں کے سہارے جھگڑا کرتے ہیں تاکہ اس (باطل) کے ذریعہ حق کو زائل کردیں اور وہ میری آیتوں کو اور اس (عذاب) کو جس سے وہ ڈرائے جاتے ہیں ہنسی مذاق بنا لیتے ہیں،\qt@no{56}}%
\qt@newcmd\qurantrans@ur@mmcxcvii{اور اس شخص سے بڑھ کر ظالم کون ہوگا جسے اس کے رب کی نشانیاں یاد دلائی گئیں تو اس نے ان سے رُوگردانی کی اور ان (بداَعمالیوں) کو بھول گیا جو اس کے ہاتھ آگے بھیج چکے تھے، بیشک ہم نے ان کے دلوں پر پردے ڈال دیئے ہیں کہ وہ اس حق کو سمجھ (نہ) سکیں اور ان کے کانوں میں بوجھ پیدا کر دیا ہے (کہ وہ اس حق کو سن نہ سکیں)، اور اگر آپ انہیں ہدایت کی طرف بلائیں تو وہ کبھی بھی قطعًا ہدایت نہیں پائیں گے،\qt@no{57}}%
\qt@newcmd\qurantrans@ur@mmcxcviii{اور آپ کا رب بڑا بخشنے والا صاحبِ رحمت ہے، اگر وہ ان کے کئے پر ان کا مؤاخذہ فرماتا تو ان پر یقیناً جلد عذاب بھیجتا، بلکہ ان کے لئے (تو) وقتِ وعدہ (مقرر) ہے (جب وہ وقت آئے گا تو) اس کے سوا ہرگز کوئی جائے پناہ نہیں پائیں گے،\qt@no{58}}%
\qt@newcmd\qurantrans@ur@mmcxcix{اور یہ بستیاں ہیں ہم نے جن کے رہنے والوں کو ہلاک کر ڈالا جب انہوں نے ظلم کیا اور ہم نے ان کی ہلاکت کے لئے ایک وقت مقرر کر رکھا تھا،\qt@no{59}}%
\qt@newcmd\qurantrans@ur@mmcc{اور (وہ واقعہ بھی یاد کیجئے) جب موسٰی (علیہ السلام) نے اپنے (جواں سال ساتھی اور) خادم (یوشع بن نون علیہ السلام) سے کہا: میں (پیچھے) نہیں ہٹ سکتا یہاں تک کہ میں دو دریاؤں کے سنگم کی جگہ تک پہنچ جاؤں یا مدتوں چلتا رہوں،\qt@no{60}}%
\qt@newcmd\qurantrans@ur@mmcci{سو جب وہ دونوں دو دریاؤں کے درمیان سنگم پر پہنچے تو وہ دونوں اپنی مچھلی (وہیں) بھول گئے پس وہ (تلی ہوئی مچھلی زندہ ہوکر) دریا میں سرنگ کی طرح اپنا راستہ بناتے ہوئے (نکل گئی)،\qt@no{61}}%
\qt@newcmd\qurantrans@ur@mmccii{پھر جب وہ دونوں آگے بڑھ گئے (تو) موسٰی (علیہ السلام) نے اپنے خادم سے کہا: ہمارا کھانا ہمارے پاس لاؤ بیشک ہم نے اپنے اس سفر میں بڑی مشقت کا سامنا کیا ہے،\qt@no{62}}%
\qt@newcmd\qurantrans@ur@mmcciii{خادم نے) کہا: کیا آپ نے دیکھا جب ہم نے پتھر کے پاس آرام کیا تھا تو میں (وہاں) مچھلی بھول گیا تھا، اور مجھے یہ کسی نے نہیں بھلایا سوائے شیطان کے کہ میں آپ سے اس کا ذکر کروں، اور اس (مچھلی) نے تو (زندہ ہوکر) دریا میں عجیب طریقہ سے اپنا راستہ بنا لیا تھا (اور وہ غائب ہو گئی تھی)،\qt@no{63}}%
\qt@newcmd\qurantrans@ur@mmcciv{موسٰی (علیہ السلام) نے کہا: یہی وہ (مقام) ہے ہم جسے تلاش کر رہے تھے، پس دونوں اپنے قدموں کے نشانات پر (وہی راستہ) تلاش کرتے ہوئے (اسی مقام پر) واپس پلٹ آئے،\qt@no{64}}%
\qt@newcmd\qurantrans@ur@mmccv{تو دونوں نے (وہاں) ہمارے بندوں میں سے ایک (خاص) بندے (خضر علیہ السلام) کو پا لیا جسے ہم نے اپنی بارگاہ سے (خصوصی) رحمت عطا کی تھی اور ہم نے اسے اپنا علم لدنّی (یعنی اَسرار و معارف کا الہامی علم) سکھایا تھا،\qt@no{65}}%
\qt@newcmd\qurantrans@ur@mmccvi{اس سے موسٰی (علیہ السلام) نے کہا: کیا میں آپ کے ساتھ اس (شرط) پر رہ سکتا ہوں کہ آپ مجھے (بھی) اس علم میں سے کچھ سکھائیں گے جو آپ کو بغرضِ ارشاد سکھایا گیا ہے،\qt@no{66}}%
\qt@newcmd\qurantrans@ur@mmccvii{اس (خضرعلیہ السلام) نے کہا: بیشک آپ میرے ساتھ رہ کر ہرگز صبر نہ کر سکیں گے،\qt@no{67}}%
\qt@newcmd\qurantrans@ur@mmccviii{اور آپ اس (بات) پر کیسے صبر کر سکتے ہیں جسے آپ (پورے طور پر) اپنے احاطہء علم میں نہیں لائے ہوں گے،\qt@no{68}}%
\qt@newcmd\qurantrans@ur@mmccix{موسٰی (علیہ السلام) نے کہا: آپ اِن شاء اﷲ مجھے ضرور صابر پائیں گے اور میں آپ کی کسی بات کی خلاف ورزی نہیں کروں گا،\qt@no{69}}%
\qt@newcmd\qurantrans@ur@mmccx{خضرعلیہ السلام نے) کہا: پس اگر آپ میرے ساتھ رہیں تو مجھ سے کسی چیز کی بابت سوال نہ کریں یہاں تک کہ میں خود آپ سے اس کا ذکر کردوں،\qt@no{70}}%
\qt@newcmd\qurantrans@ur@mmccxi{پس دونوں چل دیئے یہاں تک کہ جب دونوں کشتی میں سوار ہوئے (تو خضر علیہ السلام نے) اس (کشتی) میں شگاف کر دیا، موسٰی (علیہ السلام) نے کہا: کیا آپ نے اسے اس لئے (شگاف کر کے) پھاڑ ڈالا ہے کہ آپ کشتی والوں کو غرق کردیں، بیشک آپ نے بڑی عجیب بات کی،\qt@no{71}}%
\qt@newcmd\qurantrans@ur@mmccxii{خضرعلیہ السلام نے) کہا: کیا میں نے نہیں کہا تھا کہ آپ میرے ساتھ رہ کر ہرگز صبر نہیں کرسکیں گے،\qt@no{72}}%
\qt@newcmd\qurantrans@ur@mmccxiii{موسٰی (علیہ السلام) نے کہا: آپ میری بھول پر میری گرفت نہ کریں اور میرے (اس) معاملہ میں مجھے زیادہ مشکل میں نہ ڈالیں،\qt@no{73}}%
\qt@newcmd\qurantrans@ur@mmccxiv{پھر وہ دونوں چل دیئے یہاں تک کہ دونوں ایک لڑکے سے ملے تو (خضر علیہ السلام نے) اسے قتل کر ڈالا، موسٰی (علیہ السلام) نے کہا: کیا آپ نے بے گناہ جان کو بغیر کسی جان (کے بدلہ) کے قتل کر دیا ہے، بیشک آپ نے بڑا ہی سخت کام کیا ہے،\qt@no{74}}%
\qt@newcmd\qurantrans@ur@mmccxv{خضرعلیہ السلام نے) کہا: کیا میں نے آپ سے نہیں کہا تھا کہ آپ میرے ساتھ رہ کر ہرگز صبر نہ کر سکیں گے،\qt@no{75}}%
\qt@newcmd\qurantrans@ur@mmccxvi{موسٰی (علیہ السلام) نے کہا: اگر میں اس کے بعد آپ سے کسی چیز کی نسبت سوال کروں تو آپ مجھے اپنے ساتھ نہ رکھیئے گا، بیشک میری طرف سے آپ حدِ عذر کو پہنچ گئے ہیں،\qt@no{76}}%
\qt@newcmd\qurantrans@ur@mmccxvii{پھر دونوں چل پڑے یہاں تک کہ جب دونوں ایک بستی والوں کے پاس آپہنچے، دونوں نے وہاں کے باشندوں سے کھانا طلب کیا تو انہوں نے ان دونوں کی میزبانی کرنے سے انکار کر دیا، پھر دونوں نے وہاں ایک دیوار پائی جو گرا چاہتی تھی تو (خضر علیہ السلام نے) اسے سیدھا کر دیا، موسٰی (علیہ السلام) نے کہا: اگر آپ چاہتے تو اس (تعمیر) پر مزدوری لے لیتے،\qt@no{77}}%
\qt@newcmd\qurantrans@ur@mmccxviii{خضرعلیہ السلام نے) کہا: یہ میرے اور آپ کے درمیان جدائی (کا وقت) ہے، اب میں آپ کو ان باتوں کی حقیقت سے آگاہ کئے دیتا ہوں جن پر آپ صبر نہیں کر سکے،\qt@no{78}}%
\qt@newcmd\qurantrans@ur@mmccxix{وہ جو کشتی تھی سو وہ چند غریب لوگوں کی تھی وہ دریا میں محنت مزدوری کیا کرتے تھے پس میں نے ارادہ کیا کہ اسے عیب دار کر دوں اور (اس کی وجہ یہ تھی کہ) ان کے آگے ایک (جابر) بادشاہ (کھڑا) تھا جو ہر (بے عیب) کشتی کو زبردستی (مالکوں سے بلامعاوضہ) چھین رہا تھا،\qt@no{79}}%
\qt@newcmd\qurantrans@ur@mmccxx{اور وہ جو لڑکا تھا تو اس کے ماں باپ صاحبِ ایمان تھے پس ہمیں اندیشہ ہوا کہ یہ (اگر زندہ رہا تو کافر بنے گا اور) ان دونوں کو (بڑا ہو کر) سرکشی اور کفر میں مبتلا کر دے گا،\qt@no{80}}%
\qt@newcmd\qurantrans@ur@mmccxxi{پس ہم نے ارادہ کیا کہ ان کا رب انہیں (ایسا) بدل عطا فرمائے جو پاکیزگی میں (بھی) اس (لڑکے) سے بہتر ہو اور شفقت و رحم دلی میں (بھی والدین سے) قریب تر ہو،\qt@no{81}}%
\qt@newcmd\qurantrans@ur@mmccxxii{اور وہ جو دیوار تھی تو وہ شہر میں (رہنے والے) دو یتیم بچوں کی تھی اور اس کے نیچے ان دونوں کے لئے ایک خزانہ (مدفون) تھا اور ان کا باپ صالح (شخص) تھا، سو آپ کے رب نے ارادہ کیا کہ وہ دونوں اپنی جوانی کو پہنچ جائیں اور آپ کے رب کی رحمت سے وہ اپنا خزانہ (خود ہی) نکالیں، اور میں نے (جو کچھ بھی کیا) وہ اَز خود نہیں کیا، یہ ان (واقعات) کی حقیقت ہے جن پر آپ صبر نہ کر سکے،\qt@no{82}}%
\qt@newcmd\qurantrans@ur@mmccxxiii{اور (اے حبیبِ معظّم!) یہ آپ سے ذوالقرنین کے بارے میں سوال کرتے ہیں، فرما دیجئے: میں ابھی تمہیں اس کے حال کا تذکرہ پڑھ کر سناتا ہوں،\qt@no{83}}%
\qt@newcmd\qurantrans@ur@mmccxxiv{بیشک ہم نے اسے (زمانۂ قدیم میں) زمین پر اقتدار بخشا تھا اور ہم نے اس (کی سلطنت) کو تمام وسائل و اسباب سے نوازا تھا،\qt@no{84}}%
\qt@newcmd\qurantrans@ur@mmccxxv{پس وہ (مزید) اسباب کے پیچھے چل پڑا،\qt@no{85}}%
\qt@newcmd\qurantrans@ur@mmccxxvi{یہاں تک کہ وہ غروبِ آفتاب (کی سمت آبادی) کے آخری کنارے پر جا پہنچا وہاں اس نے سورج کے غروب کے منظر کو ایسے محسوس کیا جیسے وہ (کیچڑ کی طرح سیاہ رنگ) پانی کے گرم چشمہ میں ڈوب رہا ہو اور اس نے وہاں ایک قوم کو (آباد) پایا۔ ہم نے فرمایا: اے ذوالقرنین! (یہ تمہاری مرضی پر منحصر ہے) خواہ تم انہیں سزا دو یا ان کے ساتھ اچھا سلوک کرو،\qt@no{86}}%
\qt@newcmd\qurantrans@ur@mmccxxvii{ذوالقرنین نے کہا: جو شخص (کفر و فسق کی صورت میں) ظلم کرے گا تو ہم اسے ضرور سزا دیں گے، پھر وہ اپنے رب کی طرف لوٹایا جائے گا، پھر وہ اسے بہت ہی سخت عذاب دے گا،\qt@no{87}}%
\qt@newcmd\qurantrans@ur@mmccxxviii{اور جو شخص ایمان لے آئے گا اور نیک عمل کرے گا تو اس کے لئے بہتر جزا ہے اور ہم (بھی) اس کے لئے اپنے احکام میں آسان بات کہیں گے،\qt@no{88}}%
\qt@newcmd\qurantrans@ur@mmccxxix{مغرب میں فتوحات مکمل کرنے کے بعد) پھر وہ (دوسرے) راستہ پر چل پڑا،\qt@no{89}}%
\qt@newcmd\qurantrans@ur@mmccxxx{یہاں تک کہ وہ طلوعِ آفتاب (کی سمت آبادی) کے آخری کنارے پر جا پہنچا، وہاں اس نے سورج (کے طلوع کے منظر) کو ایسے محسوس کیا (جیسے) سورج (زمین کے اس خطہ پر آباد) ایک قوم پر اُبھر رہا ہو جس کے لئے ہم نے سورج سے (بچاؤ کی خاطر) کوئی حجاب تک نہیں بنایا تھا (یعنی وہ لوگ بغیر لباس اور مکان کے غاروں میں رہتے تھے)،\qt@no{90}}%
\qt@newcmd\qurantrans@ur@mmccxxxi{واقعہ اسی طرح ہے، اور جو کچھ اس کے پاس تھا ہم نے اپنے علم سے اس کا احاطہ کر لیا ہے،\qt@no{91}}%
\qt@newcmd\qurantrans@ur@mmccxxxii{مشرق میں فتوحات مکمل کرنے کے بعد) پھر وہ (ایک اور) راستہ پر چل پڑا،\qt@no{92}}%
\qt@newcmd\qurantrans@ur@mmccxxxiii{یہاں تک کہ وہ (ایک مقام پر) دو پہاڑوں کے درمیان جا پہنچا اس نے ان پہاڑوں کے پیچھے ایک ایسی قوم کو آباد پایا جو (کسی کی) بات نہیں سمجھ سکتے تھے،\qt@no{93}}%
\qt@newcmd\qurantrans@ur@mmccxxxiv{انہوں نے کہا: اے ذوالقرنین! بیشک یاجوج اور ماجوج نے زمین میں فساد بپا کر رکھا ہے تو کیا ہم آپ کے لئے اس (شرط) پر کچھ مالِ (خراج) مقرر کردیں کہ آپ ہمارے اور ان کے درمیان ایک بلند دیوار بنا دیں،\qt@no{94}}%
\qt@newcmd\qurantrans@ur@mmccxxxv{ذوالقرنین نے) کہا: مجھے میرے رب نے اس بارے میں جو اختیار دیا ہے (وہ) بہتر ہے، تم اپنے زورِ بازو (یعنی محنت و مشقت) سے میری مدد کرو، میں تمہارے اور ان کے درمیان ایک مضبوط دیوار بنا دوں گا،\qt@no{95}}%
\qt@newcmd\qurantrans@ur@mmccxxxvi{تم مجھے لوہے کے بڑے بڑے ٹکڑے لا دو، یہاں تک کہ جب اس نے (وہ لوہے کی دیوار پہاڑوں کی) دونوں چوٹیوں کے درمیان برابر کر دی تو کہنے لگا: (اب آگ لگا کر اسے) دھونکو، یہاں تک کہ جب اس نے اس (لوہے) کو (دھونک دھونک کر) آگ بنا ڈالا تو کہنے لگا: میرے پاس لاؤ (اب) میں اس پر پگھلا ہوا تانبا ڈالوں گا،\qt@no{96}}%
\qt@newcmd\qurantrans@ur@mmccxxxvii{پھر ان (یاجوج اور ماجوج) میں نہ اتنی طاقت تھی کہ اس پر چڑھ سکیں اور نہ اتنی قدرت پا سکے کہ اس میں سوراخ کر دیں،\qt@no{97}}%
\qt@newcmd\qurantrans@ur@mmccxxxviii{ذوالقرنین نے) کہا: یہ میرے رب کی جانب سے رحمت ہے، پھر جب میرے رب کا وعدۂ (قیامت قریب) آئے گا تو وہ اس دیوار کو (گرا کر) ہموار کردے گا (دیوار ریزہ ریزہ ہوجائے گی)، اور میرے رب کا وعدہ برحق ہے،\qt@no{98}}%
\qt@newcmd\qurantrans@ur@mmccxxxix{اور ہم اس وقت (جملہ مخلوقات یا یاجوج اور ماجوج کو) آزاد کر دیں گے وہ (تیز و تند موجوں کی طرح) ایک دوسرے میں گھس جائیں گے اور صور پھونکا جائے گا تو ہم ان سب کو (میدانِ حشر میں) جمع کرلیں گے،\qt@no{99}}%
\qt@newcmd\qurantrans@ur@mmccxl{اور ہم اس دن دوزخ کو کافروں کے سامنے بالکل عیاں کر کے پیش کریں گے،\qt@no{100}}%
\qt@newcmd\qurantrans@ur@mmccxli{وہ لوگ جن کی آنکھیں میری یاد سے حجابِ (غفلت) میں تھیں اور وہ (میرا ذکر) سن بھی نہ سکتے تھے،\qt@no{101}}%
\qt@newcmd\qurantrans@ur@mmccxlii{کیا کافر لوگ یہ سمجھتے ہیں کہ وہ مجھے چھوڑ کر میرے بندوں کو کار ساز بنا لیں گے، بیشک ہم نے کافروں کے لئے جہنم کی میزبانی کو تیار کر رکھا ہے،\qt@no{102}}%
\qt@newcmd\qurantrans@ur@mmccxliii{فرما دیجئے: کیا ہم تمہیں ایسے لوگوں سے خبردار کر دیں جو اعمال کے حساب سے سخت خسارہ پانے والے ہیں،\qt@no{103}}%
\qt@newcmd\qurantrans@ur@mmccxliv{یہ وہ لوگ ہیں جن کی ساری جد و جہد دنیا کی زندگی میں ہی برباد ہوگئی اور وہ یہ خیال کرتے ہیں کہ ہم بڑے اچھے کام انجام دے رہے ہیں،\qt@no{104}}%
\qt@newcmd\qurantrans@ur@mmccxlv{یہی وہ لوگ ہیں جنہوں نے اپنے رب کی نشانیوں کا اور (مرنے کے بعد) اس سے ملاقات کا انکار کردیا ہے سو ان کے سارے اعمال اکارت گئے پس ہم ان کے لئے قیامت کے دن کوئی وزن اور حیثیت (ہی) قائم نہیں کریں گے،\qt@no{105}}%
\qt@newcmd\qurantrans@ur@mmccxlvi{یہی دوزخ ہی ان کی جزا ہے اس وجہ سے کہ وہ کفر کرتے رہے اور میری نشانیوں اور میرے رسولوں کا مذاق اڑاتے رہے،\qt@no{106}}%
\qt@newcmd\qurantrans@ur@mmccxlvii{بیشک جو لوگ ایمان لائے اور نیک عمل کرتے رہے تو ان کے لئے فردوس کے باغات کی مہمانی ہوگی،\qt@no{107}}%
\qt@newcmd\qurantrans@ur@mmccxlviii{وہ اس میں ہمیشہ رہیں گے وہاں سے (اپنا ٹھکانا) کبھی بدلنا نہ چاہیں گے،\qt@no{108}}%
\qt@newcmd\qurantrans@ur@mmccxlix{فرما دیجئے: اگر سمندر میرے رب کے کلمات کے لئے روشنائی ہوجائے تو وہ سمندر میرے رب کے کلمات کے ختم ہونے سے پہلے ہی ختم ہوجائے گا اگرچہ ہم اس کی مثل اور (سمندر یا روشنائی) مدد کے لئے لے آئیں،\qt@no{109}}%
\qt@newcmd\qurantrans@ur@mmccl{فرما دیجئے: میں تو صرف (بخلقتِ ظاہری) بشر ہونے میں تمہاری مثل ہوں (اس کے سوا اور تمہاری مجھ سے کیا مناسبت ہے! ذرا غور کرو) میری طرف وحی کی جاتی ہے (بھلا تم میں یہ نوری استعداد کہاں ہے کہ تم پر کلامِ الٰہی اتر سکے) وہ یہ کہ تمہارا معبود، معبودِ یکتا ہی ہے پس جو شخص اپنے رب سے ملاقات کی امید رکھتا ہے تو اسے چاہئے کہ نیک عمل کرے اور اپنے رب کی عبادت میں کسی کو شریک نہ کرے،\qt@no{110}}%
\qt@newcmd\qurantrans@ur@mmccli{\basmalahur کاف، ہا، یا، عین، صاد (حقیقی معنی اﷲ اور رسول صلی اللہ علیہ وآلہ وسلم ہی بہتر جانتے ہیں)،\qt@no{1}}%
\qt@newcmd\qurantrans@ur@mmcclii{یہ آپ کے رب کی رحمت کا ذکر ہے (جو اس نے) اپنے (برگزیدہ) بندے زکریا (علیہ السلام) پر (فرمائی تھی)،\qt@no{2}}%
\qt@newcmd\qurantrans@ur@mmccliii{جب انہوں نے اپنے رب کو (ادب بھری) دبی آواز سے پکارا،\qt@no{3}}%
\qt@newcmd\qurantrans@ur@mmccliv{عرض کیا: اے میرے رب! میرے جسم کی ہڈیاں کمزور ہوگئی ہیں اوربڑھاپے کے باعث سر آگ کے شعلہ کی مانند سفید ہوگیا ہے اور اے میرے رب! میں تجھ سے مانگ کر کبھی محروم نہیں رہا،\qt@no{4}}%
\qt@newcmd\qurantrans@ur@mmcclv{اور میں اپنے (رخصت ہوجانے کے) بعد (بے دین) رشتہ داروں سے ڈرتا ہوں (کہ وہ دین کی نعمت ضائع نہ کر بیٹھیں) اور میری بیوی (بھی) بانجھ ہے سو تو مجھے اپنی (خاص) بارگاہ سے ایک وارث (فرزند) عطا فرما،\qt@no{5}}%
\qt@newcmd\qurantrans@ur@mmcclvi{جو (آسمانی نعمت میں) میرا (بھی) وارث بنے اور یعقوب (علیہ السلام) کی اولاد (کے سلسلۂ نبوت) کا (بھی) وارث ہو، اور اے میرے رب! تو (بھی) اسے اپنی رضا کا حامل بنا لے،\qt@no{6}}%
\qt@newcmd\qurantrans@ur@mmcclvii{ارشاد ہوا:) اے زکریا! بیشک ہم تمہیں ایک لڑکے کی خوشخبری سناتے ہیں جس کا نام یحیٰی (علیہ السلام) ہوگا ہم نے اس سے پہلے اس کا کوئی ہم نام نہیں بنایا،\qt@no{7}}%
\qt@newcmd\qurantrans@ur@mmcclviii{زکریا علیہ السلام نے) عرض کیا: اے میرے رب! میرے ہاں لڑکا کیسے ہو سکتا ہے درآنحالیکہ میری بیوی بانجھ ہے اور میں خود بڑھاپے کے باعث (انتہائی ضعف میں) سوکھ جانے کی حالت کو پہنچ گیا ہوں،\qt@no{8}}%
\qt@newcmd\qurantrans@ur@mmcclix{فرمایا: (تعجب نہ کرو) ایسے ہی ہوگا، تمہارے رب نے فرمایا ہے: یہ (لڑکا پیدا کرنا) مجھ پر آسان ہے اور بیشک میں اس سے پہلے تمہیں (بھی) پیدا کرچکا ہوں اس حالت سے کہ تم (سرے سے) کوئی چیز ہی نہ تھے،\qt@no{9}}%
\qt@newcmd\qurantrans@ur@mmcclx{زکریا علیہ السلام نے) عرض کیا: اے میرے رب! میرے لئے کوئی نشانی مقرر فرما، ارشاد ہوا: تمہاری نشانی یہ ہے کہ تم بالکل تندرست ہوتے ہوئے بھی تین رات (دن) لوگوں سے کلام نہ کرسکوگے،\qt@no{10}}%
\qt@newcmd\qurantrans@ur@mmcclxi{پھر (زکریا علیہ السلام) حجرۂ عبادت سے نکل کر اپنے لوگوں کے پاس آئے تو ان کی طرف اشارہ کیا (اور سمجھایا) کہ تم صبح و شام (اللہ کی) تسبیح کیا کرو،\qt@no{11}}%
\qt@newcmd\qurantrans@ur@mmcclxii{اے یحیٰی! (ہماری) کتاب (تورات) کو مضبوطی سے تھامے رکھو، اور ہم نے انہیں بچپن ہی سے حکمت و بصیرت (نبوت) عطا فرما دی تھی،\qt@no{12}}%
\qt@newcmd\qurantrans@ur@mmcclxiii{اور اپنے لطفِ خاص سے (انہیں) درد و گداز اور پاکیزگی و طہارت (سے بھی نوازا تھا)، اور وہ بڑے پرہیزگار تھے،\qt@no{13}}%
\qt@newcmd\qurantrans@ur@mmcclxiv{اور اپنے ماں باپ کے ساتھ بڑی نیکی (اور خدمت) سے پیش آنے والے (تھے) اور (عام لڑکوں کی طرح) ہرگز سرکش و نافرمان نہ تھے،\qt@no{14}}%
\qt@newcmd\qurantrans@ur@mmcclxv{اور یحیٰی پر سلام ہو ان کے میلاد کے دن اور ان کی وفات کے دن اور جس دن وہ زندہ اٹھائے جائیں گے،\qt@no{15}}%
\qt@newcmd\qurantrans@ur@mmcclxvi{اور (اے حبیبِ مکرّم!) آپ کتاب (قرآن مجید) میں مریم (علیہا السلام) کا ذکر کیجئے، جب وہ اپنے گھر والوں سے الگ ہو کر (عبادت کے لئے خلوت اختیار کرتے ہوئے) مشرقی مکان میں آگئیں،\qt@no{16}}%
\qt@newcmd\qurantrans@ur@mmcclxvii{پس انہوں نے ان (گھر والوں اور لوگوں) کی طرف سے حجاب اختیار کر لیا (تاکہ حسنِ مطلق اپنا حجاب اٹھا دے)، تو ہم نے ان کی طرف اپنی روح (یعنی فرشتہ جبرائیل) کو بھیجا سو (جبرائیل) ان کے سامنے مکمل بشری صورت میں ظاہر ہوا،\qt@no{17}}%
\qt@newcmd\qurantrans@ur@mmcclxviii{مریم علیہا السلام نے) کہا: بیشک میں تجھ سے (خدائے) رحمان کی پناہ مانگتی ہوں اگر تو (اللہ سے) ڈرنے والا ہے،\qt@no{18}}%
\qt@newcmd\qurantrans@ur@mmcclxix{جبرائیل علیہ السلام نے) کہا: میں تو فقط تیرے رب کا بھیجا ہوا ہوں، (اس لئے آیا ہوں) کہ میں تجھے ایک پاکیزہ بیٹا عطا کروں،\qt@no{19}}%
\qt@newcmd\qurantrans@ur@mmcclxx{مریم علیہا السلام نے) کہا: میرے ہاں لڑکا کیسے ہوسکتا ہے جبکہ مجھے کسی انسان نے چھوا تک نہیں اور نہ ہی میں بدکار ہوں،\qt@no{20}}%
\qt@newcmd\qurantrans@ur@mmcclxxi{جبرائیل علیہ السلام نے) کہا: (تعجب نہ کر) ایسے ہی ہوگا، تیرے رب نے فرمایا ہے: یہ (کام) مجھ پر آسان ہے، اور (یہ اس لئے ہوگا) تاکہ ہم اسے لوگوں کے لئے نشانی اور اپنی جانب سے رحمت بنادیں، اور یہ امر (پہلے سے) طے شدہ ہے،\qt@no{21}}%
\qt@newcmd\qurantrans@ur@mmcclxxii{پس مریم نے اسے پیٹ میں لے لیا اور (آبادی سے) الگ ہوکر دور ایک مقام پر جا بیٹھیں،\qt@no{22}}%
\qt@newcmd\qurantrans@ur@mmcclxxiii{پھر دردِ زہ انہیں ایک کھجور کے تنے کی طرف لے آیا، وہ (پریشانی کے عالم میں) کہنے لگیں: اے کاش! میں پہلے سے مرگئی ہوتی اور بالکل بھولی بسری ہوچکی ہوتی،\qt@no{23}}%
\qt@newcmd\qurantrans@ur@mmcclxxiv{پھر ان کے نیچے کی جانب سے (جبرائیل نے یا خود عیسٰی علیہ السلام نے) انہیں آواز دی کہ تو رنجیدہ نہ ہو، بیشک تمہارے رب نے تمہارے نیچے ایک چشمہ جاری کر دیا ہے (یا تمہارے نیچے ایک عظیم المرتبہ انسان کو پیدا کر کے لٹا دیا ہے)،\qt@no{24}}%
\qt@newcmd\qurantrans@ur@mmcclxxv{اور کھجور کے تنے کو اپنی طرف ہلاؤ وہ تم پر تازہ پکی ہوئی کھجوریں گرا دے گا،\qt@no{25}}%
\qt@newcmd\qurantrans@ur@mmcclxxvi{سو تم کھاؤ اور پیو اور (اپنے حسین و جمیل فرزند کو دیکھ کر) آنکھیں ٹھنڈی کرو، پھر اگر تم کسی بھی انسان کو دیکھو تو (اشارے سے) کہہ دینا کہ میں نے (خدائے) رحمان کے لئے (خاموشی کے) روزہ کی نذر مانی ہوئی ہے سو میں آج کسی انسان سے قطعاً گفتگو نہیں کروں گی،\qt@no{26}}%
\qt@newcmd\qurantrans@ur@mmcclxxvii{پھر وہ اس (بچے) کو (گود میں) اٹھائے ہوئے اپنی قوم کے پاس آگئیں۔ وہ کہنے لگے: اے مریم! یقیناً تو بہت ہی عجیب چیز لائی ہے،\qt@no{27}}%
\qt@newcmd\qurantrans@ur@mmcclxxviii{اے ہارون کی بہن! نہ تیرا باپ برا آدمی تھا اور نہ ہی تیری ماں بدچلن تھی،\qt@no{28}}%
\qt@newcmd\qurantrans@ur@mmcclxxix{تو مریم نے اس (بچے) کی طرف اشارہ کیا، وہ کہنے لگے: ہم اس سے کس طرح بات کریں جو (ابھی) گہوارہ میں بچہ ہے،\qt@no{29}}%
\qt@newcmd\qurantrans@ur@mmcclxxx{بچہ خود) بول پڑا: بیشک میں اللہ کا بندہ ہوں، اس نے مجھے کتاب عطا فرمائی ہے اور مجھے نبی بنایا ہے،\qt@no{30}}%
\qt@newcmd\qurantrans@ur@mmcclxxxi{اور میں جہاں کہیں بھی رہوں اس نے مجھے سراپا برکت بنایا ہے اور میں جب تک (بھی) زندہ ہوں اس نے مجھے نماز اور زکوٰۃ کا حکم فرمایا ہے،\qt@no{31}}%
\qt@newcmd\qurantrans@ur@mmcclxxxii{اور اپنی والدہ کے ساتھ نیک سلوک کرنے والا (بنایا ہے) اور اس نے مجھے سرکش و بدبخت نہیں بنایا،\qt@no{32}}%
\qt@newcmd\qurantrans@ur@mmcclxxxiii{اور مجھ پر سلام ہو میرے میلاد کے دن، اور میری وفات کے دن، اور جس دن میں زندہ اٹھایا جاؤں گا،\qt@no{33}}%
\qt@newcmd\qurantrans@ur@mmcclxxxiv{یہ مریم (علیہا السلام) کے بیٹے عیسٰی (علیہ السلام) ہیں، (یہی) سچی بات ہے جس میں یہ لوگ شک کرتے ہیں،\qt@no{34}}%
\qt@newcmd\qurantrans@ur@mmcclxxxv{یہ اللہ کی شان نہیں کہ وہ (کسی کو اپنا) بیٹا بنائے، وہ (اس سے) پاک ہے، جب وہ کسی کام کا فیصلہ فرماتا ہے تو اسے صرف یہی حکم دیتا ہے: ”ہوجا“ بس وہ ہوجاتا ہے،\qt@no{35}}%
\qt@newcmd\qurantrans@ur@mmcclxxxvi{اور بیشک اللہ میرا (بھی) رب ہے اور تمہارا (بھی) رب ہے سو تم اسی کی عبادت کیا کرو، یہی سیدھا راستہ ہے،\qt@no{36}}%
\qt@newcmd\qurantrans@ur@mmcclxxxvii{پھر ان کے فرقے آپس میں اختلاف کرنے لگے، پس کافروں کے لئے (قیامت کے) بڑے دن کی حاضری سے تباہی ہے،\qt@no{37}}%
\qt@newcmd\qurantrans@ur@mmcclxxxviii{جس دن وہ ہمارے پاس حاضر ہوں گے تو کیسے (کان کھول کر) سنیں گے اور (آنکھیں پھاڑ پھاڑ کر) دیکھیں گے لیکن ظالم لوگ آج کھلی گمراہی میں (غرق) ہیں،\qt@no{38}}%
\qt@newcmd\qurantrans@ur@mmcclxxxix{اور آپ انہیں حسرت (و ندامت) کے دن سے ڈرائیے جب (ہر) بات کا فیصلہ کردیا جائے گا، مگر وہ غفلت (کی حالت) میں پڑے ہیں اور ایمان لاتے ہی نہیں،\qt@no{39}}%
\qt@newcmd\qurantrans@ur@mmccxc{بیشک ہم ہی زمین کے (بھی) وارث ہیں اور ان کے (بھی) جو اس پر (رہتے) ہیں اور (سب) ہماری ہی طرف لوٹائے جائیں گے،\qt@no{40}}%
\qt@newcmd\qurantrans@ur@mmccxci{اور آپ کتاب (قرآن مجید) میں ابراہیم (علیہ السلام) کا ذکر کیجئے، بیشک وہ بڑے صاحبِ صدق نبی تھے،\qt@no{41}}%
\qt@newcmd\qurantrans@ur@mmccxcii{جب انہوں نے اپنے باپ (یعنی چچا آزر سے جس نے آپ کے والد تارخ کے انتقال کے بعد آپ کو پالا تھا) سے کہا: اے میرے باپ! تم ان (بتوں) کی پرستش کیوں کرتے ہو جو نہ سن سکتے ہیں اور نہ دیکھ سکتے ہیں اور نہ تم سے کوئی (تکلیف دہ) چیز دور کرسکتے ہیں،\qt@no{42}}%
\qt@newcmd\qurantrans@ur@mmccxciii{اے ابّا! بیشک میرے پاس (بارگاہِ الٰہی سے) وہ علم آچکا ہے جو تمہارے پاس نہیں آیا تم میری پیروی کرو میں تمہیں سیدھی راہ دکھاؤں گا،\qt@no{43}}%
\qt@newcmd\qurantrans@ur@mmccxciv{اے ابّا! شیطان کی پرستش نہ کیا کرو، بیشک شیطان (خدائے) رحمان کا بڑا ہی نافرمان ہے،\qt@no{44}}%
\qt@newcmd\qurantrans@ur@mmccxcv{اے ابّا! بیشک میں اس بات سے ڈرتا ہوں کہ تمہیں (خدائے) رحمان کا عذاب پہنچے اور تم شیطان کے ساتھی بن جاؤ،\qt@no{45}}%
\qt@newcmd\qurantrans@ur@mmccxcvi{آزر نے) کہا: اے ابراہیم! کیا تم میرے معبودوں سے روگرداں ہو؟ اگر واقعی تم (اس مخالفت سے) باز نہ آئے تو میں تمہیں ضرور سنگ سار کر دوں گا اور ایک طویل عرصہ کے لئے تم مجھ سے الگ ہوجاؤ،\qt@no{46}}%
\qt@newcmd\qurantrans@ur@mmccxcvii{ابراہیم علیہ السلام نے) کہا: (اچھا) تمہیں سلام، میں اب (بھی) اپنے رب سے تمہارے لئے بخشش مانگوں گا، بیشک وہ مجھ پر بہت مہربان ہے (شاید تمہیں ہدایت عطا فرما دے)،\qt@no{47}}%
\qt@newcmd\qurantrans@ur@mmccxcviii{اور میں تم (سب) سے اور ان (بتوں) سے جنہیں تم اللہ کے سوا پوجتے ہو کنارہ کش ہوتا ہوں اور اپنے رب کی عبادت میں (یک سُو ہو کر) مصروف ہوتا ہوں، امید ہے میں اپنے رب کی عبادت کے باعث محرومِ (کرم) نہ رہوں گا،\qt@no{48}}%
\qt@newcmd\qurantrans@ur@mmccxcix{پھر جب ابراہیم (علیہ السلام) ان لوگوں سے اور ان (بتوں) سے جن کی وہ اﷲ کے سوا پرستش کرتے تھے (میل ملاپ چھوڑ کر) بالکل جدا ہو گئے (تو) ہم نے انہیں اسحاق (بیٹے) اور یعقوب (پوتے، علیھما السلام) سے نوازا، اور ہم نے ہر (دو) کو نبی بنایا،\qt@no{49}}%
\qt@newcmd\qurantrans@ur@mmccc{اور ہم نے ان (سب) کو اپنی (خاص) رحمت بخشی اور ہم نے ان کے لئے (ہر آسمانی مذہب کے ماننے والوں میں) تعریف و ستائش کی زبان بلند کردی،\qt@no{50}}%
\qt@newcmd\qurantrans@ur@mmccci{اور (اس) کتاب میں موسٰی (علیہ السلام) کا ذکر کیجئے، بیشک وہ (نفس کی گرفت سے خلاصی پاکر) برگزیدہ ہو چکے تھے اور صاحبِ رسالت نبی تھے،\qt@no{51}}%
\qt@newcmd\qurantrans@ur@mmcccii{اور ہم نے انہیں (کوہِ) طور کی داہنی جانب سے ندا دی اور راز و نیاز کی باتیں کرنے کے لئے ہم نے انہیں قربتِ (خاص) سے نوازا،\qt@no{52}}%
\qt@newcmd\qurantrans@ur@mmccciii{اور ہم نے اپنی رحمت سے ان کے بھائی ہارون (علیہ السلام) کو نبی بنا کر انہیں بخشا (تاکہ وہ ان کے کام میں معاون ہوں)،\qt@no{53}}%
\qt@newcmd\qurantrans@ur@mmccciv{اور آپ (اس) کتاب میں اسماعیل (علیہ السلام) کا ذکر کریں، بیشک وہ وعدہ کے سچے تھے اور صاحبِ رسالت نبی تھے،\qt@no{54}}%
\qt@newcmd\qurantrans@ur@mmcccv{اور وہ اپنے گھر والوں کو نماز اور زکوٰۃ کا حکم دیتے تھے، اور وہ اپنے رب کے حضور مقام مرضیّہ پر (فائز) تھے (یعنی ان کا رب ان سے راضی تھا)،\qt@no{55}}%
\qt@newcmd\qurantrans@ur@mmcccvi{اور (اس) کتاب میں ادریس (علیہ السلام) کا ذکر کیجئے، بیشک وہ بڑے صاحبِ صدق نبی تھے،\qt@no{56}}%
\qt@newcmd\qurantrans@ur@mmcccvii{اور ہم نے انہیں بلند مقام پر اٹھا لیا تھا،\qt@no{57}}%
\qt@newcmd\qurantrans@ur@mmcccviii{یہ وہ لوگ ہیں جن پر اللہ نے انعام فرمایا ہے زمرۂ انبیاء میں سے آدم (علیہ السلام) کی اولاد سے ہیں اور ان (مومنوں) میں سے ہیں جنہیں ہم نے نوح (علیہ السلام) کے ساتھ کشتی میں (طوفان سے بچا کر) اٹھا لیا تھا، اور ابراہیم (علیہ السلام) کی اور اسرائیل (یعنی یعقوب علیہ السلام) کی اولاد سے ہیں اور ان (منتخب) لوگوں میں سے ہیں جنہیں ہم نے ہدایت بخشی اور برگزیدہ بنایا، جب ان پر (خدائے) رحمان کی آیتوں کی تلاوت کی جاتی ہے وہ سجدہ کرتے ہوئے اور (زار و قطار) روتے ہوئے گر پڑتے ہیں،\qt@no{58}}%
\qt@newcmd\qurantrans@ur@mmcccix{پھر ان کے بعد وہ ناخلف جانشین ہوئے جنہوں نے نمازیں ضائع کردیں اور خواہشاتِ (نفسانی) کے پیرو ہوگئے تو عنقریب وہ آخرت کے عذاب (دوزخ کی وادئ غی) سے دوچار ہوں گے،\qt@no{59}}%
\qt@newcmd\qurantrans@ur@mmcccx{سوائے اس شخص کے جس نے توبہ کر لی اور ایمان لے آیا اور نیک عمل کرتا رہا تو یہ لوگ جنت میں داخل ہوں گے اور ان پر کچھ بھی ظلم نہیں کیا جائے گا،\qt@no{60}}%
\qt@newcmd\qurantrans@ur@mmcccxi{ایسے سدا بہار باغات میں (رہیں گے) جن کا (خدائے) رحمان نے اپنے بندوں سے غیب میں وعدہ کیا ہے، بیشک اس کا وعدہ پہنچنے ہی والا ہے،\qt@no{61}}%
\qt@newcmd\qurantrans@ur@mmcccxii{وہ اس میں کوئی بے ہودہ بات نہیں سنیں گے مگر (ہر طرف سے) سلام (سنائی دے گا)، ان کے لئے ان کا رزق اس میں صبح و شام (میسر) ہوگا،\qt@no{62}}%
\qt@newcmd\qurantrans@ur@mmcccxiii{یہ وہ جنت ہے جس کا ہم اپنے بندوں میں سے اسے وارث بنائیں گے جو متقی ہوگا،\qt@no{63}}%
\qt@newcmd\qurantrans@ur@mmcccxiv{اور (جبرائیل میرے حبیب صلی اللہ علیہ وآلہ وسلم سے کہو کہ) ہم آپ کے رب کے حکم کے بغیر (زمین پر) نہیں اتر سکتے، جو کچھ ہمارے آگے ہے اور جو کچھ ہمارے پیچھے ہے اور جو کچھ اس کے درمیان ہے (سب) اسی کا ہے، اور آپ کا رب (آپ کو) کبھی بھی بھولنے والا نہیں ہے،\qt@no{64}}%
\qt@newcmd\qurantrans@ur@mmcccxv{وہ) آسمانوں اور زمین کا اور جو کچھ ان دو کے درمیان ہے (سب) کا رب ہے پس اس کی عبادت کیجئے اور اس کی عبادت میں ثابت قدم رہئے، کیا آپ اس کا کوئی ہم نام جانتے ہیں،\qt@no{65}}%
\qt@newcmd\qurantrans@ur@mmcccxvi{اور انسان کہتا ہے: کیا جب میں مرجاؤں گا تو عنقریب زندہ کر کے نکالا جاؤں گا،\qt@no{66}}%
\qt@newcmd\qurantrans@ur@mmcccxvii{کیا انسان یہ بات یاد نہیں کرتا کہ ہم نے اس سے پہلے (بھی) اسے پیدا کیا تھا جبکہ وہ کوئی چیز ہی نہ تھا،\qt@no{67}}%
\qt@newcmd\qurantrans@ur@mmcccxviii{پس آپ کے رب کی قسم ہم ان کو اور (جملہ) شیطانوں کو (قیامت کے دن) ضرور جمع کریں گے پھر ہم ان (سب) کو جہنم کے گرد ضرور حاضر کر دیں گے اس طرح کہ وہ گھٹنوں کے بل گرے پڑے ہوں گے،\qt@no{68}}%
\qt@newcmd\qurantrans@ur@mmcccxix{پھر ہم ہر گروہ سے ایسے شخص کو ضرور چن کر نکال لیں گے جو ان میں سے (خدائے) رحمان پر سب سے زیادہ نافرمان و سرکش ہوگا،\qt@no{69}}%
\qt@newcmd\qurantrans@ur@mmcccxx{پھر ہم ان لوگوں کو خوب جانتے ہیں جو دوزخ میں جھونکے جانے کے زیادہ سزاوار ہیں،\qt@no{70}}%
\qt@newcmd\qurantrans@ur@mmcccxxi{اور تم میں سے کوئی شخص نہیں ہے مگر اس کا اس (دوزخ) پر سے گزر ہونے والا ہے، یہ (وعدہ) قطعی طور پر آپ کے رب کے ذمہ ہے جو ضرور پورا ہوکر رہے گا،\qt@no{71}}%
\qt@newcmd\qurantrans@ur@mmcccxxii{پھر ہم پرہیزگاروں کو نجات دے دیں گے اور ظالموں کو اس میں گھٹنوں کے بل گرا ہوا چھوڑ دیں گے،\qt@no{72}}%
\qt@newcmd\qurantrans@ur@mmcccxxiii{اور جب ان پر ہماری روشن آیتیں تلاوت کی جاتی ہیں تو کافر لوگ ایمان والوں سے کہتے ہیں: (اسی دنیا میں دیکھ لو! ہم) دونوں گروہوں میں سے کس کی رہائش گاہ بہتر اور مجلس خوب تر ہے،\qt@no{73}}%
\qt@newcmd\qurantrans@ur@mmcccxxiv{اور ہم نے ان سے پہلے کتنی ہی قوموں کو ہلاک کر ڈالا جو ساز و سامانِ زندگی اور نمود و نمائش کے لحاظ سے (ان سے بھی) کہیں بہتر تھے،\qt@no{74}}%
\qt@newcmd\qurantrans@ur@mmcccxxv{فرما دیجئے: جو شخص گمراہی میں مبتلا ہو تو (خدائے) رحمان (بھی) اسے عمر و عیش میں خوب مہلت دیتا رہتا ہے، یہاں تک کہ جب وہ لوگ اس چیز کو دیکھ لیں گے جس کا ان سے وعدہ کیا گیا ہے خواہ عذاب اور خواہ قیامت، تب وہ اس شخص کو جان لیں گے جو رہائش گاہ کے اعتبار سے (بھی) برا ہے اور لشکر کے اعتبار سے (بھی) کمزور تر ہے،\qt@no{75}}%
\qt@newcmd\qurantrans@ur@mmcccxxvi{اور اللہ ہدایت یافتہ لوگوں کی ہدایت میں مزید اضافہ فرماتا ہے، اور باقی رہنے والے نیک اعمال آپ کے رب کے نزدیک اجر و ثواب میں (بھی) بہتر ہیں اور انجام میں (بھی) خوب تر ہیں،\qt@no{76}}%
\qt@newcmd\qurantrans@ur@mmcccxxvii{کیا آپ نے اس شخص کو دیکھا ہے جس نے ہماری آیتوں سے کفر کیا اور کہنے لگا: مجھے (قیامت کے روز بھی اسی طرح) مال و اولاد ضرور دیئے جائیں گے،\qt@no{77}}%
\qt@newcmd\qurantrans@ur@mmcccxxviii{وہ غیب پر مطلع ہے یا اس نے (خدائے) رحمان سے (کوئی) عہد لے رکھا ہے،\qt@no{78}}%
\qt@newcmd\qurantrans@ur@mmcccxxix{ہرگز نہیں! اب ہم وہ سب کچھ لکھتے رہیں گے جو وہ کہتا ہے اور اس کے لئے عذاب (پر عذاب) خوب بڑھاتے چلے جائیں گے،\qt@no{79}}%
\qt@newcmd\qurantrans@ur@mmcccxxx{اور (مرنے کے بعد) جو یہ کہہ رہا ہے اس کے ہم ہی وارث ہوں گے اور وہ ہمارے پاس تنہا آئے گا (اس کے مال و اولاد ساتھ نہ ہوں گے)،\qt@no{80}}%
\qt@newcmd\qurantrans@ur@mmcccxxxi{اور انہوں نے اللہ کے سوا (کئی اور) معبود بنا لئے ہیں تاکہ وہ ان کے لئے باعثِ عزت ہوں،\qt@no{81}}%
\qt@newcmd\qurantrans@ur@mmcccxxxii{ہرگز (ایسا) نہیں ہے، عنقریب وہ (معبودانِ باطلہ خود) ان کی پرستش کا انکار کر دیں گے اور ان کے دشمن ہوجائیں گے،\qt@no{82}}%
\qt@newcmd\qurantrans@ur@mmcccxxxiii{کیا آپ نے نہیں دیکھا کہ ہم نے شیطانوں کو کافروں پر بھیجا ہے وہ انہیں ہر وقت (اسلام کی مخالفت پر) اکساتے رہتے ہیں،\qt@no{83}}%
\qt@newcmd\qurantrans@ur@mmcccxxxiv{سو آپ ان پر (عذاب کے لئے) جلدی نہ کریں ہم تو خود ہی ان کے (انجام کے) لئے دن شمار کرتے رہتے ہیں،\qt@no{84}}%
\qt@newcmd\qurantrans@ur@mmcccxxxv{جس دن ہم پرہیزگاروں کو جمع کر کے (خدائے) رحمان کے حضور (معزز مہمانوں کی طرح) سواریوں پر لے جائیں گے،\qt@no{85}}%
\qt@newcmd\qurantrans@ur@mmcccxxxvi{اور ہم مجرموں کو جہنم کی طرف پیاسا ہانک کر لے جائیں گے،\qt@no{86}}%
\qt@newcmd\qurantrans@ur@mmcccxxxvii{اس دن) لوگ شفاعت کے مالک نہ ہوں گے سوائے ان کے جنہوں نے (خدائے) رحمان سے وعدۂ (شفاعت) لے لیا ہے،\qt@no{87}}%
\qt@newcmd\qurantrans@ur@mmcccxxxviii{اور (کافر) کہتے ہیں کہ (خدائے) رحمان نے (اپنے لئے) لڑکا بنا لیا ہے،\qt@no{88}}%
\qt@newcmd\qurantrans@ur@mmcccxxxix{اے کافرو!) بیشک تم بہت ہی سخت اور عجیب بات (زبان پر) لائے ہو،\qt@no{89}}%
\qt@newcmd\qurantrans@ur@mmcccxl{کچھ بعید نہیں کہ اس (بہتان) سے آسمان پھٹ پڑیں اور زمین شق ہو جائے اور پہاڑ ریزہ ریزہ ہو کر گر جائیں،\qt@no{90}}%
\qt@newcmd\qurantrans@ur@mmcccxli{کہ انہوں نے (خدائے) رحمان کے لئے لڑکے کا دعوٰی کیا ہے،\qt@no{91}}%
\qt@newcmd\qurantrans@ur@mmcccxlii{اور (خدائے) رحمان کے شایانِ شان نہیں ہے کہ وہ (کسی کو اپنا) لڑکا بنائے،\qt@no{92}}%
\qt@newcmd\qurantrans@ur@mmcccxliii{آسمانوں اور زمین میں جو کوئی بھی (آباد) ہیں (خواہ فرشتے ہیں یا جن و انس) وہ اللہ کے حضور محض بندہ کے طور پر حاضر ہونے والے ہیں،\qt@no{93}}%
\qt@newcmd\qurantrans@ur@mmcccxliv{بیشک اس (اللہ) نے انہیں اپنے (علم کے) احاطہ میں لے لیا ہے اور انہیں(ایک ایک کرکے) پوری طرح شمار کر رکھا ہے،\qt@no{94}}%
\qt@newcmd\qurantrans@ur@mmcccxlv{اور ان میں سے ہر ایک قیامت کے دن اس کے حضور تنہا آنے والا ہے،\qt@no{95}}%
\qt@newcmd\qurantrans@ur@mmcccxlvi{بیشک جو لوگ ایمان لائے اور نیک عمل کئے تو (خدائے) رحمان ان کے لئے (لوگوں کے) دلوں میں محبت پیدا فرما دے گا،\qt@no{96}}%
\qt@newcmd\qurantrans@ur@mmcccxlvii{سو بیشک ہم نے اس (قرآن) کو آپ کی زبان میں ہی آسان کر دیا ہے تاکہ آپ اس کے ذریعہ پرہیزگاروں کو خوشخبری سنا سکیں اور اس کے ذریعہ جھگڑالو قوم کو ڈر سنا سکیں،\qt@no{97}}%
\qt@newcmd\qurantrans@ur@mmcccxlviii{اور ہم نے ان سے پہلے کتنی ہی قوموں کو ہلاک کر دیا ہے، کیا آپ ان میں سے کسی کا وجود بھی دیکھتے ہیں یا کسی کی کوئی آہٹ بھی سنتے ہیں،\qt@no{98}}%
\qt@newcmd\qurantrans@ur@mmcccxlix{\basmalahur طا، ہا (حقیقی معنی اﷲ اور رسول صلی اللہ علیہ وآلہ وسلم ہی بہتر جانتے ہیں)،\qt@no{1}}%
\qt@newcmd\qurantrans@ur@mmcccl{اے محبوبِ مکرّم!) ہم نے آپ پر قرآن (اس لئے) نازل نہیں فرمایا کہ آپ مشقت میں پڑ جائیں،\qt@no{2}}%
\qt@newcmd\qurantrans@ur@mmcccli{مگر (اسے) اس شخص کے لئے نصیحت (بنا کر اتارا) ہے جو (اپنے رب سے) ڈرتا ہے،\qt@no{3}}%
\qt@newcmd\qurantrans@ur@mmccclii{یہ) اس (اللہ) کی طرف سے اتارا ہوا ہے جس نے زمین اور بلند و بالا آسمان پیدا فرمائے،\qt@no{4}}%
\qt@newcmd\qurantrans@ur@mmcccliii{وہ) نہایت رحمت والا (ہے) جو عرش (یعنی جملہ نظام ہائے کائنات کے اقتدار) پر متمکّن ہوگیا،\qt@no{5}}%
\qt@newcmd\qurantrans@ur@mmcccliv{پس) جو کچھ آسمانوں (کی بالائی نوری کائناتوں اور خلائی مادی کائناتوں) میں ہے اور جو کچھ زمین میں ہے اور جو کچھ ان دونوں کے درمیان (فضائی اور ہوائی کرّوں میں) ہے اور جو کچھ سطح ارضی کے نیچے آخری تہہ تک ہے سب اسی کے (نظام اور قدرت کے تابع) ہیں،\qt@no{6}}%
\qt@newcmd\qurantrans@ur@mmccclv{اور اگر آپ ذکر و دعا میں جہر (یعنی آواز بلند) کریں (تو بھی کوئی حرج نہیں) وہ تو سِرّ (یعنی دلوں کے رازوں) اور اخفی (یعنی سب سے زیادہ مخفی بھیدوں) کو بھی جانتا ہے (تو بلند التجاؤں کو کیوں نہیں سنے گا)،\qt@no{7}}%
\qt@newcmd\qurantrans@ur@mmccclvi{اللہ (اسی کا اسمِ ذات) ہے جس کے سوا کوئی معبود نہیں (گویا تم اسی کا اثبات کرو اور باقی سب جھوٹے معبودوں کی نفی کر دو)، اس کے لئے (اور بھی) بہت خوبصورت نام ہیں (جو اس کی حسین و جمیل صفات کا پتہ دیتے ہیں)،\qt@no{8}}%
\qt@newcmd\qurantrans@ur@mmccclvii{اور کیا آپ کے پاس موسٰی (علیہ السلام) کی خبر آچکی ہے،\qt@no{9}}%
\qt@newcmd\qurantrans@ur@mmccclviii{جب موسٰی (علیہ السلام) نے (مدین سے واپس مصر آتے ہوئے) ایک آگ دیکھی تو انہوں نے اپنے گھر والوں سے کہا: تم یہاں ٹھہرے رہو میں نے ایک آگ دیکھی ہے (یا میں نے ایک آگ میں انس و محبت کا شعلہ پایا ہے) شاید میں اس میں سے کوئی چنگاری تمہارے لئے (بھی) لے آؤں یا میں اس آگ پر (سے وہ) رہنمائی پا لوں (جس کی تلاش میں سرگرداں ہوں)،\qt@no{10}}%
\qt@newcmd\qurantrans@ur@mmccclix{پھر جب وہ اس (آگ) کے پاس پہنچے تو ندا کی گئی: اے موسٰی،\qt@no{11}}%
\qt@newcmd\qurantrans@ur@mmccclx{بیشک میں ہی تمہارا رب ہوں سو تم اپنے جوتے اتار دو، بیشک تم طوٰی کی مقدس وادی میں ہو،\qt@no{12}}%
\qt@newcmd\qurantrans@ur@mmccclxi{اور میں نے تمہیں (اپنی رسالت کے لئے) چن لیا ہے پس تم پوری توجہ سے سنو جو تمہیں وحی کی جا رہی ہے،\qt@no{13}}%
\qt@newcmd\qurantrans@ur@mmccclxii{بیشک میں ہی اللہ ہوں میرے سوا کوئی معبود نہیں سو تم میری عبادت کیا کرو اور میری یاد کی خاطر نماز قائم کیا کرو،\qt@no{14}}%
\qt@newcmd\qurantrans@ur@mmccclxiii{بیشک قیامت کی گھڑی آنے والی ہے، میں اسے پوشیدہ رکھنا چاہتا ہوں تاکہ ہر جان کو اس (عمل) کا بدلہ دیا جائے جس کے لئے وہ کوشاں ہے،\qt@no{15}}%
\qt@newcmd\qurantrans@ur@mmccclxiv{پس تمہیں وہ شخص اس (کے دھیان) سے روکے نہ رکھے جو (خود) اس پر ایمان نہیں رکھتا اور اپنی خواہشِ (نفس) کا پیرو ہے ورنہ تم (بھی) ہلاک ہوجاؤ گے،\qt@no{16}}%
\qt@newcmd\qurantrans@ur@mmccclxv{اور یہ تمہارے داہنے ہاتھ میں کیا ہے اے موسی،\qt@no{17}}%
\qt@newcmd\qurantrans@ur@mmccclxvi{انہوں نے کہا: یہ میری لاٹھی ہے، میں اس پر ٹیک لگاتا ہوں اور میں اس سے اپنی بکریوں کے لئے پتے جھاڑتا ہوں اور اس میں میرے لئے کئی اور فائدے بھی ہیں،\qt@no{18}}%
\qt@newcmd\qurantrans@ur@mmccclxvii{ارشاد ہوا: اے موسٰی! اسے (زمین پر) ڈال دو،\qt@no{19}}%
\qt@newcmd\qurantrans@ur@mmccclxviii{پس انہوں نے اسے (زمین پر) ڈال دیا تو وہ اچانک سانپ ہوگیا (جو ادھر ادھر) دوڑنے لگا،\qt@no{20}}%
\qt@newcmd\qurantrans@ur@mmccclxix{ارشاد فرمایا: اسے پکڑ لو اور مت ڈرو ہم اسے ابھی اس کی پہلی حالت پر لوٹا دیں گے،\qt@no{21}}%
\qt@newcmd\qurantrans@ur@mmccclxx{اور (حکم ہوا:) اپنا ہاتھ اپنی بغل میں دبا لو وہ بغیر کسی بیماری کے سفید چمک دار ہو کر نکلے گا (یہ) دوسری نشانی ہے،\qt@no{22}}%
\qt@newcmd\qurantrans@ur@mmccclxxi{یہ اس لئے (کر رہے ہیں) کہ ہم تمہیں اپنی (قدرت کی) بڑی بڑی نشانیاں دکھائیں،\qt@no{23}}%
\qt@newcmd\qurantrans@ur@mmccclxxii{تم فرعون کے پاس جاؤ وہ (نافرمانی و سرکشی میں) حد سے بڑھ گیا ہے،\qt@no{24}}%
\qt@newcmd\qurantrans@ur@mmccclxxiii{موسٰی علیہ السلام نے) عرض کیا: اے میرے رب! میرے لئے میرا سینہ کشادہ فرما دے،\qt@no{25}}%
\qt@newcmd\qurantrans@ur@mmccclxxiv{اور میرا کارِ (رسالت) میرے لئے آسان فرما دے،\qt@no{26}}%
\qt@newcmd\qurantrans@ur@mmccclxxv{اور میری زبان کی گرہ کھول دے،\qt@no{27}}%
\qt@newcmd\qurantrans@ur@mmccclxxvi{کہ لوگ میری بات (آسانی سے) سمجھ سکیں،\qt@no{28}}%
\qt@newcmd\qurantrans@ur@mmccclxxvii{اور میرے گھر والوں میں سے میرا ایک وزیر بنا دے،\qt@no{29}}%
\qt@newcmd\qurantrans@ur@mmccclxxviii{وہ) میرا بھائی ہارون (علیہ السلام) ہو،\qt@no{30}}%
\qt@newcmd\qurantrans@ur@mmccclxxix{اس سے میری کمرِ ہمت مضبوط فرما دے،\qt@no{31}}%
\qt@newcmd\qurantrans@ur@mmccclxxx{اور اسے میرے کارِ (رسالت) میں شریک فرما دے،\qt@no{32}}%
\qt@newcmd\qurantrans@ur@mmccclxxxi{تاکہ ہم (دونوں) کثرت سے تیری تسبیح کیا کریں،\qt@no{33}}%
\qt@newcmd\qurantrans@ur@mmccclxxxii{اور ہم کثرت سے تیرا ذکر کیا کریں،\qt@no{34}}%
\qt@newcmd\qurantrans@ur@mmccclxxxiii{بیشک تو ہمیں (سب حالات کے تناظر میں) خوب دیکھنے والا ہے،\qt@no{35}}%
\qt@newcmd\qurantrans@ur@mmccclxxxiv{اللہ نے) ارشاد فرمایا: اے موسٰی! تمہاری ہر مانگ تمہیں عطا کردی،\qt@no{36}}%
\qt@newcmd\qurantrans@ur@mmccclxxxv{اور بیشک ہم نے تم پر ایک اور بار (اس سے پہلے بھی) احسان فرمایا تھا،\qt@no{37}}%
\qt@newcmd\qurantrans@ur@mmccclxxxvi{جب ہم نے تمہاری والدہ کے دل میں وہ بات ڈال دی جو ڈالی گئی تھی،\qt@no{38}}%
\qt@newcmd\qurantrans@ur@mmccclxxxvii{کہ تم اس (موسٰی علیہ السلام) کو صندوق میں رکھ دو پھر اس (صندوق) کو دریا میں ڈال دو پھر دریا اسے کنارے کے ساتھ آلگائے گا، اسے میرا دشمن اور اس کا دشمن اٹھا لے گا، اور میں نے تجھ پر اپنی جناب سے (خاص) محبت کا پرتَو ڈال دیا ہے (یعنی تیری صورت کو اس قدر پیاری اور من موہنی بنا دیا ہے کہ جو تجھے دیکھے گا فریفتہ ہو جائے گا)، اور (یہ اس لئے کیا) تاکہ تمہاری پرورش میری آنکھوں کے سامنے کی جائے،\qt@no{39}}%
\qt@newcmd\qurantrans@ur@mmccclxxxviii{اور جب تمہاری بہن (اجنبی بن کر) چلتے چلتے (فرعون کے گھر والوں سے) کہنے لگی: کیا میں تمہیں کسی (ایسی عورت) کی نشاندہی کر دوں جو اس (بچہ) کی پرورش کر دے، پھر ہم نے تم کو تمہاری والدہ کی طرف (پرورش کے بہانے) واپس لوٹا دیا تاکہ اس کی آنکھ بھی ٹھنڈی ہوتی رہے اور وہ رنجیدہ بھی نہ ہو، اور تم نے (قومِ فرعون کے) ایک (کافر) شخص کو مار ڈالا تھا پھر ہم نے تمہیں (اس) غم سے (بھی) نجات بخشی اور ہم نے تمہیں بہت سی آزمائشوں سے گزار کر خوب جانچا، پھر تم کئی سال اہلِ مدین میں ٹھہرے رہے پھر تم (اللہ کے) مقرر کردہ وقت پر (یہاں) آگئے اے موسٰی! (اس وقت ان کی عمر ٹھیک چالیس برس ہوگئی تھی)،\qt@no{40}}%
\qt@newcmd\qurantrans@ur@mmccclxxxix{اور (اب) میں نے تمہیں اپنے (امرِ رسالت اور خصوصی انعام کے) لئے چن لیا ہے،\qt@no{41}}%
\qt@newcmd\qurantrans@ur@mmcccxc{تم اور تمہارا بھائی (ہارون) میری نشانیاں لے کر جاؤ اور میری یاد میں سستی نہ کرنا،\qt@no{42}}%
\qt@newcmd\qurantrans@ur@mmcccxci{تم دونوں فرعون کے پاس جاؤ بیشک وہ سرکشی میں حد سے گزر چکا ہے،\qt@no{43}}%
\qt@newcmd\qurantrans@ur@mmcccxcii{سو تم دونوں اس سے نرم (انداز میں) گفتگو کرنا شاید وہ نصیحت قبول کر لے یا (میرے غضب سے) ڈرنے لگے،\qt@no{44}}%
\qt@newcmd\qurantrans@ur@mmcccxciii{دونوں نے عرض کیا: اے ہمارے رب! بیشک ہمیں اندیشہ ہے کہ وہ ہم پر زیادتی کرے (گا) یا (زیادہ) سرکش ہوجائے (گا)،\qt@no{45}}%
\qt@newcmd\qurantrans@ur@mmcccxciv{ارشاد فرمایا: تم دونوں نہ ڈرو بیشک میں تم دونوں کے ساتھ ہوں میں (سب کچھ) سنتا اور دیکھتا ہوں،\qt@no{46}}%
\qt@newcmd\qurantrans@ur@mmcccxcv{پس تم دونوں اس کے پاس جاؤ اور کہو: ہم تیرے رب کے بھیجے ہوئے (رسول) ہیں سو تو بنی اسرائیل کو (اپنی غلامی سے آزاد کرکے) ہمارے ساتھ بھیج دے اور انہیں (مزید) اذیت نہ پہنچا، بیشک ہم تیرے پاس تیرے رب کی طرف سے نشانی لے کر آئے ہیں، اور اس شخص پر سلامتی ہو جس نے ہدایت کی پیروی کی،\qt@no{47}}%
\qt@newcmd\qurantrans@ur@mmcccxcvi{بیشک ہماری طرف وحی بھیجی گئی ہے کہ عذاب (ہر) اس شخص پر ہوگا جو (رسول کو) جھٹلائے گا اور (اس سے) منہ پھیر لے گا،\qt@no{48}}%
\qt@newcmd\qurantrans@ur@mmcccxcvii{فرعون نے) کہا: تو اے موسٰی! تم دونوں کا رب کون ہے،\qt@no{49}}%
\qt@newcmd\qurantrans@ur@mmcccxcviii{موسٰی علیہ السلام نے) فرمایا: ہمارا رب وہی ہے جس نے ہر چیز کو (اس کے لائق) وجود بخشا پھر (اس کے حسبِ حال) اس کی رہنمائی کی،\qt@no{50}}%
\qt@newcmd\qurantrans@ur@mmcccxcix{فرعون نے) کہا: تو (ان) پہلی قوموں کا کیا حال ہوا (جو تمہارے رب کو نہیں مانتی تھیں)،\qt@no{51}}%
\qt@newcmd\qurantrans@ur@mmcd{موسٰی علیہ السلام نے) فرمایا: ان کا علم میرے رب کے پاس کتاب میں (محفوظ) ہے، نہ میرا رب بھٹکتا ہے اور نہ بھولتا ہے،\qt@no{52}}%
\qt@newcmd\qurantrans@ur@mmcdi{وہی ہے جس نے زمین کو تمہارے رہنے کی جگہ بنایا اور اس میں تمہارے (سفر کرنے کے) لئے راستے بنائے اور آسمان کی جانب سے پانی اتارا، پھر ہم نے اس (پانی) کے ذریعے (زمین سے) انواع و اقسام کی نباتات کے جوڑے نکال دیئے،\qt@no{53}}%
\qt@newcmd\qurantrans@ur@mmcdii{تم کھاؤ اور اپنے مویشیوں کو چراؤ، بیشک اس میں دانش مندوں کے لئے نشانیاں ہیں،\qt@no{54}}%
\qt@newcmd\qurantrans@ur@mmcdiii{زمین کی) اسی (مٹی) سے ہم نے تمہیں پیدا کیا اور اسی میں ہم تمہیں لوٹائیں گے اور اسی سے ہم تمہیں دوسری مرتبہ (پھر) نکالیں گے،\qt@no{55}}%
\qt@newcmd\qurantrans@ur@mmcdiv{اور بیشک ہم نے اس (فرعون) کو اپنی ساری نشانیاں (جو موسٰی اور ہارون علیھما السلام کو دی گئی تھیں) دکھائیں مگر اس نے جھٹلایا اور (ماننے سے) انکار کر دیا،\qt@no{56}}%
\qt@newcmd\qurantrans@ur@mmcdv{اس نے کہا: اے موسٰی! کیا تم ہمارے پاس اس لئے آئے ہو کہ تم اپنے جادو کے ذریعہ ہمیں ہمارے ملک سے نکال دو،\qt@no{57}}%
\qt@newcmd\qurantrans@ur@mmcdvi{سو ہم بھی تمہارے پاس اسی کی مانند جادو لائیں گے تم ہمارے اور اپنے درمیان (مقابلہ کے لئے) وعدہ طے کرلو جس کی خلاف ورزی نہ ہم کریں اور نہ ہی تم، (مقابلہ کی جگہ) کھلا اور ہموار میدان ہو،\qt@no{58}}%
\qt@newcmd\qurantrans@ur@mmcdvii{موسٰی علیہ السلام نے) فرمایا: تمہارے وعدے کا دن یومِ عید (سالانہ جشن کا دن) ہے اور یہ کہ (اس دن) سارے لوگ چاشت کے وقت جمع ہوجائیں،\qt@no{59}}%
\qt@newcmd\qurantrans@ur@mmcdviii{پھر فرعون (مجلس سے) واپس مڑ گیا سو اس نے اپنے مکر و فریب (کی تدبیروں) کو اکٹھا کیا پھر (مقررہ وقت پر) آگیا،\qt@no{60}}%
\qt@newcmd\qurantrans@ur@mmcdix{موسٰی (علیہ السلام) نے ان (جادوگروں) سے فرمایا: تم پر افسوس (خبردار!) اللہ پر جھوٹا بہتان مت باندھنا ورنہ وہ تمہیں عذاب کے ذریعے تباہ و برباد کردے گا اور واقعی وہ شخص نامراد ہوا جس نے (اللہ پر) بہتان باندھا،\qt@no{61}}%
\qt@newcmd\qurantrans@ur@mmcdx{چنانچہ وہ (جادوگر) اپنے معاملہ میں باہم جھگڑ پڑے اور چپکے چپکے سرگوشیاں کرنے لگے،\qt@no{62}}%
\qt@newcmd\qurantrans@ur@mmcdxi{کہنے لگے: یہ دونوں واقعی جادوگر ہیں جو یہ ارادہ رکھتے ہیں کہ تمہیں جادو کے ذریعہ تمہاری سر زمین سے نکال باہر کریں اور تمہارے مثالی مذہب و ثقافت کو نابود کردیں،\qt@no{63}}%
\qt@newcmd\qurantrans@ur@mmcdxii{انہوں نے باہم فیصلہ کیا) پس تم (جادو کی) اپنی ساری تدابیر جمع کر لو پھر قطار باندھ کر (اکٹھے ہی) میدان میں آجاؤ، اور آج کے دن وہی کامیاب رہے گا جو غالب آجائے گا،\qt@no{64}}%
\qt@newcmd\qurantrans@ur@mmcdxiii{جادوگر) بولے: اے موسٰی! یا تو تم (اپنی چیز) ڈالو اور یا ہم ہی پہلے ڈالنے والے ہوجائیں،\qt@no{65}}%
\qt@newcmd\qurantrans@ur@mmcdxiv{موسٰی علیہ السلام نے) فرمایا: بلکہ تم ہی ڈال دو، پھر کیا تھا اچانک ان کی رسیاں اور ان کی لاٹھیاں ان کے جادو کے اثر سے موسٰی (علیہ السلام) کے خیال میں یوں محسوس ہونے لگیں جیسے وہ (میدان میں) دوڑ رہی ہیں،\qt@no{66}}%
\qt@newcmd\qurantrans@ur@mmcdxv{تو موسٰی (علیہ السلام) اپنے دل میں ایک چھپا ہوا خوف سا پانے لگے،\qt@no{67}}%
\qt@newcmd\qurantrans@ur@mmcdxvi{ہم نے (موسٰی علیہ السلام سے) فرمایا: خوف مت کرو بیشک تم ہی غالب رہوگے،\qt@no{68}}%
\qt@newcmd\qurantrans@ur@mmcdxvii{اور تم (اس لاٹھی کو) جو تمہارے داہنے ہاتھ میں ہے (زمین پر) ڈال دو وہ اس (فریب) کو نگل جائے گی جو انہوں نے (مصنوعی طور پر) بنا رکھا ہے۔ جو کچھ انہوں نے بنا رکھا ہے (وہ تو) فقط جادوگر کا فریب ہے، اور جادوگر جہاں کہیں بھی آئے گا فلاح نہیں پائے گا،\qt@no{69}}%
\qt@newcmd\qurantrans@ur@mmcdxviii{پھر ایسا ہی ہوا) پس سارے جادوگر سجدہ میں گر پڑے کہنے لگے: ہم ہارون اور موسٰی (علیہما السلام) کے رب پر ایمان لے آئے،\qt@no{70}}%
\qt@newcmd\qurantrans@ur@mmcdxix{فرعون) کہنے لگا: تم اس پر ایمان لے آئے ہو قبل اس کے کہ میں تمہیں اجازت دوں، بیشک وہ (موسٰی) تمہارا (بھی) بڑا (استاد) ہے جس نے تم کو جادو سکھایا ہے، پس (اب) میں ضرور تمہارے ہاتھ اور تمہارے پاؤں الٹی سمتوں سے کاٹوں گا اور تمہیں ضرور کھجور کے تنوں میں سولی چڑھاؤں گا اور تم ضرور جان لوگے کہ ہم میں سے کون عذاب دینے میں زیادہ سخت اور زیادہ مدت تک باقی رہنے والا ہے،\qt@no{71}}%
\qt@newcmd\qurantrans@ur@mmcdxx{جادوگروں نے) کہا: ہم تمہیں ہرگز ان واضح دلائل پر ترجیح نہیں دیں گے جو ہمارے پاس آچکے ہیں، اس (رب) کی قسم جس نے ہمیں پیدا فرمایا ہے! تو جو حکم کرنے والا ہے کر لے، تُو فقط (اس چند روزہ) دنیوی زندگی ہی سے متعلق فیصلہ کر سکتا ہے،\qt@no{72}}%
\qt@newcmd\qurantrans@ur@mmcdxxi{بیشک ہم اپنے رب پر ایمان لائے ہیں تاکہ وہ ہماری خطائیں بخش دے اور اسے بھی (معاف فرما دے) جس جادوگری پر تو نے ہمیں مجبور کیا تھا، اور اللہ ہی بہتر ہے اور ہمیشہ باقی رہنے والا ہے،\qt@no{73}}%
\qt@newcmd\qurantrans@ur@mmcdxxii{بیشک جو شخص اپنے رب کے پاس مجرم بن کر آئے گا تو بیشک اس کے لئے جہنم ہے، (اور وہ ایسا عذاب ہے کہ) نہ وہ اس میں مر سکے گا اور نہ ہی زندہ رہے گا،\qt@no{74}}%
\qt@newcmd\qurantrans@ur@mmcdxxiii{اور جو شخص اس کے حضور مومن بن کر آئے گا (مزید یہ کہ) اس نے نیک عمل کئے ہوں گے تو ان ہی لوگوں کے لئے بلند درجات ہیں،\qt@no{75}}%
\qt@newcmd\qurantrans@ur@mmcdxxiv{وہ) سدا بہار باغات ہیں جن کے نیچے سے نہریں رواں ہیں (وہ) ان میں ہمیشہ رہنے والے ہیں، اور یہ اس شخص کا صلہ ہے جو (کفر و معصیت کی آلودگی سے) پاک ہو گیا،\qt@no{76}}%
\qt@newcmd\qurantrans@ur@mmcdxxv{اور بیشک ہم نے موسٰی (علیہ السلام) کی طرف وحی بھیجی کہ میرے بندوں کو راتوں رات لے کر نکل جاؤ، سو ان کے لئے دریا میں (اپنا عصا مار کر) خشک راستہ بنا لو، نہ (فرعون کے) آپکڑنے کا خوف کرو اور نہ (غرق ہونے کا) اندیشہ رکھو،\qt@no{77}}%
\qt@newcmd\qurantrans@ur@mmcdxxvi{پھر فرعون نے اپنے لشکروں کے ساتھ ان کا تعاقب کیا پس دریا (کی موجوں) نے انہیں ڈھانپ لیا جتنا بھی انہیں ڈھانپا،\qt@no{78}}%
\qt@newcmd\qurantrans@ur@mmcdxxvii{اور فرعون نے اپنی قوم کو گمراہ کردیا اور انہیں سیدھے راستہ پر نہ لگایا،\qt@no{79}}%
\qt@newcmd\qurantrans@ur@mmcdxxviii{اے بنی اسرائیل! (دیکھو) بیشک ہم نے تمہیں تمہارے دشمن سے نجات بخشی اور ہم نے تم سے (کوہِ) طور کی داہنی جانب (آنے کا) وعدہ کیا اور (وہاں) ہم نے تم پر من و سلوٰی اتارا،\qt@no{80}}%
\qt@newcmd\qurantrans@ur@mmcdxxix{اور تم سے فرمایا:) ان پاکیزہ چیزوں میں سے کھاؤ جن کی ہم نے تمہیں روزی دی ہے اور اس میں حد سے نہ بڑھو ورنہ تم پر میرا غضب واجب ہو جائے گا، اور جس پر میرا غضب واجب ہوگیا سو وہ واقعی ہلاک ہوگیا،\qt@no{81}}%
\qt@newcmd\qurantrans@ur@mmcdxxx{اور بیشک میں بہت زیادہ بخشنے والا ہوں اس شخص کو جس نے توبہ کی اور ایمان لایا اور نیک عمل کیا پھر ہدایت پر (قائم) رہا،\qt@no{82}}%
\qt@newcmd\qurantrans@ur@mmcdxxxi{اور اے موسٰی! تم نے اپنی قوم سے (پہلے طور پر آجانے میں) جلدی کیوں کی،\qt@no{83}}%
\qt@newcmd\qurantrans@ur@mmcdxxxii{موسٰی علیہ السلام نے) عرض کیا: وہ لوگ بھی میرے پیچھے آرہے ہیں اور میں نے (غلبۂ شوق و محبت میں) تیرے حضور پہنچنے میں جلدی کی ہے اے میرے رب! تاکہ تو راضی ہو جائے،\qt@no{84}}%
\qt@newcmd\qurantrans@ur@mmcdxxxiii{ارشاد ہوا: بیشک ہم نے تمہارے (آنے کے) بعد تمہاری قوم کو فتنہ میں مبتلا کر دیا ہے اور انہیں سامری نے گمراہ کر ڈالا ہے،\qt@no{85}}%
\qt@newcmd\qurantrans@ur@mmcdxxxiv{پس موسٰی (علیہ السلام) اپنی قوم کی طرف سخت غضبناک (اور) رنجیدہ ہوکر پلٹ گئے (اور) فرمایا: اے میری قوم! کیا تمہارے رب نے تم سے ایک اچھا وعدہ نہیں فرمایا تھا، کیا تم پر وعدہ (کے پورے ہونے) میں طویل مدت گزر گئی تھی، کیا تم نے یہ چاہا کہ تم پر تمہارے رب کی طرف سے غضب واجب (اور نازل) ہوجائے؟ پس تم نے میرے وعدہ کی خلاف ورزی کی ہے،\qt@no{86}}%
\qt@newcmd\qurantrans@ur@mmcdxxxv{وہ بولے: ہم نے اپنے اختیار سے آپ کے وعدہ کی خلاف ورزی نہیں کی مگر (ہوا یہ کہ) قوم کے زیورات کے بھاری بوجھ ہم پر لاد دیئے گئے تھے تو ہم نے انہیں (آگ میں) ڈال دیا پھر اسی طرح سامری نے (بھی) ڈال دیئے،\qt@no{87}}%
\qt@newcmd\qurantrans@ur@mmcdxxxvi{پھر اس (سامری) نے ان کے لئے (ان گلے ہوئے زیورات سے) ایک بچھڑے کا قالب (تیار کرکے) نکال لیا اس میں (سے) گائے کی سی آواز (نکلتی) تھی تو انہوں نے کہا: یہ تمہارا معبود ہے اور موسٰی (علیہ السلام) کا (بھی یہی) معبود ہے بس وہ (سامری یہاں پر) بھول گیا،\qt@no{88}}%
\qt@newcmd\qurantrans@ur@mmcdxxxvii{بھلا کیا وہ (اتنا بھی) نہیں دیکھتے تھے کہ وہ (بچھڑا) انہیں کسی بات کا جواب (بھی) نہیں دے سکتا اور نہ ان کے لئے کسی نقصان کا اختیار رکھتا ہے اور نہ نفع کا،\qt@no{89}}%
\qt@newcmd\qurantrans@ur@mmcdxxxviii{اور بیشک ہارون (علیہ السلام) نے (بھی) ان کو اس سے پہلے (تنبیہاً) کہہ دیا تھا کہ اے قوم! تم اس (بچھڑے) کے ذریعہ تو بس فتنہ میں ہی مبتلا ہوگئے ہو، حالانکہ بیشک تمہارا رب (یہ نہیں وہی) رحمان ہے پس تم میری پیروی کرو اور میرے حکم کی اطاعت کرو،\qt@no{90}}%
\qt@newcmd\qurantrans@ur@mmcdxxxix{وہ بولی: ہم تو اسی (کی پوجا) پر جمے رہیں گے تاوقتیکہ موسٰی (علیہ السلام) ہماری طرف پلٹ آئیں،\qt@no{91}}%
\qt@newcmd\qurantrans@ur@mmcdxl{موسٰی علیہ السلام نے) فرمایا: اے ہارون! تم کو کس چیز نے روکے رکھا جب تم نے دیکھا کہ یہ گمراہ ہو رہے ہیں،\qt@no{92}}%
\qt@newcmd\qurantrans@ur@mmcdxli{مزید یہ کہ تمہیں کس نے منع کیا کہ انہیں سختی سے روکنے میں) تم میرے طریقے کی پیروی نہ کرو، کیا تم نے میری نافرمانی کی،\qt@no{93}}%
\qt@newcmd\qurantrans@ur@mmcdxlii{ہارون علیہ السلام نے) کہا: اے میری ماں کے بیٹے! آپ نہ میری داڑھی پکڑیں اور نہ میرا سر، میں (سختی کرنے میں) اس بات سے ڈرتا تھا کہ کہیں آپ یہ (نہ) کہیں کہ تم نے بنی اسرائیل کے درمیان فرقہ بندی کردی ہے اور میرے قول کی نگہداشت نہیں کی،\qt@no{94}}%
\qt@newcmd\qurantrans@ur@mmcdxliii{موسٰی علیہ السلام نے) فرمایا: اے سامری! (بتا) تیرا کیا معاملہ ہے،\qt@no{95}}%
\qt@newcmd\qurantrans@ur@mmcdxliv{اس نے کہا: میں نے وہ چیز دیکھی جو ان لوگوں نے نہیں دیکھی تھی سو میں نے اُس فرستادہ (فرشتے) کے نقش قدم سے (جو آپ کے پاس آیا تھا) ایک مٹھی (مٹی کی) بھر لی پھر میں نے اسے (بچھڑے کے قالب میں) ڈال دیا اور اسی طرح میرے نفس نے مجھے (یہ بات) بھلی کر دکھائی،\qt@no{96}}%
\qt@newcmd\qurantrans@ur@mmcdxlv{موسٰی علیہ السلام نے) فرمایا: پس تو (یہاں سے نکل کر) چلا جا چنانچہ تیرے لئے (ساری) زندگی میں یہ (سزا) ہے کہ تو (ہر کسی کو یہی) کہتا رہے: (مجھے) نہ چھونا (مجھے نہ چھونا)، اور بیشک تیرے لئے ایک اور وعدۂ (عذاب) بھی ہے جس کی ہرگز خلاف ورزی نہ ہوگی، اور تو اپنے اس (من گھڑت) معبود کی طرف دیکھ جس (کی پوجا) پر تو جم کر بیٹھا رہا، ہم اسے ضرور جلا ڈالیں گے پھر ہم اس (کی راکھ) کو ضرور دریا میں اچھی طرح بکھیر دیں گے،\qt@no{97}}%
\qt@newcmd\qurantrans@ur@mmcdxlvi{لوگو!) تمہارا معبود صرف (وہی) اللہ ہے جس کے سوا کوئی معبود نہیں، وہ ہر چیز کو (اپنے) علم کے احاطہ میں لئے ہوئے ہے،\qt@no{98}}%
\qt@newcmd\qurantrans@ur@mmcdxlvii{اس طرح ہم آپ کو (اے حبیبِ معظّم!) ان (قوموں) کی خبریں سناتے ہیں جو گزر چکی ہیں اور بیشک ہم نے آپ کو اپنی خاص جناب سے ذکر (یعنی نصیحت نامہ) عطا فرمایا ہے،\qt@no{99}}%
\qt@newcmd\qurantrans@ur@mmcdxlviii{جو شخص اس سے روگردانی کرے گا تو بیشک وہ قیامت کے دن سخت بوجھ اٹھائے گا،\qt@no{100}}%
\qt@newcmd\qurantrans@ur@mmcdxlix{وہ اس (عذاب) میں ہمیشہ (پڑے) رہیں گے، اور ان کے لئے قیامت کے دن بہت ہی بُرا بوجھ ہوگا،\qt@no{101}}%
\qt@newcmd\qurantrans@ur@mmcdl{جس دن صور پھونکا جائے گا اور اس دن ہم مجرموں کو یوں جمع کریں گے کہ ان کے جسم اور آنکھیں (شدّتِ خوف اور اندھے پن کے باعث) نیلگوں ہوں گی،\qt@no{102}}%
\qt@newcmd\qurantrans@ur@mmcdli{آپس میں چپکے چپکے باتیں کرتے ہوں گے کہ تم دنیا میں مشکل سے دس دن ہی ٹھہرے ہوگے،\qt@no{103}}%
\qt@newcmd\qurantrans@ur@mmcdlii{ہم خوب جانتے ہیں وہ جو کچھ کہہ رہے ہوں گے جبکہ ان میں سے ایک عقل و عمل میں بہتر شخص کہے گا کہ تم تو ایک دن کے سوا (دنیا میں) ٹھہرے ہی نہیں ہو،\qt@no{104}}%
\qt@newcmd\qurantrans@ur@mmcdliii{اور آپ سے یہ لوگ پہاڑوں کی نسبت سوال کرتے ہیں، سو فرمادیجئے: میرا رب انہیں ریزہ ریزہ کر کے اڑا دے گا،\qt@no{105}}%
\qt@newcmd\qurantrans@ur@mmcdliv{پھر اسے ہموار اور بے آب و گیاہ زمین بنا دے گا،\qt@no{106}}%
\qt@newcmd\qurantrans@ur@mmcdlv{جس میں آپ نہ کوئی پستی دیکھیں گے نہ کوئی بلندی،\qt@no{107}}%
\qt@newcmd\qurantrans@ur@mmcdlvi{اس دن لوگ پکارنے والے کے پیچھے چلتے جائیں گے اس (کے پیچھے چلنے) میں کوئی کجی نہیں ہوگی، اور (خدائے) رحمان کے جلال سے سب آوازیں پست ہوجائیں گی پس تم ہلکی سی آہٹ کے سوا کچھ نہ سنوگے،\qt@no{108}}%
\qt@newcmd\qurantrans@ur@mmcdlvii{اس دن سفارش سود مند نہ ہوگی سوائے اس شخص (کی سفارش) کے جسے (خدائے) رحمان نے اذن (و اجازت) دے دی ہے اور جس کی بات سے وہ راضی ہوگیا ہے (جیسا کہ انبیاء و مرسلین، اولیاء، متقین، معصوم بچوں اور دیگر کئی بندوں کا شفاعت کرنا ثابت ہے)،\qt@no{109}}%
\qt@newcmd\qurantrans@ur@mmcdlviii{وہ ان (سب چیزوں) کو جانتا ہے جو ان کے آگے ہیں اور جو ان کے پیچھے ہیں اور وہ (اپنے) علم سے اس (کے علم) کا احاطہ نہیں کرسکتے،\qt@no{110}}%
\qt@newcmd\qurantrans@ur@mmcdlix{اور (سب) چہرے اس ہمیشہ زندہ (اور) قائم رہنے والے (رب) کے حضور جھک جائیں گے، اور بیشک وہ شخص نامراد ہوگا جس نے ظلم کا بوجھ اٹھا لیا،\qt@no{111}}%
\qt@newcmd\qurantrans@ur@mmcdlx{اور جو شخص نیک عمل کرتا ہے اور وہ صاحبِ ایمان بھی ہے تو اسے نہ کسی ظلم کا خوف ہوگا اور نہ نقصان کا،\qt@no{112}}%
\qt@newcmd\qurantrans@ur@mmcdlxi{اور اسی طرح ہم نے اس (آخری وحی) کو عربی زبان میں (بشکلِ) قرآن اتارا ہے اور ہم نے اس میں (عذاب سے) ڈرانے کی باتیں بار بار (مختلف طریقوں سے) بیان کی ہیں تاکہ وہ پرہیزگار بن جائیں یا (یہ قرآن) ان (کے دلوں) میں یادِ (آخرت یا قبولِ نصیحت کا جذبہ) پیدا کردے،\qt@no{113}}%
\qt@newcmd\qurantrans@ur@mmcdlxii{پس اللہ بلند شان والا ہے وہی بادشاہِ حقیقی ہے، اور آپ قرآن (کے پڑھنے) میں جلدی نہ کیا کریں قبل اس کے کہ اس کی وحی آپ پر پوری اتر جائے، اور آپ (رب کے حضور یہ) عرض کیا کریں کہ اے میرے رب! مجھے علم میں اور بڑھا دے،\qt@no{114}}%
\qt@newcmd\qurantrans@ur@mmcdlxiii{اور درحقیقت ہم نے اس سے (بہت) پہلے آدم (علیہ السلام) کو تاکیدی حکم فرمایا تھا سو وہ بھول گئے اور ہم نے ان میں بالکل (نافرمانی کا کوئی) ارادہ نہیں پایا (یہ محض ایک بھول تھی)،\qt@no{115}}%
\qt@newcmd\qurantrans@ur@mmcdlxiv{اور (وہ وقت یاد کریں) جب ہم نے فرشتوں سے فرمایا: تم آدم (علیہ السلام) کو سجدہ کرو تو انہوں نے سجدہ کیا سوائے ابلیس کے، اس نے انکار کیا،\qt@no{116}}%
\qt@newcmd\qurantrans@ur@mmcdlxv{پھر ہم نے فرمایا: اے آدم! بیشک یہ (شیطان) تمہارا اور تمہاری بیوی کا دشمن ہے، سو یہ کہیں تم دونوں کو جنت سے نکلوا نہ دے پھر تم مشقت میں پڑ جاؤ گے،\qt@no{117}}%
\qt@newcmd\qurantrans@ur@mmcdlxvi{بیشک تمہارے لئے اس (جنت) میں یہ (راحت) ہے کہ تمہیں نہ بھوک لگے گی اور نہ برہنہ ہوگے،\qt@no{118}}%
\qt@newcmd\qurantrans@ur@mmcdlxvii{اور یہ کہ تمہیں نہ یہاں پیاس لگے گی اور نہ دھوپ ستائے گی،\qt@no{119}}%
\qt@newcmd\qurantrans@ur@mmcdlxviii{پس شیطان نے انہیں (ایک) خیال دلا دیا وہ کہنے لگا: اے آدم! کیا میں تمہیں (قربِ الٰہی کی جنت میں) دائمی زندگی بسر کرنے کا درخت بتا دوں اور (ایسی ملکوتی) بادشاہت (کا راز) بھی جسے نہ زوال آئے گا نہ فنا ہوگی،\qt@no{120}}%
\qt@newcmd\qurantrans@ur@mmcdlxix{سو دونوں نے (اس مقامِ قربِ الٰہی کی لازوال زندگی کے شوق میں) اس درخت سے پھل کھا لیا پس ان پر ان کے مقام ہائے سَتَر ظاہر ہو گئے اور دونوں اپنے (بدن) پر جنت (کے درختوں) کے پتے چپکانے لگے اور آدم (علیہ السلام) سے اپنے رب کے حکم (کو سمجھنے) میں فروگذاشت ہوئی٭ سو وہ (جنت میں دائمی زندگی کی) مراد نہ پا سکے، ٭ (کہ ممانعت مخصوص ایک درخت کی تھی یا اس کی پوری نوع کی تھی، کیونکہ آپ علیہ السلام نے پھل اس مخصوص درخت کا نہیں کھایا تھا بلکہ اسی نوع کے دوسرے درخت سے کھایا تھا، یہ سمجھ کر کہ شاید ممانعت اسی ایک درخت کی تھی۔)\qt@no{121}}%
\qt@newcmd\qurantrans@ur@mmcdlxx{پھر ان کے رب نے انہیں (اپنی قربت و نبوت کے لئے) چن لیا اور ان پر (عفو و رحمت کی خاص) توجہ فرمائی اور منزلِ مقصود کی راہ دکھا دی،\qt@no{122}}%
\qt@newcmd\qurantrans@ur@mmcdlxxi{ارشاد ہوا: تم یہاں سے سب کے سب اتر جاؤ، تم میں سے بعض بعض کے دشمن ہوں گے، پھر جب میری جانب سے تمہارے پاس کوئی ہدایت (وحی) آجائے سو جو شخص میری ہدایت کی پیروی کرے گا تو وہ نہ (دنیا میں) گمراہ ہوگا اور نہ (آخرت میں) بدنصیب ہوگا،\qt@no{123}}%
\qt@newcmd\qurantrans@ur@mmcdlxxii{اور جس نے میرے ذکر (یعنی میری یاد اور نصیحت) سے روگردانی کی تو اس کے لئے دنیاوی معاش (بھی) تنگ کردیا جائے گا اور ہم اسے قیامت کے دن (بھی) اندھا اٹھائیں گے،\qt@no{124}}%
\qt@newcmd\qurantrans@ur@mmcdlxxiii{وہ کہے گا: اے میرے رب! تو نے مجھے (آج) اندھا کیوں اٹھایا حالانکہ میں (دنیا میں) بینا تھا،\qt@no{125}}%
\qt@newcmd\qurantrans@ur@mmcdlxxiv{ارشاد ہوگا: ایسا ہی (ہوا کہ دنیا میں) تیرے پاس ہماری نشانیاں آئیں پس تو نے انہیں بھلا دیا اور آج اسی طرح تو (بھی) بھلا دیا جائے گا،\qt@no{126}}%
\qt@newcmd\qurantrans@ur@mmcdlxxv{اور اسی طرح ہم اس شخص کو بدلہ دیتے ہیں جو (گناہوں میں) حد سے نکل جائے اور اپنے رب کی آیتوں پر ایمان نہ لائے، اور بیشک آخرت کا عذاب بڑا ہی سخت اور ہمیشہ رہنے والا ہے،\qt@no{127}}%
\qt@newcmd\qurantrans@ur@mmcdlxxvi{کیا انہیں (اس بات نے) ہدایت نہ دی کہ ہم نے ان سے پہلے کتنی ہی امتوں کو ہلاک کر دیا جن کی رہائش گاہوں میں (اب) یہ لوگ چلتے پھرتے ہیں، بیشک اس میں دانش مندوں کے لئے (بہت سی) نشانیاں ہیں،\qt@no{128}}%
\qt@newcmd\qurantrans@ur@mmcdlxxvii{اور اگر آپ کے رب کی جانب سے ایک بات پہلے سے طے نہ ہو چکی ہوتی اور (ان کے عذاب کے لئے قیامت کا) وقت مقرر نہ ہوتا تو (ان پر عذاب کا ابھی اترنا) لازم ہو جاتا،\qt@no{129}}%
\qt@newcmd\qurantrans@ur@mmcdlxxviii{پس آپ ان کی (دل آزار) باتوں پر صبر فرمایا کریں اور اپنے رب کی حمد کے ساتھ تسبیح کیا کریں طلوعِ آفتاب سے پہلے (نمازِ فجر میں) اور اس کے غروب سے قبل (نمازِ عصر میں)، اور رات کی ابتدائی ساعتوں میں (یعنی مغرب اور عشاء میں) بھی تسبیح کیا کریں اور دن کے کناروں پر بھی (نمازِ ظہر میں جب دن کا نصفِ اوّل ختم اور نصفِ ثانی شروع ہوتا ہے، (اے حبیبِ مکرّم! یہ سب کچھ اس لئے ہے) تاکہ آپ راضی ہو جائیں،\qt@no{130}}%
\qt@newcmd\qurantrans@ur@mmcdlxxix{اور آپ دنیوی زندگی میں زیب و آرائش کی ان چیزوں کی طرف حیرت و تعجب کی نگاہ نہ فرمائیں جو ہم نے (کافر دنیاداروں کے) بعض طبقات کو (عارضی) لطف اندوزی کے لئے دے رکھی ہیں تاکہ ہم ان (ہی چیزوں) میں ان کے لئے فتنہ پیدا کر دیں، اور آپ کے رب کی (اخروی) عطا بہتر اور ہمیشہ باقی رہنے والی ہے،\qt@no{131}}%
\qt@newcmd\qurantrans@ur@mmcdlxxx{اور آپ اپنے گھر والوں کو نماز کا حکم فرمائیں اور اس پر ثابت قدم رہیں، ہم آپ سے رزق طلب نہیں کرتے (بلکہ) ہم آپ کو رزق دیتے ہیں، اور بہتر انجام پرہیزگاری کا ہی ہے،\qt@no{132}}%
\qt@newcmd\qurantrans@ur@mmcdlxxxi{اور (کفار) کہتے ہیں کہ یہ (رسول) ہمارے پاس اپنے رب کی طرف سے کوئی نشانی کیوں نہیں لاتے، کیا ان کے پاس ان باتوں کا واضح ثبوت (یعنی قرآن) نہیں آگیا جو اگلی کتابوں میں (مذکور) تھیں،\qt@no{133}}%
\qt@newcmd\qurantrans@ur@mmcdlxxxii{اور اگر ہم ان لوگوں کو اس سے پہلے (ہی) کسی عذاب کے ذریعہ ہلاک کرڈالتے تو یہ کہتے: اے ہمارے رب! تو نے ہمارے پاس کسی رسول کو کیوں نہ بھیجا کہ ہم تیری آیتوں کی پیروی کرلیتے اس سے قبل کہ ہم ذلیل اور رسوا ہوتے،\qt@no{134}}%
\qt@newcmd\qurantrans@ur@mmcdlxxxiii{فرما دیجئے: ہر کوئی منتظر ہے، سو تم انتظار کرتے رہو، پس تم جلد ہی جان لوگے کہ کون لوگ راہِ راست والے ہیں اور کون ہدایت یافتہ ہیں،\qt@no{135}}%
\qt@newcmd\qurantrans@ur@mmcdlxxxiv{\basmalahur لوگوں کے لئے ان کے حساب کا وقت قریب آپہنچا مگر وہ غفلت میں (پڑے طاعت سے) منہ پھیرے ہوئے ہیں،\qt@no{1}}%
\qt@newcmd\qurantrans@ur@mmcdlxxxv{ان کے پاس ان کے رب کی جانب سے جب بھی کوئی نئی نصیحت آتی ہے تو وہ اسے یوں (بے پرواہی سے) سنتے ہیں گویا وہ کھیل کود میں لگے ہوئے ہیں،\qt@no{2}}%
\qt@newcmd\qurantrans@ur@mmcdlxxxvi{ان کے دل غافل ہو چکے ہیں، اور (یہ) ظالم لوگ (آپ کے خلاف) آہستہ آہستہ سرگوشیاں کرتے ہیں کہ یہ تو محض تمہارے ہی جیسا ایک بشر ہے، کیا پھر (بھی) تم (اس کے) جادو کے پاس جاتے ہو حالانکہ تم دیکھ رہے ہو،\qt@no{3}}%
\qt@newcmd\qurantrans@ur@mmcdlxxxvii{نبئ معظّم صلی اللہ علیہ وآلہ وسلم نے) فرمایا کہ میرا رب آسمان اور زمین میں کہی جانے والی (ہر) بات کو جانتا ہے اور وہ خوب سننے والا خوب جاننے والا ہے،\qt@no{4}}%
\qt@newcmd\qurantrans@ur@mmcdlxxxviii{بلکہ (ظالموں نے یہاں تک) کہا کہ یہ (قرآن) پریشان خوابوں (میں دیکھی ہوئی باتیں) ہیں بلکہ اس (رسول صلی اللہ علیہ وآلہ وسلم) نے اسے (خود ہی) گھڑ لیا ہے بلکہ (یہ کہ) وہ شاعر ہے، (اگر یہ سچا ہے) تو یہ (بھی) ہمارے پاس کوئی نشانی لے آئے جیسا کہ اگلے (رسول نشانیوں کے ساتھ) بھیجے گئے تھے،\qt@no{5}}%
\qt@newcmd\qurantrans@ur@mmcdlxxxix{ان سے پہلے ہم نے جس بھی بستی کو ہلاک کیا وہ (انہی نشانیوں پر) ایمان نہیں لائی تھی، تو کیا یہ ایمان لے آئیں گے،\qt@no{6}}%
\qt@newcmd\qurantrans@ur@mmcdxc{اور (اے حبیبِ مکرّم!) ہم نے آپ سے پہلے (بھی) مَردوں کو ہی (رسول بنا کر) بھیجا تھا ہم ان کی طرف وحی بھیجا کرتے تھے (لوگو!) تم اہلِ ذکر سے پوچھ لیا کرو اگر تم (خود) نہ جانتے ہو،\qt@no{7}}%
\qt@newcmd\qurantrans@ur@mmcdxci{اور ہم نے ان (انبیاء) کو ایسے جسم والا نہیں بنایا تھا کہ وہ کھانا نہ کھاتے ہوں اور نہ ہی وہ (دنیا میں بہ حیاتِ ظاہری) ہمیشہ رہنے والے تھے،\qt@no{8}}%
\qt@newcmd\qurantrans@ur@mmcdxcii{پھر ہم نے انہیں اپنا وعدہ سچا کر دکھایا پھر ہم نے انہیں اور جسے ہم نے چاہا نجات بخشی اور ہم نے حد سے بڑھ جانے والوں کو ہلاک کر ڈالا،\qt@no{9}}%
\qt@newcmd\qurantrans@ur@mmcdxciii{بیشک ہم نے تمہاری طرف ایسی کتاب نازل فرمائی ہے جس میں تمہاری نصیحت (کا سامان) ہے، کیا تم عقل نہیں رکھتے،\qt@no{10}}%
\qt@newcmd\qurantrans@ur@mmcdxciv{اور ہم نے کتنی ہی بستیوں کو تباہ و برباد کر ڈالا جو ظالم تھیں اور ان کے بعد ہم نے اور قوموں کو پیدا فرما دیا،\qt@no{11}}%
\qt@newcmd\qurantrans@ur@mmcdxcv{پھر جب انہوں نے ہمارے عذاب (کی آمد) کو محسوس کیا تو وہ وہاں سے تیزی کے ساتھ بھاگنے لگے،\qt@no{12}}%
\qt@newcmd\qurantrans@ur@mmcdxcvi{ان سے کہا گیا:) تم جلدی مت بھاگو اور اسی جگہ واپس لوٹ جاؤ جس میں تمہیں آسائشیں دی گئی تھیں اور اپنی (پرتعیش) رہائش گاہوں کی طرف (پلٹ جاؤ) شاید تم سے باز پرس کی جائے،\qt@no{13}}%
\qt@newcmd\qurantrans@ur@mmcdxcvii{وہ کہنے لگے: ہائے شومئ قسمت! بیشک ہم ظالم تھے،\qt@no{14}}%
\qt@newcmd\qurantrans@ur@mmcdxcviii{سو ہمیشہ ان کی یہی فریاد رہی یہاں تک کہ ہم نے ان کو کٹی ہوئی کھیتی (اور) بجھی ہوئی آگ (کے ڈھیر) کی طرح بنا دیا،\qt@no{15}}%
\qt@newcmd\qurantrans@ur@mmcdxcix{اور ہم نے آسمان اور زمین کو اور جو کچھ ان کے درمیان ہے کھیل تماشے کے طور پر (بے کار) نہیں بنایا،\qt@no{16}}%
\qt@newcmd\qurantrans@ur@mmd{اگر ہم کوئی کھیل تماشا اختیار کرنا چاہتے تو اسے اپنی ہی طرف سے اختیار کر لیتے اگر ہم (ایسا) کرنے والے ہوتے،\qt@no{17}}%
\qt@newcmd\qurantrans@ur@mmdi{بلکہ ہم حق سے باطل پر پوری قوت کے ساتھ چوٹ لگاتے ہیں سو حق اسے کچل دیتا ہے پس وہ (باطل) ہلاک ہو جاتا ہے، اور تمہارے لئے ان باتوں کے باعث تباہی ہے جو تم بیان کرتے ہو،\qt@no{18}}%
\qt@newcmd\qurantrans@ur@mmdii{اور جو کوئی آسمانوں اور زمین میں ہے اسی کا (بندہ و مملوک) ہے، اور جو (فرشتے) اس کی قربت میں (رہتے) ہیں وہ نہ تو اس کی عبادت سے تکبّر کرتے ہیں اور نہ وہ (اس کی طاعت بجا لاتے ہوئے) تھکتے ہیں،\qt@no{19}}%
\qt@newcmd\qurantrans@ur@mmdiii{وہ رات دن (اس کی) تسبیح کرتے رہتے ہیں اور معمولی سا وقفہ بھی نہیں کرتے،\qt@no{20}}%
\qt@newcmd\qurantrans@ur@mmdiv{کیا ان (کافروں) نے زمین (کی چیزوں) میں سے ایسے معبود بنا لئے ہیں جو (مُردوں کو) زندہ کر کے اٹھا سکتے ہیں،\qt@no{21}}%
\qt@newcmd\qurantrans@ur@mmdv{اگر ان دونوں (زمین و آسمان) میں اﷲ کے سوا اور (بھی) معبود ہوتے تو یہ دونوں تباہ ہو جاتے، پس اﷲ جو عرش کا مالک ہے ان (باتوں) سے پاک ہے جو یہ (مشرک) بیان کرتے ہیں،\qt@no{22}}%
\qt@newcmd\qurantrans@ur@mmdvi{اس سے اس کی بازپرس نہیں کی جا سکتی وہ جو کچھ بھی کرتا ہے، اور ان سے (ہر کام کی) بازپرس کی جائے گی،\qt@no{23}}%
\qt@newcmd\qurantrans@ur@mmdvii{کیا ان (کافروں) نے اسے چھوڑ کر اور معبود بنا لئے ہیں؟ فرما دیجئے: اپنی دلیل لاؤ، یہ (قرآن) ان لوگوں کا ذکر ہے جو میرے ساتھ ہیں اور ان کا (بھی) ذکر ہے جو مجھ سے پہلے تھے بلکہ ان میں سے اکثر لوگ حق کو نہیں جانتے اِس لئے وہ اِس سے رُوگردانی کئے ہوئے ہیں،\qt@no{24}}%
\qt@newcmd\qurantrans@ur@mmdviii{اور ہم نے آپ سے پہلے کوئی رسول نہیں بھیجا مگر ہم اس کی طرف یہی وحی کرتے رہے کہ میرے سوا کوئی معبود نہیں پس تم میری (ہی) عبادت کیا کرو،\qt@no{25}}%
\qt@newcmd\qurantrans@ur@mmdix{یہ لوگ کہتے ہیں کہ (خدائے) رحمان نے (فرشتوں کو اپنی) اولاد بنا رکھا ہے وہ پاک ہے، بلکہ (جن فرشتوں کو یہ اُس کی اولاد سمجھتے ہیں) وہ (اﷲ کے) معزز بندے ہیں،\qt@no{26}}%
\qt@newcmd\qurantrans@ur@mmdx{وہ کسی بات (کے کرنے) میں اس سے سبقت نہیں کرتے اور وہ اسی کے امر کی تعمیل کرتے رہتے ہیں،\qt@no{27}}%
\qt@newcmd\qurantrans@ur@mmdxi{وہ (اﷲ) ان چیزوں کو جانتا ہے جو ان کے سامنے ہیں اور جو ان کے پیچھے ہیں اور وہ (اس کے حضور) سفارش بھی نہیں کرتے مگر اس کے لئے (کرتے ہیں) جس سے وہ خوش ہوگیا ہو اور وہ اس کی ہیبت و جلال سے خائف رہتے ہیں،\qt@no{28}}%
\qt@newcmd\qurantrans@ur@mmdxii{اور ان میں سے کون ہے جو کہہ دے کہ میں اس (اﷲ) کے سوا معبود ہوں سو ہم اسی کو دوزخ کی سزا دیں گے، اسی طرح ہم ظالموں کو سزا دیا کرتے ہیں،\qt@no{29}}%
\qt@newcmd\qurantrans@ur@mmdxiii{اور کیا کافر لوگوں نے نہیں دیکھا کہ جملہ آسمانی کائنات اور زمین (سب) ایک اکائی کی شکل میں جڑے ہوئے تھے پس ہم نے ان کو پھاڑ کر جدا کر دیا، اور ہم نے (زمین پر) پیکرِ حیات (کی زندگی) کی نمود پانی سے کی، تو کیا وہ (قرآن کے بیان کردہ اِن حقائق سے آگاہ ہو کر بھی) ایمان نہیں لاتے،\qt@no{30}}%
\qt@newcmd\qurantrans@ur@mmdxiv{اور ہم نے زمین میں مضبوط پہاڑ بنا دیئے تاکہ ایسا نہ ہو کہ کہیں وہ (اپنے مدار میں حرکت کرتے ہوئے) انہیں لے کر کانپنے لگے اور ہم نے اس (زمین) میں کشادہ راستے بنائے تاکہ لوگ (مختلف منزلوں تک پہنچنے کے لئے) راہ پاسکیں،\qt@no{31}}%
\qt@newcmd\qurantrans@ur@mmdxv{اور ہم نے سماء (یعنی زمین کے بالائی کرّوں) کو محفوظ چھت بنایا (تاکہ اہلِ زمین کو خلا سے آنے والی مہلک قوتوں اور جارحانہ لہروں کے مضر اثرات سے بچائیں) اور وہ اِن (سماوی طبقات کی) نشانیوں سے رُوگرداں ہیں،\qt@no{32}}%
\qt@newcmd\qurantrans@ur@mmdxvi{اور وہی (اﷲ) ہے جس نے رات اور دن کو پیدا کیا اور سورج اور چاند کو (بھی)، تمام (آسمانی کرّے) اپنے اپنے مدار کے اندر تیزی سے تیرتے چلے جاتے ہیں،\qt@no{33}}%
\qt@newcmd\qurantrans@ur@mmdxvii{اور ہم نے آپ سے پہلے کسی اِنسان کو (دنیا کی ظاہری زندگی میں) بقائے دوام نہیں بخشی، تو کیا اگر آپ (یہاں سے) اِنتقال فرما جائیں تو یہ لوگ ہمیشہ رہنے والے ہیں؟،\qt@no{34}}%
\qt@newcmd\qurantrans@ur@mmdxviii{ہر جان کو موت کا مزہ چکھنا ہے، اور ہم تمہیں برائی اور بھلائی میں آزمائش کے لئے مبتلا کرتے ہیں، اور تم ہماری ہی طرف پلٹائے جاؤ گے،\qt@no{35}}%
\qt@newcmd\qurantrans@ur@mmdxix{اور جب کافر لوگ آپ کو دیکھتے ہیں تو آپ سے محض تمسخر ہی کرنے لگتے ہیں (اور کہتے ہیں:) کیا یہی ہے وہ شخص جو تمہارے معبودوں کا (ردّ و انکار کے ساتھ) ذکر کرتا ہے؟ اور وہ خود (خدائے) رحمان کے ذکر سے انکاری ہیں،\qt@no{36}}%
\qt@newcmd\qurantrans@ur@mmdxx{انسان (فطرتًا) جلد بازی میں سے پیدا کیا گیا ہے، میں تمہیں جلد ہی اپنی نشانیاں دکھاؤں گا پس تم جلدی کا مطالبہ نہ کرو،\qt@no{37}}%
\qt@newcmd\qurantrans@ur@mmdxxi{اور وہ کہتے ہیں: یہ وعدۂ (عذاب) کب (پورا) ہوگا اگر تم سچے ہو،\qt@no{38}}%
\qt@newcmd\qurantrans@ur@mmdxxii{اگر کافر لوگ وہ وقت جان لیتے جبکہ وہ (دوزخ کی) آگ کو نہ اپنے چہروں سے روک سکیں گے اور نہ اپنی پشتوں سے اور نہ ہی ان کی مدد کی جائے گی (تو پھر عذاب طلب کرنے میں جلدی کا شور نہ کرتے)،\qt@no{39}}%
\qt@newcmd\qurantrans@ur@mmdxxiii{بلکہ (قیامت) انہیں اچانک آپہنچے گی تو انہیں بدحواس کر دے گی سو وہ نہ تو اسے لوٹا دینے کی طاقت رکھتے ہوں گے اور نہ ہی انہیں مہلت دی جائے گی،\qt@no{40}}%
\qt@newcmd\qurantrans@ur@mmdxxiv{اور بیشک آپ سے پہلے بھی رسولوں کے ساتھ مذاق کیا گیا سو ان لوگوں میں سے انہیں جو تمسخر کرتے تھے اسی (عذاب) نے گھیر لیا جس کا وہ مذاق اڑایا کرتے تھے،\qt@no{41}}%
\qt@newcmd\qurantrans@ur@mmdxxv{فرما دیجئے: شب و روز (خدائے) رحمان (کے عذاب) سے تمہاری حفاظت و نگہبانی کون کر سکتا ہے، بلکہ وہ اپنے (اسی) رب کے ذکر سے گریزاں ہے،\qt@no{42}}%
\qt@newcmd\qurantrans@ur@mmdxxvi{کیا ہمارے سوا ان کے کچھ اور معبود ہیں جو انہیں (عذاب سے) بچا سکیں، وہ تو خود اپنی ہی مدد پر قدرت نہیں رکھتے اور نہ ہماری طرف سے انہیں کوئی تائید و رفاقت میسّر ہوگی،\qt@no{43}}%
\qt@newcmd\qurantrans@ur@mmdxxvii{بلکہ ہم نے ان کو اور ان کے آباء و اجداد کو (فراخئ عیش سے) بہرہ مند فرمایا تھا یہاں تک کہ ان کی عمریں بھی دراز ہوتی گئیں، تو کیا وہ نہیں دیکھتے کہ ہم (اب اسلامی فتوحات کے ذریعہ ان کے زیرِ تسلّط) علاقوں کو تمام اَطراف سے گھٹاتے چلے جا رہے ہیں، تو کیا وہ (اب) غلبہ پانے والے ہیں،\qt@no{44}}%
\qt@newcmd\qurantrans@ur@mmdxxviii{فرما دیجئے: میں تو تمہیں صرف وحی کے ذریعہ ہی ڈراتا ہوں، اور بہرے پکار کو نہیں سنا کرتے جب بھی انہیں ڈرایا جائے،\qt@no{45}}%
\qt@newcmd\qurantrans@ur@mmdxxix{اگر واقعتاً انہیں آپ کے رب کی طرف سے تھوڑا سا عذاب (بھی) چھو جائے تو وہ ضرور کہنے لگیں گے: ہائے ہماری بدقسمتی! بیشک ہم ہی ظالم تھے،\qt@no{46}}%
\qt@newcmd\qurantrans@ur@mmdxxx{اور ہم قیامت کے دن عدل و انصاف کے ترازو رکھ دیں گے سو کسی جان پر کوئی ظلم نہ کیا جائے گا، اور اگر (کسی کا عمل) رائی کے دانہ کے برابر بھی ہوگا (تو) ہم اسے (بھی) حاضر کر دیں گے، اور ہم حساب کرنے کو کافی ہیں،\qt@no{47}}%
\qt@newcmd\qurantrans@ur@mmdxxxi{اور بیشک ہم نے موسٰی اور ہارون (علیہما السلام) کو (حق و باطل میں) فرق کرنے والی اور (سراپا) روشنی اور پرہیز گاروں کے لئے نصیحت (پر مبنی کتاب تورات) عطا فرمائی،\qt@no{48}}%
\qt@newcmd\qurantrans@ur@mmdxxxii{جو لوگ اپنے رب سے نادیدہ ڈرتے ہیں اور جو قیامت (کی ہولناکیوں) سے خائف رہتے ہیں،\qt@no{49}}%
\qt@newcmd\qurantrans@ur@mmdxxxiii{یہ (قرآن) برکت والا ذکر ہے جسے ہم نے نازل فرمایا ہے، کیا تم اِس سے انکار کرنے والے ہو،\qt@no{50}}%
\qt@newcmd\qurantrans@ur@mmdxxxiv{اور بیشک ہم نے پہلے سے ہی ابراہیم (علیہ السلام) کو ان کے (مرتبہ کے مطابق) فہم و ہدایت دے رکھی تھی اور ہم ان (کی استعداد و اہلیت) کو خوب جاننے والے تھے،\qt@no{51}}%
\qt@newcmd\qurantrans@ur@mmdxxxv{جب انہوں نے اپنے باپ (چچا) اور اپنی قوم سے فرمایا: یہ کیسی مورتیاں ہیں جن (کی پرستش) پر تم جمے بیٹھے ہو،\qt@no{52}}%
\qt@newcmd\qurantrans@ur@mmdxxxvi{وہ بولے: ہم نے اپنے باپ دادا کو انہی کی پرستش کرتے پایا تھا،\qt@no{53}}%
\qt@newcmd\qurantrans@ur@mmdxxxvii{ابراہیم علیہ السلام نے) فرمایا: بیشک تم اور تمہارے باپ دادا (سب) صریح گمراہی میں تھے،\qt@no{54}}%
\qt@newcmd\qurantrans@ur@mmdxxxviii{وہ بولے: کیا (صرف) تم ہی حق لائے ہو یا تم (محض) تماشا گروں میں سے ہو،\qt@no{55}}%
\qt@newcmd\qurantrans@ur@mmdxxxix{ابراہیم علیہ السلام نے) فرمایا: بلکہ تمہارا رب آسمانوں اور زمین کا رب ہے جس نے ان (سب) کو پیدا فرمایا اور میں اس (بات) پر گواہی دینے والوں میں سے ہوں،\qt@no{56}}%
\qt@newcmd\qurantrans@ur@mmdxl{اور اﷲ کی قسم! میں تمہارے بتوں کے ساتھ ضرور ایک تدبیر عمل میں لاؤں گا اس کے بعد کہ جب تم پیٹھ پھیر کر پلٹ جاؤ گے،\qt@no{57}}%
\qt@newcmd\qurantrans@ur@mmdxli{پھر ابراہیم (علیہ السلام) نے ان (بتوں) کو ٹکڑے ٹکڑے کر ڈالا سوائے بڑے (بُت) کے تاکہ وہ لوگ اس کی طرف رجوع کریں،\qt@no{58}}%
\qt@newcmd\qurantrans@ur@mmdxlii{وہ کہنے لگے: ہمارے معبودوں کا یہ حال کس نے کیا ہے؟ بیشک وہ ضرور ظالموں میں سے ہے،\qt@no{59}}%
\qt@newcmd\qurantrans@ur@mmdxliii{کچھ) لوگ بولے: ہم نے ایک نوجوان کا سنا ہے جو ان کا ذکر (انکار و تنقید سے) کرتا ہے اسے ابراہیم کہا جاتا ہے،\qt@no{60}}%
\qt@newcmd\qurantrans@ur@mmdxliv{وہ بولے: اسے لوگوں کے سامنے لے آؤ تاکہ وہ (اسے) دیکھ لیں،\qt@no{61}}%
\qt@newcmd\qurantrans@ur@mmdxlv{جب ابراہیم علیہ السلام آئے تو) وہ کہنے لگے: کیا تم نے ہی ہمارے معبودوں کے ساتھ یہ حال کیا ہے اے ابراہیم،\qt@no{62}}%
\qt@newcmd\qurantrans@ur@mmdxlvi{آپ نے فرمایا: بلکہ یہ (کام) ان کے اس بڑے (بت) نے کیا ہوگا تو ان (بتوں) سے ہی پوچھو اگر وہ بول سکتے ہیں،\qt@no{63}}%
\qt@newcmd\qurantrans@ur@mmdxlvii{پھر وہ اپنی ہی (سوچوں کی) طرف پلٹ گئے تو کہنے لگے: بیشک تم خود ہی (ان مجبور و بے بس بتوں کی پوجا کر کے) ظالم (ہوگئے) ہو،\qt@no{64}}%
\qt@newcmd\qurantrans@ur@mmdxlviii{پھر وہ اپنے سروں کے بل اوندھے کر دیئے گئے (یعنی ان کی عقلیں اوندھی ہوگئیں اور کہنے لگے:) بیشک (اے ابراہیم!) تم خود ہی جانتے ہو کہ یہ تو بولتے نہیں ہیں،\qt@no{65}}%
\qt@newcmd\qurantrans@ur@mmdxlix{ابراہیم علیہ السلام نے) فرمایا: پھر کیا تم اﷲ کو چھوڑ کر ان (مورتیوں) کو پوجتے ہو جو نہ تمہیں کچھ نفع دے سکتی ہیں اور نہ تمہیں نقصان پہنچا سکتی ہیں،\qt@no{66}}%
\qt@newcmd\qurantrans@ur@mmdl{تف ہے تم پر (بھی) اور ان (بتوں) پر (بھی) جنہیں تم اﷲ کے سوا پوجتے ہو، تو کیا تم عقل نہیں رکھتے،\qt@no{67}}%
\qt@newcmd\qurantrans@ur@mmdli{وہ بولے: اس کو جلا دو اور اپنے (تباہ حال) معبودوں کی مدد کرو اگر تم (کچھ) کرنے والے ہو،\qt@no{68}}%
\qt@newcmd\qurantrans@ur@mmdlii{ہم نے فرمایا: اے آگ! تو ابراہیم پر ٹھنڈی اور سراپا سلامتی ہو جا،\qt@no{69}}%
\qt@newcmd\qurantrans@ur@mmdliii{اور انہوں نے ابراہیم (علیہ السلام) کے ساتھ بری چال کا ارادہ کیا تھا مگر ہم نے انہیں بری طرح ناکام کر دیا،\qt@no{70}}%
\qt@newcmd\qurantrans@ur@mmdliv{اور ہم ابراہیم (علیہ السلام) کو اور لوط (علیہ السلام) کو (جو آپ کے بھتیجے یعنی آپ کے بھائی ہاران کے بیٹے تھے) بچا کر (عراق سے) اس سرزمینِ (شام) کی طرف لے گئے جس میں ہم نے جہان والوں کے لئے برکتیں رکھی ہیں،\qt@no{71}}%
\qt@newcmd\qurantrans@ur@mmdlv{اور ہم نے انہیں (فرزند) اسحاق (علیہ السلام) بخشا اور (پوتا) یعقوب (علیہ السلام ان کی دعا سے) اضافی بخشا، اور ہم نے ان سب کو صالح بنایا تھا،\qt@no{72}}%
\qt@newcmd\qurantrans@ur@mmdlvi{اور ہم نے انہیں (انسانیت کا) پیشوا بنایا وہ (لوگوں کو) ہمارے حکم سے ہدایت کرتے تھے اور ہم نے ان کی طرف اَعمالِ خیر اور نماز قائم کرنے اور زکوٰۃ ادا کرنے (کے احکام) کی وحی بھیجی، اور وہ سب ہمارے عبادت گزار تھے،\qt@no{73}}%
\qt@newcmd\qurantrans@ur@mmdlvii{اور لوط (علیہ السلام) کو (بھی) ہم نے حکمت اور علم سے نوازا تھا اور ہم نے انہیں اس بستی سے نجات دی جہاں کے لوگ گندے کام کیا کرتے تھے۔ بیشک وہ بہت ہی بری (اور) بد کردار قوم تھی،\qt@no{74}}%
\qt@newcmd\qurantrans@ur@mmdlviii{اور ہم نے لوط (علیہ السلام) کو اپنے حریمِ رحمت میں داخل فرما لیا۔ بیشک وہ صالحین میں سے تھے،\qt@no{75}}%
\qt@newcmd\qurantrans@ur@mmdlix{اور نوح (علیہ السلام کو بھی یاد کریں) جب انہوں نے ان (انبیاء علیہم السلام) سے پہلے (ہمیں) پکارا تھا سو ہم نے ان کی دعا قبول فرمائی پس ہم نے ان کو اور ان کے گھر والوں کو بڑے شدید غم و اندوہ سے نجات بخشی،\qt@no{76}}%
\qt@newcmd\qurantrans@ur@mmdlx{اور ہم نے اس قوم (کے اذیت ناک ماحول) میں ان کی مدد فرمائی جو ہماری آیتوں کو جھٹلاتے تھے۔ بیشک وہ (بھی) بہت بری قوم تھی سو ہم نے ان سب کو غرق کر دیا،\qt@no{77}}%
\qt@newcmd\qurantrans@ur@mmdlxi{اور داؤد اور سلیمان (علیہما السلام کا قصہ بھی یاد کریں) جب وہ دونوں کھیتی (کے ایک مقدمہ) میں فیصلہ کرنے لگے جب ایک قوم کی بکریاں اس میں رات کے وقت بغیر چرواہے کے گھس گئی تھیں (اور اس کھیتی کو تباہ کر دیا تھا)، اور ہم ان کے فیصلہ کا مشاہدہ فرما رہے تھے،\qt@no{78}}%
\qt@newcmd\qurantrans@ur@mmdlxii{چنانچہ ہم ہی نے سلیمان (علیہ السلام) کو وہ (فیصلہ کرنے کا طریقہ) سکھایا تھا اور ہم نے ان سب کو حکمت اور علم سے نوازا تھا اور ہم نے پہاڑوں اور پرندوں (تک) کو داؤد (علیہ السلام) کے (حکم کے) ساتھ پابند کر دیا تھا وہ (سب ان کے ساتھ مل کر) تسبیح پڑھتے تھے، اور ہم ہی (یہ سب کچھ) کرنے والے تھے،\qt@no{79}}%
\qt@newcmd\qurantrans@ur@mmdlxiii{اور ہم نے داؤد (علیہ السلام) کو تمہارے لئے زِرہ بنانے کا فن سکھایا تھا تاکہ وہ تمہاری لڑائی میں تمہیں ضرر سے بچائے، تو کیا تم شکر گزار ہو،\qt@no{80}}%
\qt@newcmd\qurantrans@ur@mmdlxiv{اور (ہم نے) سلیمان (علیہ السلام) کے لئے تیز ہوا کو (مسخّر کردیا) جو ان کے حکم سے (جملہ اَطراف و اَکناف سے) اس سرزمینِ (شام) کی طرف چلا کرتی تھی جس میں ہم نے برکتیں رکھی ہیں، اور ہم ہر چیز کو (خوب) جاننے والے ہیں،\qt@no{81}}%
\qt@newcmd\qurantrans@ur@mmdlxv{اور کچھ شیطان (دیووں اور جنّوں) کو بھی (سلیمان علیہ السلام کے تابع کر دیا تھا) جو ان کے لئے (دریا میں) غوطے لگاتے تھے اور اس کے سوا (ان کے حکم پر) دیگر خدمات بھی انجام دیتے تھے، اور ہم ہی ان (دیووں) کے نگہبان تھے،\qt@no{82}}%
\qt@newcmd\qurantrans@ur@mmdlxvi{اور ایوب (علیہ السلام کا قصّہ یاد کریں) جب انہوں نے اپنے رب کو پکارا کہ مجھے تکلیف چھو رہی ہے اور تو سب رحم کرنے والوں سے بڑھ کر مہربان ہے،\qt@no{83}}%
\qt@newcmd\qurantrans@ur@mmdlxvii{تو ہم نے ان کی دعا قبول فرما لی اور انہیں جو تکلیف (پہنچ رہی) تھی سو ہم نے اسے دور کر دیا اور ہم نے انہیں ان کے اہل و عیال (بھی) عطا فرمائے اور ان کے ساتھ اتنے ہی اور (عطا فرما دیئے)، یہ ہماری طرف سے خاص رحمت اور عبادت گزاروں کے لئے نصیحت ہے (کہ اﷲ صبر و شکر کا اجر کیسے دیتا ہے)،\qt@no{84}}%
\qt@newcmd\qurantrans@ur@mmdlxviii{اور اسماعیل اور ادریس اور ذوالکفل (علیہم السلام کو بھی یاد فرمائیں)، یہ سب صابر لوگ تھے،\qt@no{85}}%
\qt@newcmd\qurantrans@ur@mmdlxix{اور ہم نے انہیں اپنے (دامنِ) رحمت میں داخل فرمایا۔ بیشک وہ نیکو کاروں میں سے تھے،\qt@no{86}}%
\qt@newcmd\qurantrans@ur@mmdlxx{اور ذوالنون (مچھلی کے پیٹ والے نبی علیہ السلام کو بھی یاد فرمائیے) جب وہ (اپنی قوم پر) غضبناک ہو کر چل دیئے پس انہوں نے یہ خیال کر لیا کہ ہم ان پر (اس سفر میں) کوئی تنگی نہیں کریں گے پھر انہوں نے (دریا، رات اور مچھلی کے پیٹ کی تہہ در تہہ) تاریکیوں میں (پھنس کر) پکارا کہ تیرے سوا کوئی معبود نہیں تیری ذات پاک ہے، بیشک میں ہی (اپنی جان پر) زیادتی کرنے والوں میں سے تھا،\qt@no{87}}%
\qt@newcmd\qurantrans@ur@mmdlxxi{پس ہم نے ان کی دعا قبول فرما لی اور ہم نے انہیں غم سے نجات بخشی، اور اسی طرح ہم مومنوں کو نجات دیا کرتے ہیں،\qt@no{88}}%
\qt@newcmd\qurantrans@ur@mmdlxxii{اور زکریا (علیہ السلام کو بھی یاد کریں) جب انہوں نے اپنے رب کو پکارا: اے میرے رب! مجھے اکیلا مت چھوڑ اور تو سب وارثوں سے بہتر ہے،\qt@no{89}}%
\qt@newcmd\qurantrans@ur@mmdlxxiii{تو ہم نے ان کی دعا قبول فرما لی اور ہم نے انہیں یحیٰی (علیہ السلام) عطا فرمایا اور ان کی خاطر ان کی زوجہ کو (بھی) درست (قابلِ اولاد) بنا دیا۔ بیشک یہ (سب) نیکی کے کاموں (کی انجام دہی) میں جلدی کرتے تھے اور ہمیں شوق و رغبت اور خوف و خشیّت (کی کیفیتوں) کے ساتھ پکارا کرتے تھے، اور ہمارے حضور بڑے عجز و نیاز کے ساتھ گڑگڑاتے تھے،\qt@no{90}}%
\qt@newcmd\qurantrans@ur@mmdlxxiv{اس (پاکیزہ) خاتون (مریم علیہا السلام) کو بھی (یاد کریں) جس نے اپنی عفت کی حفاظت کی پھر ہم نے اس میں اپنی روح پھونک دی اور ہم نے اسے اور اس کے بیٹے (عیسٰی علیہ السلام) کو جہان والوں کے لئے (اپنی قدرت کی) نشانی بنا دیا،\qt@no{91}}%
\qt@newcmd\qurantrans@ur@mmdlxxv{بیشک یہ تمہاری ملت ہے (سب) ایک ہی ملت ہے اور میں تمہارا رب ہوں پس تم میری (ہی) عبادت کیا کرو،\qt@no{92}}%
\qt@newcmd\qurantrans@ur@mmdlxxvi{اور ان (اہلِ کتاب) نے آپس میں اپنے دین کو ٹکڑے ٹکڑے کر ڈالا، یہ سب ہماری ہی جانب لوٹ کر آنے والے ہیں،\qt@no{93}}%
\qt@newcmd\qurantrans@ur@mmdlxxvii{پس جو کوئی نیک عمل کرے اور وہ مومن بھی ہو تو اس کی کوشش (کی جزا) کا انکار نہ ہوگا، اور بیشک ہم اس کے (سب) اعمال کو لکھ رہے ہیں،\qt@no{94}}%
\qt@newcmd\qurantrans@ur@mmdlxxviii{اور جس بستی کو ہم نے ہلاک کر ڈالا ناممکن ہے کہ اس کے لوگ (مرنے کے بعد) ہماری طرف پلٹ کر نہ آئیں،\qt@no{95}}%
\qt@newcmd\qurantrans@ur@mmdlxxix{یہاں تک کہ جب یاجوج اور ماجوج کھول دیئے جائیں گے اور وہ ہر بلندی سے دوڑتے ہوئے اتر آئیں گے،\qt@no{96}}%
\qt@newcmd\qurantrans@ur@mmdlxxx{اور (قیامت کا) سچا وعدہ قریب ہو جائے گا تو اچانک کافر لوگوں کی آنکھیں کھلی رہ جائیں گی (وہ پکار اٹھیں گے:) ہائے ہماری شومئ قسمت! کہ ہم اس (دن کی آمد) سے غفلت میں پڑے رہے بلکہ ہم ظالم تھے،\qt@no{97}}%
\qt@newcmd\qurantrans@ur@mmdlxxxi{بیشک تم اور وہ (بت) جن کی تم اﷲ کے سوا پرستش کرتے تھے (سب) دوزخ کا ایندھن ہیں، تم اس میں داخل ہونے والے ہو،\qt@no{98}}%
\qt@newcmd\qurantrans@ur@mmdlxxxii{اگر یہ (واقعۃً) معبود ہوتے تو جہنم میں داخل نہ ہوتے، اور وہ سب اس میں ہمیشہ رہیں گے،\qt@no{99}}%
\qt@newcmd\qurantrans@ur@mmdlxxxiii{وہاں ان کی (آہوں کا شور اور) چیخ و پکار ہوگی اور اس میں کچھ (اور) نہ سن سکیں گے،\qt@no{100}}%
\qt@newcmd\qurantrans@ur@mmdlxxxiv{بیشک جن لوگوں کے لئے پہلے سے ہی ہماری طرف سے بھلائی مقرر ہو چکی ہے وہ اس (جہنم) سے دور رکھے جائیں گے،\qt@no{101}}%
\qt@newcmd\qurantrans@ur@mmdlxxxv{وہ اس کی آہٹ بھی نہ سنیں گے اور وہ ان (نعمتوں) میں ہمیشہ رہیں گے جن کی ان کے دل خواہش کریں گے،\qt@no{102}}%
\qt@newcmd\qurantrans@ur@mmdlxxxvi{روزِ قیامت کی) سب سے بڑی ہولناکی (بھی) انہیں رنجیدہ نہیں کرے گی اور فرشتے ان کا استقبال کریں گے (اور کہیں گے:) یہ تمہارا (ہی) دن ہے جس کا تم سے وعدہ کیا جاتا رہا،\qt@no{103}}%
\qt@newcmd\qurantrans@ur@mmdlxxxvii{اس دن ہم (ساری) سماوی کائنات کو اس طرح لپیٹ دیں گے جیسے لکھے ہوئے کاغذات کو لپیٹ دیا جاتا ہے، جس طرح ہم نے (کائنات کو) پہلی بار پیدا کیا تھا ہم (اس کے ختم ہو جانے کے بعد) اسی عملِ تخلیق کو دہرائیں گے۔ یہ وعدہ پورا کرنا ہم نے لازم کر لیا ہے۔ ہم (یہ اعادہ) ضرور کرنے والے ہیں،\qt@no{104}}%
\qt@newcmd\qurantrans@ur@mmdlxxxviii{اور بلا شبہ ہم نے زبور میں نصیحت کے (بیان کے) بعد یہ لکھ دیا تھا کہ (عالمِ آخرت کی) زمین کے وارث صرف میرے نیکو کار بندے ہوں گے،\qt@no{105}}%
\qt@newcmd\qurantrans@ur@mmdlxxxix{بیشک اس (قرآن) میں عبادت گزاروں کے لئے (حصولِ مقصد کی) کفایت و ضمانت ہے،\qt@no{106}}%
\qt@newcmd\qurantrans@ur@mmdxc{اور (اے رسولِ محتشم!) ہم نے آپ کو نہیں بھیجا مگر تمام جہانوں کے لئے رحمت بنا کر،\qt@no{107}}%
\qt@newcmd\qurantrans@ur@mmdxci{فرما دیجئے کہ میری طرف تو یہی وحی کی جاتی ہے کہ تمہارا معبود فقط ایک (ہی) معبود ہے، تو کیا تم اسلام قبول کرتے ہو،\qt@no{108}}%
\qt@newcmd\qurantrans@ur@mmdxcii{پھر اگر وہ رُوگردانی کریں تو فرما دیجئے: میں نے تم سب کو یکساں طور پر باخبر کر دیا ہے، اور میں نہیں جانتا کہ وہ (عذاب) نزدیک ہے یا دور جس کا تم سے وعدہ کیا جا رہا ہے،\qt@no{109}}%
\qt@newcmd\qurantrans@ur@mmdxciii{بیشک وہ بلند آواز کی بات بھی جانتا ہے اور وہ (کچھ) بھی جانتا ہے جو تم چھپاتے ہو،\qt@no{110}}%
\qt@newcmd\qurantrans@ur@mmdxciv{اور میں یہ نہیں جانتا شاید یہ (تاخیرِ عذاب اور تمہیں دی گئی ڈھیل) تمہارے حق میں آزمائش ہو اور (تمہیں) ایک مقرر وقت تک فائدہ پہنچانا مقصود ہو،\qt@no{111}}%
\qt@newcmd\qurantrans@ur@mmdxcv{ہمارے حبیب نے) عرض کیا: اے میرے رب! (ہمارے درمیان) حق کے ساتھ فیصلہ فرما دے، اور ہمارا رب بے حد رحم فرمانے والا ہے، اسی سے مدد طلب کی جاتی ہے ان (دل آزار) باتوں پر جو (اے کافرو!) تم بیان کرتے ہو،\qt@no{112}}%
\qt@newcmd\qurantrans@ur@mmdxcvi{\basmalahur اے لوگو! اپنے رب سے ڈرتے رہو۔ بیشک قیامت کا زلزلہ بڑی سخت چیز ہے،\qt@no{1}}%
\qt@newcmd\qurantrans@ur@mmdxcvii{جس دن تم اسے دیکھو گے ہر دودھ پلانے والی (ماں) اس (بچی) کو بھول جائے گی جسے وہ دودھ پلا رہی تھی اور ہر حمل والی عورت اپنا حمل گرا دے گی اور (اے دیکھنے والے!) تو لوگوں کو نشہ (کی حالت) میں دیکھے گا حالانکہ وہ (فی الحقیقت) نشہ میں نہیں ہوں گے لیکن اﷲ کا عذاب (ہی اتنا) سخت ہوگا (کہ ہر شخص حواس باختہ ہو جائے گا)،\qt@no{2}}%
\qt@newcmd\qurantrans@ur@mmdxcviii{اور کچھ لوگ (ایسے) ہیں جو اﷲ کے بارے میں بغیر علم و دانش کے جھگڑا کرتے ہیں اور ہر سرکش شیطان کی پیروی کرتے ہیں،\qt@no{3}}%
\qt@newcmd\qurantrans@ur@mmdxcix{جس (شیطان) کے بارے میں لکھ دیا گیا ہے کہ جو شخص اسے دوست رکھے گا سو وہ اسے گمراہ کر دے گا اور اسے دوزخ کے عذاب کا راستہ دکھائے گا،\qt@no{4}}%
\qt@newcmd\qurantrans@ur@mmdc{اے لوگو! اگر تمہیں (مرنے کے بعد) جی اٹھنے میں شک ہے تو (اپنی تخلیق و ارتقاء پر غور کرو) کہ ہم نے تمہاری تخلیق (کی کیمیائی ابتداء) مٹی سے کی پھر (حیاتیاتی ابتداء) ایک تولیدی قطرہ سے پھر (رِحمِ مادر کے اندر جونک کی صورت میں) معلق وجود سے پھر ایک (ایسے) لوتھڑے سے جو دانتوں سے چبایا ہوا لگتا ہے، جس میں بعض اعضاء کی ابتدائی تخلیق نمایاں ہو چکی ہے اور بعض (اعضاء) کی تخلیق ابھی عمل میں نہیں آئی تاکہ ہم تمہارے لئے (اپنی قدرت اور اپنے کلام کی حقانیت) ظاہر کر دیں، اور ہم جسے چاہتے ہیں رحموں میں مقررہ مدت تک ٹھہرائے رکھتے ہیں پھر ہم تمہیں بچہ بنا کر نکالتے ہیں، پھر (تمہاری پرورش کرتے ہیں) تاکہ تم اپنی جوانی کو پہنچ جاؤ، اور تم میں سے وہ بھی ہیں جو (جلد) وفات پا جاتے ہیں اور کچھ وہ ہیں جو نہایت ناکارہ عمر تک لوٹائے جاتے ہیں تاکہ وہ (شخص یہ منظر بھی دیکھ لے کہ) سب کچھ جان لینے کے بعد (اب پھر) کچھ (بھی) نہیں جانتا، اور تو زمین کو بالکل خشک (مُردہ) دیکھتا ہے پھر جب ہم اس پر پانی برسا دیتے ہیں تو اس میں تازگی و شادابی کی جنبش آجاتی ہے اور وہ پھولنے بڑھنے لگتی ہے اور خوش نما نباتات میں سے ہر نوع کے جوڑے اگاتی ہے،\qt@no{5}}%
\qt@newcmd\qurantrans@ur@mmdci{یہ (سب کچھ) اس لئے (ہوتا رہتا) ہے کہ اﷲ ہی سچا (خالق اور رب) ہے اور بیشک وہی مُردوں (بے جان) کو زندہ (جان دار) کرتا ہے، اور یقینًا وہی ہر چیز پر بڑا قادر ہے،\qt@no{6}}%
\qt@newcmd\qurantrans@ur@mmdcii{اور بیشک قیامت آنے والی ہے اس میں کوئی شک نہیں اور یقیناً اﷲ ان لوگوں کو زندہ کر کے اٹھا دے گا جو قبروں میں ہوں گے،\qt@no{7}}%
\qt@newcmd\qurantrans@ur@mmdciii{اور لوگوں میں سے کچھ ایسے بھی ہیں جو اﷲ (کی ذات و صفات اور قدرتوں) کے بارے میں جھگڑا کرتے رہتے ہیں بغیر علم و دانش کے اور بغیر کسی ہدایت و دلیل کے اور بغیر کسی روشن کتاب کے (جو آسمان سے اتری ہو)،\qt@no{8}}%
\qt@newcmd\qurantrans@ur@mmdciv{اپنی گردن کو (تکبّر سے) مروڑے ہوئے تاکہ (دوسروں کو بھی) اﷲ کی راہ سے بہکا دے، اس کے لئے دنیا میں (بھی) رسوائی ہے اور قیامت کے دن ہم اسے جلا دینے والے عذاب کا مزہ چکھائیں گے،\qt@no{9}}%
\qt@newcmd\qurantrans@ur@mmdcv{یہ تیرے ان اعمال کے باعث ہے جو تیرے ہاتھ آگے بھیج چکے تھے اور بیشک اﷲ اپنے بندوں پر بالکل ظلم کرنے والا نہیں ہے،\qt@no{10}}%
\qt@newcmd\qurantrans@ur@mmdcvi{اور لوگوں میں سے کوئی ایسا بھی ہوتا ہے جو (بالکل دین کے) کنارے پر (رہ کر) اﷲ کی عبادت کرتا ہے، پس اگر اسے کوئی (دنیاوی) بھلائی پہنچتی ہے تو وہ اس (دین) سے مطمئن ہو جاتا ہے اور اگر اسے کوئی آزمائش پہنچتی ہے تو اپنے منہ کے بل (دین سے) پلٹ جاتا ہے، اس نے دنیا میں (بھی) نقصان اٹھایا اور آخرت میں (بھی)، یہی تو واضح (طور پر) بڑا خسارہ ہے،\qt@no{11}}%
\qt@newcmd\qurantrans@ur@mmdcvii{وہ (شخص) اﷲ کو چھوڑ کر اس (بت) کی عبادت کرتا ہے جو نہ اسے نقصان پہنچا سکے اور نہ ہی اسے نفع پہنچا سکے، یہی تو (بہت) دور کی گمراہی ہے،\qt@no{12}}%
\qt@newcmd\qurantrans@ur@mmdcviii{وہ اسے پوجتا ہے جس کا نقصان اس کے نفع سے زیادہ قریب ہے، وہ کیا ہی برا مددگار ہے اور کیا ہی برا ساتھی ہے،\qt@no{13}}%
\qt@newcmd\qurantrans@ur@mmdcix{بیشک اﷲ ان لوگوں کو جو ایمان لائے اور نیک عمل کرتے رہے جنتوں میں داخل فرمائے گا جن کے نیچے سے نہریں رواں ہیں، یقیناً اﷲ جو ارادہ فرماتا ہے کر دیتا ہے،\qt@no{14}}%
\qt@newcmd\qurantrans@ur@mmdcx{جو شخص یہ گمان کرتا ہے کہ اﷲ اپنے (محبوب و برگزیدہ) رسول کی دنیا و آخرت میں ہرگز مدد نہیں کرے گا اسے چاہئے کہ (گھر کی) چھت سے ایک رسی باندھ کر لٹک جائے پھر (خود کو) پھانسی دے لے پھر دیکھے کیا اس کی یہ تدبیر اس (نصرتِ الٰہی) کو دور کر دیتی ہے جس پر غصہ کھا رہا ہے،\qt@no{15}}%
\qt@newcmd\qurantrans@ur@mmdcxi{اور اسی طرح ہم نے اس (پورے قرآن) کو روشن دلائل کی صورت میں نازل فرمایا ہے اور بیشک اﷲ جسے ارادہ فرماتا ہے ہدایت سے نوازتا ہے،\qt@no{16}}%
\qt@newcmd\qurantrans@ur@mmdcxii{بیشک جو لوگ ایمان لائے اور جو لوگ یہودی ہوئے اور ستارہ پرست اور نصارٰی (عیسائی) اور آتش پرست اور جو مشرک ہوئے، یقیناً اﷲ قیامت کے دن ان (سب) کے درمیان فیصلہ فرما دے گا۔ بیشک اﷲ ہر چیز کا مشاہدہ فرما رہا ہے،\qt@no{17}}%
\qt@newcmd\qurantrans@ur@mmdcxiii{کیا تم نے نہیں دیکھا کہ اﷲ ہی کے لئے (وہ ساری مخلوق) سجدہ ریز ہے جو آسمانوں میں ہے اور جو زمین میں ہے اور سورج (بھی) اور چاند (بھی) اور ستارے (بھی) اور پہاڑ (بھی) اور درخت (بھی) اور جانور (بھی) اور بہت سے انسان (بھی)، اور بہت سے (انسان) ایسے بھی ہیں جن پر (ان کے کفر و شرک کے باعث) عذاب ثابت ہو چکا ہے، اور اﷲ جسے ذلیل کر دے تو اسے کوئی عزت دینے والا نہیں ہے۔ بیشک اﷲ جو چاہتا ہے کر دیتا ہے،\qt@no{18}}%
\qt@newcmd\qurantrans@ur@mmdcxiv{یہ دو فریق ہیں جو اپنے رب کے بارے میں جھگڑ رہے ہیں پس جو کافر ہوگئے ہیں ان کے لئے آتشِ دوزخ کے کپڑے کاٹ (کر، سِی) دیئے گئے ہیں۔ ان کے سروں پر کھولتا ہوا پانی انڈیلا جائے گا،\qt@no{19}}%
\qt@newcmd\qurantrans@ur@mmdcxv{جس سے ان کے شکموں میں جو کچھ ہے پگھل جائے گا اور (ان کی) کھالیں بھی،\qt@no{20}}%
\qt@newcmd\qurantrans@ur@mmdcxvi{اور ان (کے سروں پر مارنے) کے لئے لوہے کے ہتھوڑے ہوں گے،\qt@no{21}}%
\qt@newcmd\qurantrans@ur@mmdcxvii{وہ جب بھی شدّتِ تکلیف سے وہاں سے نکلنے کا ارادہ کریں گے (تو) اس میں واپس لوٹا دیئے جائیں گے اور (ان سے کہا جائے گا:) سخت آگ کے عذاب کا مزہ چکھو،\qt@no{22}}%
\qt@newcmd\qurantrans@ur@mmdcxviii{بیشک اﷲ ان لوگوں کو جو ایمان لے آئے ہیں اور نیک اعمال انجام دیتے ہیں جنتوں میں داخل فرمائے گا جن کے نیچے سے نہریں جاری ہیں وہاں انہیں سونے کے کنگنوں اور موتیوں سے آراستہ کیا جائے گا، اور وہاں ان کا لباس ریشم ہوگا،\qt@no{23}}%
\qt@newcmd\qurantrans@ur@mmdcxix{اور انہیں (دنیا میں) پاکیزہ قول کی ہدایت کی گئی اور انہیں (اسلام کے) پسندیدہ راستہ کی طرف رہنمائی کی گئی،\qt@no{24}}%
\qt@newcmd\qurantrans@ur@mmdcxx{بیشک جن لوگوں نے کفر کیا ہے اور (دوسروں کو) اﷲ کی راہ سے اور اس مسجدِ حرام (کعبۃ اﷲ) سے روکتے ہیں جسے ہم نے سب لوگوں کے لئے یکساں بنایا ہے اس میں وہاں کے باسی اور پردیسی (میں کوئی فرق نہیں)، اور جو شخص اس میں ناحق طریقہ سے کج روی (یعنی مقررہ حدود و حقوق کی خلاف ورزی) کا ارادہ کرے ہم اسے دردناک عذاب کا مزہ چکھائیں گے،\qt@no{25}}%
\qt@newcmd\qurantrans@ur@mmdcxxi{اور (وہ وقت یاد کیجئے) جب ہم نے ابراہیم (علیہ السلام) کے لئے بیت اﷲ (یعنی خانہ کعبہ کی تعمیر) کی جگہ کا تعین کر دیا (اور انہیں حکم فرمایا) کہ میرے ساتھ کسی چیز کو شریک نہ ٹھہرانا اور میرے گھر کو (تعمیر کرنے کے بعد) طواف کرنے والوں اور قیام کرنے والوں اور رکوع کر نے والوں اور سجود کرنے والوں کے لئے پاک و صاف رکھنا،\qt@no{26}}%
\qt@newcmd\qurantrans@ur@mmdcxxii{اور تم لوگوں میں حج کا بلند آواز سے اعلان کرو وہ تمہارے پاس پیدل اور تمام دبلے اونٹوں پر (سوار) حاضر ہو جائیں گے جو دور دراز کے راستوں سے آتے ہیں،\qt@no{27}}%
\qt@newcmd\qurantrans@ur@mmdcxxiii{تاکہ وہ اپنے فوائد (بھی) پائیں اور (قربانی کے) مقررہ دنوں کے اندر اﷲ نے جو مویشی چوپائے ان کو بخشے ہیں ان پر (ذبح کے وقت) اﷲ کے نام کا ذکر بھی کریں، پس تم اس میں سے خود (بھی) کھاؤ اور خستہ حال محتاج کو (بھی) کھلاؤ،\qt@no{28}}%
\qt@newcmd\qurantrans@ur@mmdcxxiv{پھر انہیں چاہئے کہ (احرام سے نکلتے ہوئے بال اور ناخن کٹوا کر) اپنا میل کچیل دور کریں اور اپنی نذریں (یا بقیہ مناسک) پوری کریں اور (اﷲ کے) قدیم گھر (خانہ کعبہ) کا طوافِ (زیارت) کریں،\qt@no{29}}%
\qt@newcmd\qurantrans@ur@mmdcxxv{یہی (حکم) ہے، اور جو شخص اﷲ (کی بارگاہ) سے عزت یافتہ چیزوں کی تعظیم کرتا ہے تو وہ اس کے رب کے ہاں اس کے لئے بہتر ہے، اور تمہارے لئے (سب) مویشی (چوپائے) حلال کر دیئے گئے ہیں سوائے ان کے جن کی ممانعت تمہیں پڑھ کر سنائی گئی ہے سو تم بتوں کی پلیدی سے بچا کرو اور جھوٹی بات سے پرہیز کیا کرو،\qt@no{30}}%
\qt@newcmd\qurantrans@ur@mmdcxxvi{صرف اﷲ کے ہوکر رہو اس کے ساتھ (کسی کو) شریک نہ ٹھہراتے ہوئے، اور جو کوئی اﷲ کے ساتھ شرک کرتاہے تو گویا وہ (ایسے ہے جیسے) آسمان سے گر پڑے پھر اس کو پرندے اچک لے جائیں یا ہوا اس کو کسی دور کی جگہ میں نیچے جا پھینکے،\qt@no{31}}%
\qt@newcmd\qurantrans@ur@mmdcxxvii{یہی (حکم) ہے، اور جو شخص اﷲ کی نشانیوں کی تعظیم کرتا ہے (یعنی ان جانداروں، یادگاروں، مقامات، احکام اور مناسک وغیرہ کی تعظیم جو اﷲ یا اﷲ والوں کے ساتھ کسی اچھی نسبت یا تعلق کی وجہ سے جانے پہچانے جاتے ہیں) تو یہ (تعظیم) دلوں کے تقوٰی میں سے ہے (یہ تعظیم وہی لوگ بجا لاتے ہیں جن کے دلوں کو تقوٰی نصیب ہوگیا ہو)،\qt@no{32}}%
\qt@newcmd\qurantrans@ur@mmdcxxviii{تمہارے لئے ان (قربانی کے جانوروں) میں مقررہ مدت تک فوائد ہیں پھر انہیں قدیم گھر (خانہ کعبہ) کی طرف (ذبح کے لئے) پہنچنا ہے،\qt@no{33}}%
\qt@newcmd\qurantrans@ur@mmdcxxix{اور ہم نے ہر امت کے لئے ایک قربانی مقرر کر دی ہے تاکہ وہ ان مویشی چوپایوں پر جو اﷲ نے انہیں عنایت فرمائے ہیں (ذبح کے وقت) اﷲ کا نام لیں، سو تمہارا معبود ایک (ہی) معبود ہے پس تم اسی کے فرمانبردار بن جاؤ، اور (اے حبیب!) عاجزی کرنے والوں کو خوشخبری سنا دیں،\qt@no{34}}%
\qt@newcmd\qurantrans@ur@mmdcxxx{یہ) وہ لوگ ہیں کہ جب اﷲ کا ذکر کیا جاتا ہے (تو) ان کے دل ڈرنے لگتے ہیں اور جو مصیبتیں انہیں پہنچتی ہیں ان پر صبر کرتے ہیں اور نماز قائم رکھنے والے ہیں اور جو کچھ ہم نے انہیں عطا فرمایا ہے اس میں سے خرچ کرتے ہیں،\qt@no{35}}%
\qt@newcmd\qurantrans@ur@mmdcxxxi{اور قربانی کے بڑے جانوروں (یعنی اونٹ اور گائے وغیرہ) کو ہم نے تمہارے لئے اﷲ کی نشانیوں میں سے بنا دیا ہے ان میں تمہارے لئے بھلائی ہے پس تم (انہیں) قطار میں کھڑا کر کے (نیزہ مار کر نحر کے وقت) ان پر اﷲ کا نام لو، پھر جب وہ اپنے پہلو کے بل گر جائیں تو تم خود (بھی) اس میں سے کھاؤ اور قناعت سے بیٹھے رہنے والوں کو اور سوال کرنے والے (محتاجوں) کو (بھی) کھلاؤ۔ اس طرح ہم نے انہیں تمہارے تابع کر دیا ہے تاکہ تم شکر بجا لاؤ،\qt@no{36}}%
\qt@newcmd\qurantrans@ur@mmdcxxxii{ہرگز نہ (تو) اﷲ کو ان (قربانیوں) کا گوشت پہنچتا ہے اور نہ ان کا خون مگر اسے تمہاری طرف سے تقوٰی پہنچتا ہے، اس طرح (اﷲ نے) انہیں تمہارے تابع کر دیا ہے تاکہ تم (وقتِ ذبح) اﷲ کی تکبیر کہو جیسے اس نے تمہیں ہدایت فرمائی ہے، اور آپ نیکی کرنے والوں کو خوشخبری سنا دیں،\qt@no{37}}%
\qt@newcmd\qurantrans@ur@mmdcxxxiii{بیشک اﷲ صاحبِ ایمان لوگوں سے (دشمنوں کا فتنہ و شر) دور کرتا رہتا ہے۔ بیشک اﷲ کسی خائن (اور) ناشکرے کو پسند نہیں کرتا،\qt@no{38}}%
\qt@newcmd\qurantrans@ur@mmdcxxxiv{ان لوگوں کو (جہاد کی) اجازت دے دی گئی ہے جن سے (ناحق) جنگ کی جارہی ہے اس وجہ سے کہ ان پر ظلم کیا گیا، اور بیشک اﷲ ان (مظلوموں) کی مدد پر بڑا قادر ہے،\qt@no{39}}%
\qt@newcmd\qurantrans@ur@mmdcxxxv{یہ) وہ لوگ ہیں جو اپنے گھروں سے ناحق نکالے گئے صرف اس بنا پر کہ وہ کہتے تھے کہ ہمارا رب اﷲ ہے (یعنی انہوں نے باطل کی فرمانروائی تسلیم کرنے سے انکار کیا تھا)، اور اگر اﷲ انسانی طبقات میں سے بعض کو بعض کے ذریعہ (جہاد و انقلابی جد و جہد کی صورت میں) ہٹاتا نہ رہتا تو خانقاہیں اور گرجے اور کلیسے اور مسجدیں (یعنی تمام ادیان کے مذہبی مراکز اور عبادت گاہیں) مسمار اور ویران کر دی جاتیں جن میں کثرت سے اﷲ کے نام کا ذکر کیا جاتا ہے، اور جو شخص اﷲ (کے دین) کی مدد کرتا ہے یقیناً اﷲ اس کی مدد فرماتا ہے۔ بیشک اﷲ ضرور (بڑی) قوت والا (سب پر) غالب ہے (گویا حق اور باطل کے تضاد و تصادم کے انقلابی عمل سے ہی حق کی بقا ممکن ہے)،\qt@no{40}}%
\qt@newcmd\qurantrans@ur@mmdcxxxvi{یہ اہلِ حق) وہ لوگ ہیں کہ اگر ہم انہیں زمین میں اقتدار دے دیں (تو) وہ نماز (کا نظام) قائم کریں اور زکوٰۃ کی ادائیگی (کا انتظام) کریں اور (پورے معاشرے میں نیکی اور) بھلائی کا حکم کریں اور (لوگوں کو) برائی سے روک دیں، اور سب کاموں کا انجام اﷲ ہی کے اختیار میں ہے،\qt@no{41}}%
\qt@newcmd\qurantrans@ur@mmdcxxxvii{اور اگر یہ (کفار) آپ کو جھٹلاتے ہیں تو ا ن سے پہلے قومِ نوح اور عاد و ثمود نے بھی (اپنے رسولوں کو) جھٹلایا تھا،\qt@no{42}}%
\qt@newcmd\qurantrans@ur@mmdcxxxviii{اور قومِ ابراہیم اور قومِ لوط نے (بھی)،\qt@no{43}}%
\qt@newcmd\qurantrans@ur@mmdcxxxix{اور باشندگانِ مدین نے (بھی جھٹلایا تھا) اور موسٰی (علیہ السلام) کو بھی جھٹلایا گیا سو میں (ان سب) کافروں کو مہلت دیتا رہا پھر میں نے انہیں پکڑ لیا، پھر (بتائیے) میرا عذاب کیسا تھا،\qt@no{44}}%
\qt@newcmd\qurantrans@ur@mmdcxl{پھر کتنی ہی (ایسی) بستیاں ہیں جنہیں ہم نے ہلاک کر ڈالا اس حال میں کہ وہ ظالم تھیں پس وہ اپنی چھتوں پر گری پڑی ہیں اور (ان کی ہلاکت سے) کتنے کنویں بے کار (ہوگئے) اور کتنے مضبوط محل اجڑے پڑے (ہیں)،\qt@no{45}}%
\qt@newcmd\qurantrans@ur@mmdcxli{تو کیا انہوں نے زمین میں سیر و سیاحت نہیں کی کہ (شاید ان کھنڈرات کو دیکھ کر) ان کے دل (ایسے) ہو جاتے جن سے وہ سمجھ سکتے یا کان (ایسے) ہو جاتے جن سے وہ (حق کی بات) سن سکتے، تو حقیقت یہ ہے کہ (ایسوں کی) آنکھیں اندھی نہیں ہوتیں لیکن دل اندھے ہو جاتے ہیں جو سینوں میں ہیں،\qt@no{46}}%
\qt@newcmd\qurantrans@ur@mmdcxlii{اور یہ آپ سے عذاب میں جلدی کے خواہش مند ہیں اور اﷲ ہرگز اپنے وعدہ کی خلاف ورزی نہ کرے گا، اور (جب عذاب کا وقت آئے گا) تو (عذاب کا) ایک دن آپ کے رب کے ہاں ایک ہزار سال کی مانند ہے (اس حساب سے) جو تم شمار کرتے ہو،\qt@no{47}}%
\qt@newcmd\qurantrans@ur@mmdcxliii{اور کتنی ہی بستیاں (ایسی) ہیں جن کو میں نے مہلت دی حالانکہ وہ ظالم تھیں پھر میں نے انہیں (عذاب کی) گرفت میں لے لیا، اور (ہر کسی کو) میری ہی طرف لوٹ کر آنا ہے،\qt@no{48}}%
\qt@newcmd\qurantrans@ur@mmdcxliv{فرما دیجئے: اے لوگو! میں تو محض تمہارے لئے (عذابِ الٰہی کا) ڈر سنانے والا ہوں،\qt@no{49}}%
\qt@newcmd\qurantrans@ur@mmdcxlv{پس جو لوگ ایمان لائے اور نیک عمل کرتے رہے ان کے لئے مغفرت ہے اور (مزید) بزرگی والی عطا ہے،\qt@no{50}}%
\qt@newcmd\qurantrans@ur@mmdcxlvi{اور جو لوگ ہماری آیتوں (کے ردّ) میں کوشاں رہتے ہیں اس خیال سے کہ (ہمیں) عاجز کردیں گے وہی لوگ اہلِ دوزخ ہیں،\qt@no{51}}%
\qt@newcmd\qurantrans@ur@mmdcxlvii{اور ہم نے آپ سے پہلے کوئی رسول نہیں بھیجا اور نہ کوئی نبی مگر (سب کے ساتھ یہ واقعہ گزرا کہ) جب اس (رسول یا نبی) نے (لوگوں پر کلامِ الٰہی) پڑھا (تو) شیطان نے (لوگوں کے ذہنوں میں) اس (نبی کے) پڑھے ہوئے (یعنی تلاوت شدہ) کلام میں (اپنی طرف سے باطل شبہات اور فاسد خیالات کو) ملا دیا، سو شیطان جو (وسوسے سننے والوں کے ذہنوں میں) ڈالتا ہے اﷲ انہیں زائل فرما دیتا ہے پھر اللہ اپنی آیتوں کو (اہلِ ایمان کے دلوں میں) نہایت مضبوط کر دیتا ہے، اور اﷲ خوب جاننے والا بڑی حکمت والا ہے،\qt@no{52}}%
\qt@newcmd\qurantrans@ur@mmdcxlviii{یہ اس لئے ہوتا ہے) تاکہ اﷲ ان (باطل خیالات اور فاسد شبہات) کو جو شیطان (لوگوں کے ذہنوں میں) ڈالتا ہے ایسے لوگوں کے لئے آزمائش بنا دے جن کے دلوں میں (منافقت کی) بیماری ہے اور جن لوگوں کے دل (کفر و عناد کے باعث) سخت ہیں، اور بیشک ظالم لوگ بڑی شدید مخالفت میں مبتلا ہیں،\qt@no{53}}%
\qt@newcmd\qurantrans@ur@mmdcxlix{اور تاکہ وہ لوگ جنہیں علم (صحیح) عطا کیا گیا ہے جان لیں کہ وہی (وحی جس کی پیغمبر نے تلاوت کی ہے) آپ کے رب کی طرف سے (مَبنی) برحق ہے سو وہ اسی پر ایمان لائیں (اور شیطانی وسوسوں کو ردّ کردیں) اور ان کے دل اس (رب) کے لئے عاجزی کریں، اور بیشک اﷲ مومنوں کو ضرور سیدھی راہ کی طرف ہدایت فرمانے والا ہے،\qt@no{54}}%
\qt@newcmd\qurantrans@ur@mmdcl{اور کافر لوگ ہمیشہ اس (قرآن) کے حوالے سے شک میں رہیں گے یہاں تک کہ اچانک ان پر قیامت آپہنچے یا اس دن کا عذاب آجائے جس سے نجات کا کوئی امکان نہیں،\qt@no{55}}%
\qt@newcmd\qurantrans@ur@mmdcli{حکمرانی اس دن صرف اﷲ ہی کی ہوگی۔ وہی ان کے درمیان فیصلہ فرمائے گا، پس جو لوگ ایمان لائے اور نیک عمل کرتے رہے (وہ) نعمت کے باغات میں (قیام پذیر) ہوں گے،\qt@no{56}}%
\qt@newcmd\qurantrans@ur@mmdclii{اور جنہوں نے کفر کیا اور ہماری آیتوں کو جھٹلایا تو انہی لوگوں کے لئے ذلت آمیز عذاب ہوگا،\qt@no{57}}%
\qt@newcmd\qurantrans@ur@mmdcliii{اور جن لوگوں نے اﷲ کی راہ میں (وطن سے) ہجرت کی پھر قتل کر دیئے گئے یا (راہِ حق کی مصیبتیں جھیلتے جھیلتے) مرگئے تو اﷲ انہیں ضرور رزقِ حسن (یعنی اُخروی عطاؤں) کی روزی بخشے گا، اور بیشک اﷲ سب سے بہتر رزق دینے والا ہے،\qt@no{58}}%
\qt@newcmd\qurantrans@ur@mmdcliv{وہ ضرور انہیں اس جگہ (یعنی مقامِ رضوان میں) داخل فرمائے گا جس سے وہ راضی ہو جائیں گے، اور بیشک اﷲ خوب جاننے والا بُردبار ہے،\qt@no{59}}%
\qt@newcmd\qurantrans@ur@mmdclv{حکم) یہی ہے، اور جس شخص نے اتنا ہی بدلہ لیا جتنی اسے اذیت دی گئی تھی پھر اس شخص پر زیادتی کی جائے تو اﷲ ضرور اس کی مدد فرمائے گا۔ بیشک اﷲ درگزر فرمانے والا بڑا بخشنے والا ہے،\qt@no{60}}%
\qt@newcmd\qurantrans@ur@mmdclvi{یہ اس وجہ سے ہے کہ اﷲ رات کو دن میں داخل فرماتا ہے اور دن کو رات میں داخل فرماتا ہے اور بیشک اﷲ خوب سننے والا دیکھنے والا ہے،\qt@no{61}}%
\qt@newcmd\qurantrans@ur@mmdclvii{یہ اس لئے کہ اﷲ ہی حق ہے اور بیشک وہ (کفار) اس کے سوا جو کچھ (بھی) پوجتے ہیں وہ باطل ہے اور یقیناً اﷲ ہی بہت بلند بہت بڑا ہے،\qt@no{62}}%
\qt@newcmd\qurantrans@ur@mmdclviii{کیا آپ نے نہیں دیکھا کہ اﷲ آسمان کی جانب سے پانی اتارتا ہے تو زمین سرسبز و شاداب ہو جاتی ہے۔ بیشک اﷲ مہربان (اور) بڑا خبردار ہے،\qt@no{63}}%
\qt@newcmd\qurantrans@ur@mmdclix{اسی کا ہے جو کچھ آسمانوں میں ہے اور جو کچھ زمین میں ہے، اور بیشک اﷲ ہی بے نیاز قابلِ ستائش ہے،\qt@no{64}}%
\qt@newcmd\qurantrans@ur@mmdclx{کیا تم نے نہیں دیکھا کہ اﷲ نے جو کچھ زمین میں ہے تمہارے لئے مسخر فرما دیا ہے اور کشتیوں کو (بھی) جو اس کے اَمر (یعنی قانون) سے سمندر (و دریا) میں چلتی ہیں، اور آسمان (یعنی خلائی و فضائی کرّوں) کو زمین پر گرنے سے (ایک آفاقی نظام کے ذریعہ) تھامے ہوئے ہے مگر اسی کے حکم سے (جب وہ چاہے گا آپس میں ٹکرا جائیں گے)۔ بیشک اﷲ تمام انسانوں کے ساتھ نہایت شفقت فرمانے والا بڑا مہربان ہے،\qt@no{65}}%
\qt@newcmd\qurantrans@ur@mmdclxi{اور وہی ہے جس نے تمہیں زندگی بخشی پھر تمہیں موت دیتا ہے پھر تمہیں (دوبارہ) زندگی دے گا۔ بیشک انسان ہی بڑا ناشکر گزار ہے،\qt@no{66}}%
\qt@newcmd\qurantrans@ur@mmdclxii{ہم نے ہر ایک امت کے لئے (احکامِ شریعت یا عبادت و قربانی کی) ایک راہ مقرر کر دی ہے، انہیں اسی پر چلنا ہے، سو یہ لوگ آپ سے ہرگز (اﷲ کے) حکم میں جھگڑا نہ کریں، اور آپ اپنے رب کی طرف بلاتے رہیں۔ بیشک آپ ہی سیدھی (راہِ) ہدایت پر ہیں،\qt@no{67}}%
\qt@newcmd\qurantrans@ur@mmdclxiii{اگر وہ آپ سے جھگڑا کریں تو آپ فرما دیجئے: اﷲ بہتر جانتا ہے جو کچھ تم کر رہے ہو،\qt@no{68}}%
\qt@newcmd\qurantrans@ur@mmdclxiv{اﷲ تمہارے درمیان قیامت کے دن ان تمام باتوں کا فیصلہ فرما دے گا جن میں تم اختلاف کرتے رہے تھے،\qt@no{69}}%
\qt@newcmd\qurantrans@ur@mmdclxv{کیا تمہیں معلوم نہیں کہ اﷲ وہ سب کچھ جانتا ہے جو آسمان اور زمین میں ہے، بیشک یہ سب کتاب (لوحِ محفوظ) میں (درج) ہے، یقیناً یہ سب اﷲ پر (بہت) آسان ہے،\qt@no{70}}%
\qt@newcmd\qurantrans@ur@mmdclxvi{اور یہ لوگ اﷲ کے سوا ان (بتوں) کی پرستش کرتے ہیں جس کی اُس نے کوئی سند نہیں اتاری اور نہ (ہی) انہیں اس (بت پرستی کے انجام) کا کچھ علم ہے، اور (قیامت کے دن) ظالموں کا کوئی مددگار نہ ہوگا،\qt@no{71}}%
\qt@newcmd\qurantrans@ur@mmdclxvii{اور جب ان (کافروں) پر ہماری روشن آیتیں تلاوت کی جاتی ہیں (تو) آپ ان کافروں کے چہروں میں ناپسندیدگی (و ناگواری کے آثار) صاف دیکھ سکتے ہیں۔ ایسے لگتا ہے کہ عنقریب ان لوگوں پر جھپٹ پڑیں گے جو انہیں ہماری آیات پڑھ کر سنا رہے ہیں، آپ فرما دیجئے: (اے مضطرب ہونے والے کافرو!) کیا میں تمہیں اس سے (بھی) زیادہ تکلیف دہ چیز سے آگاہ کروں؟ (وہ دوزخ کی) آگ ہے، جس کا اﷲ نے کافروں سے وعدہ کر رکھا ہے، اور وہ بہت ہی برا ٹھکانا ہے،\qt@no{72}}%
\qt@newcmd\qurantrans@ur@mmdclxviii{اے لوگو! ایک مثال بیان کی جاتی ہے سو اسے غور سے سنو: بیشک جن (بتوں) کو تم اﷲ کے سوا پوجتے ہو وہ ہرگز ایک مکھی (بھی) پیدا نہیں کرسکتے اگرچہ وہ سب اس (کام) کے لئے جمع ہو جائیں، اور اگر ان سے مکھی کوئی چیز چھین کر لے جائے (تو) وہ اس چیز کو اس (مکھی) سے چھڑا (بھی) نہیں سکتے، کتنا بے بس ہے طالب (عابد) بھی اور مطلوب (معبود) بھی،\qt@no{73}}%
\qt@newcmd\qurantrans@ur@mmdclxix{ان (کافروں) نے اﷲ کی قدر نہ کی جیسی اس کی قدر کرنا چاہئے تھی۔ بیشک اﷲ بڑی قوت والا (ہر چیز پر) غالب ہے،\qt@no{74}}%
\qt@newcmd\qurantrans@ur@mmdclxx{اﷲ فرشتوں میں سے (بھی) اور انسانوں میں سے (بھی اپنا) پیغام پہنچانے والوں کو منتخب فرما لیتا ہے۔ بیشک اﷲ خوب سننے والا خوب دیکھنے والا ہے،\qt@no{75}}%
\qt@newcmd\qurantrans@ur@mmdclxxi{وہ ان (چیزوں) کو (خوب) جانتا ہے جو ان کے آگے ہیں اور جو ان کے پیچھے ہیں، اور تمام کام اسی کی طرف لوٹائے جاتے ہیں،\qt@no{76}}%
\qt@newcmd\qurantrans@ur@mmdclxxii{اے ایمان والو! تم رکوع کرتے رہو اور سجود کرتے رہو، اور اپنے رب کی عبادت کرتے رہو اور (دیگر) نیک کام کئے جاؤ تاکہ تم فلاح پا سکو،\qt@no{77}}%
\qt@newcmd\qurantrans@ur@mmdclxxiii{اور اﷲ (کی محبت و طاعت اور اس کے دین کی اشاعت و اقامت) میں جہاد کرو جیسا کہ اس کے جہاد کا حق ہے۔ اس نے تمہیں منتخب فرما لیا ہے اور اس نے تم پر دین میں کوئی تنگی نہیں رکھی۔ (یہی) تمہارے باپ ابراہیم (علیہ السلام) کا دین ہے۔ اس (اﷲ) نے تمہارا نام مسلمان رکھا ہے، اس سے پہلے (کی کتابوں میں) بھی اور اس (قرآن) میں بھی تاکہ یہ رسولِ (آخر الزماں صلی اللہ علیہ وآلہ وسلم) تم پر گواہ ہو جائیں اور تم بنی نوع انسان پر گواہ ہو جاؤ، پس (اس مرتبہ پر فائز رہنے کے لئے) تم نماز قائم کیا کرو اور زکوٰۃ ادا کیا کرو اور اﷲ (کے دامن) کو مضبوطی سے تھامے رکھو، وہی تمہارا مددگار (و کارساز) ہے، پس وہ کتنا اچھا کارساز (ہے) اور کتنا اچھا مددگار ہے،\qt@no{78}}%
\qt@newcmd\qurantrans@ur@mmdclxxiv{\basmalahur بیشک ایمان والے مراد پا گئے،\qt@no{1}}%
\qt@newcmd\qurantrans@ur@mmdclxxv{جو لوگ اپنی نماز میں عجز و نیاز کرتے ہیں،\qt@no{2}}%
\qt@newcmd\qurantrans@ur@mmdclxxvi{اور جو بیہودہ باتوں سے (ہر وقت) کنارہ کش رہتے ہیں،\qt@no{3}}%
\qt@newcmd\qurantrans@ur@mmdclxxvii{اور جو (ہمیشہ) زکوٰۃ ادا (کر کے اپنی جان و مال کو پاک) کرتے رہتے ہیں،\qt@no{4}}%
\qt@newcmd\qurantrans@ur@mmdclxxviii{اور جو (دائماً) اپنی شرم گاہوں کی حفاظت کرتے رہتے ہیں،\qt@no{5}}%
\qt@newcmd\qurantrans@ur@mmdclxxix{سوائے اپنی بیویوں کے یا ان باندیوں کے جو ان کے ہاتھوں کی مملوک ہیں، بیشک (احکامِ شریعت کے مطابق ان کے پاس جانے سے) ان پر کوئی ملامت نہیں،\qt@no{6}}%
\qt@newcmd\qurantrans@ur@mmdclxxx{پھر جو شخص ان (حلال عورتوں) کے سوا کسی اور کا خواہش مند ہوا تو ایسے لوگ ہی حد سے تجاوز کرنے والے (سرکش) ہیں،\qt@no{7}}%
\qt@newcmd\qurantrans@ur@mmdclxxxi{اور جو لوگ اپنی امانتوں اور اپنے وعدوں کی پاسداری کرنے والے ہیں،\qt@no{8}}%
\qt@newcmd\qurantrans@ur@mmdclxxxii{اور جو اپنی نمازوں کی (مداومت کے ساتھ) حفاظت کرنے والے ہیں،\qt@no{9}}%
\qt@newcmd\qurantrans@ur@mmdclxxxiii{یہی لوگ (جنت کے) وارث ہیں،\qt@no{10}}%
\qt@newcmd\qurantrans@ur@mmdclxxxiv{یہ لوگ جنت کے سب سے اعلیٰ باغات (جہاں تمام نعمتوں، راحتوں اور قربِ الٰہی کی لذتوں کی کثرت ہوگی ان) کی وراثت (بھی) پائیں گے، وہ ان میں ہمیشہ رہیں گے،\qt@no{11}}%
\qt@newcmd\qurantrans@ur@mmdclxxxv{اور بیشک ہم نے انسان کی تخلیق (کی ابتداء) مٹی (کے کیمیائی اجزاء) کے خلاصہ سے فرمائی،\qt@no{12}}%
\qt@newcmd\qurantrans@ur@mmdclxxxvi{پھر اسے نطفہ (تولیدی قطرہ) بنا کر ایک مضبوط جگہ (رحمِ مادر) میں رکھا،\qt@no{13}}%
\qt@newcmd\qurantrans@ur@mmdclxxxvii{پھر ہم نے اس نطفہ کو (رحمِ مادر کے اندر جونک کی صورت میں) معلّق وجود بنا دیا، پھر ہم نے اس معلّق وجود کو ایک (ایسا) لوتھڑا بنا دیا جو دانتوں سے چبایا ہوا لگتا ہے، پھر ہم نے اس لوتھڑے سے ہڈیوں کا ڈھانچہ بنایا، پھر ہم نے ان ہڈیوں پر گوشت (اور پٹھے) چڑھائے، پھر ہم نے اسے تخلیق کی دوسری صورت میں (بدل کر تدریجاً) نشو و نما دی، پھر اللہ نے (اسے) بڑھا (کر محکم وجود بنا) دیا جو سب سے بہتر پیدا فرمانے والا ہے،\qt@no{14}}%
\qt@newcmd\qurantrans@ur@mmdclxxxviii{پھر بیشک تم اس (زندگی) کے بعد ضرور مرنے والے ہو،\qt@no{15}}%
\qt@newcmd\qurantrans@ur@mmdclxxxix{پھر بیشک تم قیامت کے دن (زندہ کر کے) اٹھائے جاؤ گے،\qt@no{16}}%
\qt@newcmd\qurantrans@ur@mmdcxc{اور بیشک ہم نے تمہارے اوپر (کرّۂ اَرضی کے گرد فضائے بسیط میں نظامِ کائنات کی حفاظت کے لئے) سات راستے (یعنی سات مقناطیسی پٹیاں یا میدان) بنائے ہیں، اور ہم (کائنات کی) تخلیق (اور اس کی حفاطت کے تقاضوں) سے بے خبر نہ تھے،\qt@no{17}}%
\qt@newcmd\qurantrans@ur@mmdcxci{اور ہم ایک اندازہ کے مطابق (عرصہ دراز تک) بادلوں سے پانی برساتے رہے، پھر (جب زمین ٹھنڈی ہوگئی تو) ہم نے اس پانی کو زمین (کی نشیبی جگہوں) میں ٹھہرا دیا (جس سے ابتدائی سمندر وجود میں آئے) اور بیشک ہم اسے (بخارات بنا کر) اڑا دینے پر بھی قدرت رکھتے ہیں،\qt@no{18}}%
\qt@newcmd\qurantrans@ur@mmdcxcii{پھر ہم نے تمہارے لئے اس سے (درجہ بہ درجہ یعنی پہلے ابتدائی نباتات پھر بڑے پودے پھر درخت وجود میں لاتے ہوئے) کھجور اور انگور کے باغات بنا دیئے (مزید برآں) تمہارے لئے زمین میں (اور بھی) بہت سے پھل اور میوے (پیدا کئے) اور (اب) تم ان میں سے کھاتے ہو،\qt@no{19}}%
\qt@newcmd\qurantrans@ur@mmdcxciii{اور یہ درخت (زیتون بھی ہم نے پیدا کیا ہے) جو طورِ سینا سے نکلتا ہے (اور) تیل اور کھانے والوں کے لئے سالن لے کر اگتا ہے،\qt@no{20}}%
\qt@newcmd\qurantrans@ur@mmdcxciv{اور بیشک تمہارے لئے چوپایوں میں (بھی) غور طلب پہلو ہیں، جو کچھ ان کے شکموں میں ہوتا ہے ہم تمہیں اس میں سے (بعض اجزاء کو دودھ بنا کر) پلاتے ہیں اور تمہارے لئے ان میں (اور بھی) بہت سے فوائد ہیں اور تم ان میں سے (بعض کو) کھاتے (بھی) ہو،\qt@no{21}}%
\qt@newcmd\qurantrans@ur@mmdcxcv{اور ان پر اور کشتیوں پر تم سوار (بھی) کئے جاتے ہو،\qt@no{22}}%
\qt@newcmd\qurantrans@ur@mmdcxcvi{اور بیشک ہم نے نوح (علیہ السلام) کو ان کی قوم کی طرف بھیجا تو انہوں نے فرمایا: اے لوگو! تم اللہ کی عبادت کیا کرو اس کے سوا تمہارا کوئی معبود نہیں ہے، تو کیا تم نہیں ڈرتے،\qt@no{23}}%
\qt@newcmd\qurantrans@ur@mmdcxcvii{تو ان کی قوم کے سردار (اور وڈیرے) جو کفر کر رہے تھے کہنے لگے: یہ شخص محض تمہارے ہی جیسا ایک بشر ہے (اس کے سوا کچھ نہیں)، یہ تم پر (اپنی) فضیلت و برتری قائم کرنا چاہتا ہے، اور اگر اللہ (ہدایت کے لئے کسی پیغمبر کو بھیجنا) چاہتا تو فرشتوں کو اتار دیتا، ہم نے تو یہ بات (کہ ہمارے جیسا ہی ایک شخص ہمارا رسول بنا دیا جائے) اپنے اگلے آباء و اجداد میں (کبھی) نہیں سنی،\qt@no{24}}%
\qt@newcmd\qurantrans@ur@mmdcxcviii{یہ شخص تو سوائے اس کے اور کچھ نہیں کہ اسے دیوانگی (کا عارضہ لاحق ہو گیا) ہے سو تم ایک عرصہ تک اس کا انتظار کرو (دیکھو آگے کیا کرتا ہے)،\qt@no{25}}%
\qt@newcmd\qurantrans@ur@mmdcxcix{نوح (علیہ السلام) نے عرض کیا: اے میرے رب! میری مدد فرما کیونکہ انہوں نے مجھے جھٹلا دیا ہے،\qt@no{26}}%
\qt@newcmd\qurantrans@ur@mmdcc{پھر ہم نے ان کی طرف وحی بھیجی کہ تم ہماری نگرانی میں اور ہمارے حکم کے مطابق ایک کشتی بناؤ سو جب ہمارا حکمِ (عذاب) آجائے اور تنور (بھر کر پانی) ابلنے لگے تو تم اس میں ہر قسم کے جانوروں میں سے دو دو جوڑے (نر و مادہ) بٹھا لینا اور اپنے گھر والوں کو بھی (اس میں سوار کر لینا) سوائے ان میں سے اس شخص کے جس پر فرمانِ (عذاب) پہلے ہی صادر ہو چکا ہے، اور مجھ سے ان لوگوں کے بارے میں کچھ عرض بھی نہ کرنا جنہوں نے (تمہارے انکار و استہزاء کی صورت میں) ظلم کیا ہے، وہ (بہر طور) ڈبو دیئے جائیں گے،\qt@no{27}}%
\qt@newcmd\qurantrans@ur@mmdcci{پھر جب تم اور تمہاری سنگت والے (لوگ) کشتی میں ٹھیک طرح سے بیٹھ جائیں تو کہنا (کہ) ساری تعریفیں اللہ ہی کے لئے ہیں جس نے ہمیں ظالم قوم سے نجات بخشی،\qt@no{28}}%
\qt@newcmd\qurantrans@ur@mmdccii{اور عرض کرنا: اے میرے رب! مجھے با برکت منزل پر اتار اور تو سب سے بہتر اتارنے والا ہے،\qt@no{29}}%
\qt@newcmd\qurantrans@ur@mmdcciii{بیشک اس (واقعہ) میں (بہت سی) نشانیاں ہیں اور یقیناً ہم آزمائش کرنے والے ہیں،\qt@no{30}}%
\qt@newcmd\qurantrans@ur@mmdcciv{پھر ہم نے ان کے بعد دوسری قوم کو پیدا فرمایا،\qt@no{31}}%
\qt@newcmd\qurantrans@ur@mmdccv{سو ہم نے ان میں (بھی) انہی میں سے رسول بھیجا کہ تم اللہ کی عبادت کرو اور اس کے سوا تمہارا کوئی معبود نہیں ہے، تو کیا تم نہیں ڈرتے،\qt@no{32}}%
\qt@newcmd\qurantrans@ur@mmdccvi{اور ان کی قوم کے (بھی وہی) سردار (اور وڈیرے) بول اٹھے جو کفر کر رہے تھے اور آخرت کی ملاقات کو جھٹلاتے تھے اور ہم نے انہیں دنیوی زندگی میں (مال و دولت کی کثرت کے باعث) آسودگی (بھی) دے رکھی تھی (لوگوں سے کہنے لگے) کہ یہ شخص تو محض تمہارے ہی جیسا ایک بشر ہے، وہی چیزیں کھاتا ہے جو تم کھاتے ہو اور وہی کچھ پیتا ہے جو تم پیتے ہو،\qt@no{33}}%
\qt@newcmd\qurantrans@ur@mmdccvii{اور اگر تم نے اپنے ہی جیسے ایک بشر کی اطاعت کر لی تو پھر تم ضرور خسارہ اٹھانے والے ہو گے،\qt@no{34}}%
\qt@newcmd\qurantrans@ur@mmdccviii{کیا یہ (شخص) تم سے یہ وعدہ کر رہا ہے کہ جب تم مر جاؤ گے اور تم مٹی اور (بوسیدہ) ہڈیاں ہو جاؤ گے تو تم (دوبارہ زندہ ہو کر) نکالے جاؤ گے،\qt@no{35}}%
\qt@newcmd\qurantrans@ur@mmdccix{بعید (اَز قیاس) بعید (اَز وقوع) ہیں وہ باتیں جن کا تم سے وعدہ کیا جا رہا ہے،\qt@no{36}}%
\qt@newcmd\qurantrans@ur@mmdccx{وہ (آخرت کی زندگی کچھ) نہیں ہماری زندگانی تو یہی دنیا ہے ہم (یہیں) مرتے اور جیتے ہیں اور (بس ختم)، ہم (دوبارہ) نہیں اٹھائے جائیں گے،\qt@no{37}}%
\qt@newcmd\qurantrans@ur@mmdccxi{یہ تو محض ایسا شخص ہے جس نے اللہ پر جھوٹا بہتان لگایا ہے اور ہم بالکل اس پر ایمان لانے والے نہیں ہیں،\qt@no{38}}%
\qt@newcmd\qurantrans@ur@mmdccxii{پیغمبر نے) عرض کیا: اے میرے رب! میری مدد فرما اس صورتحال میں کہ انہوں نے مجھے جھٹلا دیا ہے،\qt@no{39}}%
\qt@newcmd\qurantrans@ur@mmdccxiii{ارشاد ہوا: تھوڑی ہی دیر میں وہ پشیماں ہو کر رہ جائیں گے،\qt@no{40}}%
\qt@newcmd\qurantrans@ur@mmdccxiv{پس سچے وعدہ کے مطابق انہیں خوفناک آواز نے آپکڑا سو ہم نے انہیں خس و خاشاک بنا دیا، پس ظالم قوم کے لئے (ہماری رحمت سے) دوری و محرومی ہے،\qt@no{41}}%
\qt@newcmd\qurantrans@ur@mmdccxv{پھر ہم نے ان کے بعد (یکے بعد دیگرے) دوسری امتوں کو پیدا فرمایا،\qt@no{42}}%
\qt@newcmd\qurantrans@ur@mmdccxvi{کوئی بھی امت اپنے وقت مقرر سے نہ آگے بڑھ سکتی ہے اور نہ وہ لوگ پیچھے ہٹ سکتے ہیں،\qt@no{43}}%
\qt@newcmd\qurantrans@ur@mmdccxvii{پھر ہم نے پے در پے اپنے رسولوں کو بھیجا۔ جب بھی کسی امت کے پاس اس کا رسول آتا وہ اسے جھٹلا دیتے تو ہم (بھی) ان میں سے بعض کو بعض کے پیچھے (ہلاک در ہلاک) کرتے چلے گئے اور ہم نے انہیں داستانیں بنا ڈالا، پس ہلاکت ہو ان لوگوں کے لئے جو ایمان نہیں لاتے،\qt@no{44}}%
\qt@newcmd\qurantrans@ur@mmdccxviii{پھر ہم نے موسٰی (علیہ السلام) اور ان کے بھائی ہارون (علیہ السلام) کو اپنی نشانیاں اور روشن دلیل دے کر بھیجا،\qt@no{45}}%
\qt@newcmd\qurantrans@ur@mmdccxix{فرعون اور اس (کی قوم) کے سرداروں کی طرف تو انہوں نے بھی تکبّر و رعونت سے کام لیا اور وہ بھی (بڑے) ظالم و سرکش لوگ تھے،\qt@no{46}}%
\qt@newcmd\qurantrans@ur@mmdccxx{سو انہوں نے (بھی یہی) کہا کہ کیا ہم اپنے جیسے دو بشروں پر ایمان لے آئیں حالانکہ ان کی قوم کے لوگ ہماری پرستش کرتے ہیں،\qt@no{47}}%
\qt@newcmd\qurantrans@ur@mmdccxxi{پس انہوں نے (بھی) ان دونوں کو جھٹلا دیا سو وہ بھی ہلاک کئے گئے لوگوں میں سے ہو گئے،\qt@no{48}}%
\qt@newcmd\qurantrans@ur@mmdccxxii{اور بیشک ہم نے موسٰی (علیہ السلام) کو کتاب عطا فرمائی تاکہ وہ لوگ ہدایت پاجائیں،\qt@no{49}}%
\qt@newcmd\qurantrans@ur@mmdccxxiii{اور ہم نے ابن مریم (عیسٰی علیہ السلام) کو اور ان کی ماں کو اپنی (زبردست) نشانی بنایا اور ہم نے ان دونوں کو ایک (ایسی) بلند زمین میں سکونت بخشی جو بآسائش و آرام رہنے کے قابل (بھی) تھی اور وہاں آنکھوں کے (نظارے کے) لئے بہتے پانی (یعنی نہریں، آبشاریں اور چشمے بھی) تھے،\qt@no{50}}%
\qt@newcmd\qurantrans@ur@mmdccxxiv{اے رُسُلِ (عظام!) تم پاکیزہ چیزوں میں سے کھایا کرو (جیسا کہ تمہارا معمول ہے) اور نیک عمل کرتے رہو، بیشک میں جو عمل بھی تم کرتے ہو اس سے خوب واقف ہوں،\qt@no{51}}%
\qt@newcmd\qurantrans@ur@mmdccxxv{اور بیشک یہ تمہاری امت ہے (جو حقیقت میں) ایک ہی امت (ہے) اور میں تمہارا رب ہوں سو مجھ سے ڈرا کرو،\qt@no{52}}%
\qt@newcmd\qurantrans@ur@mmdccxxvi{پس انہوں نے اپنے (دین کے) امر کو آپس میں اختلاف کر کے فرقہ فرقہ کر ڈالا، ہر فرقہ والے اسی قدر (دین کے حصہ) سے جو ان کے پاس ہے خوش ہیں،\qt@no{53}}%
\qt@newcmd\qurantrans@ur@mmdccxxvii{پس آپ ان کو ایک عرصہ تک ان کے نشۂ جہالت و ضلالت میں چھوڑے رکھئے،\qt@no{54}}%
\qt@newcmd\qurantrans@ur@mmdccxxviii{کیا وہ لوگ یہ گمان کرتے ہیں کہ ہم جو (دنیا میں) مال و اولاد کے ذریعہ ان کی مدد کر رہے ہیں،\qt@no{55}}%
\qt@newcmd\qurantrans@ur@mmdccxxix{تو ہم ان کے لئے بھلائیوں (کی فراہمی) میں جلدی کر رہے ہیں، (ایسا نہیں) بلکہ انہیں شعور ہی نہیں ہے،\qt@no{56}}%
\qt@newcmd\qurantrans@ur@mmdccxxx{بیشک جو لوگ اپنے رب کی خشیّت سے مضطرب اور لرزاں رہتے ہیں،\qt@no{57}}%
\qt@newcmd\qurantrans@ur@mmdccxxxi{اور جو لوگ اپنے رب کی آیتوں پر ایمان رکھتے ہیں،\qt@no{58}}%
\qt@newcmd\qurantrans@ur@mmdccxxxii{اور جو لوگ اپنے رب کے ساتھ (کسی کو) شریک نہیں ٹھہراتے،\qt@no{59}}%
\qt@newcmd\qurantrans@ur@mmdccxxxiii{اور جو لوگ (اللہ کی راہ میں اتنا کچھ) دیتے ہیں جتنا وہ دے سکتے ہیں اور (اس کے باوجود) ان کے دل خائف رہتے ہیں کہ وہ اپنے رب کی طرف پلٹ کر جانے والے ہیں (کہیں یہ نامقبول نہ ہو جائے)،\qt@no{60}}%
\qt@newcmd\qurantrans@ur@mmdccxxxiv{یہی لوگ بھلائیوں (کے سمیٹنے میں) جلدی کر رہے ہیں اور وہی اس میں آگے نکل جانے والے ہیں،\qt@no{61}}%
\qt@newcmd\qurantrans@ur@mmdccxxxv{اور ہم کسی جان کو تکلیف نہیں دیتے مگر اس کی استعداد کے مطابق اور ہمارے پاس نوشتۂ (اَعمال موجود) ہے جو سچ سچ کہہ دے گا اور ان پر ظلم نہیں کیا جائے گا،\qt@no{62}}%
\qt@newcmd\qurantrans@ur@mmdccxxxvi{بلکہ ان کے دل اس (قرآن کے پیغام) سے غفلت میں (پڑے) ہیں اور اس کے سوا (بھی) ان کے کئی اور (برے) اعمال ہیں جن پر وہ عمل پیرا ہیں،\qt@no{63}}%
\qt@newcmd\qurantrans@ur@mmdccxxxvii{یہاں تک کہ جب ہم ان کے امیر اور آسودہ حال لوگوں کو عذاب کی گرفت میں لیں گے تو اس وقت وہ چیخ اٹھیں گے،\qt@no{64}}%
\qt@newcmd\qurantrans@ur@mmdccxxxviii{ان سے کہا جائے گا:) تم آج مت چیخو، بیشک ہماری طرف سے تمہاری کوئی مدد نہیں کی جائے گے،\qt@no{65}}%
\qt@newcmd\qurantrans@ur@mmdccxxxix{بیشک میری آیتیں تم پر پڑھ پڑھ کر سنائی جاتی تھیں تو تم ایڑیوں کے بل الٹے پلٹ جایا کرتے تھے،\qt@no{66}}%
\qt@newcmd\qurantrans@ur@mmdccxl{اس سے غرور و تکبّر کرتے ہوئے رات کے اندھیرے میں بے ہودہ گوئی کرتے تھے،\qt@no{67}}%
\qt@newcmd\qurantrans@ur@mmdccxli{سو کیا انہوں نے اس فرمانِ (الٰہی) میں غور و خوض نہیں کیا یا ان کے پاس کوئی ایسی چیز آگئی ہے جو ان کے اگلے باپ دادا کے پاس نہیں آئی تھی،\qt@no{68}}%
\qt@newcmd\qurantrans@ur@mmdccxlii{یا انہوں نے اپنے رسول کو نہیں پہچانا سو (اس لئے) وہ اس کے منکر ہو گئے ہیں،\qt@no{69}}%
\qt@newcmd\qurantrans@ur@mmdccxliii{یا یہ کہتے ہیں کہ اس (رسول صلی اللہ علیہ وآلہ وسلم) کو جنون (لاحق) ہو گیا ہے، (ایسا ہر گز نہیں) بلکہ وہ ان کے پاس حق لے کر تشریف لائے ہیں اور ان میں سے اکثر لوگ حق کو پسند نہیں کرتے،\qt@no{70}}%
\qt@newcmd\qurantrans@ur@mmdccxliv{اور اگر حق (تعالیٰ) ان کی خواہشات کی پیروی کرتا تو (سارے) آسمان اور زمین اور جو (مخلوقات و موجودات) ان میں ہیں سب تباہ و برباد ہو جاتے بلکہ ہم ان کے پاس وہ (قرآن) لائے ہیں جس میں ان کی عزت و شرف (اور ناموری کا راز) ہے سو وہ اپنی عزت ہی سے منہ پھیر رہے ہیں،\qt@no{71}}%
\qt@newcmd\qurantrans@ur@mmdccxlv{کیا آپ ان سے (تبلیغِ رسالت پر) کچھ اجرت مانگتے ہیں؟ (ایسا بھی نہیں ہے) آپ کے تو رب کا اجر (ہی بہت) بہتر ہے اور وہ سب سے بہتر روزی رساں ہے،\qt@no{72}}%
\qt@newcmd\qurantrans@ur@mmdccxlvi{اور بیشک آپ تو (انہی کے بھلے کے لئے) انہیں سیدھی راہ کی طرف بلاتے ہیں،\qt@no{73}}%
\qt@newcmd\qurantrans@ur@mmdccxlvii{اور بیشک جو لوگ آخرت پر ایمان نہیں رکھتے (وہ) ضرور (سیدھی) راہ سے کترائے رہتے ہیں،\qt@no{74}}%
\qt@newcmd\qurantrans@ur@mmdccxlviii{اور اگر ہم ان پر رحم فرما دیں اور جو تکلیف انہیں (لاحق) ہے اسے دور کر دیں تو وہ بھٹکتے ہوئے اپنی سرکشی میں مزید پکے ہو جائیں گے،\qt@no{75}}%
\qt@newcmd\qurantrans@ur@mmdccxlix{اور بیشک ہم نے انہیں عذاب میں پکڑ لیا پھر (بھی) انہوں نے اپنے رب کے لئے عاجزی اختیار نہ کی اور نہ وہ (اس کے حضور) گڑگڑائے،\qt@no{76}}%
\qt@newcmd\qurantrans@ur@mmdccl{یہاں تک کہ جب ہم ان پر نہایت سخت عذاب کا دروازہ کھول دیں گے (تو) اس وقت وہ اس میں انتہائی حیرت سے ساکت و مایوس (پڑے) رہیں گے،\qt@no{77}}%
\qt@newcmd\qurantrans@ur@mmdccli{اور وہی ہے جو تمہارے لئے کان اور آنکھیں اور دل (و دماغ) رفتہ رفتہ وجود میں لایا، (مگر) تم لوگ بہت ہی کم شکر ادا کرتے ہو،\qt@no{78}}%
\qt@newcmd\qurantrans@ur@mmdcclii{اور وہی ہے جس نے تمہیں روئے زمین پر پیدا کر کے پھیلا دیا اور تم اسی کے حضور جمع کئے جاؤ گے،\qt@no{79}}%
\qt@newcmd\qurantrans@ur@mmdccliii{اور وہی ہے جو زندگی بخشتا ہے اور موت دیتا ہے اور شب و روز کا گردش کرنا (بھی) اسی کے اختیار میں ہے۔ سو کیا تم سمجھتے نہیں ہو،\qt@no{80}}%
\qt@newcmd\qurantrans@ur@mmdccliv{بلکہ یہ لوگ (بھی) اسی طرح کی باتیں کرتے ہیں جس طرح کی اگلے (کافر) کرتے رہے ہیں،\qt@no{81}}%
\qt@newcmd\qurantrans@ur@mmdcclv{یہ کہتے ہیں کہ جب ہم مر جائیں گے اور ہم خاک اور (بوسیدہ) ہڈیاں ہو جائیں گے تو کیا ہم (پھر زندہ کر کے) اٹھائے جائیں گے،\qt@no{82}}%
\qt@newcmd\qurantrans@ur@mmdcclvi{بیشک ہم سے (بھی) اور ہمارے آباء و اجداد سے (بھی) پہلے یہی وعدہ کیا جاتا رہا (ہے)، یہ (باتیں) محض پہلے لوگوں کے افسانے ہیں،\qt@no{83}}%
\qt@newcmd\qurantrans@ur@mmdcclvii{ان سے) فرمائیے کہ زمین اور جو کوئی اس میں (رہ رہا) ہے (سب) کس کی مِلک ہے، اگر تم (کچھ) جانتے ہو،\qt@no{84}}%
\qt@newcmd\qurantrans@ur@mmdcclviii{وہ فوراً بول اٹھیں گے کہ (سب کچھ) اللہ کا ہے، (تو) آپ فرمائیں: پھر تم نصیحت قبول کیوں نہیں کرتے؟،\qt@no{85}}%
\qt@newcmd\qurantrans@ur@mmdcclix{ان سے دریافت) فرمائیے کہ ساتوں آسمانوں کا اور عرشِ عظیم (یعنی ساری کائنات کے اقتدارِ اعلیٰ) کا مالک کون ہے؟،\qt@no{86}}%
\qt@newcmd\qurantrans@ur@mmdcclx{وہ فوراً کہیں گے: یہ (سب کچھ) اللہ کا ہے (تو) آپ فرمائیں: پھر تم ڈرتے کیوں نہیں ہو،\qt@no{87}}%
\qt@newcmd\qurantrans@ur@mmdcclxi{آپ (ان سے) فرمائیے کہ وہ کون ہے جس کے دستِ قدرت میں ہر چیز کی کامل ملکیت ہے اور جو پناہ دیتا ہے اور جس کے خلاف (کوئی) پناہ نہیں دی جا سکتی، اگر تم (کچھ) جانتے ہو،\qt@no{88}}%
\qt@newcmd\qurantrans@ur@mmdcclxii{وہ فوراً کہیں گے: یہ (سب شانیں) اللہ ہی کے لئے ہیں، (تو) آپ فرمائیں: پھر تمہیں کہاں سے (جادو کی طرح) فریب دیا جا رہا ہے،\qt@no{89}}%
\qt@newcmd\qurantrans@ur@mmdcclxiii{بلکہ ہم نے انہیں حق پہنچا دیا اور بیشک وہ جھوٹے ہیں،\qt@no{90}}%
\qt@newcmd\qurantrans@ur@mmdcclxiv{اللہ نے (اپنے لئے) کوئی اولاد نہیں بنائی اور نہ ہی اس کے ساتھ کوئی اور خدا ہے ورنہ ہر خدا اپنی اپنی مخلوق کو ضرور (الگ) لے جاتا اور یقیناً وہ ایک دوسرے پر غلبہ حاصل کرتے (اور پوری کائنات میں فساد بپا ہو جاتا)۔ اللہ ان باتوں سے پاک ہے جو وہ بیان کرتے ہیں،\qt@no{91}}%
\qt@newcmd\qurantrans@ur@mmdcclxv{وہ) پوشیدہ اور آشکار (سب چیزوں) کا جاننے والا ہے سو وہ ان چیزوں سے بلند و برتر ہے جنہیں یہ شریک ٹھہراتے ہیں،\qt@no{92}}%
\qt@newcmd\qurantrans@ur@mmdcclxvi{آپ (دعا) فرمائیے کہ اے میرے رب! اگر تو مجھے وہ (عذاب) دکھانے لگے جس کا ان سے وعدہ کیا جا رہا ہے،\qt@no{93}}%
\qt@newcmd\qurantrans@ur@mmdcclxvii{تو) اے میرے رب! مجھے ظالم قوم میں شامل نہ فرمانا،\qt@no{94}}%
\qt@newcmd\qurantrans@ur@mmdcclxviii{اور بیشک ہم اس بات پرضرور قادر ہیں کہ ہم آپ کو وہ (عذاب) دکھا دیں جس کا ہم ان سے وعدہ کر رہے ہیں،\qt@no{95}}%
\qt@newcmd\qurantrans@ur@mmdcclxix{آپ برائی کو ایسے طریقہ سے دفع کیا کریں جو سب سے بہتر ہو، ہم ان (باتوں) کو خوب جانتے ہیں جو یہ بیان کرتے ہیں،\qt@no{96}}%
\qt@newcmd\qurantrans@ur@mmdcclxx{اور آپ (دعا) فرمائیے: اے میرے رب! میں شیطانوں کے وسوسوں سے تیری پناہ مانگتا ہوں،\qt@no{97}}%
\qt@newcmd\qurantrans@ur@mmdcclxxi{اور اے میرے رب! میں اس بات سے (بھی) تیری پناہ مانگتا ہوں کہ وہ میرے پاس آئیں،\qt@no{98}}%
\qt@newcmd\qurantrans@ur@mmdcclxxii{یہاں تک کہ جب ان میں سے کسی کو موت آجائے گی (تو) وہ کہے گا: اے میرے رب! مجھے (دنیا میں) واپس بھیج دے،\qt@no{99}}%
\qt@newcmd\qurantrans@ur@mmdcclxxiii{تاکہ میں اس (دنیا) میں کچھ نیک عمل کر لوں جسے میں چھوڑ آیا ہوں۔ ہر گز نہیں، یہ وہ بات ہے جسے وہ (بطورِ حسرت) کہہ رہا ہوگا اور ان کے آگے اس دن تک ایک پردہ (حائل) ہے (جس دن) وہ (قبروں سے) اٹھائے جائیں گے،\qt@no{100}}%
\qt@newcmd\qurantrans@ur@mmdcclxxiv{پھر جب صور پھونکا جائے گا تو ان کے درمیان اس دن نہ رشتے (باقی) رہیں گے اور نہ وہ ایک دوسرے کا حال پوچھ سکیں گے،\qt@no{101}}%
\qt@newcmd\qurantrans@ur@mmdcclxxv{پس جن کے پلڑے (زیادہ اعمال کے باعث) بھاری ہوں گے تو وہی لوگ کامیاب و کامران ہوں گے،\qt@no{102}}%
\qt@newcmd\qurantrans@ur@mmdcclxxvi{اور جن کے پلڑے (اعمال کا وزن نہ ہونے کے باعث) ہلکے ہوں گے تو یہی لوگ ہیں جنہوں نے اپنے آپ کو نقصان پہنچایا وہ ہمیشہ دوزخ میں رہنے والے ہیں،\qt@no{103}}%
\qt@newcmd\qurantrans@ur@mmdcclxxvii{ان کے چہروں کو آگ جھلس دے گی اور وہ اس میں دانت نکلے بگڑے ہوئے منہ کے ساتھ پڑے ہوں گے،\qt@no{104}}%
\qt@newcmd\qurantrans@ur@mmdcclxxviii{ان سے کہا جائے گا:) کیا تم پر میری آیتیں پڑھ پڑھ کر نہیں سنائی جاتی تھیں پھر تم انہیں جھٹلایا کرتے تھے،\qt@no{105}}%
\qt@newcmd\qurantrans@ur@mmdcclxxix{وہ کہیں گے: اے ہمارے رب! ہم پر ہماری بدبختی غالب آگئی تھی اور ہم یقیناً گمراہ قوم تھے،\qt@no{106}}%
\qt@newcmd\qurantrans@ur@mmdcclxxx{اے ہمارے رب! تو ہمیں یہاں سے نکال دے پھر اگر ہم (اسی گمراہی کا) اعادہ کریں تو بیشک ہم ظالم ہوں گے،\qt@no{107}}%
\qt@newcmd\qurantrans@ur@mmdcclxxxi{ارشاد ہو گا: (اب) اسی میں ذلت کے ساتھ پڑے رہو اور مجھ سے بات نہ کرو،\qt@no{108}}%
\qt@newcmd\qurantrans@ur@mmdcclxxxii{بیشک میرے بندوں میں سے ایک طبقہ ایسا بھی تھا جو (میرے حضور) عرض کیا کرتے تھے: اے ہمارے رب! ہم ایمان لے آئے ہیں پس تو ہمیں بخش دے اور ہم پر رحم فرما اور تو (ہی) سب سے بہتر رحم فرمانے والا ہے،\qt@no{109}}%
\qt@newcmd\qurantrans@ur@mmdcclxxxiii{تو تم ان کا تمسخر کیا کرتے تھے یہاں تک کہ انہوں نے تمہیں میری یاد بھی بھلا دی اور تم (صرف) ان کی تضحیک ہی کرتے رہتے تھے،\qt@no{110}}%
\qt@newcmd\qurantrans@ur@mmdcclxxxiv{بیشک آج میں نے انہیں ان کے صبر کا جو وہ کرتے رہے (یہ) صلہ عطا فرمایا ہے کہ وہ کامیاب ہو گئے ہیں،\qt@no{111}}%
\qt@newcmd\qurantrans@ur@mmdcclxxxv{ارشاد ہو گا کہ تم زمین میں برسوں کے شمار سے کتنی مدت ٹھہرے رہے (ہو)،\qt@no{112}}%
\qt@newcmd\qurantrans@ur@mmdcclxxxvi{وہ کہیں گے: ہم ایک دن یا دن کا کچھ حصہ ٹھہرے (ہوں گے) آپ اعداد و شمار کرنے والوں سے پوچھ لیں،\qt@no{113}}%
\qt@newcmd\qurantrans@ur@mmdcclxxxvii{ارشاد ہوگا: تم (وہاں) نہیں ٹھہرے مگر بہت ہی تھوڑا عرصہ، کاش! تم (یہ بات وہیں) جانتے ہوتے،\qt@no{114}}%
\qt@newcmd\qurantrans@ur@mmdcclxxxviii{سو کیا تم نے یہ خیال کر لیا تھا کہ ہم نے تمہیں بے کار (و بے مقصد) پیدا کیا ہے اور یہ کہ تم ہماری طرف لوٹ کر نہیں آؤ گے؟،\qt@no{115}}%
\qt@newcmd\qurantrans@ur@mmdcclxxxix{پس اللہ جو بادشاہِ حقیقی ہے بلند و برتر ہے، اس کے سوا کوئی معبود نہیں، بزرگی اور عزت والے عرش (اقتدار) کا (وہی) مالک ہے،\qt@no{116}}%
\qt@newcmd\qurantrans@ur@mmdccxc{اور جو شخص اللہ کے ساتھ کسی اور معبود کی پرستش کرتا ہے اس کے پاس اس کی کوئی سند نہیں ہے سو اس کا حساب اس کے رب ہی کے پاس ہے۔ بیشک کافر لوگ فلاح نہیں پائیں گے،\qt@no{117}}%
\qt@newcmd\qurantrans@ur@mmdccxci{اور آپ عرض کیجئے: اے میرے رب! تو بخش دے اور رحم فرما اور تو (ہی) سب سے بہتر رحم فرمانے والا ہے،\qt@no{118}}%
\qt@newcmd\qurantrans@ur@mmdccxcii{\basmalahur (یہ) ایک (عظیم) سورت ہے جسے ہم نے اتارا ہے اور ہم نے اس (کے احکام) کو فرض کر دیا ہے اور ہم نے اس میں واضح آیتیں نازل فرمائی ہیں تاکہ تم نصیحت حاصل کرو،\qt@no{1}}%
\qt@newcmd\qurantrans@ur@mmdccxciii{بدکار عورت اور بدکار مرد (اگر غیر شادی شدہ ہوں) تو ان دونوں میں سے ہر ایک کو (شرائطِ حد کے ساتھ جرمِ زنا کے ثابت ہو جانے پر) سو (سو) کوڑے مارو (جبکہ شادی شدہ مرد و عورت کی بدکاری پر سزا رجم ہے اور یہ سزائے موت ہے) اور تمہیں ان دونوں پر اللہ کے دین (کے حکم کے اجراء) میں ذرا ترس نہیں آنا چاہئے اگر تم اللہ پر اور آخرت کے دن پر ایمان رکھتے ہو، اور چاہئے کہ ان دونوں کی سزا (کے موقع) پر مسلمانوں کی (ایک اچھی خاصی) جماعت موجود ہو،\qt@no{2}}%
\qt@newcmd\qurantrans@ur@mmdccxciv{بدکار مرد سوائے بدکار عورت یا مشرک عورت کے (کسی پاکیزہ عورت سے) نکاح (کرنا پسند) نہیں کرتا اور بدکار عورت سے (بھی) سوائے بدکار مرد یا مشرک کے کوئی (صالح شخص) نکاح (کرنا پسند) نہیں کرتا، اور یہ (فعلِ زنا) مسلمانوں پر حرام کر دیا گیا ہے،\qt@no{3}}%
\qt@newcmd\qurantrans@ur@mmdccxcv{اور جو لوگ پاک دامن عورتوں پر (بدکاری کی) تہمت لگائیں پھر چار گواہ پیش نہ کر سکیں تو تم انہیں (سزائے قذف کے طور پر) اسّی کوڑے لگاؤ اور کبھی بھی ان کی گواہی قبول نہ کرو، اور یہی لوگ بدکردار ہیں،\qt@no{4}}%
\qt@newcmd\qurantrans@ur@mmdccxcvi{سوائے ان کے جنہوں نے اس (تہمت لگنے) کے بعد توبہ کر لی اور (اپنی) اصلاح کر لی، تو بیشک اللہ بڑا بخشنے والا نہایت مہربان ہے (ان کا شمار فاسقوں میں نہیں ہوگا مگر اس سے حدِ قذف معاف نہیں ہوگی)،\qt@no{5}}%
\qt@newcmd\qurantrans@ur@mmdccxcvii{اور جو لوگ اپنی بیویوں پر (بدکاری کی) تہمت لگائیں اور ان کے پاس سوائے اپنی ذات کے کوئی گواہ نہ ہوں تو ایسے کسی بھی ایک شخص کی گواہی یہ ہے کہ (وہ خود) چار مرتبہ اللہ کی قَسم کھا کر گواہی دے کہ وہ (الزام لگانے میں) سچا ہے،\qt@no{6}}%
\qt@newcmd\qurantrans@ur@mmdccxcviii{اور پانچویں مرتبہ یہ (کہے) کہ اس پر اللہ کی لعنت ہو اگر وہ جھوٹا ہو،\qt@no{7}}%
\qt@newcmd\qurantrans@ur@mmdccxcix{اور (اسی طرح) یہ بات اس (عورت) سے (بھی) سزا کو ٹال سکتی ہے کہ وہ چار مرتبہ اللہ کی قسم کھا کر (خود) گواہی دے کہ وہ (مرد اس تہمت کے لگانے میں) جھوٹا ہے،\qt@no{8}}%
\qt@newcmd\qurantrans@ur@mmdccc{اور پانچویں مرتبہ یہ (کہے) کہ اس پر (یعنی مجھ پر) اللہ کا غضب ہو اگر یہ (مرد اس الزام لگانے میں) سچا ہو،\qt@no{9}}%
\qt@newcmd\qurantrans@ur@mmdccci{اور اگر تم پر اللہ کا فضل اور اس کی رحمت نہ ہوتی (تو تم ایسے حالات میں زیادہ پریشان ہوتے) اور بیشک اللہ بڑا ہی توبہ قبول فرمانے والا بڑی حکمت والا ہے،\qt@no{10}}%
\qt@newcmd\qurantrans@ur@mmdcccii{بیشک جن لوگوں نے (عائشہ صدیقہ طیبہ طاہرہ رضی اﷲ عنہا پر) بہتان لگایا تھا (وہ بھی) تم ہی میں سے ایک جماعت تھی، تم اس (بہتان کے واقعہ) کو اپنے حق میں برا مت سمجھو بلکہ وہ تمہارے حق میں بہتر (ہوگیا) ہے٭ ان میں سے ہر ایک کے لئے اتنا ہی گناہ ہے جتنا اس نے کمایا، اور ان میں سے جس نے اس (بہتان) میں سب سے زیادہ حصہ لیا اس کے لئے زبردست عذاب ہے، ٭ (کیونکہ تمہیں اسی حوالے سے احکامِ شریعت مل گئے اور عائشہ صدیقہ طیبہ طاہرہ رضی اﷲ عنہا کی پاک دامنی کا گواہ خود اللہ بن گیا جس سے تمہیں ان کی شان کا پتہ چل گیا۔)\qt@no{11}}%
\qt@newcmd\qurantrans@ur@mmdccciii{ایسا کیوں نہ ہوا کہ جب تم نے اس (بہتان) کو سنا تھا تو مومن مرد اور مومن عورتیں اپنوں کے بارے میں نیک گمان کر لیتے اور (یہ) کہہ دیتے کہ یہ کھلا (جھوٹ پر مبنی) بہتان ہے،\qt@no{12}}%
\qt@newcmd\qurantrans@ur@mmdccciv{یہ (افترا پرداز لوگ) اس (طوفان) پر چار گواہ کیوں نہ لائے، پھر جب وہ گواہ نہیں لا سکے تو یہی لوگ اللہ کے نزدیک جھوٹے ہیں،\qt@no{13}}%
\qt@newcmd\qurantrans@ur@mmdcccv{اور اگر تم پر دنیا و آخرت میں اللہ کا فضل اور اس کی رحمت نہ ہوتی تو جس (تہمت کے) چرچے میں تم پڑ گئے ہو اس پر تمہیں زبردست عذاب پہنچتا،\qt@no{14}}%
\qt@newcmd\qurantrans@ur@mmdcccvi{جب تم اس (بات) کو (ایک دوسرے سے سن کر) اپنی زبانوں پر لاتے رہے اور اپنے منہ سے وہ کچھ کہتے رہے جس کا (خود) تمہیں کوئی علم ہی نہ تھا اور اس (چرچے) کو معمولی بات خیال کر رہے تھے، حالانکہ وہ اللہ کے حضور بہت بڑی (جسارت ہو رہی) تھی،\qt@no{15}}%
\qt@newcmd\qurantrans@ur@mmdcccvii{اور جب تم نے یہ (بہتان) سنا تھا تو تم نے (اسی وقت) یہ کیوں نہ کہہ دیا کہ ہمارے لئے یہ (جائز ہی) نہیں کہ ہم اسے زبان پر لے آئیں (بلکہ تم یہ کہتے کہ اے اللہ!) تو پاک ہے (اس بات سے کہ ایسی عورت کو اپنے حبیب مکرم صلی اللہ علیہ وآلہ وسلم کی محبوب زوجہ بنا دے)، یہ بہت بڑا بہتان ہے،\qt@no{16}}%
\qt@newcmd\qurantrans@ur@mmdcccviii{اللہ تم کو نصیحت فرماتا ہے کہ پھر کبھی بھی ایسی بات (عمر بھر) نہ کرنا اگر تم اہلِ ایمان ہو،\qt@no{17}}%
\qt@newcmd\qurantrans@ur@mmdcccix{اور اللہ تمہارے لئے آیتوں کو واضح طور پر بیان فرماتا ہے، اور اللہ خوب جاننے والا بڑی حکمت والا ہے،\qt@no{18}}%
\qt@newcmd\qurantrans@ur@mmdcccx{بیشک جو لوگ اس بات کو پسند کرتے ہیں کہ مسلمانوں میں بے حیائی پھیلے ان کے لئے دنیا اور آخرت میں دردناک عذاب ہے، اور اللہ (ایسے لوگوں کے عزائم کو) جانتا ہے اور تم نہیں جانتے،\qt@no{19}}%
\qt@newcmd\qurantrans@ur@mmdcccxi{اور اگر تم پر (اس رسولِ مکرّم صلی اللہ علیہ وآلہ وسلم کے صدقہ میں) اللہ کا فضل اور اس کی رحمت نہ ہوتی تو (تم بھی پہلی امتوں کی طرح تباہ کر دیئے جاتے) مگر اللہ بڑا شفیق بڑا رحم فرمانے والا ہے،\qt@no{20}}%
\qt@newcmd\qurantrans@ur@mmdcccxii{اے ایمان والو! شیطان کے راستوں پر نہ چلو، اور جو شخص شیطان کے نقوشِ قدم پر چلتا ہے تو وہ یقیناً بے حیائی اور برے کاموں (کے فروغ) کا حکم دیتا ہے، اور اگر تم پر اللہ کا فضل اور اس کی رحمت نہ ہوتی تو تم میں سے کوئی شخص بھی کبھی (اس گناہِ تہمت کے داغ سے) پاک نہ ہو سکتا لیکن اللہ جسے چاہتا ہے پاک فرما دیتا ہے، اور اللہ خوب سننے والا جاننے والا ہے،\qt@no{21}}%
\qt@newcmd\qurantrans@ur@mmdcccxiii{اور تم میں سے (دینی) بزرگی والے اور (دنیوی) کشائش والے (اب) اس بات کی قَسم نہ کھائیں کہ وہ (اس بہتان کے جرم میں شریک) رشتہ داروں اور محتاجوں اور اللہ کی راہ میں ہجرت کرنے والوں کو (مالی امداد نہ) دیں گے انہیں چاہئے کہ (ان کا قصور) معاف کر دیں اور (ان کی غلطی سے) درگزر کریں، کیا تم اس بات کو پسند نہیں کرتے کہ اللہ تمہیں بخش دے، اور اللہ بڑا بخشنے والا مہربان ہے،\qt@no{22}}%
\qt@newcmd\qurantrans@ur@mmdcccxiv{بیشک جو لوگ ان پارسا مومن عورتوں پر جو (برائی کے تصور سے بھی) بے خبر اور ناآشنا ہیں (ایسی) تہمت لگاتے ہیں وہ دنیا اور آخرت (دونوں جہانوں) میں ملعون ہیں اور ان کے لئے زبردست عذاب ہے،\qt@no{23}}%
\qt@newcmd\qurantrans@ur@mmdcccxv{جس دن (خود) ان کی زبانیں اور ان کے ہاتھ اور ان کے پاؤں انہی کے خلاف گواہی دیں گے کہ جو کچھ وہ کرتے رہے تھے،\qt@no{24}}%
\qt@newcmd\qurantrans@ur@mmdcccxvi{اس دن اللہ انہیں ان (کے اعمال) کی پوری پوری جزا جس کے وہ صحیح حق دار ہیں دے دے گا اور وہ جان لیں گے کہ اللہ (خود بھی) حق ہے (اور حق کو) ظاہر فرمانے والا (بھی) ہے،\qt@no{25}}%
\qt@newcmd\qurantrans@ur@mmdcccxvii{ناپاک عورتیں ناپاک مردوں کے لئے (مخصوص) ہیں اور پلید مرد پلید عورتوں کے لئے ہیں، اور (اسی طرح) پاک و طیب عورتیں پاکیزہ مردوں کے لئے (مخصوص) ہیں اور پاک و طیب مرد پاکیزہ عورتوں کے لئے ہیں (سو تم رسول اللہ صلی اللہ علیہ وآلہ وسلم کی پاکیزگی و طہارت کو دیکھ کر خود سوچ لیتے کہ اللہ نے ان کے لئے زوجہ بھی کس قدر پاکیزہ و طیب بنائی ہوگی)، یہ (پاکیزہ لوگ) ان (تہمتوں) سے کلیتًا بری ہیں جو یہ (بدزبان) لوگ کہہ رہے ہیں، ان کے لئے (تو) بخشائش اور عزت و بزرگی والی عطا (مقدر ہو چکی) ہے (تم ان کی شان میں زبان درازی کر کے کیوں اپنا منہ کالا اور اپنی آخرت تباہ و برباد کرتے ہو)،\qt@no{26}}%
\qt@newcmd\qurantrans@ur@mmdcccxviii{اے ایمان والو! اپنے گھروں کے سوا دوسرے گھروں میں داخل نہ ہوا کرو، یہاں تک کہ تم ان سے اجازت لے لو اور ان کے رہنے والوں کو (داخل ہوتے ہی) سلام کہا کرو، یہ تمہارے لئے بہتر (نصیحت) ہے تاکہ تم (اس کی حکمتوں میں) غور و فکر کرو،\qt@no{27}}%
\qt@newcmd\qurantrans@ur@mmdcccxix{پھر اگر تم ان (گھروں) میں کسی شخص کو موجود نہ پاؤ تو تم ان کے اندر مت جایا کرو یہاں تک کہ تمہیں (اس بات کی) اجازت دی جائے اور اگر تم سے کہا جائے کہ واپس چلے جاؤ تو تم واپس پلٹ جایا کرو، یہ تمہارے حق میں بڑی پاکیزہ بات ہے، اور اللہ ان کاموں سے جو تم کرتے ہو خوب آگاہ ہے،\qt@no{28}}%
\qt@newcmd\qurantrans@ur@mmdcccxx{اس میں تم پر گناہ نہیں کہ تم ان مکانات (و عمارات) میں جو کسی کی مستقل رہائش گاہ نہیں ہیں (مثلاً ہوٹل، سرائے اور مسافر خانے وغیرہ میں بغیر اجازت کے) چلے جاؤ (کہ) ان میں تمہیں فائدہ اٹھانے کا حق (حاصل) ہے، اور اللہ ان (سب باتوں) کو جانتا ہے جو تم ظاہر کرتے ہو اور جو تم چھپاتے ہو،\qt@no{29}}%
\qt@newcmd\qurantrans@ur@mmdcccxxi{آپ مومن مَردوں سے فرما دیں کہ وہ اپنی نگاہیں نیچی رکھا کریں اور اپنی شرم گاہوں کی حفاظت کیا کریں، یہ ان کے لئے بڑی پاکیزہ بات ہے۔ بیشک اللہ ان کاموں سے خوب آگاہ ہے جو یہ انجام دے رہے ہیں،\qt@no{30}}%
\qt@newcmd\qurantrans@ur@mmdcccxxii{اور آپ مومن عورتوں سے فرما دیں کہ وہ (بھی) اپنی نگاہیں نیچی رکھا کریں اور اپنی شرم گاہوں کی حفاظت کیا کریں اور اپنی آرائش و زیبائش کو ظاہر نہ کیا کریں سوائے (اسی حصہ) کے جو اس میں سے خود ظاہر ہوتا ہے اور وہ اپنے سروں پر اوڑھے ہوئے دوپٹے (اور چادریں) اپنے گریبانوں اور سینوں پر (بھی) ڈالے رہا کریں اور وہ اپنے بناؤ سنگھار کو (کسی پر) ظاہر نہ کیا کریں سوائے اپنے شوہروں کے یا اپنے باپ دادا یا اپنے شوہروں کے باپ دادا کے یا اپنے بیٹوں یا اپنے شوہروں کے بیٹوں کے یا اپنے بھائیوں یا اپنے بھتیجوں یا اپنے بھانجوں کے یا اپنی (ہم مذہب، مسلمان) عورتوں یا اپنی مملوکہ باندیوں کے یا مردوں میں سے وہ خدمت گار جو خواہش و شہوت سے خالی ہوں یا وہ بچے جو (کم سِنی کے باعث ابھی) عورتوں کی پردہ والی چیزوں سے آگاہ نہیں ہوئے (یہ بھی مستثنٰی ہیں) اور نہ (چلتے ہوئے) اپنے پاؤں (زمین پر اس طرح) مارا کریں کہ (پیروں کی جھنکار سے) ان کا وہ سنگھار معلوم ہو جائے جسے وہ (حکمِ شریعت سے) پوشیدہ کئے ہوئے ہیں، اور تم سب کے سب اللہ کے حضور توبہ کرو اے مومنو! تاکہ تم (ان احکام پر عمل پیرا ہو کر) فلاح پا جاؤ،\qt@no{31}}%
\qt@newcmd\qurantrans@ur@mmdcccxxiii{اور تم اپنے مردوں اور عورتوں میں سے ان کا نکاح کر دیا کرو جو (عمرِ نکاح کے باوجود) بغیر ازدواجی زندگی کے (رہ رہے) ہوں اور اپنے باصلاحیت غلاموں اور باندیوں کا بھی (نکاح کر دیا کرو)، اگر وہ محتاج ہوں گے (تو) اللہ اپنے فضل سے انہیں غنی کر دے گا، اور اللہ بڑی وسعت والا بڑے علم والا ہے،\qt@no{32}}%
\qt@newcmd\qurantrans@ur@mmdcccxxiv{اور ایسے لوگوں کو پاک دامنی اختیار کرنا چاہئے جو نکاح (کی استطاعت) نہیں پاتے یہاں تک کہ اللہ انہیں اپنے فضل سے غنی فرما دے، اور تمہارے زیردست (غلاموں اور باندیوں) میں سے جو مکاتب (کچھ مال کما کر دینے کی شرط پر آزاد) ہونا چاہیں تو انہیں مکاتب (مذکورہ شرط پر آزاد) کر دو اگر تم ان میں بھلائی جانتے ہو، اور تم (خود بھی) انہیں اللہ کے مال میں سے (آزاد ہونے کے لئے) دے دو جو اس نے تمہیں عطا فرمایا ہے، اور تم اپنی باندیوں کو دنیوی زندگی کا فائدہ حاصل کرنے کے لئے بدکاری پر مجبور نہ کرو جبکہ وہ پاک دامن (یا حفاطتِ نکاح میں) رہنا چاہتی ہیں، اور جو شخص انہیں مجبور کرے گا تو اللہ ان کے مجبور ہو جانے کے بعد (بھی) بڑا بخشنے والا مہربان ہے،\qt@no{33}}%
\qt@newcmd\qurantrans@ur@mmdcccxxv{اور بیشک ہم نے تمہاری طرف واضح اور روشن آیتیں نازل فرمائی ہیں اور کچھ ان لوگوں کی مثالیں (یعنی قصۂ عائشہ کی طرح قصۂ مریم اور قصۂ یوسف) جو تم سے پہلے گزر چکے ہیں اور (یہ) پرہیزگاروں کے لئے نصیحت ہے،\qt@no{34}}%
\qt@newcmd\qurantrans@ur@mmdcccxxvi{اللہ آسمانوں اور زمین کا نور ہے، اس کے نور کی مثال (جو نورِ محمدی صلی اللہ علیہ وآلہ وسلم کی شکل میں دنیا میں روشن ہے) اس طاق (نما سینۂ اقدس) جیسی ہے جس میں چراغِ (نبوت روشن) ہے؛ (وہ) چراغ، فانوس (قلبِ محمدی صلی اللہ علیہ وآلہ وسلم) میں رکھا ہے۔ (یہ) فانوس (نورِ الٰہی کے پرتَو سے اس قدر منور ہے) گویا ایک درخشندہ ستارہ ہے (یہ چراغِ نبوت) جو زیتون کے مبارک درخت سے (یعنی عالم قدس کے بابرکت رابطہ وحی سے یا انبیاء و رسل ہی کے مبارک شجرۂ نبوت سے) روشن ہوا ہے نہ (فقط) شرقی ہے اور نہ غربی (بلکہ اپنے فیضِ نور کی وسعت میں عالم گیر ہے) ۔ ایسا معلوم ہوتا ہے کہ اس کا تیل (خود ہی) چمک رہا ہے اگرچہ ابھی اسے (وحی ربّانی اور معجزاتِ آسمانی کی) آگ نے چھوا بھی نہیں، (وہ) نور کے اوپر نور ہے (یعنی نورِ وجود پر نورِ نبوت گویا وہ ذات دوہرے نور کا پیکر ہے)، اللہ جسے چاہتا ہے اپنے نور (کی معرفت) تک پہنچا دیتا ہے، اور اللہ لوگوں (کی ہدایت) کے لئے مثالیں بیان فرماتا ہے، اور اللہ ہر چیز سے خوب آگاہ ہے،\qt@no{35}}%
\qt@newcmd\qurantrans@ur@mmdcccxxvii{اللہ کا یہ نور) ایسے گھروں (مساجد اور مراکز) میں (میسر آتا ہے) جن (کی قدر و منزلت) کے بلند کئے جانے اور جن میں اللہ کے نام کا ذکر کئے جانے کا حکم اللہ نے دیا ہے (یہ وہ گھر ہیں کہ اللہ والے) ان میں صبح و شام اس کی تسبیح کرتے ہیں،\qt@no{36}}%
\qt@newcmd\qurantrans@ur@mmdcccxxviii{اللہ کے اس نور کے حامل) وہی مردانِ (خدا) ہیں جنہیں تجارت اور خرید و فروخت نہ اللہ کی یاد سے غافل کرتی ہے اور نہ نماز قائم کرنے سے اور نہ زکوٰۃ ادا کرنے سے (بلکہ دنیوی فرائض کی ادائیگی کے دوران بھی) وہ (ہمہ وقت) اس دن سے ڈرتے رہتے ہیں جس میں (خوف کے باعث) دل اور آنکھیں (سب) الٹ پلٹ ہو جائیں گی،\qt@no{37}}%
\qt@newcmd\qurantrans@ur@mmdcccxxix{تاکہ اللہ انہیں ان (نیک) اعمال کا بہتر بدلہ دے جو انہوں نے کئے ہیں اور اپنے فضل سے انہیں اور (بھی) زیادہ (عطا) فرما دے، اور اللہ جسے چاہتا ہے بغیر حساب کے رزق (و عطا) سے نوازتا ہے،\qt@no{38}}%
\qt@newcmd\qurantrans@ur@mmdcccxxx{اور کافروں کے اعمال چٹیل میدان میں سراب کی مانند ہیں جس کو پیاسا پانی سمجھتا ہے۔ یہاں تک کہ جب اس کے پاس آتا ہے تو اسے کچھ (بھی) نہیں پاتا (اسی طرح اس نے آخرت میں) اللہ کو اپنے پاس پایا مگر اللہ نے اس کا پورا حساب (دنیا میں ہی) چکا دیا تھا، اور اللہ جلد حساب کرنے والا ہے،\qt@no{39}}%
\qt@newcmd\qurantrans@ur@mmdcccxxxi{یا (کافروں کے اعمال) اس گہرے سمندر کی تاریکیوں کی مانند ہیں جسے موج نے ڈھانپا ہوا ہو (پھر) اس کے اوپر ایک اور موج ہو (اور) اس کے اوپر بادل ہوں (یہ تہ در تہ) تاریکیاں ایک دوسرے کے اوپر ہیں، جب (ایسے سمندر میں ڈوبنے والا کوئی شخص) اپنا ہاتھ باہر نکالے تو اسے (کوئی بھی) دیکھ نہ سکے، اور جس کے لئے اللہ ہی نے نورِ (ہدایت) نہیں بنایا تو اس کے لئے (کہیں بھی) نور نہیں ہوتا،\qt@no{40}}%
\qt@newcmd\qurantrans@ur@mmdcccxxxii{کیا تم نے نہیں دیکھا کہ جو کوئی بھی آسمانوں اور زمین میں ہے وہ (سب) اللہ ہی کی تسبیح کرتے ہیں اور پرندے (بھی فضاؤں میں) پر پھیلائے ہوئے (اسی کی تسبیح کرتے ہیں)، ہر ایک (اللہ کے حضور) اپنی نماز اور اپنی تسبیح کو جانتا ہے، اور اللہ ان کاموں سے خوب آگاہ ہے جو وہ انجام دیتے ہیں،\qt@no{41}}%
\qt@newcmd\qurantrans@ur@mmdcccxxxiii{اور سارے آسمانوں اور زمین کی حکمرانی اللہ ہی کی ہے، اور سب کو اسی کی طرف لوٹ کر جانا ہے،\qt@no{42}}%
\qt@newcmd\qurantrans@ur@mmdcccxxxiv{کیا تم نے نہیں دیکھا کہ اللہ ہی بادل کو (پہلے) آہستہ آہستہ چلاتا ہے پھر اس (کے مختلف ٹکڑوں) کو آپس میں ملا دیتا ہے پھر اسے تہ بہ تہ بنا دیتا ہے پھر تم دیکھتے ہو کہ اس کے درمیان خالی جگہوں سے بارش نکل کر برستی ہے، اور وہ اسی آسمان (یعنی فضا) میں برفانی پہاڑوں کی طرح (دکھائی دینے والے) بادلوں میں سے اولے برساتا ہے، پھر جس پر چاہتا ہے ان اولوں کو گراتا ہے اور جس سے چاہتا ہے ان کو پھیر دیتا ہے (مزید یہ کہ انہی بادلوں سے بجلی بھی پیدا کرتا ہے)، یوں لگتا ہے کہ اس (بادل) کی بجلی کی چمک آنکھوں (کو خیرہ کر کے ان) کی بینائی اچک لے جائے گی،\qt@no{43}}%
\qt@newcmd\qurantrans@ur@mmdcccxxxv{اور اللہ رات اور دن کو (ایک دوسرے کے اوپر) پلٹتا رہتا ہے، اور بیشک اس میں عقل و بصیرت والوں کے لئے (بڑی) رہنمائی ہے،\qt@no{44}}%
\qt@newcmd\qurantrans@ur@mmdcccxxxvi{اور اللہ نے ہر چلنے پھرنے والے (جاندار) کی پیدائش (کی کیمیائی ابتداء) پانی سے فرمائی، پھر ان میں سے بعض وہ ہوئے جو اپنے پیٹ کے بل چلتے ہیں اور ان میں سے بعض وہ ہوئے جو دو پاؤں پر چلتے ہیں، اور ان میں سے بعض وہ ہوئے جو چار (پیروں) پر چلتے ہیں، اللہ جو چاہتا ہے پیدا فرماتا رہتا ہے، بیشک اللہ ہر چیز پر بڑا قادر ہے،\qt@no{45}}%
\qt@newcmd\qurantrans@ur@mmdcccxxxvii{یقیناً ہم نے واضح اور روشن بیان والی آیتیں نازل فرمائی ہیں، اور اللہ (ان کے ذریعے) جسے چاہتا ہے سیدھی راہ کی طرف ہدایت فرما دیتا ہے،\qt@no{46}}%
\qt@newcmd\qurantrans@ur@mmdcccxxxviii{اور وہ (لوگ) کہتے ہیں کہ ہم اللہ پر اور رسول (صلی اللہ علیہ وآلہ وسلم) پر ایمان لے آئے ہیں اور اطاعت کرتے ہیں پھر اس (قول) کے بعد ان میں سے ایک گروہ (اپنے اقرار سے) رُوگردانی کرتا ہے، اور یہ لوگ (حقیقت میں) مومن (ہی) نہیں ہیں،\qt@no{47}}%
\qt@newcmd\qurantrans@ur@mmdcccxxxix{اور جب ان لوگوں کو اللہ اور اس کے رسول (صلی اللہ علیہ وآلہ وسلم) کی طرف بلایا جاتا ہے کہ وہ ان کے درمیان فیصلہ فرما دے تو اس وقت ان میں سے ایک گروہ (دربارِ رسالت صلی اللہ علیہ وآلہ وسلم میں آنے سے) گریزاں ہوتا ہے،\qt@no{48}}%
\qt@newcmd\qurantrans@ur@mmdcccxl{اور اگر وہ حق والے ہوتے تو وہ اس (رسول صلی اللہ علیہ وآلہ وسلم) کی طرف مطیع ہو کر تیزی سے چلے آتے،\qt@no{49}}%
\qt@newcmd\qurantrans@ur@mmdcccxli{کیا ان کے دلوں میں (منافقت کی) بیماری ہے یا وہ (شانِ رسالت صلی اللہ علیہ وآلہ وسلم میں) شک کرتے ہیں یا وہ اس بات کا اندیشہ رکھتے ہیں کہ اللہ اور اس کا رسول (صلی اللہ علیہ وآلہ وسلم) ان پر ظلم کریں گے، (نہیں) بلکہ وہی لوگ خود ظالم ہیں،\qt@no{50}}%
\qt@newcmd\qurantrans@ur@mmdcccxlii{ایمان والوں کی بات تو فقط یہ ہوتی ہے کہ جب انہیں اللہ اور اس کے رسول (صلی اللہ علیہ وآلہ وسلم) کی طرف بلایا جاتا ہے تاکہ وہ ان کے درمیان فیصلہ فرمائے تو وہ یہی کچھ کہیں کہ ہم نے سن لیا، اور ہم (سراپا) اطاعت پیرا ہو گئے، اور ایسے ہی لوگ فلاح پانے والے ہیں،\qt@no{51}}%
\qt@newcmd\qurantrans@ur@mmdcccxliii{اور جو شخص اللہ اور اس کے رسول (صلی اللہ علیہ وآلہ وسلم) کی اطاعت کرتا ہے اور اللہ سے ڈرتا اور اس کا تقوٰی اختیار کرتا ہے پس ایسے ہی لوگ مراد پانے والے ہیں،\qt@no{52}}%
\qt@newcmd\qurantrans@ur@mmdcccxliv{اور وہ لوگ اللہ کی بڑی بھاری (تاکیدی) قَسمیں کھاتے ہیں کہ اگر آپ انہیں حکم دیں تو وہ (جہاد کے لئے) ضرور نکلیں گے، آپ فرما دیں کہ تم قَسمیں مت کھاؤ (بلکہ) معروف طریقہ سے فرمانبرداری (درکار) ہے، بیشک اللہ ان کاموں سے خوب آگاہ ہے جو تم کرتے ہو،\qt@no{53}}%
\qt@newcmd\qurantrans@ur@mmdcccxlv{فرما دیجئے: تم اللہ کی اطاعت کرو اور رسول (صلی اللہ علیہ وآلہ وسلم) کی اطاعت کرو، پھر اگر تم نے (اطاعت) سے رُوگردانی کی تو (جان لو) رسول (صلی اللہ علیہ وآلہ وسلم) کے ذمہ وہی کچھ ہے جو ان پر لازم کیا گیا اور تمہارے ذمہ وہ ہے جو تم پر لازم کیا گیا ہے، اور اگر تم ان کی اطاعت کرو گے تو ہدایت پا جاؤ گے، اور رسول (صلی اللہ علیہ وآلہ وسلم) پر (احکام کو) صریحاً پہنچا دینے کے سوا (کچھ لازم) نہیں ہے،\qt@no{54}}%
\qt@newcmd\qurantrans@ur@mmdcccxlvi{اللہ نے ایسے لوگوں سے وعدہ فرمایا ہے (جس کا ایفا اور تعمیل امت پر لازم ہے) جو تم میں سے ایمان لائے اور نیک عمل کرتے رہے وہ ضرور انہی کو زمین میں خلافت (یعنی امانتِ اقتدار کا حق) عطا فرمائے گا جیسا کہ اس نے ان لوگوں کو (حقِ) حکومت بخشا تھا جو ان سے پہلے تھے اور ان کے لئے ان کے دین کو جسے اس نے ان کے لئے پسند فرمایا ہے (غلبہ و اقتدار کے ذریعہ) مضبوط و مستحکم فرما دے گا اور وہ ضرور (اس تمکّن کے باعث) ان کے پچھلے خوف کو (جو ان کی سیاسی، معاشی اور سماجی کمزوری کی وجہ سے تھا) ان کے لئے امن و حفاظت کی حالت سے بدل دے گا، وہ (بے خوف ہو کر) میری عبادت کریں گے میرے ساتھ کسی کو شریک نہیں ٹھہرائیں گے (یعنی صرف میرے حکم اور نظام کے تابع رہیں گے)، اور جس نے اس کے بعد ناشکری (یعنی میرے احکام سے انحراف و انکار) کو اختیار کیا تو وہی لوگ فاسق (و نافرمان) ہوں گے،\qt@no{55}}%
\qt@newcmd\qurantrans@ur@mmdcccxlvii{اور تم نماز (کے نظام) کو قائم رکھو اور زکوٰۃ کی ادائیگی (کا انتظام) کرتے رہو اور رسول (صلی اللہ علیہ وآلہ وسلم) کی (مکمل) اطاعت بجا لاؤ تاکہ تم پر رحم فرمایا جائے (یعنی غلبہ و اقتدار، استحکام اور امن و حفاظت کی نعمتوں کو برقرار رکھا جائے)،\qt@no{56}}%
\qt@newcmd\qurantrans@ur@mmdcccxlviii{اور یہ خیال ہر گز نہ کرنا کہ انکار و ناشکری کرنے والے لوگ زمین میں (اپنے ہلاک کئے جانے سے اللہ کو) عاجز کر دیں گے، اور ان کا ٹھکانا دوزخ ہے، اور وہ بہت ہی برا ٹھکانا ہے،\qt@no{57}}%
\qt@newcmd\qurantrans@ur@mmdcccxlix{اے ایمان والو! چاہئے کہ تمہارے زیردست (غلام اور باندیاں) اور تمہارے ہی وہ بچے جو (ابھی) جوان نہیں ہوئے (تمہارے پاس آنے کے لئے) تین مواقع پر تم سے اجازت لیا کریں: (ایک) نمازِ فجر سے پہلے اور (دوسرے) دوپہر کے وقت جب تم (آرام کے لئے) کپڑے اتارتے ہو اور (تیسرے) نمازِ عشاء کے بعد (جب تم خواب گاہوں میں چلے جاتے ہو)، (یہ) تین (وقت) تمہارے پردے کے ہیں، ان (اوقات) کے علاوہ نہ تم پر کوئی گناہ ہے اور نہ ان پر، (کیونکہ بقیہ اوقات میں وہ) تمہارے ہاں کثرت کے ساتھ ایک دوسرے کے پاس آتے جاتے رہتے ہیں، اسی طرح اللہ تمہارے لئے آیتیں واضح فرماتا ہے، اور اللہ خوب جاننے والا حکمت والا ہے،\qt@no{58}}%
\qt@newcmd\qurantrans@ur@mmdcccl{اور جب تم میں سے بچے حدِ بلوغ کو پہنچ جائیں تو وہ (تمہارے پاس آنے کے لئے) اجازت لیا کریں جیسا کہ ان سے پہلے (دیگر بالغ افراد) اجازت لیتے رہتے ہیں، اس طرح اللہ تمہارے لئے اپنے احکام خُوب واضح فرماتا ہے، اور اللہ خوب علم والا اور حکمت والا ہے،\qt@no{59}}%
\qt@newcmd\qurantrans@ur@mmdcccli{اور وہ بوڑھی خانہ نشین عورتیں جنہیں (اب) نکاح کی خواہش نہیں رہی ان پر اس بات میں کوئی گناہ نہیں کہ وہ اپنے (اوپر سے ڈھانپنے والے اضافی) کپڑے اتار لیں بشرطیکہ وہ (بھی) اپنی آرائش کو ظاہر کرنے والی نہ بنیں، اور اگر وہ (مزید) پرہیزگاری اختیار کریں (یعنی زائد اوڑھنے والے کپڑے بھی نہ اتاریں) تو ان کے لئے بہتر ہے، اور اللہ خوب سننے والا جاننے والا ہے،\qt@no{60}}%
\qt@newcmd\qurantrans@ur@mmdccclii{اندھے پر کوئی رکاوٹ نہیں اور نہ لنگڑے پر کوئی حرج ہے اور نہ بیمار پر کوئی گناہ ہے اور نہ خود تمہارے لئے (کوئی مضائقہ ہے) کہ تم اپنے گھروں سے (کھانا) کھا لو یا اپنے باپ دادا کے گھروں سے یا اپنی ماؤں کے گھروں سے یا اپنے بھائیوں کے گھروں سے یا اپنی بہنوں کے گھروں سے یا اپنے چچاؤں کے گھروں سے یا اپنی پھوپھیوں کے گھروں سے یا اپنے ماموؤں کے گھروں سے یا اپنی خالاؤں کے گھروں سے یا جن گھروں کی کنجیاں تمہارے اختیار میں ہیں (یعنی جن میں ان کے مالکوں کی طرف سے تمہیں ہر قسم کے تصرّف کی اجازت ہے) یا اپنے دوستوں کے گھروں سے (کھانا کھا لینے میں مضائقہ نہیں)، تم پر اس بات میں کوئی گناہ نہیں کہ تم سب کے سب مل کر کھاؤ یا الگ الگ، پھر جب تم گھروں میں داخل ہوا کرو تو اپنے (گھر والوں) پر سلام کہا کرو (یہ) اللہ کی طرف سے بابرکت پاکیزہ دعا ہے، اس طرح اللہ اپنی آیتوں کو تمہارے لئے واضح فرماتا ہے تاکہ تم (احکامِ شریعت اور آدابِ زندگی کو) سمجھ سکو،\qt@no{61}}%
\qt@newcmd\qurantrans@ur@mmdcccliii{ایمان والے تو وہی لوگ ہیں جو اللہ پر اور اس کے رسول (صلی اللہ علیہ وآلہ وسلم) پر ایمان لے آئے ہیں اور جب وہ آپ کے ساتھ کسی ایسے (اجتماعی) کام پر حاضر ہوں جو (لوگوں کو) یکجا کرنے والا ہو تو وہاں سے چلے نہ جا ئیں (یعنی امت میں اجتماعیت اور وحدت پیدا کرنے کے عمل میں دل جمعی سے شریک ہوں) جب تک کہ وہ (کسی خاص عذر کے باعث) آپ سے اجازت نہ لے لیں، (اے رسولِ معظّم!) بیشک جو لوگ (آپ ہی کو حاکم اور مَرجَع سمجھ کر) آپ سے اجازت طلب کرتے ہیں وہی لوگ اللہ اور اس کے رسول (صلی اللہ علیہ وآلہ وسلم) پر ایمان رکھنے والے ہیں، پھر جب وہ آپ سے اپنے کسی کام کے لئے (جانے کی) اجازت چاہیں تو آپ (حاکم و مختار ہیں) ان میں سے جسے چاہیں اجازت مرحمت فرما دیں اور ان کے لئے (اپنی مجلس سے اجازت لے کر جانے پر بھی) اللہ سے بخشش مانگیں (کہ کہیں اتنی بات پر بھی گرفت نہ ہو جائے)، بیشک اللہ بڑا بخشنے والا نہایت مہربان ہے،\qt@no{62}}%
\qt@newcmd\qurantrans@ur@mmdcccliv{اے مسلمانو!) تم رسول کے بلانے کو آپس میں ایک دوسرے کو بلانے کی مثل قرار نہ دو (جب رسولِ اکرم صلی اللہ علیہ وآلہ وسلم کو بلانا تمہارے باہمی بلاوے کی مثل نہیں تو خود رسول صلی اللہ علیہ وآلہ وسلم کی ذاتِ گرامی تمہاری مثل کیسے ہو سکتی ہے)، بیشک اللہ ایسے لوگوں کو (خوب) جانتا ہے جو تم میں سے ایک دوسرے کی آڑ میں (دربارِ رسالت صلی اللہ علیہ وآلہ وسلم سے) چپکے سے کھسک جاتے ہیں، پس وہ لوگ ڈریں جو رسول (صلی اللہ علیہ وآلہ وسلم) کے امرِ (ادب) کی خلاف ورزی کر رہے ہیں کہ (دنیا میں ہی) انہیں کوئی آفت آپہنچے گی یا (آخرت میں) ان پر دردناک عذاب آن پڑے گا،\qt@no{63}}%
\qt@newcmd\qurantrans@ur@mmdccclv{خبردار! جو کچھ آسمانوں اور زمین میں ہے (سب) اللہ ہی کا ہے، وہ یقیناً جانتا ہے جس حال پر تم ہو (ایمان پر ہو یا منافقت پر)، اور جس دن لوگ اس کی طرف لوٹائے جائیں گے تو وہ انہیں بتا دے گا جو کچھ وہ کیا کرتے تھے اور اللہ ہر چیز کو خوب جاننے والا ہے،\qt@no{64}}%
\qt@newcmd\qurantrans@ur@mmdccclvi{\basmalahur (وہ اللہ) بڑی برکت والا ہے جس نے (حق و باطل میں فرق اور) فیصلہ کرنے والا (قرآن) اپنے (محبوب و مقرّب) بندہ پر نازل فرمایا تاکہ وہ تمام جہانوں کے لئے ڈر سنانے والا ہو جائے،\qt@no{1}}%
\qt@newcmd\qurantrans@ur@mmdccclvii{وہ (اللہ) کہ آسمانوں اور زمین کی بادشاہت اسی کے لئے ہے اور جس نے نہ (اپنے لئے) کوئی اولاد بنائی ہے اور نہ بادشاہی میں اس کا کوئی شریک ہے اور اسی نے ہر چیز کو پیدا فرمایا ہے پھر اس (کی بقا و ارتقاء کے ہر مرحلہ پر اس کے خواص، افعال اور مدت، الغرض ہر چیز) کو ایک مقررہ اندازے پر ٹھہرایا ہے،\qt@no{2}}%
\qt@newcmd\qurantrans@ur@mmdccclviii{اور ان (مشرکین) نے اللہ کو چھوڑ کر اور معبود بنا لئے ہیں جو کوئی چیز بھی پیدا نہیں کر سکتے بلکہ وہ خود پیدا کئے گئے ہیں اور نہ ہی وہ اپنے لئے کسی نقصان کے مالک ہیں اور نہ نفع کے اور نہ وہ موت کے مالک ہیں اور نہ حیات کے اور نہ (ہی مرنے کے بعد) اٹھا کر جمع کرنے کا (اختیار رکھتے ہیں)،\qt@no{3}}%
\qt@newcmd\qurantrans@ur@mmdccclix{اور کافر لوگ کہتے ہیں کہ یہ (قرآن) محض افتراء ہے جسے اس (مدعئ رسالت) نے گھڑ لیا ہے اور اس (کے گھڑنے) پر دوسرے لوگوں نے اس کی مدد کی ہے، بیشک کافر ظلم اور جھوٹ پر (اتر) آئے ہیں،\qt@no{4}}%
\qt@newcmd\qurantrans@ur@mmdccclx{اور کہتے ہیں: (یہ قرآن) اگلوں کے افسانے ہیں جن کو اس شخص نے لکھوا رکھا ہے پھر وہ (افسانے) اسے صبح و شام پڑھ کر سنائے جاتے ہیں (تاکہ انہیں یاد کر کے آگے سنا سکے)،\qt@no{5}}%
\qt@newcmd\qurantrans@ur@mmdccclxi{فرما دیجئے: اِس (قرآن) کو اُس (اللہ) نے نازل فرمایا ہے جو آسمانوں اور زمین میں (موجود) تمام رازوں کو جانتا ہے، بیشک وہ بڑا بخشنے والا مہربان ہے،\qt@no{6}}%
\qt@newcmd\qurantrans@ur@mmdccclxii{اور وہ کہتے ہیں کہ اس رسول کو کیا ہوا ہے، یہ کھانا کھاتا ہے اور بازاروں میں چلتا پھرتا ہے۔ اس کی طرف کوئی فرشتہ کیوں نہیں اتارا گیا کہ وہ اس کے ساتھ (مل کر) ڈر سنانے والا ہوتا،\qt@no{7}}%
\qt@newcmd\qurantrans@ur@mmdccclxiii{یا اس کی طرف کوئی خزانہ اتار دیا جاتا یا (کم از کم) اس کا کوئی باغ ہوتا جس (کی آمدنی) سے وہ کھایا کرتا اور ظالم لوگ (مسلمانوں) سے کہتے ہیں کہ تم تو محض ایک سحر زدہ شخص کی پیروی کر رہے ہو،\qt@no{8}}%
\qt@newcmd\qurantrans@ur@mmdccclxiv{اے حبیبِ مکرّم!) ملاحظہ فرمائیے یہ لوگ آپ کے لئے کیسی (کیسی) مثالیں بیان کرتے ہیں پس یہ گمراہ ہو چکے ہیں سو یہ (ہدایت کا) کوئی راستہ نہیں پا سکتے،\qt@no{9}}%
\qt@newcmd\qurantrans@ur@mmdccclxv{وہ بڑی برکت والا ہے اگر چاہے تو آپ کے لئے (دنیا ہی میں) اس سے (کہیں) بہتر باغات بنا دے جن کے نیچے سے نہریں رواں ہوں اور آپ کے لئے عالی شان محلات بنا دے (مگر نبوت و رسالت کے لئے یہ شرائط نہیں ہیں)،\qt@no{10}}%
\qt@newcmd\qurantrans@ur@mmdccclxvi{بلکہ انہوں نے قیامت کو (بھی) جھٹلا دیا ہے، اور ہم نے (ہر) اس شخص کے لئے جو قیامت کو جھٹلاتا ہے (دوزخ کی) بھڑکتی ہوئی آگ تیار کر رکھی ہے،\qt@no{11}}%
\qt@newcmd\qurantrans@ur@mmdccclxvii{جب وہ (آتشِ دوزخ) دور کی جگہ سے (ہی) ان کے سامنے ہوگی یہ اس کے جوش مارنے اور چنگھاڑنے کی آواز کو سنیں گے،\qt@no{12}}%
\qt@newcmd\qurantrans@ur@mmdccclxviii{اور جب وہ اس میں کسی تنگ جگہ سے زنجیروں کے ساتھ جکڑے ہوئے (یا اپنے شیطانوں کے ساتھ بندھے ہوئے) ڈالے جائیں گے اس وقت وہ (اپنی) ہلاکت کو پکاریں گے،\qt@no{13}}%
\qt@newcmd\qurantrans@ur@mmdccclxix{ان سے کہا جائے گا:) آج (صرف) ایک ہی ہلاکت کو نہ پکارو بلکہ بہت سی ہلاکتوں کو پکارو،\qt@no{14}}%
\qt@newcmd\qurantrans@ur@mmdccclxx{فرما دیجئے: کیا یہ (حالت) بہتر ہے یا دائمی جنت (کی زندگی) جس کا پرہیزگاروں سے وعدہ کیا گیا ہے، یہ ان (کے اعمال) کی جزا اور ٹھکانا ہے،\qt@no{15}}%
\qt@newcmd\qurantrans@ur@mmdccclxxi{ان کے لئے ان (جنتوں) میں وہ (سب کچھ میسّر) ہوگا جو وہ چاہیں گے (اس میں) ہمیشہ رہیں گے، یہ آپ کے رب کے ذمۂ (کرم) پر مطلوبہ وعدہ ہے (جو پورا ہو کر رہے گا)،\qt@no{16}}%
\qt@newcmd\qurantrans@ur@mmdccclxxii{اور اس دن اللہ انہیں اور ان کو، جن کی وہ اللہ کے سوا پرستش کرتے تھے، جمع کرے گا، پھر فرمائے گا: کیا تم نے ہی میرے ان بندوں کو گمراہ کر دیا تھا یا وہ (خود) ہی راہ سے بھٹک گئے تھے،\qt@no{17}}%
\qt@newcmd\qurantrans@ur@mmdccclxxiii{وہ کہیں گے: تیری ذات پاک ہے ہمیں (تو) یہ بات (بھی) زیبا نہ تھی کہ ہم تیرے سوا اوروں کو دوست (ہی) بنائیں (چہ جائے کہ ہم انہیں تیرے غیر کی عبادت کا کہتے) لیکن (اے مولا!) تو نے انہیں اور ان کے باپ دادا کو (دنیوی مال و اسباب سے) اتنا بہرہ مند فرمایا، یہاں تک کہ وہ تیری یاد (بھی) بھول گئے، اور یہ (بدبخت) ہلاک ہونے والے لوگ (ہی) تھے،\qt@no{18}}%
\qt@newcmd\qurantrans@ur@mmdccclxxiv{سو (اے کافرو!) انہوں نے (تو) ان باتوں میں تمہیں جھٹلا دیا ہے جو تم کہتے تھے پس (اب) تم نہ تو عذاب پھیرنے کی طاقت رکھتے ہو اور نہ (اپنی) مدد کی، اور (سن لو!) تم میں سے جو شخص (بھی) ظلم کرتا ہے ہم اسے بڑے عذاب کا مزہ چکھائیں گے،\qt@no{19}}%
\qt@newcmd\qurantrans@ur@mmdccclxxv{اور ہم نے آپ سے پہلے رسول نہیں بھیجے مگر (یہ کہ) وہ کھانا (بھی) یقیناً کھاتے تھے اور بازاروں میں بھی (حسبِ ضرورت) چلتے پھرتے تھے اور ہم نے تم کو ایک دوسرے کے لئے آزمائش بنایا ہے، کیا تم (آزمائش پر) صبر کرو گے؟ اور آپ کا رب خوب دیکھنے والا ہے،\qt@no{20}}%
\qt@newcmd\qurantrans@ur@mmdccclxxvi{اور جو لوگ ہماری ملاقات کی امید نہیں رکھتے کہتے ہیں کہ ہمارے اوپر فرشتے کیوں نہیں اتارے گئے یا ہم اپنے رب کو (اپنی آنکھوں سے) دیکھ لیتے (تو پھر ضرور ایمان لے آتے)، حقیقت میں یہ لوگ اپنے دِلوں میں (اپنے آپ کو) بہت بڑا سمجھنے لگے ہیں اور حد سے بڑھ کر سرکشی کر رہے ہیں،\qt@no{21}}%
\qt@newcmd\qurantrans@ur@mmdccclxxvii{جس دن وہ فرشتوں کو دیکھیں گے (تو) اس دن مجرموں کے لئے چنداں خوشی کی بات نہ ہوگی بلکہ وہ (انہیں دیکھ کر ڈرتے ہوئے) کہیں گے: کوئی روک والی آڑ ہوتی (جو ہمیں ان سے بچا لیتی یا فرشتے انہیں دیکھ کر کہیں گے کہ تم پر داخلۂ جنت قطعاً ممنوع ہے)،\qt@no{22}}%
\qt@newcmd\qurantrans@ur@mmdccclxxviii{اور (پھر) ہم ان اعمال کی طرف متوجہ ہوں گے جو (بزعمِ خویش) انہوں نے (زندگی میں) کئے تھے تو ہم انہیں بکھرا ہوا غبار بنا دیں گے،\qt@no{23}}%
\qt@newcmd\qurantrans@ur@mmdccclxxix{اس دن اہلِ جنت کی قیام گاہ (بھی) بہتر ہوگی اور آرام گاہ بھی خوب تر (جہاں وہ حساب و کتاب کی دوپہر کے بعد جا کر قیلولہ کریں گے)،\qt@no{24}}%
\qt@newcmd\qurantrans@ur@mmdccclxxx{اور اس دن آسمان پھٹ کر بادل (کی طرح دھوئیں) میں بدل جائے گا اور فرشتے گروہ در گروہ اتارے جائیں گے،\qt@no{25}}%
\qt@newcmd\qurantrans@ur@mmdccclxxxi{اس دن سچی حکمرانی صرف (خدائے) رحمان کی ہوگی اور وہ دن کافروں پر سخت (مشکل) ہوگا،\qt@no{26}}%
\qt@newcmd\qurantrans@ur@mmdccclxxxii{اور اس دن ہر ظالم (غصہ اور حسرت سے) اپنے ہاتھوں کو کاٹ کاٹ کھائے گا (اور) کہے گا: کاش! میں نے رسولِ (اکرم صلی اللہ علیہ وآلہ وسلم) کی معیّت میں (آکر ہدایت کا) راستہ اختیار کر لیا ہوتا،\qt@no{27}}%
\qt@newcmd\qurantrans@ur@mmdccclxxxiii{ہائے افسوس! کاش میں نے فلاں شخص کو دوست نہ بنایا ہوتا،\qt@no{28}}%
\qt@newcmd\qurantrans@ur@mmdccclxxxiv{بیشک اس نے میرے پاس نصیحت آجانے کے بعد مجھے اس سے بہکا دیا، اور شیطان انسان کو (مصیبت کے وقت) بے یار و مددگار چھوڑ دینے والا ہے،\qt@no{29}}%
\qt@newcmd\qurantrans@ur@mmdccclxxxv{اور رسولِ (اکرم صلی اللہ علیہ وآلہ وسلم) عرض کریں گے: اے رب! بیشک میری قوم نے اس قرآن کو بالکل ہی چھوڑ رکھا تھا،\qt@no{30}}%
\qt@newcmd\qurantrans@ur@mmdccclxxxvi{اور اسی طرح ہم نے ہر نبی کے لئے جرائم شعار لوگوں میں سے (ان کے) دشمن بنائے تھے (جو ان کے پیغمبرانہ مشن کی مخالفت کرتے اور اس طرح حق اور باطل قوتوں کے درمیان تضاد پیدا ہوتا جس سے انقلاب کے لئے سازگار فضا تیار ہو جاتی تھی)، اور آپ کا رب ہدایت کرنے اور مدد فرمانے کے لئے کافی ہے،\qt@no{31}}%
\qt@newcmd\qurantrans@ur@mmdccclxxxvii{اور کافر کہتے ہیں کہ اس (رسول) پر قرآن ایک ہی بار (یک جا کرکے) کیوں نہیں اتارا گیا؟ یوں (تھوڑا تھوڑا کر کے اسے) تدریجاً اس لئے اتارا گیا ہے تاکہ ہم اس سے آپ کے قلبِ (اطہر) کو قوت بخشیں اور (اسی وجہ سے) ہم نے اسے ٹھہر ٹھہر کر پڑھا ہے (تاکہ آپ کو ہمارے پیغام کے ذریعے بار بار سکونِ قلب ملتا رہے)،\qt@no{32}}%
\qt@newcmd\qurantrans@ur@mmdccclxxxviii{اور یہ (کفار) آپ کے پاس کوئی (ایسی) مثال (سوال اور اعتراض کے طور پر) نہیں لاتے مگر ہم آپ کے پاس (اس کے جواب میں) حق اور (اس سے) بہتر وضاحت کا بیان لے آتے ہیں،\qt@no{33}}%
\qt@newcmd\qurantrans@ur@mmdccclxxxix{یہ) ایسے لوگ ہیں جو اپنے چہروں کے بل دوزخ کی طرف ہانکے جائیں گے یہی لوگ ہیں جو ٹھکانے کے لحاظ سے نہایت برے اور راستے سے (بھی) بہت بہکے ہوئے ہیں،\qt@no{34}}%
\qt@newcmd\qurantrans@ur@mmdcccxc{اور بیشک ہم نے موسٰی (علیہ السلام) کو کتاب عطا فرمائی اور ہم نے ان کے ساتھ (ان کی معاونت کے لئے) ان کے بھائی ہارون (علیہ السلام) کو وزیر بنایا،\qt@no{35}}%
\qt@newcmd\qurantrans@ur@mmdcccxci{پھر ہم نے کہا: تم دونوں اس قوم کے پاس جاؤ جنہوں نے ہماری آیتوں کو جھٹلایا ہے (جب وہ ہماری تکذیب سے پھر بھی باز نہ آئے) تو ہم نے انہیں بالکل ہی ہلاک کر ڈالا،\qt@no{36}}%
\qt@newcmd\qurantrans@ur@mmdcccxcii{اور نوح (علیہ السلام) کی قوم کو (بھی)، جب انہوں نے رسولوں کو جھٹلایا (تو) ہم نے انہیں غرق کر ڈالا اور ہم نے انہیں (دوسرے) لوگوں کے لئے نشانِ عبرت بنا دیا اور ہم نے ظالموں کے لئے درد ناک عذاب تیار کر رکھا ہے،\qt@no{37}}%
\qt@newcmd\qurantrans@ur@mmdcccxciii{اور عاد اور ثمود اور باشندگانِ رس کو، اور ان کے درمیان بہت سی(اور) امتوں کو (بھی ہلاک کر ڈالا)،\qt@no{38}}%
\qt@newcmd\qurantrans@ur@mmdcccxciv{اور ہم نے (ان میں سے) ہر ایک (کی نصیحت) کے لئے مثالیں بیان کیں اور (جب وہ سرکشی سے باز نہ آئے تو) ہم نے ان سب کو نیست و نابود کر دیا،\qt@no{39}}%
\qt@newcmd\qurantrans@ur@mmdcccxcv{اور بیشک یہ (کفار) اس بستی پر سے گزرے ہیں جس پر بری طرح (پتھروں کی) بارش برسائی گئی تھی، تو کیا یہ اس (تباہ شدہ بستی) کو دیکھتے نہ تھے بلکہ یہ تو (مرنے کے بعد) اٹھائے جانے کی امید ہی نہیں رکھتے،\qt@no{40}}%
\qt@newcmd\qurantrans@ur@mmdcccxcvi{اور (اے حبیبِ مکرّم!) جب (بھی) وہ آپ کو دیکھتے ہیں آپ کا مذاق اڑانے کے سوا کچھ نہیں کرتے (اور کہتے ہیں:) کیا یہی وہ (شخص) ہے جسے اللہ نے رسول بنا کر بھیجا ہے،\qt@no{41}}%
\qt@newcmd\qurantrans@ur@mmdcccxcvii{قریب تھا کہ یہ ہمیں ہمارے معبودوں سے بہکا دیتا اگر ہم ان (کی پرستش) پر ثابت قدم نہ رہتے اور وہ عنقریب جان لیں گے جس وقت عذاب دیکھیں گے کہ کون زیادہ گمراہ تھا،\qt@no{42}}%
\qt@newcmd\qurantrans@ur@mmdcccxcviii{کیا آپ نے اس شخص کو دیکھا ہے جس نے اپنی خواہشِ نفس کو اپنا معبود بنا لیا ہے؟ تو کیا آپ اس پر نگہبان بنیں گے،\qt@no{43}}%
\qt@newcmd\qurantrans@ur@mmdcccxcix{کیا آپ یہ خیال کرتے ہیں کہ ان میں سے اکثر لوگ سنتے یا سمجھتے ہیں؟ (نہیں) وہ تو چوپایوں کی مانند (ہو چکے) ہیں بلکہ ان سے بھی بدتر گمراہ ہیں،\qt@no{44}}%
\qt@newcmd\qurantrans@ur@mmcm{کیا آپ نے اپنے رب (کی قدرت) کی طرف نگاہ نہیں ڈالی کہ وہ کس طرح (دوپہر تک) سایہ دراز کرتا ہے اور اگر وہ چاہتا تو اسے ضرور ساکن کر دیتا پھر ہم نے سورج کو اس (سایہ) پر دلیل بنایا ہے،\qt@no{45}}%
\qt@newcmd\qurantrans@ur@mmcmi{پھر ہم آہستہ آہستہ اس (سایہ) کو اپنی طرف کھینچ کر سمیٹ لیتے ہیں،\qt@no{46}}%
\qt@newcmd\qurantrans@ur@mmcmii{اور وہی ہے جس نے تمہارے لئے رات کو پوشاک (کی طرح ڈھانک لینے والا) بنایا اور نیند کو (تمہارے لئے) آرام (کا باعث) بنایا اور دن کو (کام کاج کے لئے) اٹھ کھڑے ہونے کا وقت بنایا،\qt@no{47}}%
\qt@newcmd\qurantrans@ur@mmcmiii{اور وہی ہے جو اپنی رحمت (کی بارش) سے پہلے ہواؤں کو خوشخبری بنا کر بھیجتا ہے، اور ہم ہی آسمان سے پاک (صاف کرنے والا) پانی اتارتے ہیں،\qt@no{48}}%
\qt@newcmd\qurantrans@ur@mmcmiv{تاکہ اس کے ذریعے ہم (کسی بھی) مُردہ شہر کو زندگی بخشیں اور (مزید یہ کہ) ہم یہ (پانی) اپنے پیدا کئے ہوئے بہت سے چوپایوں اور (بادیہ نشین) انسانوں کو پلائیں،\qt@no{49}}%
\qt@newcmd\qurantrans@ur@mmcmv{اور بیشک ہم اس (بارش) کو ان کے درمیان (مختلف شہروں اور وقتوں کے حساب سے) گھماتے (رہتے) ہیں تاکہ وہ غور و فکر کریں پھر بھی اکثر لوگوں نے بجز ناشکری کے (کچھ) قبول نہ کیا،\qt@no{50}}%
\qt@newcmd\qurantrans@ur@mmcmvi{اور اگر ہم چاہتے تو ہر ایک بستی میں ایک ڈر سنانے والا بھیج دیتے،\qt@no{51}}%
\qt@newcmd\qurantrans@ur@mmcmvii{پس (اے مردِ مومن!) تو کافروں کا کہنا نہ مان اور تو اس (قرآن کی دعوت اور دلائل) کے ذریعے ان کے ساتھ بڑا جہاد کر،\qt@no{52}}%
\qt@newcmd\qurantrans@ur@mmcmviii{اور وہی ہے جس نے دو دریاؤں کو ملا دیا۔ یہ (ایک) میٹھا نہایت شیریں ہے اور یہ (دوسرا) کھاری نہایت تلخ ہے۔ اور اس نے ان دونوں کے درمیان ایک پردہ اور مضبوط رکاوٹ بنا دی،\qt@no{53}}%
\qt@newcmd\qurantrans@ur@mmcmix{اور وہی ہے جس نے پانی (کی مانند ایک نطفہ) سے آدمی کو پیدا کیا پھر اسے نسب اور سسرال (کی قرابت) والا بنایا، اور آپ کا رب بڑی قدرت والا ہے،\qt@no{54}}%
\qt@newcmd\qurantrans@ur@mmcmx{اور وہ (کفار) اللہ کے سوا ان (بتوں) کی عبادت کرتے ہیں جو انہیں نہ (تو) نفع پہنچا سکتے ہیں اور نہ (ہی) انہیں نقصان پہنچا سکتے ہیں، اور کافر اپنے رب (کی نافرمانی) پر (ہمیشہ شیطان کا) مددگار ہوتا ہے،\qt@no{55}}%
\qt@newcmd\qurantrans@ur@mmcmxi{اور ہم نے آپ کو نہیں بھیجا مگر (اللہ کے اطاعت گزار بندوں کو) خوشخبری سنانے والا اور (بغاوت شعار لوگوں کو) ڈر سنانے والا بنا کر،\qt@no{56}}%
\qt@newcmd\qurantrans@ur@mmcmxii{آپ فرما دیجئے کہ میں تم سے اس (تبلیغ) پر کچھ بھی معاوضہ نہیں مانگتا مگر جو شخص اپنے رب تک (پہنچنے کا) راستہ اختیار کرنا چاہتا ہے (کرلے)،\qt@no{57}}%
\qt@newcmd\qurantrans@ur@mmcmxiii{اور آپ اس (ہمیشہ) زندہ رہنے والے (رب) پر بھروسہ کیجئے جو کبھی نہیں مرے گا اور اس کی تعریف کے ساتھ تسبیح کرتے رہئے، اور اس کا اپنے بندوں کے گناہوں سے باخبر ہونا کافی ہے،\qt@no{58}}%
\qt@newcmd\qurantrans@ur@mmcmxiv{جس نے آسمانی کرّوں اور زمین کو اور اس (کائنات) کو جو ان دونوں کے درمیان ہے چھ اَدوار میں پیدا فرمایا٭ پھر وہ (حسبِ شان) عرش پر جلوہ افروز ہوا (وہ) رحمان ہے، (اے معرفتِ حق کے طالب!) تو اس کے بارے میں کسی باخبر سے پوچھ (بے خبر اس کا حال نہیں جانتے)، ٭ (ستۃ اَیّام سے مراد چھ اَدوارِ تخلیق ہیں، معروف معنٰی میں چھ دن نہیں کیونکہ یہاں تو خود زمین اور جملہ آسمانی کرّوں، کہکشاؤں، ستاروں، سیاروں اور خلاؤں کی پیدائش کا زمانہ بیان ہو رہا ہے، اس وقت رات اور دن کا وجود کہاں تھا؟)\qt@no{59}}%
\qt@newcmd\qurantrans@ur@mmcmxv{اور جب ان سے کہا جاتا ہے کہ تم رحمان کو سجدہ کرو تو وہ (منکرینِ حق) کہتے ہیں کہ رحمان کیا (چیز) ہے؟ کیا ہم اسی کو سجدہ کرنے لگ جائیں جس کا آپ ہمیں حکم دے دیں اور اس (حکم) نے انہیں نفرت میں اور بڑھا دیا،\qt@no{60}}%
\qt@newcmd\qurantrans@ur@mmcmxvi{وہی بڑی برکت و عظمت والا ہے جس نے آسمانی کائنات میں (کہکشاؤں کی شکل میں) سماوی کرّوں کی وسیع منزلیں بنائیں اور اس میں (سورج کو روشنی اور تپش دینے والا) چراغ بنایا اور (اس نظامِ شمسی کے اندر) چمکنے والا چاند بنایا،\qt@no{61}}%
\qt@newcmd\qurantrans@ur@mmcmxvii{اور وہی ذات ہے جس نے رات اور دن کو ایک دوسرے کے پیچھے گردش کرنے والا بنایا اس کے لئے جو غور و فکر کرنا چاہے یا شکر گزاری کا ارادہ کرے (ان تخلیقی قدرتوں میں نصیحت و ہدایت ہے)،\qt@no{62}}%
\qt@newcmd\qurantrans@ur@mmcmxviii{اور (خدائے) رحمان کے (مقبول) بندے وہ ہیں جو زمین پر آہستگی سے چلتے ہیں اور جب ان سے جاہل (اکھڑ) لوگ (ناپسندیدہ) بات کرتے ہیں تو وہ سلام کہتے (ہوئے الگ ہو جاتے) ہیں،\qt@no{63}}%
\qt@newcmd\qurantrans@ur@mmcmxix{اور (یہ) وہ لوگ ہیں جو اپنے رب کے لئے سجدہ ریزی اور قیامِ (نِیاز) میں راتیں بسر کرتے ہیں،\qt@no{64}}%
\qt@newcmd\qurantrans@ur@mmcmxx{اور (یہ) وہ لوگ ہیں جو (ہمہ وقت حضورِ باری تعالیٰ میں) عرض گزار رہتے ہیں کہ اے ہمارے رب! تو ہم سے دوزخ کا عذاب ہٹا لے، بیشک اس کا عذاب بڑا مہلک (اور دائمی) ہے،\qt@no{65}}%
\qt@newcmd\qurantrans@ur@mmcmxxi{بیشک وہ (عارضی ٹھہرنے والوں کے لئے) بُری قرار گاہ اور (دائمی رہنے والوں کے لئے) بُری قیام گاہ ہے،\qt@no{66}}%
\qt@newcmd\qurantrans@ur@mmcmxxii{اور (یہ) وہ لوگ ہیں کہ جب خرچ کرتے ہیں تو نہ بے جا اڑاتے ہیں اور نہ تنگی کرتے ہیں اور ان کا خرچ کرنا (زیادتی اور کمی کی) ان دو حدوں کے درمیان اعتدال پر (مبنی) ہوتا ہے،\qt@no{67}}%
\qt@newcmd\qurantrans@ur@mmcmxxiii{اور (یہ) وہ لوگ ہیں جو اللہ کے ساتھ کسی دوسرے معبود کی پوجا نہیں کرتے اور نہ (ہی) کسی ایسی جان کو قتل کرتے ہیں جسے بغیرِ حق مارنا اللہ نے حرام فرمایا ہے اور نہ (ہی) بدکاری کرتے ہیں، اور جو شخص یہ کام کرے گا وہ سزائے گناہ پائے گا،\qt@no{68}}%
\qt@newcmd\qurantrans@ur@mmcmxxiv{اس کے لئے قیامت کے دن عذاب دو گنا کر دیا جائے گا اور وہ اس میں ذلت و خواری کے ساتھ ہمیشہ رہے گا،\qt@no{69}}%
\qt@newcmd\qurantrans@ur@mmcmxxv{مگر جس نے توبہ کر لی اور ایمان لے آیا اور نیک عمل کیا تو یہ وہ لوگ ہیں کہ اللہ جن کی برائیوں کو نیکیوں سے بدل دے گا، اور اللہ بڑا بخشنے والا نہایت مہربان ہے،\qt@no{70}}%
\qt@newcmd\qurantrans@ur@mmcmxxvi{اور جس نے توبہ کر لی اور نیک عمل کیا تو اس نے اللہ کی طرف (وہ) رجوع کیا جو رجوع کا حق تھا،\qt@no{71}}%
\qt@newcmd\qurantrans@ur@mmcmxxvii{اور (یہ) وہ لوگ ہیں جو کذب اور باطل کاموں میں (قولاً اور عملاً دونوں صورتوں میں) حاضر نہیں ہوتے اور جب بے ہودہ کاموں کے پاس سے گزرتے ہیں تو (دامن بچاتے ہوئے) نہایت وقار اور متانت کے ساتھ گزر جاتے ہیں،\qt@no{72}}%
\qt@newcmd\qurantrans@ur@mmcmxxviii{اور (یہ) وہ لوگ ہیں کہ جب انہیں ان کے رب کی آیتوں کے ذریعے نصیحت کی جاتی ہے تو ان پر بہرے اور اندھے ہو کر نہیں گر پڑتے (بلکہ غور و فکر بھی کرتے ہیں)،\qt@no{73}}%
\qt@newcmd\qurantrans@ur@mmcmxxix{اور (یہ) وہ لوگ ہیں جو (حضورِ باری تعالیٰ میں) عرض کرتے ہیں: اے ہمارے رب! ہمیں ہماری بیویوں اور ہماری اولاد کی طرف سے آنکھوں کی ٹھنڈک عطا فرما، اور ہمیں پرہیزگاروں کا پیشوا بنا دے،\qt@no{74}}%
\qt@newcmd\qurantrans@ur@mmcmxxx{انہی لوگوں کو (جنت میں) بلند ترین محلات ان کے صبر کرنے کی جزا کے طور پر بخشے جائیں گے اور وہاں دعائے خیر اور سلام کے ساتھ ان کا استقبال کیا جائے گا،\qt@no{75}}%
\qt@newcmd\qurantrans@ur@mmcmxxxi{یہ اس میں ہمیشہ رہنے والے ہیں وہ (بلند محلاتِ جنت) بہترین قرار گاہ اور (عمدہ) قیام گاہ ہیں،\qt@no{76}}%
\qt@newcmd\qurantrans@ur@mmcmxxxii{فرما دیجئے: میرے رب کو تمہاری کوئی پرواہ نہیں اگر تم (اس کی) عبادت نہ کرو، پس واقعی تم نے (اسے) جھٹلایا ہے تو اب یہ (جھٹلانا تمہارے لئے) دائمی عذاب بنا رہے گا،\qt@no{77}}%
\qt@newcmd\qurantrans@ur@mmcmxxxiii{\basmalahur طا، سین، میم (حقیقی معنی اﷲ اور رسول صلی اللہ علیہ وآلہ وسلم ہی بہتر جانتے ہیں)،\qt@no{1}}%
\qt@newcmd\qurantrans@ur@mmcmxxxiv{یہ (حق کو) واضح کرنے والی کتاب کی آیتیں ہیں،\qt@no{2}}%
\qt@newcmd\qurantrans@ur@mmcmxxxv{اے حبیبِ مکرّم!) شاید آپ (اس غم میں) اپنی جانِ (عزیز) ہی دے بیٹھیں گے کہ وہ ایمان نہیں لاتے،\qt@no{3}}%
\qt@newcmd\qurantrans@ur@mmcmxxxvi{اگر ہم چاہیں تو ان پر آسمان سے (ایسی) نشانی اتار دیں کہ ان کی گردنیں اس کے آگے جھکی رہ جائیں،\qt@no{4}}%
\qt@newcmd\qurantrans@ur@mmcmxxxvii{اور ان کے پاس (خدائے) رحمان کی جانب سے کوئی نئی نصیحت نہیں آتی مگر وہ اس سے رُوگرداں ہو جاتے ہیں،\qt@no{5}}%
\qt@newcmd\qurantrans@ur@mmcmxxxviii{سو بیشک وہ (حق کو) جھٹلا چکے پس عنقریب انہیں اس امر کی خبریں پہنچ جائیں گی جس کا وہ مذاق اڑایا کرتے تھے،\qt@no{6}}%
\qt@newcmd\qurantrans@ur@mmcmxxxix{اور کیا انہوں نے زمین کی طرف نگاہ نہیں کی کہ ہم نے اس میں کتنی ہی نفیس چیزیں اگائی ہیں،\qt@no{7}}%
\qt@newcmd\qurantrans@ur@mmcmxl{بیشک اس میں ضرور (قدرتِ الٰہیہ کی) نشانی ہے اور ان میں سے اکثر لوگ ایمان لانے والے نہیں ہیں،\qt@no{8}}%
\qt@newcmd\qurantrans@ur@mmcmxli{اور یقیناً آپ کا رب ہی تو غالب، مہربان ہے،\qt@no{9}}%
\qt@newcmd\qurantrans@ur@mmcmxlii{اور (وہ واقعہ یاد کیجئے) جب آپ کے رب نے موسٰی (علیہ السلام) کو نِدا دی کہ تم ظالموں کی قوم کے پاس جاؤ،\qt@no{10}}%
\qt@newcmd\qurantrans@ur@mmcmxliii{یعنی) قومِ فرعون کے پاس، کیا وہ (اللہ سے) نہیں ڈرتے،\qt@no{11}}%
\qt@newcmd\qurantrans@ur@mmcmxliv{موسٰی (علیہ السلام) نے عرض کیا: اے رب! میں ڈرتا ہوں کہ وہ مجھے جھٹلا دیں گے،\qt@no{12}}%
\qt@newcmd\qurantrans@ur@mmcmxlv{اور (ایسے ناسازگار ماحول میں) میرا سینہ تنگ ہوجاتا ہے اور میری زبان (روانی سے) نہیں چلتی سو ہارون (علیہ السلام) کی طرف (بھی جبرائیل علیہ السلام کو وحی کے ساتھ) بھیج دے (تاکہ وہ میرا معاون بن جائے)،\qt@no{13}}%
\qt@newcmd\qurantrans@ur@mmcmxlvi{اور ان کا میرے اوپر (قبطی کو مار ڈالنے کا) ایک الزام بھی ہے سو میں ڈرتا ہوں کہ وہ مجھے قتل کر ڈالیں گے،\qt@no{14}}%
\qt@newcmd\qurantrans@ur@mmcmxlvii{ارشاد ہوا: ہرگز نہیں، پس تم دونوں ہماری نشانیاں لے کر جاؤ بیشک ہم تمہارے ساتھ (ہر بات) سننے والے ہیں،\qt@no{15}}%
\qt@newcmd\qurantrans@ur@mmcmxlviii{پس تم دونوں فرعون کے پاس جاؤ اور کہو: ہم سارے جہانوں کے پروردگار کے (بھیجے ہوئے) رسول ہیں،\qt@no{16}}%
\qt@newcmd\qurantrans@ur@mmcmxlix{ہمارا مدعا یہ ہے) کہ تو بنی اسرائیل کو (آزادی دے کر) ہمارے ساتھ بھیج دے،\qt@no{17}}%
\qt@newcmd\qurantrans@ur@mmcml{فرعون نے) کہا: کیا ہم نے تمہیں اپنے یہاں بچپن کی حالت میں پالا نہیں تھا اور تم نے اپنی عمر کے کتنے ہی سال ہمارے اندر بسر کئے تھے،\qt@no{18}}%
\qt@newcmd\qurantrans@ur@mmcmli{اور (پھر) تم نے اپنا وہ کام کر ڈالا جو تم نے کیا تھا (یعنی ایک قبطی کو قتل کر دیا) اور تم ناشکر گزاروں میں سے ہو (ہماری پرورش اور احسانات کو بھول گئے ہو)،\qt@no{19}}%
\qt@newcmd\qurantrans@ur@mmcmlii{موسٰی علیہ السلام نے) فرمایا: جب میں نے وہ کام کیا میں بے خبر تھا (کہ کیا ایک گھونسے سے اس کی موت بھی واقع ہو سکتی ہے)،\qt@no{20}}%
\qt@newcmd\qurantrans@ur@mmcmliii{پھر میں (اس وقت) تمہارے (دائرہ اختیار) سے نکل گیا جب میں تمہارے (ارادوں) سے خوفزدہ ہوا پھر میرے رب نے مجھے حکمِ (نبوت) بخشا اور (بالآخر) مجھے رسولوں میں شامل فرما دیا،\qt@no{21}}%
\qt@newcmd\qurantrans@ur@mmcmliv{اور کیا وہ (کوئی) بھلائی ہے جس کا تو مجھ پر احسان جتا رہا ہے (اس کا سبب بھی یہ تھا) کہ تو نے (میری پوری قوم) بنی اسرائیل کو غلام بنا رکھا تھا،\qt@no{22}}%
\qt@newcmd\qurantrans@ur@mmcmlv{فرعون نے کہا: سارے جہانوں کا پروردگار کیا چیز ہے،\qt@no{23}}%
\qt@newcmd\qurantrans@ur@mmcmlvi{موسٰی علیہ السلام نے) فرمایا: (وہ) جملہ آسمانوں کا اور زمین کا اور اُس (ساری کائنات) کا رب ہے جو ان دونوں کے درمیان ہے اگر تم یقین کرنے والے ہو،\qt@no{24}}%
\qt@newcmd\qurantrans@ur@mmcmlvii{اس نے ان (لوگوں) سے کہا جو اس کے گرد (بیٹھے) تھے: کیا تم سن نہیں رہے ہو،\qt@no{25}}%
\qt@newcmd\qurantrans@ur@mmcmlviii{موسٰی علیہ السلام نے مزید) کہا کہ (وہی) تمہارا (بھی) رب ہے اور تمہارے اگلے باپ دادوں کا (بھی) رب ہے،\qt@no{26}}%
\qt@newcmd\qurantrans@ur@mmcmlix{فرعون نے) کہا: بیشک تمہارا رسول جو تمہاری طرف بھیجا گیا ہے ضرور دیوانہ ہے،\qt@no{27}}%
\qt@newcmd\qurantrans@ur@mmcmlx{موسٰی علیہ السلام نے) کہا: (وہ) مشرق اور مغرب اور اس (ساری کائنات) کا رب ہے جو ان دونوں کے درمیان ہے اگر تم (کچھ) عقل رکھتے ہو،\qt@no{28}}%
\qt@newcmd\qurantrans@ur@mmcmlxi{فرعون نے) کہا: (اے موسٰی!) اگر تم نے میرے سوا کسی اور کو معبود بنایا تو میں تم کو ضرور (گرفتار کر کے) قیدیوں میں شامل کر دوں گا،\qt@no{29}}%
\qt@newcmd\qurantrans@ur@mmcmlxii{موسٰی علیہ السلام نے) فرمایا: اگرچہ میں تیرے پاس کوئی واضح چیز (بطور معجزہ بھی) لے آؤں،\qt@no{30}}%
\qt@newcmd\qurantrans@ur@mmcmlxiii{فرعون نے) کہا: تم اسے لے آؤ اگر تم سچے ہو،\qt@no{31}}%
\qt@newcmd\qurantrans@ur@mmcmlxiv{پس (موسیٰ علیہ السلام نے) اپنا عصا (زمین پر) ڈال دیا وہ اسی وقت واضح (طور پر) اژدھا بن گیا،\qt@no{32}}%
\qt@newcmd\qurantrans@ur@mmcmlxv{اور (موسٰی علیہ السلام نے) اپنا ہاتھ (بغل میں ڈال کر) باہر نکالا تو وہ اسی وقت دیکھنے والوں کے لئے (چمک دار) سفید ہوگیا،\qt@no{33}}%
\qt@newcmd\qurantrans@ur@mmcmlxvi{فرعون نے) اپنے ارد گرد (بیٹھے ہوئے) سرداروں سے کہا: بلاشبہ یہ بڑا دانا جادوگر ہے،\qt@no{34}}%
\qt@newcmd\qurantrans@ur@mmcmlxvii{یہ چاہتا ہے کہ تمہیں اپنے جادو (کے زور) سے تمہارے ملک سے باہر نکال دے پس تم (اب اس کے بارے میں) کیا رائے دیتے ہو،\qt@no{35}}%
\qt@newcmd\qurantrans@ur@mmcmlxviii{وہ بولے کہ تو اسے اور اس کے بھائی (ہارون کے حکمِ سزا سنانے) کو مؤخر کر دے اور (تمام) شہروں میں (جادوگروں کو بلانے کے لئے) ہرکارے بھیج دے،\qt@no{36}}%
\qt@newcmd\qurantrans@ur@mmcmlxix{وہ تیرے پاس ہر بڑے ماہرِ فن جادوگر کو لے آئیں،\qt@no{37}}%
\qt@newcmd\qurantrans@ur@mmcmlxx{پس سارے جادوگر مقررہ دن کے معینہ وقت پر جمع کر لئے گئے،\qt@no{38}}%
\qt@newcmd\qurantrans@ur@mmcmlxxi{اور (فرعون کی طرف سے) لوگوں کو کہا گیا کہ تم (اس موقع پر) جمع ہونے والے ہو،\qt@no{39}}%
\qt@newcmd\qurantrans@ur@mmcmlxxii{تاکہ ہم جادوگروں (کے دین) کی پیروی کر سکیں اگر وہ (موسٰی اور ہارون پر) غالب آگئے،\qt@no{40}}%
\qt@newcmd\qurantrans@ur@mmcmlxxiii{پھر جب وہ جادوگر آگئے (تو) انہوں نے فرعون سے کہا: کیا ہمارے لئے کوئی اُجرت (بھی مقرر) ہے اگر ہم (مقابلہ میں) غالب ہو جائیں،\qt@no{41}}%
\qt@newcmd\qurantrans@ur@mmcmlxxiv{فرعون نے) کہا: ہاں بیشک تم اسی وقت (اجرت والوں کی بجائے میرے) قربت والوں میں شامل ہو جاؤ گے (اور قربت کا درجہ اُجرت سے کہیں بلند ہے)،\qt@no{42}}%
\qt@newcmd\qurantrans@ur@mmcmlxxv{موسٰی (علیہ السلام) نے ان (جادوگروں سے) فرمایا: تم وہ (جادو کی) چیزیں ڈال دو جو تم ڈالنے والے ہو،\qt@no{43}}%
\qt@newcmd\qurantrans@ur@mmcmlxxvi{تو انہوں نے اپنی رسیاں اور اپنی لاٹھیاں ڈال دیں اور کہنے لگے: فرعون کی عزت کی قسم! ہم ضرور غالب ہوں گے،\qt@no{44}}%
\qt@newcmd\qurantrans@ur@mmcmlxxvii{پھر موسٰی (علیہ السلام) نے اپنا ڈنڈا ڈال دیا تو وہ (اژدھا بن کر) فوراً ان چیزوں کو نگلنے لگا جو انہوں نے فریب کاری سے (اپنی اصل حقیقت سے) پھیر رکھی تھیں،\qt@no{45}}%
\qt@newcmd\qurantrans@ur@mmcmlxxviii{پس سارے جادوگر سجدہ کرتے ہوئے گر پڑے،\qt@no{46}}%
\qt@newcmd\qurantrans@ur@mmcmlxxix{وہ کہنے لگے: ہم سارے جہانوں کے پروردگار پر ایمان لے آئے،\qt@no{47}}%
\qt@newcmd\qurantrans@ur@mmcmlxxx{جو) موسٰی اور ہارون (علیہما السلام) کا رب ہے،\qt@no{48}}%
\qt@newcmd\qurantrans@ur@mmcmlxxxi{فرعون نے) کہا: تم اس پر ایمان لے آئے ہو قبل اس کے کہ میں تمہیں اجازت دیتا، بیشک یہ (موسٰی علیہ السلام) ہی تمہارا بڑا (استاد) ہے جس نے تمہیں جادو سکھایا ہے، تم جلد ہی (اپنا انجام) معلوم کر لو گے، میں ضرور ہی تمہارے ہاتھ اور تمہارے پاؤں الٹی طرف سے کاٹ ڈالوں گا اور تم سب کو یقیناً سولی پر چڑھا دوں گا،\qt@no{49}}%
\qt@newcmd\qurantrans@ur@mmcmlxxxii{انہوں نے کہا: (اس میں) کوئی نقصان نہیں، بیشک ہم اپنے رب کی طرف پلٹنے والے ہیں،\qt@no{50}}%
\qt@newcmd\qurantrans@ur@mmcmlxxxiii{ہم قوی امید رکھتے ہیں کہ ہمارا رب ہماری خطائیں معاف فرما دے گا، اس وجہ سے کہ (اب) ہم ہی سب سے پہلے ایمان لانے والے ہیں،\qt@no{51}}%
\qt@newcmd\qurantrans@ur@mmcmlxxxiv{اور ہم نے موسٰی (علیہ السلام) کی طرف وحی بھیجی کہ تم میرے بندوں کو راتوں رات (یہاں سے) لے جاؤ بیشک تمہارا تعاقب کیا جائے گا،\qt@no{52}}%
\qt@newcmd\qurantrans@ur@mmcmlxxxv{پھر فرعون نے شہروں میں ہرکارے بھیج دئیے،\qt@no{53}}%
\qt@newcmd\qurantrans@ur@mmcmlxxxvi{اور کہا:) بیشک یہ (بنی اسرائیل) تھوڑی سی جماعت ہے،\qt@no{54}}%
\qt@newcmd\qurantrans@ur@mmcmlxxxvii{اور بلاشبہ وہ ہمیں غصہ دلا رہے ہیں،\qt@no{55}}%
\qt@newcmd\qurantrans@ur@mmcmlxxxviii{اور یقیناً ہم سب (بھی) مستعد اور چوکس ہیں،\qt@no{56}}%
\qt@newcmd\qurantrans@ur@mmcmlxxxix{پس ہم نے ان (فرعونیوں) کو باغوں اور چشموں سے نکال باہر کیا،\qt@no{57}}%
\qt@newcmd\qurantrans@ur@mmcmxc{اور خزانوں اور نفیس قیام گاہوں سے (بھی نکال دیا)،\qt@no{58}}%
\qt@newcmd\qurantrans@ur@mmcmxci{ہم نے) اسی طرح (کیا) اور ہم نے بنی اسرائیل کو ان (سب چیزوں) کا وارث بنا دیا،\qt@no{59}}%
\qt@newcmd\qurantrans@ur@mmcmxcii{پھر سورج نکلتے وقت ان (فرعونیوں) نے ان کا تعاقب کیا،\qt@no{60}}%
\qt@newcmd\qurantrans@ur@mmcmxciii{پھر جب دونوں جماعتیں آمنے سامنے ہوئیں (تو) موسٰی (علیہ السلام) کے ساتھیوں نے کہا: (اب) ہم ضرور پکڑے گئے،\qt@no{61}}%
\qt@newcmd\qurantrans@ur@mmcmxciv{موسٰی علیہ السلام نے) فرمایا: ہرگز نہیں، بیشک میرے ساتھ میرا رب ہے وہ ابھی مجھے راہِ (نجات) دکھا دے گا،\qt@no{62}}%
\qt@newcmd\qurantrans@ur@mmcmxcv{پھر ہم نے موسٰی (علیہ السلام) کی طرف وحی بھیجی کہ اپنا عصا دریا پر مارو، پس دریا (بارہ حصوں میں) پھٹ گیا اور ہر ٹکڑا زبردست پہاڑ کی مانند ہو گیا،\qt@no{63}}%
\qt@newcmd\qurantrans@ur@mmcmxcvi{اور ہم نے دوسروں (یعنی فرعون اور اس کے ساتھیوں) کو اس جگہ کے قریب کر دیا،\qt@no{64}}%
\qt@newcmd\qurantrans@ur@mmcmxcvii{اور ہم نے موسٰی علیہ السلام کو (بھی) نجات بخشی اور ان سب لوگوں کو (بھی) جو ان کے ساتھ تھے،\qt@no{65}}%
\qt@newcmd\qurantrans@ur@mmcmxcviii{پھر ہم نے دوسروں (یعنی فرعونیوں) کو غرق کر دیا،\qt@no{66}}%
\qt@newcmd\qurantrans@ur@mmcmxcix{بیشک اس (واقعہ) میں (قدرتِ الٰہیہ) کی بڑی نشانی ہے، اور ان میں سے اکثر لوگ مومن نہ تھے،\qt@no{67}}%
\qt@newcmd\qurantrans@ur@mmm{اور بیشک آپ کا رب ہی یقیناً غالب رحمت والا ہے،\qt@no{68}}%
\qt@newcmd\qurantrans@ur@mmmi{اور آپ ان پر ابراہیم (علیہ السلام) کا قصہ (بھی) پڑھ کر سنا دیں،\qt@no{69}}%
\qt@newcmd\qurantrans@ur@mmmii{جب انہوں نے اپنے باپ ٭ اور اپنی قوم سے فرمایا: تم کس چیز کو پوجتے ہو، ٭ (یہ حقیقی باپ نہ تھا، چچا تھا۔ اسی نے حضرت ابراہیم علیہ السلام کی پرورش کی تھی جس کی وجہ سے اسے باپ کہا کرتے تھے۔ اس کا نام آزر ہے جبکہ آپ کے حقیقی والد کا نام تارخ ہے۔)\qt@no{70}}%
\qt@newcmd\qurantrans@ur@mmmiii{انہوں نے کہا: ہم بتوں کی پرستش کرتے ہیں اور ہم انہی (کی عبادت و خدمت) کے لئے جمے رہنے والے ہیں،\qt@no{71}}%
\qt@newcmd\qurantrans@ur@mmmiv{ابراہیم علیہ السلام نے) فرمایا: کیا وہ تمہیں سنتے ہیں جب تم (ان کو) پکارتے ہو،\qt@no{72}}%
\qt@newcmd\qurantrans@ur@mmmv{یا وہ تمہیں نفع پہنچاتے ہیں یا نقصان پہنچاتے ہیں،\qt@no{73}}%
\qt@newcmd\qurantrans@ur@mmmvi{وہ بولے: (یہ تو معلوم نہیں) لیکن ہم نے اپنے باپ دادا کو ایسا ہی کرتے پایا تھا،\qt@no{74}}%
\qt@newcmd\qurantrans@ur@mmmvii{ابراہیم علیہ السلام نے) فرمایا: کیا تم نے (کبھی ان کی حقیقت میں) غور کیا ہے جن کی تم پرستش کرتے ہو،\qt@no{75}}%
\qt@newcmd\qurantrans@ur@mmmviii{تم اور تمہارے اگلے آباء و اجداد (الغرض کسی نے بھی سوچا)،\qt@no{76}}%
\qt@newcmd\qurantrans@ur@mmmix{پس وہ (سب بُت) میرے دشمن ہیں سوائے تمام جہانوں کے رب کے (وہی میرا معبود ہے)،\qt@no{77}}%
\qt@newcmd\qurantrans@ur@mmmx{وہ جس نے مجھے پیدا کیا سو وہی مجھے ہدایت فرماتا ہے،\qt@no{78}}%
\qt@newcmd\qurantrans@ur@mmmxi{اور وہی ہے جو مجھے کھلاتا اور پلاتا ہے،\qt@no{79}}%
\qt@newcmd\qurantrans@ur@mmmxii{اور جب میں بیمار ہو جاتا ہوں تو وہی مجھے شفا دیتا ہے،\qt@no{80}}%
\qt@newcmd\qurantrans@ur@mmmxiii{اور وہی مجھے موت دے گا پھر وہی مجھے (دوبارہ) زندہ فرمائے گا،\qt@no{81}}%
\qt@newcmd\qurantrans@ur@mmmxiv{اور اسی سے میں امید رکھتا ہوں کہ روزِ قیامت وہ میری خطائیں معاف فرما دے گا،\qt@no{82}}%
\qt@newcmd\qurantrans@ur@mmmxv{اے میرے رب! مجھے علم و عمل میں کمال عطا فرما اور مجھے اپنے قربِ خاص کے سزاواروں میں شامل فرما لے،\qt@no{83}}%
\qt@newcmd\qurantrans@ur@mmmxvi{اور میرے لئے بعد میں آنے والوں میں (بھی) ذکرِ خیر اور قبولیت جاری فرما،\qt@no{84}}%
\qt@newcmd\qurantrans@ur@mmmxvii{اور مجھے نعمتوں والی جنت کے وارثوں میں سے بنا دے،\qt@no{85}}%
\qt@newcmd\qurantrans@ur@mmmxviii{اور میرے باپ کو بخش دے بیشک وہ گمراہوں میں سے تھا،\qt@no{86}}%
\qt@newcmd\qurantrans@ur@mmmxix{اور مجھے (اُس دن) رسوا نہ کرنا جس دن لوگ قبروں سے اٹھائے جائیں گے،\qt@no{87}}%
\qt@newcmd\qurantrans@ur@mmmxx{جس دن نہ کوئی مال نفع دے گا اور نہ اولاد،\qt@no{88}}%
\qt@newcmd\qurantrans@ur@mmmxxi{مگر وہی شخص (نفع مند ہوگا) جو اللہ کی بارگاہ میں سلامتی والے بے عیب دل کے ساتھ حاضر ہوا،\qt@no{89}}%
\qt@newcmd\qurantrans@ur@mmmxxii{اور (اس دن) جنت پرہیزگاروں کے قریب کر دی جائے گے،\qt@no{90}}%
\qt@newcmd\qurantrans@ur@mmmxxiii{اور دوزخ گمراہوں کے سامنے ظاہر کر دی جائے گی،\qt@no{91}}%
\qt@newcmd\qurantrans@ur@mmmxxiv{اور ان سے کہا جائے گا: وہ (بت) کہاں ہیں جنہیں تم پوجتے تھے،\qt@no{92}}%
\qt@newcmd\qurantrans@ur@mmmxxv{اللہ کے سوا، کیا وہ تمہاری مدد کرسکتے ہیں یا خود اپنی مدد کرسکتے ہیں؟ (کہ اپنے آپ کو دوزخ سے بچالیں)،\qt@no{93}}%
\qt@newcmd\qurantrans@ur@mmmxxvi{سو وہ (بت بھی) اس (دوزخ) میں اوندھے منہ گرا دیئے جائیں گے اور گمراہ لوگ (بھی)،\qt@no{94}}%
\qt@newcmd\qurantrans@ur@mmmxxvii{اور ابلیس کی ساری فوجیں (بھی واصل جہنم ہوں گی)،\qt@no{95}}%
\qt@newcmd\qurantrans@ur@mmmxxviii{وہ (گمراہ لوگ) اس (دوزخ) میں باہم جھگڑا کرتے ہوئے کہیں گے،\qt@no{96}}%
\qt@newcmd\qurantrans@ur@mmmxxix{اللہ کی قسم! ہم کھلی گمراہی میں تھے،\qt@no{97}}%
\qt@newcmd\qurantrans@ur@mmmxxx{جب ہم تمہیں سب جہانوں کے رب کے برابر ٹھہراتے تھے،\qt@no{98}}%
\qt@newcmd\qurantrans@ur@mmmxxxi{اور ہم کو (ان) مجرموں کے سوا کسی نے گمراہ نہیں کیا،\qt@no{99}}%
\qt@newcmd\qurantrans@ur@mmmxxxii{سو (آج) نہ کوئی ہماری سفارش کرنے والا ہے،\qt@no{100}}%
\qt@newcmd\qurantrans@ur@mmmxxxiii{اور نہ کوئی گرم جوش دوست ہے،\qt@no{101}}%
\qt@newcmd\qurantrans@ur@mmmxxxiv{سو کاش ہمیں ایک بار (دنیا میں) پلٹنا (نصیب) ہو جاتا تو ہم مومن ہوجاتے،\qt@no{102}}%
\qt@newcmd\qurantrans@ur@mmmxxxv{بیشک اس (واقعہ) میں (قدرتِ الٰہیہ کی) بڑی نشانی ہے، اور ان کے اکثر لوگ مومن نہ تھے،\qt@no{103}}%
\qt@newcmd\qurantrans@ur@mmmxxxvi{اور بیشک آپ کا رب ہی یقیناً غالب رحمت والا ہے،\qt@no{104}}%
\qt@newcmd\qurantrans@ur@mmmxxxvii{نوح (علیہ السلام) کی قوم نے (بھی) پیغمبروں کو جھٹلایا،\qt@no{105}}%
\qt@newcmd\qurantrans@ur@mmmxxxviii{جب ان سے ان کے (قومی) بھائی نوح (علیہ السلام) نے فرمایا: کیا تم (اللہ سے) ڈرتے نہیں ہو،\qt@no{106}}%
\qt@newcmd\qurantrans@ur@mmmxxxix{بیشک میں تمہارے لئے امانت دار رسول (بن کر آیا) ہوں،\qt@no{107}}%
\qt@newcmd\qurantrans@ur@mmmxl{سو تم اللہ سے ڈرو اور میری اطاعت کرو،\qt@no{108}}%
\qt@newcmd\qurantrans@ur@mmmxli{اور میں تم سے اس (تبلیغِ حق) پر کوئی معاوضہ نہیں مانگتا، میرا اجر تو صرف سب جہانوں کے رب کے ذمہ ہے،\qt@no{109}}%
\qt@newcmd\qurantrans@ur@mmmxlii{پس تم اللہ سے ڈرو اور میری فرمانبرادری کرو،\qt@no{110}}%
\qt@newcmd\qurantrans@ur@mmmxliii{وہ بولے: کیا ہم تم پر ایمان لے آئیں حالانکہ تمہاری پیروی (معاشرے کے) انتہائی نچلے اور حقیر (طبقات کے) لوگ کر رہے ہیں،\qt@no{111}}%
\qt@newcmd\qurantrans@ur@mmmxliv{نوح علیہ السلام نے) فرمایا: میرے علم کو ان کے (پیشہ وارانہ) کاموں سے کیا سروکار،\qt@no{112}}%
\qt@newcmd\qurantrans@ur@mmmxlv{ان کا حساب تو صرف میرے رب ہی کے ذمہ ہے۔ کاش! تم سمجھتے (کہ حقیقی عزت و ذلت کیا ہے)،\qt@no{113}}%
\qt@newcmd\qurantrans@ur@mmmxlvi{اور میں مومنوں کو دھتکارنے والا نہیں ہوں،\qt@no{114}}%
\qt@newcmd\qurantrans@ur@mmmxlvii{میں تو فقط کھلا ڈر سنانے والا ہوں،\qt@no{115}}%
\qt@newcmd\qurantrans@ur@mmmxlviii{وہ بولے: اے نوح! اگر تم (ان باتوں سے) باز نہ آئے تو تمہیں یقیناً سنگ سار کر دیا جائے گا،\qt@no{116}}%
\qt@newcmd\qurantrans@ur@mmmxlix{نوح علیہ السلام نے) عرض کیا: اے میرے رب! میری قوم نے مجھے جھٹلا دیا،\qt@no{117}}%
\qt@newcmd\qurantrans@ur@mmml{پس تو میرے اور ان کے درمیان فیصلہ فرما دے اور مجھے اور ان مومنوں کو جو میرے ساتھ ہیں نجات دے دے،\qt@no{118}}%
\qt@newcmd\qurantrans@ur@mmmli{پس ہم نے ان کو اور جو ان کے ساتھ بھری ہوئی کشتی میں (سوار) تھے نجات دے دی،\qt@no{119}}%
\qt@newcmd\qurantrans@ur@mmmlii{پھر اس کے بعد ہم نے باقی ماندہ لوگوں کو غرق کر دیا،\qt@no{120}}%
\qt@newcmd\qurantrans@ur@mmmliii{بیشک اس (واقعہ) میں (قدرتِ الٰہیہ کی) بڑی نشانی ہے اور ان کے اکثر لوگ مومن نہ تھے،\qt@no{121}}%
\qt@newcmd\qurantrans@ur@mmmliv{اور بیشک آپ کا رب ہی یقیناً غالب رحمت والا ہے،\qt@no{122}}%
\qt@newcmd\qurantrans@ur@mmmlv{قومِ) عاد نے (بھی) پیغمبروں کو جھٹلایا،\qt@no{123}}%
\qt@newcmd\qurantrans@ur@mmmlvi{جب اُن سے اُن کے (قومی) بھائی ھود (علیہ السلام) نے فرمایا: کیا تم (اللہ سے) ڈرتے نہیں ہو،\qt@no{124}}%
\qt@newcmd\qurantrans@ur@mmmlvii{بیشک میں تمہارے لئے امانت دار رسول (بن کر آیا) ہوں،\qt@no{125}}%
\qt@newcmd\qurantrans@ur@mmmlviii{سو تم اللہ سے ڈرو اور میری اطاعت کرو،\qt@no{126}}%
\qt@newcmd\qurantrans@ur@mmmlix{اور میں تم سے اس (تبلیغِ حق) پر کوئی معاوضہ نہیں مانگتا، میرا اجر تو فقط تمام جہانوں کے رب کے ذمہ ہے،\qt@no{127}}%
\qt@newcmd\qurantrans@ur@mmmlx{کیا تم ہر اونچی جگہ پر ایک یادگار تعمیر کرتے ہو (محض) تفاخر اور فضول مشغلوں کے لئے،\qt@no{128}}%
\qt@newcmd\qurantrans@ur@mmmlxi{اور تم (تالابوں والے) مضبوط محلات بناتے ہو اس امید پر کہ تم (دنیا میں) ہمیشہ رہو گے،\qt@no{129}}%
\qt@newcmd\qurantrans@ur@mmmlxii{اور جب تم کسی کی گرفت کرتے ہو تو سخت ظالم و جابر بن کر گرفت کرتے ہو،\qt@no{130}}%
\qt@newcmd\qurantrans@ur@mmmlxiii{سو تم اللہ سے ڈرو اور میری فرمانبرداری اختیار کرو،\qt@no{131}}%
\qt@newcmd\qurantrans@ur@mmmlxiv{اور اس (اللہ) سے ڈرو جس نے تمہاری ان چیزوں سے مدد کی جو تم جانتے ہو،\qt@no{132}}%
\qt@newcmd\qurantrans@ur@mmmlxv{اس نے تمہاری چوپایہ جانوروں اور اولاد سے مدد فرمائی،\qt@no{133}}%
\qt@newcmd\qurantrans@ur@mmmlxvi{اور باغات اور چشموں سے (بھی)،\qt@no{134}}%
\qt@newcmd\qurantrans@ur@mmmlxvii{بیشک میں تم پر ایک زبردست دن کے عذاب کا خوف رکھتا ہوں،\qt@no{135}}%
\qt@newcmd\qurantrans@ur@mmmlxviii{وہ بولے: ہمارے حق میں برابر ہے خواہ تم نصیحت کرو یا نصیحت کرنے والوں میں نہ بنو (ہم نہیں مانیں گے)،\qt@no{136}}%
\qt@newcmd\qurantrans@ur@mmmlxix{یہ (اور) کچھ نہیں مگر صرف پہلے لوگوں کی عادات (و اطوار) ہیں (جنہیں ہم چھوڑ نہیں سکتے)،\qt@no{137}}%
\qt@newcmd\qurantrans@ur@mmmlxx{اور ہم پر عذاب نہیں کیا جائے گا،\qt@no{138}}%
\qt@newcmd\qurantrans@ur@mmmlxxi{سو انہوں نے اس کو (یعنی ھود علیہ السلام کو) جھٹلا دیا پس ہم نے انہیں ہلاک کر ڈالا، بیشک اس (قصہ) میں (قدرتِ الٰہیہ کی) بڑی نشانی ہے، اور ان میں سے اکثر لوگ مومن نہ تھے،\qt@no{139}}%
\qt@newcmd\qurantrans@ur@mmmlxxii{اور بیشک آپ کا رب ہی یقیناً غالب رحمت والا ہے،\qt@no{140}}%
\qt@newcmd\qurantrans@ur@mmmlxxiii{قومِ) ثمود نے (بھی) پیغمبروں کو جھٹلایا،\qt@no{141}}%
\qt@newcmd\qurantrans@ur@mmmlxxiv{جب ان سے ان کے (قومی) بھائی صالح (علیہ السلام) نے فرمایا: کیا تم (اللہ سے) ڈرتے نہیں ہو،\qt@no{142}}%
\qt@newcmd\qurantrans@ur@mmmlxxv{بیشک میں تمہارے لئے امانت دار رسول (بن کر آیا) ہوں،\qt@no{143}}%
\qt@newcmd\qurantrans@ur@mmmlxxvi{پس تم اللہ سے ڈرو اور میری اطاعت کرو،\qt@no{144}}%
\qt@newcmd\qurantrans@ur@mmmlxxvii{اور میں تم سے اس (تبلیغِ حق) پر کچھ معاوضہ طلب نہیں کرتا، میرا اجر تو صرف سارے جہانوں کے پروردگار کے ذمہ ہے،\qt@no{145}}%
\qt@newcmd\qurantrans@ur@mmmlxxviii{کیا تم ان (نعمتوں) میں جو یہاں (تمہیں میسر) ہیں (ہمیشہ کے لئے) امن و اطمینان سے چھوڑ دیئے جاؤ گے،\qt@no{146}}%
\qt@newcmd\qurantrans@ur@mmmlxxix{یعنی یہاں کے) باغوں اور چشموں میں،\qt@no{147}}%
\qt@newcmd\qurantrans@ur@mmmlxxx{اور کھیتوں اور کھجوروں میں جن کے خوشے نرم و نازک ہوتے ہیں،\qt@no{148}}%
\qt@newcmd\qurantrans@ur@mmmlxxxi{اور تم (سنگ تراشی کی) مہارت کے ساتھ پہاڑوں میں تراش (تراش) کر مکانات بناتے ہو،\qt@no{149}}%
\qt@newcmd\qurantrans@ur@mmmlxxxii{پس تم اللہ سے ڈرو اور میری اطاعت کرو،\qt@no{150}}%
\qt@newcmd\qurantrans@ur@mmmlxxxiii{اور حد سے تجاوز کرنے والوں کا کہنا نہ مانو،\qt@no{151}}%
\qt@newcmd\qurantrans@ur@mmmlxxxiv{جو زمین میں فساد پھیلاتے ہیں اور (معاشرہ کی) اصلاح نہیں کرتے،\qt@no{152}}%
\qt@newcmd\qurantrans@ur@mmmlxxxv{وہ بولے کہ تم تو فقط جادو زدہ لوگوں میں سے ہو،\qt@no{153}}%
\qt@newcmd\qurantrans@ur@mmmlxxxvi{تم تو محض ہمارے جیسے بشر ہو، پس تم کوئی نشانی لے آؤ اگر تم سچے ہو،\qt@no{154}}%
\qt@newcmd\qurantrans@ur@mmmlxxxvii{صالح علیہ السلام نے) فرمایا: (وہ نشانی) یہ اونٹنی ہے پانی کا ایک وقت اس کے لئے (مقرر) ہے اور ایک مقررہ دن تمہارے پانی کی باری ہے،\qt@no{155}}%
\qt@newcmd\qurantrans@ur@mmmlxxxviii{اور اِسے برائی (کے ارادہ) سے ہاتھ مت لگانا ورنہ بڑے (سخت) دن کا عذاب تمہیں آپکڑے گا،\qt@no{156}}%
\qt@newcmd\qurantrans@ur@mmmlxxxix{پھر انہوں نے اس کی کونچیں کاٹ ڈالیں (سو اسے ہلاک کر دیا) پھر وہ (اپنے کئے پر) پشیمان ہو گئے،\qt@no{157}}%
\qt@newcmd\qurantrans@ur@mmmxc{سو انہیں عذاب نے آپکڑا، بیشک اس (واقعہ) میں بڑی نشانی ہے، اور ان میں سے اکثر لوگ مومن نہ تھے،\qt@no{158}}%
\qt@newcmd\qurantrans@ur@mmmxci{اور بیشک آپ کا رب ہی بڑا غالب رحمت والا ہے،\qt@no{159}}%
\qt@newcmd\qurantrans@ur@mmmxcii{قومِ لوط نے (بھی) پیغمبروں کو جھٹلایا،\qt@no{160}}%
\qt@newcmd\qurantrans@ur@mmmxciii{جب ان سے ان کے (قومی) بھائی لوط (علیہ السلام) نے فرمایا: کیا تم (اللہ سے) ڈرتے نہیں ہو،\qt@no{161}}%
\qt@newcmd\qurantrans@ur@mmmxciv{بیشک میں تمہارے لئے امانت دار رسول (بن کر آیا) ہوں،\qt@no{162}}%
\qt@newcmd\qurantrans@ur@mmmxcv{پس تم اللہ سے ڈرو اور میری اطاعت اختیار کرو،\qt@no{163}}%
\qt@newcmd\qurantrans@ur@mmmxcvi{اور میں تم سے اس (تبلیغِ حق) پر کوئی اجرت طلب نہیں کرتا، میرا اجر تو صرف تمام جہانوں کے رب کے ذمہ ہے،\qt@no{164}}%
\qt@newcmd\qurantrans@ur@mmmxcvii{کیا تم سارے جہان والوں میں سے صرف مَردوں ہی کے پاس (اپنی شہوانی خواہشات پوری کرنے کے لئے) آتے ہو،\qt@no{165}}%
\qt@newcmd\qurantrans@ur@mmmxcviii{اور اپنی بیویوں کو چھوڑ دیتے ہو جو تمہارے رب نے تمہارے لئے پیدا کی ہیں، بلکہ تم (سرکشی میں) حد سے نکل جانے والے لوگ ہو،\qt@no{166}}%
\qt@newcmd\qurantrans@ur@mmmxcix{وہ بولے: اے لوط! اگر تم (ان باتوں سے) باز نہ آئے تو تم ضرور شہر بدر کئے جانے والوں میں سے ہو جاؤ گے،\qt@no{167}}%
\qt@newcmd\qurantrans@ur@mmmc{لوط علیہ السلام نے) فرمایا: بیشک میں تمہارے عمل سے بیزار ہونے والوں میں سے ہوں،\qt@no{168}}%
\qt@newcmd\qurantrans@ur@mmmci{اے رب! تو مجھے اور میرے گھر والوں کو اس (کام کے وبال) سے نجات عطا فرما جو یہ کر رہے ہیں،\qt@no{169}}%
\qt@newcmd\qurantrans@ur@mmmcii{پس ہم نے ان کو اور ان کے سب گھر والوں کو نجات عطا فرما دی،\qt@no{170}}%
\qt@newcmd\qurantrans@ur@mmmciii{سوائے ایک بوڑھی عورت کے جو پیچھے رہ جانے والوں میں تھی،\qt@no{171}}%
\qt@newcmd\qurantrans@ur@mmmciv{پھر ہم نے دوسروں کو ہلاک کر دیا،\qt@no{172}}%
\qt@newcmd\qurantrans@ur@mmmcv{اور ہم نے ان پر (پتھروں کی) بارش برسائی سو ڈرائے ہوئے لوگوں کی بارش کتنی تباہ کن تھی،\qt@no{173}}%
\qt@newcmd\qurantrans@ur@mmmcvi{بیشک اس (واقعہ) میں بڑی نشانی ہے اور ان کے اکثر لوگ مومن نہ تھے،\qt@no{174}}%
\qt@newcmd\qurantrans@ur@mmmcvii{اور بیشک آپ کا رب ہی بڑا غالب رحمت والا ہے،\qt@no{175}}%
\qt@newcmd\qurantrans@ur@mmmcviii{باشندگانِ ایکہ (یعنی جنگل کے رہنے والوں) نے (بھی) رسولوں کو جھٹلایا،\qt@no{176}}%
\qt@newcmd\qurantrans@ur@mmmcix{جب ان سے شعیب (علیہ السلام) نے فرمایا: کیا تم (اللہ سے) ڈرتے نہیں ہو،\qt@no{177}}%
\qt@newcmd\qurantrans@ur@mmmcx{بیشک میں تمہارے لئے امانت دار رسول (بن کر آیا) ہوں،\qt@no{178}}%
\qt@newcmd\qurantrans@ur@mmmcxi{پس تم اللہ سے ڈرو اور میری فرمانبرداری اختیار کرو،\qt@no{179}}%
\qt@newcmd\qurantrans@ur@mmmcxii{اور میں تم سے اس (تبلیغِ حق) پر کوئی اجرت نہیں مانگتا، میرا اجر تو صرف تمام جہانوں کے رب کے ذمہ ہے،\qt@no{180}}%
\qt@newcmd\qurantrans@ur@mmmcxiii{تم پیمانہ پورا بھرا کرو اور (لوگوں کے حقوق کو) نقصان پہنچانے والے نہ بنو،\qt@no{181}}%
\qt@newcmd\qurantrans@ur@mmmcxiv{اور سیدھی ترازو سے تولا کرو،\qt@no{182}}%
\qt@newcmd\qurantrans@ur@mmmcxv{اور لوگوں کو ان کی چیزیں کم (تول کے ساتھ) مت دیا کرو اور ملک میں (ایسی اخلاقی، مالی اور سماجی خیانتوں کے ذریعے) فساد انگیزی مت کرتے پھرو،\qt@no{183}}%
\qt@newcmd\qurantrans@ur@mmmcxvi{اور اس (اللہ) سے ڈرو جس نے تم کو اور پہلی امتوں کو پیدا فرمایا،\qt@no{184}}%
\qt@newcmd\qurantrans@ur@mmmcxvii{وہ کہنے لگے: (اے شعیب!) تم تو محض جادو زدہ لوگوں میں سے ہو،\qt@no{185}}%
\qt@newcmd\qurantrans@ur@mmmcxviii{اور تم فقط ہمارے جیسے بشر ہی تو ہو اور ہم تمہیں یقیناً جھوٹے لوگوں میں سے خیال کرتے ہیں،\qt@no{186}}%
\qt@newcmd\qurantrans@ur@mmmcxix{پس تم ہمارے اوپر آسمان کا کوئی ٹکڑا گرا دو اگر تم سچے ہو،\qt@no{187}}%
\qt@newcmd\qurantrans@ur@mmmcxx{شعیب علیہ السلام نے) فرمایا: میرا رب ان (کارستانیوں) کو خوب جاننے والا ہے جو تم انجام دے رہے ہو،\qt@no{188}}%
\qt@newcmd\qurantrans@ur@mmmcxxi{سو انہوں نے شعیب (علیہ السلام) کو جھٹلا دیا پس انہیں سائبان کے دن کے عذاب نے آپکڑا، بیشک وہ زبردست دن کا عذاب تھا،\qt@no{189}}%
\qt@newcmd\qurantrans@ur@mmmcxxii{بیشک اس (واقعہ) میں بڑی نشانی ہے اور ان کے اکثر لوگ مومن نہ تھے۔،\qt@no{190}}%
\qt@newcmd\qurantrans@ur@mmmcxxiii{اور بیشک آپ کا رب ہی بڑا غالب رحمت والا ہے،\qt@no{191}}%
\qt@newcmd\qurantrans@ur@mmmcxxiv{اور بیشک یہ (قرآن) سارے جہانوں کے رب کا نازل کردہ ہے،\qt@no{192}}%
\qt@newcmd\qurantrans@ur@mmmcxxv{اسے روح الامین (جبرائیل علیہ السلام) لے کر اترا ہے،\qt@no{193}}%
\qt@newcmd\qurantrans@ur@mmmcxxvi{آپ کے قلبِ (انور) پر تاکہ آپ (نافرمانوں کو) ڈر سنانے والوں میں سے ہو جائیں،\qt@no{194}}%
\qt@newcmd\qurantrans@ur@mmmcxxvii{اس کا نزول) فصیح عربی زبان میں (ہوا) ہے،\qt@no{195}}%
\qt@newcmd\qurantrans@ur@mmmcxxviii{اور بیشک یہ پہلی امتوں کے صحیفوں میں (بھی مذکور) ہے،\qt@no{196}}%
\qt@newcmd\qurantrans@ur@mmmcxxix{اور کیا ان کے لئے (صداقتِ قرآن اور صداقتِ نبوتِ محمدی صلی اللہ علیہ وآلہ وسلم کی) یہ دلیل (کافی) نہیں ہے کہ اسے بنی اسرائیل کے علماء (بھی) جانتے ہیں،\qt@no{197}}%
\qt@newcmd\qurantrans@ur@mmmcxxx{اور اگر ہم اسے غیر عربی لوگوں (یعنی عجمیوں) میں سے کسی پر نازل کرتے،\qt@no{198}}%
\qt@newcmd\qurantrans@ur@mmmcxxxi{سو وہ اس کو ان لوگوں پر پڑھتا تو (بھی) یہ لوگ اس پر ایمان لانے والے نہ ہوتے،\qt@no{199}}%
\qt@newcmd\qurantrans@ur@mmmcxxxii{اس طرح ہم نے اس (کے انکار) کو مجرموں کے دلوں میں پختگی سے داخل کر دیا ہے،\qt@no{200}}%
\qt@newcmd\qurantrans@ur@mmmcxxxiii{وہ اس پر ایمان نہیں لائیں گے یہاں تک کہ درد ناک عذاب دیکھ لیں،\qt@no{201}}%
\qt@newcmd\qurantrans@ur@mmmcxxxiv{پس وہ (عذاب) انہیں اچانک آپہنچے گا اور انہیں شعور (بھی) نہ ہوگا،\qt@no{202}}%
\qt@newcmd\qurantrans@ur@mmmcxxxv{تب وہ کہیں گے: کیا ہمیں مہلت دی جائے گی،\qt@no{203}}%
\qt@newcmd\qurantrans@ur@mmmcxxxvi{کیا یہ ہمارے عذاب میں جلدی کے طلب گار ہیں،\qt@no{204}}%
\qt@newcmd\qurantrans@ur@mmmcxxxvii{بھلا بتائیے اگر ہم انہیں برسوں فائدہ پہنچاتے رہیں،\qt@no{205}}%
\qt@newcmd\qurantrans@ur@mmmcxxxviii{پھر ان کے پاس وہ (عذاب) آپہنچے جس کا ان سے وعدہ کیا جار ہا ہے،\qt@no{206}}%
\qt@newcmd\qurantrans@ur@mmmcxxxix{تو) وہ چیزیں (ان سے عذاب کو دفع کرنے میں) کیا کام آئیں گی جن سے وہ فائدہ اٹھاتے رہے تھے،\qt@no{207}}%
\qt@newcmd\qurantrans@ur@mmmcxl{اور ہم نے سوائے ان (بستیوں) کے جن کے لئے ڈرانے والے (آچکے) تھے کسی بستی کو ہلاک نہیں کیا،\qt@no{208}}%
\qt@newcmd\qurantrans@ur@mmmcxli{اور یہ بھی) نصیحت کے لئے اور ہم ظالم نہ تھے،\qt@no{209}}%
\qt@newcmd\qurantrans@ur@mmmcxlii{اور شیطان اس (قرآن) کو لے کرنہیں اترے،\qt@no{210}}%
\qt@newcmd\qurantrans@ur@mmmcxliii{نہ (یہ) ان کے لئے سزاوار ہے اور نہ وہ (اس کی) طاقت رکھتے ہیں،\qt@no{211}}%
\qt@newcmd\qurantrans@ur@mmmcxliv{بیشک وہ (اس کلام کے) سننے سے روک دیئے گئے ہیں،\qt@no{212}}%
\qt@newcmd\qurantrans@ur@mmmcxlv{پس (اے بندے!) تو اللہ کے ساتھ کسی دوسرے معبود کو نہ پوجا کر ورنہ تو عذاب یافتہ لوگوں میں سے ہو جائے گا،\qt@no{213}}%
\qt@newcmd\qurantrans@ur@mmmcxlvi{اور (اے حبیبِ مکرّم!) آپ اپنے قریبی رشتہ داروں کو (ہمارے عذاب سے) ڈرائیے،\qt@no{214}}%
\qt@newcmd\qurantrans@ur@mmmcxlvii{اور آپ اپنا بازوئے (رحمت و شفقت) ان مومنوں کے لئے بچھا دیجئے جنہوں نے آپ کی پیروی اختیار کر لی ہے،\qt@no{215}}%
\qt@newcmd\qurantrans@ur@mmmcxlviii{پھر اگر وہ آپ کی نافرمانی کریں تو آپ فرما دیجئے کہ میں ان اعمالِ (بد) سے بیزار ہوں جو تم انجام دے رہے ہو،\qt@no{216}}%
\qt@newcmd\qurantrans@ur@mmmcxlix{اور بڑے غالب مہربان (رب) پر بھروسہ رکھیے،\qt@no{217}}%
\qt@newcmd\qurantrans@ur@mmmcl{جو آپ کو (رات کی تنہائیوں میں بھی) دیکھتا ہے جب آپ (نمازِ تہجد کے لئے) قیام کرتے ہیں،\qt@no{218}}%
\qt@newcmd\qurantrans@ur@mmmcli{اور سجدہ گزاروں میں (بھی) آپ کا پلٹنا دیکھتا (رہتا) ہے،\qt@no{219}}%
\qt@newcmd\qurantrans@ur@mmmclii{بیشک وہ خوب سننے والا جاننے والا ہے،\qt@no{220}}%
\qt@newcmd\qurantrans@ur@mmmcliii{کیا میں تمہیں بتاؤں کہ شیاطین کس پر اترتے ہیں،\qt@no{221}}%
\qt@newcmd\qurantrans@ur@mmmcliv{وہ ہر جھوٹے (بہتان طراز) گناہگار پر اترا کرتے ہیں،\qt@no{222}}%
\qt@newcmd\qurantrans@ur@mmmclv{جو سنی سنائی باتیں (ان کے کانوں میں) ڈال دیتے ہیں اور ان میں سے اکثر جھوٹے ہوتے ہیں،\qt@no{223}}%
\qt@newcmd\qurantrans@ur@mmmclvi{اور شاعروں کی پیروی بہکے ہوئے لوگ ہی کرتے ہیں،\qt@no{224}}%
\qt@newcmd\qurantrans@ur@mmmclvii{کیا تو نے نہیں دیکھا کہ وہ (شعراء) ہر وادئ (خیال) میں (یونہی) سرگرداں پھرتے رہتے ہیں (انہیں حق میں سچی دلچسپی اور سنجیدگی نہیں ہوتی بلکہ فقط لفظی و فکری جولانیوں میں مست اور خوش رہتے ہیں)،\qt@no{225}}%
\qt@newcmd\qurantrans@ur@mmmclviii{اور یہ کہ وہ (ایسی باتیں) کہتے ہیں جنہیں (خود) کرتے نہیں ہیں،\qt@no{226}}%
\qt@newcmd\qurantrans@ur@mmmclix{سوائے ان (شعراء) کے جو ایمان لائے اور نیک عمل کرتے رہے اور اللہ کو کثرت سے یاد کرتے رہے (یعنی اللہ اور رسول صلی اللہ علیہ وآلہ وسلم کے مدح خواں بن گئے) اور اپنے اوپر ظلم ہونے کے بعد (ظالموں سے بزبانِ شعر) انتقام لیا (اور اپنے کلام کے ذریعے اسلام اور مظلوموں کا دفاع کیا بلکہ ان کاجوش بڑھایا تو یہ شاعری مذموم نہیں)، اور وہ لوگ جنہوں نے ظلم کیا عنقریب جان لیں گے کہ وہ (مرنے کے بعد) کونسی پلٹنے کی جگہ پلٹ کر جاتے ہیں،\qt@no{227}}%
\qt@newcmd\qurantrans@ur@mmmclx{\basmalahur طا، سین (حقیقی معنی اﷲ اور رسول صلی اللہ علیہ وآلہ وسلم ہی بہتر جانتے ہیں)، یہ قرآن اور روشن کتاب کی آیتیں ہیں،\qt@no{1}}%
\qt@newcmd\qurantrans@ur@mmmclxi{جو) ہدایت ہے اور (ایسے) ایمان والوں کے لئے خوشخبری ہے،\qt@no{2}}%
\qt@newcmd\qurantrans@ur@mmmclxii{جو نماز قائم کرتے ہیں اور زکوٰۃ ادا کرتے ہیں اور وہی ہیں جو آخرت پر (بھی) یقین رکھتے ہیں،\qt@no{3}}%
\qt@newcmd\qurantrans@ur@mmmclxiii{بیشک جو لوگ آخرت پر ایمان نہیں رکھتے ہم نے ان کے اَعمالِ (بد ان کی نگاہوں میں) خوش نما کر دیئے ہیں سو وہ (گمراہی میں) سرگرداں رہتے ہیں،\qt@no{4}}%
\qt@newcmd\qurantrans@ur@mmmclxiv{یہی وہ لوگ ہیں جن کے لئے بُرا عذاب ہے اور یہی لوگ آخرت میں (سب سے) زیادہ نقصان اٹھانے والے ہیں،\qt@no{5}}%
\qt@newcmd\qurantrans@ur@mmmclxv{اور بیشک آپ کو (یہ) قرآن بڑے حکمت والے، علم والے (رب) کی طرف سے سکھایا جا رہا ہے،\qt@no{6}}%
\qt@newcmd\qurantrans@ur@mmmclxvi{وہ واقعہ یاد کریں) جب موسٰی (علیہ السلام) نے اپنی اہلیہ سے فرمایا کہ میں نے ایک آگ دیکھی ہے (یا مجھے ایک آگ میں شعلۂ انس و محبت نظر آیا ہے)، عنقریب میں تمہارے پاس اس میں سے کوئی خبر لاتا ہوں (جس کے لئے مدت سے دشت و بیاباں میں پھر رہے ہیں) یا تمہیں (بھی اس میں سے) کوئی چمکتا ہوا انگارا لا دیتا ہوں تاکہ تم (بھی اس کی حرارت سے) تپ اٹھو،\qt@no{7}}%
\qt@newcmd\qurantrans@ur@mmmclxvii{پھر جب وہ اس کے پاس آپہنچے تو آواز دی گئی کہ بابرکت ہے جو اس آگ میں (اپنے حجاب نور کی تجلی فرما رہا) ہے اور وہ (بھی) جو اس کے آس پاس (اُلوہی جلووں کے پرتَو میں) ہے، اور اللہ (ہر قسم کے جسم و مثال سے) پاک ہے جو سارے جہانوں کا رب ہے،\qt@no{8}}%
\qt@newcmd\qurantrans@ur@mmmclxviii{اے موسٰی! بیشک وہ (جلوہ فرمانے والا) میں ہی اللہ ہوں جو نہایت غالب حکمت والا ہے،\qt@no{9}}%
\qt@newcmd\qurantrans@ur@mmmclxix{اور (اے موسٰی!) اپنی لاٹھی (زمین پر) ڈال دو، پھر جب (موسٰی نے لاٹھی کو زمین پر ڈالنے کے بعد) اسے دیکھا کہ سانپ کی مانند تیز حرکت کر رہی ہے تو (فطری رد ِعمل کے طور پر) پیٹھ پھیر کر بھاگے اور پیچھے مڑ کر (بھی) نہ دیکھا، (ارشاد ہوا): اے موسٰی! خوف نہ کرو بیشک پیغمبر میرے حضور ڈرا نہیں کرتے،\qt@no{10}}%
\qt@newcmd\qurantrans@ur@mmmclxx{مگر جس نے ظلم کیا پھر برائی کے بعد (اسے) نیکی سے بدل دیا تو بیشک میں بڑا بخشنے والا نہایت مہربان ہوں،\qt@no{11}}%
\qt@newcmd\qurantrans@ur@mmmclxxi{اور تم اپنا ہاتھ اپنے گریبان کے اندر ڈالو وہ بغیر کسی عیب کے سفید چمک دار (ہو کر) نکلے گا، (یہ دونوں اللہ کی) نو نشانیوں میں (سے) ہیں (انہیں لے کر) فرعون اور اس کی قوم کے پاس جاؤ۔ بیشک وہ نافرمان قوم ہیں،\qt@no{12}}%
\qt@newcmd\qurantrans@ur@mmmclxxii{پھر جب ان کے پاس ہماری نشانیاں واضح اور روشن ہو کر پہنچ گئیں تو وہ کہنے لگے کہ یہ کھلا جادو ہے،\qt@no{13}}%
\qt@newcmd\qurantrans@ur@mmmclxxiii{اور انہوں نے ظلم اور تکبّر کے طور پر ان کا سراسر انکار کر دیا حالانکہ ان کے دل ان (نشانیوں کے حق ہونے) کا یقین کر چکے تھے۔ پس آپ دیکھئے کہ فساد بپا کرنے والوں کا کیسا (بُرا) انجام ہوا،\qt@no{14}}%
\qt@newcmd\qurantrans@ur@mmmclxxiv{اور بیشک ہم نے داؤد اور سلیمان (علیہما السلام) کو (غیر معمولی) علم عطا کیا، اور دونوں نے کہا کہ ساری تعریفیں اللہ ہی کے لئے ہیں جس نے ہمیں اپنے بہت سے مومن بندوں پر فضیلت بخشی ہے،\qt@no{15}}%
\qt@newcmd\qurantrans@ur@mmmclxxv{اور سلیمان (علیہ السلام)، داؤد (علیہ السلام) کے جانشین ہوئے اور انہوں نے کہا: اے لوگو! ہمیں پرندوں کی بولی (بھی) سکھائی گئی ہے اور ہمیں ہر چیز عطا کی گئی ہے۔ بیشک یہ (اللہ کا) واضح فضل ہے،\qt@no{16}}%
\qt@newcmd\qurantrans@ur@mmmclxxvi{اور سلیمان (علیہ السلام) کے لئے ان کے لشکر جنّوں اور انسانوں اور پرندوں (کی تمام جنسوں) میں سے جمع کئے گئے تھے، چنانچہ وہ بغرضِ نظم و تربیت (ان کی خدمت میں) روکے جاتے تھے،\qt@no{17}}%
\qt@newcmd\qurantrans@ur@mmmclxxvii{یہاں تک کہ جب وہ (لشکر) چیونٹیوں کے میدان پر پہنچے تو ایک چیونٹی کہنے لگی: اے چیونٹیو! اپنی رہائش گاہوں میں داخل ہو جاؤ کہیں سلیمان (علیہ السلام) اور ان کے لشکر تمہیں کچل نہ دیں اس حال میں کہ انہیں خبر بھی نہ ہو،\qt@no{18}}%
\qt@newcmd\qurantrans@ur@mmmclxxviii{تو وہ (یعنی سلیمان علیہ السلام) اس (چیونٹی) کی بات سے ہنسی کے ساتھ مسکرائے اور عرض کیا: اے پروردگار! مجھے اپنی توفیق سے اس بات پر قائم رکھ کہ میں تیری اس نعمت کا شکر بجا لاتا رہوں جو تو نے مجھ پر اور میرے والدین پر انعام فرمائی ہے اور میں ایسے نیک عمل کرتا رہوں جن سے تو راضی ہوتا ہے اور مجھے اپنی رحمت سے اپنے خاص قرب والے نیکوکار بندوں میں داخل فرما لے،\qt@no{19}}%
\qt@newcmd\qurantrans@ur@mmmclxxix{اور سلیمان (علیہ السلام) نے پرندوں کا جائزہ لیا تو کہنے لگے: مجھے کیا ہوا ہے کہ میں ہدہد کو نہیں دیکھ پا رہا یا وہ (واقعی) غائب ہو گیا ہے،\qt@no{20}}%
\qt@newcmd\qurantrans@ur@mmmclxxx{میں اسے (بغیر اجازت غائب ہونے پر) ضرور سخت سزا دوں گا یا اسے ضرور ذبح کر ڈالوں گا یا وہ میرے پاس (اپنے بے قصور ہونے کی) واضح دلیل لائے گا،\qt@no{21}}%
\qt@newcmd\qurantrans@ur@mmmclxxxi{پس وہ تھوڑی ہی دیر (باہر) ٹھہرا تھا کہ اس نے (حاضر ہو کر) عرض کیا: مجھے ایک ایسی بات معلوم ہوئی ہے جس پر (شاید) آپ مطلع نہ تھے اور میں آپ کے پاس (ملکِ) سبا سے ایک یقینی خبر لایا ہوں،\qt@no{22}}%
\qt@newcmd\qurantrans@ur@mmmclxxxii{میں نے (وہاں) ایک ایسی عورت کو پایا ہے جو ان (یعنی ملکِ سبا کے باشندوں) پر حکومت کرتی ہے اور اسے (ملکیت و اقتدار میں) ہر ایک چیز بخشی گئی ہے اور اس کے پاس بہت بڑا تخت ہے،\qt@no{23}}%
\qt@newcmd\qurantrans@ur@mmmclxxxiii{میں نے اسے اور اس کی قوم کو اللہ کی بجائے سورج کو سجدہ کرتے پایا ہے اور شیطان نے ان کے اَعمالِ (بد) ان کے لئے خوب خوش نما بنا دیئے ہیں اور انہیں (توحید کی) راہ سے روک دیا ہے سو وہ ہدایت نہیں پا رہے،\qt@no{24}}%
\qt@newcmd\qurantrans@ur@mmmclxxxiv{اس لئے (روکے گئے ہیں) کہ وہ اس اللہ کے حضور سجدہ ریز نہ ہوں جو آسمانوں اور زمین میں پوشیدہ (حقائق اور موجودات) کو باہر نکالتا (یعنی ظاہر کرتا) ہے اور ان (سب) چیزوں کو جانتا ہے جسے تم چھپاتے ہو اور جسے تم آشکار کرتے ہو،\qt@no{25}}%
\qt@newcmd\qurantrans@ur@mmmclxxxv{اللہ کے سوا کوئی لائقِ عبادت نہیں (وہی) عظیم تختِ اقتدار کا مالک ہے،\qt@no{26}}%
\qt@newcmd\qurantrans@ur@mmmclxxxvi{سلیمان علیہ السلام نے) فرمایا: ہم ابھی دیکھتے ہیں کیا تو سچ کہہ رہا ہے یا توجھوٹ بولنے والوں سے ہے،\qt@no{27}}%
\qt@newcmd\qurantrans@ur@mmmclxxxvii{میرا یہ خط لے جا اور اسے ان کی طرف ڈال دے پھر ان کے پاس سے ہٹ آپھر دیکھ وہ کس بات کی طرف رجوع کرتے ہیں،\qt@no{28}}%
\qt@newcmd\qurantrans@ur@mmmclxxxviii{ملکہ نے) کہا: اے سردارو! میری طرف ایک نامۂ بزرگ ڈالا گیا ہے،\qt@no{29}}%
\qt@newcmd\qurantrans@ur@mmmclxxxix{بیشک وہ (خط) سلیمان (علیہ السلام) کی جانب سے (آیا) ہے اور وہ اللہ کے نام سے شروع (کیا گیا) ہے جو بے حد مہربان بڑا رحم فرمانے والا ہے،\qt@no{30}}%
\qt@newcmd\qurantrans@ur@mmmcxc{اس کامضمون یہ ہے) کہ تم لوگ مجھ پر سربلندی (کی کوشش) مت کرو اور فرمانبردار ہو کر میرے پاس آجاؤ،\qt@no{31}}%
\qt@newcmd\qurantrans@ur@mmmcxci{ملکہ نے) کہا: اے دربار والو! تم مجھے میرے (اس) معاملہ میں مشورہ دو، میں کسی کام کا قطعی فیصلہ کرنے والی نہیں ہوں یہاں تک کہ تم میرے پاس حاضر ہو کر (اس اَمر کے موافق یا مخالف) گواہی دو،\qt@no{32}}%
\qt@newcmd\qurantrans@ur@mmmcxcii{انہوں نے کہا: ہم طاقتور اور سخت جنگ جُو ہیں مگر حکم آپ کے اختیار میں ہے سو آپ (خود ہی) غور کر لیں کہ آپ کیا حکم دیتی ہیں،\qt@no{33}}%
\qt@newcmd\qurantrans@ur@mmmcxciii{ملکہ نے) کہا: بیشک جب بادشاہ کسی بستی میں داخل ہوتے ہیں تواسے تباہ و برباد کر دیتے ہیں اور وہاں کے باعزت لوگوں کو ذلیل و رسوا کر ڈالتے ہیں اور یہ (لوگ بھی) اسی طرح کریں گے،\qt@no{34}}%
\qt@newcmd\qurantrans@ur@mmmcxciv{اور بیشک میں ان کی طرف کچھ تحفہ بھیجنے والی ہوں پھر دیکھتی ہوں قاصد کیا جواب لے کر واپس لوٹتے ہیں،\qt@no{35}}%
\qt@newcmd\qurantrans@ur@mmmcxcv{سو جب وہ (قاصد) سلیمان (علیہ السلام) کے پاس آیا (تو سلیمان علیہ السلام نے اس سے) فرمایا: کیا تم لوگ مال و دولت سے میری مدد کرنا چاہتے ہو۔ سو جو کچھ اللہ نے مجھے عطا فرمایا ہے اس (دولت) سے بہتر ہے جو اس نے تمہیں عطا کی ہے بلکہ تم ہی ہو جو اپنے تحفہ سے فرحاں (اور) نازاں ہو،\qt@no{36}}%
\qt@newcmd\qurantrans@ur@mmmcxcvi{تو ان کے پاس (تحفہ سمیت) واپس پلٹ جا سو ہم ان پر ایسے لشکروں کے ساتھ (حملہ کرنے) آئیں گے جن سے انہیں مقابلہ (کی طاقت) نہیں ہوگی اور ہم انہیں وہاں سے بے عزت کر کے اس حال میں نکالیں گے کہ وہ (قیدی بن کر) رسوا ہوں گے،\qt@no{37}}%
\qt@newcmd\qurantrans@ur@mmmcxcvii{سلیمان علیہ السلام نے) فرمایا: اے دربار والو! تم میں سے کون اس (ملکہ) کا تخت میرے پاس لا سکتا ہے قبل اس کے کہ وہ لوگ فرمانبردار ہو کر میرے پاس آجائیں،\qt@no{38}}%
\qt@newcmd\qurantrans@ur@mmmcxcviii{ایک قوی ہیکل جِن نے عرض کیا: میں اسے آپ کے پاس لاسکتا ہوں قبل اس کے کہ آپ اپنے مقام سے اٹھیں اور بیشک میں اس (کے لانے) پر طاقتور (اور) امانت دار ہوں،\qt@no{39}}%
\qt@newcmd\qurantrans@ur@mmmcxcix{پھر) ایک ایسے شخص نے عرض کیا جس کے پاس (آسمانی) کتاب کا کچھ علم تھا کہ میں اسے آپ کے پاس لا سکتا ہوں قبل اس کے کہ آپ کی نگاہ آپ کی طرف پلٹے (یعنی پلک جھپکنے سے بھی پہلے)، پھر جب (سلیمان علیہ السلام نے) اس (تخت) کو اپنے پاس رکھا ہوا دیکھا (تو) کہا: یہ میرے رب کا فضل ہے تاکہ وہ مجھے آزمائے کہ آیا میں شکر گزاری کرتا ہوں یا نا شکری، اور جس نے (اللہ کا) شکر ادا کیا سو وہ محض اپنی ہی ذات کے فائدہ کے لئے شکر مندی کرتا ہے اور جس نے ناشکری کی تو بیشک میرا رب بے نیاز، کرم فرمانے والا ہے،\qt@no{40}}%
\qt@newcmd\qurantrans@ur@mmmcc{سلیمان علیہ السلام نے) فرمایا: اس(ملکہ کے امتحان) کے لئے اس کے تخت کی صورت اور ہیئت بدل دو ہم دیکھیں گے کہ آیا وہ (پہچان کی) راہ پاتی ہے یا ان میں سے ہوتی ہے جو سوجھ بوجھ نہیں رکھتے،\qt@no{41}}%
\qt@newcmd\qurantrans@ur@mmmcci{پھر جب وہ (ملکہ) آئی تو اس سے کہا گیا: کیا تمہارا تخت اسی طرح کا ہے، وہ کہنے لگی: گویا یہ وہی ہے اور ہمیں اس سے پہلے ہی (نبوتِ سلیمان کے حق ہونے کا) علم ہو چکا تھا اور ہم مسلمان ہو چکے ہیں،\qt@no{42}}%
\qt@newcmd\qurantrans@ur@mmmccii{اور اس (ملکہ) کو اس (معبودِ باطل) نے (پہلے قبولِ حق سے) روک رکھا تھا جس کی وہ اللہ کے سوا پرستش کرتی رہی تھی۔ بیشک وہ کافروں کی قوم میں سے تھی،\qt@no{43}}%
\qt@newcmd\qurantrans@ur@mmmcciii{اس (ملکہ) سے کہا گیا: اس محل کے صحن میں داخل ہو جا (جس کے نیچے نیلگوں پانی کی لہریں چلتی تھیں)، پھر جب ملکہ نے اس (مزیّن بلوریں فرش) کو دیکھا تو اسے گہرے پانی کا تالاب سمجھا اور اس نے (پائینچے اٹھا کر) اپنی دونوں پنڈلیاں کھول دیں، سلیمان (علیہ السلام) نے فرمایا: یہ تو محل کا شیشوں جڑا صحن ہے، اس (ملکہ) نے عرض کیا: اے میرے پروردگار! (میں اسی طرح فریبِ نظر میں مبتلا تھی) بیشک میں نے اپنی جان پر ظلم کیا اور اب میں سلیمان (علیہ السلام) کی معیّت میں اس اللہ کی فرمانبردار ہو گئی ہوں جو تمام جہانوں کا رب ہے،\qt@no{44}}%
\qt@newcmd\qurantrans@ur@mmmcciv{اور بیشک ہم نے قومِ ثمود کے پاس ان کے (قومی) بھائی صالح (علیہ السلام) کو (پیغمبر بنا کر) بھیجا کہ تم لوگ اللہ کی عبادت کرو تو اس وقت وہ دو فرقے ہو گئے جو آپس میں جھگڑتے تھے،\qt@no{45}}%
\qt@newcmd\qurantrans@ur@mmmccv{صالح علیہ السلام نے) فرمایا: اے میری قوم! تم لوگ بھلائی (یعنی رحمت) سے پہلے برائی (یعنی عذاب) میں کیوں جلدی چاہتے ہو؟ تم اللہ سے بخشش کیوں طلب نہیں کرتے تاکہ تم پر رحم کیا جائے،\qt@no{46}}%
\qt@newcmd\qurantrans@ur@mmmccvi{وہ کہنے لگے: ہمیں تم سے (بھی) نحوست پہنچی ہے اور ان لوگوں سے (بھی) جو تمہارے ساتھ ہیں۔ (صالح علیہ السلام نے) فرمایا: تمہاری نحوست (کا سبب) اللہ کے پاس (لکھا ہوا) ہے بلکہ تم لوگ فتنہ میں مبتلا کئے گئے ہو،\qt@no{47}}%
\qt@newcmd\qurantrans@ur@mmmccvii{اور (قومِ ثمود کے) شہر میں نو سرکردہ لیڈر (جو اپنی اپنی جماعتوں کے سربراہ) تھے ملک میں فساد پھیلاتے تھے اور اصلاح نہیں کرتے تھے،\qt@no{48}}%
\qt@newcmd\qurantrans@ur@mmmccviii{ان سرغنوں نے) کہا: تم آپس میں اللہ کی قسم کھا کر عہد کرو کہ ہم ضرور رات کو صالح (علیہ السلام) اور اس کے گھر والوں پر قاتلانہ حملہ کریں گے پھر ان کے وارثوں سے کہہ دیں گے کہ ہم ان کی ہلاکت کے موقع پر حاضر ہی نہ تھے اور بیشک ہم سچے ہیں،\qt@no{49}}%
\qt@newcmd\qurantrans@ur@mmmccix{اور انہوں نے خفیہ سازش کی اور ہم نے (بھی اس کے توڑ کے لئے) خفیہ تدبیر فرمائی اور انہیں خبر بھی نہ ہوئی،\qt@no{50}}%
\qt@newcmd\qurantrans@ur@mmmccx{تو آپ دیکھئے کہ ان کی (مکارانہ) سازش کا انجام کیسا ہوا، بیشک ہم نے ان (سرداروں) کو اور ان کی ساری قوم کو تباہ و برباد کر دیا،\qt@no{51}}%
\qt@newcmd\qurantrans@ur@mmmccxi{سو یہ ان کے گھر ویران پڑے ہیں اس لئے کہ انہوں نے ظلم کیا تھا۔ بیشک اس میں اس قوم کے لئے (عبرت کی) نشانی ہے جو علم رکھتے ہیں،\qt@no{52}}%
\qt@newcmd\qurantrans@ur@mmmccxii{اور ہم نے ان لوگوں کو نجات بخشی جو ایمان لائے اور تقوٰی شعار ہوئے،\qt@no{53}}%
\qt@newcmd\qurantrans@ur@mmmccxiii{اور لوط (علیہ السلام) کو (یاد کریں) جب انہوں نے اپنی قوم سے فرمایا: کیا تم بے حیائی کا ارتکاب کرتے ہو حالانکہ تم دیکھتے (بھی) ہو،\qt@no{54}}%
\qt@newcmd\qurantrans@ur@mmmccxiv{کیا تم اپنی نفسانی خواہش پوری کرنے کے لئے عورتوں کو چھوڑ کر مَردوں کے پاس جاتے ہو بلکہ تم جاہل لوگ ہو،\qt@no{55}}%
\qt@newcmd\qurantrans@ur@mmmccxv{تو ان کی قوم کا جواب اس کے سوا کچھ نہ تھا کہ وہ کہنے لگے: تم لوط کے گھر والوں کو اپنی بستی سے نکال دو یہ بڑے پاک باز بنتے ہیں،\qt@no{56}}%
\qt@newcmd\qurantrans@ur@mmmccxvi{پس ہم نے لوط (علیہ السلام) کو اور ان کے گھر والوں کو نجات بخشی سوائے ان کی بیوی کے کہ ہم نے اسے (عذاب کے لئے) پیچھے رہ جانے والوں میں سے مقرر کر لیا تھا،\qt@no{57}}%
\qt@newcmd\qurantrans@ur@mmmccxvii{اور ہم نے ان پر خوب (پتھروں کی) بارش برسائی، سو (ان) ڈرائے گئے لوگوں پر (پتھروں کی) بارش نہایت ہی بری تھی۔،\qt@no{58}}%
\qt@newcmd\qurantrans@ur@mmmccxviii{فرما دیجئے کہ تمام تعریفیں اللہ ہی کے لئے ہیں اور اس کے منتخب (برگزیدہ) بندوں پر سلامتی ہو، کیا اللہ ہی بہتر ہے یا وہ (معبودانِ باطلہ) جنہیں یہ لوگ (اس کا) شریک ٹھہراتے ہیں،\qt@no{59}}%
\qt@newcmd\qurantrans@ur@mmmccxix{بلکہ وہ کون ہے جس نے آسمانوں اور زمین کو پیدا فرمایا اور تمہارے لئے آسمانی فضا سے پانی اتارا، پھر ہم نے اس (پانی) سے تازہ اور خوش نما باغات اُگائے؟ تمہارے لئے ممکن نہ تھا کہ تم ان (باغات) کے درخت اُگا سکتے۔ کیا اللہ کے ساتھ کوئی (اور بھی) معبود ہے؟ بلکہ یہ وہ لوگ ہیں جو (راہِ حق سے) پرے ہٹ رہے ہیں،\qt@no{60}}%
\qt@newcmd\qurantrans@ur@mmmccxx{بلکہ وہ کون ہے جس نے زمین کو قرار گاہ بنایا اور اس کے درمیان نہریں بنائیں اور اس کے لئے بھاری پہاڑ بنائے۔ اور (کھاری اور شیریں) دو سمندروں کے درمیان آڑ بنائی؟ کیا اللہ کے ساتھ کوئی (اور بھی) معبود ہے؟ بلکہ ان (کفار) میں سے اکثر لوگ بے علم ہیں،\qt@no{61}}%
\qt@newcmd\qurantrans@ur@mmmccxxi{بلکہ وہ کون ہے جو بے قرار شخص کی دعا قبول فرماتا ہے جب وہ اسے پکارے اور تکلیف دور فرماتا ہے اور تمہیں زمین میں(پہلے لوگوں کا) وارث و جانشین بناتا ہے؟ کیا اللہ کے ساتھ کوئی (اور بھی) معبود ہے؟ تم لوگ بہت ہی کم نصیحت قبول کرتے ہو،\qt@no{62}}%
\qt@newcmd\qurantrans@ur@mmmccxxii{بلکہ وہ کون ہے جو تمہیں خشک و تر (یعنی زمین اور سمندر) کی تاریکیوں میں راستہ دکھاتا ہے اور جو ہواؤں کو اپنی (بارانِ) رحمت سے پہلے خوشخبری بنا کر بھیجتا ہے؟ کیا اللہ کے ساتھ کوئی (اور بھی) معبود ہے؟ اللہ ان (معبودانِ باطلہ) سے برتر ہے جنہیں وہ شریک ٹھہراتے ہیں،\qt@no{63}}%
\qt@newcmd\qurantrans@ur@mmmccxxiii{بلکہ وہ کون ہے جو مخلوق کو پہلی بار پیدا فرماتا ہے پھر اسی (عملِ تخلیق) کو دہرائے گا اور جو تمہیں آسمان و زمین سے رزق عطا فرماتا ہے؟ کیا اللہ کے ساتھ کوئی (اور بھی)معبود ہے؟ فرما دیجئے: (اے مشرکو!) اپنی دلیل پیش کرو اگر تم سچے ہو،\qt@no{64}}%
\qt@newcmd\qurantrans@ur@mmmccxxiv{فرمادیجئے کہ جو لوگ آسمانوں اور زمین میں ہیں (اَز خود) غیب کا علم نہیں رکھتے سوائے اللہ کے (وہ عالم بالذّات ہے) اور نہ ہی وہ یہ خبر رکھتے ہیں کہ وہ (دوبارہ زندہ کر کے) کب اٹھائے جائیں گے،\qt@no{65}}%
\qt@newcmd\qurantrans@ur@mmmccxxv{بلکہ آخرت کے بارے میں ان کا علم (اپنی) انتہاء کو پہنچ کر منقطع ہوگیا، مگر وہ اس سے متعلق محض شک میں ہی (مبتلاء) ہیں، بلکہ وہ اس (کے علمِ قطعی) سے اندھے ہیں،\qt@no{66}}%
\qt@newcmd\qurantrans@ur@mmmccxxvi{اور کافر لوگ کہتے ہیں: کیا جب ہم اور ہمارے باپ دادا (مَر کر) مٹی ہوجائیں گے تو کیا ہم (پھر زندہ کر کے قبروں میں سے) نکالے جائیں گے،\qt@no{67}}%
\qt@newcmd\qurantrans@ur@mmmccxxvii{درحقیقت اس کا وعدہ ہم سے (بھی) کیا گیا اور اس سے پہلے ہمارے باپ دادا سے (بھی)، یہ اگلے لوگوں کے من گھڑت افسانوں کے سوا کچھ نہیں،\qt@no{68}}%
\qt@newcmd\qurantrans@ur@mmmccxxviii{فرما دیجئے: تم زمین میں سیر و سیاحت کرو پھر دیکھو مجرموں کا انجام کیسا ہوا،\qt@no{69}}%
\qt@newcmd\qurantrans@ur@mmmccxxix{اور (اے حبیبِ مکرّم!) آپ ان (کی باتوں) پر غم زدہ نہ ہوا کریں اور نہ اس مکر و فریب کے باعث جو وہ کر رہے ہیں تنگ دلی میں (مبتلاء) ہوں،\qt@no{70}}%
\qt@newcmd\qurantrans@ur@mmmccxxx{اور وہ کہتے ہیں کہ اگر تم سچے ہو تو (بتاؤ) یہ (عذابِ آخرت کا) وعدہ کب پورا ہوگا،\qt@no{71}}%
\qt@newcmd\qurantrans@ur@mmmccxxxi{فرما دیجئے: کچھ بعید نہیں کہ اس (عذاب) کا کچھ حصہ تمہارے نزدیک ہی آپہنچا ہو جسے تم بہت جلد طلب کر رہے ہو،\qt@no{72}}%
\qt@newcmd\qurantrans@ur@mmmccxxxii{اور بیشک آپ کا رب لوگوں پر فضل (فرمانے) والا ہے لیکن ان میں سے اکثر لوگ شکر نہیں کرتے،\qt@no{73}}%
\qt@newcmd\qurantrans@ur@mmmccxxxiii{اور بیشک آپ کا رب ان (باتوں) کو ضرور جانتا ہے جو ان کے سینے (اندر) چھپائے ہوئے ہیں اور (ان باتوں کو بھی) جو یہ آشکار کرتے ہیں،\qt@no{74}}%
\qt@newcmd\qurantrans@ur@mmmccxxxiv{اور آسمان اور زمین میں کوئی (بھی) پوشیدہ چیز نہیں ہے مگر (وہ) روشن کتاب (لوح ِمحفوظ) میں (درج) ہے،\qt@no{75}}%
\qt@newcmd\qurantrans@ur@mmmccxxxv{بیشک یہ قرآن بنی اسرائیل کے سامنے وہ بیشتر چیزیں بیان کرتا ہے جن میں وہ اختلاف کرتے ہیں،\qt@no{76}}%
\qt@newcmd\qurantrans@ur@mmmccxxxvi{اور بیشک یہ ہدایت ہے اور مومنوں کے لئے رحمت ہے،\qt@no{77}}%
\qt@newcmd\qurantrans@ur@mmmccxxxvii{اور بیشک آپ کا رب ان (مومنوں اور کافروں) کے درمیان اپنے حکم (عدل) سے فیصلہ فرمائے گا، اور وہ غالب ہے بہت جاننے والا ہے،\qt@no{78}}%
\qt@newcmd\qurantrans@ur@mmmccxxxviii{پس آپ اللہ پر بھروسہ کریں بیشک آپ صریح حق پر (قائم اور فائز) ہیں،\qt@no{79}}%
\qt@newcmd\qurantrans@ur@mmmccxxxix{بیشک آپ نہ (تو حیاتِ ایمانی سے محروم) مُردوں کو (حق کی بات) سنا سکتے ہیں اور نہ ہی (ایسے) بہروں کو (ہدایت کی) پکار سنا سکتے ہیں جبکہ وہ (غلبۂ کفر کے باعث ہدایت سے) پیٹھ پھیر کر (قبولِ حق سے) رُوگرداں ہو رہے ہوں،\qt@no{80}}%
\qt@newcmd\qurantrans@ur@mmmccxl{اور نہ ہی آپ (دل کے) اندھوں کو ان کی گمراہی سے (بچا کر) ہدایت دینے والے ہیں، آپ تو (فی الحقیقت) انہی کو سناتے ہیں جو (آپ کی دعوت قبول کر کے) ہماری آیتوں پر ایمان لے آتے ہیں سو وہی لوگ مسلمان ہیں (اور وہی زندہ کہلانے کے حق دار ہیں)،\qt@no{81}}%
\qt@newcmd\qurantrans@ur@mmmccxli{اور جب ان پر (عذاب کا) فرمان پورا ہونے کا وقت آجائے گا تو ہم ان کے لئے زمین سے ایک جانور نکالیں گے جو ان سے گفتگو کرے گا کیونکہ لوگ ہماری نشانیوں پر یقین نہیں کرتے تھے،\qt@no{82}}%
\qt@newcmd\qurantrans@ur@mmmccxlii{اور جس دن ہم ہر امت میں سے ان لوگوں کا (ایک ایک) گروہ جمع کریں گے جو ہماری آیتوں کو جھٹلاتے تھے سو وہ (اکٹھا چلنے کے لئے آگے کی طرف سے) روکے جائیں گے،\qt@no{83}}%
\qt@newcmd\qurantrans@ur@mmmccxliii{یہاں تک کہ جب وہ سب (مقامِ حساب پر) آپہنچیں گے تو ارشاد ہوگا کیا تم (بغیر غور و فکر کے) میری آیتوں کو جھٹلاتے تھے حالانکہ تم (اپنے ناقص) علم سے انہیں کاملاً جان بھی نہیں سکے تھے یا (تم خود ہی بتاؤ) اس کے علاوہ اور کیا (سبب) تھا جو تم (حق کی تکذیب) کیا کرتے تھے،\qt@no{84}}%
\qt@newcmd\qurantrans@ur@mmmccxliv{اور ان پر (ہمارا) وعدہ پورا ہوچکا اس وجہ سے کہ وہ ظلم کر تے رہے سو وہ (جواب میں) کچھ بول نہ سکیں گے،\qt@no{85}}%
\qt@newcmd\qurantrans@ur@mmmccxlv{کیا انہوں نے نہیں دیکھا کہ ہم نے رات بنائی تاکہ وہ اس میں آرام کرسکیں اور دن کو (امورِ حیات کی نگرانی کے لئے) روشن (یعنی اشیاء کو دِکھانے اور سُجھانے والا) بنایا، بیشک اس میں ان لوگوں کے لئے نشانیاں ہیں جو ایمان رکھتے ہیں،\qt@no{86}}%
\qt@newcmd\qurantrans@ur@mmmccxlvi{اور جس دن صُور پھونکا جائے گا تو وہ (سب لوگ) گھبرا جائیں گے جو آسمانوں میں ہیں اور جو زمین میں ہیں مگر جنہیں اللہ چاہے گا (نہیں گھبرائیں گے)، اور سب اس کی بارگاہ میں عاجزی کرتے ہوئے حاضر ہوں گے،\qt@no{87}}%
\qt@newcmd\qurantrans@ur@mmmccxlvii{اور (اے انسان!) تو پہاڑوں کو دیکھے گا تو خیال کرے گا کہ جمے ہوئے ہیں حالانکہ وہ بادل کے اڑنے کی طرح اڑ رہے ہوں گے۔ (یہ) اللہ کی کاریگری ہے جس نے ہر چیز کو (حکمت و تدبیر کے ساتھ) مضبوط و مستحکم بنا رکھا ہے۔ بیشک وہ ان سب (کاموں) سے خبردار ہے جو تم کرتے ہو،\qt@no{88}}%
\qt@newcmd\qurantrans@ur@mmmccxlviii{جو شخص (اس دن) نیکی لے کر آئے گا اس کے لئے اس سے بہتر (جزا) ہوگی اور وہ لوگ اس دن گھبراہٹ سے محفوظ و مامون ہوں گے،\qt@no{89}}%
\qt@newcmd\qurantrans@ur@mmmccxlix{اور جو شخص برائی لے کر آئے گا تو ان کے منہ (دوزخ کی) آگ میں اوندھے ڈالے جائیں گے۔ بس تمہیں وہی بدلہ دیا جائے گا جو تم کیا کرتے تھے،\qt@no{90}}%
\qt@newcmd\qurantrans@ur@mmmccl{آپ ان سے فرما دیجئے کہ) مجھے تو یہی حکم دیا گیا ہے کہ اس شہرِ (مکّہ) کے رب کی عبادت کروں جس نے اسے عزت و حُرمت والا بنایا ہے اور ہر چیز اُسی کی (مِلک) ہے اور مجھے (یہ) حکم (بھی) دیا گیا ہے کہ میں (اللہ کے) فرمانبرداروں میں رہوں،\qt@no{91}}%
\qt@newcmd\qurantrans@ur@mmmccli{نیز یہ کہ میں قرآن پڑھ کر سناتا رہوں سو جس شخص نے ہدایت قبول کی تو اس نے اپنے ہی فائدہ کے لئے راہِ راست اختیار کی، اور جو بہکا رہا تو آپ فرما دیں کہ میں تو صِرف ڈر سنانے والوں میں سے ہوں،\qt@no{92}}%
\qt@newcmd\qurantrans@ur@mmmcclii{اور آپ فرمادیجئے کہ تمام تعریفیں اللہ ہی کے لئے ہیں وہ عنقریب تمہیں اپنی نشانیاں دکھا دے گا سو تم انہیں پہچان لو گے، اور آپ کا رب ان کاموں سے بے خبر نہیں جو تم انجام دیتے ہو،\qt@no{93}}%
\qt@newcmd\qurantrans@ur@mmmccliii{\basmalahur طا، سین، میم (حقیقی معنی اللہ اور رسول صلی اللہ علیہ وآلہ وسلم ہی بہتر جانتے ہیں)،\qt@no{1}}%
\qt@newcmd\qurantrans@ur@mmmccliv{یہ روشن کتاب کی آیتیں ہیں،\qt@no{2}}%
\qt@newcmd\qurantrans@ur@mmmcclv{اے حبیبِ مکرّم!) ہم آپ پر موسٰی (علیہ السلام) اور فرعون کے حقیقت پر مبنی حال میں سے ان لوگوں کے لئے کچھ پڑھ کر سناتے ہیں جو ایمان رکھتے ہیں،\qt@no{3}}%
\qt@newcmd\qurantrans@ur@mmmcclvi{بیشک فرعون زمین میں سرکش و متکبّر (یعنی آمرِ مطلق) ہوگیا تھا اور اس نے اپنے (ملک کے) باشندوں کو (مختلف) فرقوں (اور گروہوں) میں بانٹ دیا تھا اس نے ان میں سے ایک گروہ (یعنی بنی اسرائیل کے عوام) کو کمزور کردیا تھا کہ ان کے لڑکوں کو (ان کے مستقبل کی طاقت کچلنے کے لئے) ذبح کر ڈالتا اور ان کی عورتوں کو زندہ چھوڑ دیتا (تاکہ مَردوں کے بغیر ان کی تعداد بڑھے اور ان میں اخلاقی بے راہ روی کا اضافہ ہو)، بیشک وہ فساد انگیز لوگوں میں سے تھا،\qt@no{4}}%
\qt@newcmd\qurantrans@ur@mmmcclvii{اور ہم چاہتے تھے کہ ہم ایسے لوگوں پر احسان کریں جو زمین میں (حقوق اور آزادی سے محرومی اور ظلم و استحصال کے باعث) کمزور کر دیئے گئے تھے اور انہیں (مظلوم قوم کے) رہبر و پیشوا بنا دیں اور انہیں (ملکی تخت کا) وارث بنا دیں،\qt@no{5}}%
\qt@newcmd\qurantrans@ur@mmmcclviii{اور ہم انہیں ملک میں حکومت و اقتدار بخشیں اور فرعون اور ہامان اور ان دونوں کی فوجوں کو وہ (انقلاب) دکھا دیں جس سے وہ ڈرا کرتے تھے،\qt@no{6}}%
\qt@newcmd\qurantrans@ur@mmmcclix{اور ہم نے موسٰی (علیہ السلام) کی والدہ کے دل میں یہ بات ڈالی کہ تم انہیں دودھ پلاتی رہو، پھر جب تمہیں ان پر (قتل کردیئے جانے کا) اندیشہ ہو جائے تو انہیں دریا میں ڈال دینا اور نہ تم (اس صورتِ حال سے) خوفزدہ ہونا اور نہ رنجیدہ ہونا، بیشک ہم انہیں تمہاری طرف واپس لوٹانے والے ہیں اور انہیں رسولوں میں(شامل) کرنے والے ہیں۔،\qt@no{7}}%
\qt@newcmd\qurantrans@ur@mmmcclx{پھر فرعون کے گھر والوں نے انہیں (دریا سے) اٹھا لیا تاکہ وہ (مشیّتِ الٰہی سے) ان کے لئے دشمن اور (باعثِ) غم ثابت ہوں، بیشک فرعون اور ہامان اور ان دونوں کی فوجیں سب خطاکار تھے،\qt@no{8}}%
\qt@newcmd\qurantrans@ur@mmmcclxi{اور فرعون کی بیوی نے (موسٰی علیہ السلام کو دیکھ کر) کہا کہ (یہ بچہ) میری اور تیری آنکھ کے لئے ٹھنڈک ہے۔ اسے قتل نہ کرو، شاید یہ ہمیں فائدہ پہنچائے یا ہم اس کو بیٹا بنالیں اور وہ (اس تجویز کے انجام سے) بے خبر تھے،\qt@no{9}}%
\qt@newcmd\qurantrans@ur@mmmcclxii{اور موسٰی (علیہ السلام) کی والدہ کا دل (صبر سے) خالی ہوگیا، قریب تھا کہ وہ (اپنی بے قراری کے باعث) اس راز کو ظاہر کردیتیں اگر ہم ان کے دل پر صبر و سکون کی قوّت نہ اتارتے تاکہ وہ (وعدۂ الٰہی پر) یقین رکھنے والوں میں سے رہیں،\qt@no{10}}%
\qt@newcmd\qurantrans@ur@mmmcclxiii{اور (موسٰی علیہ السلام کی والدہ نے) ان کی بہن سے کہا کہ (ان کا حال معلوم کرنے کے لئے) ان کے پیچھے جاؤ سو وہ انہیں دور سے دیکھتے رہے اور وہ لوگ (بالکل) بے خبر تھے،\qt@no{11}}%
\qt@newcmd\qurantrans@ur@mmmcclxiv{اور ہم نے پہلے ہی سے موسٰی (علیہ السلام) پر دائیوں کا دودھ حرام کر دیا تھا سو (موسٰی علیہ السلام کی بہن نے) کہا: کیا میں تمہیں ایسے گھر والوں کی نشاندہی کروں جو تمہارے لئے اس (بچے) کی پرورش کر دیں اور وہ اس کے خیر خواہ (بھی) ہوں،\qt@no{12}}%
\qt@newcmd\qurantrans@ur@mmmcclxv{پس ہم نے موسٰی (علیہ السلام) کو (یوں) ان کی والدہ کے پاس لوٹا دیا تاکہ ان کی آنکھ ٹھنڈی رہے اور وہ رنجیدہ نہ ہوں اور تاکہ وہ (یقین سے) جان لیں کہ اللہ کا وعدہ سچا ہے لیکن اکثر لوگ نہیں جانتے،\qt@no{13}}%
\qt@newcmd\qurantrans@ur@mmmcclxvi{اور جب موسٰی (علیہ السلام) اپنی جوانی کو پہنچ گئے اور (سنِّ) اعتدال پر آگئے تو ہم نے انہیں حکمِ (نبوّت) اور علم و دانش سے نوازا، اور ہم نیکوکاروں کو اسی طرح صلہ دیا کرتے ہیں،\qt@no{14}}%
\qt@newcmd\qurantrans@ur@mmmcclxvii{اور موسٰی (علیہ السلام) شہرِ (مصر) میں داخل ہوئے اس حال میں کہ شہر کے باشندے (نیند میں) غافل پڑے تھے، تو انہوں نے اس میں دو مَردوں کو باہم لڑتے ہوئے پایا یہ (ایک) تو ان کے (اپنے) گروہ (بنی اسرائیل) میں سے تھا اور یہ (دوسرا) ان کے دشمنوں (قومِ فرعون) میں سے تھا، پس اس شخص نے جو انہی کے گروہ میں سے تھا آپ سے اس شخص کے خلاف مدد طلب کی جو آپ کے دشمنوں میں سے تھا پس موسٰی (علیہ السلام) نے اسے مکّا مارا تو اس کا کام تمام کردیا، (پھر) فرمانے لگے: یہ شیطان کا کام ہے (جو مجھ سے سرزَد ہوا ہے)، بیشک وہ صریح بہکانے والا دشمن ہے،\qt@no{15}}%
\qt@newcmd\qurantrans@ur@mmmcclxviii{موسٰی علیہ السلام) عرض کرنے لگے: اے میرے رب! بیشک میں نے اپنی جان پر ظلم کیا سو تو مجھے معاف فرما دے پس اس نے انہیں معاف فرما دیا، بیشک وہ بڑا ہی بخشنے والا نہایت مہربان ہے،\qt@no{16}}%
\qt@newcmd\qurantrans@ur@mmmcclxix{مزید) عرض کرنے لگے: اے میرے رب! اس سبب سے کہ تو نے مجھ پر (اپنی مغفرت کے ذریعہ) احسان فرمایا ہے اب میں ہرگز مجرموں کا مددگار نہیں بنوں گا،\qt@no{17}}%
\qt@newcmd\qurantrans@ur@mmmcclxx{پس موسٰی (علیہ السلام) نے اس شہر میں ڈرتے ہوئے صبح کی اس انتظار میں (کہ اب کیا ہوگا؟) تو دفعتًہ وہی شخص جس نے آپ سے گزشتہ روز مدد طلب کی تھی آپ کو (دوبارہ) امداد کے لئے پکار رہا ہے تو موسٰی (علیہ السلام) نے اس سے کہا: بیشک تو صریح گمراہ ہے،\qt@no{18}}%
\qt@newcmd\qurantrans@ur@mmmcclxxi{سو جب انہوں نے ارادہ کیا کہ اس شخص کو پکڑیں جو ان دونوں کا دشمن ہے تو وہ بول اٹھا: اے موسٰی! کیا تم مجھے (بھی) قتل کرنا چاہتے ہو جیسا کہ تم نے کل ایک شخص کو قتل کر ڈالا تھا۔ تم صرف یہی چاہتے ہو کہ ملک میں بڑے جابر بن جاؤ اور تم یہ نہیں چاہتے کہ اصلاح کرنے والوں میں سے بنو،\qt@no{19}}%
\qt@newcmd\qurantrans@ur@mmmcclxxii{اور شہر کے آخری کنارے سے ایک شخص دوڑتا ہوا آیا اس نے کہا: اے موسٰی! (قومِ فرعون کے) سردار آپ کے بارے میں مشورہ کر رہے ہیں کہ وہ آپ کو قتل کردیں سو آپ (یہاں سے) نکل جائیں بیشک میں آپ کے خیر خواہوں میں سے ہوں،\qt@no{20}}%
\qt@newcmd\qurantrans@ur@mmmcclxxiii{سو موسٰی (علیہ السلام) وہاں سے خوف زدہ ہو کر (مددِ الٰہی کا) انتظار کرتے ہوئے نکل کھڑے ہوئے، عرض کیا: اے رب! مجھے ظالم قوم سے نجات عطا فرما،\qt@no{21}}%
\qt@newcmd\qurantrans@ur@mmmcclxxiv{اور جب وہ مَديَن کی طرف رخ کر کے چلے (تو) کہنے لگے: امید ہے میرا رب مجھے (منزلِ مقصود تک پہنچانے کے لئے) سیدھی راہ دکھا دے گا،\qt@no{22}}%
\qt@newcmd\qurantrans@ur@mmmcclxxv{اور جب وہ مَدْيَنَْ کے پانی (کے کنویں) پر پہنچے تو انہوں نے اس پر لوگوں کا ایک ہجوم پایا جو (اپنے جانوروں کو) پانی پلا رہے تھے اور ان سے الگ ایک جانب دو عورتیں دیکھیں جو (اپنی بکریوں کو) روکے ہوئے تھیں (موسٰی علیہ السلام نے) فرمایا: تم دونوں اس حال میں کیوں (کھڑی) ہو؟ دونوں بولیں کہ ہم (اپنی بکریوں کو) پانی نہیں پلا سکتیں یہاں تک کہ چرواہے (اپنے مویشیوں کو) واپس لے جائیں، اور ہمارے والد عمر رسیدہ بزرگ ہیں،\qt@no{23}}%
\qt@newcmd\qurantrans@ur@mmmcclxxvi{سو انہوں نے دونوں (کے ریوڑ) کو پانی پلا دیا پھر سایہ کی طرف پلٹ گئے اور عرض کیا: اے رب! میں ہر اس بھلائی کا جو تو میری طرف اتارے محتا ج ہوں،\qt@no{24}}%
\qt@newcmd\qurantrans@ur@mmmcclxxvii{پھر (تھوڑی دیر بعد) ان کے پاس ان دونوں میں سے ایک (لڑکی) آئی جو شرم و حیاء (کے انداز) سے چل رہی تھی۔ اس نے کہا: میرے والد آپ کو بلا رہے ہیں تاکہ وہ آپ کو اس (محنت) کا معاوضہ دیں جو آپ نے ہمارے لئے (بکریوں کو) پانی پلایا ہے۔ سو جب موسٰی (علیہ السلام) ان (لڑکیوں کے والد شعیب علیہ السلام) کے پاس آئے اور ان سے (پچھلے) واقعات بیان کئے تو انہوں نے کہا: آپ خوف نہ کریں آپ نے ظالم قوم سے نجات پا لی ہے،\qt@no{25}}%
\qt@newcmd\qurantrans@ur@mmmcclxxviii{ان میں سے ایک (لڑکی) نے کہا: اے (میرے) والد گرامی! انہیں (اپنے پاس مزدوری) پر رکھ لیں بیشک بہترین شخص جسے آپ مزدوری پر رکھیں وہی ہے جو طاقتور امانت دار ہو (اور یہ اس ذمہ داری کے اہل ہیں)،\qt@no{26}}%
\qt@newcmd\qurantrans@ur@mmmcclxxix{انہوں نے (موسٰی علیہ السلام سے) کہا: میں چاہتا ہوں کہ اپنی ان دو لڑکیوں میں سے ایک کا نکاح آپ سے کردوں اس (مَہر) پر کہ آپ آٹھ سال تک میرے پاس اُجرت پر کام کریں، پھر اگر آپ نے دس (سال) پور ے کردیئے تو آپ کی طرف سے (احسان) ہوگا اور میں آپ پر مشقت نہیں ڈالنا چاہتا، اگر اللہ نے چاہا تو آپ مجھے نیک لوگوں میں سے پائیں گے،\qt@no{27}}%
\qt@newcmd\qurantrans@ur@mmmcclxxx{موسٰی (علیہ السلام) نے کہا: یہ (معاہدہ) میرے اور آپ کے درمیان (طے) ہوگیا، دو میں سے جو مدت بھی میں پوری کروں سو مجھ پر کوئی جبر نہیں ہوگا، اور اللہ اس (بات) پر جو ہم کہہ رہے ہیں نگہبان ہے،\qt@no{28}}%
\qt@newcmd\qurantrans@ur@mmmcclxxxi{پھر جب موسٰی (علیہ السلام) نے مقررہ مدت پوری کر لی اور اپنی اہلیہ کو لے کر چلے (تو) انہوں نے طور کی جانب سے ایک آگ دیکھی (وہ شعلۂ حسنِ مطلق تھا جس کی طرف آپ کی طبیعت مانوس ہوگئی)، انہوں نے اپنی اہلیہ سے فرمایا: تم (یہیں) ٹھہرو میں نے آگ دیکھی ہے۔ شاید میں تمہارے لئے اس (آگ) سے کچھ (اُس کی) خبر لاؤں (جس کی تلاش میں مدتوں سے سرگرداں ہوں) یا آتشِ (سوزاں) کی کوئی چنگاری (لادوں) تاکہ تم (بھی) تپ اٹھو،\qt@no{29}}%
\qt@newcmd\qurantrans@ur@mmmcclxxxii{جب موسٰی (علیہ السلام) وہاں پہنچے تو وادئ (طور) کے دائیں کنارے سے بابرکت مقام میں (واقع) ایک درخت سے آواز دی گئی کہ اے موسٰی! بیشک میں ہی اللہ ہوں (جو) تمام جہانوں کا پروردگار (ہوں)،\qt@no{30}}%
\qt@newcmd\qurantrans@ur@mmmcclxxxiii{اور یہ کہ اپنی لاٹھی (زمین پر) ڈال دو، پھر جب موسٰی (علیہ السلام) نے اسے دیکھا کہ وہ تیز لہراتی تڑپتی ہوئی حرکت کر رہی ہے گویا وہ سانپ ہو، تو پیٹھ پھیر کر چل پڑے اور پیچھے مڑ کر نہ دیکھا، (ندا آئی:) اے موسٰی! سامنے آؤ اور خوف نہ کرو، بیشک تم امان یافتہ لوگوں میں سے ہو،\qt@no{31}}%
\qt@newcmd\qurantrans@ur@mmmcclxxxiv{اپنا ہاتھ اپنے گریبان میں ڈالو وہ بغیر کسی عیب کے سفید چمک دار ہوکر نکلے گا اور خوف (دور کرنے کی غرض) سے اپنا بازو اپنے (سینے کی) طرف سکیڑ لو، پس تمہارے رب کی جانب سے یہ دو دلیلیں فرعون اور اس کے درباریوں کی طرف (بھیجنے اور مشاہدہ کرانے کے لئے) ہیں، بیشک وہ نافرمان لوگ ہیں،\qt@no{32}}%
\qt@newcmd\qurantrans@ur@mmmcclxxxv{موسٰی علیہ السلام نے) عرض کیا: اے پروردگار! میں نے ان میں سے ایک شخص کو قتل کر ڈالا تھا سو میں ڈرتا ہوں کہ وہ مجھے قتل کرڈالیں گے،\qt@no{33}}%
\qt@newcmd\qurantrans@ur@mmmcclxxxvi{اور میرے بھائی ہارون (علیہ السلام)، وہ زبان میں مجھ سے زیادہ فصیح ہیں سو انہیں میرے ساتھ مددگار بنا کر بھیج دے کہ وہ میری تصدیق کر سکیں میں اس بات سے (بھی) ڈرتا ہوں کہ (وہ) لوگ مجھے جھٹلائیں گے،\qt@no{34}}%
\qt@newcmd\qurantrans@ur@mmmcclxxxvii{ارشاد فرمایا: ہم تمہارا بازو تمہارے بھائی کے ذریعے مضبوط کر دیں گے۔ اور ہم تم دونوں کے لئے (لوگوں کے دلوں میں اور تمہاری کاوشوں میں) ہیبت و غلبہ پیدا کئے دیتے ہیں۔ سو وہ ہماری نشانیوں کے سبب سے تم تک (گزند پہنچانے کے لئے) نہیں پہنچ سکیں گے، تم دونوں اور جو لوگ تمہاری پیروی کریں گے غالب رہیں گے،\qt@no{35}}%
\qt@newcmd\qurantrans@ur@mmmcclxxxviii{پھر جب موسٰی (علیہ السلام) ان کے پاس ہماری واضح اور روشن نشانیاں لے کر آئے تو وہ لوگ کہنے لگے کہ یہ تو مَن گھڑت جادو کے سوا (کچھ) نہیں ہے۔ اور ہم نے یہ باتیں اپنے پہلے آباء و اجداد میں (کبھی) نہیں سنی تھیں،\qt@no{36}}%
\qt@newcmd\qurantrans@ur@mmmcclxxxix{اور موسٰی (علیہ السلام) نے کہا: میرا رب اس کو خوب جانتا ہے جو اس کے پاس سے ہدایت لے کر آیا ہے اور اس کو (بھی) جس کے لئے آخرت کے گھر کا انجام (بہتر) ہوگا، بیشک ظالم فلاح نہیں پائیں گے،\qt@no{37}}%
\qt@newcmd\qurantrans@ur@mmmccxc{اور فرعون نے کہا: اے درباریو! میں تمہارے لئے اپنے سوا کوئی دوسرا معبود نہیں جانتا۔ اے ہامان! میرے لئے گارے کو آگ لگا (کر کچھ اینٹیں پکا) دے، پھر میرے لئے (ان سے) ایک اونچی عمارت تیار کر، شاید میں (اس پر چڑھ کر) موسٰی کے خدا تک رسائی پا سکوں، اور میں تو اس کو جھوٹ بولنے والوں میں گمان کرتا ہوں،\qt@no{38}}%
\qt@newcmd\qurantrans@ur@mmmccxci{اور اس (فرعون) نے خود اور اس کی فوجوں نے ملک میں ناحق تکبّر و سرکشی کی اور یہ گمان کر بیٹھے کہ وہ ہماری طرف نہیں لوٹائے جائیں گے،\qt@no{39}}%
\qt@newcmd\qurantrans@ur@mmmccxcii{سو ہم نے اس کو اور اس کی فوجوں کو (عذاب میں) پکڑ لیا اور ان کو دریا میں پھینک دیا، تو آپ دیکھئے کہ ظالموں کا انجام کیسا (عبرت ناک) ہوا،\qt@no{40}}%
\qt@newcmd\qurantrans@ur@mmmccxciii{اور ہم نے انہیں (دوزخیوں کا) پیشوا بنا دیا کہ وہ (لوگوں کو) دوزخ کی طرف بلاتے تھے اور قیامت کے دن ان کی کوئی مدد نہیں کی جائے گی،\qt@no{41}}%
\qt@newcmd\qurantrans@ur@mmmccxciv{اور ہم نے ان کے پیچھے اس دنیا میں (بھی) لعنت لگا دی اور قیامت کے دن (بھی) وہ بدحال لوگوں میں (شمار) ہوں گے،\qt@no{42}}%
\qt@newcmd\qurantrans@ur@mmmccxcv{اور بیشک ہم نے اس (صورتِ حال) کے بعد کہ ہم پہلی (نافرمان) قوموں کو ہلاک کر چکے تھے موسٰی (علیہ السلام) کو کتاب عطا کی جو لوگوں کے لئے (خزانۂ) بصیرت اور ہدایت و رحمت تھی، تاکہ وہ نصیحت قبول کریں،\qt@no{43}}%
\qt@newcmd\qurantrans@ur@mmmccxcvi{اور آپ (اس وقت طُور کے) مغربی جانب (تو موجود) نہیں تھے جب ہم نے موسٰی (علیہ السلام) کی طرف حکمِ (رسالت) بھیجا تھا، اور نہ (ہی) آپ (ان ستّر افراد میں شامل تھے جو وحیِ موسٰی علیہ السلام کی) گواہی دینے والوں میں سے تھے (پس یہ سارا بیان غیب کی خبر نہیں تو اور کیا ہے؟)،\qt@no{44}}%
\qt@newcmd\qurantrans@ur@mmmccxcvii{لیکن ہم نے (موسٰی علیہ السلام کے بعد یکے بعد دیگرے) کئی قومیں پیدا فرمائیں پھر ان پر طویل مدّت گزر گئی، اور نہ (ہی) آپ (موسٰی اور شعیب علیہما السلام کی طرح) اہل مدین میں مقیم تھے کہ آپ ان پر ہماری آیتیں پڑھ کر سناتے ہوں لیکن ہم ہی (آپ کو اخبارِ غیب سے سرفراز فرما کر) مبعوث فرمانے والے ہیں،\qt@no{45}}%
\qt@newcmd\qurantrans@ur@mmmccxcviii{اور نہ (ہی) آپ طُور کے کنارے (اس وقت موجود) تھے جب ہم نے (موسٰی علیہ السلام کو) ندا فرمائی مگر (آپ کو ان تمام احوالِ غیب پر مطلع فرمانا) آپ کے رب کی جانب سے (خصوصی) رحمت ہے۔ تاکہ آپ (ان واقعات سے باخبر ہو کر) اس قوم کو (عذابِ الٰہی سے) ڈرائیں جن کے پاس آپ سے پہلے کوئی ڈر سنانے والا نہیں آیا، تاکہ وہ نصیحت قبول کریں،\qt@no{46}}%
\qt@newcmd\qurantrans@ur@mmmccxcix{اور (ہم کوئی رسول نہ بھیجتے) اگر یہ بات نہ ہوتی کہ جب انہیں کوئی مصیبت پہنچے ان کے اعمالِ بد کے باعث جو انہوں نے خود انجام دیئے تو وہ یہ نہ کہنے لگیں کہ اے ہمارے رب! تو نے ہماری طرف کوئی رسول کیوں نہ بھیجا تاکہ ہم تیری آیتوں کی پیروی کرتے اور ہم ایمان والوں میں سے ہوجاتے،\qt@no{47}}%
\qt@newcmd\qurantrans@ur@mmmccc{پھر جب ان کے پاس ہمارے حضور سے حق آپہنچا (تو) وہ کہنے لگے کہ اس (رسول) کو ان (نشانیوں) جیسی (نشانیاں) کیوں نہیں دی گئیں جو موسٰی (علیہ السلام) کو دی گئیں تھیں؟ کیا انہوں نے ان (نشانیوں) کا انکار نہیں کیا تھا جو اس سے پہلے موسٰی (علیہ السلام) کو دی گئی تھیں؟ وہ کہنے لگے کہ دونوں (قرآن اور تورات) جادو ہیں (جو) ایک دوسرے کی تائید و موافقت کرتے ہیں، اور انہوں نے کہا کہ ہم (ان) سب کے منکر ہیں،\qt@no{48}}%
\qt@newcmd\qurantrans@ur@mmmccci{آپ فرما دیں کہ تم اللہ کے حضور سے کوئی (اور) کتاب لے آؤ جو ان دونوں سے زیادہ ہدایت والی ہو (تو) میں اس کی پیروی کروں گا اگر تم (اپنے الزامات میں) سچے ہو،\qt@no{49}}%
\qt@newcmd\qurantrans@ur@mmmcccii{پھر اگر وہ آپ کا ارشاد قبول نہ کریں تو آپ جان لیں (کہ ان کے لئے کوئی حجت باقی نہیں رہی) وہ محض اپنی خواہشات کی پیروی کرتے ہیں، اور اس شخص سے زیادہ گمراہ کون ہوسکتا ہے جو اللہ کی جانب سے ہدایت کو چھوڑ کر اپنی خواہش کی پیروی کرے۔ بیشک اللہ ظالم قوم کو ہدایت نہیں فرماتا،\qt@no{50}}%
\qt@newcmd\qurantrans@ur@mmmccciii{اور درحقیقت ہم ان کے لئے پے در پے (قرآن کے) فرمان بھیجتے رہے تاکہ وہ نصیحت قبو ل کریں،\qt@no{51}}%
\qt@newcmd\qurantrans@ur@mmmccciv{جن لوگوں کو ہم نے اس سے پہلے کتاب عطا کی تھی وہ (اسی ہدایت کے تسلسل میں) اس (قرآن) پر (بھی) ایمان رکھتے ہیں،\qt@no{52}}%
\qt@newcmd\qurantrans@ur@mmmcccv{اور جب ان پر (قرآن) پڑھ کر سنایا جاتا ہے تو وہ کہتے ہیں: ہم اس پر ایمان لائے بیشک یہ ہمارے رب کی جانب سے حق ہے، حقیقت میں تو ہم اس سے پہلے ہی مسلمان (یعنی فرمانبردار) ہوچکے تھے،\qt@no{53}}%
\qt@newcmd\qurantrans@ur@mmmcccvi{یہ وہ لوگ ہیں جنہیں ان کا اجر دوبار دیا جائے گا اس وجہ سے کہ انہوں نے صبر کیا اور وہ برائی کو بھلائی کے ذریعے دفع کرتے ہیں اور اس عطا میں سے جو ہم نے انہیں بخشی خرچ کرتے ہیں،\qt@no{54}}%
\qt@newcmd\qurantrans@ur@mmmcccvii{اورجب وہ کوئی بیہودہ بات سنتے ہیں تو اس سے منہ پھیر لیتے ہیں اور کہتے ہیں کہ ہمارے لئے ہمارے اعمال ہیں اور تمہارے لئے تمہارے اعمال، تم پر سلامتی ہو ہم جاہلوں (کے فکر و عمل) کو (اپنانا) نہیں چاہتے (گویا ان کی برائی کے عوض ہم اپنی اچھائی کیوں چھوڑیں)،\qt@no{55}}%
\qt@newcmd\qurantrans@ur@mmmcccviii{حقیقت یہ ہے کہ جسے آپ (راہِ ہدایت پر لانا) چاہتے ہیں اسے راہِ ہدایت پر آپ خود نہیں لاتے بلکہ جسے اللہ چاہتا ہے (آپ کے ذریعے) راہِ ہدایت پر چلا دیتا ہے، اور وہ راہِ ہدایت پانے والوں سے خوب واقف ہے۔،\qt@no{56}}%
\qt@newcmd\qurantrans@ur@mmmcccix{اور (قدر ناشناس) کہتے ہیں کہ اگر ہم آپ کی معیّت میں ہدایت کی پیروی کر لیں تو ہم اپنے ملک سے اچک لئے جائیں گے۔ کیا ہم نے انہیں (اس) امن والے حرم (شہرِ مکہ جو آپ ہی کا وطن ہے) میں نہیں بسایا جہاں ہماری طرف سے رزق کے طور پر (دنیا کی ہر سمت سے) ہر جنس کے پھل پہنچائے جاتے ہیں، لیکن ان میں سے اکثر لوگ نہیں جانتے (کہ یہ سب کچھ کس کے صدقے سے ہو رہا ہے)،\qt@no{57}}%
\qt@newcmd\qurantrans@ur@mmmcccx{اور ہم نے کتنی ہی (ایسی) بستیوں کو برباد کر ڈالا جو اپنی خوشحال معیشت پر غرور و ناشکری کر رہی تھیں، تو یہ ان کے (تباہ شدہ) مکانات ہیں جو ان کے بعد کبھی آباد ہی نہیں ہوئے مگر بہت کم، اور (آخر کار) ہم ہی وارث و مالک ہیں،\qt@no{58}}%
\qt@newcmd\qurantrans@ur@mmmcccxi{اور آپ کا رب بستیوں کو تباہ کرنے والا نہیں ہے یہاں تک کہ وہ اس کے بڑے مرکزی شہر میں پیغمبر بھیج دے جو ان پر ہماری آیتیں تلاوت کرے، اور ہم بستیوں کو ہلاک کرنے والے نہیں ہیں مگر اس حال میں کہ وہاں کے مکین ظالم ہوں،\qt@no{59}}%
\qt@newcmd\qurantrans@ur@mmmcccxii{اور جو چیز بھی تمہیں عطا کی گئی ہے سو (وہ) دنیوی زندگی کا سامان اور اس کی رونق و زینت ہے۔ مگر جو چیز (بھی) اللہ کے پاس ہے وہ (اس سے) زیادہ بہتر اور دائمی ہے۔ کیا تم (اس حقیقت کو) نہیں سمجھتے،\qt@no{60}}%
\qt@newcmd\qurantrans@ur@mmmcccxiii{کیا وہ شخص جس سے ہم نے کوئی (آخرت کا) اچھا وعدہ فرمایا ہو پھر وہ اسے پانے والا ہو جائے، اس (بدنصیب) کی مثل ہو سکتا ہے جسے ہم نے دنیوی زندگی کے سامان سے نوازا ہو پھر وہ (کفرانِ نعمت کے باعث) روزِ قیامت (عذاب کے لئے) حاضر کئے جانے والوں میں سے ہو جائے،\qt@no{61}}%
\qt@newcmd\qurantrans@ur@mmmcccxiv{اور جس دن (اللہ) انہیں پکارے گا تو فرمائے گا کہ میرے وہ شریک کہاں ہیں جنہیں تم (معبود) خیال کیا کرتے تھے،\qt@no{62}}%
\qt@newcmd\qurantrans@ur@mmmcccxv{وہ لوگ جن پر (عذاب کا) فرمان ثابت ہو چکا کہیں گے: اے ہمارے رب! یہی وہ لوگ ہیں جن کو ہم نے گمراہ کیا تھا ہم نے انہیں (اسی طرح) گمراہ کیا تھا جس طرح ہم (خود) گمراہ ہوئے تھے، ہم ان سے بیزاری ظاہر کرتے ہوئے تیری طرف متوجہ ہوتے ہیں اور وہ (درحقیقت) ہماری پرستش نہیں کرتے تھے (بلکہ اپنی نفسانی خواہشات کے پجاری تھے)،\qt@no{63}}%
\qt@newcmd\qurantrans@ur@mmmcccxvi{اور (ان سے) کہا جائے گا: تم اپنے (خود ساختہ) شریکوں کو بلاؤ، سو وہ انہیں پکاریں گے پس وہ (شریک) انہیں کوئی جواب نہ دیں گے اور وہ لوگ عذاب کو دیکھ لیں گے، کاش! وہ (دنیا میں) راہِ ہدایت پا چکے ہوتے،\qt@no{64}}%
\qt@newcmd\qurantrans@ur@mmmcccxvii{اور جس دن (اللہ) انہیں پکارے گا تو وہ فرمائے گا: تم نے پیغمبروں کو کیا جواب دیا تھا،\qt@no{65}}%
\qt@newcmd\qurantrans@ur@mmmcccxviii{تو ان پر اس دن خبریں پوشیدہ ہو جائیں گی سو وہ ایک دوسرے سے پوچھ (بھی) نہ سکیں گے،\qt@no{66}}%
\qt@newcmd\qurantrans@ur@mmmcccxix{لیکن جس نے توبہ کر لی اور ایمان لے آیا اور نیک عمل کیا تو یقیناً وہ فلاح پانے والوں میں سے ہوگا،\qt@no{67}}%
\qt@newcmd\qurantrans@ur@mmmcccxx{اور آپ کا رب جو چاہتا ہے پیدا فرماتا ہے اور (جسے چاہتا ہے نبوت اور حقِ شفاعت سے نوازنے کے لئے) منتخب فرما لیتا ہے، ان (منکر اور مشرک) لوگوں کو (اس امر میں) کوئی مرضی اور اختیار حاصل نہیں ہے۔ اللہ پاک ہے اور بالاتر ہے ان (باطل معبودوں) سے جنہیں وہ (اللہ کا) شریک گردانتے ہیں۔،\qt@no{68}}%
\qt@newcmd\qurantrans@ur@mmmcccxxi{اور آپ کا رب ان (تمام باتوں) کو جانتا ہے جو ان کے سینے (اپنے اندر) چھپائے ہوئے ہیں اور جو کچھ وہ آشکار کرتے ہیں۔،\qt@no{69}}%
\qt@newcmd\qurantrans@ur@mmmcccxxii{اور وہی اللہ ہے اس کے سوا کوئی معبود نہیں۔ دنیا اور آخرت میں ساری تعریفیں اسی کے لئے ہیں، اور (حقیقی) حکم و فرمانروائی (بھی) اسی کی ہے اور تم اسی کی طرف لوٹائے جاؤ گے،\qt@no{70}}%
\qt@newcmd\qurantrans@ur@mmmcccxxiii{فرما دیجئے: ذرا اتنا بتاؤ کہ اگر اللہ تمہارے اوپر روزِ قیامت تک ہمیشہ رات طاری فرما دے (تو) اللہ کے سوا کون معبود ہے جو تمہیں روشنی لا دے۔ کیا تم (یہ باتیں) سنتے نہیں ہو،\qt@no{71}}%
\qt@newcmd\qurantrans@ur@mmmcccxxiv{فرما دیجئے: ذرا یہ (بھی) بتاؤ کہ اگر اللہ تمہارے اوپر روزِ قیامت تک ہمیشہ دن طاری فرما دے (تو) اللہ کے سوا کون معبود ہے جو تمہیں رات لا دے کہ تم اس میں آرام کر سکو، کیا تم دیکھتے نہیں ہو،\qt@no{72}}%
\qt@newcmd\qurantrans@ur@mmmcccxxv{اور اس نے اپنی رحمت سے تمہارے لئے رات اور دن کو بنایا تاکہ تم رات میں آرام کرو اور (دن میں) اس کا فضل (روزی) تلاش کرسکو اور تاکہ تم شکر گزار بنو،\qt@no{73}}%
\qt@newcmd\qurantrans@ur@mmmcccxxvi{اور جس دن وہ انہیں پکارے گا تو ارشاد فرمائے گا کہ میرے وہ شریک کہاں ہیں جنہیں تم (معبود) خیال کرتے تھے،\qt@no{74}}%
\qt@newcmd\qurantrans@ur@mmmcccxxvii{اور ہم ہر امت سے ایک گواہ نکالیں گے پھر ہم (کفار سے) کہیں گے کہ تم اپنی دلیل لاؤ تو وہ جان لیں گے کہ سچ بات اللہ ہی کی ہے اور ان سے وہ سب (باتیں) جاتی رہیں گی جو وہ جھوٹ باندھا کرتے تھے،\qt@no{75}}%
\qt@newcmd\qurantrans@ur@mmmcccxxviii{بیشک قارون موسٰی (علیہ السلام) کی قوم سے تھا پھر اس نے لوگوں پر سرکشی کی اور ہم نے اسے اس قدر خزانے عطا کئے تھے کہ اس کی کنجیاں (اٹھانا) ایک بڑی طاقتور جماعت کو دشوار ہوتا تھا، جبکہ اس کی قوم نے اس سے کہا: تُو (خوشی کے مارے) غُرور نہ کر بیشک اللہ اِترانے والوں کو پسند نہیں فرماتا،\qt@no{76}}%
\qt@newcmd\qurantrans@ur@mmmcccxxix{اور تو اس (دولت) میں سے جو اللہ نے تجھے دے رکھی ہے آخرت کا گھر طلب کر، اور دنیا سے (بھی) اپنا حصہ نہ بھول اور تو (لوگوں سے ویسا ہی) احسان کر جیسا احسان اللہ نے تجھ سے فرمایا ہے اور ملک میں (ظلم، ارتکاز اور استحصال کی صورت میں) فساد انگیزی (کی راہیں) تلاش نہ کر، بیشک اللہ فساد بپا کرنے والوں کو پسند نہیں فرماتا،\qt@no{77}}%
\qt@newcmd\qurantrans@ur@mmmcccxxx{وہ کہنے لگا: (میں یہ مال معاشرے اور عوام پر کیوں خرچ کروں) مجھے تویہ مال صرف اس (کسبی) علم و ہنر کی بنا پر دیا گیا ہے جو میرے پاس ہے۔ کیا اسے یہ معلوم نہ تھا کہ اللہ نے واقعۃً اس سے پہلے بہت سی ایسی قوموں کو ہلاک کر دیا تھا جو طاقت میں اس سے کہیں زیادہ سخت تھیں اور (مال و دولت اور افرادی قوت کے) جمع کرنے میں کہیں زیادہ (آگے) تھیں، اور (بوقتِ ہلاکت) مجرموں سے ان کے گناہوں کے بارے میں (مزید تحقیق یا کوئی عذر اور سبب) نہیں پوچھا جائے گا،\qt@no{78}}%
\qt@newcmd\qurantrans@ur@mmmcccxxxi{پھر وہ اپنی قوم کے سامنے (پوری) زینت و آرائش (کی حالت) میں نکلا۔ (اس کی ظاہری شان و شوکت کو دیکھ کر) وہ لوگ بول اٹھے جو دنیوی زندگی کے خواہش مند تھے: کاش! ہمارے لئے (بھی) ایسا (مال و متاع) ہوتا جیسا قارون کو دیا گیا ہے، بیشک وہ بڑے نصیب والا ہے،\qt@no{79}}%
\qt@newcmd\qurantrans@ur@mmmcccxxxii{اور (دوسری طرف) وہ لوگ جنہیں علمِ (حق) دیا گیا تھا بول اٹھے: تم پر افسوس ہے اللہ کا ثواب اس شخص کے لئے (اس دولت و زینت سے کہیں زیادہ) بہتر ہے جو ایمان لایا ہو اور نیک عمل کرتا ہو، مگر یہ (اجر و ثواب) صبر کرنے والوں کے سوا کسی کو عطا نہیں کیا جائے گا،\qt@no{80}}%
\qt@newcmd\qurantrans@ur@mmmcccxxxiii{پھرہم نے اس (قارون) کو اور اس کے گھر کو زمین میں دھنسا دیا، سو اللہ کے سوا اس کے لئے کوئی بھی جماعت (ایسی) نہ تھی جو (عذاب سے بچانے میں) اس کی مدد کرسکتی اور نہ وہ خود ہی عذاب کو روک سکا،\qt@no{81}}%
\qt@newcmd\qurantrans@ur@mmmcccxxxiv{اور جو لوگ کل اس کے مقام و مرتبہ کی تمنا کر رہے تھے (اَز رہِ ندامت) کہنے لگے: کتنا عجیب ہے کہ اللہ اپنے بندوں میں سے جس کے لئے چاہتا ہے رزق کشادہ فرماتا اور (جس کے لئے چاہتا ہے) تنگ فرماتا ہے، اگر اللہ نے ہم پر احسان نہ فرمایا ہوتا تو ہمیں (بھی) دھنسا دیتا، ہائے تعجب ہے! (اب معلوم ہوا) کہ کافر نجات نہیں پا سکتے،\qt@no{82}}%
\qt@newcmd\qurantrans@ur@mmmcccxxxv{یہ) وہ آخرت کا گھر ہے جسے ہم نے ایسے لوگوں کے لئے بنایا ہے جو نہ (تو) زمین میں سرکشی و تکبر چاہتے ہیں اور نہ فساد انگیزی، اور نیک انجام پرہیزگاروں کے لئے ہے،\qt@no{83}}%
\qt@newcmd\qurantrans@ur@mmmcccxxxvi{جو شخص نیکی لے کر آئے گا اس کے لئے اس سے بہتر (صلہ) ہے اور جو شخص برائی لے کر آئے گا تو برے کام کرنے والوں کو کوئی بدلہ نہیں دیا جائے گا مگر اسی قدر جو وہ کرتے رہے تھے،\qt@no{84}}%
\qt@newcmd\qurantrans@ur@mmmcccxxxvii{بیشک جس (رب) نے آپ پر قرآن (کی تبلیغ و اقامت کو) فرض کیا ہے یقیناً وہ آپ کو (آپ کی چاہت کے مطابق) لوٹنے کی جگہ (مکہ یا آخرت) کی طرف (فتح و کامیابی کے ساتھ) واپس لے جانے والا ہے۔ فرما دیجئے: میرا رب اسے خوب جانتا ہے جو ہدایت لے کر آیا اور اسے (بھی) جو صریح گمراہی میں ہے۔٭، ٭ (یہ آیت مکہ سے مدینہ کی طرف ہجرت فرماتے ہوئے حجفہ کے مقام پر نازل ہوئی اور یہ وعدہ فتح مکہ کے دن پورا ہو گیا۔)\qt@no{85}}%
\qt@newcmd\qurantrans@ur@mmmcccxxxviii{اور تم (حضور صلی اللہ علیہ وآلہ وسلم کی وساطت سے اُمتِ محمدی کو خطاب ہے) اس بات کی امید نہ رکھتے تھے کہ تم پر (یہ) کتاب اتاری جائے گی مگر (یہ) تمہارے رب کی رحمت (سے اتری) ہے، پس تم ہرگز کافروں کے مددگار نہ بننا،\qt@no{86}}%
\qt@newcmd\qurantrans@ur@mmmcccxxxix{اور وہ (کفار) تمہیں ہرگز اللہ کی آیتوں (کی تعمیل و تبلیغ) سے باز نہ رکھیں اس کے بعد کہ وہ تمہاری طرف اتاری جا چکی ہیں اور تم (لوگوں کو) اپنے رب کی طرف بلاتے رہو اور مشرکوں میں سے ہرگز نہ ہونا،\qt@no{87}}%
\qt@newcmd\qurantrans@ur@mmmcccxl{اور تم اللہ کے ساتھ کسی دوسرے (خود ساختہ) معبود کو نہ پوجا کرو، اس کے سوا کوئی عبادت کے لائق نہیں، اس کی ذات کے سوا ہر چیز فانی ہے، حکم اسی کا ہے اور تم (سب) اسی کی طرف لوٹائے جاؤ گے،\qt@no{88}}%
\qt@newcmd\qurantrans@ur@mmmcccxli{\basmalahur الف، لام، میم (حقیقی معنی اﷲ اور رسول صلی اللہ علیہ وآلہ وسلم ہی بہتر جانتے ہیں)،\qt@no{1}}%
\qt@newcmd\qurantrans@ur@mmmcccxlii{کیا لوگ یہ خیال کرتے ہیں کہ (صرف) ان کے (اتنا) کہنے سے کہ ہم ایمان لے آئے ہیں چھوڑ دیئے جائیں گے اور ان کی آزمائش نہ کی جائے گی،\qt@no{2}}%
\qt@newcmd\qurantrans@ur@mmmcccxliii{اور بیشک ہم نے ان لوگوں کو (بھی) آزمایا تھا جو ان سے پہلے تھے سو یقیناً اللہ ان لوگوں کو ضرور (آزمائش کے ذریعے) نمایاں فرما دے گا جو (دعوٰی ایمان میں) سچے ہیں اور جھوٹوں کو (بھی) ضرور ظاہر کر دے گا،\qt@no{3}}%
\qt@newcmd\qurantrans@ur@mmmcccxliv{کیا جو لوگ برے کام کرتے ہیں یہ گمان کئے ہوئے ہیں کہ وہ ہمارے (قابو) سے باہر نکل جائیں گے؟ کیا ہی برا ہے جو وہ (اپنے ذہنوں میں) فیصلہ کرتے ہیں،\qt@no{4}}%
\qt@newcmd\qurantrans@ur@mmmcccxlv{جو شخص اللہ سے ملاقات کی امید رکھتا ہے تو بیشک اللہ کا مقرر کردہ وقت ضرور آنے والا ہے، اور وہی سننے والا جاننے والا ہے،\qt@no{5}}%
\qt@newcmd\qurantrans@ur@mmmcccxlvi{جو شخص (راہِ حق میں) جد و جہد کرتا ہے وہ اپنے ہی (نفع کے) لئے تگ و دو کرتا ہے، بیشک اللہ تمام جہانوں (کی طاعتوں، کوششوں اور مجاہدوں) سے بے نیاز ہے،\qt@no{6}}%
\qt@newcmd\qurantrans@ur@mmmcccxlvii{اور جو لوگ ایمان لائے اور نیک عمل کرتے رہے تو ہم ان کی ساری خطائیں ان (کے نامۂ اعمال) سے مٹا دیں گے اور ہم یقیناً انہیں اس سے بہتر جزا عطا فرما دیں گے جو عمل وہ (فی الواقع) کرتے رہے تھے،\qt@no{7}}%
\qt@newcmd\qurantrans@ur@mmmcccxlviii{اور ہم نے انسان کو اس کے والدین سے نیک سلوک کا حکم فرمایا اور اگر وہ تجھ پر (یہ) کوشش کریں کہ تو میرے ساتھ اس چیز کو شریک ٹھہرائے جس کا تجھے کچھ بھی علم نہیں تو ان کی اطاعت مت کر، میری ہی طرف تم (سب) کو پلٹنا ہے سو میں تمہیں ان (کاموں) سے آگاہ کردوں گا جو تم (دنیا میں) کیا کرتے تھے،\qt@no{8}}%
\qt@newcmd\qurantrans@ur@mmmcccxlix{اور جو لوگ ایمان لائے اور نیک اعمال کرتے رہے تو ہم انہیں ضرور نیکو کاروں (کے گروہ) میں داخل فرما دیں گے،\qt@no{9}}%
\qt@newcmd\qurantrans@ur@mmmcccl{اور لوگوں میں ایسے شخص (بھی) ہوتے ہیں جو (زبان سے) کہتے ہیں کہ ہم اللہ پر ایمان لائے، پھر جب انہیں اللہ کی راہ میں (کوئی) تکلیف پہنچائی جاتی ہے تو وہ لوگوں کی آزمائش کواللہ کے عذاب کی مانند قرار دیتے ہیں، اور اگر آپ کے رب کی جانب سے کوئی مدد آپہنچتی ہے تو وہ یقیناً یہ کہنے لگتے ہیں کہ ہم تو تمہارے ساتھ ہی تھے، کیا اللہ ان (باتوں) کو نہیں جانتا جو جہان والوں کے سینوں میں (پوشیدہ) ہیں،\qt@no{10}}%
\qt@newcmd\qurantrans@ur@mmmcccli{اور اللہ ضرور ایسے لوگوں کو ممتاز فرما دے گا جو (سچے دل سے) ایمان لائے ہیں اور منافقوں کو (بھی) ضرور ظاہر کر دے گا،\qt@no{11}}%
\qt@newcmd\qurantrans@ur@mmmccclii{اور کافر لوگ ایمان والوں سے کہتے ہیں کہ تم ہماری راہ کی پیروی کرو اور ہم تمہاری خطاؤں (کے بوجھ) کو اٹھا لیں گے، حالانکہ وہ ان کے گناہوں کا کچھ بھی (بوجھ) اٹھانے والے نہیں ہیں بیشک وہ جھوٹے ہیں،\qt@no{12}}%
\qt@newcmd\qurantrans@ur@mmmcccliii{وہ یقیناً اپنے (گناہوں کے) بوجھ اٹھائیں گے اور اپنے بوجھوں کے ساتھ کئی (دوسرے) بوجھ (بھی اپنے اوپر لادے ہوں گے) اور ان سے روزِ قیامت ان (بہتانوں) کی ضرور پرسش کی جائے گی جو وہ گھڑا کرتے تھے،\qt@no{13}}%
\qt@newcmd\qurantrans@ur@mmmcccliv{اور بیشک ہم نے نوح (علیہ السلام) کو ان کی قوم کی طرف بھیجا تو وہ ان میں پچاس برس کم ایک ہزار سال رہے، پھر ان لوگوں کو طوفان نے آپکڑا اس حال میں کہ وہ ظالم تھے،\qt@no{14}}%
\qt@newcmd\qurantrans@ur@mmmccclv{پھر ہم نے نوح (علیہ السلام) کو اور (ان کے ہمراہ) کشتی والوں کو نجات بخشی اور ہم نے اس (کشتی اور واقعہ) کو تمام جہان والوں کے لئے نشانی بنا دیا،\qt@no{15}}%
\qt@newcmd\qurantrans@ur@mmmccclvi{اور ابراہیم (علیہ السلام) کو (یاد کریں) جب انہوں نے اپنی قوم سے فرمایا کہ تم اللہ کی عبادت کرو اور اس سے ڈرو، یہی تمہارے حق میں بہتر ہے اگر تم (حقیقت کو) جانتے ہو،\qt@no{16}}%
\qt@newcmd\qurantrans@ur@mmmccclvii{تم تو اللہ کے سوا بتوں کی پوجا کرتے ہو اور محض جھوٹ گھڑتے ہو، بیشک تم اللہ کے سوا جن کی پوجا کرتے ہو وہ تمہارے لئے رزق کے مالک نہیں ہیں پس تم اللہ کی بارگاہ سے رزق طلب کیا کرو اور اسی کی عبادت کیا کرو اور اسی کا شکر بجا لایا کرو، تم اسی کی طرف پلٹائے جاؤ گے،\qt@no{17}}%
\qt@newcmd\qurantrans@ur@mmmccclviii{اور اگر تم نے (میری باتوں کو) جھٹلایا تو یقیناً تم سے پہلے (بھی) کئی امتیں (حق کو) جھٹلا چکی ہیں، اور رسول پر واضح طریق سے (احکام) پہنچا دینے کے سوا (کچھ لازم) نہیں ہے،\qt@no{18}}%
\qt@newcmd\qurantrans@ur@mmmccclix{کیا انہوں نے نہیں دیکھا (یعنی غور نہیں کیا) کہ اللہ کس طرح تخلیق کی ابتداء فرماتا ہے پھر (اسی طرح) اس کا اعادہ فرماتا ہے۔ بیشک یہ (کام) اللہ پر آسان ہے،\qt@no{19}}%
\qt@newcmd\qurantrans@ur@mmmccclx{فرما دیجئے: تم زمین میں (کائناتی زندگی کے مطالعہ کے لئے) چلو پھرو، پھر دیکھو (یعنی غور و تحقیق کرو) کہ اس نے مخلوق کی (زندگی کی) ابتداء کیسے فرمائی پھر وہ دوسری زندگی کو کس طرح اٹھا کر (ارتقاء کے مراحل سے گزارتا ہوا) نشو و نما دیتا ہے۔ بیشک اللہ ہر شے پر بڑی قدرت رکھنے والا ہے،\qt@no{20}}%
\qt@newcmd\qurantrans@ur@mmmccclxi{وہ جسے چاہتا ہے عذاب دیتا ہے اور جس پر چاہتا ہے رحم فرماتا ہے اور اسی کی طرف تم پلٹائے جاؤ گے،\qt@no{21}}%
\qt@newcmd\qurantrans@ur@mmmccclxii{اور نہ تم (اللہ کو) زمین میں عاجز کرنے والے ہو اور نہ آسمان میں اور نہ تمہارے لئے اللہ کے سوا کوئی دوست ہے اور نہ مددگار،\qt@no{22}}%
\qt@newcmd\qurantrans@ur@mmmccclxiii{اور جن لوگوں نے اللہ کی آیتوں کا اور اس کی ملاقات کا انکار کیا وہ لوگ میری رحمت سے مایوس ہوگئے اور ان ہی لوگوں کے لئے درد ناک عذاب ہے،\qt@no{23}}%
\qt@newcmd\qurantrans@ur@mmmccclxiv{سو قومِ ابراہیم کا جواب اس کے سوا کچھ نہ تھا کہ وہ کہنے لگے: تم اسے قتل کر ڈالو یا اسے جلا دو، پھر اللہ نے اسے (نمرود کی) آگ سے نجات بخشی، بیشک اس (واقعہ) میں ان لوگوں کے لئے نشانیاں ہیں جو ایمان لائے ہیں،\qt@no{24}}%
\qt@newcmd\qurantrans@ur@mmmccclxv{اور ابراہیم (علیہ السلام) نے کہا: بس تم نے تو اللہ کو چھوڑ کر بتوں کو معبود بنا لیا ہے محض دنیوی زندگی میں آپس کی دوستی کی خاطر پھر روزِ قیامت تم میں سے (ہر) ایک دوسرے (کی دوستی) کا انکار کر دے گا اور تم میں سے (ہر) ایک دوسرے پر لعنت بھیجے گا، تو تمہارا ٹھکانا دوزخ ہے اور تمہارے لئے کوئی بھی مددگار نہ ہوگا،\qt@no{25}}%
\qt@newcmd\qurantrans@ur@mmmccclxvi{پھر لوط (علیہ السلام) ان پر (یعنی ابراہیم علیہ السلام پر) ایمان لے آئے اور انہوں نے کہا: میں اپنے رب کی طرف ہجرت کرنے والا ہوں۔ بیشک وہ غالب ہے حکمت والا ہے،\qt@no{26}}%
\qt@newcmd\qurantrans@ur@mmmccclxvii{اور ہم نے انہیں اسحاق اور یعقوب (علیہما السلام بیٹا اور پوتا) عطا فرمائے اور ہم نے ابراہیم (علیہ السلام) کی اولاد میں نبوت اور کتاب مقرر فرما دی اور ہم نے انہیں دنیا میں (ہی) ان کا صلہ عطا فرما دیا، اور بیشک وہ آخرت میں (بھی) نیکوکاروں میں سے ہیں،\qt@no{27}}%
\qt@newcmd\qurantrans@ur@mmmccclxviii{اور لوط (علیہ السلام) کو (یاد کریں) جب انہوں نے اپنی قوم سے کہا: بیشک تم بڑی بے حیائی کا ارتکاب کرتے ہو، اقوامِ عالم میں سے کسی ایک (قوم) نے (بھی) اس (بے حیائی) میں تم سے پہل نہیں کی،\qt@no{28}}%
\qt@newcmd\qurantrans@ur@mmmccclxix{کیا تم (شہوت رانی کے لئے) مَردوں کے پاس جاتے ہو اور ڈاکہ زنی کرتے ہو اور اپنی (بھری) مجلس میں ناپسندیدہ کام کرتے ہو، تو ان کی قوم کا جواب (بھی) اس کے سوا کچھ نہ تھا کہ کہنے لگے: تم ہم پر اللہ کا عذاب لے آؤ اگر تم سچے ہو،\qt@no{29}}%
\qt@newcmd\qurantrans@ur@mmmccclxx{لوط (علیہ السلام) نے عرض کیا: اے رب! تو فساد انگیزی کرنے والی قوم کے خلاف میری مدد فرما،\qt@no{30}}%
\qt@newcmd\qurantrans@ur@mmmccclxxi{اور جب ہمارے بھیجے ہوئے (فرشتے) ابراہیم (علیہ السلام) کے پاس خوشخبری لے کر آئے (تو) انہوں نے (ساتھ) یہ (بھی) کہا کہ ہم اس بستی کے مکینوں کو ہلاک کرنے والے ہیں کیونکہ یہاں کے باشندے ظالم ہیں،\qt@no{31}}%
\qt@newcmd\qurantrans@ur@mmmccclxxii{ابراہیم (علیہ السلام) نے کہا: اس (بستی) میں تو لوط (علیہ السلام بھی) ہیں، انہوں نے کہا: ہم ان لوگوں کوخوب جانتے ہیں جو (جو) اس میں (رہتے) ہیں ہم لوط (علیہ السلام) کو اور ان کے گھر والوں کو سوائے ان کی عورت کے ضرور بچالیں گے، وہ پیچھے رہ جانے والوں میں سے ہے،\qt@no{32}}%
\qt@newcmd\qurantrans@ur@mmmccclxxiii{اور جب ہمارے بھیجے ہوئے (فرشتے) لوط (علیہ السلام) کے پاس آئے تو وہ ان (کے آنے) سے رنجیدہ ہوئے اور ان کے (ارادۂ عذاب کے) باعث نڈھال سے ہوگئے اور (فرشتوں نے) کہا: آپ نہ خوفزدہ ہوں اور نہ غم زدہ ہوں، بیشک ہم آپ کو اور آپ کے گھر والوں کو بچانے والے ہیں سوائے آپ کی عورت کے وہ (عذاب کے لئے) پیچھے رہ جانے والوں میں سے ہے،\qt@no{33}}%
\qt@newcmd\qurantrans@ur@mmmccclxxiv{بیشک ہم اس بستی کے باشندوں پر آسمان سے عذاب نازل کرنے والے ہیں اس وجہ سے کہ وہ نافرمانی کیا کرتے تھے،\qt@no{34}}%
\qt@newcmd\qurantrans@ur@mmmccclxxv{اور بیشک ہم نے اس بستی سے (ویران مکانوں کو) ایک واضح نشانی کے طور پر عقل مند لوگوں کے لئے برقرار رکھا،\qt@no{35}}%
\qt@newcmd\qurantrans@ur@mmmccclxxvi{اور مَدیَن کی طرف ان کے (قومی) بھائی شعیب (علیہ السلام) کو (بھیجا)، سو انہوں نے کہا: اے میری قوم! اللہ کی عبادت کرو اور یومِ آخرت کی امید رکھو اور زمین میں فساد انگیزی نہ کرتے پھرو،\qt@no{36}}%
\qt@newcmd\qurantrans@ur@mmmccclxxvii{تو انہوں نے شعیب (علیہ السلام) کو جھٹلا ڈالا پس انہیں (بھی) زلزلہ (کے عذاب) نے آپکڑا، سو انہوں نے صبح اس حال میں کی کہ اپنے گھروں میں اوندھے منہ (مُردہ) پڑے تھے،\qt@no{37}}%
\qt@newcmd\qurantrans@ur@mmmccclxxviii{اور عاد اور ثمود کو (بھی ہم نے ہلاک کیا) اور بیشک ان کے کچھ (تباہ شدہ) مکانات تمہارے لیئے (بطورِ عبرت) ظاہر ہو چکے ہیں اور شیطان نے ان کے اَعمالِ بد، ان کے لئے خوش نما بنا دیئے تھے اورانہیں (حق کی) راہ سے پھیر دیا تھا حالانکہ وہ بینا و دانا تھے،\qt@no{38}}%
\qt@newcmd\qurantrans@ur@mmmccclxxix{اور (ہم نے) قارون اور فرعون اور ہامان کو (بھی ہلاک کیا) اور بیشک موسٰی (علیہ السلام) ان کے پاس واضح نشانیاں لے کر آئے تھے تو انہوں نے ملک میں غرور و سرکشی کی اور وہ (ہماری گرفت سے) آگے بڑھ جانے والے نہ تھے،\qt@no{39}}%
\qt@newcmd\qurantrans@ur@mmmccclxxx{سو ہم نے (ان میں سے) ہر ایک کو اس کے گناہ کے باعث پکڑ لیا، اور ان میں سے وہ (طبقہ بھی) تھا جس پر ہم نے پتھر برسانے والی آندھی بھیجی اوران میں سے وہ (طبقہ بھی) تھا جسے دہشت ناک آواز نے آپکڑا اور ان میں سے وہ (طبقہ بھی) تھا جسے ہم نے زمین میں دھنسا دیا اور ان میں سے (ایک) وہ (طبقہ بھی) تھا جسے ہم نے غرق کر دیا اور ہرگز ایسا نہ تھا کہ اللہ ان پر ظلم کرے بلکہ وہ خود ہی اپنی جانوں پر ظلم کرتے تھے،\qt@no{40}}%
\qt@newcmd\qurantrans@ur@mmmccclxxxi{ایسے (کافر) لوگوں کی مثال جنہوں نے اللہ کو چھوڑ کر اوروں (یعنی بتوں) کو کارساز بنا لیا ہے مکڑی کی داستان جیسی ہے جس نے (اپنے لئے جالے کا) گھر بنایا، اور بیشک سب گھروں سے زیادہ کمزور مکڑی کا گھر ہے، کاش! وہ لوگ (یہ بات) جانتے ہوتے،\qt@no{41}}%
\qt@newcmd\qurantrans@ur@mmmccclxxxii{بیشک اللہ ان (بتوں کی حقیقت) کو جانتا ہے جن کی بھی وہ اس کے سوا پوجا کرتے ہیں، اور وہی غالب ہے حکمت والا ہے،\qt@no{42}}%
\qt@newcmd\qurantrans@ur@mmmccclxxxiii{اور یہ مثالیں ہیں ہم انہیں لوگوں (کے سمجھانے) کے لئے بیان کرتے ہیں، اور انہیں اہلِ علم کے سوا کوئی نہیں سمجھتا،\qt@no{43}}%
\qt@newcmd\qurantrans@ur@mmmccclxxxiv{اللہ نے آسمانوں اور زمین کو درست تدبیر کے ساتھ پیدا فرمایا ہے، بیشک اس (تخلیق) میں اہلِ ایمان کے لئے (اس کی وحدانیت اور قدرت کی) نشانی ہے،\qt@no{44}}%
\qt@newcmd\qurantrans@ur@mmmccclxxxv{اے حبیبِ مکرّم!) آپ وہ کتاب پڑھ کر سنائیے جو آپ کی طرف (بذریعہ) وحی بھیجی گئی ہے، اور نماز قائم کیجئے، بیشک نماز بے حیائی اور برائی سے روکتی ہے، اور واقعی اﷲ کا ذکر سب سے بڑا ہے، اور اﷲ ان (کاموں) کو جانتا ہے جو تم کرتے ہو،\qt@no{45}}%
\qt@newcmd\qurantrans@ur@mmmccclxxxvi{اور (اے مومنو!) اہلِ کتاب سے نہ جھگڑا کرو مگر ایسے طریقہ سے جو بہتر ہو سوائے ان لوگوں کے جنہوں نے ان میں سے ظلم کیا، اور (ان سے) کہہ دو کہ ہم اس (کتاب) پر ایمان لائے (ہیں) جو ہماری طرف اتاری گئی (ہے) اور جو تمہاری طرف اتاری گئی تھی، اور ہمارا معبود اور تمہارا معبود ایک ہی ہے، اور ہم اسی کے فرمانبردار ہیں،\qt@no{46}}%
\qt@newcmd\qurantrans@ur@mmmccclxxxvii{اور اسی طرح ہم نے آپ کی طرف کتاب اتاری، تو جن (حق شناس) لوگوں کو ہم نے (پہلے سے) کتاب عطا کر رکھی تھی وہ اس (کتاب) پر ایمان لاتے ہیں، اور اِن (اہلِ مکّہ) میں سے (بھی) ایسے ہیں جو اس پر ایمان لاتے ہیں، اور ہماری آیتوں کا اِنکار کافروں کے سوا کوئی نہیں کرتا،\qt@no{47}}%
\qt@newcmd\qurantrans@ur@mmmccclxxxviii{اور (اے حبیب!) اس سے پہلے آپ کوئی کتاب نہیں پڑھا کرتے تھے اور نہ ہی آپ اسے اپنے ہاتھ سے لکھتے تھے ورنہ اہلِ باطل اسی وقت ضرور شک میں پڑ جاتے،\qt@no{48}}%
\qt@newcmd\qurantrans@ur@mmmccclxxxix{بلکہ وہ (قرآن ہی کی) واضح آیتیں ہیں جو ان لوگوں کے سینوں میں (محفوظ) ہیں جنہیں (صحیح) علم عطا کیا گیا ہے، اور ظالموں کے سوا ہماری آیتوں کا کوئی انکار نہیں کرتا،\qt@no{49}}%
\qt@newcmd\qurantrans@ur@mmmcccxc{اور کفّار کہتے ہیں کہ اِن پر (یعنی نبی اکرم صلی اللہ علیہ وآلہ وسلم پر) ان کے رب کی طرف سے نشانیاں کیوں نہیں اتاری گئیں، آپ فرما دیجئے کہ نشانیاں تو اﷲ ہی کے پاس ہیں اور میں تو محض صریح ڈر سنانے والا ہوں،\qt@no{50}}%
\qt@newcmd\qurantrans@ur@mmmcccxci{کیا ان کے لئے یہ (نشانی) کافی نہیں ہے کہ ہم نے آپ پر (وہ) کتاب نازل فرمائی ہے جو ان پر پڑھی جاتی ہے (یا ہمیشہ پڑھی جاتی رہے گی)، بیشک اس (کتاب) میں رحمت اور نصیحت ہے ان لوگوں کے لئے جو ایمان رکھتے ہیں،\qt@no{51}}%
\qt@newcmd\qurantrans@ur@mmmcccxcii{آپ فرما دیجئے: میرے اور تمہارے درمیان اﷲ ہی گواہ کافی ہے۔ وہ جو کچھ آسمانوں اور زمین میں ہے (سب کا حال) جانتا ہے، اور جو لوگ باطل پر ایمان لائے اور اﷲ کا انکار کیا وہی نقصان اٹھانے والے ہیں،\qt@no{52}}%
\qt@newcmd\qurantrans@ur@mmmcccxciii{اور یہ لوگ آپ سے عذاب میں جلدی چاہتے ہیں، اور اگر (عذاب کا) وقت مقرر نہ ہوتا تو ان پر عذاب آچکا ہوتا، اور وہ (عذاب یا وقتِ عذاب) ضرور انہیں اچانک آپہنچے گا اور انہیں خبر بھی نہ ہوگی،\qt@no{53}}%
\qt@newcmd\qurantrans@ur@mmmcccxciv{یہ لوگ آپ سے عذاب جلد طلب کرتے ہیں، اور بیشک دوزخ کافروں کو گھیر لینے والی ہے،\qt@no{54}}%
\qt@newcmd\qurantrans@ur@mmmcccxcv{جس دن عذاب انہیں ان کے اوپر سے اور ان کے پاؤں کے نیچے سے ڈھانپ لے گا تو ارشاد ہوگا: تم ان کاموں کا مزہ چکھو جو تم کرتے تھے،\qt@no{55}}%
\qt@newcmd\qurantrans@ur@mmmcccxcvi{اے میرے بندو! جو ایمان لے آئے ہو بیشک میری زمین کشادہ ہے سو تم میری ہی عبادت کرو،\qt@no{56}}%
\qt@newcmd\qurantrans@ur@mmmcccxcvii{ہر جان موت کا مزہ چکھنے والی ہے، پھر تم ہماری ہی طرف لوٹائے جاؤ گے،\qt@no{57}}%
\qt@newcmd\qurantrans@ur@mmmcccxcviii{اور جو لوگ ایمان لائے اور نیک اعمال کرتے رہے ہم انہیں ضرور جنت کے بالائی محلّات میں جگہ دیں گے جن کے نیچے سے نہریں بہہ رہی ہوں گی وہ ان میں ہمیشہ رہیں گے، یہ عملِ (صالح) کرنے والوں کا کیا ہی اچھا اجر ہے،\qt@no{58}}%
\qt@newcmd\qurantrans@ur@mmmcccxcix{یہ وہ لوگ ہیں) جنہوں نے صبر کیا اور اپنے رب پر ہی توکّل کرتے رہے،\qt@no{59}}%
\qt@newcmd\qurantrans@ur@mmmcd{اور کتنے ہی جانور ہیں جو اپنی روزی (اپنے ساتھ) نہیں اٹھائے پھرتے، اﷲ انہیں بھی رزق عطا کرتا ہے اور تمہیں بھی، اور وہ خوب سننے والا جاننے والا ہے،\qt@no{60}}%
\qt@newcmd\qurantrans@ur@mmmcdi{اور اگر آپ اِن (کفّار) سے پوچھیں کہ آسمانوں اور زمین کو کس نے پیدا کیا اور سورج اور چاند کو کس نے تابع فرمان بنا دیا، تو وہ ضرور کہہ دیں گے: اﷲ نے، پھر وہ کدھر الٹے جا رہے ہیں،\qt@no{61}}%
\qt@newcmd\qurantrans@ur@mmmcdii{اﷲ اپنے بندوں میں سے جس کے لئے چاہتا ہے رزق کشادہ فرما دیتا ہے، اور جس کے لئے (چاہتا ہے) تنگ کر دیتا ہے، بیشک اﷲ ہر چیز کو خوب جاننے والا ہے،\qt@no{62}}%
\qt@newcmd\qurantrans@ur@mmmcdiii{اور اگر آپ ان سے پوچھیں کہ آسمان سے پانی کس نے اتارا پھر اس سے زمین کو اس کی مُردنی کے بعد حیات (اور تازگی) بخشی، تو وہ ضرور کہہ دیں گے: اﷲ نے، آپ فرما دیں: ساری تعریفیں اﷲ ہی کے لئے ہیں، بلکہ ان میں سے اکثر (لوگ) عقل نہیں رکھتے،\qt@no{63}}%
\qt@newcmd\qurantrans@ur@mmmcdiv{اور (اے لوگو!) یہ دنیا کی زندگی کھیل اور تماشے کے سوا کچھ نہیں ہے، اور حقیقت میں آخرت کا گھر ہی (صحیح) زندگی ہے۔ کاش! وہ لوگ (یہ راز) جانتے ہوتے،\qt@no{64}}%
\qt@newcmd\qurantrans@ur@mmmcdv{پھر جب وہ کشتی میں سوار ہوتے ہیں تو (مشکل وقت میں بتوں کو چھوڑ کر) صرف اﷲ کو اس کے لئے (اپنا) دین خالص کرتے ہوئے پکارتے ہیں، پھر جب اﷲ انہیں بچا کر خشکی تک پہنچا دیتا ہے تو اس وقت وہ (دوبارہ) شرک کرنے لگتے ہیں،\qt@no{65}}%
\qt@newcmd\qurantrans@ur@mmmcdvi{تاکہ اس (نعمتِ نجات) کی ناشکری کریں جو ہم نے انہیں عطا کی اور (کفر کی زندگی کے حرام) فائدے اٹھاتے رہیں۔ پس وہ عنقریب (اپنا انجام) جان لیں گے،\qt@no{66}}%
\qt@newcmd\qurantrans@ur@mmmcdvii{اور کیا انہوں نے نہیں دیکھا کہ ہم نے حرمِ (کعبہ) کو جائے امان بنا دیا ہے اور اِن کے اِردگرِد کے لوگ اُچک لئے جاتے ہیں، تو کیا (پھر بھی) وہ باطل پر ایمان رکھتے اور اﷲ کے احسان کی ناشکری کرتے رہیں گے،\qt@no{67}}%
\qt@newcmd\qurantrans@ur@mmmcdviii{اور اس شخص سے بڑھ کر ظالم کون ہو سکتا ہے جو اﷲ پر جھوٹا بہتان باندھے یا حق کو جھٹلا دے جب وہ اس کے پاس آپہنچے۔ کیا دوزخ میں کافروں کے لئے ٹھکانہ (مقرر) نہیں ہے،\qt@no{68}}%
\qt@newcmd\qurantrans@ur@mmmcdix{اور جو لوگ ہمارے حق میں جہاد (اور مجاہدہ) کرتے ہیں تو ہم یقیناً انہیں اپنی (طرف سَیر اور وصول کی) راہیں دکھا دیتے ہیں، اور بیشک اﷲ صاحبانِ احسان کو اپنی معیّت سے نوازتا ہے،\qt@no{69}}%
\qt@newcmd\qurantrans@ur@mmmcdx{\basmalahur الف، لام، میم (حقیقی معنی اﷲ اور رسول صلی اللہ علیہ وآلہ وسلم ہی بہتر جانتے ہیں)،\qt@no{1}}%
\qt@newcmd\qurantrans@ur@mmmcdxi{اہلِ روم (فارس سے) مغلوب ہوگئے،\qt@no{2}}%
\qt@newcmd\qurantrans@ur@mmmcdxii{نزدیک کے ملک میں، اور وہ اپنے مغلوب ہونے کے بعد عنقریب غالب ہو جائیں گے،\qt@no{3}}%
\qt@newcmd\qurantrans@ur@mmmcdxiii{چند ہی سال میں (یعنی دس سال سے کم عرصہ میں)، اَمر تو اﷲ ہی کا ہے پہلے (غلبۂ فارس میں) بھی اور بعد (کے غلبۂ روم میں) بھی، اور اس وقت اہلِ ایمان خوش ہوں گے،\qt@no{4}}%
\qt@newcmd\qurantrans@ur@mmmcdxiv{اﷲ کی مدد سے، وہ جس کی چاہتا ہے مدد فرماتا ہے، اور وہ غالب ہے مہربان ہے،\qt@no{5}}%
\qt@newcmd\qurantrans@ur@mmmcdxv{یہ تو) اﷲ کا وعدہ ہے، اﷲ اپنے وعدہ کے خلاف نہیں کرتا، لیکن اکثر لوگ نہیں جانتے،\qt@no{6}}%
\qt@newcmd\qurantrans@ur@mmmcdxvi{وہ (تو) دنیا کی ظاہری زندگی کو (ہی) جانتے ہیں اور وہ لوگ آخرت (کی حقیقی زندگی) سے غافل و بے خبر ہیں،\qt@no{7}}%
\qt@newcmd\qurantrans@ur@mmmcdxvii{کیا انہوں نے اپنے مَن میں کبھی غور نہیں کیا کہ اﷲ نے آسمانوں اور زمین کو اور جوکچھ ان دونوں کے درمیان ہے پیدا نہیں فرمایا مگر (نظامِ) حق اور مقرّرہ مدت (کے دورانیے) کے ساتھ، اور بیشک بہت سے لوگ اپنے رب کی ملاقات کے مُنکِر ہیں،\qt@no{8}}%
\qt@newcmd\qurantrans@ur@mmmcdxviii{کیا ان لوگوں نے زمین میں سَیر و سیاحت نہیں کی تاکہ وہ دیکھ لیتے کہ ان لوگوں کا انجام کیا ہوا جو ان سے پہلے تھے، وہ لوگ اِن سے زیادہ طاقتور تھے، اور انہوں نے زمین میں زراعت کی تھی اور اسے آباد کیا تھا، اس سے کہیں بڑھ کر جس قدر اِنہوں نے زمین کو آباد کیا ہے، پھر ان کے پاس ان کے پیغمبر واضح نشانیاں لے کر آئے تھے، سو اﷲ ایسا نہ تھا کہ ان پر ظلم کرتا، لیکن وہ خود ہی اپنی جانوں پر ظلم کر رہے تھے،\qt@no{9}}%
\qt@newcmd\qurantrans@ur@mmmcdxix{پھر ان لوگوں کا انجام بہت برا ہوا جنہوں نے برائی کی اس لئے کہ وہ اﷲ کی آیتوں کو جھٹلاتے اور ان کا مذاق اڑایا کرتے تھے،\qt@no{10}}%
\qt@newcmd\qurantrans@ur@mmmcdxx{اﷲ مخلوق کو پہلی بار پیدا فرماتا ہے پھر (وہی) اسے دوبارہ پیدا فرمائے گا، پھر تم اسی کی طرف لوٹائے جاؤ گے،\qt@no{11}}%
\qt@newcmd\qurantrans@ur@mmmcdxxi{اور جس دن قیامت قائم ہوگی تو مجرم لوگ مایوس ہو جائیں گے،\qt@no{12}}%
\qt@newcmd\qurantrans@ur@mmmcdxxii{اور ان کے (خود ساختہ) شریکوں میں سے ان کے لئے سفارشی نہیں ہوں گے اور وہ (بالآخر) اپنے شریکوں کے (ہی) مُنکِر ہو جائیں گے،\qt@no{13}}%
\qt@newcmd\qurantrans@ur@mmmcdxxiii{اور جس دن قیامت برپا ہوگی اس دن لوگ (نفسا نفسی میں) الگ الگ ہو جائیں گے،\qt@no{14}}%
\qt@newcmd\qurantrans@ur@mmmcdxxiv{پس جو لوگ ایمان لائے اور نیک اعمال کرتے رہے تو وہ باغاتِ جنت میں خوش حال و مسرور کر دیئے جائیں گے،\qt@no{15}}%
\qt@newcmd\qurantrans@ur@mmmcdxxv{اور جن لوگوں نے کفر کیا اور ہماری آیتوں کو اور آخرت کی پیشی کو جھٹلایا تو یہی لوگ عذاب میں حاضر کئے جائیں گے،\qt@no{16}}%
\qt@newcmd\qurantrans@ur@mmmcdxxvi{پس تم اﷲ کی تسبیح کیا کرو جب تم شام کرو (یعنی مغرب اور عشاء کے وقت) اور جب تم صبح کرو (یعنی فجر کے وقت)،\qt@no{17}}%
\qt@newcmd\qurantrans@ur@mmmcdxxvii{اور ساری تعریفیں آسمانوں اور زمین میں اسی کے لئے ہیں اور (تم تسبیح کیا کرو) سہ پہر کو بھی (یعنی عصر کے وقت) اور جب تم دوپہر کرو (یعنی ظہر کے وقت)،\qt@no{18}}%
\qt@newcmd\qurantrans@ur@mmmcdxxviii{وُہی مُردہ سے زندہ کو نکالتا ہے اور زندہ سے مُردہ کو نکالتا ہے اور زمین کو اس کی مُردنی کے بعد زندہ و شاداب فرماتا ہے، اور تم (بھی) اسی طرح (قبروں سے) نکالے جاؤ گے،\qt@no{19}}%
\qt@newcmd\qurantrans@ur@mmmcdxxix{اور یہ اس کی نشانیوں میں سے ہے کہ اس نے تمہیں مٹی سے پیدا کیا پھر اب تم انسان ہو جو (زمین میں) پھیلے ہوئے ہو،\qt@no{20}}%
\qt@newcmd\qurantrans@ur@mmmcdxxx{اور یہ (بھی) اس کی نشانیوں میں سے ہے کہ اس نے تمہارے لئے تمہاری ہی جنس سے جوڑے پیدا کئے تاکہ تم ان کی طرف سکون پاؤ اور اس نے تمہارے درمیان محبت اور رحمت پیدا کر دی، بیشک اس (نظامِ تخلیق) میں ان لوگوں کے لئے نشانیاں ہیں جو غور و فکر کرتے ہیں،\qt@no{21}}%
\qt@newcmd\qurantrans@ur@mmmcdxxxi{اور اس کی نشانیوں میں سے آسمانوں اور زمین کی تخلیق (بھی) ہے اور تمہاری زبانوں اور تمہارے رنگوں کا اختلاف (بھی) ہے، بیشک اس میں اہلِ علم (و تحقیق) کے لئے نشانیاں ہیں،\qt@no{22}}%
\qt@newcmd\qurantrans@ur@mmmcdxxxii{اور اس کی نشانیوں میں سے رات اور دن میں تمہارا سونا اور اس کے فضل (یعنی رزق) کو تمہارا تلاش کرنا (بھی) ہے۔ بیشک اس میں ان لوگوں کے لئے نشانیاں ہیں جو (غور سے) سنتے ہیں،\qt@no{23}}%
\qt@newcmd\qurantrans@ur@mmmcdxxxiii{اور اس کی نشانیوں میں سے یہ (بھی) ہے کہ وہ تمہیں ڈرانے اور امید دلانے کے لئے بجلی دکھاتا ہے اور آسمان سے (بارش کا) پانی اتارتا ہے پھر اس سے زمین کو اس کی مُردنی کے بعد زندہ و شاداب کر دیتا ہے، بیشک اس میں ان لوگوں کے لئے نشانیاں ہیں جو عقل سے کام لیتے ہیں،\qt@no{24}}%
\qt@newcmd\qurantrans@ur@mmmcdxxxiv{اور اس کی نشانیوں میں سے یہ بھی ہے کہ آسمان و زمین اس کے (نظامِ) اَمر کے ساتھ قائم ہیں پھر جب وہ تم کو زمین سے (نکلنے کے لئے) ایک بار پکارے گا تو تم اچانک (باہر) نکل آؤ گے،\qt@no{25}}%
\qt@newcmd\qurantrans@ur@mmmcdxxxv{اور جو کچھ آسمانوں اور زمین میں ہے (سب) اسی کا ہے، سب اسی کے اطاعت گزار ہیں،\qt@no{26}}%
\qt@newcmd\qurantrans@ur@mmmcdxxxvi{اور وہی ہے جو پہلی بار تخلیق کرتا ہے پھر اس کا اِعادہ فرمائے گا اور یہ (دوبارہ پیدا کرنا) اُس پر بہت آسان ہے۔ اور آسمانوں اور زمین میں سب سے اونچی شان اسی کی ہے، اور وہ غالب ہے حکمت والا ہے،\qt@no{27}}%
\qt@newcmd\qurantrans@ur@mmmcdxxxvii{اُس نے (نکتۂ توحید سمجھانے کے لئے) تمہارے لئے تمہاری ذاتی زندگیوں سے ایک مثال بیان فرمائی ہے کہ کیا جو (لونڈی، غلام) تمہاری مِلک میں ہیں اس مال میں جو ہم نے تمہیں عطا کیا ہے شراکت دار ہیں، کہ تم (سب) اس (ملکیت) میں برابر ہو جاؤ۔ (مزید یہ کہ کیا) تم ان سے اسی طرح ڈرتے ہو جس طرح تمہیں اپنوں کا خوف ہوتا ہے (نہیں) اسی طرح ہم عقل رکھنے والوں کے لئے نشانیاں کھول کر بیان کرتے ہیں (کہ اﷲ کا بھی اس کی مخلوق میں کوئی شریک نہیں ہے)،\qt@no{28}}%
\qt@newcmd\qurantrans@ur@mmmcdxxxviii{بلکہ جن لوگوں نے ظلم کیا ہے وہ بغیر علم (و ہدایت) کے اپنی نفسانی خواہشات کی پیروی کرتے ہیں، پس اس شخص کو کون ہدایت دے سکتا ہے جسے اﷲ نے گمراہ ٹھہرا دیا ہو اور ان لوگوں کے لئے کوئی مددگار نہیں ہے،\qt@no{29}}%
\qt@newcmd\qurantrans@ur@mmmcdxxxix{پس آپ اپنا رخ اﷲ کی اطاعت کے لئے کامل یک سُوئی کے ساتھ قائم رکھیں۔ اﷲ کی (بنائی ہوئی) فطرت (اسلام) ہے جس پر اس نے لوگوں کو پیدا فرمایا ہے (اسے اختیار کر لو)، اﷲ کی پیدا کردہ (سرِشت) میں تبدیلی نہیں ہوگی، یہ دین مستقیم ہے لیکن اکثر لوگ (ان حقیقتوں کو) نہیں جانتے،\qt@no{30}}%
\qt@newcmd\qurantrans@ur@mmmcdxl{اسی کی طرف رجوع و اِنابت کا حال رکھو اور اس کا تقوٰی اختیار کرو اور نماز قائم کرو اور مشرکوں میں سے مت ہو جاؤ،\qt@no{31}}%
\qt@newcmd\qurantrans@ur@mmmcdxli{ان (یہود و نصارٰی) میں سے (بھی نہ ہونا) جنہوں نے اپنے دین کو ٹکڑے ٹکڑے کر ڈالا اور وہ گروہ در گروہ ہو گئے، ہر گروہ اسی (ٹکڑے) پر اِتراتا ہے جو اس کے پاس ہے،\qt@no{32}}%
\qt@newcmd\qurantrans@ur@mmmcdxlii{اور جب لوگوں کو کوئی تکلیف پہنچتی ہے تو وہ اپنے رب کو اس کی طرف رجوع کرتے ہوئے پکارتے ہیں، پھر جب وہ ان کو اپنی جانب سے رحمت سے لطف اندوز فرماتا ہے تو پھر فوراً ان میں سے کچھ لوگ اپنے رب کے ساتھ شرک کرنے لگتے ہیں،\qt@no{33}}%
\qt@newcmd\qurantrans@ur@mmmcdxliii{تاکہ اس نعمت کی ناشکری کریں جو ہم نے انہیں عطا کی ہے پس تم (چند روزہ زندگی کے) فائدے اٹھا لو، پھر عنقریب تم (اپنے انجام کو) جان لو گے،\qt@no{34}}%
\qt@newcmd\qurantrans@ur@mmmcdxliv{کیا ہم نے ان پر کوئی (ایسی) دلیل اتاری ہے جو ان (بتوں) کے حق میں شہادۃً کلام کرتی ہو جنہیں وہ اﷲ کا شریک بنا رہے ہیں،\qt@no{35}}%
\qt@newcmd\qurantrans@ur@mmmcdxlv{اور جب ہم لوگوں کو رحمت سے لطف اندوز کرتے ہیں تو وہ اس سے خوش ہو جاتے ہیں، اور جب انہیں کوئی تکلیف پہنچتی ہے ان (گناہوں) کے باعث جو وہ پہلے سے کر چکے ہیں تو وہ فوراً مایوس ہو جاتے ہیں،\qt@no{36}}%
\qt@newcmd\qurantrans@ur@mmmcdxlvi{کیا انہوں نے نہیں دیکھا کہ اﷲ جس کے لئے چاہتا ہے رزق کشادہ فرما دیتا ہے اور (جس کے لئے چاہتا ہے) تنگ کر دیتا ہے۔ بیشک اس میں ان لوگوں کے لئے نشانیاں ہیں جو ایمان رکھتے ہیں،\qt@no{37}}%
\qt@newcmd\qurantrans@ur@mmmcdxlvii{پس آپ قرابت دار کو اس کا حق ادا کرتے رہیں اور محتاج اور مسافر کو (ان کا حق)، یہ ان لوگوں کے لئے بہتر ہے جو اﷲ کی رضامندی کے طالب ہیں، اور وہی لوگ مراد پانے والے ہیں،\qt@no{38}}%
\qt@newcmd\qurantrans@ur@mmmcdxlviii{اور جو مال تم سود پر دیتے ہو تاکہ (تمہارا اثاثہ) لوگوں کے مال میں مل کر بڑھتا رہے تو وہ اﷲ کے نزدیک نہیں بڑھے گا اور جو مال تم زکوٰۃ (و خیرات) میں دیتے ہو (فقط) اﷲ کی رضا چاہتے ہوئے تو وہی لوگ (اپنا مال عند اﷲ) کثرت سے بڑھانے والے ہیں،\qt@no{39}}%
\qt@newcmd\qurantrans@ur@mmmcdxlix{اﷲ ہی ہے جس نے تمہیں پیدا کیا پھر اس نے تمہیں رزق بخشا پھر تمہیں موت دیتا ہے پھر تمہیں زندہ فرمائے گا، کیا تمہارے (خود ساختہ) شریکوں میں سے کوئی ایسا ہے جو ان (کاموں) میں سے کچھ بھی کر سکے، وہ (اﷲ) پاک ہے اور ان چیزوں سے برتر ہے جنہیں وہ (اس کا) شریک ٹھہراتے ہیں،\qt@no{40}}%
\qt@newcmd\qurantrans@ur@mmmcdl{بحر و بر میں فساد ان (گناہوں) کے باعث پھیل گیا ہے جو لوگوں کے ہاتھوں نے کما رکھے ہیں تاکہ (اﷲ) انہیں بعض (برے) اعمال کا مزہ چکھا دے جو انہوں نے کئے ہیں، تاکہ وہ باز آجائیں،\qt@no{41}}%
\qt@newcmd\qurantrans@ur@mmmcdli{آپ فرما دیجئے کہ تم زمین میں سیر و سیاحت کیا کرو پھر دیکھو پہلے لوگوں کا کیسا (عبرت ناک) انجام ہوا، ان میں زیادہ تر مشرک تھے،\qt@no{42}}%
\qt@newcmd\qurantrans@ur@mmmcdlii{سو آپ اپنا رُخِ (انور) سیدھے دین کے لئے قائم رکھیئے قبل اس کے کہ وہ دن آجائے جسے اﷲ کی طرف سے (قطعاً) نہیں پھرنا ہے۔ اس دن سب لوگ جدا جدا ہو جائیں گے،\qt@no{43}}%
\qt@newcmd\qurantrans@ur@mmmcdliii{جس نے کفر کیا تو اس کا (وبالِ) کفر اسی پر ہے اور جو نیک عمل کرے سو یہ لوگ اپنے لئے (جنّت کی) آرام گاہیں درست کر رہے ہیں،\qt@no{44}}%
\qt@newcmd\qurantrans@ur@mmmcdliv{تاکہ اﷲ اپنے فضل سے ان لوگوں کو بدلہ دے جو ایمان لائے اور نیک عمل کرتے رہے۔ بیشک وہ کافروں کو دوست نہیں رکھتا،\qt@no{45}}%
\qt@newcmd\qurantrans@ur@mmmcdlv{اور اس کی نشانیوں میں سے یہ (بھی) ہے کہ وہ (بارش کی) خوشخبری سنانے والی ہواؤں کو بھیجتا ہے تاکہ تمہیں (بارش کے ثمرات کی صورت میں) اپنی رحمت سے بہرہ اندوز فرمائے اور تاکہ (ان ہواؤں کے ذریعے) جہاز (بھی) اس کے حکم سے چلیں۔ اور (یہ سب) اس لئے ہے کہ تم اس کا فضل (بصورتِ زراعت و تجارت) تلاش کرو اور شاید تم (یوں) شکرگزار ہو جاؤ،\qt@no{46}}%
\qt@newcmd\qurantrans@ur@mmmcdlvi{اور درحقیقت ہم نے آپ سے پہلے رسولوں کو ان کی قوموں کی طرف بھیجا اور وہ ان کے پاس واضح نشانیاں لے کر آئے پھر ہم نے (تکذیب کرنے والے) مجرموں سے بدلہ لے لیا، اور مومنوں کی مدد کرنا ہمارے ذمۂ کرم پر تھا (اور ہے)،\qt@no{47}}%
\qt@newcmd\qurantrans@ur@mmmcdlvii{اﷲ ہی ہے جو ہواؤں کو بھیجتا ہے تو وہ بادل کو ابھارتی ہیں پھر وہ اس (بادل) کو فضائے آسمانی میں جس طرح چاہتا ہے پھیلا دیتا ہے پھر اسے (متفرق) ٹکڑے (کر کے تہ بہ تہ) کر دیتا ہے، پھر تم دیکھتے ہو کہ بارش اس کے درمیان سے نکلتی ہے، پھر جب اس (بارش) کو اپنے بندوں میں سے جنہیں چاہتا ہے پہنچا دیتا ہے تو وہ فوراً خوش ہو جاتے ہیں،\qt@no{48}}%
\qt@newcmd\qurantrans@ur@mmmcdlviii{اگرچہ ان پر بارش کے اتارے جانے سے پہلے وہ لوگ مایوس ہو رہے تھے،\qt@no{49}}%
\qt@newcmd\qurantrans@ur@mmmcdlix{سو آپ اﷲ کی رحمت کے اثرات کی طرف دیکھئے کہ وہ کس طرح زمین کو اس کی مُردنی کے بعد زندہ فرما دیتا ہے، بیشک وہ مُردوں کو (بھی اسی طرح) ضرور زندہ کرنے والا ہے اور وہ ہر چیز پر خوب قادر ہے،\qt@no{50}}%
\qt@newcmd\qurantrans@ur@mmmcdlx{اور اگر ہم (خشک) ہوا بھیج دیں اور وہ (اپنی) کھیتی کو زرد ہوتا ہوا دیکھ لیں تو اس کے بعد وہ (پہلی تمام نعمتوں سے) کفر کرنے لگیں گے،\qt@no{51}}%
\qt@newcmd\qurantrans@ur@mmmcdlxi{اے حبیب!) بیشک آپ نہ تو (اِن کافر) مُردوں کو اپنی پکار سناتے ہیں اور نہ (بدبخت) بہروں کو، جبکہ وہ (آپ ہی سے) پیٹھ پھیرے جا رہے ہوں،\qt@no{52}}%
\qt@newcmd\qurantrans@ur@mmmcdlxii{اور نہ ہی آپ (ان) اندھوں کو (جو محرومِ بصیرت ہیں) گمراہی سے راہِ ہدایت پر لانے والے ہیں، آپ تو صرف انہی لوگوں کو (فہم اور قبولیت کی توفیق کے ساتھ) سناتے ہیں جو ہماری آیتوں پر ایمان لے آتے ہیں، سو وہی مسلمان ہیں (ان کے سوا کسی اور کو آپ سناتے ہی نہیں ہیں)،\qt@no{53}}%
\qt@newcmd\qurantrans@ur@mmmcdlxiii{اﷲ ہی ہے جس نے تمہیں کمزور چیز (یعنی نطفہ) سے پیدا فرمایا پھر اس نے کمزوری کے بعد قوتِ (شباب) پیدا کیا، پھر اس نے قوت کے بعد کمزوری اور بڑھاپا پیدا کر دیا، وہ جو چاہتا ہے پیدا فرماتا ہے اور وہ خوب جاننے والا، بڑی قدرت والا ہے،\qt@no{54}}%
\qt@newcmd\qurantrans@ur@mmmcdlxiv{اور جس دن قیامت برپا ہوگی مُجرم لوگ قَسمیں کھائیں گے کہ وہ (دنیا میں) ایک گھڑی کے سوا ٹھہرے ہی نہیں تھے، اسی طرح وہ (دنیا میں بھی حق سے) پھرے رہتے تھے،\qt@no{55}}%
\qt@newcmd\qurantrans@ur@mmmcdlxv{اور جنہیں علم اور ایمان سے نوازا گیا ہے (ان سے) کہیں گے: درحقیقت تم اﷲ کی کتاب میں (ایک گھڑی نہیں بلکہ) اٹھنے کے دن تک ٹھہرے رہے ہو، سو یہ ہے اٹھنے کا دن، لیکن تم جانتے ہی نہ تھے،\qt@no{56}}%
\qt@newcmd\qurantrans@ur@mmmcdlxvi{پس اس دن ظالموں کو ان کی معذرت کوئی فائدہ نہ دے گی اور نہ ہی ان سے (اﷲ کو) راضی کرنے کا مطالبہ کیا جائے گا،\qt@no{57}}%
\qt@newcmd\qurantrans@ur@mmmcdlxvii{اور درحقیقت ہم نے لوگوں (کے سمجھانے) کے لئے اس قرآن میں ہر طرح کی مثال بیان کر دی ہے، اور اگر آپ ان کے پاس کوئی (ظاہری) نشانی لے آئیں تب بھی یہ کافر لوگ ضرور (یہی) کہہ دیں گے کہ آپ محض باطل و فریب کار ہیں،\qt@no{58}}%
\qt@newcmd\qurantrans@ur@mmmcdlxviii{اسی طرح اﷲ ان لوگوں کے دلوں پر مہر لگا دیتا ہے جو (حق کو) نہیں جانتے،\qt@no{59}}%
\qt@newcmd\qurantrans@ur@mmmcdlxix{پس آپ صبر کیجئے، بیشک اﷲ کا وعدہ سچا ہے، جو لوگ یقین نہیں رکھتے کہیں (ان کی گمراہی کا غم اور ہدایت کی فکر) آپ کو کمزور ہی نہ کر دیں۔ (اے جانِ جہاں! ان کے کفر کو غمِ جاں نہ بنا لیں)،\qt@no{60}}%
\qt@newcmd\qurantrans@ur@mmmcdlxx{\basmalahur الف، لام، میم (حقیقی معنی اﷲ اور رسول صلی اللہ علیہ وآلہ وسلم ہی بہتر جانتے ہیں)،\qt@no{1}}%
\qt@newcmd\qurantrans@ur@mmmcdlxxi{یہ حکمت والی کتاب کی آیتیں ہیں،\qt@no{2}}%
\qt@newcmd\qurantrans@ur@mmmcdlxxii{جو نیکوکاروں کے لئے ہدایت اور رحمت ہے،\qt@no{3}}%
\qt@newcmd\qurantrans@ur@mmmcdlxxiii{جو لوگ نماز قائم کرتے ہیں اور زکوٰۃ دیتے ہیں اور وہ لوگ جو آخرت پر یقین رکھتے ہیں،\qt@no{4}}%
\qt@newcmd\qurantrans@ur@mmmcdlxxiv{یہی لوگ اپنے رب کی طرف سے ہدایت پر ہیں اور یہی لوگ ہی فلاح پانے والے ہیں،\qt@no{5}}%
\qt@newcmd\qurantrans@ur@mmmcdlxxv{اور لوگوں میں سے کچھ ایسے بھی ہیں جو بیہودہ کلام خریدتے ہیں تاکہ بغیر سوجھ بوجھ کے لوگوں کو اﷲ کی راہ سے بھٹکا دیں اور اس (راہ) کا مذاق اڑائیں، ان ہی لوگوں کے لئے رسوا کن عذاب ہے،\qt@no{6}}%
\qt@newcmd\qurantrans@ur@mmmcdlxxvi{اور جب اس پر ہماری آیتیں پڑھ کر سنائی جاتی ہیں تو وہ غرور کرتے ہوئے منہ پھیر لیتا ہے گویا اس نے انہیں سنا ہی نہیں، جیسے اس کے کانوں میں (بہرے پن کی) گرانی ہے، سو آپ اسے دردناک عذاب کی خبر سنا دیں،\qt@no{7}}%
\qt@newcmd\qurantrans@ur@mmmcdlxxvii{بیشک جو لوگ ایمان لائے اور نیک اعمال کرتے رہے ان کے لئے نعمتوں کی جنتیں ہیں،\qt@no{8}}%
\qt@newcmd\qurantrans@ur@mmmcdlxxviii{وہ) ان میں ہمیشہ رہیں گے، اﷲ کا وعدہ سچّا ہے، اور وہ غالب ہے حکمت والا ہے،\qt@no{9}}%
\qt@newcmd\qurantrans@ur@mmmcdlxxix{اس نے آسمانوں کو بغیر ستونوں کے بنایا (جیسا کہ) تم انہیں دیکھ رہے ہو اور اس نے زمین میں اونچے مضبوط پہاڑ رکھ دیئے تاکہ تمہیں لے کر (دورانِ گردش) نہ کانپے اور اُس نے اس میں ہر قسم کے جانور پھیلا دیئے اور ہم نے آسمان سے پانی اتارا اور ہم نے اس میں ہر قسم کی عمدہ و مفید نباتات اگا دیں،\qt@no{10}}%
\qt@newcmd\qurantrans@ur@mmmcdlxxx{یہ اﷲ کی مخلوق ہے، پس (اے مشرکو!) مجھے دکھاؤ جو کچھ اﷲ کے سوا دوسروں نے پیدا کیا ہو۔ بلکہ ظالم کھلی گمراہی میں ہیں،\qt@no{11}}%
\qt@newcmd\qurantrans@ur@mmmcdlxxxi{اور بیشک ہم نے لقمان کو حکمت و دانائی عطا کی، (اور اس سے فرمایا) کہ اﷲ کا شکر ادا کرو اور جو شکر کرتا ہے وہ اپنے ہی فائدہ کے لئے شکر کرتا ہے، اور جو ناشکری کرتا ہے تو بیشک اﷲ بے نیاز ہے (خود ہی) سزاوارِ حمد ہے،\qt@no{12}}%
\qt@newcmd\qurantrans@ur@mmmcdlxxxii{اور (یاد کیجئے) جب لقمان نے اپنے بیٹے سے کہا اور وہ اسے نصیحت کر رہا تھا: اے میرے فرزند! اﷲ کے ساتھ شرک نہ کرنا، بیشک شِرک بہت بڑا ظلم ہے،\qt@no{13}}%
\qt@newcmd\qurantrans@ur@mmmcdlxxxiii{اور ہم نے انسان کو اس کے والدین کے بارے میں (نیکی کا) تاکیدی حکم فرمایا، جسے اس کی ماں تکلیف پر تکلیف کی حالت میں (اپنے پیٹ میں) برداشت کرتی رہی اور جس کا دودھ چھوٹنا بھی دو سال میں ہے (اسے یہ حکم دیا) کہ تو میرا (بھی) شکر ادا کر اور اپنے والدین کا بھی۔ (تجھے) میری ہی طرف لوٹ کر آنا ہے،\qt@no{14}}%
\qt@newcmd\qurantrans@ur@mmmcdlxxxiv{اور اگر وہ دونوں تجھ پر اس بات کی کوشش کریں کہ تو میرے ساتھ اس چیز کو شریک ٹھہرائے جس (کی حقیقت) کا تجھے کچھ علم نہیں ہے تو ان کی اطاعت نہ کرنا، اور دنیا (کے کاموں) میں ان کا اچھے طریقے سے ساتھ دینا، اور (عقیدہ و امورِ آخرت میں) اس شخص کی پیروی کرنا جس نے میری طرف توبہ و طاعت کا سلوک اختیار کیا۔ پھر میری ہی طرف تمہیں پلٹ کر آنا ہے تو میں تمہیں ان کاموں سے باخبر کر دوں گا جو تم کرتے رہے تھے،\qt@no{15}}%
\qt@newcmd\qurantrans@ur@mmmcdlxxxv{لقمان نے کہا:) اے میرے فرزند! اگر کوئی چیز رائی کے دانہ کے برابر ہو، پھر خواہ وہ کسی چٹان میں (چھُپی) ہو یا آسمانوں میں یا زمین میں (تب بھی) اﷲ اسے (روزِ قیامت حساب کے لئے) موجود کر دے گا۔ بیشک اﷲ باریک بین (بھی) ہے آگاہ و خبردار (بھی) ہے،\qt@no{16}}%
\qt@newcmd\qurantrans@ur@mmmcdlxxxvi{اے میرے فرزند! تو نماز قائم رکھ اور نیکی کا حکم دے اور برائی سے منع کر اور جو تکلیف تجھے پہنچے اس پر صبر کر، بیشک یہ بڑی ہمت کے کام ہیں،\qt@no{17}}%
\qt@newcmd\qurantrans@ur@mmmcdlxxxvii{اور لوگوں سے (غرور کے ساتھ) اپنا رخ نہ پھیر، اور زمین پر اکڑ کر مت چل، بیشک اﷲ ہر متکبّر، اِترا کر چلنے والے کو ناپسند فرماتا ہے،\qt@no{18}}%
\qt@newcmd\qurantrans@ur@mmmcdlxxxviii{اور اپنے چلنے میں میانہ روی اختیار کر، اور اپنی آواز کو کچھ پست رکھا کر، بیشک سب سے بری آواز گدھے کی آواز ہے،\qt@no{19}}%
\qt@newcmd\qurantrans@ur@mmmcdlxxxix{لوگو!) کیا تم نے نہیں دیکھا کہ اﷲ نے تمہارے لئے ان تمام چیزوں کو مسخّر فرما دیا ہے جو آسمانوں میں ہیں اور جو زمین میں ہیں، اور اس نے اپنی ظاہری اور باطنی نعمتیں تم پر پوری کر دی ہیں۔ اور لوگوں میں کچھ ایسے (بھی) ہیں جو اﷲ کے بارے میں جھگڑا کرتے ہیں بغیر علم کے اور بغیر ہدایت کے اور بغیر روشن کتاب (کی دلیل) کے،\qt@no{20}}%
\qt@newcmd\qurantrans@ur@mmmcdxc{اور جب ان سے کہا جاتا ہے کہ تم اس (کتاب) کی پیروی کرو جو اﷲ نے نازل فرمائی ہے تو کہتے ہیں (نہیں) بلکہ ہم تو اس (طریقہ) کی پیروی کریں گے جس پر ہم نے اپنے باپ دادا کو پایا، اور اگرچہ شیطان انہیں عذابِ دوزخ کی طرف ہی بلاتا ہو،\qt@no{21}}%
\qt@newcmd\qurantrans@ur@mmmcdxci{جو شخص اپنا رخِ اطاعت اﷲ کی طرف جھکا دے اور وہ (اپنے عَمل اور حال میں) صاحبِ احسان بھی ہو تو اس نے مضبوط حلقہ کو پختگی سے تھام لیا، اور سب کاموں کا انجام اﷲ ہی کی طرف ہے،\qt@no{22}}%
\qt@newcmd\qurantrans@ur@mmmcdxcii{اور جو کفر کرتا ہے (اے حبیبِ مکرّم!) اس کا کفر آپ کو غمگین نہ کر دے، انہیں (بھی) ہماری ہی طرف پلٹ کر آنا ہے، ہم انہیں ان اعمال سے آگاہ کر دیں گے جو وہ کرتے رہے ہیں، بیشک اﷲ سینوں کی (مخفی) باتوں کو خوب جاننے والا ہے،\qt@no{23}}%
\qt@newcmd\qurantrans@ur@mmmcdxciii{ہم انہیں (دنیا میں) تھوڑا سا فائدہ پہنچائیں گے پھر ہم انہیں بے بس کر کے سخت عذاب کی طرف لے جائیں گے،\qt@no{24}}%
\qt@newcmd\qurantrans@ur@mmmcdxciv{اور اگر آپ ان سے دریافت کریں کہ آسمانوں اور زمین کو کس نے پیدا کیا۔ تو وہ ضرور کہہ دیں گے کہ اﷲ نے، آپ فرما دیجئے: تمام تعریفیں اﷲ ہی کے لئے ہیں بلکہ ان میں سے اکثر لوگ نہیں جانتے،\qt@no{25}}%
\qt@newcmd\qurantrans@ur@mmmcdxcv{جو کچھ آسمانوں اور زمین میں ہے (سب) اﷲ ہی کا ہے، بیشک اﷲ ہی بے نیاز ہے (اَز خود) سزاوارِ حمد ہے،\qt@no{26}}%
\qt@newcmd\qurantrans@ur@mmmcdxcvi{اور اگر زمین میں جتنے درخت ہیں (سب) قلم ہوں اور سمندر (روشنائی ہو) اس کے بعد اور سات سمندر اسے بڑھاتے چلے جائیں تو اﷲ کے کلمات (تب بھی) ختم نہیں ہوں گے۔ بیشک اﷲ غالب ہے حکمت والا ہے،\qt@no{27}}%
\qt@newcmd\qurantrans@ur@mmmcdxcvii{تم سب کو پیدا کرنا اور تم سب کو (مرنے کے بعد) اٹھانا (قدرتِ الٰہیہ کے لئے) صرف ایک شخص (کو پیدا کرنے اور اٹھانے) کی طرح ہے۔ بیشک اﷲ سننے والا دیکھنے والا ہے،\qt@no{28}}%
\qt@newcmd\qurantrans@ur@mmmcdxcviii{کیا آپ نے نہیں دیکھا کہ اﷲ رات کو دن میں داخل فرماتا ہے اور دن کو رات میں داخل فرماتا ہے اور (اسی نے) سورج اور چاند کو مسخّر کر رکھا ہے، ہر کوئی ایک مقرّر میعاد تک چل رہا ہے، اور یہ کہ اﷲ ان (تمام) کاموں سے جو تم کرتے ہو خبردار ہے،\qt@no{29}}%
\qt@newcmd\qurantrans@ur@mmmcdxcix{یہ اس لئے کہ اﷲ ہی حق ہے اور جن کی یہ لوگ اﷲ کے سوا عبادت کرتے ہیں، وہ باطل ہیں اور یہ کہ اﷲ ہی بلند و بالا، بڑائی والا ہے،\qt@no{30}}%
\qt@newcmd\qurantrans@ur@mmmd{کیا آپ نے نہیں دیکھا کہ کشتیاں سمندر میں اﷲ کی نعمت سے چلتی ہیں تاکہ وہ تمہیں اپنی کچھ نشانیاں دکھا دے۔ بیشک اس میں ہر بڑے صابر و شاکر کے لئے نشانیاں ہیں،\qt@no{31}}%
\qt@newcmd\qurantrans@ur@mmmdi{اور جب سمندر کی موج (پہاڑوں، بادلوں یا) سائبانوں کی طرح ان پر چھا جاتی ہے تو وہ (کفّار و مشرکین) اﷲ کو اسی کے لئے اطاعت کو خالص رکھتے ہوئے پکارنے لگتے ہیں، پھر جب وہ انہیں بچا کر خشکی کی طرف لے جاتا ہے تو ان میں سے چند ہی اعتدال کی راہ (یعنی راہِ ہدایت) پر چلنے والے ہوتے ہیں، ہماری آیتوں کا کوئی انکار نہیں کرتا سوائے ہر بڑے عہد شکن اور بڑے ناشکرگزار کے،\qt@no{32}}%
\qt@newcmd\qurantrans@ur@mmmdii{اے لوگو! اپنے رب سے ڈرو، اور اس دن سے ڈرو جس دن کوئی باپ اپنے بیٹے کی طرف سے بدلہ نہیں دے سکے گا اور نہ کوئی ایسا فرزند ہوگا جو اپنے والد کی طرف سے کچھ بھی بدلہ دینے والا ہو، بیشک اﷲ کا وعدہ سچا ہے سو دنیا کی زندگی تمہیں ہرگز دھوکہ میں نہ ڈال دے، اور نہ ہی فریب دینے والا (شیطان) تمہیں اﷲ کے بارے میں دھوکہ میں ڈال دے،\qt@no{33}}%
\qt@newcmd\qurantrans@ur@mmmdiii{بیشک اﷲ ہی کے پاس قیامت کا علم ہے، اور وہی بارش اتارتا ہے، اور جو کچھ رحموں میں ہے وہ جانتا ہے، اور کوئی شخص یہ نہیں جانتا کہ وہ کل کیا (عمل) کمائے گا، اور نہ کوئی شخص یہ جانتا ہے کہ وہ کِس سرزمین پر مرے گا، بیشک اﷲ خوب جاننے والا ہے، خبر رکھنے والا ہے (یعنی علیم بالذّات ہے اور خبیر للغیر ہے، اَز خود ہر شے کا علم رکھتا ہے اور جسے پسند فرمائے باخبر بھی کر دیتا ہے)،\qt@no{34}}%
\qt@newcmd\qurantrans@ur@mmmdiv{\basmalahur الف، لام، میم (حقیقی معنی اﷲ اور رسول صلی اللہ علیہ وآلہ وسلم ہی بہتر جانتے ہیں)،\qt@no{1}}%
\qt@newcmd\qurantrans@ur@mmmdv{اس کتاب کا اتارا جانا، اس میں کچھ شک نہیں کہ تمام جہانوں کے پروردگار کی طرف سے ہے،\qt@no{2}}%
\qt@newcmd\qurantrans@ur@mmmdvi{کیا کفار و مشرکین یہ کہتے ہیں کہ اسے اس (رسول) نے گھڑ لیا ہے۔ بلکہ وہ آپ کے رب کی طرف سے حق ہے تاکہ آپ اس قوم کو ڈر سنائیں جن کے پاس آپ سے پہلے کوئی ڈر سنانے والا نہیں آیا تاکہ وہ ہدایت پائیں،\qt@no{3}}%
\qt@newcmd\qurantrans@ur@mmmdvii{اللہ ہی ہے جس نے آسمانوں اور زمین کو اور جو کچھ ان کے درمیان ہے (اسے) چھ دنوں (یعنی چھ مدتوں) میں پیدا فرمایا پھر (نظامِ کائنات کے) عرشِ (اقتدار) پر قائم ہوا، تمہارے لئے اسے چھوڑ کر نہ کوئی کارساز ہے اور نہ کوئی سفارشی، سو کیا تم نصیحت قبول نہیں کرتے،\qt@no{4}}%
\qt@newcmd\qurantrans@ur@mmmdviii{وہ آسمان سے زمین تک (نظامِ اقتدار) کی تدبیر فرماتا ہے پھر وہ امر اس کی طرف ایک دن میں چڑھتا ہے (اور چڑھے گا) جس کی مقدار ایک ہزار سال ہے اس (حساب) سے جو تم شمار کرتے ہو،\qt@no{5}}%
\qt@newcmd\qurantrans@ur@mmmdix{وہی غیب اور ظاہر کا جاننے والا ہے، غالب و مہربان ہے،\qt@no{6}}%
\qt@newcmd\qurantrans@ur@mmmdx{وہی ہے جس نے خوبی و حسن بخشا ہر اس چیز کو جسے اس نے پیدا فرمایا اور اس نے انسانی تخلیق کی ابتداء مٹی (یعنی غیر نامی مادّہ) سے کی،\qt@no{7}}%
\qt@newcmd\qurantrans@ur@mmmdxi{پھر اس کی نسل کو حقیر پانی کے نچوڑ (یعنی نطفہ) سے چلایا،\qt@no{8}}%
\qt@newcmd\qurantrans@ur@mmmdxii{پھر اس (میں اعضاء) کو درست کیا اور اس میں اپنی روحِ (حیات) پھونکی اور تمہارے لئے (رحمِ مادر ہی میں پہلے) کان اور (پھر) آنکھیں اور (پھر) دل و دماغ بنائے، تم بہت ہی کم شکر ادا کرتے ہو،\qt@no{9}}%
\qt@newcmd\qurantrans@ur@mmmdxiii{اور کفار کہتے ہیں کہ جب ہم مٹی میں مِل کر گم ہوجائیں گے تو (کیا) ہم اَز سرِ نَو پیدائش میں آئیں گے، بلکہ وہ اپنے رب سے ملاقات ہی کے مُنکِر ہیں،\qt@no{10}}%
\qt@newcmd\qurantrans@ur@mmmdxiv{آپ فرما دیں کہ موت کا فرشتہ جو تم پر مقرر کیا گیا ہے تمہاری روح قبض کرتا ہے پھر تم اپنے رب کی طرف لوٹائے جاؤ گے،\qt@no{11}}%
\qt@newcmd\qurantrans@ur@mmmdxv{اور اگر آپ دیکھیں (تو ان پر تعجب کریں) کہ جب مُجرِم لوگ اپنے رب کے حضور سر جھکائے ہوں گے اور (کہیں گے:) اے ہمارے رب! ہم نے دیکھ لیا اور ہم نے سُن لیا، پس (اب) ہمیں (دنیا میں) واپس لوٹا دے کہ ہم نیک عمل کر لیں بیشک ہم یقین کرنے والے ہیں،\qt@no{12}}%
\qt@newcmd\qurantrans@ur@mmmdxvi{اور اگر ہم چاہتے تو ہم ہر نفس کو اس کی ہدایت (اَز خود ہی) عطا کر دیتے لیکن میری طرف سے (یہ) فرمان ثابت ہو چکا ہے کہ میں ضرور سب (مُنکر) جنّات اور انسانوں سے دوزخ کو بھر دوں گا،\qt@no{13}}%
\qt@newcmd\qurantrans@ur@mmmdxvii{پس (اب) تم مزہ چکھو کہ تم نے اپنے اس دن کی پیشی کو بھلا رکھا تھا، بیشک ہم نے تم کو بھلا دیا ہے اور اپنے ان اعمال کے بدلے جو تم کرتے رہے تھے دائمی عذاب چکھتے رہو،\qt@no{14}}%
\qt@newcmd\qurantrans@ur@mmmdxviii{پس ہماری آیتوں پر وہی لوگ ایمان لاتے ہیں جنہیں اُن (آیتوں) کے ذریعے نصیحت کی جاتی ہے تو وہ سجدہ کرتے ہوئے گر جاتے ہیں اور اپنے رب کی حمد کے ساتھ تسبیح کرتے ہیں اور وہ تکبّر نہیں کرتے،\qt@no{15}}%
\qt@newcmd\qurantrans@ur@mmmdxix{ان کے پہلو اُن کی خواب گاہوں سے جدا رہتے ہیں اور اپنے رب کو خوف اور امید (کی مِلی جُلی کیفیت) سے پکارتے ہیں اور ہمارے عطا کردہ رزق میں سے (ہماری راہ میں) خرچ کرتے ہیں،\qt@no{16}}%
\qt@newcmd\qurantrans@ur@mmmdxx{سو کسی کو معلوم نہیں جو آنکھوں کی ٹھنڈک ان کے لئے پوشیدہ رکھی گئی ہے، یہ ان (اَعمالِ صالحہ) کا بدلہ ہوگا جو وہ کرتے رہے تھے،\qt@no{17}}%
\qt@newcmd\qurantrans@ur@mmmdxxi{بھلا وہ شخص جو صاحبِ ایمان ہو اس کی مثل ہو سکتا ہے جو نافرمان ہو، (نہیں) یہ (دونوں) برابر نہیں ہو سکتے،\qt@no{18}}%
\qt@newcmd\qurantrans@ur@mmmdxxii{چنانچہ جو لوگ ایمان لائے اور نیک اعمال کرتے رہے تو ان کے لئے دائمی سکونت کے باغات ہیں، (اللہ کی طرف سے ان کی) ضیافت و اِکرام میں اُن (اَعمال) کے بدلے جو وہ کرتے رہے تھے،\qt@no{19}}%
\qt@newcmd\qurantrans@ur@mmmdxxiii{اور جو لوگ نافرمان ہوئے سو ان کا ٹھکانا دوزخ ہے۔ وہ جب بھی اس سے نکل بھاگنے کا ارادہ کریں گے تو اسی میں لوٹا دیئے جائیں گے اور ان سے کہا جائے گا کہ اِس آتشِ دوزخ کا عذاب چکھتے رہو جِسے تم جھٹلایا کرتے تھے،\qt@no{20}}%
\qt@newcmd\qurantrans@ur@mmmdxxiv{اور ہم ان کو یقیناً (آخرت کے) بڑے عذاب سے پہلے قریب تر (دنیوی) عذاب (کا مزہ) چکھائیں گے تاکہ وہ (کفر سے) باز آجائیں،\qt@no{21}}%
\qt@newcmd\qurantrans@ur@mmmdxxv{اور اس شخص سے بڑھ کر ظالم کون ہو سکتا ہے جسے اس کے رب کی آیتوں کے ذریعے نصیحت کی جائے پھر وہ اُن سے منہ پھیر لے، بیشک ہم مُجرموں سے بدلہ لینے والے ہیں،\qt@no{22}}%
\qt@newcmd\qurantrans@ur@mmmdxxvi{اور بیشک ہم نے موسٰی (علیہ السلام) کو کتاب (تورات) عطا فرمائی تو آپ ان کی ملاقات کی نسبت شک میں نہ رہیں (وہ ملاقات آپ سے عنقریب شبِ معراج ہونے والی ہے) اور ہم نے اسے بنی اسرائیل کے لئے ہدایت بنایا،\qt@no{23}}%
\qt@newcmd\qurantrans@ur@mmmdxxvii{اور ہم نے ان میں سے جب وہ صبر کرتے رہے کچھ امام و پیشوا بنا دیئے جو ہمارے حکم سے ہدایت کرتے رہے اور وہ ہماری آیتوں پر یقین رکھتے تھے،\qt@no{24}}%
\qt@newcmd\qurantrans@ur@mmmdxxviii{بیشک آپ کا رب ہی ان لوگوں کے درمیان قیامت کے دن ان (باتوں) کا فیصلہ فرما دے گا جن میں وہ اختلاف کیا کرتے تھے،\qt@no{25}}%
\qt@newcmd\qurantrans@ur@mmmdxxix{اور کیا انہیں (اس امر سے) ہدایت نہیں ہوئی کہ ہم نے اِن سے پہلے کتنی ہی امّتوں کو ہلاک کر ڈالا تھا جن کی رہائش گاہوں میں (اب) یہ لوگ چَلتے پِھرتے ہیں۔ بیشک اس میں نشانیاں ہیں، تو کیا وہ سنتے نہیں ہیں،\qt@no{26}}%
\qt@newcmd\qurantrans@ur@mmmdxxx{اور کیا انہوں نے نہیں دیکھا کہ ہم پانی کو بنجَر زمین کی طرف بہا لے جاتے ہیں، پھر ہم اس سے کھیت نکالتے ہیں جس سے ان کے چوپائے (بھی) کھاتے ہیں اور وہ خود بھی کھاتے ہیں، تو کیا وہ دیکھتے نہیں ہیں،\qt@no{27}}%
\qt@newcmd\qurantrans@ur@mmmdxxxi{اور کہتے ہیں: یہ فیصلہ (کا دن) کب ہوگا اگر تم سچے ہو،\qt@no{28}}%
\qt@newcmd\qurantrans@ur@mmmdxxxii{آپ فرما دیں: فیصلہ کے دن نہ کافروں کو ان کا ایمان فائدہ دے گا اور نہ ہی انہیں مہلت دی جائے گی،\qt@no{29}}%
\qt@newcmd\qurantrans@ur@mmmdxxxiii{پس آپ اُن سے منہ پھیر لیجئے اور انتظار کیجئے اور وہ لوگ (بھی) انتظار کر رہے ہیں،\qt@no{30}}%
\qt@newcmd\qurantrans@ur@mmmdxxxiv{\basmalahur اے نبی! آپ اللہ کے تقوٰی پر (حسبِ سابق استقامت سے) قائم رہیں اور کافروں اور منافقوں کا (یہ) کہنا (کہ ہمارے ساتھ مذہبی سمجھوتہ کر لیں ہرگز) نہ مانیں، بیشک اللہ خوب جاننے والا بڑی حکمت والا ہے،\qt@no{1}}%
\qt@newcmd\qurantrans@ur@mmmdxxxv{اور آپ اس (فرمان) کی پیروی جاری رکھیئے جو آپ کے پاس آپ کے رب کی طرف سے وحی کیا جاتا ہے، بیشک اللہ ان کاموں سے خبردار ہے جو تم انجام دیتے ہو،\qt@no{2}}%
\qt@newcmd\qurantrans@ur@mmmdxxxvi{اور اللہ پر بھروسہ (جاری) رکھئے، اور اللہ ہی کارساز کافی ہے،\qt@no{3}}%
\qt@newcmd\qurantrans@ur@mmmdxxxvii{اللہ نے کسی آدمی کے لئے اس کے پہلو میں دو دل نہیں بنائے، اور اس نے تمہاری بیویوں کو جنہیں تم ظِہار کرتے ہوئے ماں کہہ دیتے ہو تمہاری مائیں نہیں بنایا، اور نہ تمہارے منہ بولے بیٹوں کو تمہارے (حقیقی) بیٹے بنایا، یہ سب تمہارے منہ کی اپنی باتیں ہیں، اور اللہ حق بات فرماتا ہے، اور وہی (سیدھا) راستہ دکھاتا ہے،\qt@no{4}}%
\qt@newcmd\qurantrans@ur@mmmdxxxviii{تم اُن (منہ بولے بیٹوں) کو ان کے باپ (ہی کے نام) سے پکارا کرو، یہی اللہ کے نزدیک زیادہ عدل ہے، پھر اگر تمہیں ان کے باپ معلوم نہ ہوں تو (وہ) دین میں تمہارے بھائی ہیں اور تمہارے دوست ہیں۔ اور اس بات میں تم پر کوئی گناہ نہیں جو تم نے غلطی سے کہی لیکن (اس پر ضرور گناہ ہوگا) جس کا ارادہ تمہارے دلوں نے کیا ہو، اور اللہ بہت بخشنے والا بہت رحم فرمانے والا ہے،\qt@no{5}}%
\qt@newcmd\qurantrans@ur@mmmdxxxix{یہ نبیِ (مکرّم) مومنوں کے ساتھ اُن کی جانوں سے زیادہ قریب اور حق دار ہیں اور آپ کی اَزواجِ (مطہّرات) اُن کی مائیں ہیں، اور خونی رشتہ دار اللہ کی کتاب میں (دیگر) مومنین اور مہاجرین کی نسبت (تقسیمِ وراثت میں) ایک دوسرے کے زیادہ حق دار ہیں سوائے اس کے کہ تم اپنے دوستوں پر احسان کرنا چاہو، یہ حکم کتابِ (الٰہی) میں لکھا ہوا ہے،\qt@no{6}}%
\qt@newcmd\qurantrans@ur@mmmdxl{اور (اے حبیب! یاد کیجئے) جب ہم نے انبیاء سے اُن (کی تبلیغِ رسالت) کا عہد لیا اور (خصوصاً) آپ سے اور نوح سے اور ابراہیم سے اور موسیٰ سے اور عیسٰی ابن مریم (علیھم السلام) سے اور ہم نے اُن سے نہایت پختہ عہد لیا،\qt@no{7}}%
\qt@newcmd\qurantrans@ur@mmmdxli{تاکہ (اللہ) سچوں سے اُن کے سچ کے بارے میں دریافت فرمائے، اور اس نے کافروں کے لئے دردناک عذاب تیار کر رکھا ہے،\qt@no{8}}%
\qt@newcmd\qurantrans@ur@mmmdxlii{اے ایمان والو! اپنے اوپر اللہ کا احسان یاد کرو جب (کفار کی) فوجیں تم پر آپہنچیں، تو ہم نے ان پر ہوا اور (فرشتوں کے) لشکروں کو بھیجا جنہیں تم نے نہیں دیکھا اور جو کچھ تم کرتے ہو اللہ اسے خوب دیکھنے والا ہے،\qt@no{9}}%
\qt@newcmd\qurantrans@ur@mmmdxliii{جب وہ (کافر) تمہارے اوپر (وادی کی بالائی مشرقی جانب) سے اور تمہارے نیچے (وادی کی زیریں مغربی جانب) سے چڑھ آئے تھے اور جب (ہیبت سے تمہاری) آنکھیں پھر گئی تھیں اور (دہشت سے تمہارے) دل حلقوم تک آپہنچے تھے اور تم (خوف و امید کی کیفیت میں) اللہ کی نسبت مختلف گمان کرنے لگے تھے،\qt@no{10}}%
\qt@newcmd\qurantrans@ur@mmmdxliv{اُس مقام پر مومنوں کی آزمائش کی گئی اور انہیں نہایت سخت جھٹکے دئیے گئے،\qt@no{11}}%
\qt@newcmd\qurantrans@ur@mmmdxlv{اور جب منافق لوگ اور وہ لوگ جن کے دلوں میں (کمزورئ عقیدہ اور شک و شبہ کی) بیماری تھی، یہ کہنے لگے کہ ہم سے اللہ اور اس کے رسول نے صرف دھوکہ اور فریب کے لئے (فتح کا) وعدہ کیا تھا،\qt@no{12}}%
\qt@newcmd\qurantrans@ur@mmmdxlvi{اور جبکہ اُن میں سے ایک گروہ کہنے لگا: اے اہلِ یثرب! تمہارے (بحفاظت) ٹھہرنے کی کوئی جگہ نہیں رہی، تم واپس (گھروں کو) چلے جاؤ، اور ان میں سے ایک گروہ نبی (اکرم صلی اللہ علیہ وآلہ وسلم) سے یہ کہتے ہوئے (واپس جانے کی) اجازت مانگنے لگا کہ ہمارے گھر کھلے پڑے ہیں، حالانکہ وہ کھلے نہ تھے، وہ (اس بہانے سے) صرف فرار چاہتے تھے،\qt@no{13}}%
\qt@newcmd\qurantrans@ur@mmmdxlvii{اور اگر ان پر مدینہ کے اَطراف و اَکناف سے فوجیں داخل کر دی جاتیں پھر اِن (نِفاق کا عقیدہ رکھنے والوں) سے فتنۂ (کفر و شرک) کا سوال کیا جاتا تو وہ اس (مطالبہ) کو بھی پورا کر دیتے، اور تھوڑے سے توقّف کے سوا اس میں تاخیر نہ کرتے،\qt@no{14}}%
\qt@newcmd\qurantrans@ur@mmmdxlviii{اور بیشک انہوں نے اس سے پہلے اللہ سے عہد کر رکھا تھا کہ پیٹھ پھیر کر نہ بھاگیں گے، اور اللہ سے کیے ہوئے عہد کی (ضرور) باز پُرس ہوگی،\qt@no{15}}%
\qt@newcmd\qurantrans@ur@mmmdxlix{فرما دیجئے: تمہیں فرار ہرگز کوئی نفع نہ دے گا، اگر تم موت یا قتل سے (ڈر کر) بھاگے ہو تو تم تھوڑی سی مدت کے سوا (زندگانی کا) کوئی فائدہ نہ اٹھا سکو گے،\qt@no{16}}%
\qt@newcmd\qurantrans@ur@mmmdl{فرما دیجئے: کون ایسا شخص ہے جو تمہیں اللہ سے بچا سکتا ہے اگر وہ تمہیں تکلیف دینا چاہے یا تم پر رحمت کا ارادہ فرمائے، اور وہ لوگ اپنے لئے اللہ کے سوا نہ کوئی کارساز پائیں گے اور نہ کوئی مددگار،\qt@no{17}}%
\qt@newcmd\qurantrans@ur@mmmdli{بیشک اﷲ تم میں سے ان لوگوں کو جانتا ہے جو (رسول سے اور ان کی معیّت میں جہاد سے) روکتے ہیں اور جو اپنے بھائیوں سے کہتے ہیں کہ ہماری طرف آجاؤ، اور یہ لوگ لڑائی میں نہیں آتے مگر بہت ہی کم،\qt@no{18}}%
\qt@newcmd\qurantrans@ur@mmmdlii{تمہارے حق میں بخیل ہو کر (ایسا کرتے ہیں)، پھر جب خوف (کی حالت) پیش آجائے تو آپ دیکھیں گے کہ وہ آپ کی طرف تکتے ہوں گے (اور) ان کی آنکھیں اس شخص کی طرح گھومتی ہوں گی جس پر موت کی غشی طاری ہو رہی ہو، پھر جب خوف جاتا رہے تو تمہیں تیز زبانوں کے ساتھ طعنے دیں گے (آزردہ کریں گے، ان کا حال یہ ہے کہ) مالِ غنیمت پر بڑے حریص ہیں۔ یہ لوگ (حقیقت میں) ایمان ہی نہیں لائے، سو اﷲ نے ان کے اعمال ضبط کر لئے ہیں اور یہ اﷲ پر آسان تھا،\qt@no{19}}%
\qt@newcmd\qurantrans@ur@mmmdliii{یہ لوگ (ابھی تک یہ) گمان کرتے ہیں کہ کافروں کے لشکر (واپس) نہیں گئے اور اگر وہ لشکر (دوبارہ) آجائیں تو یہ چاہیں گے کہ کاش وہ دیہاتیوں میں جا کر بادیہ نشین ہو جائیں (اور) تمہاری خبریں دریافت کرتے رہیں، اور اگر وہ تمہارے اندر موجود ہوں تو بھی بہت ہی کم لوگوں کے سوا وہ جنگ نہیں کریں گے،\qt@no{20}}%
\qt@newcmd\qurantrans@ur@mmmdliv{فی الحقیقت تمہارے لئے رسول اﷲ (صلی اللہ علیہ وآلہ وسلم کی ذات) میں نہایت ہی حسین نمونۂ (حیات) ہے ہر اُس شخص کے لئے جو اﷲ (سے ملنے) کی اور یومِ آخرت کی امید رکھتا ہے اور اﷲ کا ذکر کثرت سے کرتا ہے،\qt@no{21}}%
\qt@newcmd\qurantrans@ur@mmmdlv{اور جب اہلِ ایمان نے (کافروں کے) لشکر دیکھے تو بول اٹھے کہ یہ ہے جس کا اﷲ اور اس کے رسول نے ہم سے وعدہ فرمایا تھا اور اﷲ اور اس کے رسول نے سچ فرمایا ہے، سو اس (منظر) سے ان کے ایمان اور اطاعت گزاری میں اضافہ ہی ہوا،\qt@no{22}}%
\qt@newcmd\qurantrans@ur@mmmdlvi{مومنوں میں سے (بہت سے) مَردوں نے وہ بات سچ کر دکھائی جس پر انہوں نے اﷲ سے عہد کیا تھا، پس ان میں سے کوئی (تو شہادت پا کر) اپنی نذر پوری کر چکا ہے اور ان میں سے کوئی (اپنی باری کا) انتظار کر رہا ہے، مگر انہوں نے (اپنے عہد میں) ذرا بھی تبدیلی نہیں کی،\qt@no{23}}%
\qt@newcmd\qurantrans@ur@mmmdlvii{یہ) اس لئے کہ اﷲ سچے لوگوں کو ان کی سچائی کا بدلہ دے اور منافقوں کو چاہے تو عذاب دے یا ان کی توبہ قبول فرما لے۔ بیشک اﷲ بڑا بخشنے والا بڑا رحم فرمانے والا ہے،\qt@no{24}}%
\qt@newcmd\qurantrans@ur@mmmdlviii{اور اﷲ نے کافروں کو ان کے غصّہ کی جلن کے ساتھ (مدینہ سے نامراد) واپس لوٹا دیا کہ وہ کوئی کامیابی نہ پا سکے، اور اﷲ ایمان والوں کے لئے جنگِ (احزاب) میں کافی ہوگیا، اور اﷲ بڑی قوت والا عزت والا ہے،\qt@no{25}}%
\qt@newcmd\qurantrans@ur@mmmdlix{اور (بنو قُرَیظہ کے) جن اہلِ کتاب نے ان (کافروں) کی مدد کی تھی اﷲ نے انہیں (بھی) ان کے قلعوں سے اتار دیا اور ان کے دلوں میں (اسلام کا) رعب ڈال دیا، تم (ان میں سے) ایک گروہ کو (ان کے جنگی جرائم کی پاداش میں) قتل کرتے ہو اور ایک گروہ کو جنگی قیدی بناتے ہو،\qt@no{26}}%
\qt@newcmd\qurantrans@ur@mmmdlx{اور اس نے تمہیں ان (جنگی دشمنوں) کی زمین کا اور ان کے گھروں کا اور ان کے اموال کا اوراس (مفتوحہ) زمین کا جِس میں تم نے (پہلے) قدم بھی نہ رکھا تھا مالک بنا دیا، اور اﷲ ہر چیز پر بڑا قادر ہے،\qt@no{27}}%
\qt@newcmd\qurantrans@ur@mmmdlxi{اے نبیِ (مکرَّم!) اپنی اَزواج سے فرما دیں کہ اگر تم دنیا اور اس کی زینت و آرائش کی خواہش مند ہو تو آؤ میں تمہیں مال و متاع دے دوں اور تمہیں حسنِ سلوک کے ساتھ رخصت کر دوں،\qt@no{28}}%
\qt@newcmd\qurantrans@ur@mmmdlxii{اور اگر تم اﷲ اور اس کے رسول اور دارِ آخرت کی طلب گار ہو تو بیشک اﷲ نے تم میں نیکوکار بیبیوں کے لئے بہت بڑا اَجر تیار فرما رکھا ہے،\qt@no{29}}%
\qt@newcmd\qurantrans@ur@mmmdlxiii{اے اَزواجِ نبیِ (مکرّم!) تم میں سے کوئی ظاہری معصیت کی مرتکب ہو تو اس کے لئے عذاب دوگنا کر دیا جائے گا، اور یہ اﷲ پر بہت آسان ہے،\qt@no{30}}%
\qt@newcmd\qurantrans@ur@mmmdlxiv{اور تم میں سے جو اللہ اور اس کے رسول (صلی اللہ علیہ وآلہ وسلم) کی اطاعت گزار رہیں اور نیک اعمال کرتی رہیں تو ہم ان کا ثواب (بھی) انہیں دوگنا دیں گے اور ہم نے اُن کے لئے (جنّت میں) باعزّت رزق تیار کر رکھا ہے،\qt@no{31}}%
\qt@newcmd\qurantrans@ur@mmmdlxv{اے اَزواجِ پیغمبر! تم عورتوں میں سے کسی ایک کی بھی مِثل نہیں ہو، اگر تم پرہیزگار رہنا چاہتی ہو تو (مَردوں سے حسبِ ضرورت) بات کرنے میں نرم لہجہ اختیار نہ کرنا کہ جس کے دل میں (نِفاق کی) بیماری ہے (کہیں) وہ لالچ کرنے لگے اور (ہمیشہ) شک اور لچک سے محفوظ بات کرنا،\qt@no{32}}%
\qt@newcmd\qurantrans@ur@mmmdlxvi{اور اپنے گھروں میں سکون سے قیام پذیر رہنا اور پرانی جاہلیت کی طرح زیب و زینت کا اظہار مت کرنا، اور نماز قائم رکھنا اور زکوٰۃ دیتے رہنا اور اللہ اور اس کے رسول (صلی اللہ علیہ وآلہ وسلم) کی اطاعت گزاری میں رہنا، بس اللہ یہی چاہتا ہے کہ اے (رسول صلی اللہ علیہ وآلہ وسلم کے) اہلِ بیت! تم سے ہر قسم کے گناہ کا میل (اور شک و نقص کی گرد تک) دُور کر دے اور تمہیں (کامل) طہارت سے نواز کر بالکل پاک صاف کر دے،\qt@no{33}}%
\qt@newcmd\qurantrans@ur@mmmdlxvii{اور تم اللہ کی آیتوں کو اور (رسول صلی اللہ علیہ وآلہ وسلم کی) سنت و حکمت کو جن کی تمہارے گھروں میں تلاوت کی جاتی ہے یاد رکھا کرو، بیشک اللہ (اپنے اولیاء کے لئے) صاحبِ لُطف (اور ساری مخلوق کے لئے) خبردار ہے،\qt@no{34}}%
\qt@newcmd\qurantrans@ur@mmmdlxviii{بیشک مسلمان مرد اور مسلمان عورتیں، اور مومن مَرد اور مومن عورتیں، اور فرمانبردار مرد اور فرمانبردار عورتیں، اور صدق والے مرد اور صدق والی عورتیں، اور صبر والے مرد اور صبر والی عورتیں، اور عاجزی والے مرد اور عاجزی والی عورتیں، اور صدقہ و خیرات کرنے والے مرد اور صدقہ و خیرات کرنے والی عورتیں اور روزہ دار مرد اور روزہ دار عورتیں، اور اپنی شرم گاہوں کی حفاظت کرنے والے مرد اور حفاظت کرنے والی عورتیں، اور کثرت سے اللہ کا ذکر کرنے والے مرد اور ذکر کرنے والی عورتیں، اللہ نے اِن سب کے لئے بخشِش اور عظیم اجر تیار فرما رکھا ہے،\qt@no{35}}%
\qt@newcmd\qurantrans@ur@mmmdlxix{اور نہ کسی مومن مرد کو (یہ) حق حاصل ہے اور نہ کسی مومن عورت کو کہ جب اللہ اور اس کا رسول (صلی اللہ علیہ وآلہ وسلم) کسی کام کا فیصلہ (یا حکم) فرما دیں تو ان کے لئے اپنے (اس) کام میں (کرنے یا نہ کرنے کا) کوئی اختیار ہو، اور جو شخص اللہ اور اس کے رسول (صلی اللہ علیہ وآلہ وسلم) کی نافرمانی کرتا ہے تو وہ یقیناً کھلی گمراہی میں بھٹک گیا،\qt@no{36}}%
\qt@newcmd\qurantrans@ur@mmmdlxx{اور (اے حبیب!) یاد کیجئے جب آپ نے اس شخص سے فرمایا جس پر اللہ نے انعام فرمایا تھا اور اس پر آپ نے (بھی) اِنعام فرمایا تھا کہ تُو اپنی بیوی (زینب) کو اپنی زوجیت میں روکے رکھ اور اللہ سے ڈر، اور آپ اپنے دل میں وہ بات٭ پوشیدہ رکھ رہے تھے جِسے اللہ ظاہر فرمانے والا تھا اور آپ (دل میں حیاءً) لوگوں (کی طعنہ زنی) کا خوف رکھتے تھے۔ (اے حبیب! لوگوں کو خاطر میں لانے کی کوئی ضرورت نہ تھی) اور فقط اللہ ہی زیادہ حق دار ہے کہ آپ اس کا خوف رکھیں (اور وہ آپ سے بڑھ کر کس میں ہے؟)، پھر جب (آپ کے متبنٰی) زید نے اسے طلاق دینے کی غرض پوری کرلی، تو ہم نے اس سے آپ کا نکاح کر دیا تاکہ مومنوں پر ان کے منہ بولے بیٹوں کی بیویوں (کے ساتھ نکاح) کے بارے میں کوئی حَرج نہ رہے جبکہ (طلاق دے کر) وہ ان سے بے غَرض ہو گئے ہوں، اور اللہ کا حکم تو پورا کیا جانے والا ہی تھا، ٭: (کہ زینب کی تمہارے ساتھ مصالحت نہ ہو سکے گی اور منشاء ایزدی کے تحت وہ طلاق کے بعد اَزواجِ مطہرات میں داخل ہوں گی۔)\qt@no{37}}%
\qt@newcmd\qurantrans@ur@mmmdlxxi{اور نبی (صلی اللہ علیہ وآلہ وسلم) پر اس کام (کی انجام دہی) میں کوئی حرج نہیں ہے جو اللہ نے ان کے لئے فرض فرما دیا ہے، اللہ کا یہی طریقہ و دستور اُن لوگوں میں (بھی رہا) ہے جو پہلے گزر چکے، اور اللہ کا حکم فیصلہ ہے جو پورا ہوچکا،\qt@no{38}}%
\qt@newcmd\qurantrans@ur@mmmdlxxii{وہ (پہلے) لوگ اللہ کے پیغامات پہنچاتے تھے اور اس کا خوف رکھتے تھے اور اللہ کے سوا کسی سے نہیں ڈرتے تھے، اور اللہ حساب لینے والا کافی ہے،\qt@no{39}}%
\qt@newcmd\qurantrans@ur@mmmdlxxiii{محمد (صلی اللہ علیہ وآلہ وسلم) تمہارے مَردوں میں سے کسی کے باپ نہیں ہیں لیکن وہ اللہ کے رسول ہیں اور سب انبیاء کے آخر میں (سلسلۂ نبوت ختم کرنے والے) ہیں، اور اللہ ہر چیز کا خوب علم رکھنے والا ہے،\qt@no{40}}%
\qt@newcmd\qurantrans@ur@mmmdlxxiv{اے ایمان والو! تم اللہ کا کثرت سے ذکر کیا کرو،\qt@no{41}}%
\qt@newcmd\qurantrans@ur@mmmdlxxv{اور صبح و شام اس کی تسبیح کیا کرو،\qt@no{42}}%
\qt@newcmd\qurantrans@ur@mmmdlxxvi{وہی ہے جو تم پر درود بھیجتا ہے اور اس کے فرشتے بھی، تاکہ تمہیں اندھیروں سے نکال کر نور کی طرف لے جائے اور وہ مومنوں پر بڑی مہربانی فرمانے والا ہے،\qt@no{43}}%
\qt@newcmd\qurantrans@ur@mmmdlxxvii{جس دن وہ (مومِن) اس سے ملاقات کریں گے تو ان (کی ملاقات) کا تحفہ سلام ہوگا، اور اس نے ان کے لئے بڑی عظمت والا اجر تیار کر رکھا ہے،\qt@no{44}}%
\qt@newcmd\qurantrans@ur@mmmdlxxviii{اے نبیِ (مکرّم!) بیشک ہم نے آپ کو (حق اور خَلق کا) مشاہدہ کرنے والا اور (حُسنِ آخرت کی) خوشخبری دینے والا اور (عذابِ آخرت کا) ڈر سنانے والا بنا کر بھیجا ہے،\qt@no{45}}%
\qt@newcmd\qurantrans@ur@mmmdlxxix{اور اس کے اِذن سے اللہ کی طرف دعوت دینے والا اور منوّر کرنے والا آفتاب (بنا کر بھیجا ہے)،\qt@no{46}}%
\qt@newcmd\qurantrans@ur@mmmdlxxx{اور اہلِ ایمان کو اس بات کی بشارت دے دیں کہ ان کے لئے اللہ کا بڑا فضل ہے (کہ وہ اس خاتم الانبیاء کی نسبتِ غلامی میں ہیں)،\qt@no{47}}%
\qt@newcmd\qurantrans@ur@mmmdlxxxi{اور آپ کافروں اور منافقوں کا (یہ) کہنا (کہ ہمارے ساتھ مذہبی سمجھوتہ کر لیں ہرگز) نہ مانیں اور اُن کی ایذاء رسانی سے درگزر فرمائیں، اور اﷲ پر بھروسہ (جاری) رکھیں، اور اﷲ ہی (حق و باطل کی معرکہ آرائی میں) کافی کارساز ہے،\qt@no{48}}%
\qt@newcmd\qurantrans@ur@mmmdlxxxii{اے ایمان والو! جب تم مومن عورتوں سے نکاح کرو پھر تم انہیں طلاق دے دو قبل اس کے کہ تم انہیں مَس کرو (یعنی خلوتِ صحیحہ کرو) تو تمہارے لئے ان پر کوئی عدّت (واجب) نہیں ہے کہ تم اسے شمار کرنے لگو، پس انہیں کچھ مال و متاع دو اور انہیں اچھی طرح حُسنِ سلوک کے ساتھ رخصت کرو،\qt@no{49}}%
\qt@newcmd\qurantrans@ur@mmmdlxxxiii{اے نبی! بیشک ہم نے آپ کے لئے آپ کی وہ بیویاں حلال فرما دی ہیں جن کا مہَر آپ نے ادا فرما دیا ہے اور جو (احکامِ الٰہی کے مطابق) آپ کی مملوک ہیں، جو اللہ نے آپ کو مالِ غنیمت میں عطا فرمائی ہیں، اور آپ کے چچا کی بیٹیاں، اور آپ کی پھوپھیوں کی بیٹیاں، اور آپ کے ماموں کی بیٹیاں، اور آپ کی خالاؤں کی بیٹیاں، جنہوں نے آپ کے ساتھ ہجرت کی ہے اور کوئی بھی مؤمنہ عورت بشرطیکہ وہ اپنے آپ کو نبی (صلی اللہ علیہ وآلہ وسلم کے نکاح) کے لئے دے دے اور نبی (صلی اللہ علیہ وآلہ وسلم بھی) اسے اپنے نکاح میں لینے کا ارادہ فرمائیں (تو یہ سب آپ کے لئے حلال ہیں)، (یہ حکم) صرف آپ کے لئے خاص ہے (امّت کے) مومنوں کے لئے نہیں، واقعی ہمیں معلوم ہے جو کچھ ہم نے اُن (مسلمانوں) پر اُن کی بیویوں اور ان کی مملوکہ باندیوں کے بارے میں فرض کیا ہے، (مگر آپ کے حق میں تعدّدِ ازواج کی حِلّت کا خصوصی حکم اِس لئے ہے) تاکہ آپ پر (امتّ میں تعلیم و تربیتِ نسواں کے وسیع انتظام میں) کوئی تنگی نہ رہے، اور اللہ بڑا بخشنے والا بڑا رحم فرمانے والا ہے،\qt@no{50}}%
\qt@newcmd\qurantrans@ur@mmmdlxxxiv{اے حبیب! آپ کو اختیار ہے) ان میں سے جِس (زوجہ) کو چاہیں (باری میں) مؤخّر رکھیں اور جسے چاہیں اپنے پاس (پہلے) جگہ دیں، اور جن سے آپ نے (عارضی) کنارہ کشی اختیار فرما رکھی تھی آپ انہیں (اپنی قربت کے لئے) طلب فرما لیں تو آپ پر کچھ مضائقہ نہیں، یہ اس کے قریب تر ہے کہ ان کی آنکھیں (آپ کے دیدار سے) ٹھنڈی ہوں گی اور وہ غمگین نہیں رہیں گی اور وہ سب اس سے راضی رہیں گی جو کچھ آپ نے انہیں عطا فرما دیا ہے، اور اللہ جانتا ہے جو کچھ تمہارے دلوں میں ہے، اور اللہ خوب جاننے والا بڑا حِلم والا ہے،\qt@no{51}}%
\qt@newcmd\qurantrans@ur@mmmdlxxxv{اس کے بعد (کہ انہوں نے دنیوی منفعتوں پر آپ کی رضا و خدمت کو ترجیح دے دی ہے) آپ کے لئے بھی اور عورتیں (نکاح میں لینا) حلال نہیں (تاکہ یہی اَزواج اپنے شرف میں ممتاز رہیں) اور یہ بھی جائز نہیں کہ (بعض کی طلاق کی صورت میں اس عدد کو ہمارا حکم سمجھ کر برقرار رکھنے کے لئے) آپ ان کے بدلے دیگر اَزواج (عقد میں) لے لیں اگرچہ آپ کو ان کا حُسنِ (سیرت و اخلاق اور اشاعتِ دین کا سلیقہ) کتنا ہی عمدہ لگے مگر جو کنیز (ہمارے حکم سے) آپ کی مِلک میں ہو (جائز ہے)، اور اللہ ہر چیز پر نگہبان ہے،\qt@no{52}}%
\qt@newcmd\qurantrans@ur@mmmdlxxxvi{اے ایمان والو! نبیِ (مکرّم صلی اللہ علیہ وآلہ وسلم) کے گھروں میں داخل نہ ہوا کرو سوائے اس کے کہ تمہیں کھانے کے لئے اجازت دی جائے (پھر وقت سے پہلے پہنچ کر) کھانا پکنے کا انتظار کرنے والے نہ بنا کرو، ہاں جب تم بلائے جاؤ تو (اس وقت) اندر آیا کرو پھر جب کھانا کھا چکو تو (وہاں سے اُٹھ کر) فوراً منتشر ہوجایا کرو اور وہاں باتوں میں دل لگا کر بیٹھے رہنے والے نہ بنو۔ یقیناً تمہارا ایسے (دیر تک بیٹھے) رہنا نبیِ (اکرم) کو تکلیف دیتا ہے اور وہ تم سے (اُٹھ جانے کا کہتے ہوئے) شرماتے ہیں اور اللہ حق (بات کہنے) سے نہیں شرماتا، اور جب تم اُن (اَزواجِ مطّہرات) سے کوئی سامان مانگو تو اُن سے پسِ پردہ پوچھا کرو، یہ (ادب) تمہارے دلوں کے لئے اور ان کے دلوں کے لئے بڑی طہارت کا سبب ہے، اور تمہارے لئے (ہرگز جائز) نہیں کہ تم رسول اللہ (صلی اللہ علیہ وآلہ وسلم) کو تکلیف پہنچاؤ اور نہ یہ (جائز) ہے کہ تم اُن کے بعد ابَد تک اُن کی اَزواجِ (مطّہرات) سے نکاح کرو، بیشک یہ اللہ کے نزدیک بہت بڑا (گناہ) ہے،\qt@no{53}}%
\qt@newcmd\qurantrans@ur@mmmdlxxxvii{خواہ تم کسی چیز کو ظاہر کرو یا اسے چھپاؤ بیشک اللہ ہر چیز کو خوب جاننے والا ہے،\qt@no{54}}%
\qt@newcmd\qurantrans@ur@mmmdlxxxviii{ان پر (پردہ نہ کرنے میں) کوئی گناہ نہیں اپنے (حقیقی) آباء سے، اور نہ اپنے بیٹوں سے اور نہ اپنے بھائیوں سے، اور نہ اپنے بھتیجوں سے اور نہ اپنے بھانجوں سے اور نہ اپنی (مسلِم) عورتوں اور نہ اپنی مملوک باندیوں سے، تم اللہ کا تقوٰی (برقرار) رکھو، بیشک اللہ ہر چیز پر گواہ و نگہبان ہے،\qt@no{55}}%
\qt@newcmd\qurantrans@ur@mmmdlxxxix{بیشک اللہ اور ا س کے (سب) فرشتے نبیِ (مکرمّ صلی اللہ علیہ وآلہ وسلم) پر درود بھیجتے رہتے ہیں، اے ایمان والو! تم (بھی) اُن پر درود بھیجا کرو اور خوب سلام بھیجا کرو،\qt@no{56}}%
\qt@newcmd\qurantrans@ur@mmmdxc{بیشک جو لوگ اللہ اور اس کے رسول (صلی اللہ علیہ وآلہ وسلم) کو اذیت دیتے ہیں اللہ ان پر دنیا اور آخرت میں لعنت بھیجتا ہے اور اُس نے ان کے لئے ذِلّت انگیز عذاب تیار کر رکھا ہے،\qt@no{57}}%
\qt@newcmd\qurantrans@ur@mmmdxci{اور جو لوگ مومِن مَردوں اور مومِن عورتوں کو اذیتّ دیتے ہیں بغیر اِس کے کہ انہوں نے کچھ (خطا) کی ہو تو بیشک انہوں نے بہتان اور کھلے گناہ کا بوجھ (اپنے سَر) لے لیا،\qt@no{58}}%
\qt@newcmd\qurantrans@ur@mmmdxcii{اے نبی! اپنی بیویوں اور اپنی صاحبزادیوں اور مسلمانوں کی عورتوں سے فرما دیں کہ (باہر نکلتے وقت) اپنی چادریں اپنے اوپر اوڑھ لیا کریں، یہ اس بات کے قریب تر ہے کہ وہ پہچان لی جائیں (کہ یہ پاک دامن آزاد عورتیں ہیں) پھر انہیں (آوارہ باندیاں سمجھ کر غلطی سے) ایذاء نہ دی جائے، اور اللہ بڑا بخشنے والا بڑا رحم فرمانے والا ہے،\qt@no{59}}%
\qt@newcmd\qurantrans@ur@mmmdxciii{اگر منافق لوگ اور وہ لوگ جن کے دلوں میں (رسول صلی اللہ علیہ وآلہ وسلم سے بُغض اور گستاخی کی) بیماری ہے، اور (اسی طرح) مدینہ میں جھوٹی افواہیں پھیلانے والے لوگ (رسول صلی اللہ علیہ وآلہ وسلم کو ایذاء رسانی سے) باز نہ آئے تو ہم آپ کو ان پر ضرور مسلّط کر دیں گے پھر وہ مدینہ میں آپ کے پڑوس میں نہ ٹھہر سکیں گے مگر تھوڑے (دن)،\qt@no{60}}%
\qt@newcmd\qurantrans@ur@mmmdxciv{یہ) لعنت کئے ہوئے لوگ جہاں کہیں پائے جائیں، پکڑ لئے جائیں اور چُن چُن کر بری طرح قتل کر دیئے جائیں،\qt@no{61}}%
\qt@newcmd\qurantrans@ur@mmmdxcv{اللہ کی (یہی) سنّت اُن لوگوں میں (بھی جاری رہی) ہے جو پہلے گزر چکے ہیں، اور آپ اللہ کے دستور میں ہرگز کوئی تبدیلی نہ پائیں گے،\qt@no{62}}%
\qt@newcmd\qurantrans@ur@mmmdxcvi{لوگ آپ سے قیامت کے (وقت کے) بارے میں دریافت کرتے ہیں۔ فرما دیجئے: اس کا علم تو اللہ ہی کے پاس ہے، اور آپ کو کس نے آگاہ کیا شاید قیامت قریب ہی آچکی ہو،\qt@no{63}}%
\qt@newcmd\qurantrans@ur@mmmdxcvii{بیشک اللہ نے کافروں پر لعنت فرمائی ہے اور اُن کے لِئے (دوزخ کی) بھڑکتی آگ تیار کر رکھی ہے،\qt@no{64}}%
\qt@newcmd\qurantrans@ur@mmmdxcviii{جِس میں وہ ہمیشہ ہمیشہ رہنے والے ہیں۔ نہ وہ کوئی حمایتی پائیں گے اور نہ مددگار،\qt@no{65}}%
\qt@newcmd\qurantrans@ur@mmmdxcix{جِس دن ان کے مُنہ آتشِ دوزخ میں (بار بار) الٹائے جائیں گے (تو) وہ کہیں گے: اے کاش! ہم نے اللہ کی اطاعت کی ہوتی اور ہم نے رسول (صلی اللہ علیہ وآلہ وسلم) کی اطاعت کی ہوتی،\qt@no{66}}%
\qt@newcmd\qurantrans@ur@mmmdc{اور وہ کہیں گے: اے ہمارے رب! بیشک ہم نے اپنے سرداروں اور اپنے بڑوں کا کہا مانا تھا تو انہوں نے ہمیں (سیدھی) راہ سے بہکا دیا،\qt@no{67}}%
\qt@newcmd\qurantrans@ur@mmmdci{اے ہمارے رب! انہیں دوگنا عذاب دے اور اُن پر بہت بڑی لعنت کر،\qt@no{68}}%
\qt@newcmd\qurantrans@ur@mmmdcii{اے ایمان والو! تم اُن لوگوں کی طرح نہ ہوجانا جنہوں نے موسٰی (علیہ السلام) کو (گستاخانہ کلمات کے ذریعے) اذیت پہنچائی، پس اللہ نے انہیں اُن باتوں سے بے عیب ثابت کردیا جو وہ کہتے تھے، اور وہ (موسٰی علیہ السلام) اللہ کے ہاں بڑی قدر و منزلت والے تھے،\qt@no{69}}%
\qt@newcmd\qurantrans@ur@mmmdciii{اے ایمان والو! اللہ سے ڈرا کرو اور صحیح اور سیدھی بات کہا کرو،\qt@no{70}}%
\qt@newcmd\qurantrans@ur@mmmdciv{وہ تمہارے لئے تمہارے (سارے) اعمال درست فرما دے گا اور تمہارے گناہ تمہارے لئے بخش دے گا، اور جو شخص اللہ اور اس کے رسول کی فرمانبرداری کرتا ہے تو بیشک وہ بڑی کامیابی سے سرفراز ہوا،\qt@no{71}}%
\qt@newcmd\qurantrans@ur@mmmdcv{بیشک ہم نے (اِطاعت کی) امانت آسمانوں اور زمین اور پہاڑوں پر پیش کی تو انہوں نے اس (بوجھ) کے اٹھانے سے انکار کر دیا اور اس سے ڈر گئے اور انسان نے اسے اٹھا لیا، بیشک وہ (اپنی جان پر) بڑی زیادتی کرنے والا (ادائیگئ امانت میں کوتاہی کے انجام سے) بڑا بے خبر و نادان ہے،\qt@no{72}}%
\qt@newcmd\qurantrans@ur@mmmdcvi{یہ) اس لئے کہ اللہ منافق مَردوں اورمنافق عورتوں اور مشرِک مَردوں اور مشرِک عورتوں کو عذاب دے اور اللہ مومِن مَردوں اور مومِن عورتوں کی توبہ قبول فرمائے، اور اللہ بڑا بخشنے والا بڑا رحم فرمانے والا ہے،\qt@no{73}}%
\qt@newcmd\qurantrans@ur@mmmdcvii{\basmalahur تمام تعریفیں اﷲ ہی کے لئے ہیں، جو کچھ آسمانوں میں ہے اور جو کچھ زمین میں ہے (سب) اسی کا ہے اور آخرت میں بھی تعریف اسی کے لئے ہے، اور وہ بڑی حکمت والا، خبردار ہے،\qt@no{1}}%
\qt@newcmd\qurantrans@ur@mmmdcviii{وہ اُن (سب) چیزوں کو جانتا ہے جو زمین میں داخل ہوتی ہیں اور جو اس میں سے باہر نکلتی ہیں اور جو آسمان سے اترتی ہیں اور جو اس میں چڑھتی ہیں، اور وہ بہت رحم فرمانے والا بڑا بخشنے والا ہے،\qt@no{2}}%
\qt@newcmd\qurantrans@ur@mmmdcix{اور کافر لوگ کہتے ہیں کہ ہم پر قیامت نہیں آئے گی، آپ فرما دیں: کیوں نہیں؟ میرے عالم الغیب رب کی قسم! وہ تم پر ضرور آئے گی، اس سے نہ آسمانوں میں ذرّہ بھر کوئی چیز غائب ہو سکتی ہے اور نہ زمین میں اور نہ اس سے کوئی چھوٹی (چیز ہے) اور نہ بڑی مگر روشن کتاب (یعنی لوحِ محفوظ) میں (لکھی ہوئی) ہے،\qt@no{3}}%
\qt@newcmd\qurantrans@ur@mmmdcx{تاکہ اﷲ ان لوگوں کو پورا بدلہ عطا فرمائے جو ایمان لائے اور نیک عمل کرتے رہے۔ یہی وہ لوگ ہیں جن کے لئے بخشِش اور بزرگی والا (اخروی) رِزق ہے،\qt@no{4}}%
\qt@newcmd\qurantrans@ur@mmmdcxi{اور جنہوں نے ہماری آیتوں میں (مخالفانہ) کوشش کی (ہمیں) عاجز کرنے کے زعم میں انہی لوگوں کے لئے سخت دردناک عذاب کی سزا ہے،\qt@no{5}}%
\qt@newcmd\qurantrans@ur@mmmdcxii{اور ایسے لوگ جنہیں علم دیا گیا ہے وہ جانتے ہیں کہ جو (کتاب) آپ کے رب کی طرف سے آپ کی جانب اتاری گئی ہے وہی حق ہے اور وہ (کتاب) عزت والے، سب خوبیوں والے (رب) کی راہ کی طرف ہدایت کرتی ہے،\qt@no{6}}%
\qt@newcmd\qurantrans@ur@mmmdcxiii{اور کافر لوگ (تعجب و استہزاء کی نیت سے) کہتے ہیں کہ کیا ہم تمہیں ایسے شخص کا بتائیں جو تمہیں یہ خبر دیتا ہے کہ جب تم (مَر کر) بالکل ریزہ ریزہ ہوجاؤ گے تو یقیناً تمہیں (ایک) نئی پیدائش ملے گی،\qt@no{7}}%
\qt@newcmd\qurantrans@ur@mmmdcxiv{یا تو) وہ اﷲ پر جھوٹا بہتان باندھتا ہے یا اسے جنون ہے، (ایسا کچھ بھی نہیں) بلکہ جو لوگ آخرت پر ایمان نہیں رکھتے وہ عذاب اور پرلے درجہ کی گمراہی میں (مبتلا) ہیں،\qt@no{8}}%
\qt@newcmd\qurantrans@ur@mmmdcxv{سو کیا انہوں نے اُن (نشانیوں) کو نہیں دیکھا جو آسمان اور زمین سے اُن کے آگے اور اُن کے پیچھے (انہیں گھیرے ہوئے) ہیں۔ اگر ہم چاہیں تو انہیں زمین میں دھنسا دیں یا اُن پر آسمان سے کچھ ٹکڑے گرا دیں، بیشک اس میں ہر اس بندے کے لئے نشانی ہے جو اﷲ کی طرف رجوع کرنے والا ہے،\qt@no{9}}%
\qt@newcmd\qurantrans@ur@mmmdcxvi{اور بیشک ہم نے داؤد (علیہ السلام) کو اپنی بارگاہ سے بڑا فضل عطا فرمایا، (اور حکم فرمایا:) اے پہاڑو! تم اِن کے ساتھ مل کر خوش اِلحانی سے (تسبیح) پڑھا کرو، اور پرندوں کو بھی (مسخّر کر کے یہی حکم دیا)، اور ہم نے اُن کے لئے لوہا نرم کر دیا،\qt@no{10}}%
\qt@newcmd\qurantrans@ur@mmmdcxvii{اور ارشاد فرمایا) کہ کشادہ زرہیں بناؤ اور (ان کے) حلقے جوڑنے میں اندازے کو ملحوظ رکھو اور (اے آلِ داوؤد!) تم لوگ نیک عمل کرتے رہو، میں اُن (کاموں) کو جو تم کرتے ہو خوب دیکھنے والا ہوں،\qt@no{11}}%
\qt@newcmd\qurantrans@ur@mmmdcxviii{اور سلیمان (علیہ السلام) کے لئے (ہم نے) ہوا کو (مسخّر کر دیا) جس کی صبح کی مسافت ایک مہینہ کی (راہ) تھی اور اس کی شام کی مسافت (بھی) ایک ماہ کی راہ ہوتی، اور ہم نے اُن کے لئے پگھلے ہوئے تانبے کا چشمہ بہا دیا، اور کچھ جنّات (ان کے تابع کردیئے) تھے جو اُن کے رب کے حکم سے اُن کے سامنے کام کرتے تھے، اور (فرما دیا تھا کہ) ان میں سے جو کوئی ہمارے حکم سے پھرے گا ہم اسے دوزخ کی بھڑکتی آگ کا عذاب چکھائیں گے،\qt@no{12}}%
\qt@newcmd\qurantrans@ur@mmmdcxix{وہ (جنّات) ان کے لئے جو وہ چاہتے تھے بنا دیتے تھے۔ اُن میں بلند و بالا قلعے اور مجسّمے اور بڑے بڑے لگن تھے جو تالاب اور لنگر انداز دیگوں کی مانند تھے۔ اے آلِ داؤد! (اﷲ کا) شکر بجا لاتے رہو، اور میرے بندوں میں شکرگزار کم ہی ہوئے ہیں،\qt@no{13}}%
\qt@newcmd\qurantrans@ur@mmmdcxx{پھر جب ہم نے سلیمان (علیہ السلام) پر موت کا حکم صادر فرما دیا تو اُن (جنّات) کو ان کی موت پر کسی نے آگاہی نہ کی سوائے زمین کی دیمک کے جو اُن کے عصا کو کھاتی رہی، پھر جب آپ کا جسم زمین پر آگیا تو جنّات پر ظاہر ہوگیا کہ اگر وہ غیب جانتے ہوتے تو اس ذلّت انگیز عذاب میں نہ پڑے رہتے،\qt@no{14}}%
\qt@newcmd\qurantrans@ur@mmmdcxxi{درحقیقت (قومِ) سبا کے لئے ان کے وطن ہی میں نشانی موجود تھی۔ (وہ) دو باغ تھے، دائیں طرف اور بائیں طرف۔ (اُن سے ارشاد ہوا:) تم اپنے رب کے رزق سے کھایا کرو اور اس کا شکر بجا لایا کرو۔ (تمہارا) شہر (کتنا) پاکیزہ ہے اور رب بڑا بخشنے والا ہے،\qt@no{15}}%
\qt@newcmd\qurantrans@ur@mmmdcxxii{پھر انہوں نے (طاعت سے) مُنہ پھیر لیا تو ہم نے ان پر زور دار سیلاب بھیج دیا اور ہم نے اُن کے دونوں باغوں کو دو (ایسے) باغوں سے بدل دیا جن میں بدمزہ پھل اور کچھ جھاؤ اور کچھ تھوڑے سے بیری کے درخت رہ گئے تھے،\qt@no{16}}%
\qt@newcmd\qurantrans@ur@mmmdcxxiii{یہ ہم نے انہیں ان کے کفر و ناشکری کا بدلہ دیا، اور ہم بڑے ناشکرگزار کے سوا (کسی کو ایسی) سزا نہیں دیتے،\qt@no{17}}%
\qt@newcmd\qurantrans@ur@mmmdcxxiv{اور ہم نے ان باشندوں کے اور ان بستیوں کے درمیان جن میں ہم نے برکت دے رکھی تھی، (یمن سے شام تک) نمایاں (اور) متصل بستیاں آباد کر دی تھیں، اور ہم نے ان میں آمد و رفت (کے دوران آرام کرنے) کی منزلیں مقرر کر رکھی تھیں کہ تم لوگ ان میں راتوں کو (بھی) اور دنوں کو (بھی) بے خوف ہو کر چلتے پھرتے رہو،\qt@no{18}}%
\qt@newcmd\qurantrans@ur@mmmdcxxv{تو وہ کہنے لگے: اے ہمارے رب! ہماری منازلِ سفر کے درمیان فاصلے پیدا کر دے، اور انہوں نے اپنی جانوں پر ظلم کیا تو ہم نے انہیں (عبرت کے) فسانے بنا دیا اور ہم نے انہیں ٹکڑے ٹکڑے کر کے منتشر کر دیا۔ بیشک اس میں بہت صابر اور نہایت شکر گزار شخص کے لئے نشانیاں ہیں،\qt@no{19}}%
\qt@newcmd\qurantrans@ur@mmmdcxxvi{بیشک ابلیس نے ان کے بارے میں اپنا خیال سچ کر دکھایا تو ان لوگوں نے اس کی پیروی کی بجز ایک گروہ کے جو (صحیح) مومنین کا تھا،\qt@no{20}}%
\qt@newcmd\qurantrans@ur@mmmdcxxvii{اور شیطان کا ان پر کچھ زور نہ تھا مگر یہ اس لئے (ہوا) کہ ہم ان لوگوں کو جو آخرت پر ایمان رکھتے ہیں ان لوگوں سے ممتاز کر دیں جو اس کے بارے میں شک میں ہیں، اور آپ کا رب ہر چیز پر نگہبان ہے،\qt@no{21}}%
\qt@newcmd\qurantrans@ur@mmmdcxxviii{فرما دیجئے: تم انہیں بلا لو جنہیں تم اللہ کے سوا (معبود) سمجھتے ہو، وہ آسمانوں میں ذرّہ بھر کے مالک نہیں ہیں اور نہ زمین میں، اور نہ ان کی دونوں (زمین و آسمان) میں کوئی شراکت ہے اور نہ ان میں سے کوئی اللہ کا مددگار ہے،\qt@no{22}}%
\qt@newcmd\qurantrans@ur@mmmdcxxix{اور اس کی بارگاہ میں شفاعت نفع نہ دے گی سوائے جس کے حق میں اس نے اِذن دیا ہوگا، یہاں تک کہ جب ان کے دلوں سے گھبراہٹ دور کر دی جائے گی تو وہ (سوالاً) کہیں گے کہ تمہارے رب نے کیا فرمایا؟ وہ (جواباً) کہیں گے: 'حق فرمایا' (یعنی اذن دے دیا)، وہی نہایت بلند، بہت بڑا ہے،\qt@no{23}}%
\qt@newcmd\qurantrans@ur@mmmdcxxx{آپ فرمائیے: تمہیں آسمانوں اور زمین سے روزی کون دیتا ہے، آپ (خود ہی) فرما دیجئے کہ اللہ (دیتا ہے)، اور بیشک ہم یا تم ضرور ہدایت پر ہیں یا کھلی گمراہی میں،\qt@no{24}}%
\qt@newcmd\qurantrans@ur@mmmdcxxxi{فرما دیجئے: تم سے اس جرم کی باز پرس نہ ہوگی جو (تمہارے گمان میں) ہم سے سرزد ہوا اور نہ ہم سے اس کا پوچھا جائے گا جو تم کرتے ہو،\qt@no{25}}%
\qt@newcmd\qurantrans@ur@mmmdcxxxii{فرما دیجئے: ہم سب کو ہمارا رب (روزِ قیامت) جمع فرمائے گا پھر ہمارے درمیان حق کے ساتھ فیصلہ فرمائے گا، اور وہ خوب فیصلہ فرمانے والا خوب جاننے والا ہے،\qt@no{26}}%
\qt@newcmd\qurantrans@ur@mmmdcxxxiii{فرما دیجئے: مجھے وہ شریک دکھاؤ جنہیں تم نے اللہ کے ساتھ ملا رکھا ہے، ہرگز (کوئی شریک) نہیں ہے! بلکہ وہی اللہ بڑی عزت والا، بڑی حکمت والا ہے،\qt@no{27}}%
\qt@newcmd\qurantrans@ur@mmmdcxxxiv{اور (اے حبیبِ مکرّم!) ہم نے آپ کو نہیں بھیجا مگر اس طرح کہ (آپ) پوری انسانیت کے لئے خوشخبری سنانے والے اور ڈر سنانے والے ہیں لیکن اکثر لوگ نہیں جانتے،\qt@no{28}}%
\qt@newcmd\qurantrans@ur@mmmdcxxxv{اور وہ کہتے ہیں کہ یہ وعدۂ (آخرت) کب پورا ہوگا اگر تم سچے ہو،\qt@no{29}}%
\qt@newcmd\qurantrans@ur@mmmdcxxxvi{فرما دیجئے: تمہارے لئے وعدہ کا دن مقرر ہے نہ تم اس سے ایک گھڑی پیچھے رہو گے اور نہ آگے بڑھ سکو گے،\qt@no{30}}%
\qt@newcmd\qurantrans@ur@mmmdcxxxvii{اور کافر لوگ کہتے ہیں کہ ہم اس قرآن پر ہرگز ایمان نہیں لائیں گے اور نہ اس (وحی) پر جو اس سے پہلے اتر چکی، اور اگر آپ دیکھیں جب ظالم لوگ اپنے رب کے حضور کھڑے کئے جائیں گے (تو کیا منظر ہوگا) کہ ان میں سے ہر ایک (اپنی) بات پھیر کر دوسرے پر ڈال رہا ہوگا، کمزور لوگ متکبّروں سے کہیں گے: اگر تم نہ ہوتے تو ہم ضرور ایمان لے آتے،\qt@no{31}}%
\qt@newcmd\qurantrans@ur@mmmdcxxxviii{متکبرّ لوگ کمزوروں سے کہیں گے: کیا ہم نے تمہیں ہدایت سے روکا اس کے بعد کہ وہ تمہارے پاس آچکی تھی، بلکہ تم خود ہی مُجرم تھے،\qt@no{32}}%
\qt@newcmd\qurantrans@ur@mmmdcxxxix{پھر کمزور لوگ متکبرّوں سے کہیں گے: بلکہ (تمہارے) رات دن کے مَکر ہی نے (ہمیں روکا تھا) جب تم ہمیں حکم دیتے تھے کہ ہم اللہ سے کفر کریں اور ہم اس کے لئے شریک ٹھہرائیں، اور وہ (ایک دوسرے سے) ندامت چھپائیں گے جب وہ عذاب دیکھ لیں گے اور ہم کافروں کی گردنوں میں طوق ڈال دیں گے، اور انہیں اُن کے کئے کا ہی بدلہ دیا جائے گا،\qt@no{33}}%
\qt@newcmd\qurantrans@ur@mmmdcxl{اور ہم نے کسی بستی میں کوئی ڈر سنانے والا نہیں بھیجا مگر یہ کہ وہاں کے خوشحال لوگوں نے (ہمیشہ یہی) کہا کہ تم جو (ہدایت) دے کر بھیجے گئے ہو ہم اس کے مُنکِر ہیں،\qt@no{34}}%
\qt@newcmd\qurantrans@ur@mmmdcxli{اور انہوں نے کہا کہ ہم مال و اولاد میں بہت زیادہ ہیں اور ہم پر عذاب نہیں کیا جائے گا،\qt@no{35}}%
\qt@newcmd\qurantrans@ur@mmmdcxlii{فرما دیجئے: میرا رب جس کے لئے چاہتا ہے رِزق کشادہ فرما دیتا ہے اور (جس کے لئے چاہتا ہے) تنگ کر دیتا ہے لیکن اکثر لوگ نہیں جانتے،\qt@no{36}}%
\qt@newcmd\qurantrans@ur@mmmdcxliii{اور نہ تمہارے مال اس قابل ہیں اور نہ تمہاری اولاد کہ تمہیں ہمارے حضور قرب اور نزدیکی دلا سکیں مگر جو ایمان لایا اور اس نے نیک عمل کئے، پس ایسے ہی لوگوں کے لئے دوگنا اجر ہے ان کے عمل کے بدلے میں اور وہ (جنت کے) بالاخانوں میں امن و امان سے ہوں گے،\qt@no{37}}%
\qt@newcmd\qurantrans@ur@mmmdcxliv{اور جو لوگ ہماری آیتوں میں (مخالفانہ) کوشش کرتے ہیں (ہمیں) عاجز کرنے کے گمان میں، وہی لوگ عذاب میں حاضر کئے جائیں گے،\qt@no{38}}%
\qt@newcmd\qurantrans@ur@mmmdcxlv{فرما دیجئے: بیشک میرا رب اپنے بندوں میں سے جس کے لئے چاہتا ہے رِزق کشادہ فرما دیتا ہے اور جس کے لئے (چاہتا ہے) تنگ کر دیتا ہے، اور تم (اﷲ کی راہ میں) جو کچھ بھی خرچ کرو گے تو وہ اس کے بدلہ میں اور دے گا اور وہ سب سے بہتر رِزق دینے والا ہے،\qt@no{39}}%
\qt@newcmd\qurantrans@ur@mmmdcxlvi{اور جس دن وہ سب کو ایک ساتھ جمع کرے گا پھر فرشتوں سے ارشاد فرمائے گا: کیا یہی لوگ ہیں جو تمہاری عبادت کیا کرتے تھے،\qt@no{40}}%
\qt@newcmd\qurantrans@ur@mmmdcxlvii{وہ عرض کریں گے: تو پاک ہے تو ہی ہمارا دوست ہے نہ کہ یہ لوگ، بلکہ یہ لوگ جنات کی پوجا کیا کرتے تھے، ان میں سے اکثر اُنہی پر ایمان رکھنے والے ہیں،\qt@no{41}}%
\qt@newcmd\qurantrans@ur@mmmdcxlviii{پس آج کے دن تم میں سے کوئی نہ ایک دوسرے کے نفع کا مالک ہے اور نہ نقصان کا، اور ہم ظالموں سے کہیں گے: دوزخ کے عذاب کا مزہ چکھو جسے تم جھٹلایا کرتے تھے،\qt@no{42}}%
\qt@newcmd\qurantrans@ur@mmmdcxlix{اور جب اُن پر ہماری روشن آیتیں پڑھ کر سنائی جاتی ہیں تو وہ کہتے ہیں: یہ (رسول صلی اللہ علیہ وآلہ وسلم) تو ایک ایسا شخص ہے جو تمہیں صرف اُن (بتوں) سے روکنا چاہتا ہے جن کی تمہارے باپ دادا پوجا کیا کرتے تھے، اور یہ (بھی) کہتے ہیں کہ یہ (قرآن) محض من گھڑت بہتان ہے، اور کافر لوگ اس حق (یعنی قرآن) سے متعلق جبکہ وہ اِن کے پاس آچکا ہے، یہ بھی کہتے ہیں کہ یہ تو محض کھلا جادو ہے،\qt@no{43}}%
\qt@newcmd\qurantrans@ur@mmmdcl{اور ہم نے ان (اہلِ مکہّ) کو نہ آسمانی کتابیں عطا کی تھیں جنہیں یہ لوگ پڑھتے ہوں اور نہ ہی آپ سے پہلے ان کی طرف کوئی ڈر سنانے والا بھیجا تھا،\qt@no{44}}%
\qt@newcmd\qurantrans@ur@mmmdcli{اور اِن سے پہلے لوگوں نے بھی (حق کو) جھٹلایا تھا اور یہ اس کے دسویں حصّے کو بھی نہیں پہنچے جو کچھ ہم نے اُن (پہلے گزرے ہوؤں) کو دیا تھا پھر انہوں نے (بھی) میرے رسولوں کو جھٹلایا، سو میرا انکار کیسا (عبرت ناک ثابت) ہوا،\qt@no{45}}%
\qt@newcmd\qurantrans@ur@mmmdclii{فرما دیجئے: میں تمہیں بس ایک ہی (بات کی) نصیحت کرتا ہوں کہ تم اﷲ کے لئے (روحانی بیداری اور انتباہ کے حال میں) قیام کرو، دو دو اور ایک ایک، پھر تفکّر کرو (یعنی حقیقت کا معاینہ اور مراقبہ کرو تو تمہیں مشاہدہ ہو جائے گا) کہ تمہیں شرفِ صحبت سے نوازنے والے (رسولِ مکرّم صلی اللہ علیہ وآلہ وسلم) ہرگز جنون زدہ نہیں ہیں وہ تو سخت عذاب (کے آنے) سے پہلے تمہیں (بروقت) ڈر سنانے والے ہیں (تاکہ تم غفلت سے جاگ اٹھو)،\qt@no{46}}%
\qt@newcmd\qurantrans@ur@mmmdcliii{فرما دیجئے: میں نے (اس اِحسان کا) جو صلہ تم سے مانگا ہو وہ بھی تم ہی کو دے دیا، میرا اجر صرف اﷲ ہی کے ذمّہ ہے، اور وہ ہر چیز پر نگہبان ہے،\qt@no{47}}%
\qt@newcmd\qurantrans@ur@mmmdcliv{فرما دیجئے: میرا رب (انبیاء کی طرف) حق کا القاء فرماتا ہے (وہ) سب غیبوں کو خوب جاننے والا ہے،\qt@no{48}}%
\qt@newcmd\qurantrans@ur@mmmdclv{فرما دیجئے: حق آگیا ہے اور باطل نہ (کچھ) پہلی بار پیدا کر سکتا ہے اور نہ دوبارہ پلٹا سکتا ہے،\qt@no{49}}%
\qt@newcmd\qurantrans@ur@mmmdclvi{فرما دیجئے: اگر میں بہک جاؤں تو میرے بہکنے کا گناہ (یا نقصان) میری اپنی ہی ذات پر ہے، اور اگر میں نے ہدایت پا لی ہے تو اس وجہ سے (پائی ہے) کہ میرا رب میری طرف وحی بھیجتا ہے۔ بیشک وہ سننے والا ہے قریب ہے،\qt@no{50}}%
\qt@newcmd\qurantrans@ur@mmmdclvii{اور اگر آپ (ان کا حال) دیکھیں جب یہ لوگ بڑے مضطرب ہوں گے، پھر بچ نہ سکیں گے اور نزدیکی جگہ سے ہی پکڑ لئے جائیں گے،\qt@no{51}}%
\qt@newcmd\qurantrans@ur@mmmdclviii{اور کہیں گے: ہم اس پر ایمان لے آئے ہیں، مگر اب وہ (ایمان کو اتنی) دُور کی جگہ سے کہاں پا سکتے ہیں،\qt@no{52}}%
\qt@newcmd\qurantrans@ur@mmmdclix{حالانکہ وہ اس سے پہلے کفر کر چکے، اور وہ بِن دیکھے دور کی جگہ سے باطل گمان کے تیر پھینکتے رہے ہیں،\qt@no{53}}%
\qt@newcmd\qurantrans@ur@mmmdclx{اور ان کے اور ان کی خواہشات کے درمیان رکاوٹ ڈال دی گئی جیسا کہ پہلے اُن کے مثل گروہوں کے ساتھ کیا گیا تھا۔ بیشک وہ دھوکہ میں ڈالنے والے شک میں مبتلا تھے،\qt@no{54}}%
\qt@newcmd\qurantrans@ur@mmmdclxi{\basmalahur تمام تعریفیں اﷲ ہی کے لئے ہیں جو آسمانوں اور زمین (کی تمام وسعتوں) کا پیدا فرمانے والا ہے، فرشتوں کو جو دو دو اور تین تین اور چار چار پَروں والے ہیں، قاصد بنانے والا ہے، اور تخلیق میں جس قدر چاہتا ہے اضافہ (اور توسیع) فرماتا رہتا ہے، بیشک اﷲ ہر چیز پر بڑا قادر ہے،\qt@no{1}}%
\qt@newcmd\qurantrans@ur@mmmdclxii{اﷲ انسانوں کے لئے (اپنے خزانۂ) رحمت سے جو کچھ کھول دے تو اسے کوئی روکنے والا نہیں ہے، اور جو روک لے تو اس کے بعد کوئی اسے چھوڑنے والا نہیں، اور وہی غالب ہے بڑی حکمت والا ہے،\qt@no{2}}%
\qt@newcmd\qurantrans@ur@mmmdclxiii{اے لوگو! اپنے اوپر اﷲ کے انعام کو یاد کرو، کیا اﷲ کے سوا کوئی اور خالق ہے جو تمہیں آسمان اور زمین سے روزی دے، اس کے سوا کوئی معبود نہیں، پس تم کہاں بہکے پھرتے ہو،\qt@no{3}}%
\qt@newcmd\qurantrans@ur@mmmdclxiv{اور اگر وہ آپ کو جھٹلائیں تو آپ سے پہلے کتنے ہی رسول جھٹلائے گئے، اور تمام کام اﷲ ہی کی طرف لوٹائے جائیں گے،\qt@no{4}}%
\qt@newcmd\qurantrans@ur@mmmdclxv{اے لوگو! بیشک اﷲ کا وعدہ سچا ہے سو دنیا کی زندگی تمہیں ہرگز فریب نہ دے دے، اور نہ وہ دغا باز شیطان تمہیں اﷲ (کے نام) سے دھوکہ دے،\qt@no{5}}%
\qt@newcmd\qurantrans@ur@mmmdclxvi{بیشک شیطان تمہارا دشمن ہے سو تم بھی (اس کی مخالفت کی شکل میں) اسے دشمن ہی بنائے رکھو، وہ تو اپنے گروہ کو صرف اِس لئے بلاتا ہے کہ وہ دوزخیوں میں شامل ہو جائیں،\qt@no{6}}%
\qt@newcmd\qurantrans@ur@mmmdclxvii{کافر لوگوں کے لئے سخت عذاب ہے، اور جو لوگ ایمان لائے اور نیک اعمال کرتے رہے ان کے لئے مغفرت اور بہت بڑا ثواب ہے،\qt@no{7}}%
\qt@newcmd\qurantrans@ur@mmmdclxviii{بھلا جس شخص کے لئے اس کا برا عمل آراستہ کر دیا گیا ہو اور وہ اسے (حقیقتاً) اچھا سمجھنے لگے (کیا وہ مومنِ صالح جیسا ہو سکتا ہے)، سو بیشک اﷲ جسے چاہتا ہے گمراہ ٹھہرا دیتا ہے اور جسے چاہتا ہے ہدایت فرماتا ہے، سو (اے جانِ جہاں!) ان پر حسرت اور فرطِ غم میں آپ کی جان نہ جاتی رہے، بیشک وہ جو کچھ سرانجام دیتے ہیں اﷲ اسے خوب جاننے والا ہے،\qt@no{8}}%
\qt@newcmd\qurantrans@ur@mmmdclxix{اور اﷲ ہی ہے جو ہوائیں بھیجتا ہے تو وہ بادل کو ابھار کر اکٹھا کرتی ہیں پھر ہم اس (بادل) کو خشک اور بنجر بستی کی طرف سیرابی کے لئے لے جاتے ہیں، پھر ہم اس کے ذریعے اس زمین کو اس کی مُردنی کے بعد زندگی عطا کرتے ہیں، اسی طرح (مُردوں کا) جی اٹھنا ہوگا،\qt@no{9}}%
\qt@newcmd\qurantrans@ur@mmmdclxx{جو شخص عزت چاہتا ہے تو اﷲ ہی کے لئے ساری عزت ہے، پاکیزہ کلمات اسی کی طرف چڑھتے ہیں اور وہی نیک عمل(کے مدارج) کو بلند فرماتا ہے، اور جو لوگ بری چالوں میں لگے رہتے ہیں ان کے لئے سخت عذاب ہے اور ان کا مکر و فریب نیست و نابود ہو جائے گا،\qt@no{10}}%
\qt@newcmd\qurantrans@ur@mmmdclxxi{اور اﷲ ہی نے تمہیں مٹی (یعنی غیر نامی مادّہ) سے پیدا فرمایا پھر ایک تولیدی قطرہ سے، پھر تمہیں جوڑے جوڑے بنایا، اور کوئی مادّہ حاملہ نہیں ہوتی اور نہ بچہ جنتی ہے مگر اس کے علم سے، اور نہ کسی دراز عمر شخص کی عمر بڑھائی جاتی ہے اور نہ اس کی عمر کم کی جاتی ہے مگر (یہ سب کچھ) لوحِ (محفوظ) میں ہے، بیشک یہ اﷲ پر بہت آسان ہے،\qt@no{11}}%
\qt@newcmd\qurantrans@ur@mmmdclxxii{اور دو سمندر (یا دریا) برابر نہیں ہو سکتے، یہ (ایک) شیریں، پیاس بجھانے والا ہے، اس کا پینا خوشگوار ہے اور یہ (دوسرا) کھاری، سخت کڑوا ہے، اور تم ہر ایک سے تازہ گوشت کھاتے ہو، اور زیور (جن میں موتی، مرجان اور مونگے وغیرہ سب شامل ہیں) نکالتے ہو، جنہیں تم پہنتے ہو اور تُو اس میں کشتیوں (اور جہازوں) کو دیکھتا ہے جو (پانی کو) پھاڑتے چلے جاتے ہیں تاکہ تم (بحری تجارت کے راستوں سے) اس کا فضل تلاش کر سکو اور تاکہ تم شکرگزار ہو جاؤ،\qt@no{12}}%
\qt@newcmd\qurantrans@ur@mmmdclxxiii{وہ رات کو دن میں داخل فرماتا ہے اور دن کو رات میں داخل فرماتا ہے اور اس نے سورج اور چاند کو (ایک نظام کے تحت) مسخرّ فرما رکھا ہے، ہر کوئی ایک مقرر میعاد کے مطابق حرکت پذیر ہے۔ یہی اﷲ تمہارا رب ہے اسی کی ساری بادشاہت ہے، اور اس کے سوا تم جن بتوں کو پوجتے ہو وہ کھجور کی گٹھلی کے باریک چھلکے کے (بھی) مالک نہیں ہیں،\qt@no{13}}%
\qt@newcmd\qurantrans@ur@mmmdclxxiv{اے مشرکو!) اگر تم انہیں پکارو تو وہ (بت ہیں) تمہاری پکار نہیں سُن سکتے اور اگر (بالفرض) وہ سُن لیں تو تمہیں جواب نہیں دے سکتے، اور قیامت کے دن وہ تمہارے شِرک کا بالکل انکار کر دیں گے، اور تجھے خدائے باخبر جیسا کوئی خبردار نہ کرے گا،\qt@no{14}}%
\qt@newcmd\qurantrans@ur@mmmdclxxv{اے لوگو! تم سب اﷲ کے محتاج ہو اور اﷲ ہی بے نیاز، سزاوارِ حمد و ثنا ہے،\qt@no{15}}%
\qt@newcmd\qurantrans@ur@mmmdclxxvi{اگر وہ چاہے تمہیں نابود کر دے اور نئی مخلوق لے آئے،\qt@no{16}}%
\qt@newcmd\qurantrans@ur@mmmdclxxvii{اور یہ اﷲ پر کچھ مشکل نہیں ہے،\qt@no{17}}%
\qt@newcmd\qurantrans@ur@mmmdclxxviii{اور کوئی بوجھ اٹھانے والا دوسرے کا بارِ (گناہ) نہ اٹھا سکے گا، اور کوئی بوجھ میں دبا ہوا (دوسرے کو) اپنا بوجھ بٹانے کے لئے بلائے گا تو اس سے کچھ بھی بوجھ نہ اٹھایا جا سکے گا خواہ قریبی رشتہ دار ہی ہو، (اے حبیب!) آپ ان ہی لوگوں کو ڈر سناتے ہیں جو اپنے رب سے بن دیکھے ڈرتے ہیں اور نماز قائم کرتے ہیں، اور جو کوئی پاکیزگی حاصل کرتا ہے وہ اپنے ہی فائدہ کے لئے پاک ہوتا ہے، اور اﷲ ہی کی طرف پلٹ کر جانا ہے،\qt@no{18}}%
\qt@newcmd\qurantrans@ur@mmmdclxxix{اور اندھا اور بینا برابر نہیں ہو سکتے،\qt@no{19}}%
\qt@newcmd\qurantrans@ur@mmmdclxxx{اور نہ تاریکیاں اور نہ نور (برابر ہو سکتے ہیں)،\qt@no{20}}%
\qt@newcmd\qurantrans@ur@mmmdclxxxi{اور نہ سایہ اور نہ دھوپ،\qt@no{21}}%
\qt@newcmd\qurantrans@ur@mmmdclxxxii{اور نہ زندہ لوگ اور نہ مُردے برابر ہو سکتے ہیں، بیشک اﷲ جسے چاہتا ہے سنا دیتا ہے، اور آپ کے ذمّہ ان کو سنانا نہیں جو قبروں میں (مدفون) ہیں (یعنی آپ کافروں سے اپنی بات قبول کروانے کے ذمّہ دار نہیں ہیں)،\qt@no{22}}%
\qt@newcmd\qurantrans@ur@mmmdclxxxiii{آپ تو فقط ڈر سنانے والے ہیں،\qt@no{23}}%
\qt@newcmd\qurantrans@ur@mmmdclxxxiv{بیشک ہم نے آپ کو حق و ہدایت کے ساتھ، خوشخبری سنانے والا اور (آخرت کا) ڈر سنانے والا بنا کر بھیجا ہے۔ اور کوئی امّت (ایسی) نہیں مگر اُس میں کوئی (نہ کوئی) ڈر سنانے والا (ضرور) گزرا ہے،\qt@no{24}}%
\qt@newcmd\qurantrans@ur@mmmdclxxxv{اور اگر یہ لوگ آپ کو جھٹلائیں تو بیشک اِن سے پہلے لوگ (بھی) جھٹلا چکے ہیں، اُن کے پاس (بھی) اُن کے رسول واضح نشانیاں اور صحیفے اور روشن کرنے والی کتاب لے کر آئے تھے،\qt@no{25}}%
\qt@newcmd\qurantrans@ur@mmmdclxxxvi{پھر میں نے ان کافروں کو (عذاب میں) پکڑ لیا سو میرا انکار (کیا جانا) کیسا (عبرت ناک) ثابت ہوا،\qt@no{26}}%
\qt@newcmd\qurantrans@ur@mmmdclxxxvii{کیا آپ نے نہیں دیکھا کہ اﷲ نے آسمان سے پانی اتارا، پھر ہم نے اس سے پھل نکالے جن کے رنگ جداگانہ ہیں، اور (اسی طرح) پہاڑوں میں بھی سفید اور سرخ گھاٹیاں ہیں ان کے رنگ (بھی) مختلف ہیں اور بہت گہری سیاہ (گھاٹیاں) بھی ہیں،\qt@no{27}}%
\qt@newcmd\qurantrans@ur@mmmdclxxxviii{اور انسانوں اور جانوروں اور چوپایوں میں بھی اسی طرح مختلف رنگ ہیں، بس اﷲ کے بندوں میں سے اس سے وہی ڈرتے ہیں جو (ان حقائق کا بصیرت کے ساتھ) علم رکھنے والے ہیں، یقیناً اﷲ غالب ہے بڑا بخشنے والا ہے،\qt@no{28}}%
\qt@newcmd\qurantrans@ur@mmmdclxxxix{بیشک جو لوگ اﷲ کی کتاب کی تلاوت کرتے ہیں اور نماز قائم رکھتے ہیں اور جو کچھ ہم نے انہیں عطا کیا ہے اس میں سے خرچ کرتے ہیں، پوشیدہ بھی اور ظاہر بھی، اور ایسی (اُخروی) تجارت کے امیدوار ہیں جو کبھی خسارے میں نہیں ہوگی،\qt@no{29}}%
\qt@newcmd\qurantrans@ur@mmmdcxc{تاکہ اﷲ ان کا اجر انہیں پورا پورا عطا فرمائے اور اپنے فضل سے انہیں مزید نوازے، بیشک اﷲ بڑا بخشنے والا، بڑا ہی شکر قبول فرمانے والا ہے،\qt@no{30}}%
\qt@newcmd\qurantrans@ur@mmmdcxci{اور جو کتاب (قرآن) ہم نے آپ کی طرف وحی فرمائی ہے، وہی حق ہے اور اپنے سے پہلے کی کتابوں کی تصدیق کرنے والی ہے، بیشک اﷲ اپنے بندوں سے پوری طرح باخبر ہے خوب دیکھنے والا ہے،\qt@no{31}}%
\qt@newcmd\qurantrans@ur@mmmdcxcii{پھر ہم نے اس کتاب (قرآن) کا وارث ایسے لوگوں کو بنایا جنہیں ہم نے اپنے بندوں میں سے چُن لیا (یعنی امّتِ محمدیہ صلی اللہ علیہ وآلہ وسلم کو)، سو ان میں سے اپنی جان پر ظلم کرنے والے بھی ہیں، اور ان میں سے درمیان میں رہنے والے بھی ہیں، اور ان میں سے اﷲ کے حکم سے نیکیوں میں آگے بڑھ جانے والے بھی ہیں، یہی (آگے نکل کر کامل ہو جانا ہی) بڑا فضل ہے،\qt@no{32}}%
\qt@newcmd\qurantrans@ur@mmmdcxciii{دائمی اِقامت کے لئے) عدن کی جنّتیں ہیں جن میں وہ داخل ہوں گے، ان میں انہیں سونے اور موتیوں کے کنگنوں سے آراستہ کیا جائے گا اور وہاں ان کی پوشاک ریشمی ہوگی،\qt@no{33}}%
\qt@newcmd\qurantrans@ur@mmmdcxciv{اور وہ کہیں گے: اﷲ کا شکر و حمد ہے جس نے ہم سے کُل غم دور فرما دیا، بیشک ہمارا رب بڑا بخشنے والا، بڑا شکر قبول فرمانے والا ہے،\qt@no{34}}%
\qt@newcmd\qurantrans@ur@mmmdcxcv{جس نے ہمیں اپنے فضل سے دائمی اقامت کے گھر لا اتارا ہے، جس میں ہمیں نہ کوئی مشقّت پہنچے گی اور نہ اس میں ہمیں کوئی تھکن پہنچے گی،\qt@no{35}}%
\qt@newcmd\qurantrans@ur@mmmdcxcvi{اور جن لوگوں نے کفر کیا ان کے لئے دوزخ کی آگ ہے، نہ ان پر (موت کا) فیصلہ کیا جائے گا کہ مر جائیں اور نہ ان سے عذاب میں سے کچھ کم کیا جائے گا، اسی طرح ہم ہر نافرمان کو بدلہ دیا کرتے ہیں،\qt@no{36}}%
\qt@newcmd\qurantrans@ur@mmmdcxcvii{اور وہ اس دوزخ میں چِلّائیں گے کہ اے ہمارے رب! ہمیں (یہاں سے) نکال دے، (اب) ہم نیک عمل کریں گے ان (اَعمال) سے مختلف جو ہم (پہلے) کیا کرتے تھے۔ (ارشاد ہوگا:) کیا ہم نے تمہیں اتنی عمر نہیں دی تھی کہ اس میں جو شخص نصیحت حاصل کرنا چاہتا، وہ سوچ سکتا تھا اور (پھر) تمہارے پاس ڈر سنانے والا بھی آچکا تھا، پس اب (عذاب کا) مزہ چکھو سو ظالموں کے لئے کوئی مددگار نہ ہوگا،\qt@no{37}}%
\qt@newcmd\qurantrans@ur@mmmdcxcviii{بیشک اﷲ آسمانوں اور زمین کے غیب کو جاننے والا ہے، یقیناً وہ سینوں کی (پوشیدہ) باتوں سے خوب واقف ہے،\qt@no{38}}%
\qt@newcmd\qurantrans@ur@mmmdcxcix{وہی ہے جس نے تمہیں زمین میں (گزشتہ اقوام کا) جانشین بنایا، پس جس نے کفر کیا سو اس کا وبالِ کفر اسی پر ہوگا، اور کافروں کے حق میں ان کا کفر اُن کے رب کے حضور سوائے ناراضگی کے اور کچھ نہیں بڑھاتا، اور کافروں کے حق میں ان کا کفر سوائے نقصان کے کسی (بھی) اور چیز کا اضافہ نہیں کرتا،\qt@no{39}}%
\qt@newcmd\qurantrans@ur@mmmdcc{فرما دیجئے: کیا تم نے اپنے شریکوں کو دیکھا ہے جنہیں تم اﷲ کے سوا پوجتے ہو، مجھے دکھا دو کہ انہوں نے زمین سے کیا چیز پیدا کی ہے یا آسمانوں (کی تخلیق) میں ان کی کوئی شراکت ہے، یا ہم نے انہیں کوئی کتاب عطا کر رکھی ہے کہ وہ اس کی دلیل پر قائم ہیں؟ (کچھ بھی نہیں ہے) بلکہ ظالم لوگ ایک دوسرے سے فریب کے سوا کوئی وعدہ نہیں کرتے،\qt@no{40}}%
\qt@newcmd\qurantrans@ur@mmmdcci{بیشک اﷲ آسمانوں اور زمین کو (اپنے نظامِ قدرت کے ذریعے) اس بات سے روکے ہوئے ہے کہ وہ (اپنی اپنی جگہوں اور راستوں سے) ہٹ سکیں، اور اگر وہ دونوں ہٹنے لگیں تو اس کے بعد کوئی بھی ان دونوں کو روک نہیں سکتا، بیشک وہ بڑا بُردبار، بڑا بخشنے والا ہے،\qt@no{41}}%
\qt@newcmd\qurantrans@ur@mmmdccii{اور یہ لوگ اﷲ کے ساتھ بڑی پختہ قَسمیں کھایا کرتے تھے کہ اگر اُن کے پاس کوئی ڈر سنانے والا آجائے تو یہ ضرور ہر ایک امّت سے بڑھ کر راہِ راست پر ہوں گے، پھر جب اُن کے پاس ڈر سنانے والے (نبی آخر الزماں صلی اللہ علیہ وآلہ وسلم) تشریف لے آئے تو اس سے اُن کی حق سے بیزاری میں اضافہ ہی ہوا،\qt@no{42}}%
\qt@newcmd\qurantrans@ur@mmmdcciii{انہوں نے) زمین میں اپنے آپ کو سب سے بڑا سمجھنا اور بری چالیں چلنا (اختیار کیا)، اور برُی چالیں اُسی چال چلنے والے کو ہی گھیر لیتی ہیں، سو یہ اگلے لوگوں کی رَوِشِ (عذاب) کے سوا (کسی اور چیز کے) منتظر نہیں ہیں۔ سو آپ اﷲ کے دستور میں ہرگز کوئی تبدیلی نہیں پائیں گے، اور نہ ہی اﷲ کے دستور میں ہرگز کوئی پھرنا پائیں گے،\qt@no{43}}%
\qt@newcmd\qurantrans@ur@mmmdcciv{کیا یہ لوگ زمین میں چلتے پھرتے نہیں ہیں کہ دیکھ لیتے کہ اُن لوگوں کا انجام کیسا ہوا جو اِن سے پہلے تھے حالانکہ وہ اِن سے کہیں زیادہ زورآور تھے، اور اﷲ ایسا نہیں ہے کہ آسمانوں میں کوئی بھی چیز اسے عاجز کر سکے اور نہ ہی زمین میں (ایسی کوئی چیز ہے)، بیشک وہ بہت علم والا بڑی قدرت والا ہے،\qt@no{44}}%
\qt@newcmd\qurantrans@ur@mmmdccv{اور اگر اﷲ لوگوں کو اُن اعمالِ (بد) کے بدلے جو انہوں نے کما رکھے ہیں (عذاب کی) گرفت میں لینے لگے تو وہ اس زمین کی پشت پر کسی چلنے والے کو نہ چھوڑے لیکن وہ انہیں مقررہ مدّت تک مہلت دے رہا ہے۔ پھر جب ان کا مقررہ وقت آجائے گا تو بیشک اﷲ اپنے بندوں کو خوب دیکھنے والا ہے،\qt@no{45}}%
\qt@newcmd\qurantrans@ur@mmmdccvi{\basmalahur یا، سین (حقیقی معنی اللہ اور رسول صلی اللہ علیہ وآلہ وسلم ہی بہتر جانتے ہیں)،\qt@no{1}}%
\qt@newcmd\qurantrans@ur@mmmdccvii{حکمت سے معمور قرآن کی قَسم،\qt@no{2}}%
\qt@newcmd\qurantrans@ur@mmmdccviii{بیشک آپ ضرور رسولوں میں سے ہیں،\qt@no{3}}%
\qt@newcmd\qurantrans@ur@mmmdccix{سیدھی راہ پر (قائم ہیں)،\qt@no{4}}%
\qt@newcmd\qurantrans@ur@mmmdccx{یہ) بڑی عزت والے، بڑے رحم والے (رب) کا نازل کردہ ہے،\qt@no{5}}%
\qt@newcmd\qurantrans@ur@mmmdccxi{تاکہ آپ اس قوم کو ڈر سنائیں جن کے باپ دادا کو (بھی) نہیں ڈرایا گیا سو وہ غافل ہیں،\qt@no{6}}%
\qt@newcmd\qurantrans@ur@mmmdccxii{درحقیقت اُن کے اکثر لوگوں پر ہمارا فرمان (سچ) ثابت ہو چکا ہے سو وہ ایمان نہیں لائیں گے،\qt@no{7}}%
\qt@newcmd\qurantrans@ur@mmmdccxiii{بیشک ہم نے اُن کی گردنوں میں طوق ڈال دیئے ہیں تو وہ اُن کی ٹھوڑیوں تک ہیں، پس وہ سر اوپر اٹھائے ہوئے ہیں،\qt@no{8}}%
\qt@newcmd\qurantrans@ur@mmmdccxiv{اور ہم نے اُن کے آگے سے (بھی) ایک دیوار اور اُن کے پیچھے سے (بھی) ایک دیوار بنا دی ہے، پھر ہم نے اُن (کی آنکھوں) پر پردہ ڈال دیا ہے سو وہ کچھ نہیں دیکھتے،\qt@no{9}}%
\qt@newcmd\qurantrans@ur@mmmdccxv{اور اُن پر برابر ہے خواہ آپ انہیں ڈرائیں یا انہیں نہ ڈرائیں وہ ایمان نہ لائیں گے،\qt@no{10}}%
\qt@newcmd\qurantrans@ur@mmmdccxvi{آپ تو صرف اسی شخص کو ڈر سناتے ہیں جو نصیحت کی پیروی کرتا ہے اور خدائے رحمان سے بن دیکھے ڈرتا ہے، سو آپ اسے بخشش اور بڑی عزت والے اجر کی خوشخبری سنا دیں،\qt@no{11}}%
\qt@newcmd\qurantrans@ur@mmmdccxvii{بیشک ہم ہی تو مُردوں کو زندہ کرتے ہیں اور ہم وہ سب کچھ لکھ رہے ہیں جو (اَعمال) وہ آگے بھیج چکے ہیں، اور اُن کے اثرات (جو پیچھے رہ گئے ہیں)، اور ہر چیز کو ہم نے روشن کتاب (لوحِ محفوظ) میں احاطہ کر رکھا ہے،\qt@no{12}}%
\qt@newcmd\qurantrans@ur@mmmdccxviii{اور آپ اُن کے لئے ایک بستی (انطاکیہ) کے باشندوں کی مثال (حکایۃً) بیان کریں، جب اُن کے پاس کچھ پیغمبر آئے،\qt@no{13}}%
\qt@newcmd\qurantrans@ur@mmmdccxix{جبکہ ہم نے اُن کی طرف (پہلے) دو (پیغمبر) بھیجے تو انہوں نے ان دونوں کو جھٹلا دیا پھر ہم نے (ان کو) تیسرے (پیغمبر) کے ذریعے قوت دی، پھر اُن تینوں نے کہا: بیشک ہم تمہاری طرف بھیجے گئے ہیں،\qt@no{14}}%
\qt@newcmd\qurantrans@ur@mmmdccxx{بستی والوں نے) کہا: تم تو محض ہماری طرح بشر ہو اور خدائے رحمان نے کچھ بھی نازل نہیں کیا، تم فقط جھوٹ بول رہے ہو،\qt@no{15}}%
\qt@newcmd\qurantrans@ur@mmmdccxxi{پیغمبروں نے) کہا: ہمارا رب جانتا ہے کہ ہم یقیناً تمہاری طرف بھیجے گئے ہیں،\qt@no{16}}%
\qt@newcmd\qurantrans@ur@mmmdccxxii{اور واضح طور پر پیغام پہنچا دینے کے سوا ہم پر کچھ لازم نہیں ہے،\qt@no{17}}%
\qt@newcmd\qurantrans@ur@mmmdccxxiii{بستی والوں نے) کہا: ہمیں تم سے نحوست پہنچی ہے اگر تم واقعی باز نہ آئے تو ہم تمہیں یقیناً سنگ سار کر دیں گے اور ہماری طرف سے تمہیں ضرور دردناک عذاب پہنچے گا،\qt@no{18}}%
\qt@newcmd\qurantrans@ur@mmmdccxxiv{پیغمبروں نے) کہا: تمہاری نحوست تمہارے ساتھ ہے، کیا یہ نحوست ہے کہ تمہیں نصیحت کی گئی، بلکہ تم لوگ حد سے گزر جانے والے ہو،\qt@no{19}}%
\qt@newcmd\qurantrans@ur@mmmdccxxv{اور شہر کے پرلے کنارے سے ایک آدمی دوڑتا ہوا آیا، اس نے کہا: اے میری قوم! تم پیغمبروں کی پیروی کرو،\qt@no{20}}%
\qt@newcmd\qurantrans@ur@mmmdccxxvi{ایسے لوگوں کی پیروی کرو جو تم سے کوئی معاوضہ نہیں مانگتے اور وہ ہدایت یافتہ ہیں،\qt@no{21}}%
\qt@newcmd\qurantrans@ur@mmmdccxxvii{اور مجھے کیا ہے کہ میں اس ذات کی عبادت نہ کروں جس نے مجھے پیدا فرمایا ہے اور تم (سب) اسی کی طرف لوٹائے جاؤ گے،\qt@no{22}}%
\qt@newcmd\qurantrans@ur@mmmdccxxviii{کیا میں اس (اللہ) کو چھوڑ کر ایسے معبود بنا لوں کہ اگر خدائے رحمان مجھے کوئی تکلیف پہنچانا چاہے تو نہ مجھے اُن کی سفارش کچھ نفع پہنچا سکے اور نہ وہ مجھے چھڑا ہی سکیں،\qt@no{23}}%
\qt@newcmd\qurantrans@ur@mmmdccxxix{بے شک تب تو میں کھلی گمراہی میں ہوں گا،\qt@no{24}}%
\qt@newcmd\qurantrans@ur@mmmdccxxx{بے شک میں تمہارے رب پر ایمان لے آیا ہوں، سو تم مجھے (غور سے) سنو،\qt@no{25}}%
\qt@newcmd\qurantrans@ur@mmmdccxxxi{اسے کافروں نے شہید کر دیا تو اسے) کہا گیا: (آ) بہشت میں داخل ہوجا، اس نے کہا: اے کاش! میری قوم کو معلوم ہو جاتا،\qt@no{26}}%
\qt@newcmd\qurantrans@ur@mmmdccxxxii{کہ میرے رب نے میری مغفرت فرما دی ہے اور مجھے عزت و قربت والوں میں شامل فرما دیا ہے،\qt@no{27}}%
\qt@newcmd\qurantrans@ur@mmmdccxxxiii{اور ہم نے اس کے بعد اس کی قوم پر آسمان سے (فرشتوں کا) کوئی لشکر نہیں اتارا اور نہ ہی ہم (ان کی ہلاکت کے لئے فرشتوں کو) اتارنے والے تھے،\qt@no{28}}%
\qt@newcmd\qurantrans@ur@mmmdccxxxiv{ان کا عذاب) ایک سخت چنگھاڑ کے سوا اور کچھ نہ تھا، بس وہ اُسی دم (مر کر کوئلے کی طرح) بُجھ گئے،\qt@no{29}}%
\qt@newcmd\qurantrans@ur@mmmdccxxxv{ہائے (اُن) بندوں پر افسوس! اُن کے پاس کوئی رسول نہ آتا تھا مگر یہ کہ وہ اس کا مذاق اڑاتے تھے،\qt@no{30}}%
\qt@newcmd\qurantrans@ur@mmmdccxxxvi{کیا اِنہوں نے نہیں دیکھا کہ ہم نے اِن سے پہلے کتنی ہی قومیں ہلاک کر ڈالیں، کہ اب وہ لوگ ان کی طرف پلٹ کر نہیں آئیں گے،\qt@no{31}}%
\qt@newcmd\qurantrans@ur@mmmdccxxxvii{مگر یہ کہ وہ سب کے سب ہمارے حضور حاضر کیے جائیں گے،\qt@no{32}}%
\qt@newcmd\qurantrans@ur@mmmdccxxxviii{اور اُن کے لئے ایک نشانی مُردہ زمین ہے، جِسے ہم نے زندہ کیا اور ہم نے اس سے (اناج کے) دانے نکالے، پھر وہ اس میں سے کھاتے ہیں،\qt@no{33}}%
\qt@newcmd\qurantrans@ur@mmmdccxxxix{اور ہم نے اس میں کھجوروں اور انگوروں کے باغات بنائے اور اس میں ہم نے کچھ چشمے بھی جاری کردیئے،\qt@no{34}}%
\qt@newcmd\qurantrans@ur@mmmdccxl{تاکہ وہ اس کے پھل کھائیں اور اسے اُن کے ہاتھوں نے نہیں بنایا، پھر (بھی) کیا وہ شکر نہیں کرتے،\qt@no{35}}%
\qt@newcmd\qurantrans@ur@mmmdccxli{پاک ہے وہ ذات جس نے سب چیزوں کے جوڑے پیدا کئے، ان سے (بھی) جنہیں زمین اگاتی ہے اور خود اُن کی جانوں سے بھی اور (مزید) ان چیزوں سے بھی جنہیں وہ نہیں جانتے،\qt@no{36}}%
\qt@newcmd\qurantrans@ur@mmmdccxlii{اور ایک نشانی اُن کے لئے رات (بھی) ہے، ہم اس میں سے (کیسے) دن کو کھینچ لیتے ہیں سو وہ اس وقت اندھیرے میں پڑے رہ جاتے ہیں،\qt@no{37}}%
\qt@newcmd\qurantrans@ur@mmmdccxliii{اور سورج ہمیشہ اپنی مقررہ منزل کے لئے (بغیر رکے) چلتا رہتا، ہے یہ بڑے غالب بہت علم والے (رب) کی تقدیر ہے،\qt@no{38}}%
\qt@newcmd\qurantrans@ur@mmmdccxliv{اور ہم نے چاند کی (حرکت و گردش کی) بھی منزلیں مقرر کر رکھی ہیں یہاں تک کہ (اس کا اہلِ زمین کو دکھائی دینا گھٹتے گھٹتے) کھجور کی پرانی ٹہنی کی طرح ہوجاتا ہے،\qt@no{39}}%
\qt@newcmd\qurantrans@ur@mmmdccxlv{نہ سورج کی یہ مجال کہ وہ (اپنا مدار چھوڑ کر) چاند کو جا پکڑے اور نہ رات ہی دن سے پہلے نمودار ہوسکتی ہے، اور سب (ستارے اور سیارے) اپنے (اپنے) مدار میں حرکت پذیر ہیں،\qt@no{40}}%
\qt@newcmd\qurantrans@ur@mmmdccxlvi{اور ایک نشانی اُن کے لئے یہ (بھی) ہے کہ ہم نے ان کے آباء و اجداد کو (جو ذُریّت آدم تھے) بھری کشتیِ (نوح) میں سوار کر (کے بچا) لیا تھا،\qt@no{41}}%
\qt@newcmd\qurantrans@ur@mmmdccxlvii{اور ہم نے اُن کے لئے اس (کشتی) کے مانند ان (بہت سی اور سواریوں) کو بنایا جن پر یہ لوگ سوار ہوتے ہیں،\qt@no{42}}%
\qt@newcmd\qurantrans@ur@mmmdccxlviii{اور اگر ہم چاہیں تو انہیں غرق کر دیں تو نہ ان کے لئے کوئی فریاد رَس ہوگا اور نہ وہ بچائے جاسکیں گے،\qt@no{43}}%
\qt@newcmd\qurantrans@ur@mmmdccxlix{سوائے ہماری رحمت کے اور (یہ) ایک مقررہ مدّت تک کا فائدہ ہے،\qt@no{44}}%
\qt@newcmd\qurantrans@ur@mmmdccl{اور جب اُن سے کہا جاتا ہے کہ تم اس (عذاب) سے ڈرو جو تمہارے سامنے ہے اور جو تمہارے پیچھے ہے تاکہ تم پر رحم کیا جائے،\qt@no{45}}%
\qt@newcmd\qurantrans@ur@mmmdccli{اور اُن کے رب کی نشانیوں میں سے کوئی (بھی) نشانی اُن کے پاس نہیں آتی مگر وہ اس سے رُوگردانی کرتے ہیں،\qt@no{46}}%
\qt@newcmd\qurantrans@ur@mmmdcclii{اور جب اُن سے کہا جاتا ہے کہ تم اس میں سے (راہِ خدا میں) خرچ کرو جو تمہیں اللہ نے عطا کیا ہے تو کافر لوگ ایمان والوں سے کہتے ہیں: کیا ہم اس (غریب) شخص کو کھلائیں جسے اگر اللہ چاہتا تو (خود ہی) کھلا دیتا۔ تم تو کھلی گمراہی میں ہی (مبتلا) ہوگئے ہو،\qt@no{47}}%
\qt@newcmd\qurantrans@ur@mmmdccliii{اور وہ کہتے ہیں کہ یہ وعدۂ (قیامت) کب پورا ہوگا اگر تم سچے ہو،\qt@no{48}}%
\qt@newcmd\qurantrans@ur@mmmdccliv{وہ لوگ صرِف ایک سخت چنگھاڑ کے ہی منتظر ہیں جو انہیں (اچانک) پکڑے گی اور وہ آپس میں جھگڑ رہے ہوں گے،\qt@no{49}}%
\qt@newcmd\qurantrans@ur@mmmdcclv{پھر وہ نہ تو وصیّت کرنے کے ہی قابل رہیں گے اور نہ اپنے گھر والوں کی طرف واپس پلٹ سکیں گے،\qt@no{50}}%
\qt@newcmd\qurantrans@ur@mmmdcclvi{اور (جس وقت دوبارہ) صُور پھونکا جائے گا تو وہ فوراً قبروں سے نکل کر اپنے رب کی طرف دوڑ پڑیں گے،\qt@no{51}}%
\qt@newcmd\qurantrans@ur@mmmdcclvii{روزِ محشر کی ہولناکیاں دیکھ کر) کہیں گے: ہائے ہماری کم بختی! ہمیں کس نے ہماری خواب گاہوں سے اٹھا دیا، (یہ زندہ ہونا) وہی تو ہے جس کا خدائے رحمان نے وعدہ کیا تھا اور رسولوں نے سچ فرمایا تھا،\qt@no{52}}%
\qt@newcmd\qurantrans@ur@mmmdcclviii{یہ محض ایک بہت سخت چنگھاڑ ہوگی تو وہ سب کے سب یکایک ہمارے حضور لا کر حاضر کر دیئے جائیں گے،\qt@no{53}}%
\qt@newcmd\qurantrans@ur@mmmdcclix{پھر آج کے دن کسی جان پر کچھ ظلم نہ کیا جائے گا اور نہ تمہیں کوئی بدلہ دیا جائے گا سوائے اُن کاموں کے جو تم کیا کرتے تھے،\qt@no{54}}%
\qt@newcmd\qurantrans@ur@mmmdcclx{بے شک اہلِ جنت آج (اپنے) دل پسند مشاغل (مثلاً زیارتوں، ضیافتوں، سماع اور دیگر نعمتوں) میں لطف اندوز ہو رہے ہوں گے،\qt@no{55}}%
\qt@newcmd\qurantrans@ur@mmmdcclxi{وہ اور ان کی بیویاں گھنے سایوں میں تختوں پر تکیے لگائے بیٹھے ہوں گے،\qt@no{56}}%
\qt@newcmd\qurantrans@ur@mmmdcclxii{اُن کے لئے اس میں (ہر قسم کا) میوہ ہوگا اور ان کے لئے ہر وہ چیز (میسر) ہوگی جو وہ طلب کریں گے،\qt@no{57}}%
\qt@newcmd\qurantrans@ur@mmmdcclxiii{تم پر) سلام ہو، (یہ) ربِّ رحیم کی طرف سے فرمایا جائے گا،\qt@no{58}}%
\qt@newcmd\qurantrans@ur@mmmdcclxiv{اور اے مجرمو! تم آج (نیکو کاروں سے) الگ ہوجاؤ،\qt@no{59}}%
\qt@newcmd\qurantrans@ur@mmmdcclxv{اے بنی آدم! کیا میں نے تم سے اس بات کا عہد نہیں لیا تھا کہ تم شیطان کی پرستش نہ کرنا، بے شک وہ تمہارا کھلا دشمن ہے،\qt@no{60}}%
\qt@newcmd\qurantrans@ur@mmmdcclxvi{اور یہ کہ میری عبادت کرتے رہنا، یہی سیدھا راستہ ہے،\qt@no{61}}%
\qt@newcmd\qurantrans@ur@mmmdcclxvii{اور بے شک اس نے تم میں سے بہت سی خلقت کو گمراہ کر ڈالا، پھر کیا تم عقل نہیں رکھتے تھے،\qt@no{62}}%
\qt@newcmd\qurantrans@ur@mmmdcclxviii{یہ وہی دوزخ ہے جس کا تم سے وعدہ کیا جاتا رہا ہے،\qt@no{63}}%
\qt@newcmd\qurantrans@ur@mmmdcclxix{آج اس دوزخ میں داخل ہو جاؤ اس وجہ سے کہ تم کفر کرتے رہے تھے،\qt@no{64}}%
\qt@newcmd\qurantrans@ur@mmmdcclxx{آج ہم اُن کے مونہوں پر مُہر لگا دیں گے اور اُن کے ہاتھ ہم سے باتیں کریں گے اور اُن کے پاؤں اُن اعمال کی گواہی دیں گے جو وہ کمایا کرتے تھے،\qt@no{65}}%
\qt@newcmd\qurantrans@ur@mmmdcclxxi{اور اگر ہم چاہتے تو اُن کی آنکھوں کے نشان تک مِٹا دیتے پھر وہ راستے پر دوڑتے تو کہاں دیکھ سکتے،\qt@no{66}}%
\qt@newcmd\qurantrans@ur@mmmdcclxxii{اور اگر ہم چاہتے تو اُن کی رہائش گاہوں پر ہی ہم ان کی صورتیں بگاڑ دیتے پھر نہ وہ آگے جانے کی قدرت رکھتے اور نہ ہی واپس لوٹ سکتے،\qt@no{67}}%
\qt@newcmd\qurantrans@ur@mmmdcclxxiii{اور ہم جسے طویل عمر دیتے ہیں اسے قوت و طبیعت میں واپس (بچپن یا کمزوری کی طرف) پلٹا دیتے ہیں، پھر کیا وہ عقل نہیں رکھتے،\qt@no{68}}%
\qt@newcmd\qurantrans@ur@mmmdcclxxiv{اور ہم نے اُن کو (یعنی نبیِ مکرّم صلی اللہ علیہ وآلہ وسلم کو) شعر کہنا نہیں سکھایا اور نہ ہی یہ اُن کے شایانِ شان ہے۔ یہ (کتاب) تو فقط نصیحت اور روشن قرآن ہے،\qt@no{69}}%
\qt@newcmd\qurantrans@ur@mmmdcclxxv{تاکہ وہ اس شخص کو ڈر سنائیں جو زندہ ہو اور کافروں پر فرمانِ حجت ثابت ہو جائے،\qt@no{70}}%
\qt@newcmd\qurantrans@ur@mmmdcclxxvi{کیا انہوں نے نہیں دیکھا کہ ہم نے اپنے دستِ قدرت سے بنائی ہوئی (مخلوق) میں سے اُن کے لئے چوپائے پیدا کیے تو وہ ان کے مالک ہیں،\qt@no{71}}%
\qt@newcmd\qurantrans@ur@mmmdcclxxvii{اور ہم نے اُن (چوپایوں) کو ان کے تابع کر دیا سو ان میں سے کچھ تو اُن کی سواریاں ہیں اور ان میں سے بعض کو وہ کھاتے ہیں،\qt@no{72}}%
\qt@newcmd\qurantrans@ur@mmmdcclxxviii{اور ان میں ان کے لئے اور بھی فوائد ہیں اور مشروب ہیں، تو پھر وہ شکر ادا کیوں نہیں کرتے،\qt@no{73}}%
\qt@newcmd\qurantrans@ur@mmmdcclxxix{اور انہوں نے اللہ کے سوا بتوں کو معبود بنا لیا ہے اس امید پر کہ ان کی مدد کی جائے گی،\qt@no{74}}%
\qt@newcmd\qurantrans@ur@mmmdcclxxx{وہ بت اُن کی مدد کی قدرت نہیں رکھتے اور یہ (کفار و مشرکین) اُن (بتوں) کے لشکر ہوں گے جو (اکٹھے دوزخ میں) حاضر کر دیئے جائیں گے،\qt@no{75}}%
\qt@newcmd\qurantrans@ur@mmmdcclxxxi{پس اُن کی باتیں آپ کو رنجیدہ خاطر نہ کریں، بیشک ہم جانتے ہیں جو کچھ وہ چھپاتے ہیں اور جو کچھ وہ ظاہر کرتے ہیں،\qt@no{76}}%
\qt@newcmd\qurantrans@ur@mmmdcclxxxii{کیا انسان نے یہ نہیں دیکھا کہ ہم نے اسے ایک تولیدی قطرہ سے پیدا کیا، پھر بھی وہ کھلے طور پر سخت جھگڑالو بن گیا،\qt@no{77}}%
\qt@newcmd\qurantrans@ur@mmmdcclxxxiii{اور (خود) ہمارے لئے مثالیں بیان کرنے لگا اور اپنی پیدائش (کی حقیقت) کو بھول گیا۔ کہنے لگا: ہڈیوں کو کون زندہ کرے گا جبکہ وہ بوسیدہ ہوچکی ہوں گی؟،\qt@no{78}}%
\qt@newcmd\qurantrans@ur@mmmdcclxxxiv{فرما دیجئے: انہیں وہی زندہ فرمائے گا جس نے انہیں پہلی بار پیدا کیا تھا، اور وہ ہر مخلوق کو خوب جاننے والا ہے،\qt@no{79}}%
\qt@newcmd\qurantrans@ur@mmmdcclxxxv{جس نے تمہارے لئے سرسبز درخت سے آگ پیدا کی پھر اب تم اسی سے آگ سلگاتے ہو،\qt@no{80}}%
\qt@newcmd\qurantrans@ur@mmmdcclxxxvi{اور کیا وہ جس نے آسمانوں اور زمین کو پیدا فرمایا ہے اس بات پر قادر نہیں کہ ان جیسی تخلیق (دوبارہ) کردے، کیوں نہیں، اور وہ بڑا پیدا کرنے والا خوب جاننے والا ہے،\qt@no{81}}%
\qt@newcmd\qurantrans@ur@mmmdcclxxxvii{اس کا امرِ (تخلیق) فقط یہ ہے کہ جب وہ کسی شے کو (پیدا فرمانا) چاہتا ہے تو اسے فرماتا ہے: ہو جا، پس وہ فوراً (موجود یا ظاہر) ہو جاتی ہے (اور ہوتی چلی جاتی ہے)،\qt@no{82}}%
\qt@newcmd\qurantrans@ur@mmmdcclxxxviii{پس وہ ذات پاک ہے جس کے دستِ (قدرت) میں ہر چیز کی بادشاہت ہے اور تم اسی کی طرف لوٹائے جاؤ گے،\qt@no{83}}%
\qt@newcmd\qurantrans@ur@mmmdcclxxxix{\basmalahur قسم ہے قطار در قطار صف بستہ جماعتوں کی،\qt@no{1}}%
\qt@newcmd\qurantrans@ur@mmmdccxc{پھر بادلوں کو کھینچ کر لے جانے والی یا برائیوں پر سختی سے جھڑکنے والی جماعتوں کی،\qt@no{2}}%
\qt@newcmd\qurantrans@ur@mmmdccxci{پھر ذکرِ الٰہی (یا قرآن مجید) کی تلاوت کرنے والی جماعتوں کی،\qt@no{3}}%
\qt@newcmd\qurantrans@ur@mmmdccxcii{بے شک تمہارا معبود ایک ہی ہے،\qt@no{4}}%
\qt@newcmd\qurantrans@ur@mmmdccxciii{جو) آسمانوں اور زمین کا اور جو (مخلوق) اِن دونوں کے درمیان ہے اس کا رب ہے، اور طلوعِ آفتاب کے تمام مقامات کا رب ہے،\qt@no{5}}%
\qt@newcmd\qurantrans@ur@mmmdccxciv{بے شک ہم نے آسمانِ دنیا (یعنی پہلے کرّۂ سماوی) کو ستاروں اور سیاروں کی زینت سے آراستہ کر دیا،\qt@no{6}}%
\qt@newcmd\qurantrans@ur@mmmdccxcv{اور (انہیں) ہر سرکش شیطان سے محفوظ بنایا،\qt@no{7}}%
\qt@newcmd\qurantrans@ur@mmmdccxcvi{وہ (شیاطین) عالمِ بالا کی طرف کان نہیں لگا سکتے اور اُن پر ہر طرف سے (انگارے) پھینکے جاتے ہیں،\qt@no{8}}%
\qt@newcmd\qurantrans@ur@mmmdccxcvii{اُن کو بھگانے کے لئے اور اُن کے لئے دائمی عذاب ہے،\qt@no{9}}%
\qt@newcmd\qurantrans@ur@mmmdccxcviii{مگر جو (شیطان) ایک بار جھپٹ کر (فرشتوں کی کوئی بات) اُچک لے تو چمکتا ہوا انگارہ اُس کے پیچھے لگ جاتا ہے،\qt@no{10}}%
\qt@newcmd\qurantrans@ur@mmmdccxcix{اِن سے پوچھئے کہ کیا یہ لوگ تخلیق کئے جانے میں زیادہ سخت (اور مشکل) ہیں یا وہ چیزیں جنہیں ہم نے (آسمانی کائنات میں) تخلیق فرمایا ہے، بیشک ہم نے اِن لوگوں کو چپکنے والے گارے سے پیدا کیا ہے،\qt@no{11}}%
\qt@newcmd\qurantrans@ur@mmmdccc{بلکہ آپ تعجب فرماتے ہیں اور وہ مذاق اڑاتے ہیں،\qt@no{12}}%
\qt@newcmd\qurantrans@ur@mmmdccci{اور جب انہیں نصیحت کی جاتی ہے تو نصیحت قبول نہیں کرتے،\qt@no{13}}%
\qt@newcmd\qurantrans@ur@mmmdcccii{اور جب کوئی نشانی دیکھتے ہیں تو تمسخر کرتے ہیں،\qt@no{14}}%
\qt@newcmd\qurantrans@ur@mmmdccciii{اور کہتے ہیں کہ یہ تو صرف کھلا جادو ہے،\qt@no{15}}%
\qt@newcmd\qurantrans@ur@mmmdccciv{کیا جب ہم مر جائیں گے اور ہم مٹی اور ہڈیاں ہو جائیں گے تو ہم یقینی طور پر (دوبارہ زندہ کر کے) اٹھائے جائیں گے،\qt@no{16}}%
\qt@newcmd\qurantrans@ur@mmmdcccv{اور کیا ہمارے اگلے باپ دادا بھی (اٹھائے جائیں گے)،\qt@no{17}}%
\qt@newcmd\qurantrans@ur@mmmdcccvi{فرما دیجئے: ہاں اور (بلکہ) تم ذلیل و رسوا (بھی) ہو گے،\qt@no{18}}%
\qt@newcmd\qurantrans@ur@mmmdcccvii{پس وہ تو محض ایک (زور دار آواز کی) سخت جھڑک ہوگی سو سب اچانک (اٹھ کر) دیکھنے لگ جائیں گے،\qt@no{19}}%
\qt@newcmd\qurantrans@ur@mmmdcccviii{اور کہیں گے: ہائے ہماری شامت! یہ تو جزا کا دن ہے،\qt@no{20}}%
\qt@newcmd\qurantrans@ur@mmmdcccix{کہا جائے گا: ہاں) یہ وہی فیصلہ کا دن ہے جسے تم جھٹلایا کرتے تھے،\qt@no{21}}%
\qt@newcmd\qurantrans@ur@mmmdcccx{اُن (سب) لوگوں کو جمع کرو جنہوں نے ظلم کیا اور ان کے ساتھیوں اور پیروکاروں کو (بھی) اور اُن (معبودانِ باطلہ) کو (بھی) جنہیں وہ پوجا کرتے تھے،\qt@no{22}}%
\qt@newcmd\qurantrans@ur@mmmdcccxi{اللہ کو چھوڑ کر، پھر ان سب کو دوزخ کی راہ پر لے چلو،\qt@no{23}}%
\qt@newcmd\qurantrans@ur@mmmdcccxii{اور انہیں (صراط کے پاس) روکو، اُن سے پوچھ گچھ ہوگی،\qt@no{24}}%
\qt@newcmd\qurantrans@ur@mmmdcccxiii{اُن سے کہا جائے گا:) تمہیں کیا ہوا تم ایک دوسرے کی مدد نہیں کرتے؟،\qt@no{25}}%
\qt@newcmd\qurantrans@ur@mmmdcccxiv{وہ مدد کیا کریں گے) بلکہ آج تو وہ خود گردنیں جھکائے کھڑے ہوں گے،\qt@no{26}}%
\qt@newcmd\qurantrans@ur@mmmdcccxv{اور وہ ایک دوسرے کی طرف متوجہ ہوکر باہم سوال کریں گے،\qt@no{27}}%
\qt@newcmd\qurantrans@ur@mmmdcccxvi{وہ کہیں گے: بے شک تم ہی تو ہمارے پاس دائیں طرف سے (یعنی اپنے حق پر ہونے کی قَسمیں کھاتے ہوئے) آیا کرتے تھے،\qt@no{28}}%
\qt@newcmd\qurantrans@ur@mmmdcccxvii{انہیں گمراہ کرنے والے پیشوا) کہیں گے: بلکہ تم خود ہی ایمان لانے والے نہ تھے،\qt@no{29}}%
\qt@newcmd\qurantrans@ur@mmmdcccxviii{اور ہمارا تم پر کچھ زور (اور دباؤ) نہ تھا بلکہ تم خود سرکش لوگ تھے،\qt@no{30}}%
\qt@newcmd\qurantrans@ur@mmmdcccxix{پس ہم پر ہمارے رب کا فرمان ثابت ہوگیا۔ (اب) ہم ذائقۂ (عذاب) چکھنے والے ہیں،\qt@no{31}}%
\qt@newcmd\qurantrans@ur@mmmdcccxx{سو ہم نے تمہیں گمراہ کر دیا بے شک ہم خود گمراہ تھے،\qt@no{32}}%
\qt@newcmd\qurantrans@ur@mmmdcccxxi{پس اس دن عذاب میں وہ (سب) باہم شریک ہوں گے،\qt@no{33}}%
\qt@newcmd\qurantrans@ur@mmmdcccxxii{بے شک ہم مُجرموں کے ساتھ ایسا ہی کیا کرتے ہیں،\qt@no{34}}%
\qt@newcmd\qurantrans@ur@mmmdcccxxiii{یقیناً وہ ایسے لوگ تھے کہ جب ان سے کہا جاتا کہ اللہ کے سوا کوئی لائقِ عبادت نہیں تو وہ تکبّر کرتے تھے،\qt@no{35}}%
\qt@newcmd\qurantrans@ur@mmmdcccxxiv{اور کہتے تھے: کیا ہم ایک دیوانے شاعر کی خاطر اپنے معبودوں کو چھوڑنے والے ہیں،\qt@no{36}}%
\qt@newcmd\qurantrans@ur@mmmdcccxxv{وہ نہ مجنوں ہے نہ شاعر) بلکہ وہ (دینِ) حق لے کر آئے ہیں اور انہوں نے (اللہ کے) پیغمبروں کی تصدیق کی ہے،\qt@no{37}}%
\qt@newcmd\qurantrans@ur@mmmdcccxxvi{بے شک تم دردناک عذاب کا مزہ چکھنے والے ہو،\qt@no{38}}%
\qt@newcmd\qurantrans@ur@mmmdcccxxvii{اور تمہیں (کوئی) بدلہ نہیں دیا جائے گا مگر صرف اسی کا جو تم کیا کرتے تھے،\qt@no{39}}%
\qt@newcmd\qurantrans@ur@mmmdcccxxviii{ہاں) مگر اللہ کے وہ (برگزیدہ و منتخب) بندے جنہیں (نفس اور نفسانیت سے) رہائی مل چکی ہے،\qt@no{40}}%
\qt@newcmd\qurantrans@ur@mmmdcccxxix{یہی وہ لوگ ہیں جن کے لئے (صبح و شام) رزقِ خاص مقرّر ہے،\qt@no{41}}%
\qt@newcmd\qurantrans@ur@mmmdcccxxx{ہر قسم کے) میوے ہوں گے، اور ان کی تعظیم و تکریم ہوگی،\qt@no{42}}%
\qt@newcmd\qurantrans@ur@mmmdcccxxxi{نعمتوں اور راحتوں کے باغات میں (مقیم ہوں گے)،\qt@no{43}}%
\qt@newcmd\qurantrans@ur@mmmdcccxxxii{تختوں پر مسند لگائے آمنے سامنے (جلوہ افروز ہوں گے)،\qt@no{44}}%
\qt@newcmd\qurantrans@ur@mmmdcccxxxiii{اُن پر چھلکتی ہوئی شرابِ (طہور) کے جام کا دور چل رہا ہوگا،\qt@no{45}}%
\qt@newcmd\qurantrans@ur@mmmdcccxxxiv{جو نہایت سفید ہوگی، پینے والوں کے لئے سراسر لذّت ہوگی،\qt@no{46}}%
\qt@newcmd\qurantrans@ur@mmmdcccxxxv{نہ اس میں کوئی ضرر یا سَر کا چکرانا ہوگا اور نہ وہ اس (کے پینے) سے بہک سکیں گے،\qt@no{47}}%
\qt@newcmd\qurantrans@ur@mmmdcccxxxvi{اور ان کے پہلو میں نگاہیں نیچی رکھنے والی، بڑی خوبصورت آنکھوں والی (حوریں بیٹھی) ہوں گی،\qt@no{48}}%
\qt@newcmd\qurantrans@ur@mmmdcccxxxvii{وہ سفید و دلکش رنگت میں ایسے لگیں گی) گویا گرد و غبار سے محفوظ انڈے (رکھے) ہوں،\qt@no{49}}%
\qt@newcmd\qurantrans@ur@mmmdcccxxxviii{پھر وہ (جنّتی) آپس میں متوجہ ہو کر ایک دوسرے سے (حال و احوال) دریافت کریں گے،\qt@no{50}}%
\qt@newcmd\qurantrans@ur@mmmdcccxxxix{ان میں سے ایک کہنے والا (دوسرے سے) کہے گا کہ میرا ایک ملنے والا تھا (جو آخرت کا منکِر تھا)،\qt@no{51}}%
\qt@newcmd\qurantrans@ur@mmmdcccxl{وہ (مجھے) کہتا تھا: کیا تم بھی (ان باتوں کا) یقین اور تصدیق کرنے والوں میں سے ہو،\qt@no{52}}%
\qt@newcmd\qurantrans@ur@mmmdcccxli{کیا جب ہم مر جائیں گے اور ہم مٹی اور ہڈیاں ہو جائیں گے تو کیا ہمیں (اس حال میں) بدلہ دیا جائے گا،\qt@no{53}}%
\qt@newcmd\qurantrans@ur@mmmdcccxlii{پھر وہ (جنّتی) کہے گا: کیا تم (اُسے) جھانک کر دیکھو گے (کہ وہ کس حال میں ہے)،\qt@no{54}}%
\qt@newcmd\qurantrans@ur@mmmdcccxliii{پھر وہ جھانکے گا تو اسے دوزخ کے (بالکل) وسط میں پائے گا،\qt@no{55}}%
\qt@newcmd\qurantrans@ur@mmmdcccxliv{اس سے) کہے گا: خدا کی قسم! تو اس کے قریب تھا کہ مجھے بھی ہلاک کر ڈالے،\qt@no{56}}%
\qt@newcmd\qurantrans@ur@mmmdcccxlv{اور اگر میرے رب کا احسان نہ ہوتا تو میں (بھی تمہارے ساتھ عذاب میں) حاضر کئے جانے والوں میں شامل ہو جاتا،\qt@no{57}}%
\qt@newcmd\qurantrans@ur@mmmdcccxlvi{سو (جنّتی خوشی سے پوچھیں گے:) کیا اب ہم مریں گے تو نہیں،\qt@no{58}}%
\qt@newcmd\qurantrans@ur@mmmdcccxlvii{اپنی پہلی موت کے سوا (جس سے گزر کر ہم یہاں آچکے) اور نہ ہم پر کبھی عذاب کیا جائے گا،\qt@no{59}}%
\qt@newcmd\qurantrans@ur@mmmdcccxlviii{بیشک یہی تو عظیم کامیابی ہے،\qt@no{60}}%
\qt@newcmd\qurantrans@ur@mmmdcccxlix{ایسی (کامیابی) کے لئے عمل کرنے والوں کو عمل کرنا چاہیے،\qt@no{61}}%
\qt@newcmd\qurantrans@ur@mmmdcccl{بھلا یہ (خُلد کی) مہمانی بہتر ہے یا زقّوم کا درخت،\qt@no{62}}%
\qt@newcmd\qurantrans@ur@mmmdcccli{بیشک ہم نے اس (درخت) کو ظالموں کے لئے عذاب بنایا ہے،\qt@no{63}}%
\qt@newcmd\qurantrans@ur@mmmdccclii{بیشک یہ ایک درخت ہے جو دوزخ کے سب سے نچلے حصہ سے نکلتا ہے،\qt@no{64}}%
\qt@newcmd\qurantrans@ur@mmmdcccliii{اس کے خوشے ایسے ہیں گویا (بدنما) شیطانوں کے سَر ہوں،\qt@no{65}}%
\qt@newcmd\qurantrans@ur@mmmdcccliv{پس وہ (دوزخی) اسی میں سے کھانے والے ہیں اور اسی سے پیٹ بھرنے والے ہیں،\qt@no{66}}%
\qt@newcmd\qurantrans@ur@mmmdccclv{پھر یقیناً اُن کے لئے اس (کھانے) پر (پیپ کا) ملا ہوا نہایت گرم پانی ہوگا (جو انتڑیوں کو کاٹ دے گا)،\qt@no{67}}%
\qt@newcmd\qurantrans@ur@mmmdccclvi{کھانے کے بعد) پھر یقیناً ان کا دوزخ ہی کی طرف (دوبارہ) پلٹنا ہوگا،\qt@no{68}}%
\qt@newcmd\qurantrans@ur@mmmdccclvii{بے شک انہوں نے اپنے باپ دادا کوگمراہ پایا،\qt@no{69}}%
\qt@newcmd\qurantrans@ur@mmmdccclviii{سو وہ انہی کے نقشِ قدم پر دوڑائے جا رہے ہیں،\qt@no{70}}%
\qt@newcmd\qurantrans@ur@mmmdccclix{اور درحقیقت اُن سے قبل پہلے لوگوں میں (بھی) اکثر گمراہ ہوگئے تھے،\qt@no{71}}%
\qt@newcmd\qurantrans@ur@mmmdccclx{اور یقیناً ہم نے ان میں بھی ڈر سنانے والے بھیجے،\qt@no{72}}%
\qt@newcmd\qurantrans@ur@mmmdccclxi{سو آپ دیکھئے کہ ان لوگوں کا انجام کیسا ہوا جو ڈرائے گئے تھے،\qt@no{73}}%
\qt@newcmd\qurantrans@ur@mmmdccclxii{سوائے اﷲ کے چنیدہ و برگزیدہ بندوں کے،\qt@no{74}}%
\qt@newcmd\qurantrans@ur@mmmdccclxiii{اور بیشک ہمیں نوح (علیہ السلام) نے پکارا تو ہم کتنے اچھے فریاد رَس ہیں،\qt@no{75}}%
\qt@newcmd\qurantrans@ur@mmmdccclxiv{اور ہم نے اُنہیں اور اُن کے گھر والوں کو سخت تکلیف سے بچا لیا،\qt@no{76}}%
\qt@newcmd\qurantrans@ur@mmmdccclxv{اور ہم نے فقط اُن ہی کی نسل کو باقی رہنے والا بنایا،\qt@no{77}}%
\qt@newcmd\qurantrans@ur@mmmdccclxvi{اور پیچھے آنے والوں (یعنی انبیاء و اُمم) میں ہم نے ان کا ذکرِ خیر باقی رکھا،\qt@no{78}}%
\qt@newcmd\qurantrans@ur@mmmdccclxvii{سلام ہو نوح پر سب جہانوں میں،\qt@no{79}}%
\qt@newcmd\qurantrans@ur@mmmdccclxviii{بیشک ہم نیکو کاروں کو اسی طرح بدلہ دیا کرتے ہیں،\qt@no{80}}%
\qt@newcmd\qurantrans@ur@mmmdccclxix{بے شک وہ ہمارے (کامل) ایمان والے بندوں میں سے تھے،\qt@no{81}}%
\qt@newcmd\qurantrans@ur@mmmdccclxx{پھر ہم نے دوسروں کو غرق کردیا،\qt@no{82}}%
\qt@newcmd\qurantrans@ur@mmmdccclxxi{بے شک اُن کے گروہ میں سے ابراہیم (علیہ السلام) (بھی) تھے،\qt@no{83}}%
\qt@newcmd\qurantrans@ur@mmmdccclxxii{جب وہ اپنے رب کی بارگاہ میں قلبِ سلیم کے ساتھ حاضر ہوئے،\qt@no{84}}%
\qt@newcmd\qurantrans@ur@mmmdccclxxiii{جبکہ انہوں نے اپنے باپ (جو حقیقت میں چچا تھا، آپ بوجہ پرورش اسے باپ کہتے تھے) اور اپنی قوم سے کہا: تم کن چیزوں کی پرستش کرتے ہو؟،\qt@no{85}}%
\qt@newcmd\qurantrans@ur@mmmdccclxxiv{کیا تم بہتان باندھ کر اﷲ کے سوا (جھوٹے) معبودوں کا ارادہ کرتے ہو؟،\qt@no{86}}%
\qt@newcmd\qurantrans@ur@mmmdccclxxv{بھلا تمام جہانوں کے رب کے بارے میں تمہارا کیا خیال ہے؟،\qt@no{87}}%
\qt@newcmd\qurantrans@ur@mmmdccclxxvi{پھر (ابراہیم علیہ السلام نے اُنہیں وہم میں ڈالنے کے لئے) ایک نظر ستاروں کی طرف کی،\qt@no{88}}%
\qt@newcmd\qurantrans@ur@mmmdccclxxvii{اور کہا: میری طبیعت مُضمحِل ہے (تمہارے ساتھ میلے پر نہیں جاسکتا)،\qt@no{89}}%
\qt@newcmd\qurantrans@ur@mmmdccclxxviii{سو وہ اُن سے پیٹھ پھیر کر لوٹ گئے،\qt@no{90}}%
\qt@newcmd\qurantrans@ur@mmmdccclxxix{پھر (ابراہیم علیہ السلام) ان کے معبودوں (یعنی بتوں) کے پاس خاموشی سے گئے اور اُن سے کہا: کیا تم کھاتے نہیں ہو؟،\qt@no{91}}%
\qt@newcmd\qurantrans@ur@mmmdccclxxx{تمہیں کیا ہے کہ تم بولتے نہیں ہو؟،\qt@no{92}}%
\qt@newcmd\qurantrans@ur@mmmdccclxxxi{پھر (ابراہیم علیہ السلام) پوری قوّت کے ساتھ انہیں مارنے (اور توڑنے) لگے،\qt@no{93}}%
\qt@newcmd\qurantrans@ur@mmmdccclxxxii{پھر لوگ (میلے سے واپسی پر) دوڑتے ہوئے ان کی طرف آئے،\qt@no{94}}%
\qt@newcmd\qurantrans@ur@mmmdccclxxxiii{ابراہیم (علیہ السلام) نے (اُن سے) کہا: کیا تم اِن (ہی بے جان پتھروں) کو پوجتے ہو جنہیں خود تراشتے ہو؟،\qt@no{95}}%
\qt@newcmd\qurantrans@ur@mmmdccclxxxiv{حالانکہ اﷲ نے تمہیں اور تمہارے (سارے) کاموں کو خَلق فرمایا ہے،\qt@no{96}}%
\qt@newcmd\qurantrans@ur@mmmdccclxxxv{وہ کہنے لگے: ان کے (جلانے کے) لئے ایک عمارت بناؤ پھر ان کو (اس کے اندر) سخت بھڑکتی آگ میں ڈال دو،\qt@no{97}}%
\qt@newcmd\qurantrans@ur@mmmdccclxxxvi{غرض انہوں نے ابراہیم (علیہ السلام) کے ساتھ ایک چال چلنا چاہی سو ہم نے اُن ہی کو نیچا دکھا دیا (نتیجۃً آگ گلزار بن گئی)،\qt@no{98}}%
\qt@newcmd\qurantrans@ur@mmmdccclxxxvii{پھر ابراہیم (علیہ السلام) نے کہا: میں (ہجرت کر کے) اپنے رب کی طرف جانے والا ہوں وہ مجھے ضرور راستہ دکھائے گا (وہ ملکِ شام کی طرف ہجرت فرما گئے)،\qt@no{99}}%
\qt@newcmd\qurantrans@ur@mmmdccclxxxviii{پھر اَرضِ مقدّس میں پہنچ کر دعا کی:) اے میرے رب! صالحین میں سے مجھے ایک (فرزند) عطا فرما،\qt@no{100}}%
\qt@newcmd\qurantrans@ur@mmmdccclxxxix{پس ہم نے انہیں بڑے بُرد بار بیٹے (اسماعیل علیہ السلام) کی بشارت دی،\qt@no{101}}%
\qt@newcmd\qurantrans@ur@mmmdcccxc{پھر جب وہ (اسماعیل علیہ السلام) ان کے ساتھ دوڑ کر چل سکنے (کی عمر) کو پہنچ گیا تو (ابراہیم علیہ السلام نے) فرمایا: اے میرے بیٹے! میں خواب میں دیکھتا ہوں کہ میں تجھے ذبح کررہا ہوں سو غور کرو کہ تمہاری کیا رائے ہے۔ (اسماعیل علیہ السلام نے) کہا: ابّاجان! وہ کام (فوراً) کر ڈالیے جس کا آپ کو حکم دیا جا رہا ہے۔ اگر اﷲ نے چاہا تو آپ مجھے صبر کرنے والوں میں سے پائیں گے،\qt@no{102}}%
\qt@newcmd\qurantrans@ur@mmmdcccxci{پھر جب دونوں (رضائے الٰہی کے سامنے) جھک گئے (یعنی دونوں نے مولا کے حکم کو تسلیم کرلیا) اور ابراہیم (علیہ السلام) نے اسے پیشانی کے بل لِٹا دیا (اگلا منظر بیان نہیں فرمایا)،\qt@no{103}}%
\qt@newcmd\qurantrans@ur@mmmdcccxcii{اور ہم نے اسے ندا دی کہ اے ابراہیم!،\qt@no{104}}%
\qt@newcmd\qurantrans@ur@mmmdcccxciii{واقعی تم نے اپنا خواب (کیاخوب) سچا کر دکھایا۔ بے شک ہم محسنوں کو ایسا ہی صلہ دیا کرتے ہیں (سو تمہیں مقامِ خلّت سے نواز دیا گیا ہے)،\qt@no{105}}%
\qt@newcmd\qurantrans@ur@mmmdcccxciv{بے شک یہ بہت بڑی کھلی آزمائش تھی،\qt@no{106}}%
\qt@newcmd\qurantrans@ur@mmmdcccxcv{اور ہم نے ایک بہت بڑی قربانی کے ساتھ اِس کا فدیہ کر دیا،\qt@no{107}}%
\qt@newcmd\qurantrans@ur@mmmdcccxcvi{اور ہم نے پیچھے آنے والوں میں اس کا ذکرِ خیر برقرار رکھا،\qt@no{108}}%
\qt@newcmd\qurantrans@ur@mmmdcccxcvii{سلام ہو ابراہیم پر،\qt@no{109}}%
\qt@newcmd\qurantrans@ur@mmmdcccxcviii{ہم اسی طرح محسنوں کو صلہ دیا کرتے ہیں،\qt@no{110}}%
\qt@newcmd\qurantrans@ur@mmmdcccxcix{بے شک وہ ہمارے (کامل) ایمان والے بندوں میں سے تھے،\qt@no{111}}%
\qt@newcmd\qurantrans@ur@mmmcm{اور ہم نے (اِسما عیل علیہ السلام کے بعد) انہیں اِسحاق (علیہ السلام) کی بشارت دی (وہ بھی) صالحین میں سے نبی تھے،\qt@no{112}}%
\qt@newcmd\qurantrans@ur@mmmcmi{اور ہم نے اُن پر اور اسحاق (علیہ السلام) پر برکتیں نازل فرمائیں، اور ان دونوں کی نسل میں نیکو کار بھی ہیں اور اپنی جان پر کھلے ظلم شِعار بھی،\qt@no{113}}%
\qt@newcmd\qurantrans@ur@mmmcmii{اور بے شک ہم نے موسٰی اور ہارون (علیھما السلام) پر بھی احسان کئے،\qt@no{114}}%
\qt@newcmd\qurantrans@ur@mmmcmiii{اور ہم نے خود ان دونوں کو اور دونوں کی قوم کو سخت تکلیف سے نجات بخشی،\qt@no{115}}%
\qt@newcmd\qurantrans@ur@mmmcmiv{اور ہم نے اُن کی مدد فرمائی تو وہی غالب ہوگئے،\qt@no{116}}%
\qt@newcmd\qurantrans@ur@mmmcmv{اور ہم نے ان دونوں کو واضح اور بیّن کتاب (تورات) عطا فرمائی،\qt@no{117}}%
\qt@newcmd\qurantrans@ur@mmmcmvi{اور ہم نے ان دونوں کو سیدھی راہ پر چلایا،\qt@no{118}}%
\qt@newcmd\qurantrans@ur@mmmcmvii{اور ہم نے ان دونوں کے حق میں (بھی) پیچھے آنے والوں میں ذکرِ خیر باقی رکھا،\qt@no{119}}%
\qt@newcmd\qurantrans@ur@mmmcmviii{سلام ہو موسٰی اور ہارون پر،\qt@no{120}}%
\qt@newcmd\qurantrans@ur@mmmcmix{بے شک ہم نیکو کاروں کو اسی طرح صِلہ دیا کرتے ہیں،\qt@no{121}}%
\qt@newcmd\qurantrans@ur@mmmcmx{بے شک وہ دونوں ہمارے (کامل) ایمان والے بندوں میں سے تھے،\qt@no{122}}%
\qt@newcmd\qurantrans@ur@mmmcmxi{اور یقیناً الیاس (علیہ السلام بھی) رسولوں میں سے تھے،\qt@no{123}}%
\qt@newcmd\qurantrans@ur@mmmcmxii{جب انہوں نے اپنی قوم سے کہا: کیا تم (اﷲ سے) نہیں ڈرتے ہو؟،\qt@no{124}}%
\qt@newcmd\qurantrans@ur@mmmcmxiii{کیا تم بَعل (نامی بُت) کو پوجتے ہو اور سب سے بہتر خالق کو چھوڑ دیتے ہو؟،\qt@no{125}}%
\qt@newcmd\qurantrans@ur@mmmcmxiv{یعنی) اﷲ جو تمہارا (بھی) رب ہے اور تمہارے اگلے باپ دادوں کا (بھی) رب ہے،\qt@no{126}}%
\qt@newcmd\qurantrans@ur@mmmcmxv{تو ان لوگوں نے (یعنی قومِ بعلبک نے) الیاس (علیہ السلام) کو جھٹلایا پس وہ (بھی عذابِ جہنم میں) حاضر کردیے جائیں گے،\qt@no{127}}%
\qt@newcmd\qurantrans@ur@mmmcmxvi{سوائے اﷲ کے چُنے ہوئے بندوں کے،\qt@no{128}}%
\qt@newcmd\qurantrans@ur@mmmcmxvii{اور ہم نے ان کا ذکرِ خیر (بھی) پیچھے آنے والوں میں برقرار رکھا،\qt@no{129}}%
\qt@newcmd\qurantrans@ur@mmmcmxviii{سلام ہو الیاس پر،\qt@no{130}}%
\qt@newcmd\qurantrans@ur@mmmcmxix{بے شک ہم نیکو کاروں کو اسی طرح صِلہ دیا کرتے ہیں،\qt@no{131}}%
\qt@newcmd\qurantrans@ur@mmmcmxx{بے شک وہ ہمارے (کامل) ایمان والے بندوں میں سے تھے،\qt@no{132}}%
\qt@newcmd\qurantrans@ur@mmmcmxxi{اور بے شک لوط (علیہ السلام بھی) رسولوں میں سے تھے،\qt@no{133}}%
\qt@newcmd\qurantrans@ur@mmmcmxxii{جب ہم نے اُن کو اور ان کے سب گھر والوں کو نجات بخشی،\qt@no{134}}%
\qt@newcmd\qurantrans@ur@mmmcmxxiii{سوائے اس بڑھیا کے جو پیچھے رہ جانے والوں میں تھی،\qt@no{135}}%
\qt@newcmd\qurantrans@ur@mmmcmxxiv{پھر ہم نے دوسروں کو ہلاک کر ڈالا،\qt@no{136}}%
\qt@newcmd\qurantrans@ur@mmmcmxxv{اور بے شک تم لوگ اُن (کی اُجڑی بستیوں) پر (مَکّہ سے ملکِ شام کی طرف جاتے ہوئے) صبح کے وقت بھی گزرتے ہو،\qt@no{137}}%
\qt@newcmd\qurantrans@ur@mmmcmxxvi{اور رات کو بھی، کیا پھر بھی تم عقل نہیں رکھتے،\qt@no{138}}%
\qt@newcmd\qurantrans@ur@mmmcmxxvii{اور یونس (علیہ السلام بھی) واقعی رسولوں میں سے تھے،\qt@no{139}}%
\qt@newcmd\qurantrans@ur@mmmcmxxviii{جب وہ بھری ہوئی کشتی کی طرف دوڑے،\qt@no{140}}%
\qt@newcmd\qurantrans@ur@mmmcmxxix{پھر (کشتی بھنور میں پھنس گئی تو) انہوں نے قرعہ ڈالا تو وہ (قرعہ میں) مغلوب ہوگئے (یعنی ان کا نام نکل آیا اور کشتی والوں نے انہیں دریا میں پھینک دیا)،\qt@no{141}}%
\qt@newcmd\qurantrans@ur@mmmcmxxx{پھر مچھلی نے ان کو نگل لیا اور وہ (اپنے آپ پر) نادم رہنے والے تھے،\qt@no{142}}%
\qt@newcmd\qurantrans@ur@mmmcmxxxi{پھر اگر وہ (اﷲ کی) تسبیح کرنے والوں میں سے نہ ہوتے،\qt@no{143}}%
\qt@newcmd\qurantrans@ur@mmmcmxxxii{تو اس (مچھلی) کے پیٹ میں اُس دن تک رہتے جب لوگ (قبروں سے) اٹھائے جائیں گے،\qt@no{144}}%
\qt@newcmd\qurantrans@ur@mmmcmxxxiii{پھر ہم نے انہیں (ساحلِ دریا پر) کھلے میدان میں ڈال دیا حالانکہ وہ بیمار تھے،\qt@no{145}}%
\qt@newcmd\qurantrans@ur@mmmcmxxxiv{اور ہم نے ان پر (کدّو کا) بیل دار درخت اُگا دیا،\qt@no{146}}%
\qt@newcmd\qurantrans@ur@mmmcmxxxv{اور ہم نے انہیں (اَرضِ موصل میں قومِ نینوٰی کے) ایک لاکھ یا اس سے زیادہ افراد کی طرف بھیجا تھا،\qt@no{147}}%
\qt@newcmd\qurantrans@ur@mmmcmxxxvi{سو (آثارِ عذاب کو دیکھ کر) وہ لوگ ایمان لائے تو ہم نے انہیں ایک وقت تک فائدہ پہنچایا،\qt@no{148}}%
\qt@newcmd\qurantrans@ur@mmmcmxxxvii{پس آپ اِن (کفّارِ مکّہ) سے پوچھئے کیا آپ کے رب کے لئے بیٹیاں ہیں اور ان کے لئے بیٹے ہیں،\qt@no{149}}%
\qt@newcmd\qurantrans@ur@mmmcmxxxviii{کیا ہم نے فرشتوں کو عورتیں بنا کر پیدا کیا تو وہ اس وقت (موقع پر) حاضر تھے،\qt@no{150}}%
\qt@newcmd\qurantrans@ur@mmmcmxxxix{سن لو! وہ لوگ یقیناً اپنی بہتان تراشی سے (یہ) بات کرتے ہیں،\qt@no{151}}%
\qt@newcmd\qurantrans@ur@mmmcmxl{کہ اﷲ نے اولاد جنی، اور بیشک یہ لوگ جھوٹے ہیں،\qt@no{152}}%
\qt@newcmd\qurantrans@ur@mmmcmxli{کیا اس نے بیٹوں کے مقابلہ میں بیٹیوں کو پسند فرمایا ہے (کفّارِ مکّہ کی ذہنیت کی زبان میں انہی کے عقیدے کا ردّ کیا جا رہا ہے)،\qt@no{153}}%
\qt@newcmd\qurantrans@ur@mmmcmxlii{تمہیں کیا ہوا ہے؟ تم کیسا انصاف کرتے ہو؟،\qt@no{154}}%
\qt@newcmd\qurantrans@ur@mmmcmxliii{کیا تم غور نہیں کرتے؟،\qt@no{155}}%
\qt@newcmd\qurantrans@ur@mmmcmxliv{کیا تمہارے پاس (اپنے فکر و نظریہ پر) کوئی واضح دلیل ہے،\qt@no{156}}%
\qt@newcmd\qurantrans@ur@mmmcmxlv{تم اپنی کتاب پیش کرو اگر تم سچے ہو،\qt@no{157}}%
\qt@newcmd\qurantrans@ur@mmmcmxlvi{اور انہوں نے (تو) اﷲ اور جِنّات کے درمیان (بھی) نسبی رشتہ مقرر کر رکھا ہے، حالانکہ جنّات کو معلوم ہے کہ وہ (بھی اﷲ کے حضور) یقیناً پیش کیے جائیں گے،\qt@no{158}}%
\qt@newcmd\qurantrans@ur@mmmcmxlvii{اﷲ ان باتوں سے پاک ہے جو یہ بیان کرتے ہیں،\qt@no{159}}%
\qt@newcmd\qurantrans@ur@mmmcmxlviii{مگر اﷲ کے چُنیدہ و برگزیدہ بندے (اِن باتوں سے مستثنٰی ہیں)،\qt@no{160}}%
\qt@newcmd\qurantrans@ur@mmmcmxlix{پس تم اور جن (بتوں) کی تم پرستش کرتے ہو،\qt@no{161}}%
\qt@newcmd\qurantrans@ur@mmmcml{تم سب اﷲ کے خلاف کسی کو گمراہ نہیں کرسکتے،\qt@no{162}}%
\qt@newcmd\qurantrans@ur@mmmcmli{سوائے اس شخص کے جو دوزخ میں جا گرنے والا ہے،\qt@no{163}}%
\qt@newcmd\qurantrans@ur@mmmcmlii{اور (فرشتے کہتے ہیں:) ہم میں سے بھی ہر ایک کا مقام مقرر ہے،\qt@no{164}}%
\qt@newcmd\qurantrans@ur@mmmcmliii{اور یقیناً ہم تو خود صف بستہ رہنے والے ہیں،\qt@no{165}}%
\qt@newcmd\qurantrans@ur@mmmcmliv{اور یقیناً ہم تو خود (اﷲ کی) تسبیح کرنے والے ہیں،\qt@no{166}}%
\qt@newcmd\qurantrans@ur@mmmcmlv{اور یہ لوگ یقیناً کہا کرتے تھے،\qt@no{167}}%
\qt@newcmd\qurantrans@ur@mmmcmlvi{کہ اگر ہمارے پاس (بھی) پہلے لوگوں کی کوئی (کتابِ) نصیحت ہوتی،\qt@no{168}}%
\qt@newcmd\qurantrans@ur@mmmcmlvii{تو ہم (بھی) ضرور اﷲ کے برگزیدہ بندے ہوتے،\qt@no{169}}%
\qt@newcmd\qurantrans@ur@mmmcmlviii{پھر (اب) وہ اس (قرآن) کے منکِر ہوگئے سو وہ عنقریب (اپنا انجام) جان لیں گے،\qt@no{170}}%
\qt@newcmd\qurantrans@ur@mmmcmlix{اور بے شک ہمارا فرمان ہمارے بھیجے ہوئے بندوں (یعنی رسولوں) کے حق میں پہلے صادر ہوچکا ہے،\qt@no{171}}%
\qt@newcmd\qurantrans@ur@mmmcmlx{کہ بے شک وہی مدد یافتہ لوگ ہیں،\qt@no{172}}%
\qt@newcmd\qurantrans@ur@mmmcmlxi{اور بے شک ہمارا لشکر ہی غالب ہونے والا ہے،\qt@no{173}}%
\qt@newcmd\qurantrans@ur@mmmcmlxii{پس ایک وقت تک آپ ان سے توجّہ ہٹا لیجئے،\qt@no{174}}%
\qt@newcmd\qurantrans@ur@mmmcmlxiii{اور انہیں (برابر) دیکھتے رہئیے سو وہ عنقریب (اپنا انجام) دیکھ لیں گے،\qt@no{175}}%
\qt@newcmd\qurantrans@ur@mmmcmlxiv{اور کیا یہ ہمارے عذاب میں جلدی کے خواہش مند ہیں،\qt@no{176}}%
\qt@newcmd\qurantrans@ur@mmmcmlxv{پھر جب وہ (عذاب) ان کے سامنے اترے گا تو اِن کی صبح کیا ہی بُری ہوگی جنہیں ڈرایا گیا تھا،\qt@no{177}}%
\qt@newcmd\qurantrans@ur@mmmcmlxvi{پس آپ اُن سے تھوڑی مدّت تک توجّہ ہٹا ئے رکھئے،\qt@no{178}}%
\qt@newcmd\qurantrans@ur@mmmcmlxvii{اور انہیں (برابر) دیکھتے رہئیے، سو وہ عنقریب (اپنا انجام) دیکھ لیں گے،\qt@no{179}}%
\qt@newcmd\qurantrans@ur@mmmcmlxviii{آپ کا رب، جو عزت کا مالک ہے اُن (باتوں) سے پاک ہے جو وہ بیان کرتے ہیں،\qt@no{180}}%
\qt@newcmd\qurantrans@ur@mmmcmlxix{اور (تمام) رسولوں پر سلام ہو،\qt@no{181}}%
\qt@newcmd\qurantrans@ur@mmmcmlxx{اور سب تعریفیں اﷲ ہی کے لئے ہیں جو تمام جہانوں کا رب ہے،\qt@no{182}}%
\qt@newcmd\qurantrans@ur@mmmcmlxxi{\basmalahur ص (حقیقی معنی اﷲ اور رسول صلی اللہ علیہ وآلہ وسلم ہی بہتر جانتے ہیں)، ذکر والے قرآن کی قسم،\qt@no{1}}%
\qt@newcmd\qurantrans@ur@mmmcmlxxii{بلکہ کافر لوگ (ناحق) حمیّت و تکبّر میں اور (ہمارے نبی صلی اللہ علیہ وآلہ وسلم کی) مخالفت و عداوت میں (مبتلا) ہیں،\qt@no{2}}%
\qt@newcmd\qurantrans@ur@mmmcmlxxiii{ہم نے کتنی ہی امّتوں کو اُن سے پہلے ہلاک کر دیا تو وہ (عذاب کو دیکھ کر) پکارنے لگے حالانکہ اب خلاصی (اور رہائی) کا وقت نہیں رہا تھا،\qt@no{3}}%
\qt@newcmd\qurantrans@ur@mmmcmlxxiv{اور انہوں نے اس بات پر تعجب کیا کہ ان کے پاس اُن ہی میں سے ایک ڈر سنانے والا آگیا ہے۔ اور کفّار کہنے لگے: یہ جادوگر ہے، بہت جھوٹا ہے،\qt@no{4}}%
\qt@newcmd\qurantrans@ur@mmmcmlxxv{کیا اس نے سب معبودوں کو ایک ہی معبود بنا رکھا ہے؟ بے شک یہ تو بڑی ہی عجیب بات ہے،\qt@no{5}}%
\qt@newcmd\qurantrans@ur@mmmcmlxxvi{اور اُن کے سردار (ابوطالب کے گھر میں نبی اکرم صلی اللہ علیہ وآلہ وسلم کی مجلس سے اٹھ کر) چل کھڑے ہوئے (باقی لوگوں سے) یہ کہتے ہوئے کہ تم بھی چل پڑو، اور اپنے معبودوں (کی پرستش) پر ثابت قدم رہو، یہ ضرور ایسی بات ہے جس میں کوئی غرض (اور مراد) ہے،\qt@no{6}}%
\qt@newcmd\qurantrans@ur@mmmcmlxxvii{ہم نے اس (عقیدۂ توحید) کو آخری ملّتِ (نصرانی یا مذہبِ قریش) میں بھی نہیں سنا، یہ صرف خود ساختہ جھوٹ ہے،\qt@no{7}}%
\qt@newcmd\qurantrans@ur@mmmcmlxxviii{کیا ہم سب میں سے اسی پر یہ ذکر (یعنی قرآن) اتارا گیا ہے؟ بلکہ وہ میرے ذکر کی نسبت شک میں (گرفتار) ہیں، بلکہ انہوں نے ابھی میرے عذاب کا مزہ نہیں چکھا،\qt@no{8}}%
\qt@newcmd\qurantrans@ur@mmmcmlxxix{کیا ان کے پاس آپ کے رب کی رحمت کے خزانے ہیں جو غالب ہے بہت عطا فرمانے والا ہے؟،\qt@no{9}}%
\qt@newcmd\qurantrans@ur@mmmcmlxxx{یا اُن کے پاس آسمانوں اور زمین کی اور جو کچھ اِن دونوں کے درمیان ہے اس کی بادشاہت ہے؟ (اگر ہے) تو انہیں چاہئے کہ رسّیاں باندھ کر (آسمان پر) چڑھ جائیں،\qt@no{10}}%
\qt@newcmd\qurantrans@ur@mmmcmlxxxi{کفّار کے) لشکروں میں سے یہ ایک حقیر سا لشکر ہے جو اسی جگہ شکست خوردہ ہونے والا ہے،\qt@no{11}}%
\qt@newcmd\qurantrans@ur@mmmcmlxxxii{اِن سے پہلے قومِ نوح نے اور عاد نے اور بڑی مضبوط حکومت والے (یا میخوں سے اذیّت دینے والے) فرعون نے (بھی) جھٹلایا تھا،\qt@no{12}}%
\qt@newcmd\qurantrans@ur@mmmcmlxxxiii{اور ثمود نے اور قومِ لوط نے اور اَیکہ (بَن) کے رہنے والوں نے (یعنی قومِ شعیب نے) بھی (جھٹلایا تھا)، یہی وہ بڑے لشکر تھے،\qt@no{13}}%
\qt@newcmd\qurantrans@ur@mmmcmlxxxiv{اِن میں سے) ہر ایک گروہ نے رسولوں کو جھٹلایا تو (اُن پر) میرا عذاب واجب ہو گیا،\qt@no{14}}%
\qt@newcmd\qurantrans@ur@mmmcmlxxxv{اور یہ سب لوگ ایک نہایت سخت آواز (چنگھاڑ) کا انتظار کر رہے ہیں جس میں کچھ بھی توقّف نہ ہوگا،\qt@no{15}}%
\qt@newcmd\qurantrans@ur@mmmcmlxxxvi{اور وہ کہتے ہیں: اے ہمارے رب! روزِ حساب سے پہلے ہی ہمارا حصّہ ہمیں جلد دے دے،\qt@no{16}}%
\qt@newcmd\qurantrans@ur@mmmcmlxxxvii{اے حبیبِ مکرّم!) جو کچھ وہ کہتے ہیں آپ اس پر صبر جاری رکھیئے اور ہمارے بندے داؤد (علیہ السلام) کا ذکر کریں جو بڑی قوت والے تھے، بے شک وہ (ہماری طرف) بہت رجوع کرنے والے تھے،\qt@no{17}}%
\qt@newcmd\qurantrans@ur@mmmcmlxxxviii{بے شک ہم نے پہاڑوں کو اُن کے زیرِ فرمان کر دیا تھا، جو (اُن کے ساتھ مل کر) شام کو اور صبح کو تسبیح کیا کرتے تھے،\qt@no{18}}%
\qt@newcmd\qurantrans@ur@mmmcmlxxxix{اور پرندوں کو بھی جو (اُن کے پاس) جمع رہتے تھے، ہر ایک ان کی طرف (اطاعت کے لئے) رجوع کرنے والا تھا،\qt@no{19}}%
\qt@newcmd\qurantrans@ur@mmmcmxc{اور ہم نے اُن کے ملک و سلطنت کو مضبوط کر دیا تھا اور ہم نے انہیں حکمت و دانائی اور فیصلہ کن اندازِ خطاب عطا کیا تھا،\qt@no{20}}%
\qt@newcmd\qurantrans@ur@mmmcmxci{اور کیا آپ کے پاس جھگڑنے والوں کی خبر پہنچی؟ جب وہ دیوار پھاند کر (داؤد علیہ السلام کی) عبادت گاہ میں داخل ہو گئے،\qt@no{21}}%
\qt@newcmd\qurantrans@ur@mmmcmxcii{جب وہ داؤد (علیہ السلام) کے پاس اندر آگئے تو وہ اُن سے گھبرائے، انہوں نے کہا: گھبرائیے نہیں، ہم (ایک) مقدّمہ میں دو فریق ہیں، ہم میں سے ایک نے دوسرے پر زیادتی کی ہے۔ آپ ہمارے درمیان حق و انصاف کے ساتھ فیصلہ کر دیں اور حد سے تجاوز نہ کریں اور ہمیں سیدھی راہ کی طرف رہبری کر دیں،\qt@no{22}}%
\qt@newcmd\qurantrans@ur@mmmcmxciii{بے شک یہ میرا بھائی ہے، اِس کی ننانوے دُنبیاں ہیں اور میرے پاس ایک ہی دُنبی ہے، پھر کہتا ہے یہ (بھی) میرے حوالہ کر دو اور گفتگو میں (بھی) مجھے دبا لیتا ہے،\qt@no{23}}%
\qt@newcmd\qurantrans@ur@mmmcmxciv{داؤد (علیہ السلام) نے کہا: تمہاری دُنبی کو اپنی دُنبیوں سے ملانے کا سوال کر کے اس نے تم سے زیادتی کی ہے اور بیشک اکثر شریک ایک دوسرے پر زیادتی کرتے ہیں سوائے اُن لوگوں کے جو ایمان لائے اور نیک عمل کئے، اور ایسے لوگ بہت کم ہیں۔ اور داؤد (علیہ السلام) نے خیال کیا کہ ہم نے (اس مقدّمہ کے ذریعہ) اُن کی آزمائش کی ہے، سو انہوں نے اپنے رب سے مغفرت طلب کی اور سجدہ میں گر پڑے اور توبہ کی،\qt@no{24}}%
\qt@newcmd\qurantrans@ur@mmmcmxcv{تو ہم نے اُن کو معاف فرما دیا، اور بے شک اُن کے لئے ہماری بارگاہ میں قربِ خاص ہے اور (آخرت میں) اَعلیٰ مقام ہے،\qt@no{25}}%
\qt@newcmd\qurantrans@ur@mmmcmxcvi{اے داؤد! بے شک ہم نے آپ کو زمین میں (اپنا) نائب بنایا سو تم لوگوں کے درمیان حق و انصاف کے ساتھ فیصلے (یا حکومت) کیا کرو اور خواہش کی پیروی نہ کرنا ورنہ (یہ پیروی) تمہیں راہِ خدا سے بھٹکا دے گی، بے شک جو لوگ اﷲ کی راہ سے بھٹک جاتے ہیں اُن کے لئے سخت عذاب ہے اس وجہ سے کہ وہ یومِ حساب کو بھول گئے،\qt@no{26}}%
\qt@newcmd\qurantrans@ur@mmmcmxcvii{اور ہم نے آسمانوں کو اور زمین کو اور جو کائنات دونوں کے درمیان ہے اسے بے مقصد و بے مصلحت نہیں بنایا۔ یہ (بے مقصد یعنی اتفاقیہ تخلیق) کافر لوگوں کا خیال و نظریہ ہے۔ سو کافر لوگوں کے لئے آتشِ دوزخ کی ہلاکت ہے،\qt@no{27}}%
\qt@newcmd\qurantrans@ur@mmmcmxcviii{کیا ہم اُن لوگوں کو جو ایمان لائے اور اعمالِ صالحہ بجا لائے اُن لوگوں جیسا کر دیں گے جو زمین میں فساد بپا کرنے والے ہیں یا ہم پرہیزگاروں کو بدکرداروں جیسا بنا دیں گے،\qt@no{28}}%
\qt@newcmd\qurantrans@ur@mmmcmxcix{یہ کتاب برکت والی ہے جسے ہم نے آپ کی طرف نازل فرمایا ہے تاکہ دانش مند لوگ اس کی آیتوں میں غور و فکر کریں اور نصیحت حاصل کریں،\qt@no{29}}%
\qt@newcmd\qurantrans@ur@mmmm{اور ہم نے داؤد (علیہ السلام) کو (فرزند) سلیمان (علیہ السلام) بخشا، وہ کیا خوب بندہ تھا، بے شک وہ بڑی کثرت سے توبہ کرنے والا ہے،\qt@no{30}}%
\qt@newcmd\qurantrans@ur@mmmmi{جب اُن کے سامنے شام کے وقت نہایت سُبک رفتار عمدہ گھوڑے پیش کئے گئے،\qt@no{31}}%
\qt@newcmd\qurantrans@ur@mmmmii{تو انہوں نے (اِنابۃً) کہا: میں مال (یعنی گھوڑوں) کی محبت کو اپنے رب کے ذکر سے بھی (زیادہ) پسند کر بیٹھا ہوں یہاں تک کہ (سورج رات کے) پردے میں چھپ گیا،\qt@no{32}}%
\qt@newcmd\qurantrans@ur@mmmmiii{انہوں نے کہا: اُن (گھوڑوں) کو میرے پاس واپس لاؤ، تو انہوں نے (تلوار سے) اُن کی پنڈلیاں اور گردنیں کاٹ ڈالیں (یوں اپنی محبت کو اﷲ کے تقرّب کے لئے ذبح کر دیا)،\qt@no{33}}%
\qt@newcmd\qurantrans@ur@mmmmiv{اور بے شک ہم نے سلیمان (علیہ السلام) کی (بھی) آزمائش کی اور ہم نے اُن کے تخت پر ایک (عجیب الخلقت) جسم ڈال دیا پھر انہوں نے دوبارہ (سلطنت) پا لی،\qt@no{34}}%
\qt@newcmd\qurantrans@ur@mmmmv{عرض کیا: اے میرے پروردگار! مجھے بخش دے، اور مجھے ایسی حکومت عطا فرما کہ میرے بعد کسی کو میسّر نہ ہو، بیشک تو ہی بڑا عطا فرمانے والا ہے،\qt@no{35}}%
\qt@newcmd\qurantrans@ur@mmmmvi{پھر ہم نے اُن کے لئے ہوا کو تابع کر دیا، وہ اُن کے حکم سے نرم نرم چلتی تھی جہاں کہیں (بھی) وہ پہنچنا چاہتے،\qt@no{36}}%
\qt@newcmd\qurantrans@ur@mmmmvii{اور کل جنّات (و شیاطین بھی ان کے تابع کر دیئے) اور ہر معمار اور غوطہ زَن (بھی)،\qt@no{37}}%
\qt@newcmd\qurantrans@ur@mmmmviii{اور دوسرے (جنّات) بھی جو زنجیروں میں جکڑے ہوئے تھے،\qt@no{38}}%
\qt@newcmd\qurantrans@ur@mmmmix{ارشاد ہوا:) یہ ہماری عطا ہے (خواہ دوسروں پر) احسان کرو یا (اپنے تک) روکے رکھو (دونوں حالتوں میں) کوئی حساب نہیں،\qt@no{39}}%
\qt@newcmd\qurantrans@ur@mmmmx{اور بے شک اُن کے لئے ہماری بارگاہ میں خصوصی قربت اور آخرت میں عمدہ مقام ہے،\qt@no{40}}%
\qt@newcmd\qurantrans@ur@mmmmxi{اور ہمارے بندے ایّوب (علیہ السلام) کا ذکر کیجئے جب انہوں نے اپنے رب کو پکارا کہ مجھے شیطان نے بڑی اذیّت اور تکلیف پہنچائی ہے،\qt@no{41}}%
\qt@newcmd\qurantrans@ur@mmmmxii{ارشاد ہوا:) تم اپنا پاؤں زمین پر مارو، یہ (پانی کا) ٹھنڈا چشمہ ہے نہانے کے لئے اور پینے کے لئے،\qt@no{42}}%
\qt@newcmd\qurantrans@ur@mmmmxiii{اور ہم نے اُن کو اُن کے اہل و عیال اور اُن کے ساتھ اُن کے برابر (مزید اہل و عیال) عطا کر دیئے، ہماری طرف سے خصوصی رحمت کے طور پر، اور دانش مندوں کے لئے نصیحت کے طور پر،\qt@no{43}}%
\qt@newcmd\qurantrans@ur@mmmmxiv{اے ایوب!) تم اپنے ہاتھ میں (سَو) تنکوں کی جھاڑو پکڑ لو اور (اپنی قسم پوری کرنے کے لئے) اس سے (ایک بار اپنی زوجہ کو) مارو اور قسم نہ توڑو، بے شک ہم نے اسے ثابت قدم پایا، (ایّوب علیہ السلام) کیا خوب بندہ تھا، بے شک وہ (ہماری طرف) بہت رجوع کرنے والا تھا،\qt@no{44}}%
\qt@newcmd\qurantrans@ur@mmmmxv{اور ہمارے بندوں ابراہیم اور اسحاق اور یعقوب (علیھم السلام) کا ذکر کیجئے جو بڑی قوّت والے اور نظر والے تھے،\qt@no{45}}%
\qt@newcmd\qurantrans@ur@mmmmxvi{بے شک ہم نے اُن کو آخرت کے گھر کی یاد کی خاص (خصلت) کی وجہ سے چن لیا تھا،\qt@no{46}}%
\qt@newcmd\qurantrans@ur@mmmmxvii{اور بے شک وہ ہمارے حضور بڑے منتخب و برگزیدہ (اور) پسندیدہ بندوں میں سے تھے،\qt@no{47}}%
\qt@newcmd\qurantrans@ur@mmmmxviii{اور آپ اسماعیل اور الیسع اور ذوالکفل (علیھم السلام) کا (بھی) ذکر کیجئے، اور وہ سارے کے سارے چنے ہوئے لوگوں میں سے تھے،\qt@no{48}}%
\qt@newcmd\qurantrans@ur@mmmmxix{یہ (وہ) ذکر ہے (جس کا بیان اس سورت کی پہلی آیت میں ہے)، اور بے شک پرہیزگاروں کے لئے عمدہ ٹھکانا ہے،\qt@no{49}}%
\qt@newcmd\qurantrans@ur@mmmmxx{جو) دائمی اِقامت کے لئے باغاتِ عدن ہیں جن کے دروازے اُن کے لئے کھلے ہوں گے،\qt@no{50}}%
\qt@newcmd\qurantrans@ur@mmmmxxi{وہ اس میں (مَسندوں پر) تکیے لگائے بیٹھے ہوں گے اس میں (وقفے وقفے سے) بہت سے عمدہ پھل اور میوے اور (لذیذ) شربت طلب کرتے رہیں گے،\qt@no{51}}%
\qt@newcmd\qurantrans@ur@mmmmxxii{اور اُن کے پاس نیچی نگاہوں والی (باحیا) ہم عمر (حوریں) ہوں گی،\qt@no{52}}%
\qt@newcmd\qurantrans@ur@mmmmxxiii{یہ وہ نعمتیں ہیں جن کا روزِ حساب کے لئے تم سے وعدہ کیا جاتا ہے،\qt@no{53}}%
\qt@newcmd\qurantrans@ur@mmmmxxiv{بیشک یہ ہماری بخشش ہے اسے کبھی بھی ختم نہیں ہونا،\qt@no{54}}%
\qt@newcmd\qurantrans@ur@mmmmxxv{یہ (تو مومنوں کے لئے ہے)، اور بے شک سرکشوں کے لئے بہت ہی برا ٹھکانا ہے،\qt@no{55}}%
\qt@newcmd\qurantrans@ur@mmmmxxvi{وہ) دوزخ ہے، اس میں وہ داخل ہوں گے، سو بہت ہی بُرا بچھونا ہے،\qt@no{56}}%
\qt@newcmd\qurantrans@ur@mmmmxxvii{یہ (عذاب ہے) پس انہیں یہ چکھنا چاہئے کھولتا ہوا پانی ہے اور پیپ ہے،\qt@no{57}}%
\qt@newcmd\qurantrans@ur@mmmmxxviii{اور اسی شکل میں اور بھی طرح طرح کا (عذاب) ہے،\qt@no{58}}%
\qt@newcmd\qurantrans@ur@mmmmxxix{دوزخ کے داروغے یا پہلے سے موجود جہنمی کہیں گے:) یہ ایک (اور) فوج ہے جو تمہارے ساتھ (جہنم میں) گھستی چلی آرہی ہے، انہیں کوئی خوش آمدید نہیں، بیشک وہ (بھی) دوزخ میں داخل ہونے والے ہیں،\qt@no{59}}%
\qt@newcmd\qurantrans@ur@mmmmxxx{وہ (آنے والے) کہیں گے: بلکہ تم ہی ہو کہ تمہیں کوئی فراخی نصیب نہ ہو، تم ہی نے یہ (کفر اور عذاب) ہمارے سامنے پیش کیا، سو (یہ) بری قرارگاہ ہے،\qt@no{60}}%
\qt@newcmd\qurantrans@ur@mmmmxxxi{وہ کہیں گے: اے ہمارے رب! جس نے یہ (کفر یا عذاب) ہمارے لئے پیش کیا تھا تو اسے دوزخ میں دوگنا عذاب بڑھا دے،\qt@no{61}}%
\qt@newcmd\qurantrans@ur@mmmmxxxii{اور وہ کہیں گے: ہمیں کیا ہوگیا ہے ہم (اُن) اشخاص کو (یہاں) نہیں دیکھتے جنہیں ہم برے لوگوں میں شمار کرتے تھے،\qt@no{62}}%
\qt@newcmd\qurantrans@ur@mmmmxxxiii{کیا ہم ان کا (ناحق) مذاق اڑاتے تھے یا ہماری آنکھیں انہیں (پہچاننے) سے چوک گئی تھیں (یہ عمّار، خباب، صُہیب، بلال اور سلمان رضی اللہ عنھما جیسے فقراء اور درویش تھے)،\qt@no{63}}%
\qt@newcmd\qurantrans@ur@mmmmxxxiv{بے شک یہ اہلِ جہنم کا آپس میں جھگڑنا یقیناً حق ہے،\qt@no{64}}%
\qt@newcmd\qurantrans@ur@mmmmxxxv{فرما دیجئے: میں تو صرف ڈر سنانے والا ہوں، اور اﷲ کے سوا کوئی معبود نہیں جو یکتا سب پر غالب ہے،\qt@no{65}}%
\qt@newcmd\qurantrans@ur@mmmmxxxvi{آسمانوں اور زمین کا اور جو کائنات اِن دونوں کے درمیان ہے (سب) کا رب ہے بڑی عزت والا، بڑا بخشنے والا ہے،\qt@no{66}}%
\qt@newcmd\qurantrans@ur@mmmmxxxvii{فرما دیجئے: وہ (قیامت) بہت بڑی خبر ہے،\qt@no{67}}%
\qt@newcmd\qurantrans@ur@mmmmxxxviii{تم اس سے منہ پھیرے ہوئے ہو،\qt@no{68}}%
\qt@newcmd\qurantrans@ur@mmmmxxxix{مجھے تو (اَزخود) عالمِ بالا کی جماعتِ (ملائکہ) کی کوئی خبر نہ تھی جب وہ (تخلیقِ آدم کے بارے میں) بحث و تمحیص کر رہے تھے،\qt@no{69}}%
\qt@newcmd\qurantrans@ur@mmmmxl{مجھے تو (اﷲ کی طرف سے) وحی کی جاتی ہے مگر یہ کہ میں صاف صاف ڈر سنانے والا ہوں،\qt@no{70}}%
\qt@newcmd\qurantrans@ur@mmmmxli{وہ وقت یاد کیجئے) جب آپ کے رب نے فرشتوں سے فرمایا کہ میں (گیلی) مٹی سے ایک پیکرِ بشریت پیدا فرمانے والا ہوں،\qt@no{71}}%
\qt@newcmd\qurantrans@ur@mmmmxlii{پھر جب میں اس (کے ظاہر) کو درست کر لوں اور اس (کے باطن) میں اپنی (نورانی) روح پھونک دوں تو تم اس (کی تعظیم) کے لئے سجدہ کرتے ہوئے گر پڑنا،\qt@no{72}}%
\qt@newcmd\qurantrans@ur@mmmmxliii{پس سب کے سب فرشتوں نے اکٹھے سجدہ کیا،\qt@no{73}}%
\qt@newcmd\qurantrans@ur@mmmmxliv{سوائے ابلیس کے، اس نے (شانِ نبوّت کے سامنے) تکبّر کیا اور کافروں میں سے ہوگیا،\qt@no{74}}%
\qt@newcmd\qurantrans@ur@mmmmxlv{اﷲ نے) ارشاد فرمایا: اے ابلیس! تجھے کس نے اس (ہستی) کو سجدہ کرنے سے روکا ہے جسے میں نے خود اپنے دستِ (کرم) سے بنایا ہے، کیا تو نے (اس سے) تکبّر کیا یا تو (بزعمِ خویش) بلند رتبہ (بنا ہوا) تھا،\qt@no{75}}%
\qt@newcmd\qurantrans@ur@mmmmxlvi{اس نے (نبی کے ساتھ اپنا موازنہ کرتے ہوئے) کہا کہ میں اس سے بہتر ہوں، تو نے مجھے آگ سے بنایا ہے اور تو نے اِسے مٹی سے بنایا ہے،\qt@no{76}}%
\qt@newcmd\qurantrans@ur@mmmmxlvii{ارشاد ہوا: سو تو (اِس گستاخئ نبوّت کے جرم میں) یہاں سے نکل جا، بے شک تو مردود ہے،\qt@no{77}}%
\qt@newcmd\qurantrans@ur@mmmmxlviii{اور بے شک تجھ پر قیامت کے دن تک میری لعنت رہے گی،\qt@no{78}}%
\qt@newcmd\qurantrans@ur@mmmmxlix{اس نے کہا: اے پروردگار! پھر مجھے اس دن تک (زندہ رہنے کی) مہلت دے جس دن لوگ قبروں سے اٹھائے جائیں گے،\qt@no{79}}%
\qt@newcmd\qurantrans@ur@mmmml{ارشاد ہوا: (جا) بے شک تو مہلت والوں میں سے ہے،\qt@no{80}}%
\qt@newcmd\qurantrans@ur@mmmmli{اس وقت کے دن تک جو مقرّر (اور معلوم) ہے،\qt@no{81}}%
\qt@newcmd\qurantrans@ur@mmmmlii{اس نے کہا: سو تیری عزّت کی قسم! میں ان سب لوگوں کو ضرور گمراہ کرتا رہوں گا،\qt@no{82}}%
\qt@newcmd\qurantrans@ur@mmmmliii{سوائے تیرے اُن بندوں کے جو چُنیدہ و برگزیدہ ہیں،\qt@no{83}}%
\qt@newcmd\qurantrans@ur@mmmmliv{ارشاد ہوا: پس حق (یہ) ہے اور میں حق ہی کہتا ہوں،\qt@no{84}}%
\qt@newcmd\qurantrans@ur@mmmmlv{کہ میں تجھ سے اور جو لوگ تیری (گستاخانہ سوچ کی) پیروی کریں گے اُن سب سے دوزخ کو بھر دوں گا،\qt@no{85}}%
\qt@newcmd\qurantrans@ur@mmmmlvi{فرما دیجئے: میں تم سے اِس (حق کی تبلیغ) پر کوئی معاوضہ طلب نہیں کرتا اور نہ میں تکلف کرنے والوں میں سے ہوں،\qt@no{86}}%
\qt@newcmd\qurantrans@ur@mmmmlvii{یہ (قرآن) تو سارے جہان والوں کے لئے نصیحت ہی ہے،\qt@no{87}}%
\qt@newcmd\qurantrans@ur@mmmmlviii{اور تمہیں تھوڑے ہی وقت کے بعد خود اِس کا حال معلوم ہو جائے گا،\qt@no{88}}%
\qt@newcmd\qurantrans@ur@mmmmlix{\basmalahur اس کتاب کا اتارا جانا اﷲ کی طرف سے ہے جو بڑی عزت والا، بڑی حکمت والا ہے،\qt@no{1}}%
\qt@newcmd\qurantrans@ur@mmmmlx{بے شک ہم نے آپ کی طرف (یہ) کتاب حق کے ساتھ نازل کی ہے تو آپ اﷲ کی عبادت اس کے لئے طاعت و بندگی کو خالص رکھتے ہوئے کیا کریں،\qt@no{2}}%
\qt@newcmd\qurantrans@ur@mmmmlxi{لوگوں سے کہہ دیں:) سُن لو! طاعت و بندگی خالصۃً اﷲ ہی کے لئے ہے، اور جن (کفّار) نے اﷲ کے سوا (بتوں کو) دوست بنا رکھا ہے، وہ (اپنی بُت پرستی کے جھوٹے جواز کے لئے یہ کہتے ہیں کہ) ہم اُن کی پرستش صرف اس لئے کرتے ہیں کہ وہ ہمیں اﷲ کا مقرّب بنا دیں، بے شک اﷲ اُن کے درمیان اس چیز کا فیصلہ فرما دے گا جس میں وہ اختلاف کرتے ہیں، یقیناً اﷲ اس شخص کو ہدایت نہیں فرماتا جو جھوٹا ہے، بڑا ناشکر گزار ہے،\qt@no{3}}%
\qt@newcmd\qurantrans@ur@mmmmlxii{اگر اﷲ ارادہ فرماتا کہ (اپنے لئے) اولاد بنائے تو اپنی مخلوق میں سے جسے چاہتا منتخب فرما لیتا، وہ پاک ہے، وہی اﷲ ہے جو یکتا ہے سب پر غالب ہے،\qt@no{4}}%
\qt@newcmd\qurantrans@ur@mmmmlxiii{اُس نے آسمانوں اور زمین کو صحیح تدبیر کے ساتھ پیدا فرمایا۔ وہ رات کو دن پر لپیٹتا ہے اور دن کو رات پر لپیٹتا ہے اور اسی نے سورج اور چاند کو (ایک نظام میں) مسخّر کر رکھا ہے، ہر ایک (ستارہ اور سیّارہ) مقرّر وقت کی حد تک (اپنے مدار میں) چلتا ہے، خبردار! وہی (پورے نظام پر) غالب، بڑا بخشنے والا ہے،\qt@no{5}}%
\qt@newcmd\qurantrans@ur@mmmmlxiv{اس نے تم سب کو ایک حیاتیاتی خلیہ سے پیدا فرمایا پھر اس سے اسی جیسا جوڑ بنایا پھر اس نے تمہارے لئے آٹھ جاندار جانور مہیا کئے، وہ تمہاری ماؤں کے رحموں میں ایک تخلیقی مرحلہ سے اگلے تخلیقی مرحلہ میں ترتیب کے ساتھ تمہاری تشکیل کرتا ہے (اس عمل کو) تین قِسم کے تاریک پردوں میں (مکمل فرماتا ہے)، یہی تمہارا پروردگار ہے جو سب قدرت و سلطنت کا مالک ہے، اس کے سوا کوئی معبود نہیں، پھر (تخلیق کے یہ مخفی حقائق جان لینے کے بعد بھی) تم کہاں بہکے پھرتے ہو،\qt@no{6}}%
\qt@newcmd\qurantrans@ur@mmmmlxv{اگر تم کفر کرو تو بے شک اللہ تم سے بے نیاز ہے اور وہ اپنے بندوں کے لئے کفر (و ناشکری) پسند نہیں کرتا، اور اگر تم شکرگزاری کرو (تو) اسے تمہارے لئے پسند فرماتا ہے، اور کوئی بوجھ اٹھانے والا کسی دوسرے کا بوجھ نہیں اٹھائے گا، پھر تمہیں اپنے رب کی طرف لوٹنا ہے پھر وہ تمہیں اُن کاموں سے خبردار کر دے گا جو تم کرتے رہے تھے، بے شک وہ سینوں کی (پوشیدہ) باتوں کو (بھی) خوب جاننے والا ہے،\qt@no{7}}%
\qt@newcmd\qurantrans@ur@mmmmlxvi{اور جب انسان کو کوئی تکلیف پہنچتی ہے تو وہ اپنے رب کو اسی کی طرف رجوع کرتے ہوئے پکارتا ہے، پھر جب (اللہ) اُسے اپنی جانب سے کوئی نعمت بخش دیتا ہے تو وہ اُس (تکلیف) کو بھول جاتا ہے جس کے لئے وہ پہلے دعا کیا کرتا تھا اور (پھر) اللہ کے لئے (بتوں کو) شریک ٹھہرانے لگتا ہے تاکہ (دوسرے لوگوں کو بھی) اس کی راہ سے بھٹکا دے، فرما دیجئے: (اے کافر!) تو اپنے کُفر کے ساتھ تھوڑا سا (ظاہری) فائدہ اٹھا لے، تو بے شک دوزخیوں میں سے ہے،\qt@no{8}}%
\qt@newcmd\qurantrans@ur@mmmmlxvii{بھلا (یہ مشرک بہتر ہے یا) وہ (مومن) جو رات کی گھڑیوں میں سجود اور قیام کی حالت میں عبادت کرنے والا ہے، آخرت سے ڈرتا رہتا ہے اور اپنے رب کی رحمت کی امید رکھتا ہے، فرما دیجئے: کیا جو لوگ علم رکھتے ہیں اور جو لوگ علم نہیں رکھتے (سب) برابر ہوسکتے ہیں؟ بس نصیحت تو عقل مند لوگ ہی قبول کرتے ہیں،\qt@no{9}}%
\qt@newcmd\qurantrans@ur@mmmmlxviii{محبوب! میری طرف سے) فرما دیجئے: اے میرے بندو! جو ایمان لائے ہو اپنے رب کا تقوٰی اختیار کرو۔ ایسے ہی لوگوں کے لئے جو اس دنیا میں صاحبانِ احسان ہوئے، بہترین صلہ ہے، اور اللہ کی سرزمین کشادہ ہے، بلاشبہ صبر کرنے والوں کو اُن کا اجر بے حساب انداز سے پورا کیا جائے گا،\qt@no{10}}%
\qt@newcmd\qurantrans@ur@mmmmlxix{فرما دیجئے: مجھے حکم دیا گیا ہے کہ میں اللہ کی عبادت، اپنی طاعت و بندگی کو اس کے لئے خالص رکھتے ہوئے سر انجام دوں،\qt@no{11}}%
\qt@newcmd\qurantrans@ur@mmmmlxx{اور مجھے یہ (بھی) حکم دیا گیا تھا کہ میں (اُس کی مخلوقات میں) سب سے پہلا مسلمان بنوں،\qt@no{12}}%
\qt@newcmd\qurantrans@ur@mmmmlxxi{فرما دیجئے: اگر میں اپنے رب کی نافرمانی کروں تو میں زبردست دن کے عذاب سے ڈرتا ہوں،\qt@no{13}}%
\qt@newcmd\qurantrans@ur@mmmmlxxii{فرما دیجئے: میں صرف اللہ کی عبادت کرتا ہوں، اپنے دین کو اسی کے لئے خالص رکھتے ہوئے،\qt@no{14}}%
\qt@newcmd\qurantrans@ur@mmmmlxxiii{سو تم اللہ کے سوا جس کی چاہو پوجا کرو، فرما دیجئے: بے شک نقصان اٹھانے والے وہی لوگ ہیں جنہوں نے قیامت کے دن اپنی جانوں کو اور اپنے گھر والوں کو خسارہ میں ڈالا۔ یاد رکھو یہی کھلا نقصان ہے،\qt@no{15}}%
\qt@newcmd\qurantrans@ur@mmmmlxxiv{ان کے لئے اُن کے اوپر (بھی) آگ کے بادل (سائبان بنے) ہوں گے اور ان کے نیچے بھی آگ کے فرش ہوں گے، یہ وہ (عذاب) ہے جس سے اللہ اپنے بندوں کو ڈراتا ہے، اے میرے بندو! بس مجھ سے ڈرتے رہو،\qt@no{16}}%
\qt@newcmd\qurantrans@ur@mmmmlxxv{اور جو لوگ بتوں کی پرستش کرنے سے بچے رہے اور اللہ کی طرف جھکے رہے، ان کے لئے خوشخبری ہے، پس آپ میرے بندوں کو بشارت دے دیجئے،\qt@no{17}}%
\qt@newcmd\qurantrans@ur@mmmmlxxvi{جو لوگ بات کو غور سے سنتے ہیں، پھر اس کے بہتر پہلو کی اتباع کرتے ہیں یہی وہ لوگ ہیں جنہیں اللہ نے ہدایت فرمائی ہے اور یہی لوگ عقل مند ہیں،\qt@no{18}}%
\qt@newcmd\qurantrans@ur@mmmmlxxvii{بھلا جس شخص پر عذاب کا حکم ثابت ہو چکا، تو کیا آپ اس شخص کو بچا سکتے ہیں جو (دائمی) دوزخی ہو چکا ہو،\qt@no{19}}%
\qt@newcmd\qurantrans@ur@mmmmlxxviii{لیکن جو لوگ اپنے رب سے ڈرتے ہیں ان کے لئے (جنت میں) بلند محلات ہوں گے جن کے اوپر (بھی) بالاخانے بنائے گئے ہوں گے، اُن کے نیچے سے نہریں رواں ہوں گی۔ یہ اللہ کا وعدہ ہے، اللہ وعدہ کی خلاف ورزی نہیں کرتا،\qt@no{20}}%
\qt@newcmd\qurantrans@ur@mmmmlxxix{اے انسان!) کیا تو نے نہیں دیکھا کہ اللہ نے آسمان سے پانی برسایا، پھر زمین میں اس کے چشمے رواں کیے، پھر اس کے ذریعے کھیتی پیدا کرتا ہے جس کے رنگ جداگانہ ہوتے ہیں، پھر وہ (تیار ہوکر) خشک ہو جاتی ہے، پھر (پکنے کے بعد) تو اسے زرد دیکھتا ہے، پھر وہ اسے چورا چورا کر دیتا ہے، بے شک اس میں عقل والوں کے لئے نصیحت ہے،\qt@no{21}}%
\qt@newcmd\qurantrans@ur@mmmmlxxx{بھلا اللہ نے جس شخص کا سینہ اسلام کے لئے کھول دیا ہو تو وہ اپنے رب کی طرف سے نور پر (فائز) ہوجاتا ہے، (اس کے برعکس) پس اُن لوگوں کے لئے ہلاکت ہے جن کے دل اللہ کے ذکر (کے فیض) سے (محروم ہو کر) سخت ہوگئے، یہی لوگ کھلی گمراہی میں ہیں،\qt@no{22}}%
\qt@newcmd\qurantrans@ur@mmmmlxxxi{اللہ ہی نے بہترین کلام نازل فرمایا ہے، جو ایک کتاب ہے جس کی باتیں (نظم اور معانی میں) ایک دوسرے سے ملتی جلتی ہیں (جس کی آیتیں) بار بار دہرائی گئی ہیں، جس سے اُن لوگوں کے جسموں کے رونگٹے کھڑے ہوجاتے ہیں جو اپنے رب سے ڈرتے ہیں، پھر اُن کی جلدیں اور دل نرم ہو جاتے ہیں (اور رِقّت کے ساتھ) اللہ کے ذکر کی طرف (محو ہو جاتے ہیں)۔ یہ اللہ کی ہدایت ہے وہ جسے چاہتا ہے اس کے ذریعے رہنمائی فرماتا ہے۔ اور اللہ جسے گمراہ کر دیتا (یعنی گمراہ چھوڑ دیتا) ہے تو اُس کے لئے کوئی ہادی نہیں ہوتا،\qt@no{23}}%
\qt@newcmd\qurantrans@ur@mmmmlxxxii{بھلا وہ شخص جو قیامت کے دن (آگ کے) برے عذاب کو اپنے چہرے سے روک رہا ہوگا (کیونکہ اس کے دونوں ہاتھ بندھے ہونگے، اس کا کیا حال ہوگا؟) اور ایسے ظالموں سے کہا جائے گا: اُن بداعمالیوں کا مزہ چکھو جو تم انجام دیا کرتے تھے،\qt@no{24}}%
\qt@newcmd\qurantrans@ur@mmmmlxxxiii{ایسے لوگوں نے جو اِن سے پہلے تھے (رسولوں کو) جھٹلایا تھا سو اُن پر ایسی جگہ سے عذاب آپہنچا کہ انہیں کچھ شعور ہی نہ تھا،\qt@no{25}}%
\qt@newcmd\qurantrans@ur@mmmmlxxxiv{پس اللہ نے انہیں دنیا کی زندگی میں (ہی) ذِلّت و رسوائی کا مزہ چکھا دیا اور یقیناً آخرت کا عذاب کہیں بڑا ہے، کاش وہ جانتے ہوتے،\qt@no{26}}%
\qt@newcmd\qurantrans@ur@mmmmlxxxv{اور درحقیقت ہم نے لوگوں کے (سمجھانے کے) لئے اس قرآن میں ہر طرح کی مثال بیان کر دی ہے تاکہ وہ نصیحت حاصل کر سکیں،\qt@no{27}}%
\qt@newcmd\qurantrans@ur@mmmmlxxxvi{قرآن عربی زبان میں ہے (جو سب زبانوں سے زیادہ صاف اور بلیغ ہے) جس میں ذرا بھی کجی نہیں ہے تاکہ وہ تقوٰی اختیار کریں،\qt@no{28}}%
\qt@newcmd\qurantrans@ur@mmmmlxxxvii{اللہ نے ایک مثال بیان فرمائی ہے ایسے (غلام) شخص کی جس کی ملکیت میں کئی ایسے لوگ شریک ہوں جو بداخلاق بھی ہوں اور باہم جھگڑالو بھی۔ اور (دوسری طرف) ایک ایسا شخص ہو جو صرف ایک ہی فرد کا غلام ہو، کیا یہ دونوں (اپنے) حالات کے لحاظ سے یکساں ہوسکتے ہیں؟ (ہرگز نہیں) ساری تعریفیں اللہ ہی کے لئے ہیں، بلکہ ان میں سے اکثر لوگ (حقیقتِ توحید کو) نہیں جانتے،\qt@no{29}}%
\qt@newcmd\qurantrans@ur@mmmmlxxxviii{اے حبیبِ مکرّم!) بے شک آپ کو (تو) موت (صرف ذائقہ چکھنے کے لئے) آنی ہے اور وہ یقیناً (دائمی ہلاکت کے لئے) مردہ ہو جائیں گے (پھر دونوں موتوں کا فرق دیکھنے والا ہوگا)۔٭، ٭جس طرح آیت: ٢۹ میں دی گئی مثال کے مطابق دو افراد کے اَحوال قطعاً برابر نہیں ہوں گے اسی طرح ارشاد فرمایا گیا ہے کہ حضور نبی اکرم صلی اللہ علیہ وآلہ وسلم کی وفات اور دوسروں کی موت بھی ہرگز برابر یا مماثل نہیں ہوں گی۔ دونوں کی ماہیت اور حالت میں عظیم فرق ہوگا۔ یہ مثال اسی مقصد کے لئے بیان کی گئی تھی کہ شانِ نبوّت کے باب میں ہمسری اور برابری کا گمان کلیتہً ردّ ہو جائے۔ جیسے ایک مالک کا غلام صحیح اور سالم رہا اور بہت سے بدخو مالکوں کا غلام تباہ حال ہوا اسی طرح اے حبیبِ مکرّم! آپ تو ایک ہی مالک کے برگزیدہ بندے اور محبوب و مقرب رسول ہیں سو وہ آپ کو ہر حال میں سلامت رکھے گا اور یہ کفار بہت سے بتوں اور شریکوں کی غلامی میں ہیں سو وہ انہیں بھی اپنی طرح دائمی ہلاکت کا شکار کر دیں گے۔\qt@no{30}}%
\qt@newcmd\qurantrans@ur@mmmmlxxxix{پھر بلاشبہ تم لوگ قیامت کے دن اپنے رب کے حضور باہم جھگڑا کروگے (ایک گروہ دوسرے کو کہے گا کہ ہمیں مقامِ نبوّت اور شانِ رسالت کو سمجھنے سے تم نے روکا تھا، وہ کہیں گے: نہیں تم خود ہی بدبخت اور گمراہ تھے)،\qt@no{31}}%
\qt@newcmd\qurantrans@ur@mmmmxc{سو اس شخص سے بڑھ کر ظالم کون ہے جو اللہ پر جھوٹ باندھے اور سچ کو جھٹلائے جبکہ وہ اس کے پاس آچکا ہو، کیا کافروں کا ٹھکانا دوزخ میں نہیں ہے،\qt@no{32}}%
\qt@newcmd\qurantrans@ur@mmmmxci{اور جو شخص سچ لے کر آیا اور جس نے اس کی تصدیق کی وہی لوگ ہی تو متقی ہیں،\qt@no{33}}%
\qt@newcmd\qurantrans@ur@mmmmxcii{اُن کے لئے وہ (سب نعمتیں) ان کے رب کے پاس (موجود) ہیں جن کی وہ خواہش کریں گے، یہی محسنوں کی جزا ہے،\qt@no{34}}%
\qt@newcmd\qurantrans@ur@mmmmxciii{تاکہ اللہ اُن کی خطاؤں کو جو انہوں نے کیں اُن سے دور کر دے اور انہیں ان کا ثواب اُن نیکیوں کے بدلہ میں عطا فرمائے جو وہ کیا کرتے تھے،\qt@no{35}}%
\qt@newcmd\qurantrans@ur@mmmmxciv{کیا اللہ اپنے بندۂ (مقرّب نبیِ مکرّم صلی اللہ علیہ وآلہ وسلم) کو کافی نہیں ہے؟ اور یہ (کفّار) آپ کو اللہ کے سوا اُن بتوں سے (جن کی یہ پوجا کرتے ہیں) ڈراتے ہیں، اور جسے اللہ (اس کے قبولِ حق سے اِنکار کے باعث) گمراہ ٹھہرا دے تو اسے کوئی ہدایت دینے والا نہیں،\qt@no{36}}%
\qt@newcmd\qurantrans@ur@mmmmxcv{اور جسے اللہ ہدایت سے نواز دے تو اسے کوئی گمراہ کرنے والا نہیں۔ کیا اللہ بڑا غالب، انتقام لینے والا نہیں ہے،\qt@no{37}}%
\qt@newcmd\qurantrans@ur@mmmmxcvi{اور اگر آپ اُن سے دریافت فرمائیں کہ آسمانوں اور زمین کو کِس نے پیدا کیا تو وہ ضرور کہیں گے: اللہ نے، آپ فرما دیجئے: بھلا یہ بتاؤ کہ جن بتوں کو تم اللہ کے سوا پوجتے ہو اگر اللہ مجھے کوئی تکلیف پہنچانا چاہے تو کیا وہ (بُت) اس کی (بھیجی ہوئی) تکلیف کو دُور کرسکتے ہیں یا وہ مجھے رحمت سے نوازنا چاہے تو کیا وہ (بُت) اس کی (بھیجی ہوئی) رحمت کو روک سکتے ہیں، فرما دیجئے: مجھے اللہ کافی ہے، اسی پر توکل کرنے والے بھروسہ کرتے ہیں،\qt@no{38}}%
\qt@newcmd\qurantrans@ur@mmmmxcvii{فرما دیجئے: اے (میری) قوم! تم اپنی جگہ عمل کئے جاؤ میں (اپنی جگہ) عمل کر رہا ہوں، پھر عنقریب تم (انجام کو) جان لو گے،\qt@no{39}}%
\qt@newcmd\qurantrans@ur@mmmmxcviii{کہ) کس پر عذاب آتا ہے جو اسے رسوا کر دے گا اور اس پر ہمیشہ قائم رہنے والا عذاب اترے گا،\qt@no{40}}%
\qt@newcmd\qurantrans@ur@mmmmxcix{بیشک ہم نے آپ پر لوگوں (کی رہنمائی) کے لئے حق کے ساتھ کتاب اتاری، سو جس نے ہدایت پائی تو اپنے ہی فائدے کے لئے اور جو گمراہ ہوا تو اپنے ہی نقصان کے لئے گمراہ ہوا اور آپ اُن کے ذمّہ دار نہیں ہیں،\qt@no{41}}%
\qt@newcmd\qurantrans@ur@mmmmc{اللہ جانوں کو اُن کی موت کے وقت قبض کر لیتا ہے اور اُن (جانوں) کو جنہیں موت نہیں آئی ہے اُن کی نیند کی حالت میں، پھر اُن کو روک لیتا ہے جن پر موت کا حکم صادر ہو چکا ہو اور دوسری (جانوں) کو مقرّرہ وقت تک چھوڑے رکھتا ہے۔ بے شک اس میں اُن لوگوں کے لئے نشانیاں ہیں جو غور و فکر کرتے ہیں،\qt@no{42}}%
\qt@newcmd\qurantrans@ur@mmmmci{کیا انہوں نے اللہ کے اِذن کے خلاف (بتوں کو) سفارشی بنا رکھا ہے؟ فرما دیجئے: اگرچہ وہ کسی چیز کے مالک بھی نہ ہوں اور ذی عقل بھی نہ ہوں،\qt@no{43}}%
\qt@newcmd\qurantrans@ur@mmmmcii{فرما دیجئے: سب شفاعت (کا اِذن) اللہ ہی کے اختیار میں ہے (جو اس نے اپنے مقرّبین کے لئے مخصوص کر رکھا ہے)، آسمانوں اور زمین کی سلطنت بھی اسی کی ہے، پھر تم اسی کی طرف لوٹائے جاؤ گے،\qt@no{44}}%
\qt@newcmd\qurantrans@ur@mmmmciii{اور جب تنہا اللہ ہی کا ذکر کیا جاتا ہے تو اُن لوگوں کے دل گھٹن اور کراہت کا شکار ہو جاتے ہیں جو آخرت پر یقین نہیں رکھتے، اور جب اللہ کے سوا اُن بتوں کا ذکر کیا جاتا ہے (جنہیں وہ پوجتے ہیں) تو وہ اچانک خوش ہو جاتے ہیں،\qt@no{45}}%
\qt@newcmd\qurantrans@ur@mmmmciv{آپ عرض کیجئے: اے اللہ! آسمانوں اور زمین کو عدم سے وجود میں لانے والے! غیب اور ظاہر کا علم رکھنے والے! تو ہی اپنے بندوں کے درمیان اُن (امور) کا فیصلہ فرمائے گا جن میں وہ اختلاف کیا کرتے تھے،\qt@no{46}}%
\qt@newcmd\qurantrans@ur@mmmmcv{اور اگر ظالموں کو وہ سب کا سب (مال و متاع) میسر ہو جائے جو روئے زمین میں ہے اور اُس کے ساتھ اس کے برابر (اور بھی مل جائے) تو وہ اسے قیامت کے دن بُرے عذاب (سے نجات پانے) کے بدلے میں دے ڈالیں گے، اور اللہ کی طرف سے اُن کے لئے وہ (عذاب) ظاہر ہوگا جس کا وہ گمان بھی نہیں کرتے تھے،\qt@no{47}}%
\qt@newcmd\qurantrans@ur@mmmmcvi{اور اُن کے لئے وہ (سب) برائیاں ظاہر ہو جائیں گی جو انہوں نے کما رکھی ہیں اور انہیں وہ (عذاب) گھیر لے گا جس کا وہ مذاق اڑایا کرتے تھے،\qt@no{48}}%
\qt@newcmd\qurantrans@ur@mmmmcvii{پھر جب انسان کو کوئی تکلیف پہنچتی ہے تو ہمیں پکارتا ہے پھر جب ہم اسے اپنی طرف سے کوئی نعمت بخش دیتے ہیں تو کہنے لگتا ہے کہ یہ نعمت تو مجھے (میرے) علم و تدبیر (کی بنا) پر ملی ہے، بلکہ یہ آزمائش ہے مگر ان میں سے اکثر لوگ نہیں جانتے،\qt@no{49}}%
\qt@newcmd\qurantrans@ur@mmmmcviii{فی الواقع یہ (باتیں) وہ لوگ بھی کیا کرتے تھے جو اُن سے پہلے تھے، سو جو کچھ وہ کماتے رہے اُن کے کسی کام نہ آسکا،\qt@no{50}}%
\qt@newcmd\qurantrans@ur@mmmmcix{تو انہیں وہ برائیاں آپہنچیں جو انہوں نے کما رکھی تھیں، اور اُن لوگوں میں سے جو ظلم کر رہے ہیں انہیں (بھی) عنقریب وہ برائیاں آپہنچیں گی جو انہوں نے کما رکھی ہیں، اور وہ (اللہ کو) عاجز نہیں کرسکتے،\qt@no{51}}%
\qt@newcmd\qurantrans@ur@mmmmcx{اور کیا وہ نہیں جانتے کہ اللہ جس کے لئے چاہتا ہے رزق کشادہ فرما دیتا ہے اور (جس کے لئے چاہتا ہے) تنگ کر دیتا ہے، بے شک اس میں ایمان رکھنے والوں کے لئے نشانیاں ہیں،\qt@no{52}}%
\qt@newcmd\qurantrans@ur@mmmmcxi{آپ فرما دیجئے: اے میرے وہ بندو جنہوں نے اپنی جانوں پر زیادتی کر لی ہے! تم اللہ کی رحمت سے مایوس نہ ہونا، بے شک اللہ سارے گناہ معاف فرما دیتا ہے، وہ یقینا بڑا بخشنے والا، بہت رحم فرمانے والا ہے،\qt@no{53}}%
\qt@newcmd\qurantrans@ur@mmmmcxii{اور تم اپنے رب کی طرف توبہ و انابت اختیار کرو اور اس کے اطاعت گزار بن جاؤ قبل اِس کے کہ تم پر عذاب آجائے پھر تمہاری کوئی مدد نہیں کی جائے گی،\qt@no{54}}%
\qt@newcmd\qurantrans@ur@mmmmcxiii{اور اس بہترین (کتاب) کی پیروی کرو جو تمہارے رب کی طرف سے تمہاری جانب اتاری گئی ہے قبل اِس کے کہ تم پر اچانک عذاب آجائے اور تمہیں خبر بھی نہ ہو،\qt@no{55}}%
\qt@newcmd\qurantrans@ur@mmmmcxiv{ایسا نہ ہو) کہ کوئی شخص کہنے لگے: ہائے افسوس! اس کمی اور کوتاہی پر جو میں نے اللہ کے حقِ (طاعت) میں کی اور میں یقیناً مذاق اڑانے والوں میں سے تھا،\qt@no{56}}%
\qt@newcmd\qurantrans@ur@mmmmcxv{یا کہنے لگے کہ اگر اللہ مجھے ہدایت دیتا تو میں ضرور پرہیزگاروں میں سے ہوتا،\qt@no{57}}%
\qt@newcmd\qurantrans@ur@mmmmcxvi{یا عذاب دیکھتے وقت کہنے لگے کہ اگر ایک بار میرا دنیا میں لوٹنا ہو جائے تو میں نیکوکاروں میں سے ہو جاؤں،\qt@no{58}}%
\qt@newcmd\qurantrans@ur@mmmmcxvii{رب فرمائے گا:) ہاں، بے شک میری آیتیں تیرے پاس آئی تھیں، سو تُو نے انہیں جھٹلا دیا، اور توُ نے تکبّر کیا اور تُو کافروں میں سے ہوگیا،\qt@no{59}}%
\qt@newcmd\qurantrans@ur@mmmmcxviii{اور آپ قیامت کے دن اُن لوگوں کو جنہوں نے اللہ پر جھوٹ بولا ہے دیکھیں گے کہ اُن کے چہرے سیاہ ہوں گے، کیا تکّبر کرنے والوں کا ٹھکانا دوزخ میں نہیں ہے؟،\qt@no{60}}%
\qt@newcmd\qurantrans@ur@mmmmcxix{اور اللہ ایسے لوگوں کو جنہوں نے پرہیزگاری اختیار کی ہے اُن کی کامیابی کے ساتھ نجات دے گا نہ انہیں کوئی برائی پہنچے گی اور نہ ہی وہ غمگین ہوں گے،\qt@no{61}}%
\qt@newcmd\qurantrans@ur@mmmmcxx{اللہ ہر چیز کا خالق ہے اور وہ ہر چیز پر نگہبان ہے،\qt@no{62}}%
\qt@newcmd\qurantrans@ur@mmmmcxxi{اسی کے پاس آسمانوں اور زمین کی کُنجیاں ہیں، اور جن لوگوں نے اللہ کی آیتوں کے ساتھ کفر کیا وہی لوگ ہی خسارہ اٹھانے والے ہیں،\qt@no{63}}%
\qt@newcmd\qurantrans@ur@mmmmcxxii{فرما دیجئے: اے جاہلو! کیا تم مجھے غیر اللہ کی پرستش کرنے کا کہتے ہو،\qt@no{64}}%
\qt@newcmd\qurantrans@ur@mmmmcxxiii{اور فی الحقیقت آپ کی طرف (یہ) وحی کی گئی ہے اور اُن (پیغمبروں) کی طرف (بھی) جو آپ سے پہلے (مبعوث ہوئے) تھے کہ (اے انسان!) اگر تُو نے شرک کیا تو یقیناً تیرا عمل برباد ہو جائے گا اور تُو ضرور نقصان اٹھانے والوں میں سے ہوگا،\qt@no{65}}%
\qt@newcmd\qurantrans@ur@mmmmcxxiv{بلکہ تُو اللہ کی عبادت کر اور شکر گزاروں میں سے ہو جا،\qt@no{66}}%
\qt@newcmd\qurantrans@ur@mmmmcxxv{اور انہوں نے اللہ کی قدر و تعظیم نہیں کی جیسے اُس کی قدر و تعظیم کا حق تھا اور ساری کی ساری زمین قیامت کے دن اُس کی مُٹھی میں ہوگی اور سارے آسمانی کرّے اُس کے دائیں ہاتھ (یعنی قبضۂ قدرت) میں لپٹے ہوئے ہوں گے، وہ پاک ہے اور ہر اس چیز سے بلند و برتر ہے جسے یہ لوگ شریک ٹھہراتے ہیں،\qt@no{67}}%
\qt@newcmd\qurantrans@ur@mmmmcxxvi{اور صُور پھونکا جائے گا تو سب لوگ جو آسمانوں میں ہیں اور جو زمین میں ہیں بے ہوش ہو جائیں گے سوائے اُس کے جسے اللہ چاہے گا، پھر اس میں دوسرا صُور پھونکا جائے گا، سو وہ سب اچانک دیکھتے ہوئے کھڑے ہو جائیں گے،\qt@no{68}}%
\qt@newcmd\qurantrans@ur@mmmmcxxvii{اور زمینِ (محشر) اپنے رب کے نور سے چمک اٹھے گی اور (ہر ایک کے اعمال کی) کتاب رکھ دی جائے گی اور انبیاء کو اور گواہوں کو لایا جائے گا اور لوگوں کے درمیان حق و انصاف کے ساتھ فیصلہ کر دیا جائے گا اور اُن پر کوئی ظلم نہیں کیا جائے گا،\qt@no{69}}%
\qt@newcmd\qurantrans@ur@mmmmcxxviii{اور ہر شخص کو اُس کے اعمال کا پورا پورا بدلہ دیا جائے گا اور وہ خوب جانتا ہے جو کچھ وہ کرتے ہیں،\qt@no{70}}%
\qt@newcmd\qurantrans@ur@mmmmcxxix{اور جن لوگوں نے کفر کیا ہے وہ دوزخ کی طرف گروہ درگروہ ہانکے جائیں گے، یہاں تک کہ جب وہ اُس (جہنم) کے پاس پہنچیں گے تو اُس کے دروازے کھول دیئے جائیں گے اور اس کے داروغے اُن سے کہیں گے: کیا تمہارے پاس تم ہی میں سے رسول نہیں آئے تھے جو تم پر تمہارے رب کی آیات پڑھ کر سناتے تھے اور تمہیں اِس دن کی پیشی سے ڈراتے تھے؟ وہ (دوزخی) کہیں گے: ہاں (آئے تھے)، لیکن کافروں پر فرمانِ عذاب ثابت ہو چکا ہوگا،\qt@no{71}}%
\qt@newcmd\qurantrans@ur@mmmmcxxx{اُن سے کہا جائے گا: دوزخ کے دروازوں میں داخل ہو جاؤ، (تم) اس میں ہمیشہ رہنے والے ہو، سو غرور کرنے والوں کا ٹھکانا کتنا برا ہے،\qt@no{72}}%
\qt@newcmd\qurantrans@ur@mmmmcxxxi{اور جو لوگ اپنے رب سے ڈرتے رہے انہیں (بھی) جنّت کی طرف گروہ در گروہ لے جایا جائے گا، یہاں تک کہ جب وہ اس (جنّت) کے پاس پہنچیں گے اور اُس کے دروازے (پہلے ہی) کھولے جا چکے ہوں گے تو اُن سے وہاں کے نگران (خوش آمدید کرتے ہوئے) کہیں گے: تم پر سلام ہو، تم خوش و خرّم رہو سو ہمیشہ رہنے کے لئے اس میں داخل ہو جاؤ،\qt@no{73}}%
\qt@newcmd\qurantrans@ur@mmmmcxxxii{اور وہ (جنتی) کہیں گے: تمام تعریفیں اللہ ہی کے لئے ہیں جس نے ہم سے اپنا وعدہ سچا کر دکھایا اور ہمیں سرزمینِ جنت کا وارث بنا دیا کہ ہم (اِس) جنّت میں جہاں چاہیں قیام کریں، سو نیک عمل کرنے والوں کا کیسا اچھا اجر ہے،\qt@no{74}}%
\qt@newcmd\qurantrans@ur@mmmmcxxxiii{اور (اے حبیب!) آپ فرشتوں کو عرش کے ارد گرد حلقہ باندھے ہوئے دیکھیں گے جو اپنے رب کی حمد کے ساتھ تسبیح کرتے ہوں گے، اور (سب) لوگوں کے درمیان حق و انصاف کے ساتھ فیصلہ کر دیا جائے گا اور کہا جائے گا کہ کُل حمد اللہ ہی کے لائق ہے جو تمام جہانوں کا پروردگار ہے،\qt@no{75}}%
\qt@newcmd\qurantrans@ur@mmmmcxxxiv{\basmalahur حا، میم (حقیقی معنی اللہ اور رسول صلی اللہ علیہ وآلہ وسلم ہی بہتر جانتے ہیں)،\qt@no{1}}%
\qt@newcmd\qurantrans@ur@mmmmcxxxv{اِس کتاب کا اتارا جانا اللہ کی طرف سے ہے جو غالب ہے، خوب جاننے والا ہے،\qt@no{2}}%
\qt@newcmd\qurantrans@ur@mmmmcxxxvi{گناہ بخشنے والا (ہے) اور توبہ قبول فرمانے والا (ہے)، سخت عذاب دینے والا (ہے)، بڑا صاحبِ کرم ہے۔ اُس کے سوا کوئی معبود نہیں، اسی کی طرف (سب کو) لوٹنا ہے،\qt@no{3}}%
\qt@newcmd\qurantrans@ur@mmmmcxxxvii{اللہ کی آیتوں میں کوئی جھگڑا نہیں کرتا سوائے اُن لوگوں کے جنہوں نے کفر کیا، سو اُن کا شہروں میں (آزادی سے) گھومنا پھرنا تمہیں مغالطہ میں نہ ڈال دے،\qt@no{4}}%
\qt@newcmd\qurantrans@ur@mmmmcxxxviii{اِن سے پہلے قومِ نوح نے اور اُن کے بعد (اور) بہت سی امتّوں نے (اپنے رسولوں کو) جھٹلایا اور ہر امّت نے اپنے رسول کے بارے میں ارادہ کیا کہ اسے پکڑ (کر قتل کر دیں یا قید کر) لیں اور بے بنیاد باتوں کے ذریعے جھگڑا کیا تاکہ اس (جھگڑے) کے ذریعے حق (کا اثر) زائل کر دیں سو میں نے انہیں (عذاب میں) پکڑ لیا، پس (میرا) عذاب کیسا تھا؟،\qt@no{5}}%
\qt@newcmd\qurantrans@ur@mmmmcxxxix{اور اسی طرح آپ کے رب کا فرمان اُن لوگوں پر پورا ہو کر رہا جنہوں نے کفر کیا تھا بے شک وہ لوگ دوزخ والے ہیں،\qt@no{6}}%
\qt@newcmd\qurantrans@ur@mmmmcxl{جو (فرشتے) عرش کو اٹھائے ہوئے ہیں اور جو اُس کے اِرد گِرد ہیں وہ (سب) اپنے رب کی حمد کے ساتھ تسبیح کرتے ہیں اور اس پر ایمان رکھتے ہیں اور اہلِ ایمان کے لئے دعائے مغفرت کرتے ہیں (یہ عرض کرتے ہیں کہ) اے ہمارے رب! تو (اپنی) رحمت اور علم سے ہر شے کا احاطہ فرمائے ہوئے ہے، پس اُن لوگوں کو بخش دے جنہوں نے توبہ کی اور تیرے راستہ کی پیروی کی اور انہیں دوزخ کے عذاب سے بچا لے،\qt@no{7}}%
\qt@newcmd\qurantrans@ur@mmmmcxli{اے ہمارے رب! اور انہیں (ہمیشہ رہنے کے لئے) جنّاتِ عدن میں داخل فرما، جن کا تُو نے اُن سے وعدہ فرما رکھا ہے اور اُن کے آباء و اجداد سے اور اُن کی بیویوں سے اور اُن کی اولاد و ذرّیت سے جو نیک ہوں (انہیں بھی اُن کے ساتھ داخل فرما)، بے شک تو ہی غالب، بڑی حکمت والا ہے،\qt@no{8}}%
\qt@newcmd\qurantrans@ur@mmmmcxlii{اور اُن کو برائیوں (کی سزا) سے بچا لے، اور جسے تو نے اُس دن برائیوں (کی سزا) سے بچا لیا سو بے شک تو نے اُس پر رحم فرمایا، اور یہی تو عظیم کامیابی ہے،\qt@no{9}}%
\qt@newcmd\qurantrans@ur@mmmmcxliii{بے شک جنہوں نے کفر کیا انہیں پکار کر کہا جائے گا: (آج) تم سے اللہ کی بیزاری، تمہاری جانوں سے تمہاری اپنی بیزاری سے زیادہ بڑھی ہوئی ہے، جبکہ تم ایمان کی طرف بلائے جاتے تھے مگر تم انکار کرتے تھے،\qt@no{10}}%
\qt@newcmd\qurantrans@ur@mmmmcxliv{وہ کہیں گے: اے ہمارے رب! تو نے ہمیں دو بار موت دی اور تو نے ہمیں دو بار (ہی) زندگی بخشی، سو (اب) ہم اپنے گناہوں کا اعتراف کرتے ہیں، پس کیا (عذاب سے بچ) نکلنے کی طرف کوئی راستہ ہے،\qt@no{11}}%
\qt@newcmd\qurantrans@ur@mmmmcxlv{ان سے کہا جائے گا: نہیں) یہ (دائمی عذاب) اس وجہ سے ہے کہ جب اللہ کو تنہا پکارا جاتا تھا تو تم انکار کرتے تھے اور اگر اس کے ساتھ (کسی کو) شریک ٹھہرایا جاتا تو تم مان جاتے تھے، پس (اب) اللہ ہی کا حکم ہے جو (سب سے) بلند و بالا ہے،\qt@no{12}}%
\qt@newcmd\qurantrans@ur@mmmmcxlvi{وہی ہے جو تمہیں اپنی نشانیاں دکھاتا ہے اور تمہارے لئے آسمان سے رزق اتارتا ہے، اور نصیحت صرف وہی قبول کرتا ہے جو رجوع (الی اﷲ) میں رہتا ہے،\qt@no{13}}%
\qt@newcmd\qurantrans@ur@mmmmcxlvii{پس تم اللہ کی عبادت اس کے لئے طاعت و بندگی کو خالص رکھتے ہوئے کیا کرو، اگرچہ کافروں کو ناگوار ہی ہو،\qt@no{14}}%
\qt@newcmd\qurantrans@ur@mmmmcxlviii{درجات بلند کرنے والا، مالکِ عرش، اپنے بندوں میں سے جس پر چاہتا ہے روح (یعنی وحی) اپنے حکم سے القاء فرماتا ہے تاکہ وہ (لوگوں کو) اکٹھا ہونے والے دن سے ڈرائے،\qt@no{15}}%
\qt@newcmd\qurantrans@ur@mmmmcxlix{جس دن وہ سب (قبروں سے) نکل پڑیں گے اور ان (کے اعمال) سے کچھ بھی اللہ پر پوشیدہ نہ رہے گا، (ارشاد ہوگا:) آج کس کی بادشاہی ہے؟ (پھر ارشاد ہوگا:) اللہ ہی کی جو یکتا ہے سب پر غالب ہے،\qt@no{16}}%
\qt@newcmd\qurantrans@ur@mmmmcl{آج کے دن ہر جان کو اس کی کمائی کا بدلہ دیا جائے گا، آج کوئی نا انصافی نہ ہوگی، بے شک اللہ بہت جلد حساب لینے والا ہے،\qt@no{17}}%
\qt@newcmd\qurantrans@ur@mmmmcli{اور آپ ان کو قریب آنے والی آفت کے دن سے ڈرائیں جب ضبطِ غم سے کلیجے منہ کو آئیں گے۔ ظالموں کے لئے نہ کوئی مہربان دوست ہوگا اور نہ کوئی سفارشی جس کی بات مانی جائے،\qt@no{18}}%
\qt@newcmd\qurantrans@ur@mmmmclii{وہ خیانت کرنے والی نگاہوں کو جانتا ہے اور (ان باتوں کو بھی) جو سینے (اپنے اندر) چھپائے رکھتے ہیں،\qt@no{19}}%
\qt@newcmd\qurantrans@ur@mmmmcliii{اور اللہ حق کے ساتھ فیصلہ فرماتا ہے، اور جن (بتوں) کو یہ لوگ اللہ کے سوا پوجتے ہیں وہ کچھ بھی فیصلہ نہیں کر سکتے، بے شک اللہ ہی سننے والا، دیکھنے والا ہے،\qt@no{20}}%
\qt@newcmd\qurantrans@ur@mmmmcliv{اور کیا یہ لوگ زمین میں چلے پھرے نہیں کہ دیکھ لیتے ان لوگوں کا انجام کیسا ہوا جو ان سے پہلے تھے، وہ لوگ قوّت میں (بھی) اِن سے بہت زیادہ تھے اور اُن آثار و نشانات میں (بھی) جو زمین میں (چھوڑ گئے) تھے۔ پھر اللہ نے ان کے گناہوں کی وجہ سے انہیں پکڑ لیا، اور ان کے لئے اللہ (کے عذاب) سے بچانے والا کوئی نہ تھا،\qt@no{21}}%
\qt@newcmd\qurantrans@ur@mmmmclv{یہ اس وجہ سے ہوا کہ ان کے پاس ان کے رسول کھلی نشانیاں لے کر آئے تھے پھر انہوں نے کفر کیا تو اللہ نے انہیں (عذاب میں) پکڑ لیا، بے شک وہ بڑی قوت والا، سخت عذاب دینے والا ہے،\qt@no{22}}%
\qt@newcmd\qurantrans@ur@mmmmclvi{اور بے شک ہم نے موسٰی (علیہ السلام) کو اپنی نشانیوں اور واضح دلیل کے ساتھ بھیجا،\qt@no{23}}%
\qt@newcmd\qurantrans@ur@mmmmclvii{فرعون اور ہامان اور قارون کی طرف، تو وہ کہنے لگے کہ یہ جادوگر ہے، بڑا جھوٹا ہے،\qt@no{24}}%
\qt@newcmd\qurantrans@ur@mmmmclviii{پھر جب وہ ہماری بارگاہ سے پیغامِ حق لے کر ان کے پاس آئے تو انہوں نے کہا: ان لوگوں کے لڑکوں کو قتل کر دو جو ان کے ساتھ ایمان لائے ہیں اور ان کی عورتوں کو زندہ چھوڑ دو، اور کافروں کی پر فریب چالیں صرف ہلاکت ہی تھیں،\qt@no{25}}%
\qt@newcmd\qurantrans@ur@mmmmclix{اور فرعون بولا: مجھے چھوڑ دو میں موسٰی کو قتل کر دوں اور اسے چاہیے کہ اپنے رب کو بلا لے۔ مجھے خوف ہے کہ وہ تمہارا دین بدل دے گا یا ملک (مصر) میں فساد پھیلا دے گا،\qt@no{26}}%
\qt@newcmd\qurantrans@ur@mmmmclx{اور موسٰی (علیہ السلام) نے کہا: میں اپنے رب اور تمہارے رب کی پناہ لے چکا ہوں، ہر متکبر شخص سے جو یومِ حساب پر ایمان نہیں رکھتا،\qt@no{27}}%
\qt@newcmd\qurantrans@ur@mmmmclxi{اور ملّتِ فرعون میں سے ایک مردِ مومن نے کہا جو اپنا ایمان چھپائے ہوئے تھا: کیا تم ایک شخص کو قتل کرتے ہو (صرف) اس لئے کہ وہ کہتا ہے: میرا رب اللہ ہے، اور وہ تمہارے پاس تمہارے رب کی طرف سے واضح نشانیاں لے کر آیا ہے، اور اگر (بالفرض) وہ جھوٹا ہے تو اس کے جھوٹ کا بوجھ اسی پر ہوگا اور اگر وہ سچا ہے تو جس قدر عذاب کا وہ تم سے وعدہ کر رہا ہے تمہیں پہنچ کر رہے گا، بے شک اﷲ اسے ہدایت نہیں دیتا جو حد سے گزرنے والا سراسر جھوٹا ہو،\qt@no{28}}%
\qt@newcmd\qurantrans@ur@mmmmclxii{اے میری قوم! آج کے دن تمہاری حکومت ہے (تم ہی) سرزمینِ (مصر) میں اقتدار پر ہو، پھر کون ہمیں اللہ کے عذاب سے بچا سکتا ہے اگر وہ (عذاب) ہمارے پاس آجائے۔ فرعون نے کہا: میں تمہیں فقط وہی بات سمجھاتا ہوں جسے میں خود (صحیح) سمجھتا ہوں اور میں تمہیں بھلائی کی راہ کے سوا (اور کوئی راستہ) نہیں دکھاتا،\qt@no{29}}%
\qt@newcmd\qurantrans@ur@mmmmclxiii{اور اس شخص نے کہا جو ایمان لا چکا تھا: اے میری قوم! میں تم پر (بھی اگلی) قوموں کے روزِ بد کی طرح (عذاب) کا خوف رکھتا ہوں،\qt@no{30}}%
\qt@newcmd\qurantrans@ur@mmmmclxiv{قومِ نوح اور عاد اور ثمود اور جو لوگ ان کے بعد ہوئے (ان) کے دستورِ سزا کی طرح، اور اللہ بندوں پر ہرگز زیادتی نہیں چاہتا،\qt@no{31}}%
\qt@newcmd\qurantrans@ur@mmmmclxv{اور اے قوم! میں تم پر چیخ و پکار کے دن (یعنی قیامت) سے خوف زدہ ہوں،\qt@no{32}}%
\qt@newcmd\qurantrans@ur@mmmmclxvi{جس دن تم پیٹھ پھیر کر بھاگو گے اور تمہیں اللہ (کے عذاب) سے بچانے والا کوئی نہیں ہو گا اور جسے اللہ گمراہ ٹھہرا دے تو اس کے لئے کوئی ہادی و رہنما نہیں ہوتا،\qt@no{33}}%
\qt@newcmd\qurantrans@ur@mmmmclxvii{اور (اے اہلِ مصر!) بے شک تمہارے پاس اس سے پہلے یوسف (علیہ السلام) واضح نشانیوں کے ساتھ آچکے اور تم ہمیشہ ان (نشانیوں) کے بارے میں شک میں (پڑے) رہے جو وہ تمہارے پاس لائے تھے، یہاں تک کہ جب وہ وفات پا گئے تو تم کہنے لگے کہ اب اللہ ان کے بعد ہرگز کسی رسول کو نہیں بھیجے گا۔ اسی طرح اللہ اس شخص کو گمراہ ٹھہرا دیتا ہے جو حد سے گزرنے والا شک کرنے والا ہو،\qt@no{34}}%
\qt@newcmd\qurantrans@ur@mmmmclxviii{جو لوگ اللہ کی آیتوں میں جھگڑا کرتے ہیں بغیر کسی دلیل کے جو ان کے پاس آئی ہو، (یہ جھگڑا کرنا) اللہ کے نزدیک اور ایمان والوں کے نزدیک سخت بیزاری (کی بات) ہے، اسی طرح اللہ ہر ایک مغرور (اور) سر کش کے دل پر مُہر لگا دیتا ہے،\qt@no{35}}%
\qt@newcmd\qurantrans@ur@mmmmclxix{اور فرعون نے کہا: اے ہامان! تو میرے لئے ایک اونچا محل بنا دے تاکہ میں (اس پر چڑھ کر) راستوں پر جا پہنچوں،\qt@no{36}}%
\qt@newcmd\qurantrans@ur@mmmmclxx{یعنی) آسمانوں کے راستوں پر، پھر میں موسٰی کے خدا کو جھانک کر دیکھ سکوں اور میں تو اسے جھوٹا ہی سمجھتا ہوں، اور اس طرح فرعون کے لئے اس کی بد عملی خوش نما کر دی گئی اور وہ (اللہ کی) راہ سے روک دیا گیا، اور فرعون کی پُرفریب تدبیر محض ہلاکت ہی میں تھی،\qt@no{37}}%
\qt@newcmd\qurantrans@ur@mmmmclxxi{اور اس شخص نے کہا جو ایمان لا چکا تھا: اے میری قوم! تم میری پیروی کرو میں تمہیں خیر و ہدایت کی راہ پر لگا دوں گا،\qt@no{38}}%
\qt@newcmd\qurantrans@ur@mmmmclxxii{اے میری قوم! یہ دنیا کی زندگی بس (چند روزہ) فائدہ اٹھانے کے سوا کچھ نہیں اور بے شک آخرت ہی ہمیشہ رہنے کا گھر ہے،\qt@no{39}}%
\qt@newcmd\qurantrans@ur@mmmmclxxiii{جس نے برائی کی تو اسے بدلہ نہیں دیا جائے گا مگر صرف اسی قدر، اور جس نے نیکی کی، خواہ مرد ہو یا عورت اور مومن بھی ہو تو وہی لوگ جنّت میں داخل ہوں گے انہیں وہاں بے حساب رِزق دیا جائے گا،\qt@no{40}}%
\qt@newcmd\qurantrans@ur@mmmmclxxiv{اور اے میری قوم! مجھے کیا ہوا ہے کہ میں تمہیں نجات کی طرف بلاتا ہوں اور تم مجھے دوزخ کی طرف بلاتے ہو،\qt@no{41}}%
\qt@newcmd\qurantrans@ur@mmmmclxxv{تم مجھے (یہ) دعوت دیتے ہو کہ میں اللہ کے ساتھ کفر کروں اور اس کے ساتھ اس چیز کو شریک ٹھہراؤں جس کا مجھے کچھ علم بھی نہیں اور میں تمہیں خدائے غالب کی طرف بلاتا ہوں جو بڑا بخشنے والا ہے،\qt@no{42}}%
\qt@newcmd\qurantrans@ur@mmmmclxxvi{سچ تو یہ ہے کہ تم مجھے جس چیز کی طرف بلا رہے ہو وہ نہ تو دنیا میں پکارے جانے کے قابل ہے اور نہ (ہی) آخرت میں اور بے شک ہمارا واپس لوٹنا اللہ ہی کی طرف ہے اور یقیناً حد سے گزرنے والے ہی دوزخی ہیں،\qt@no{43}}%
\qt@newcmd\qurantrans@ur@mmmmclxxvii{سو تم عنقریب (وہ باتیں) یاد کرو گے جو میں تم سے کہہ رہا ہوں، اور میں اپنا معاملہ اللہ کے سپرد کرتا ہوں، بے شک اللہ بندوں کو دیکھنے والا ہے،\qt@no{44}}%
\qt@newcmd\qurantrans@ur@mmmmclxxviii{پھر اللہ نے اُسے اُن لوگوں کی برائیوں سے بچا لیا جن کی وہ تدبیر کر رہے تھے اور آلِ فرعون کو بُرے عذاب نے گھیر لیا،\qt@no{45}}%
\qt@newcmd\qurantrans@ur@mmmmclxxix{آتشِ دوزخ کے سامنے یہ لوگ صبح و شام پیش کئے جاتے ہیں اور جس دن قیامت بپا ہوگی (تو حکم ہوگا:) آلِ فرعون کو سخت ترین عذاب میں داخل کر دو،\qt@no{46}}%
\qt@newcmd\qurantrans@ur@mmmmclxxx{اور جب وہ لوگ دوزخ میں باہم جھگڑیں گے تو کمزور لوگ ان سے کہیں گے جو (دنیا میں) بڑائی ظاہر کرتے تھے کہ ہم تو تمہارے پیروکار تھے سو کیا تم آتشِ دوزخ کا کچھ حصّہ (ہی) ہم سے دور کر سکتے ہو،\qt@no{47}}%
\qt@newcmd\qurantrans@ur@mmmmclxxxi{تکبر کرنے والے کہیں گے: ہم سب ہی اسی (دوزخ) میں پڑے ہیں بے شک اللہ نے بندوں کے درمیان حتمی فیصلہ فرما دیا ہے،\qt@no{48}}%
\qt@newcmd\qurantrans@ur@mmmmclxxxii{اور آگ میں پڑے ہوئے لوگ دوزخ کے داروغوں سے کہیں گے: اپنے رب سے دعا کرو کہ وہ کسی دن تو ہم سے عذاب ہلکا کر دے،\qt@no{49}}%
\qt@newcmd\qurantrans@ur@mmmmclxxxiii{وہ کہیں گے: کیا تمہارے پاس تمہارے پیغمبر واضح نشانیاں لے کر نہیں آئے تھے، وہ کہیں گے: کیوں نہیں، (پھر داروغے) کہیں گے: تم خود ہی دعا کرو اور کافروں کی دعا (ہمیشہ) رائیگاں ہی ہوگی،\qt@no{50}}%
\qt@newcmd\qurantrans@ur@mmmmclxxxiv{بے شک ہم اپنے رسولوں کی اور ایمان لانے والوں کی دنیوی زندگی میں (بھی) مدد کرتے ہیں اور اس دن (بھی کریں گے) جب گواہ کھڑے ہوں گے،\qt@no{51}}%
\qt@newcmd\qurantrans@ur@mmmmclxxxv{جس دن ظالموں کو اُن کی معذرت فائدہ نہیں دے گی اور اُن کے لئے پھٹکار ہوگی اور اُن کے لئے (جہنّم کا) بُرا گھر ہوگا،\qt@no{52}}%
\qt@newcmd\qurantrans@ur@mmmmclxxxvi{اور بے شک ہم نے موسٰی (علیہ السلام) کو (کتاب) ہدایت عطا کی اور ہم نے (اُن کے بعد) بنی اسرائیل کو (اُس) کتاب کا وارث بنایا،\qt@no{53}}%
\qt@newcmd\qurantrans@ur@mmmmclxxxvii{جو ہدایت ہے اور عقل والوں کے لئے نصیحت ہے،\qt@no{54}}%
\qt@newcmd\qurantrans@ur@mmmmclxxxviii{پس آپ صبر کیجئے، بے شک اللہ کا وعدہ حق ہے اور اپنی اُمت کے گناہوں کی بخشش طلب کیجئے٭ اور صبح و شام اپنے رب کی حمد کے ساتھ تسبیح کیا کیجئے، ٭ لِذَنبِكَ میں ”امت“ مضاف ہے جو کہ محذوف ہے، لہٰذا اس بناء پر یہاں وَاسْتَغْفِرْ لِذَنبِكَ سے مراد امت کے گناہ ہیں۔ امام نسفی، امام قرطبی اور علامہ شوکانی نے یہی معنی بیان کیا ہے۔ حوالہ جات ملاحظہ کریں: ۱۔ (وَاسْتَغْفِرْ لِذَنبِكَ) أی لِذَنبِ أُمتِکَ یعنی اپنی امت کے گناہوں کی بخشش طلب کیجئے۔ (نسفی، مدارک التنزیل و حقائق التاویل، ۴: ۳۵۹)۔ ۲۔ (وَاسْتَغْفِرْ لِذَنبِكَ) قیل: لِذَنبِ أُمتِکَ حذف المضاف و أقیم المضاف الیہ مقامہ۔ ”وَاسْتَغْفِرْ لِذَنبِكَ کے بارے میں کہا گیا ہے کہ اس سے مراد امت کے گناہ ہیں۔ یہاں مضاف کو حذف کر کے مضاف الیہ کو اس کا قائم مقام کر دیا گیا۔“ (قرطبی، الجامع لاحکام القرآن، ۱۵: ۳۲۴)۔ ۳۔ وَ قیل: لِذَنبِکَ لِذَنبِ أُمتِکَ فِی حَقِّکَ ”یہ بھی کہا گیا ہے کہ لِذَنبِکَ یعنی آپ اپنے حق میں امت سے سرزَد ہونے والی خطاؤں کی بخشش طلب کیجئے۔“ (ابن حیان اندلسی، البحر المحیط، ۷: ۴۷۱)۔ ۴۔ (وَاسْتَغْفِرْ لِذَنبِكَ) قیل: المراد ذنب أمتک فھو علی حذف المضاف ” کہا گیا ہے کہ اس سے مراد امت کے گناہ ہیں اور یہ معنی مضاف کے محذوف ہونے کی بناء پر ہے۔“ ( علامہ شوکانی، فتح القدیر، ۴: ۴۹۷)\qt@no{55}}%
\qt@newcmd\qurantrans@ur@mmmmclxxxix{بے شک جو لوگ اللہ کی آیتوں میں جھگڑا کرتے ہیں بغیر کسی دلیل کے جو اُن کے پاس آئی ہو، ان کے سینوں میں سوائے غرور کے اور کچھ نہیں ہے وہ اُس (حقیقی برتری) تک پہنچنے والے ہی نہیں۔ پس آپ (ان کے شر سے) اللہ کی پناہ مانگتے رہئے، بے شک وہی خوب سننے والا خوب دیکھنے والا ہے،\qt@no{56}}%
\qt@newcmd\qurantrans@ur@mmmmcxc{یقیناً آسمانوں اور زمین کی پیدائش انسانوں کی پیدائش سے کہیں بڑھ کر ہے لیکن اکثر لوگ علم نہیں رکھتے،\qt@no{57}}%
\qt@newcmd\qurantrans@ur@mmmmcxci{اور اندھا اور بینا برابر نہیں ہو سکتے سو (اسی طرح) جو لوگ ایمان لائے اور نیک اعمال کئے (وہ) اور بدکار بھی (برابر) نہیں ہیں۔ تم بہت ہی کم نصیحت قبول کرتے ہو،\qt@no{58}}%
\qt@newcmd\qurantrans@ur@mmmmcxcii{بے شک قیامت ضرور آنے والی ہے، اس میں کوئی شک نہیں۔ لیکن اکثر لوگ یقین نہیں رکھتے،\qt@no{59}}%
\qt@newcmd\qurantrans@ur@mmmmcxciii{اور تمہارے رب نے فرمایا ہے: تم لوگ مجھ سے دعا کیا کرو میں ضرور قبول کروں گا، بے شک جو لوگ میری بندگی سے سرکشی کرتے ہیں وہ عنقریب دوزخ میں ذلیل ہو کر داخل ہوں گے،\qt@no{60}}%
\qt@newcmd\qurantrans@ur@mmmmcxciv{اللہ ہی ہے جس نے تمہارے لئے رات بنائی تاکہ تم اس میں آرام پاؤ اور دن کو دیکھنے کے لئے روشن بنایا۔ بے شک اللہ لوگوں پر فضل فرمانے والا ہے لیکن اکثر لوگ شکر ادا نہیں کرتے،\qt@no{61}}%
\qt@newcmd\qurantrans@ur@mmmmcxcv{یہی اللہ تمہارا رب ہے جو ہر چیز کا خالق ہے، اس کے سوا کوئی معبود نہیں، پھر تم کہاں بھٹکتے پھرتے ہو،\qt@no{62}}%
\qt@newcmd\qurantrans@ur@mmmmcxcvi{اسی طرح وہ لوگ بہکے پھرتے تھے جو اللہ کی آیتوں کا انکار کیا کرتے تھے،\qt@no{63}}%
\qt@newcmd\qurantrans@ur@mmmmcxcvii{اللہ ہی ہے جس نے تمہارے لئے زمین کو قرار گاہ بنایا اور آسمان کو چھت بنایا اور تمہیں شکل و صورت بخشی پھر تمہاری صورتوں کو اچھا کیا اور تمہیں پاکیزہ چیزوں سے روزی بخشی، یہی اللہ تمہارا رب ہے۔ پس اللہ بڑی برکت والا ہے جو سب جہانوں کا رب ہے،\qt@no{64}}%
\qt@newcmd\qurantrans@ur@mmmmcxcviii{وہی زندہ ہے، اس کے سوا کوئی معبود نہیں، پس تم اس کی عبادت اُس کے لئے طاعت و بندگی کو خالص رکھتے ہوئے کیا کرو، تمام تعریفیں اللہ ہی کے لئے ہیں جو سب جہانوں کا پروردگار ہے،\qt@no{65}}%
\qt@newcmd\qurantrans@ur@mmmmcxcix{فرما دیجئے: مجھے منع کیا گیا ہے کہ میں اُن کی پرستش کروں جن بتوں کی تم اللہ کو چھوڑ کر پرستش کرتے ہو جبکہ میرے پاس میرے رب کی جانب سے واضح نشانیاں آچکی ہیں اور مجھے حکم دیا گیا ہے کہ تمام جہانوں کے پروردگار کی فرمانبرداری کروں،\qt@no{66}}%
\qt@newcmd\qurantrans@ur@mmmmcc{وہی ہے جس نے تمہاری (کیمیائی حیات کی ابتدائی) پیدائش مٹی سے کی پھر (حیاتیاتی ابتداء) ایک نطفہ (یعنی ایک خلیہ) سے، پھر رحم مادر میں معلّق وجود سے، پھر (بالآخر) وہی تمہیں بچہ بنا کر نکالتا ہے پھر (تمہیں نشو و نما دیتا ہے) تاکہ تم اپنی جوانی کو پہنچ جاؤ۔ پھر (تمہیں عمر کی مہلت دیتا ہے) تاکہ تم بوڑھے ہو جاؤ اور تم میں سے کوئی (بڑھاپے سے) پہلے ہی وفات پا جاتا ہے اور (یہ سب کچھ اس لئے کیاجاتا ہے) تاکہ تم (اپنی اپنی) مقررّہ میعاد تک پہنچ جاؤ اور اِس لئے (بھی) کہ تم سمجھ سکو،\qt@no{67}}%
\qt@newcmd\qurantrans@ur@mmmmcci{وہی ہے جو زندگی دیتا ہے اور موت دیتا ہے پھر جب وہ کسی کام کا فیصلہ فرماتا ہے تو صرف اسے فرما دیتا ہے: ``ہو جا" پس وہ ہو جاتا ہے،\qt@no{68}}%
\qt@newcmd\qurantrans@ur@mmmmccii{کیا آپ نے اُن لوگوں کو نہیں دیکھا جو اللہ کی آیتوں میں جھگڑا کرتے ہیں، وہ کہاں بھٹکے جا رہے ہیں،\qt@no{69}}%
\qt@newcmd\qurantrans@ur@mmmmcciii{جن لوگوں نے کتاب کو (بھی) جھٹلا دیا اور ان (نشانیوں) کو (بھی) جن کے ساتھ ہم نے اپنے رسولوں کو بھیجا تھا، تو وہ عنقریب (اپنا انجام) جان لیں گے،\qt@no{70}}%
\qt@newcmd\qurantrans@ur@mmmmcciv{جب اُن کی گردنوں میں طوق اور زنجیریں ہوں گی، وہ گھسیٹے جا رہے ہوں گے،\qt@no{71}}%
\qt@newcmd\qurantrans@ur@mmmmccv{کھولتے ہوئے پانی میں، پھر آگ میں (ایندھن کے طور پر) جھونک دیئے جائیں گے،\qt@no{72}}%
\qt@newcmd\qurantrans@ur@mmmmccvi{پھر اُن سے کہا جائے گا: کہاں ہیں وہ (بُت) جنہیں تم شریک ٹھہراتے تھے،\qt@no{73}}%
\qt@newcmd\qurantrans@ur@mmmmccvii{اللہ کے سوا، وہ کہیں گے: وہ ہم سے گم ہو گئے بلکہ ہم تو پہلے کسی بھی چیز کی پرستش نہیں کرتے تھے، اسی طرح اللہ کافروں کو گمراہ ٹھہراتا ہے،\qt@no{74}}%
\qt@newcmd\qurantrans@ur@mmmmccviii{یہ (سزا) اس کا بدلہ ہے کہ تم زمین میں ناحق خوشیاں منایا کرتے تھے اور اُس کا بدلہ ہے کہ تم اِترایا کرتے تھے،\qt@no{75}}%
\qt@newcmd\qurantrans@ur@mmmmccix{دوزخ کے دروازوں میں داخل ہو جاؤ تم اس میں ہمیشہ رہنے والے ہو، سو غرور کرنے والوں کا ٹھکانا کتنا بُرا ہے،\qt@no{76}}%
\qt@newcmd\qurantrans@ur@mmmmccx{پس آپ صبر کیجئے بے شک اﷲ کا وعدہ سچّا ہے، پھر اگر ہم آپ کو اس (عذاب) کا کچھ حصّہ دکھا دیں جس کا ہم اُن سے وعدہ کر رہے ہیں یا ہم آپ کو (اس سے قبل) وفات دے دیں تو (دونوں صورتوں میں) وہ ہماری ہی طرف لوٹائے جائیں گے،\qt@no{77}}%
\qt@newcmd\qurantrans@ur@mmmmccxi{اور بے شک ہم نے آپ سے پہلے بہت سے رسولوں کو بھیجا، ان میں سے بعض کا حال ہم نے آپ پر بیان فرما دیا اور ان میں سے بعض کا حال ہم نے (ابھی تک) آپ پر بیان نہیں فرمایا، اور کسی بھی رسول کے لئے یہ (ممکن) نہ تھا کہ وہ کوئی نشانی بھی اﷲ کے اِذن کے بغیر لے آئے، پھر جب اﷲ کا حکم آپہنچا (اور) حق و انصاف کے ساتھ فیصلہ کر دیا گیا تو اس وقت اہلِ باطل خسارے میں رہے،\qt@no{78}}%
\qt@newcmd\qurantrans@ur@mmmmccxii{اﷲ ہی ہے جس نے تمہارے لئے چوپائے بنائے تاکہ تم اُن میں سے بعض پر سواری کرو اور اِن میں سے بعض کو تم کھاتے ہو،\qt@no{79}}%
\qt@newcmd\qurantrans@ur@mmmmccxiii{اور تمہارے لئے ان میں اور بھی فوائد ہیں اور تاکہ تم ان پر سوار ہو کر (مزید) اُس ضرورت (کی جگہ) تک پہنچ سکو جو تمہارے سینوں میں (متعین) ہے اور (یہ کہ) تم اُن پر اور کشتیوں پر سوار کئے جاتے ہو،\qt@no{80}}%
\qt@newcmd\qurantrans@ur@mmmmccxiv{اور وہ تمہیں اپنی (بہت سے) نشانیاں دکھاتا ہے، سو تم اﷲ کی کن کن نشانیوں کا انکار کرو گے،\qt@no{81}}%
\qt@newcmd\qurantrans@ur@mmmmccxv{سو کیا انہوں نے زمین میں سیر و سیاحت نہیں کی کہ وہ دیکھتے کہ اُن لوگوں کا انجام کیسا ہوا جو اُن سے پہلے گزر گئے، وہ اِن لوگوں سے (تعداد میں بھی) بہت زیادہ تھے اور طاقت میں (بھی) سخت تر تھے اور نشانات کے لحاظ سے (بھی) جو (وہ) زمین میں چھوڑ گئے ہیں (کہیں بڑھ کر تھے) مگر جو کچھ وہ کمایا کرتے تھے اُن کے کسی کام نہ آیا،\qt@no{82}}%
\qt@newcmd\qurantrans@ur@mmmmccxvi{پھر جب اُن کے پیغمبر اُن کے پاس واضح نشانیاں لے کر آئے تو اُن کے پاس جو (دنیاوی) علم و فن تھا وہ اس پر اِتراتے رہے اور (اسی حال میں) انہیں اُس (عذاب) نے آگھیرا جس کا وہ مذاق اڑایا کرتے تھے،\qt@no{83}}%
\qt@newcmd\qurantrans@ur@mmmmccxvii{پھر جب انہوں نے ہمارا عذاب دیکھ لیا تو کہنے لگے: ہم اﷲ پر ایمان لائے جو یکتا ہے اور ہم نے اُن (سب) کا انکار کر دیا جنہیں ہم اس کا شریک ٹھہرایا کرتے تھے،\qt@no{84}}%
\qt@newcmd\qurantrans@ur@mmmmccxviii{پھر اُن کا ایمان لانا اُن کے کچھ کام نہ آیا جبکہ انہوں نے ہمارے عذاب کو دیکھ لیا تھا، اﷲ کا (یہی) دستور ہے جو اُس کے بندوں میں گزرتا چلا آرہا ہے اور اس مقام پر کافروں نے (ہمیشہ) سخت نقصان اٹھایا،\qt@no{85}}%
\qt@newcmd\qurantrans@ur@mmmmccxix{\basmalahur حا، میم (حقیقی معنی اﷲ اور رسول صلی اللہ علیہ وآلہ وسلم ہی بہتر جانتے ہیں)،\qt@no{1}}%
\qt@newcmd\qurantrans@ur@mmmmccxx{نہایت مہربان بہت رحم فرمانے والے (رب) کی جانب سے اتارا جانا ہے،\qt@no{2}}%
\qt@newcmd\qurantrans@ur@mmmmccxxi{اِس) کتاب کا جس کی آیات واضح طور پر بیان کر دی گئی ہیں علم و دانش رکھنے والی قوم کے لئے عربی (زبان میں) قرآن (ہے)،\qt@no{3}}%
\qt@newcmd\qurantrans@ur@mmmmccxxii{خوشخبری سنانے والا ہے اور ڈر سنانے والا ہے، پھر ان میں سے اکثر لوگوں نے رُوگردانی کی سو وہ (اِسے) سنتے ہی نہیں ہیں،\qt@no{4}}%
\qt@newcmd\qurantrans@ur@mmmmccxxiii{اور کہتے ہیں کہ ہمارے دل اُس چیز سے غلافوں میں ہیں جس کی طرف آپ ہمیں بلاتے ہیں اور ہمارے کانوں میں (بہرے پن کا) بوجھ ہے اور ہمارے اور آپ کے درمیان پردہ ہے سو آپ (اپنا) عمل کرتے رہئے ہم اپنا عمل کرنے والے ہیں،\qt@no{5}}%
\qt@newcmd\qurantrans@ur@mmmmccxxiv{اِن کے پردے ہٹانے اور سننے پر آمادہ کرنے کے لئے) فرما دیجئے: (اے کافرو!) بس میں ظاہراً آدمی ہونے میں تو تم ہی جیسا ہوں (پھر مجھ سے اور میری دعوت سے اس قدر کیوں گریزاں ہو) میری طرف یہ وحی بھیجی گئی ہے کہ تمہارا معبود فقط معبودِ یکتا ہے، پس تم اسی کی طرف سیدھے متوجہ رہو اور اس سے مغفرت چاہو، اور مشرکوں کے لئے ہلاکت ہے،\qt@no{6}}%
\qt@newcmd\qurantrans@ur@mmmmccxxv{جو زکوٰۃ ادا نہیں کرتے اور وہی تو آخرت کے بھی منکر ہیں،\qt@no{7}}%
\qt@newcmd\qurantrans@ur@mmmmccxxvi{بے شک جو لوگ ایمان لائے اور نیک عمل کرتے رہے اُن کے لئے ایسا اجر ہے جو کبھی ختم نہیں ہوگا،\qt@no{8}}%
\qt@newcmd\qurantrans@ur@mmmmccxxvii{فرما دیجئے: کیا تم اس (اﷲ) کا انکار کرتے ہو جس نے زمین کو دو دِن (یعنی دو مدّتوں) میں پیدا فرمایا اور تم اُس کے لئے ہمسر ٹھہراتے ہو، وہی سارے جہانوں کا پروردگار ہے،\qt@no{9}}%
\qt@newcmd\qurantrans@ur@mmmmccxxviii{اور اُس کے اندر (سے) بھاری پہاڑ (نکال کر) اس کے اوپر رکھ دیئے اور اس کے اندر (معدنیات، آبی ذخائر، قدرتی وسائل اور دیگر قوتوں کی) برکت رکھی، اور اس میں (جملہ مخلوق کے لئے) غذائیں (اور سامانِ معیشت) مقرر فرمائے (یہ سب کچھ اس نے) چار دنوں (یعنی چار ارتقائی زمانوں) میں مکمل کیا، (یہ سارا رِزق اصلًا) تمام طلب گاروں (اور حاجت مندوں) کے لئے برابر ہے،\qt@no{10}}%
\qt@newcmd\qurantrans@ur@mmmmccxxix{پھر وہ سماوی کائنات کی طرف متوجہ ہوا تو وہ (سب) دھواں تھا، سو اس نے اُسے (یعنی آسمانی کرّوں سے) اور زمین سے فرمایا: خواہ باہم کشش و رغبت سے یا گریزی و ناگواری سے (ہمارے نظام کے تابع) آجاؤ، دونوں نے کہا: ہم خوشی سے حاضر ہیں،\qt@no{11}}%
\qt@newcmd\qurantrans@ur@mmmmccxxx{پھر دو دِنوں (یعنی دو مرحلوں) میں سات آسمان بنا دیئے اور ہر سماوی کائنات میں اس کا نظام ودیعت کر دیا اور آسمانِ دنیا کو ہم نے چراغوں (یعنی ستاروں اور سیّاروں) سے آراستہ کر دیا اور محفوظ بھی (تاکہ ایک کا نظام دوسرے میں مداخلت نہ کر سکے)، یہ زبر دست غلبہ (و قوت) والے، بڑے علم والے (رب) کا مقرر کردہ نظام ہے،\qt@no{12}}%
\qt@newcmd\qurantrans@ur@mmmmccxxxi{پھر اگر وہ رُوگردانی کریں تو آپ فرما دیں: میں تمہیں اُس خوفناک عذاب سے ڈراتا ہوں جو عاد اور ثمود کی ہلاکت کے مانند ہوگا،\qt@no{13}}%
\qt@newcmd\qurantrans@ur@mmmmccxxxii{جب اُن کے پاس اُن کے آگے اور اُن کے پیچھے (یا اُن سے پہلے اور ان کے بعد) پیغمبر آئے (اور کہا) کہ اﷲ کے سوا کسی کی عبادت نہ کرو، تو وہ کہنے لگے: اگر ہمارا رب چاہتا تو فرشتوں کو اتار دیتا سو جو کچھ تم دے کر بھیجے گئے ہو ہم اس کے منکر ہیں،\qt@no{14}}%
\qt@newcmd\qurantrans@ur@mmmmccxxxiii{پس جو قومِ عاد تھی سو انہوں نے زمین میں ناحق تکبر (و سرکشی) کی اور کہنے لگے: ہم سے بڑھ کر طاقتور کون ہے؟ اور کیا انہوں نے نہیں دیکھا کہ اﷲ جس نے انہیں پیدا فرمایا ہے وہ اُن سے کہیں بڑھ کر طاقتور ہے، اور وہ ہماری آیتوں کا انکار کرتے رہے،\qt@no{15}}%
\qt@newcmd\qurantrans@ur@mmmmccxxxiv{سو ہم نے اُن پر منحوس دنوں میں خوفناک تیز و تُند آندھی بھیجی تاکہ ہم انہیں دنیوی زندگی میں ذِلت کے عذاب کا مزہ چکھائیں، اور آخرت کا عذاب تو سب سے زیادہ ذِلت انگیز ہوگا اور اُن کی کوئی مدد نہ کی جائے گی،\qt@no{16}}%
\qt@newcmd\qurantrans@ur@mmmmccxxxv{اور جو قومِ ثمود تھی، سو ہم نے انہیں راہِ ہدایت دکھائی تو انہوں نے ہدایت کے مقابلہ میں اندھا رہنا ہی پسند کیا تو انہیں ذِلّت کے عذاب کی کڑک نے پکڑ لیا اُن اعمال کے بدلے جو وہ کمایا کرتے تھے،\qt@no{17}}%
\qt@newcmd\qurantrans@ur@mmmmccxxxvi{اور ہم نے اُن لوگوں کو نجات بخشی جو ایمان لائے اور پرہیزگاری کرتے رہے،\qt@no{18}}%
\qt@newcmd\qurantrans@ur@mmmmccxxxvii{اور جس دن اﷲ کے دشمنوں کو دوزخ کی طرف جمع کر کے لایا جائے گا پھر انہیں روک روک کر (اور ہانک کر) چلایا جائے گا،\qt@no{19}}%
\qt@newcmd\qurantrans@ur@mmmmccxxxviii{یہاں تک کہ جب وہ دوزخ تک پہنچ جائیں گے تو اُن کے کان اور اُن کی آنکھیں اور اُن (کے جسموں) کی کھالیں اُن کے خلاف گواہی دیں گی اُن اعمال پر جو وہ کرتے رہے تھے،\qt@no{20}}%
\qt@newcmd\qurantrans@ur@mmmmccxxxix{پھر وہ لوگ اپنی کھالوں سے کہیں گے: تم نے ہمارے خلاف کیوں گواہی دی، وہ کہیں گی: ہمیں اُس اﷲ نے گویائی عطا کی جو ہر چیز کو قوتِ گویائی دیتا ہے اور اسی نے تمہیں پہلی بار پیدا فرمایا ہے اور تم اسی کی طرف پلٹائے جاؤ گے،\qt@no{21}}%
\qt@newcmd\qurantrans@ur@mmmmccxl{تم تو (گناہ کرتے وقت) اس (خوف) سے بھی پردہ نہیں کرتے تھے کہ تمہارے کان تمہارے خلاف گواہی دے دیں گے اور نہ (یہ کہ) تمہاری آنکھیں اور نہ (یہ کہ) تمہاری کھالیں (ہی گواہی دے دیں گی) لیکن تم گمان کرتے تھے کہ اﷲ تمہارے بہت سے کاموں کو جو تم کرتے ہو جانتا ہی نہیں ہے،\qt@no{22}}%
\qt@newcmd\qurantrans@ur@mmmmccxli{اور تمہارا یہی گمان جو تم نے اپنے رب کے بارے میں قائم کیا، تمہیں ہلاک کر گیا سو تم نقصان اٹھانے والوں میں سے ہو گئے،\qt@no{23}}%
\qt@newcmd\qurantrans@ur@mmmmccxlii{اب اگر وہ صبر کریں تب بھی ان کا ٹھکانا دوزخ ہے، اور اگر وہ (توبہ کے ذریعے اﷲ کی) رضا حاصل کرنا چاہیں تو بھی وہ رضا پانے والوں میں نہیں ہوں گے،\qt@no{24}}%
\qt@newcmd\qurantrans@ur@mmmmccxliii{اور ہم نے اُن کے لئے ساتھ رہنے والے (شیاطین) مقرر کر دیئے، سو انہوں نے اُن کے لئے وہ (تمام برے اعمال) خوش نما کر دکھائے جو اُن کے آگے تھے اور اُن کے پیچھے تھے اور اُن پر (وہی) فرمانِ عذاب ثابت ہوگیا جو اُن امتوں کے بارے میں صادر ہوچکا تھا جو جنّات اور انسانوں میں سے اُن سے پہلے گزر چکی تھیں۔ بے شک وہ نقصان اٹھانے والے تھے،\qt@no{25}}%
\qt@newcmd\qurantrans@ur@mmmmccxliv{اور کافر لوگ کہتے ہیں: تم اِس قرآن کو مت سنا کرو اور اِس (کی قرات کے اوقات) میں شور و غل مچایا کرو تاکہ تم (اِن کے قرآن پڑھنے پر) غالب رہو،\qt@no{26}}%
\qt@newcmd\qurantrans@ur@mmmmccxlv{پس ہم کافروں کو سخت عذاب کا مزہ ضرور چکھائیں گے اور ہم انہیں اُن برے اعمال کا بدلہ ضرور دیں گے جو وہ کرتے رہے تھے،\qt@no{27}}%
\qt@newcmd\qurantrans@ur@mmmmccxlvi{یہ دوزخ اﷲ کے دشمنوں کی جزا ہے، اُن کے لئے اِس میں ہمیشہ رہنے کا گھر ہے، یہ اُس کا بدلہ ہے جو وہ ہماری آیتوں کا انکار کیا کرتے تھے،\qt@no{28}}%
\qt@newcmd\qurantrans@ur@mmmmccxlvii{اور جن لوگوں نے کفر کیا ہے کہیں گے: اے ہمارے رب! ہمیں جنّات اور انسانوں میں سے وہ دونوں دِکھا دے جنہوں نے ہمیں گمراہ کیا ہے ہم انہیں اپنے قدموں کے نیچے (روند) ڈالیں تاکہ وہ سب سے زیادہ ذِلّت والوں میں ہو جائیں،\qt@no{29}}%
\qt@newcmd\qurantrans@ur@mmmmccxlviii{بے شک جن لوگوں نے کہا: ہمارا رب اﷲ ہے، پھر وہ (اِس پر مضبوطی سے) قائم ہوگئے، تو اُن پر فرشتے اترتے ہیں (اور کہتے ہیں) کہ تم خوف نہ کرو اور نہ غم کرو اور تم جنت کی خوشیاں مناؤ جس کا تم سے وعدہ کیا جاتا تھا،\qt@no{30}}%
\qt@newcmd\qurantrans@ur@mmmmccxlix{ہم دنیا کی زندگی میں (بھی) تمہارے دوست اور مددگار ہیں اور آخرت میں (بھی)، اور تمہارے لئے وہاں ہر وہ نعمت ہے جسے تمہارا جی چاہے اور تمہارے لئے وہاں وہ تمام چیزیں (حاضر) ہیں جو تم طلب کرو،\qt@no{31}}%
\qt@newcmd\qurantrans@ur@mmmmccl{یہ) بڑے بخشنے والے، بہت رحم فرمانے والے (رب) کی طرف سے مہمانی ہے،\qt@no{32}}%
\qt@newcmd\qurantrans@ur@mmmmccli{اور اس شخص سے زیادہ خوش گفتار کون ہو سکتا ہے جو اﷲ کی طرف بلائے اور نیک عمل کرے اور کہے: بے شک میں (اﷲ عزّ و جل اور رسول صلی اللہ علیہ وآلہ وسلم کے) فرمانبرداروں میں سے ہوں،\qt@no{33}}%
\qt@newcmd\qurantrans@ur@mmmmcclii{اور نیکی اور بدی برابر نہیں ہو سکتے، اور برائی کو بہتر (طریقے) سے دور کیا کرو سو نتیجتاً وہ شخص کہ تمہارے اور جس کے درمیان دشمنی تھی گویا وہ گرم جوش دوست ہو جائے گا،\qt@no{34}}%
\qt@newcmd\qurantrans@ur@mmmmccliii{اور یہ (خوبی) صرف اُنہی لوگوں کو عطا کی جاتی ہے جو صبر کرتے ہیں، اور یہ (توفیق) صرف اسی کو حاصل ہوتی ہے جو بڑے نصیب والا ہوتا ہے،\qt@no{35}}%
\qt@newcmd\qurantrans@ur@mmmmccliv{اور (اے بندۂ مومن!) اگر شیطان کی وسوسہ اندازی سے تمہیں کوئی وسوسہ آجائے تو اﷲ کی پناہ مانگ لیا کر، بے شک وہ خوب سننے والا خوب جاننے والا ہے،\qt@no{36}}%
\qt@newcmd\qurantrans@ur@mmmmcclv{اور رات اور دن اور سورج اور چاند اُس کی نشانیوں میں سے ہیں، نہ سورج کو سجدہ کیا کرو اور نہ ہی چاند کو، اور سجدہ صرف اﷲ کے لئے کیا کرو جس نے اِن (سب) کو پیدا فرمایا ہے اگر تم اسی کی بندگی کرتے ہو،\qt@no{37}}%
\qt@newcmd\qurantrans@ur@mmmmcclvi{پھر اگر وہ تکبّر کریں (تو آپ اُن کی پرواہ نہ کریں) پس جو فرشتے آپ کے رب کے حضور میں ہیں وہ رات دن اس کی تسبیح کرتے رہتے ہیں اور وہ تھکتے (اور اکتاتے) ہی نہیں ہیں،\qt@no{38}}%
\qt@newcmd\qurantrans@ur@mmmmcclvii{اور اس کی نشانیوں میں سے یہ بھی ہے کہ آپ (پہلے) زمین کو خشک (اور بے قدر) دیکھتے ہیں پھر جب ہم اس پر پانی برساتے ہیں تو وہ سرسبز و شاداب ہو جاتی ہے اور نمو پانے لگتی ہے، بے شک وہ ذات جس نے اس (مردہ زمین) کو زندہ کیا ہے یقیناً وہی (روزِ قیامت) مُردوں کو زندہ فرمانے والا ہے۔ بے شک وہ ہر چیز پر خوب قادر ہے،\qt@no{39}}%
\qt@newcmd\qurantrans@ur@mmmmcclviii{بے شک جو لوگ ہماری آیتوں (کے معنی) میں صحیح راہ سے انحراف کرتے ہیں وہ ہم پر پوشیدہ نہیں ہیں، بھلا جو شخص آتشِ دوزخ میں جھونک دیا جائے (وہ) بہتر ہے یا وہ شخص جو قیامت کے دن (عذاب سے) محفوظ و مامون ہو کر آئے، تم جو چاہو کرو، بے شک جو کام تم کرتے ہو وہ خوب دیکھنے والا ہے،\qt@no{40}}%
\qt@newcmd\qurantrans@ur@mmmmcclix{بے شک جنہوں نے قرآن کے ساتھ کفر کیا جبکہ وہ اُن کے پاس آچکا تھا (تویہ اُن کی بد نصیبی ہے)، اور بے شک وہ (قرآن) بڑی باعزت کتاب ہے،\qt@no{41}}%
\qt@newcmd\qurantrans@ur@mmmmcclx{باطل اِس (قرآن) کے پاس نہ اس کے سامنے سے آسکتا ہے اور نہ ہی اس کے پیچھے سے، (یہ) بڑی حکمت والے، بڑی حمد والے (رب) کی طرف سے اتارا ہوا ہے،\qt@no{42}}%
\qt@newcmd\qurantrans@ur@mmmmcclxi{اے حبیب!) جو آپ سے کہی جاتی ہیں (یہ) وہی باتیں ہیں جو آپ سے پہلے رسولوں سے کہی جا چکی ہیں، بے شک آپ کا رب ضرور معافی والا (بھی) ہے اور درد ناک سزا دینے والا (بھی) ہے،\qt@no{43}}%
\qt@newcmd\qurantrans@ur@mmmmcclxii{اور اگر ہم اس (کتاب) کو عجمی زبان کا قرآن بنا دیتے تو یقیناً یہ کہتے کہ اِس کی آیتیں واضح طور پر بیان کیوں نہیں کی گئیں، کیا کتاب عجمی ہے اور رسول عربی ہے (اِس لئے اے محبوبِ مکرّم! ہم نے قرآن بھی آپ ہی کی زبان میں اتار دیا ہے۔) فرما دیجئے: وہ (قرآن) ایمان والوں کے لئے ہدایت (بھی) ہے اور شفا (بھی) ہے اور جو لوگ ایمان نہیں رکھتے اُن کے کانوں میں بہرے پن کا بوجھ ہے وہ اُن کے حق میں نابینا پن (بھی) ہے (گویا) وہ لوگ کسی دور کی جگہ سے پکارے جاتے ہیں،\qt@no{44}}%
\qt@newcmd\qurantrans@ur@mmmmcclxiii{اور بے شک ہم نے موسٰی (علیہ السلام) کو کتاب عطا فرمائی تو اس میں (بھی) اختلاف کیا گیا، اور اگر آپ کے رب کی طرف سے فرمان پہلے صادر نہ ہو چکا ہوتا تو اُن کے درمیان فیصلہ کر دیا جاتا اور بے شک وہ اس (قرآن) کے بارے میں (بھی) دھوکہ دینے والے شک میں (مبتلاء) ہیں،\qt@no{45}}%
\qt@newcmd\qurantrans@ur@mmmmcclxiv{جس نے نیک عمل کیا تو اُس نے اپنی ہی ذات کے (نفع کے) لئے (کیا) اور جِس نے گناہ کیا سو (اُس کا وبال بھی) اسی کی جان پر ہے، اور آپ کا رب بندوں پر ظلم کرنے والا نہیں ہے،\qt@no{46}}%
\qt@newcmd\qurantrans@ur@mmmmcclxv{اسی (اللہ) کی طرف ہی وقتِ قیامت کے علم کا حوالہ دیا جاتا ہے، اور نہ پھل اپنے غلافوں سے نکلتے ہیں اور نہ کوئی مادہ حاملہ ہوتی ہے اور نہ وہ بچہ جنتی ہے مگر (یہ سب کچھ) اُس کے علم میں ہوتا ہے۔ اور جس دن وہ انہیں ندا فرمائے گا کہ میرے شریک کہاں ہیں، (تو) وہ (مشرک) کہیں گے: ہم آپ سے عرض کئے دیتے ہیں کہ ہم میں سے کوئی بھی (کسی کے آپ کے ساتھ شریک ہونے پر) گواہ نہیں ہے،\qt@no{47}}%
\qt@newcmd\qurantrans@ur@mmmmcclxvi{وہ سب (بت) اُن سے غائب ہو جائیں گے جن کی وہ پہلے پوجا کیا کرتے تھے وہ سمجھ لیں گے کہ اُن کے لئے بھاگنے کی کوئی راہ نہیں رہی،\qt@no{48}}%
\qt@newcmd\qurantrans@ur@mmmmcclxvii{انسان بھلائی مانگنے سے نہیں تھکتا اور اگر اسے برائی پہنچ جاتی ہے تو بہت ہی مایوس، آس و امید توڑ بیٹھنے والا ہو جاتا ہے،\qt@no{49}}%
\qt@newcmd\qurantrans@ur@mmmmcclxviii{اور اگر ہم اسے اپنی جانب سے رحمت (کا مزہ) چکھا دیں اُس تکلیف کے بعد جو اُسے پہنچ چکی تھی تو وہ ضرور کہنے لگتا ہے کہ یہ تو میرا حق تھا اور میں نہیں سمجھتا کہ قیامت برپا ہونے والی ہے اور اگر میں اپنے رب کی طرف لوٹایا بھی جاؤں تو بھی اس کے حضور میرے لئے یقیناً بھلائی ہوگی سو ہم ضرور کفر کرنے والوں کو اُن کاموں سے آگاہ کر دیں گے جو انہوں نے انجام دیئے اور ہم انہیں ضرور سخت ترین عذاب (کا مزہ) چکھا دیں گے،\qt@no{50}}%
\qt@newcmd\qurantrans@ur@mmmmcclxix{اور جب ہم انسان پر انعام فرماتے ہیں تو وہ منہ پھیر لیتا ہے اور اپنا پہلو بچا کر ہم سے دور ہو جاتا ہے اور جب اسے تکلیف پہنچتی ہے تو لمبی چوڑی دعا کرنے والا ہو جاتا ہے،\qt@no{51}}%
\qt@newcmd\qurantrans@ur@mmmmcclxx{فرما دیجئے: بھلا تم بتاؤ اگر یہ (قرآن) اللہ ہی کی طرف سے (اُترا) ہو پھر تم اِس کا انکار کرتے رہو تو اُس شخص سے بڑھ کر گمراہ کون ہوگا جو پرلے درجہ کی مخالفت میں (پڑا) ہو،\qt@no{52}}%
\qt@newcmd\qurantrans@ur@mmmmcclxxi{ہم عنقریب انہیں اپنی نشانیاں اَطرافِ عالم میں اور خود اُن کی ذاتوں میں دِکھا دیں گے یہاں تک کہ اُن پر ظاہر ہو جائے گا کہ وہی حق ہے۔ کیا آپ کا رب (آپ کی حقانیت کی تصدیق کے لئے) کافی نہیں ہے کہ وہی ہر چیز پر گواہ (بھی) ہے،\qt@no{53}}%
\qt@newcmd\qurantrans@ur@mmmmcclxxii{جان لو کہ وہ لوگ اپنے رب کے حضور پیشی کی نسبت شک میں ہیں، خبردار! وہی (اپنے علم و قدرت سے) ہر چیز کا احاطہ فرمانے والا ہے،\qt@no{54}}%
\qt@newcmd\qurantrans@ur@mmmmcclxxiii{\basmalahur حا، میم (حقیقی معنی اللہ اور رسول صلی اللہ علیہ وآلہ وسلم ہی بہتر جانتے ہیں)،\qt@no{1}}%
\qt@newcmd\qurantrans@ur@mmmmcclxxiv{عین، سین، قاف (حقیقی معنی اللہ اور رسول صلی اللہ علیہ وآلہ وسلم ہی بہتر جانتے ہیں)،\qt@no{2}}%
\qt@newcmd\qurantrans@ur@mmmmcclxxv{اسی طرح آپ کی طرف اور اُن (رسولوں) کی طرف جو آپ سے پہلے ہوئے ہیں اللہ وحی بھیجتا رہا ہے جو غالب ہے بڑی حکمت والا ہے،\qt@no{3}}%
\qt@newcmd\qurantrans@ur@mmmmcclxxvi{جو کچھ آسمانوں میں ہے اور جو کچھ زمین میں ہے اسی کا ہے، اور وہ بلند مرتبت، بڑا باعظمت ہے،\qt@no{4}}%
\qt@newcmd\qurantrans@ur@mmmmcclxxvii{قریب ہے آسمانی کرّے اپنے اوپر کی جانب سے پھٹ پڑیں اور فرشتے اپنے رب کی حمد کے ساتھ تسبیح کرتے رہتے ہیں اور اُن لوگوں کے لئے جو زمین میں ہیں بخشش طلب کرتے رہتے ہیں۔ یاد رکھو! اللہ ہی بڑا بخشنے والا بہت رحم فرمانے والا ہے،\qt@no{5}}%
\qt@newcmd\qurantrans@ur@mmmmcclxxviii{اور جن لوگوں نے اللہ کو چھوڑ کر بتوں کو دوست و کارساز بنا رکھا ہے اللہ اُن (کے حالات) پر خوب نگہبان ہے اور آپ ان (کافروں) کے ذمّہ دار نہیں ہیں،\qt@no{6}}%
\qt@newcmd\qurantrans@ur@mmmmcclxxix{اور اسی طرح ہم نے آپ کی طرف عربی زبان میں قرآن کی وحی کی تاکہ آپ مکّہ والوں کو اور اُن لوگوں کو جو اِس کے اِردگرد رہتے ہیں ڈر سنا سکیں، اور آپ جمع ہونے کے اُس دن کا خوف دلائیں جس میں کوئی شک نہیں ہے۔ (اُس دن) ایک گروہ جنت میں ہوگا اور دوسرا گروہ دوزخ میں ہوگا،\qt@no{7}}%
\qt@newcmd\qurantrans@ur@mmmmcclxxx{اور اگر اللہ چاہتا تو اُن سب کو ایک ہی امّت بنا دیتا لیکن وہ جسے چاہتا ہے اپنی رحمت میں داخل فرماتا ہے، اور ظالموں کے لئے نہ کوئی دوست ہوگا اور نہ کوئی مددگار،\qt@no{8}}%
\qt@newcmd\qurantrans@ur@mmmmcclxxxi{کیا انہوں نے اللہ کو چھوڑ کر بتوں کو اولیاء بنا لیا ہے، پس اللہ ہی ولی ہے (اسی کے دوست ہی اولیاء ہیں)، اور وہی مُردوں کو زندہ کرتا ہے اور وہی ہر چیز پر بڑا قادر ہے،\qt@no{9}}%
\qt@newcmd\qurantrans@ur@mmmmcclxxxii{اور تم جس اَمر میں اختلاف کرتے ہو تو اُس کا فیصلہ اللہ ہی کی طرف (سے) ہوگا، یہی اللہ میرا رب ہے، اسی پر میں نے بھروسہ کیا اور اسی کی طرف میں رجوع کرتا ہوں،\qt@no{10}}%
\qt@newcmd\qurantrans@ur@mmmmcclxxxiii{آسمانوں اور زمین کو عدم سے وجود میں لانے والا ہے، اسی نے تمہارے لئے تمہاری جنسوں سے جوڑے بنائے اور چوپایوں کے بھی جوڑے بنائے اور تمہیں اسی (جوڑوں کی تدبیر) سے پھیلاتا ہے، اُس کے مانند کوئی چیز نہیں ہے اور وہی سننے والا دیکھنے والا ہے،\qt@no{11}}%
\qt@newcmd\qurantrans@ur@mmmmcclxxxiv{وہی آسمانوں اور زمین کی کُنجیوں کا مالک ہے (یعنی جس کے لئے وہ چاہے خزانے کھول دیتا ہے) وہ جس کے لئے چاہتا ہے رِزق و عطا کشادہ فرما دیتا ہے اور (جس کے لئے چاہتا ہے) تنگ کر دیتا ہے۔ بیشک وہ ہر چیز کا خوب جاننے والا ہے،\qt@no{12}}%
\qt@newcmd\qurantrans@ur@mmmmcclxxxv{اُس نے تمہارے لئے دین کا وہی راستہ مقرّر فرمایا جس کا حکم اُس نے نُوح (علیہ السلام) کو دیا تھا اور جس کی وحی ہم نے آپ کی طرف بھیجی اور جس کا حکم ہم نے ابراھیم اور موسٰی و عیسٰی (علیھم السلام) کو دیا تھا (وہ یہی ہے) کہ تم (اِسی) دین پر قائم رہو اور اس میں تفرقہ نہ ڈالو، مشرکوں پر بہت ہی گراں ہے وہ (توحید کی بات) جس کی طرف آپ انہیں بلا رہے ہیں۔ اللہ جسے (خود) چاہتا ہے اپنے حضور میں (قربِ خاص کے لئے) منتخب فرما لیتا ہے، اور اپنی طرف (آنے کی) راہ دکھا دیتا ہے (ہر) اس شخص کو جو (اللہ کی طرف) قلبی رجوع کرتا ہے،\qt@no{13}}%
\qt@newcmd\qurantrans@ur@mmmmcclxxxvi{اور انہوں نے فرقہ بندی نہیں کی تھی مگر اِس کے بعد جبکہ اُن کے پاس علم آچکا تھا محض آپس کی ضِد (اور ہٹ دھرمی) کی وجہ سے، اور اگر آپ کے رب کی جانب سے مقررہ مدّت تک (کی مہلت) کا فرمان پہلے صادر نہ ہوا ہوتا تو اُن کے درمیان فیصلہ کیا جا چکا ہوتا، اور بیشک جو لوگ اُن کے بعد کتاب کے وارث بنائے گئے تھے وہ خود اُس کی نسبت فریب دینے والے شک میں (مبتلا) ہیں،\qt@no{14}}%
\qt@newcmd\qurantrans@ur@mmmmcclxxxvii{پس آپ اسی (دین) کے لئے دعوت دیتے رہیں اور جیسے آپ کو حکم دیا گیا ہے (اسی پر) قائم رہئے اور اُن کی خواہشات پر کان نہ دھریئے، اور (یہ) فرما دیجئے: جو کتاب بھی اللہ نے اتاری ہے میں اُس پر ایمان رکھتا ہوں، اور مجھے حکم دیا گیا ہے کہ میں تمہارے درمیان عدل و انصاف کروں۔ اللہ ہمارا (بھی) رب ہے اور تمہارا (بھی) رب ہے، ہمارے لئے ہمارے اعمال ہیں اور تمہارے لئے تمہارے اعمال، ہمارے اور تمہارے درمیان کوئی بحث و تکرار نہیں، اللہ ہم سب کو جمع فرمائے گا اور اسی کی طرف (سب کا) پلٹنا ہے،\qt@no{15}}%
\qt@newcmd\qurantrans@ur@mmmmcclxxxviii{اور جو لوگ اللہ (کے دین کے بارے) میں جھگڑتے ہیں بعد اِس کے کہ اسے قبول کر لیا گیا اُن کی بحث و تکرار اُن کے رب کے نزدیک باطل ہے اور اُن پر (اللہ کا) غضب ہے اور اُن کے لئے سخت عذاب ہے،\qt@no{16}}%
\qt@newcmd\qurantrans@ur@mmmmcclxxxix{اللہ وہی ہے جس نے حق کے ساتھ کتاب نازل فرمائی اور (عدل و انصاف کا) ترازو (بھی اتارا)، اور آپ کو کس نے خبردار کیا، شاید قیامت قریب ہی ہو،\qt@no{17}}%
\qt@newcmd\qurantrans@ur@mmmmccxc{اِس (قیامت) میں وہ لوگ جلدی مچاتے ہیں جو اِس پر ایمان (ہی) نہیں رکھتے اور جو لوگ ایمان رکھتے ہیں اس سے ڈرتے ہیں اور جانتے ہیں کہ اِس کا آنا حق ہے، جان لو! جو لوگ قیامت کے بارے میں جھگڑا کرتے ہیں وہ پرلے درجہ کی گمراہی میں ہیں،\qt@no{18}}%
\qt@newcmd\qurantrans@ur@mmmmccxci{اللہ اپنے بندوں پر بڑا لطف و کرم فرمانے والا ہے، جسے چاہتا ہے رِزق و عطا سے نوازتا ہے اور وہ بڑی قوت والا بڑی عزّت والا ہے،\qt@no{19}}%
\qt@newcmd\qurantrans@ur@mmmmccxcii{جو شخص آخرت کی کھیتی چاہتا ہے ہم اُس کے لئے اُس کی کھیتی میں مزید اضافہ فرما دیتے ہیں اور جو شخص دنیا کی کھیتی کا طالب ہوتا ہے (تو) ہم اُس کو اس میں سے کچھ عطا کر دیتے ہیں، پھر اُس کے لئے آخرت میں کچھ حصہ نہیں رہتا،\qt@no{20}}%
\qt@newcmd\qurantrans@ur@mmmmccxciii{کیا اُن کے لئے کچھ (ایسے) شریک ہیں جنہوں نے اُن کے لئے دین کا ایسا راستہ مقرر کر دیا ہو جس کا اللہ نے حکم نہیں دیا تھا، اور اگر فیصلہ کا فرمان (صادر) نہ ہوا ہوتا تو اُن کے درمیان قصہ چکا دیا جاتا، اور بیشک ظالموں کے لئے دردناک عذاب ہے،\qt@no{21}}%
\qt@newcmd\qurantrans@ur@mmmmccxciv{آپ ظالموں کو اُن (اعمال) سے ڈرنے والا دیکھیں گے جو انہوں نے کما رکھے ہیں اور وہ (عذاب) اُن پر واقع ہو کر رہے گا، اور جو لوگ ایمان لائے اور نیک اعمال کرتے رہے وہ بہشت کے چَمنوں میں ہوں گے، اُن کے لئے اُن کے رب کے پاس وہ (تمام نعمتیں) ہوں گی جن کی وہ خواہش کریں گے، یہی تو بہت بڑا فضل ہے،\qt@no{22}}%
\qt@newcmd\qurantrans@ur@mmmmccxcv{یہ وہ (انعام) ہے جس کی خوشخبری اللہ ایسے بندوں کو سناتا ہے جو ایمان لائے اور نیک اعمال کرتے رہے، فرما دیجئے: میں اِس (تبلیغِ رسالت) پر تم سے کوئی اُجرت نہیں مانگتا مگر (اپنی اور اللہ کی) قرابت و قربت سے محبت (چاہتا ہوں) اور جو شخص نیکی کمائے گا ہم اس کے لئے اس میں اُخروی ثواب اور بڑھا دیں گے۔ بیشک اللہ بڑا بخشنے والا قدر دان ہے،\qt@no{23}}%
\qt@newcmd\qurantrans@ur@mmmmccxcvi{کیا یہ لوگ کہتے ہیں کہ اس (رسول صلی اللہ علیہ وآلہ وسلم) نے اللہ پر جھوٹا بہتان تراشا ہے، سو اگر اللہ چاہے توآپ کے قلبِ اطہر پر (صبر و استقامت کی) مُہر ثبت فرما دے (تاکہ آپ کو اِن کی بیہودہ گوئی کا رنج نہ پہنچے)، اور اﷲ باطل کو مٹا دیتا ہے اور اپنے کلمات سے حق کو ثابت رکھتا ہے۔ بیشک وہ سینوں کی باتوں کو خوب جاننے والا ہے،\qt@no{24}}%
\qt@newcmd\qurantrans@ur@mmmmccxcvii{اور وہی ہے جو اپنے بندوں کی توبہ قبول فرماتا ہے اور لغزشوں سے درگزر فرماتا ہے اور جو کچھ تم کرتے ہو (اسے) جانتا ہے،\qt@no{25}}%
\qt@newcmd\qurantrans@ur@mmmmccxcviii{اور اُن لوگوں کی دعا قبول فرماتا ہے جو ایمان لائے اور نیک اعمال کرتے رہے اور اپنے فضل سے انہیں (اُن کی دعا سے بھی) زیادہ دیتا ہے، اور جو کافر ہیں اُن کے لئے سخت عذاب ہے،\qt@no{26}}%
\qt@newcmd\qurantrans@ur@mmmmccxcix{اور اگر اللہ اپنے تمام بندوں کے لئے روزی کشادہ فرما دے تو وہ ضرور زمین میں سرکشی کرنے لگیں لیکن وہ (ضروریات کے) اندازے کے ساتھ جتنی چاہتا ہے اتارتا ہے، بیشک وہ اپنے بندوں (کی ضرورتوں) سے خبردار ہے خوب دیکھنے والا ہے،\qt@no{27}}%
\qt@newcmd\qurantrans@ur@mmmmccc{اور وہ ہی ہے جو بارش برساتا ہے اُن کے مایوس ہو جانے کے بعد اور اپنی رحمت پھیلا دیتا ہے، اور وہ کار ساز بڑی تعریفوں کے لائق ہے،\qt@no{28}}%
\qt@newcmd\qurantrans@ur@mmmmccci{اور اُس کی نشانیوں میں سے آسمانوں اور زمین کی پیدائش ہے اور اُن چلنے والے (جانداروں) کا (پیدا کرنا) بھی جو اُس نے اِن میں پھیلا دیئے ہیں، اور وہ اِن (سب) کے جمع کرنے پر بھی جب چاہے گا بڑا قادر ہے،\qt@no{29}}%
\qt@newcmd\qurantrans@ur@mmmmcccii{اور جو مصیبت بھی تم کو پہنچتی ہے تو اُس (بد اعمالی) کے سبب سے ہی (پہنچتی ہے) جو تمہارے ہاتھوں نے کمائی ہوتی ہے حالانکہ بہت سی(کوتاہیوں) سے تو وہ درگزر بھی فرما دیتا ہے،\qt@no{30}}%
\qt@newcmd\qurantrans@ur@mmmmccciii{اور تم (اپنی تدبیروں سے) اللہ کو (پوری) زمین میں عاجِز نہیں کر سکتے اور اللہ کو چھوڑ کر (بتوں میں سے) نہ کوئی تمہارا حامی ہوگا اور نہ مددگار،\qt@no{31}}%
\qt@newcmd\qurantrans@ur@mmmmccciv{اور اُس کی نشانیوں میں سے پہاڑوں کی طرح اونچے بحری جہاز بھی ہیں،\qt@no{32}}%
\qt@newcmd\qurantrans@ur@mmmmcccv{اگر وہ چاہے ہوا کو بالکل ساکِن کر دے تو کشتیاں سطحِ سمندر پر رُکی رہ جائیں، بیشک اس میں ہر صبر شعار و شکر گزار کے لئے نشانیاں ہیں،\qt@no{33}}%
\qt@newcmd\qurantrans@ur@mmmmcccvi{یا اُن (جہازوں اور کشتیوں) کو اُن کے اعمالِ (بد) کے باعث جو انہوں نے کما رکھے ہیں غرق کر دے، مگر وہ بہت (سی خطاؤں) کو معاف فرما دیتا ہے،\qt@no{34}}%
\qt@newcmd\qurantrans@ur@mmmmcccvii{اور ہماری آیتوں میں جھگڑا کرنے والے جان لیں کہ اُن کے لئے بھاگ نکلنے کی کوئی راہ نہیں ہے،\qt@no{35}}%
\qt@newcmd\qurantrans@ur@mmmmcccviii{سو تمہیں جو کچھ بھی (مال و متاع) دیا گیا ہے وہ دنیوی زندگی کا (چند روزہ) فائدہ ہے اور جو کچھ اللہ کے پاس ہے وہ بہتر اور پائیدار ہے، (یہ) اُن لوگوں کے لئے ہے جو ایمان لاتے اور اپنے رب پر توکّل کرتے ہیں،\qt@no{36}}%
\qt@newcmd\qurantrans@ur@mmmmcccix{اور جو لوگ کبیرہ گناہوں اور بے حیائی کے کاموں سے پرہیز کرتے ہیں اور جب انہیں غصّہ آتا ہے تو معاف کر دیتے ہیں،\qt@no{37}}%
\qt@newcmd\qurantrans@ur@mmmmcccx{اور جو لوگ اپنے رب کا فرمان قبول کرتے ہیں اور نماز قائم رکھتے ہیں اور اُن کا فیصلہ باہمی مشورہ سے ہوتا ہے اور اس مال میں سے جو ہم نے انہیں عطا کیا ہے خرچ کرتے ہیں،\qt@no{38}}%
\qt@newcmd\qurantrans@ur@mmmmcccxi{اور وہ لوگ کہ جب انہیں (کسی ظالم و جابر) سے ظلم پہنچتا ہے تو (اس سے) بدلہ لیتے ہیں،\qt@no{39}}%
\qt@newcmd\qurantrans@ur@mmmmcccxii{اور برائی کا بدلہ اسی برائی کی مِثل ہوتا ہے، پھر جِس نے معاف کر دیا اور (معافی کے ذریعہ) اصلاح کی تو اُس کا اجر اللہ کے ذمّہ ہے۔ بیشک وہ ظالموں کو دوست نہیں رکھتا،\qt@no{40}}%
\qt@newcmd\qurantrans@ur@mmmmcccxiii{اور یقیناً جو شخص اپنے اوپر ظلم ہونے کے بعد بدلہ لے تو ایسے لوگوں پر (ملامت و گرفت) کی کوئی راہ نہیں ہے،\qt@no{41}}%
\qt@newcmd\qurantrans@ur@mmmmcccxiv{بس (ملامت و گرفت کی) راہ صرف اُن کے خلاف ہے جو لوگوں پر ظلم کرتے ہیں اور زمین میں ناحق سرکشی و فساد پھیلاتے ہیں، ایسے ہی لوگوں کے لئے دردناک عذاب ہے،\qt@no{42}}%
\qt@newcmd\qurantrans@ur@mmmmcccxv{اور یقیناً جو شخص صبر کرے اور معاف کر دے تو بیشک یہ بلند ہمت کاموں میں سے ہے،\qt@no{43}}%
\qt@newcmd\qurantrans@ur@mmmmcccxvi{اور جسے اللہ گمراہ ٹھہرا دے تو اُس کے لئے اُس کے بعد کوئی کارساز نہیں ہوتا، اور آپ ظالموں کو دیکھیں گے کہ جب وہ عذابِ (آخرت) دیکھ لیں گے (تو) کہیں گے: کیا (دنیا میں) پلٹ جانے کی کوئی سبیل ہے؟،\qt@no{44}}%
\qt@newcmd\qurantrans@ur@mmmmcccxvii{اور آپ انہیں دیکھیں گے کہ وہ دوزخ پر ذلّت اور خوف کے ساتھ سر جھکائے ہوئے پیش کئے جائیں گے (اسے چوری چوری) چھپی نگاہوں سے دیکھتے ہوں گے، اور ایمان والے کہیں گے: بیشک نقصان اٹھانے والے وہی لوگ ہیں جنہوں نے اپنی جانوں کو اور اپنے اہل و عیال کو قیامت کے دن خسارے میں ڈال دیا، یاد رکھو! بیشک ظالم لوگ دائمی عذاب میں (مبتلا) رہیں گے،\qt@no{45}}%
\qt@newcmd\qurantrans@ur@mmmmcccxviii{اور اُن (کافروں) کے لئے کوئی حمایتی نہیں ہوں گے جو اللہ کے مقابل اُن کی مدد کر سکیں، اور جسے اللہ گمراہ ٹھہرا دیتا ہے تو اس کے لئے (ہدایت کی) کوئی راہ نہیں رہتی،\qt@no{46}}%
\qt@newcmd\qurantrans@ur@mmmmcccxix{تم لوگ اپنے رب کا حکم قبول کر لو قبل اِس کے کہ وہ دن آجائے جو اللہ کی طرف سے ٹلنے والا نہیں ہے، نہ تمہارے لئے اُس دن کوئی جائے پناہ ہوگی اور نہ تمہارے لئے کوئی جائے انکار،\qt@no{47}}%
\qt@newcmd\qurantrans@ur@mmmmcccxx{پھر (بھی) اگر وہ رُوگردانی کریں تو ہم نے آپ کو اُن پر (تباہی سے بچانے کا) ذمّہ دار بنا کر نہیں بھیجا۔ آپ پر تو صرف (پیغامِ حق) پہنچا دینے کی ذمّہ داری ہے، اور بیشک جب ہم انسان کو اپنی بارگاہ سے رحمت (کا ذائقہ) چکھاتے ہیں تو وہ اس سے خوش ہو جاتا ہے اور اگر انہیں کوئی مصیبت پہنچتی ہے اُن کے اپنے ہاتھوں سے آگے بھیجے ہوئے اعمالِ (بد) کے باعث، تو بیشک انسان بڑا ناشکر گزار (ثابت ہوتا) ہے،\qt@no{48}}%
\qt@newcmd\qurantrans@ur@mmmmcccxxi{اللہ ہی کے لئے آسمانوں اور زمین کی بادشاہت ہے، وہ جو چاہتا ہے پیدا فرماتا ہے، جسے چاہتا ہے لڑکیاں عطا کرتا ہے اور جسے چاہتا ہے لڑکے بخشتا ہے،\qt@no{49}}%
\qt@newcmd\qurantrans@ur@mmmmcccxxii{یا انہیں بیٹے اور بیٹیاں (دونوں) جمع فرماتا ہے اور جسے چاہتا ہے بانجھ ہی بنا دیتا ہے، بیشک وہ خوب جاننے والا بڑی قدرت والا ہے،\qt@no{50}}%
\qt@newcmd\qurantrans@ur@mmmmcccxxiii{اور ہر بشر کی (یہ) مجال نہیں کہ اللہ اس سے (براہِ راست) کلام کرے مگر یہ کہ وحی کے ذریعے (کسی کو شانِ نبوت سے سرفراز فرما دے) یا پردے کے پیچھے سے (بات کرے جیسے موسٰی علیہ السلام سے طورِ سینا پر کی) یا کسی فرشتے کو فرستادہ بنا کر بھیجے اور وہ اُس کے اِذن سے جو اللہ چاہے وحی کرے (الغرض عالمِ بشریت کے لئے خطابِ اِلٰہی کا واسطہ اور وسیلہ صرف نبی اور رسول ہی ہوگا)، بیشک وہ بلند مرتبہ بڑی حکمت والا ہے،\qt@no{51}}%
\qt@newcmd\qurantrans@ur@mmmmcccxxiv{سو اسی طرح ہم نے آپ کی طرف اپنے حکم سے روحِ (قلوب و ارواح) کی وحی فرمائی (جو قرآن ہے)، اور آپ (وحی سے قبل اپنی ذاتی درایت و فکر سے) نہ یہ جانتے تھے کہ کتاب کیا ہے اور نہ ایمان (کے شرعی احکام کی تفصیلات کو ہی جانتے تھے جو بعد میں نازل اور مقرر ہوئیں)(۱) مگر ہم نے اسے نور بنا دیا۔ ہم اِس (نور) کے ذریعہ اپنے بندوں میں سے جسے چاہتے ہیں ہدایت سے نوازتے ہیں، اور بیشک آپ ہی صراطِ مستقیم کی طرف ہدایت عطا فرماتے ہیں(۲)، ۱:- آپ صلی اللہ علیہ وآلہ وسلم کی شانِ اُمّیت کی طرف اشارہ ہے تاکہ کفّار آپ کی زبان سے قرآن کی آیات اور ایمان کی تفصیلات سن کر یہ بدگمانی نہ پھیلائیں کہ یہ سب کچھ حضرت محمد مصطفی صلی اللہ علیہ وآلہ وسلم نے اپنے ذاتی علم اور تفکر سے گھڑ لیا ہے کچھ نازل نہیں ہوا، سو یہ اَز خود نہ جاننا حضور صلی اللہ علیہ وآلہ وسلم کا عظیم معجزہ بنا دیا گیا۔ ۲:- اے حبیب! آپ کا ہدایت دینا اور ہمارا ہدایت دینا دونوں کی حقیقت ایک ہی ہے اور صرف انہی کو ہدایت نصیب ہوتی ہے جو اس حقیقت کی معرفت اور اس سے وابستگی رکھتے ہیں۔\qt@no{52}}%
\qt@newcmd\qurantrans@ur@mmmmcccxxv{یہ صراطِ مستقیم) اسی اللہ ہی کا راستہ ہے جو آسمانوں اور زمین کی ہر چیز کا مالک ہے۔ جان لو! کہ سارے کام اللہ ہی کی طرف لوٹتے ہیں،\qt@no{53}}%
\qt@newcmd\qurantrans@ur@mmmmcccxxvi{\basmalahur حا، میم (حقیقی معنی اللہ اور رسول صلی اللہ علیہ وآلہ وسلم ہی بہتر جانتے ہیں)،\qt@no{1}}%
\qt@newcmd\qurantrans@ur@mmmmcccxxvii{قسم ہے روشن کتاب کی،\qt@no{2}}%
\qt@newcmd\qurantrans@ur@mmmmcccxxviii{بیشک ہم نے اسے عربی (زبان) کا قرآن بنایا ہے تاکہ تم لوگ سمجھ سکو،\qt@no{3}}%
\qt@newcmd\qurantrans@ur@mmmmcccxxix{بیشک وہ ہمارے پاس سب کتابوں کی اصل (لوحِ محفوظ) میں ثَبت ہے یقیناً (یہ سب کتابوں پر) بلند مرتبہ بڑی حکمت والا ہے،\qt@no{4}}%
\qt@newcmd\qurantrans@ur@mmmmcccxxx{اور کیا ہم اس نصیحت کو تم سے اِس بنا پر روک دیں کہ تم حد سے گزر جانے والی قوم ہو،\qt@no{5}}%
\qt@newcmd\qurantrans@ur@mmmmcccxxxi{اور پہلے لوگوں میں ہم نے کتنے ہی پیغمبر بھیجے تھے،\qt@no{6}}%
\qt@newcmd\qurantrans@ur@mmmmcccxxxii{اور کوئی نبی اُن کے پاس نہیں آتا تھا مگر وہ اُس کا مذاق اڑایا کرتے تھے،\qt@no{7}}%
\qt@newcmd\qurantrans@ur@mmmmcccxxxiii{اور ہم نے اِن (کفّارِ مکہ) سے زیادہ زور آور لوگوں کو ہلاک کر دیا اور اگلے لوگوں کا حال (کئی جگہ پہلے) گزر چکا،\qt@no{8}}%
\qt@newcmd\qurantrans@ur@mmmmcccxxxiv{اور اگر آپ اُن سے پوچھیں کہ آسمانوں اور زمین کو کِس نے پیدا کیا تو وہ یقیناً کہیں گے کہ انہیں غالب، علم والے (رب) نے پیدا کیا ہے،\qt@no{9}}%
\qt@newcmd\qurantrans@ur@mmmmcccxxxv{جس نے تمہارے لئے زمین کو بچھونا بنایا اور اس میں تمہارے لئے راستے بنائے تاکہ تم منزلِ مقصود تک پہنچ سکو،\qt@no{10}}%
\qt@newcmd\qurantrans@ur@mmmmcccxxxvi{اور جس نے آسمان سے اندازۂ (ضرورت) کے مطابق پانی اتارا، پھر ہم نے اس سے مُردہ شہر کو زندہ کر دیا، اسی طرح تم (بھی مرنے کے بعد زمین سے) نکالے جاؤ گے،\qt@no{11}}%
\qt@newcmd\qurantrans@ur@mmmmcccxxxvii{اور جس نے تمام اقسام و اصناف کی مخلوق پیدا کی اور تمہارے لئے کشتیاں اور بحری جہاز بنائے اور چوپائے بنائے جن پر تم (بحر و بر میں) سوار ہوتے ہو،\qt@no{12}}%
\qt@newcmd\qurantrans@ur@mmmmcccxxxviii{تاکہ تم ان کی پشتوں (یا نشستوں) پر درست ہو کر بیٹھ سکو، پھر تم اپنے رب کی نعمت کو یاد کرو، جب تم سکون سے اس (سواری کی نشست) پر بیٹھ جاؤ تو کہو: پاک ہے وہ ذات جس نے اِس کو ہمارے تابع کر دیا حالانکہ ہم اِسے قابو میں نہیں لا سکتے تھے،\qt@no{13}}%
\qt@newcmd\qurantrans@ur@mmmmcccxxxix{اور بیشک ہم اپنے رب کی طرف ضرور لوٹ کر جانے والے ہیں،\qt@no{14}}%
\qt@newcmd\qurantrans@ur@mmmmcccxl{اور اُن (مشرکوں) نے اس کے بندوں میں سے (بعض کو اس کی اولاد قرار دے کر) اس کے جزو بنا دیئے، بیشک انسان صریحاً بڑا ناشکر گزار ہے،\qt@no{15}}%
\qt@newcmd\qurantrans@ur@mmmmcccxli{اے کافرو! اپنے پیمانۂ فکر کے مطابق یہی جواب دو کہ) کیا اس نے اپنی مخلوقات میں سے (خود اپنے لئے تو) بیٹیاں بنا رکھی ہیں اور تمہیں بیٹوں کے ساتھ مختص کر رکھا ہے،\qt@no{16}}%
\qt@newcmd\qurantrans@ur@mmmmcccxlii{حالانکہ جب ان میں سے کسی کو اُس (کے گھر میں بیٹی کی پیدائش) کی خبر دی جاتی ہے جسے انہوں نے (خدائے) رحمان کی شبیہ بنا رکھا ہے تو اس کا چہرہ سیاہ ہو جاتا ہے اور غم و غصّہ سے بھر جاتا ہے،\qt@no{17}}%
\qt@newcmd\qurantrans@ur@mmmmcccxliii{اور کیا (اللہ اپنے امور میں شراکت و معاونت کے لئے اسے اولاد بنائے گا) جو زیور و زینت میں پرورش پائے اور (نرمیٔ طبع اور شرم و حیاء کے باعث) جھگڑے میں واضح (رائے کا اظہار کرنے والی بھی) نہ ہو،\qt@no{18}}%
\qt@newcmd\qurantrans@ur@mmmmcccxliv{اور انہوں نے فرشتوں کو جو کہ (خدائے) رحمان کے بندے ہیں عورتیں قرار دیا ہے، کیا وہ اُن کی پیدائش پر حاضر تھے؟ (نہیں، تو) اب اُن کی گواہی لکھ لی جائے گی اور (روزِ قیامت) اُن سے باز پُرس ہوگی،\qt@no{19}}%
\qt@newcmd\qurantrans@ur@mmmmcccxlv{اور وہ کہتے ہیں کہ اگر رحمان چاہتا تو ہم اِن (بتوں) کی پرستش نہ کرتے، انہیں اِس کا (بھی) کچھ علم نہیں ہے وہ محض اَٹکل سے جھوٹی باتیں کرتے ہیں،\qt@no{20}}%
\qt@newcmd\qurantrans@ur@mmmmcccxlvi{کیا ہم نے انہیں اس سے پہلے کوئی کتاب دے رکھی ہے کہ جسے وہ سند کے طور پر تھامے ہوئے ہیں،\qt@no{21}}%
\qt@newcmd\qurantrans@ur@mmmmcccxlvii{نہیں) بلکہ وہ کہتے ہیں: بیشک ہم نے اپنے باپ دادا کو ایک ملّت (و مذہب) پر پایا اور یقیناً ہم انہی کے نقوشِ قدم پر (چلتے ہوئے) ہدایت یافتہ ہیں،\qt@no{22}}%
\qt@newcmd\qurantrans@ur@mmmmcccxlviii{اور اسی طرح ہم نے کسی بستی میں آپ سے پہلے کوئی ڈر سنانے والا نہیں بھیجا مگر وہاں کے وڈیروں اور خوشحال لوگوں نے کہا: بیشک ہم نے اپنے باپ دادا کو ایک طریقہ و مذہب پر پایا اور ہم یقیناً انہی کے نقوشِ قدم کی اقتداء کرنے والے ہیں،\qt@no{23}}%
\qt@newcmd\qurantrans@ur@mmmmcccxlix{پیغمبر نے) کہا: اگرچہ میں تمہارے پاس اُس (طریقہ) سے بہتر ہدایت کا (دین اور) طریقہ لے آؤں جس پر تم نے اپنے باپ دادا کو پایا تھا، تو انہوں نے کہا: جو کچھ (بھی) تم دے کر بھیجے گئے ہو ہم اُس کے منکر ہیں،\qt@no{24}}%
\qt@newcmd\qurantrans@ur@mmmmcccl{سو ہم نے اُن سے بدلہ لے لیا پس آپ دیکھئے کہ جھٹلانے والوں کا انجام کیسا ہوا،\qt@no{25}}%
\qt@newcmd\qurantrans@ur@mmmmcccli{اور جب ابراہیم (علیہ السلام) نے اپنے (حقیقی چچا مگر پرورش کی نسبت سے) باپ اور اپنی قوم سے فرمایا: بیشک میں اُن سب چیزوں سے بیزار ہوں جنہیں تم پوجتے ہو،\qt@no{26}}%
\qt@newcmd\qurantrans@ur@mmmmccclii{بجز اس ذات کے جس نے مجھے پیدا کیا، سو وہی مجھے عنقریب راستہ دکھائے گا،\qt@no{27}}%
\qt@newcmd\qurantrans@ur@mmmmcccliii{اور ابراہیم (علیہ السلام) نے اس (کلمۂ توحید) کو اپنی نسل و ذریّت میں باقی رہنے والا کلمہ بنا دیا تاکہ وہ (اللہ کی طرف) رجوع کرتے رہیں،\qt@no{28}}%
\qt@newcmd\qurantrans@ur@mmmmcccliv{بلکہ میں نے انہیں اور اِن کے آباء و اجداد کو (اسی ابراہیم علیہ السلام کے تصدّق اور واسطہ سے اِس دنیا میں) فائدہ پہنچایا ہے یہاں تک کہ اِن کے پاس حق (یعنی قرآن) اور واضح و روشن بیان والا رسول (صلی اللہ علیہ وآلہ وسلم) تشریف لے آیا،\qt@no{29}}%
\qt@newcmd\qurantrans@ur@mmmmccclv{اور جب اُن کے پاس حق آپہنچا تو کہنے لگے: یہ جادو ہے اور ہم اس کے منکر ہیں،\qt@no{30}}%
\qt@newcmd\qurantrans@ur@mmmmccclvi{اور کہنے لگے: یہ قرآن (مکّہ اور طائف کی) دو بستیوں میں سے کسی بڑے آدمی (یعنی کسی وڈیرے، سردار اور مال دار) پر کیوں نہیں اتارا گیا،\qt@no{31}}%
\qt@newcmd\qurantrans@ur@mmmmccclvii{کیا آپ کے رب کی رحمتِ (نبوّت) کو یہ لوگ تقسیم کرتے ہیں؟ ہم اِن کے درمیان دنیوی زندگی میں ان کے (اسبابِ) معیشت کو تقسیم کرتے ہیں اور ہم ہی ان میں سے بعض کو بعض پر (وسائل و دولت میں) درجات کی فوقیت دیتے ہیں، (کیا ہم یہ اس لئے کرتے ہیں) کہ ان میں سے بعض (جو امیر ہیں) بعض (غریبوں) کا مذاق اڑائیں (یہ غربت کا تمسخر ہے کہ تم اس وجہ سے کسی کو رحمتِ نبوت کا حق دار ہی نہ سمجھو)، اور آپ کے رب کی رحمت اس (دولت) سے بہتر ہے جسے وہ جمع کرتے (اور گھمنڈ کرتے) ہیں،\qt@no{32}}%
\qt@newcmd\qurantrans@ur@mmmmccclviii{اور اگر یہ نہ ہوتا کہ سب لوگ (کفر پر جمع ہو کر) ایک ہی ملّت بن جائیں گے تو ہم (خدائے) رحمان کے ساتھ کفر کرنے والے تمام لوگوں کے گھروں کی چھتیں (بھی) چاندی کی کر دیتے اور سیڑھیاں (بھی) جن پر وہ چڑھتے ہیں،\qt@no{33}}%
\qt@newcmd\qurantrans@ur@mmmmccclix{اور (اسی طرح) اُن کے گھروں کے دروازے (بھی چاندی کے کر دیتے) اور تخت (بھی) جن پر وہ مسند لگاتے ہیں،\qt@no{34}}%
\qt@newcmd\qurantrans@ur@mmmmccclx{اور (چاندی کے اوپر) سونے اور جواہرات کی آرائش بھی (کر دیتے)، اور یہ سب کچھ دنیوی زندگی کی عارضی اور حقیر متاع ہے، اور آخرت (کا حُسن و زیبائش) آپ کے رب کے پاس ہے (جو) صرف پرہیزگاروں کے لئے ہے،\qt@no{35}}%
\qt@newcmd\qurantrans@ur@mmmmccclxi{اور جو شخص (خدائے) رحمان کی یاد سے صرف نظر کر لے تو ہم اُس کے لئے ایک شیطان مسلّط کر دیتے ہیں جو ہر وقت اس کے ساتھ جڑا رہتا ہے،\qt@no{36}}%
\qt@newcmd\qurantrans@ur@mmmmccclxii{اور وہ (شیاطین) انہیں (ہدایت کے) راستہ سے روکتے ہیں اور وہ یہی گمان کئے رہتے ہیں کہ وہ ہدایت یافتہ ہیں،\qt@no{37}}%
\qt@newcmd\qurantrans@ur@mmmmccclxiii{یہاں تک کہ جب وہ ہمارے پاس آئے گا تو (اپنے ساتھی شیطان سے) کہے گا: اے کاش! میرے اور تیرے درمیان مشرق و مغرب کا فاصلہ ہوتا پس (تو) بہت ہی برا ساتھی تھا،\qt@no{38}}%
\qt@newcmd\qurantrans@ur@mmmmccclxiv{اور آج کے دن تمہیں (یہ آرزو کرنا) سود مند نہیں ہوگا جبکہ تم (عمر بھر) ظلم کرتے رہے، (آج) تم سب عذاب میں شریک ہو،\qt@no{39}}%
\qt@newcmd\qurantrans@ur@mmmmccclxv{پھر کیا آپ بہروں کو سنائیں گے یا اندھوں کو اور اُن لوگوں کو جو کھلی گمراہی میں ہیں راہِ ہدایت دکھائیں گے،\qt@no{40}}%
\qt@newcmd\qurantrans@ur@mmmmccclxvi{پس اگر ہم آپ کو (دنیا سے) لے جائیں تو تب بھی ہم اِن سے بدلہ لینے والے ہیں،\qt@no{41}}%
\qt@newcmd\qurantrans@ur@mmmmccclxvii{یا ہم آپ کو وہ (عذاب ہی) دکھا دیں جس کا ہم نے اُن سے وعدہ کیا ہے، سو بے شک ہم اُن پر کامل قدرت رکھنے والے ہیں،\qt@no{42}}%
\qt@newcmd\qurantrans@ur@mmmmccclxviii{پس آپ اس (قرآن) کو مضبوطی سے تھامے رکھیئے جو آپ کی طرف وحی کیا گیا ہے، بیشک آپ سیدھی راہ پر (قائم) ہیں،\qt@no{43}}%
\qt@newcmd\qurantrans@ur@mmmmccclxix{اور یقیناً یہ (قرآن) آپ کے لئے اور آپ کی امت کے لئے عظیم شرف ہے، اور (لوگو!) عنقریب تم سے پوچھا جائے گا (کہ تم نے قرآن کے ساتھ کتنا تعلق استوار کیا)،\qt@no{44}}%
\qt@newcmd\qurantrans@ur@mmmmccclxx{اور جو رسول ہم نے آپ سے پہلے بھیجے آپ اُن سے پوچھئے کہ کیا ہم نے (خدائے) رحمان کے سوا کوئی اور معبود بنائے تھے کہ اُن کی پرستش کی جائے،\qt@no{45}}%
\qt@newcmd\qurantrans@ur@mmmmccclxxi{اور یقیناً ہم نے موسٰی(علیہ السلام) کو اپنی نشانیاں دے کر فرعون اور اس کے سرداروں کی طرف بھیجا تو انہوں نے کہا: بیشک میں سب جہانوں کے پروردگار کا رسول ہوں،\qt@no{46}}%
\qt@newcmd\qurantrans@ur@mmmmccclxxii{پھر جب وہ ہماری نشانیاں لے کر اُن کے پاس آئے تو وہ اسی وقت ان (نشانیوں) پر ہنسنے لگے،\qt@no{47}}%
\qt@newcmd\qurantrans@ur@mmmmccclxxiii{اور ہم انہیں کوئی نشانی نہیں دکھاتے تھے مگر (یہ کہ) وہ اپنے سے پہلی مشابہ نشانی سے کہیں بڑھ کر ہوتی تھی اور (بالآخر) ہم نے انہیں (کئی بار) عذاب میں پکڑا تاکہ وہ باز آجائیں،\qt@no{48}}%
\qt@newcmd\qurantrans@ur@mmmmccclxxiv{اور وہ کہنے لگے: اے جادوگر! تو اپنے رب سے ہمارے لئے اُس عہد کے مطابق دعا کر جو اُس نے تجھ سے کر رکھا ہے (تو) بیشک ہم ہدایت یافتہ ہو جائیں گے،\qt@no{49}}%
\qt@newcmd\qurantrans@ur@mmmmccclxxv{پھر جب ہم نے (دعائے موسٰی سے) وہ عذاب اُن سے ہٹا دیا تو وہ فوراً عہد شکنی کرنے لگے،\qt@no{50}}%
\qt@newcmd\qurantrans@ur@mmmmccclxxvi{اور فرعون نے اپنی قوم میں (فخر سے) پکارا (اور) کہا: اے میری قوم! کیا ملکِ مصر میرے قبضہ میں نہیں ہے اور یہ نہریں جو میرے (محلّات کے) نیچے سے بہہ رہی ہیں (کیا میری نہیں ہیں؟) سو کیا تم دیکھتے نہیں ہو،\qt@no{51}}%
\qt@newcmd\qurantrans@ur@mmmmccclxxvii{کیا (یہ حقیقت نہیں کہ) میں اِس شخص سے بہتر ہوں جو حقیر و بے وقعت ہے اور صاف طریقے سے گفتگو بھی نہیں کر سکتا؟،\qt@no{52}}%
\qt@newcmd\qurantrans@ur@mmmmccclxxviii{پھر (اگر یہ سچا رسول ہے تو) اِس پر (پہننے کے لئے) سونے کے کنگن کیوں نہیں اتارے جاتے یا اِس کے ساتھ فرشتے جمع ہو کر (پے در پے) کیوں نہیں آجاتے؟،\qt@no{53}}%
\qt@newcmd\qurantrans@ur@mmmmccclxxix{پس اُس نے (اِن باتوں سے) اپنی قوم کو بے وقوف بنا لیا، سو اُن لوگوں نے اُس کا کہنا مان لیا، بیشک وہ لوگ ہی نافرمان قوم تھے،\qt@no{54}}%
\qt@newcmd\qurantrans@ur@mmmmccclxxx{پھر جب انہوں نے (موسٰی علیہ السلام کی شان میں گستاخی کر کے) ہمیں شدید غضبناک کر دیا (تو) ہم نے اُن سے بدلہ لے لیا اور ہم نے اُن سب کو غرق کر دیا،\qt@no{55}}%
\qt@newcmd\qurantrans@ur@mmmmccclxxxi{سو ہم نے انہیں گیا گزرا کر دیا اور پیچھے آنے والوں کے لئے نمونۂ عبرت بنا دیا،\qt@no{56}}%
\qt@newcmd\qurantrans@ur@mmmmccclxxxii{اور جب (عیسٰی) ابنِ مریم (علیہما السلام) کی مثال بیان کی جائے تو اس وقت آپ کی قوم (کے لوگ) اس سے (خوشی کے مارے) ہنستے ہیں،\qt@no{57}}%
\qt@newcmd\qurantrans@ur@mmmmccclxxxiii{اور کہتے ہیں: آیا ہمارے معبود بہتر ہیں یا وہ (عیسٰی علیہ السلام)، وہ آپ سے یہ بات محض جھگڑنے کے لئے کرتے ہیں، بلکہ وہ لوگ بڑے جھگڑالو ہیں،\qt@no{58}}%
\qt@newcmd\qurantrans@ur@mmmmccclxxxiv{وہ (عیسٰی علیہ السلام) محض ایک (برگزیدہ) بندہ تھے جن پر ہم نے انعام فرمایا اور ہم نے انہیں بنی اسرائیل کے لئے (اپنی قدرت کا) نمونہ بنایا تھا،\qt@no{59}}%
\qt@newcmd\qurantrans@ur@mmmmccclxxxv{اور اگر ہم چاہتے تو ہم تمہارے بدلے زمین میں فرشتے پیدا کر دیتے جو تمہارے جانشین ہوتے،\qt@no{60}}%
\qt@newcmd\qurantrans@ur@mmmmccclxxxvi{اور بیشک وہ (عیسٰی علیہ السلام جب آسمان سے نزول کریں گے تو قربِ) قیامت کی علامت ہوں گے، پس تم ہرگز اس میں شک نہ کرنا اور میری پیروی کرتے رہنا، یہ سیدھا راستہ ہے،\qt@no{61}}%
\qt@newcmd\qurantrans@ur@mmmmccclxxxvii{اور شیطان تمہیں ہرگز (اس راہ سے) روکنے نہ پائے، بیشک وہ تمہارا کھلا دشمن ہے،\qt@no{62}}%
\qt@newcmd\qurantrans@ur@mmmmccclxxxviii{اور جب عیسٰی (علیہ السلام) واضح نشانیاں لے کر آئے تو انہوں نے کہا: یقیناً میں تمہارے پاس حکمت و دانائی لے کر آیا ہوں اور (اس لئے آیا ہوں) کہ بعض باتیں جن میں تم اختلاف کر رہے ہو تمہارے لئے خوب واضح کر دوں، سو تم اللہ سے ڈرو اور میری اطاعت کرو،\qt@no{63}}%
\qt@newcmd\qurantrans@ur@mmmmccclxxxix{بیشک اللہ ہی میرا (بھی) رب ہے اور تمہارا (بھی) رب ہے، پس اسی کی عبادت کرو۔ یہی سیدھا راستہ ہے،\qt@no{64}}%
\qt@newcmd\qurantrans@ur@mmmmcccxc{پس اُن کے درمیان (آپس میں ہی) مختلف فرقے ہو گئے، سو جن لوگوں نے ظلم کیا اُن کے لئے دردناک دن کے عذاب کی خرابی ہے،\qt@no{65}}%
\qt@newcmd\qurantrans@ur@mmmmcccxci{یہ لوگ کیا انتظار کر رہے ہیں (بس یہی) کہ قیامت اُن پر اچانک آجائے اور انہیں خبر بھی نہ ہو،\qt@no{66}}%
\qt@newcmd\qurantrans@ur@mmmmcccxcii{سارے دوست و احباب اُس دن ایک دوسرے کے دشمن ہوں گے سوائے پرہیزگاروں کے (انہی کی دوستی اور ولایت کام آئے گی)،\qt@no{67}}%
\qt@newcmd\qurantrans@ur@mmmmcccxciii{اُن سے فرمایا جائے گا): اے میرے (مقرّب) بندو! آج کے دن تم پر نہ کوئی خوف ہے اور نہ ہی تم غم زدہ ہو گے،\qt@no{68}}%
\qt@newcmd\qurantrans@ur@mmmmcccxciv{یہ) وہ لوگ ہیں جو ہماری آیتوں پر ایمان لائے اور ہمیشہ (ہمارے) تابعِ فرمان رہے،\qt@no{69}}%
\qt@newcmd\qurantrans@ur@mmmmcccxcv{تم اور تمہارے ساتھ جڑے رہنے والے ساتھی٭ (سب) جنت میں داخل ہو جاؤ (جنت کی نعمتوں، راحتوں اور لذّتوں کے ساتھ) تمہاری تکریم کی جائے گی، ٭ مفسرین کرام نے آیتِ کریمہ میں اَزوَاجُکُم کا معنی بیویوں کے علاوہ ”قریبی ساتھی“ بھی کیا ہے جیسے امام قرطبی نے تفسیر ”الجامع لاحکام القرآن (۱۶: ۱۱۱ )“ میں، امام ابن کثیر نے ”تفسیر القرآن العظیم (۴: ۱۳۴)“ میں، اور امام شوکانی نے تفسیر ”فتح القدیر (۴: ۵۶۳)“ میں یہ معنی بیان کیا ہے۔ اسی بناء پر یہاں اَزوَاج کا معنی بیویوں کی بجائے ”ساتھ جڑے رہنے والے ساتھی“ کیا گیا ہے۔\qt@no{70}}%
\qt@newcmd\qurantrans@ur@mmmmcccxcvi{ان پر سونے کی پلیٹوں اور گلاسوں کا دور چلایا جائے گا اور وہاں وہ سب چیزیں (موجود) ہوں گی جن کو دل چاہیں گے اور (جن سے) آنکھیں راحت پائیں گی اور تم وہاں ہمیشہ رہو گے،\qt@no{71}}%
\qt@newcmd\qurantrans@ur@mmmmcccxcvii{اور (اے پرہیزگارو!) یہ وہ جنت ہے جس کے تم مالک بنا دیئے گئے ہو، اُن (اعمال) کے صلہ میں جو تم انجام دیتے تھے،\qt@no{72}}%
\qt@newcmd\qurantrans@ur@mmmmcccxcviii{تمہارے لئے اس میں بکثرت پھل اور میوے ہیں تم ان میں سے کھاتے رہو گے،\qt@no{73}}%
\qt@newcmd\qurantrans@ur@mmmmcccxcix{بیشک مجرم لوگ دوزخ کے عذاب میں ہمیشہ رہنے والے ہیں،\qt@no{74}}%
\qt@newcmd\qurantrans@ur@mmmmcd{جو اُن سے ہلکا نہیں کیا جائے گا اور وہ اس میں ناامید ہو کر پڑے رہیں گے،\qt@no{75}}%
\qt@newcmd\qurantrans@ur@mmmmcdi{اور ہم نے اُن پر ظلم نہیں کیا لیکن وہ خود ہی ظلم کرنے والے تھے،\qt@no{76}}%
\qt@newcmd\qurantrans@ur@mmmmcdii{اور وہ (داروغۂ جہنّم کو) پکاریں گے: اے مالک! آپ کا رب ہمیں موت دے دے (تو اچھا ہے)۔ وہ کہے گا کہ تم (اب اِسی حال میں ہی) ہمیشہ رہنے والے ہو،\qt@no{77}}%
\qt@newcmd\qurantrans@ur@mmmmcdiii{بیشک ہم تمہارے پاس حق لائے لیکن تم میں سے اکثر لوگ حق کو ناپسند کرتے تھے،\qt@no{78}}%
\qt@newcmd\qurantrans@ur@mmmmcdiv{کیا انہوں نے (یعنی کفّارِ مکہ نے رسول صلی اللہ علیہ وآلہ وسلم کے خلاف کوئی تدبیر) پختہ کر لی ہے تو ہم (بھی) پختہ فیصلہ کرنے والے ہیں،\qt@no{79}}%
\qt@newcmd\qurantrans@ur@mmmmcdv{کیا وہ گمان کرتے ہیں کہ ہم ان کی پوشیدہ باتیں اور اُن کی سرگوشیاں نہیں سنتے؟ کیوں نہیں (ضرور سنتے ہیں)! اور ہمارے بھیجے ہوئے فرشتے بھی اُن کے پاس لکھ رہے ہوتے ہیں،\qt@no{80}}%
\qt@newcmd\qurantrans@ur@mmmmcdvi{فرما دیجئے کہ اگر (بفرضِ محال) رحمان کے (ہاں) کوئی لڑکا ہوتا (یا اولاد ہوتی) تو میں سب سے پہلے (اس کی) عبادت کرنے والا ہوتا،\qt@no{81}}%
\qt@newcmd\qurantrans@ur@mmmmcdvii{آسمانوں اور زمین کا پروردگار، عرش کا مالک پاک ہے اُن باتوں سے جو یہ بیان کرتے ہیں،\qt@no{82}}%
\qt@newcmd\qurantrans@ur@mmmmcdviii{سو آپ انہیں چھوڑ دیجئے، بے کار بحثوں میں پڑے رہیں اور لغو کھیل کھیلتے رہیں حتٰی کہ اپنے اس دن کو پا لیں گے جس کا اُن سے وعدہ کیا جا رہا ہے،\qt@no{83}}%
\qt@newcmd\qurantrans@ur@mmmmcdix{اور وہی ذات آسمان میں معبود ہے اور زمین میں (بھی) معبود ہے، اور وہ بڑی حکمت والا بڑے علم والا ہے،\qt@no{84}}%
\qt@newcmd\qurantrans@ur@mmmmcdx{اور وہ ذات بڑی بابرکت ہے جس کے لئے آسمانوں اور زمین کی بادشاہت ہے اور (اُن کی بھی) جو کچھ اِن کے درمیان ہے، اور (وقتِ) قیامت کا علم (بھی) اس کے پاس ہے، اور تم اسی کی طرف لوٹائے جاؤ گے،\qt@no{85}}%
\qt@newcmd\qurantrans@ur@mmmmcdxi{اور جن کی یہ (کافر لوگ) اللہ کے سوا پرستش کرتے ہیں وہ (تو) شفاعت کا (کوئی) اختیار نہیں رکھتے مگر (ان کے برعکس شفاعت کا اختیار ان کو حاصل ہے) جنہوں نے حق کی گواہی دی اور وہ اسے (یقین کے ساتھ) جانتے بھی تھے،\qt@no{86}}%
\qt@newcmd\qurantrans@ur@mmmmcdxii{اور اگر آپ اِن سے دریافت فرمائیں کہ انہیں کس نے پیدا کیا ہے تو ضرور کہیں گے: اللہ نے، پھر وہ کہاں بھٹکتے پھرتے ہیں،\qt@no{87}}%
\qt@newcmd\qurantrans@ur@mmmmcdxiii{اور اُس (حبیبِ مکرّم) کے (یوں) کہنے کی قسم کہ یا ربّ! بیشک یہ ایسے لوگ ہیں جو ایمان (ہی) نہیں لاتے،\qt@no{88}}%
\qt@newcmd\qurantrans@ur@mmmmcdxiv{سو (میرے محبوب!) آپ اُن سے چہرہ پھیر لیجئے اور (یوں) کہہ دیجئے: (بس ہمارا) سلام، پھر وہ جلد ہی (اپنا حشر) معلوم کر لیں گے،\qt@no{89}}%
\qt@newcmd\qurantrans@ur@mmmmcdxv{\basmalahur حا، میم (حقیقی معنی اللہ اور رسول صلی اللہ علیہ وآلہ وسلم ہی بہتر جانتے ہیں)،\qt@no{1}}%
\qt@newcmd\qurantrans@ur@mmmmcdxvi{اس روشن کتاب کی قسم،\qt@no{2}}%
\qt@newcmd\qurantrans@ur@mmmmcdxvii{بیشک ہم نے اسے ایک بابرکت رات میں اتارا ہے بیشک ہم ڈر سنانے والے ہیں،\qt@no{3}}%
\qt@newcmd\qurantrans@ur@mmmmcdxviii{اس (رات) میں ہر حکمت والے کام کا (جدا جدا) فیصلہ کر دیا جاتا ہے،\qt@no{4}}%
\qt@newcmd\qurantrans@ur@mmmmcdxix{ہماری بارگاہ کے حکم سے، بیشک ہم ہی بھیجنے والے ہیں،\qt@no{5}}%
\qt@newcmd\qurantrans@ur@mmmmcdxx{یہ) آپ کے رب کی جانب سے رحمت ہے، بیشک وہ خوب سننے والا خوب جاننے والا ہے،\qt@no{6}}%
\qt@newcmd\qurantrans@ur@mmmmcdxxi{آسمانوں اور زمین کا اور جو کچھ اِن کے درمیان ہے (اُس کا) پروردگار ہے، بشرطیکہ تم یقین رکھنے والے ہو،\qt@no{7}}%
\qt@newcmd\qurantrans@ur@mmmmcdxxii{اُس کے سوا کوئی معبود نہیں، وہی زندگی دیتا اور موت دیتا ہے (وہ) تمہارا (بھی) رب ہے اور تمہارے اگلے آباء و اجداد کا (بھی) رب ہے،\qt@no{8}}%
\qt@newcmd\qurantrans@ur@mmmmcdxxiii{بلکہ وہ شک میں پڑے کھیل رہے ہیں،\qt@no{9}}%
\qt@newcmd\qurantrans@ur@mmmmcdxxiv{سو آپ اُس دن کا انتظار کریں جب آسمان واضح دھواں ظاہر کر دے گا،\qt@no{10}}%
\qt@newcmd\qurantrans@ur@mmmmcdxxv{جو لوگوں کو ڈھانپ لے گا (یعنی ہر طرف محیط ہو جائے گا)، یہ دردناک عذاب ہے،\qt@no{11}}%
\qt@newcmd\qurantrans@ur@mmmmcdxxvi{اس وقت کہیں گے:) اے ہمارے رب! تو ہم سے (اس) عذاب کو دور کر دے، بیشک ہم ایمان لاتے ہیں،\qt@no{12}}%
\qt@newcmd\qurantrans@ur@mmmmcdxxvii{اب اُن کا نصیحت ماننا کہاں (مفید) ہو سکتا ہے حالانکہ ان کے پاس واضح بیان فرمانے والے رسول آچکے،\qt@no{13}}%
\qt@newcmd\qurantrans@ur@mmmmcdxxviii{پھر انہوں نے اس سے منہ پھیر لیا اور (گستاخی کرتے ہوئے) کہنے لگے: (وہ) سکھایا ہوا دیوانہ ہے،\qt@no{14}}%
\qt@newcmd\qurantrans@ur@mmmmcdxxix{بیشک ہم تھوڑا سا عذاب دور کئے دیتے ہیں تم یقیناً (وہی کفر) دہرانے لگو گے،\qt@no{15}}%
\qt@newcmd\qurantrans@ur@mmmmcdxxx{جس دن ہم بڑی سخت گرفت کریں گے تو (اس دن) ہم یقیناً انتقام لے ہی لیں گے،\qt@no{16}}%
\qt@newcmd\qurantrans@ur@mmmmcdxxxi{اور در حقیقت ہم نے اِن سے پہلے قومِ فرعون کی (بھی) آزمائش کی تھی اور اُن کے پاس بزرگی والے رسول (موسٰی علیہ السلام) آئے تھے،\qt@no{17}}%
\qt@newcmd\qurantrans@ur@mmmmcdxxxii{انہوں نے کہا تھا) کہ تم بندگانِ خدا (یعنی بنی اسرائیل) کو میرے حوالے کر دو، بیشک میں تمہاری قیادت و رہبری کے لئے امانت دار رسول ہوں،\qt@no{18}}%
\qt@newcmd\qurantrans@ur@mmmmcdxxxiii{اور یہ کہ اللہ کے مقابلے میں سرکشی نہ کرو، میں تمہارے پاس روشن دلیل لے کر آیا ہوں،\qt@no{19}}%
\qt@newcmd\qurantrans@ur@mmmmcdxxxiv{اور بیشک میں نے اپنے رب اور تمہارے رب کی پناہ لے لی ہے اس سے کہ تم مجھے سنگ سار کرو،\qt@no{20}}%
\qt@newcmd\qurantrans@ur@mmmmcdxxxv{اور اگر تم مجھ پر ایمان نہیں لاتے تو مجھ سے کنارہ کش ہو جاؤ،\qt@no{21}}%
\qt@newcmd\qurantrans@ur@mmmmcdxxxvi{پھر انہوں نے اپنے رب سے دعا کی کہ بیشک یہ لوگ مجرم قوم ہیں،\qt@no{22}}%
\qt@newcmd\qurantrans@ur@mmmmcdxxxvii{ارشاد ہوا:) پھر تم میرے بندوں کو راتوں رات لے کر چلے جاؤ بیشک تمہارا تعاقب کیا جائے گا،\qt@no{23}}%
\qt@newcmd\qurantrans@ur@mmmmcdxxxviii{اور (خود گزر جانے کے بعد) دریا کو ساکن اور کھلا چھوڑ دینا، بیشک وہ ایسا لشکر ہے جسے ڈبو دیا جائے گا،\qt@no{24}}%
\qt@newcmd\qurantrans@ur@mmmmcdxxxix{وہ کتنے ہی باغات اور چشمے چھوڑ گئے،\qt@no{25}}%
\qt@newcmd\qurantrans@ur@mmmmcdxl{اور زراعتیں اور عالی شان عمارتیں،\qt@no{26}}%
\qt@newcmd\qurantrans@ur@mmmmcdxli{اور نعمتیں (اور راحتیں) جن میں وہ عیش کیا کرتے تھے،\qt@no{27}}%
\qt@newcmd\qurantrans@ur@mmmmcdxlii{اسی طرح ہوا، اور ہم نے اِن سب کا دوسرے لوگوں کو وارث بنا دیا،\qt@no{28}}%
\qt@newcmd\qurantrans@ur@mmmmcdxliii{پھر نہ (تو) اُن پر آسمان اور زمین روئے اور نہ ہی انہیں مہلت دی گئی،\qt@no{29}}%
\qt@newcmd\qurantrans@ur@mmmmcdxliv{اور واقعتہً ہم نے بنی اسرائیل کو ذِلّت انگیز عذاب سے نجات بخشی،\qt@no{30}}%
\qt@newcmd\qurantrans@ur@mmmmcdxlv{فرعون سے، بیشک وہ بڑا سرکش، حد سے گزرنے والوں میں سے تھا،\qt@no{31}}%
\qt@newcmd\qurantrans@ur@mmmmcdxlvi{اور بیشک ہم نے ان (بنی اسرائیل) کو علم کی بنا پر ساری دنیا (کی معاصر تہذیبوں) پر چُن لیا تھا،\qt@no{32}}%
\qt@newcmd\qurantrans@ur@mmmmcdxlvii{اور ہم نے انہیں وہ نشانیاں عطا فرمائیں جن میں ظاہری نعمت (اور صریح آزمائش) تھی،\qt@no{33}}%
\qt@newcmd\qurantrans@ur@mmmmcdxlviii{بیشک وہ لوگ کہتے ہیں،\qt@no{34}}%
\qt@newcmd\qurantrans@ur@mmmmcdxlix{کہ ہماری پہلی موت کے سوا (بعد میں) کچھ نہیں ہے اور ہم (دوبارہ) نہیں اٹھائے جائیں گے،\qt@no{35}}%
\qt@newcmd\qurantrans@ur@mmmmcdl{سو تم ہمارے باپ دادا کو (زندہ کر کے) لے آؤ، اگر تم سچے ہو،\qt@no{36}}%
\qt@newcmd\qurantrans@ur@mmmmcdli{بھلا یہ لوگ بہتر ہیں یا (بادشاہِ یمن اسعد ابوکریب) تُبّع (الحمیری) کی قوم اور وہ لوگ جو اِن سے پہلے تھے، ہم نے اُن (سب) کو ہلاک کر ڈالا تھا، بیشک وہ لوگ مجرم تھے،\qt@no{37}}%
\qt@newcmd\qurantrans@ur@mmmmcdlii{اور ہم نے آسمانوں اور زمین کو اور جو کچھ اِن کے درمیان ہے اسے محض کھیلتے ہوئے نہیں بنایا،\qt@no{38}}%
\qt@newcmd\qurantrans@ur@mmmmcdliii{ہم نے دونوں کو حق کے (مقصد و حکمت کے) ساتھ پیدا کیا ہے لیکن اُن کے اکثر لوگ نہیں جانتے،\qt@no{39}}%
\qt@newcmd\qurantrans@ur@mmmmcdliv{بیشک فیصلہ کا دن، اُن سب کے لئے مقررّہ وقت ہے،\qt@no{40}}%
\qt@newcmd\qurantrans@ur@mmmmcdlv{جس دن کوئی دوست کسی دوست کے کچھ کام نہ آئے گا اور نہ ہی اُن کی مدد کی جائے گی،\qt@no{41}}%
\qt@newcmd\qurantrans@ur@mmmmcdlvi{سوائے اُن کے جن پر اللہ نے رحمت فرمائی ہے (وہ ایک دوسرے کی شفاعت کریں گے)، بیشک وہ بڑا غالب بہت رحم فرمانے والا ہے،\qt@no{42}}%
\qt@newcmd\qurantrans@ur@mmmmcdlvii{بیشک کانٹے دار پھل کا درخت،\qt@no{43}}%
\qt@newcmd\qurantrans@ur@mmmmcdlviii{بڑے نافرمانوں کا کھانا ہوگا،\qt@no{44}}%
\qt@newcmd\qurantrans@ur@mmmmcdlix{پگھلے ہوئے تانبے کی طرح وہ پیٹوں میں کَھولے گا،\qt@no{45}}%
\qt@newcmd\qurantrans@ur@mmmmcdlx{کھولتے ہوئے پانی کے جوش کی مانند،\qt@no{46}}%
\qt@newcmd\qurantrans@ur@mmmmcdlxi{حکم ہوگا:) اس کو پکڑ لو اور دوزخ کے وسط تک اسے زور سے گھسیٹتے ہوئے لے جاؤ،\qt@no{47}}%
\qt@newcmd\qurantrans@ur@mmmmcdlxii{پھر اِس کے سَر پر کھولتے ہوئے پانی کا عذاب ڈالو،\qt@no{48}}%
\qt@newcmd\qurantrans@ur@mmmmcdlxiii{مَزہ چکھ لے، ہاں تُو ہی (اپنے گمان اور دعوٰی میں) بڑا معزّز و مکرّم ہے،\qt@no{49}}%
\qt@newcmd\qurantrans@ur@mmmmcdlxiv{بیشک یہ وہی (دوزخ) ہے جس میں تم شک کیا کرتے تھے،\qt@no{50}}%
\qt@newcmd\qurantrans@ur@mmmmcdlxv{بیشک پرہیزگار لوگ اَمن والے مقام میں ہوں گے،\qt@no{51}}%
\qt@newcmd\qurantrans@ur@mmmmcdlxvi{باغات اور چشموں میں،\qt@no{52}}%
\qt@newcmd\qurantrans@ur@mmmmcdlxvii{باریک اور دبیز ریشم کا لباس پہنے ہوں گے، آمنے سامنے بیٹھے ہوں گے،\qt@no{53}}%
\qt@newcmd\qurantrans@ur@mmmmcdlxviii{اسی طرح (ہی) ہوگا، اور ہم انہیں گوری رنگت والی کشادہ چشم حوروں سے بیاہ دیں گے،\qt@no{54}}%
\qt@newcmd\qurantrans@ur@mmmmcdlxix{وہاں (بیٹھے) اطمینان سے ہر طرح کے پھل اور میوے طلب کرتے ہوں گے،\qt@no{55}}%
\qt@newcmd\qurantrans@ur@mmmmcdlxx{اس (جنت) میں موت کا مَزہ نہیں چکھیں گے سوائے (اس) پہلی موت کے (جو گزر چکی ہوگی) اور اللہ انہیں دوزخ کے عذاب سے بچا لے گا،\qt@no{56}}%
\qt@newcmd\qurantrans@ur@mmmmcdlxxi{یہ آپ کے رب کا فضل ہے (یعنی آپ کا رب آپ کے وسیلے سے ہی عطا کرے گا)، یہی بہت بڑی کامیابی ہے،\qt@no{57}}%
\qt@newcmd\qurantrans@ur@mmmmcdlxxii{بس ہم نے آپ ہی کی زبان میں اس (قرآن) کو آسان کر دیا ہے تاکہ وہ نصیحت حاصل کریں،\qt@no{58}}%
\qt@newcmd\qurantrans@ur@mmmmcdlxxiii{سو آپ (بھی) انتظار فرمائیں، یقیناً وہ (بھی) انتظار کر رہے ہیں (آپ اُن کا حشر و انتقام دیکھیں گے اور وہ آپ کی شان اور آپ کے تصدّق سے مومنوں پر میرا انعام دیکھیں گے)،\qt@no{59}}%
\qt@newcmd\qurantrans@ur@mmmmcdlxxiv{\basmalahur حا، میم (حقیقی معنی اللہ اور رسول صلی اللہ علیہ وآلہ وسلم ہی بہتر جانتے ہیں)،\qt@no{1}}%
\qt@newcmd\qurantrans@ur@mmmmcdlxxv{اِس) کتاب کا اتارا جانا اللہ کی جانب سے ہے جو بڑی عزّت والا بڑی حکمت والا ہے،\qt@no{2}}%
\qt@newcmd\qurantrans@ur@mmmmcdlxxvi{بیشک آسمانوں اور زمین میں یقیناً مومنوں کے لئے نشانیاں ہیں،\qt@no{3}}%
\qt@newcmd\qurantrans@ur@mmmmcdlxxvii{اور تمہاری (اپنی) پیدائش میں اور اُن جانوروں میں جنہیں وہ پھیلاتا ہے، یقین رکھنے والے لوگوں کے لئے نشانیاں ہیں،\qt@no{4}}%
\qt@newcmd\qurantrans@ur@mmmmcdlxxviii{اور رات دن کے آگے پیچھے آنے جانے میں اور (بصورتِ بارش) اُس رِزق میں جسے اللہ آسمان سے اتارتا ہے، پھر اس سے زمین کو اُس کی مُردنی کے بعد زندہ کر دیتا ہے اور (اسی طرح) ہواؤں کے رُخ پھیرنے میں، اُن لوگوں کے لئے نشانیاں ہیں جو عقل و شعور رکھتے ہیں،\qt@no{5}}%
\qt@newcmd\qurantrans@ur@mmmmcdlxxix{یہ اللہ کی آیتیں ہیں جنہیں ہم آپ پر پوری سچائی کے ساتھ تلاوت فرماتے ہیں، پھر اللہ اور اُس کی آیتوں کے بعد یہ لوگ کس بات پر ایمان لائیں گے،\qt@no{6}}%
\qt@newcmd\qurantrans@ur@mmmmcdlxxx{ہر بہتان تراشنے والے کذّاب (اور) بڑے سیاہ کار کے لئے ہلاکت ہے،\qt@no{7}}%
\qt@newcmd\qurantrans@ur@mmmmcdlxxxi{جو اللہ کی (اُن) آیتوں کو سنتا ہے جو اُس پر پڑھ پڑھ کر سنائی جاتی ہیں پھر (اپنے کفر پر) اصرار کرتا ہے تکبّر کرتے ہوئے، گویا اُس نے انہیں سنا ہی نہیں، تو آپ اسے دردناک عذاب کی بشارت دے دیں،\qt@no{8}}%
\qt@newcmd\qurantrans@ur@mmmmcdlxxxii{اور جب اسے ہماری (قرآنی) آیات میں سے کسی چیز کا (بھی) علم ہو جاتا ہے تو اسے مذاق بنا لیتا ہے، ایسے ہی لوگوں کے لئے ذلّت انگیز عذاب ہے،\qt@no{9}}%
\qt@newcmd\qurantrans@ur@mmmmcdlxxxiii{اُن کے (اس عرصۂ حیات کے) بعد دوزخ ہے اور جو (مالِ دنیا) انہوں نے کما رکھا ہے اُن کے کچھ کام نہیں آئے گا اور نہ وہ بت (ہی کام آئیں گے) جنہیں اللہ کے سوا انہوں نے کارساز بنا رکھا ہے، اور اُن کے لئے بہت سخت عذاب ہے،\qt@no{10}}%
\qt@newcmd\qurantrans@ur@mmmmcdlxxxiv{یہ (قرآن) ہدایت ہے، اور جن لوگوں نے اپنے رب کی آیات کے ساتھ کفر کیا اُن کے لئے سخت ترین دردناک عذاب ہے،\qt@no{11}}%
\qt@newcmd\qurantrans@ur@mmmmcdlxxxv{اللہ ہی ہے جس نے سمندر کو تمہارے قابو میں کر دیا تاکہ اس کے حکم سے اُس میں جہاز اور کشتیاں چلیں اور تاکہ تم (بحری راستوں سے بھی) اُس کا فضل (یعنی رزق) تلاش کر سکو، اور اس لئے کہ تم شکر گزار ہو جاؤ،\qt@no{12}}%
\qt@newcmd\qurantrans@ur@mmmmcdlxxxvi{اور اُس نے تمہارے لئے جو کچھ آسمانوں میں ہے اور جو کچھ زمین میں ہے، سب کو اپنی طرف سے (نظام کے تحت) مسخر کر دیا ہے، بیشک اس میں اُن لوگوں کے لئے نشانیاں ہیں جو غور و فکر کرتے ہیں،\qt@no{13}}%
\qt@newcmd\qurantrans@ur@mmmmcdlxxxvii{آپ ایمان والوں سے فرما دیجئے کہ وہ اُن لوگوں کو نظر انداز کر دیں جو اللہ کے دنوں کی (آمد کی) امید اور خوف نہیں رکھتے تاکہ وہ اُن لوگوں کو اُن (کے اعمال) کا پورا بدلہ دے دے جو وہ کمایا کرتے تھے،\qt@no{14}}%
\qt@newcmd\qurantrans@ur@mmmmcdlxxxviii{جس نے کوئی نیک عمل کیا سو اپنی ہی جان کے (نفع کے) لئے اور جِس نے برائی کی تو (اس کا وبال بھی) اسی پر ہے پھر تم سب اپنے رب کی طرف لوٹائے جاؤ گے،\qt@no{15}}%
\qt@newcmd\qurantrans@ur@mmmmcdlxxxix{اور بیشک ہم نے بنی اسرائیل کو کتاب اور حکومت اور نبوت عطا فرمائی، اور انہیں پاکیزہ چیزوں سے رزق دیا اور ہم نے انہیں (ان کے ہم زمانہ) جہانوں پر (یعنی اس دور کی قوموں اور تہذیبوں پر) فضیلت بخشی،\qt@no{16}}%
\qt@newcmd\qurantrans@ur@mmmmcdxc{اور ہم نے ان کو دین (اور نبوّت) کے واضح دلائل اور نشانیاں دی ہیں مگر اس کے بعد کہ اُن کے پاس (بعثتِ محمدی صلی اللہ علیہ وآلہ وسلم کا) علم آچکا انہوں نے (اس سے) اختلاف کیا محض باہمی حسد و عداوت کے باعث، بیشک آپ کا رب اُن کے درمیان قیامت کے دن اس امر کا فیصلہ فرما دے گا جس میں وہ اختلاف کیا کرتے تھے،\qt@no{17}}%
\qt@newcmd\qurantrans@ur@mmmmcdxci{پھر ہم نے آپ کو دین کے کھلے راستے (شریعت) پر مامور فرما دیا، سو آپ اسی راہ پر چلتے جائیے اور اُن لوگوں کی خواہشوں کو قبول نہ فرمائیے جنہیں (آپ کی اور آپ کے دین کی عظمت و حقّانیت کا) علم ہی نہیں ہے،\qt@no{18}}%
\qt@newcmd\qurantrans@ur@mmmmcdxcii{بیشک یہ لوگ اللہ کی جانب سے (اسلام کی راہ میں پیش آمدہ مشکلات کے وقت میں وعدوں کے باوجود) ہرگز آپ کے کام نہیں آئیں گے، اور بیشک ظالم لوگ (دنیا میں) ایک دوسرے کے ہی دوست اور مددگار ہوا کرتے ہیں، اور اللہ پرہیزگاروں کا دوست اور مددگار ہے،\qt@no{19}}%
\qt@newcmd\qurantrans@ur@mmmmcdxciii{یہ (قرآن) لوگوں کے لئے بصیرت و عبرت کے دلائل ہیں اور یقین رکھنے والوں کے لئے ہدایت اور رحمت ہے،\qt@no{20}}%
\qt@newcmd\qurantrans@ur@mmmmcdxciv{کیا وہ لوگ جنہوں نے برائیاں کما رکھی ہیں یہ گمان کرتے ہیں کہ ہم انہیں اُن لوگوں کی مانند کر دیں گے جو ایمان لائے اور نیک اعمال کرتے رہے (کہ) اُن کی زندگی اور ان کی موت برابر ہو جائے۔ جو دعوٰی (یہ کفّار) کر رہے ہیں نہایت برا ہے،\qt@no{21}}%
\qt@newcmd\qurantrans@ur@mmmmcdxcv{اور اللہ نے آسمانوں اور زمین کو حق (پر مبنی حکمت) کے ساتھ پیدا فرمایا اور اس لئے کہ ہر جان کو اس کے اعمال کا بدلہ دیا جائے جو اس نے کمائے ہیں اور اُن پر ظلم نہیں کیا جائے گا،\qt@no{22}}%
\qt@newcmd\qurantrans@ur@mmmmcdxcvi{کیا آپ نے اس شخص کو دیکھا جس نے اپنی نفسانی خواہش کو معبود بنا رکھا ہے اور اللہ نے اسے علم کے باوجود گمراہ ٹھہرا دیا ہے اور اس کے کان اور اس کے دل پر مُہر لگا دی ہے اور اس کی آنکھ پر پردہ ڈال دیا ہے، پھر اُسے اللہ کے بعد کون ہدایت کر سکتا ہے، سو کیا تم نصیحت قبول نہیں کرتے،\qt@no{23}}%
\qt@newcmd\qurantrans@ur@mmmmcdxcvii{اور وہ کہتے ہیں: ہماری دنیوی زندگی کے سوا (اور) کچھ نہیں ہے ہم (بس) یہیں مرتے اور جیتے ہیں اور ہمیں زمانے کے (حالات و واقعات کے) سوا کوئی ہلاک نہیں کرتا (گویا خدا اور آخرت کا مکمل انکار کرتے ہیں)، اور انہیں اس (حقیقت) کا کچھ بھی علم نہیں ہے، وہ صرف خیال و گمان سے کام لے رہے ہیں،\qt@no{24}}%
\qt@newcmd\qurantrans@ur@mmmmcdxcviii{اور جب اُن پر ہماری واضح آیتیں پڑھ کر سنائی جاتی ہیں تو اس کے سوا اُن کی کوئی دلیل نہیں ہوتی کہ ہمارے باپ دادا کو (زندہ کر کے) لے آؤ، اگر تم سچے ہو،\qt@no{25}}%
\qt@newcmd\qurantrans@ur@mmmmcdxcix{فرما دیجئے: اللہ ہی تمہیں زندگی دیتا ہے اور پھر وہی تمہیں موت دیتا ہے پھر تم سب کو قیامت کے دن کی طرف جمع فرمائے گا جس میں کوئی شک نہیں ہے، لیکن اکثر لوگ نہیں جانتے،\qt@no{26}}%
\qt@newcmd\qurantrans@ur@mmmmd{اور اللہ ہی کے لئے آسمانوں اور زمین کی بادشاہت ہے اور جِس دن قیامت برپا ہوگی تب (سب) اہلِ باطل سخت خسارے میں پڑ جائیں گے،\qt@no{27}}%
\qt@newcmd\qurantrans@ur@mmmmdi{اور آپ دیکھیں گے (کفّار و منکرین کا) ہر گروہ گھٹنوں کے بل گِرا ہوا بیٹھا ہو گا، ہر فرقے کو اس (کے اعمال) کی کتاب کی طرف بلایا جائے گا، آج تمہیں اُن اعمال کا بدلہ دیا جائے گا جو تم کیا کرتے تھے،\qt@no{28}}%
\qt@newcmd\qurantrans@ur@mmmmdii{یہ ہمارا نوشتہ ہے جو تمہارے بارے میں سچ سچ بیان کرے گا، بیشک ہم وہ سب کچھ لکھوا (کر محفوظ کر) لیا کرتے تھے جو تم کرتے تھے،\qt@no{29}}%
\qt@newcmd\qurantrans@ur@mmmmdiii{پس جو لوگ ایمان لائے اور نیک اعمال کرتے رہے تو اُن کا رب انہیں اپنی رحمت میں داخل فرما لے گا، یہی تو واضح کامیابی ہے،\qt@no{30}}%
\qt@newcmd\qurantrans@ur@mmmmdiv{اور جن لوگوں نے کُفر کیا (اُن سے کہا جائے گا:) کیا میری آیتیں تم پر پڑھ پڑھ کر نہیں سنائی جاتی تھیں، پس تم نے تکبّر کیا اور تم مُجرم لوگ تھے،\qt@no{31}}%
\qt@newcmd\qurantrans@ur@mmmmdv{اور جب کہا جاتا تھا کہ اللہ کا وعدہ سچا ہے اور قیامت (کے آنے) میں کوئی شک نہیں ہے تو تم کہتے تھے کہ ہم نہیں جانتے قیامت کیا ہے، ہم اُسے وہم و گمان کے سوا کچھ نہیں سمجھتے اور ہم (اِس پر) یقین کرنے والے نہیں ہیں،\qt@no{32}}%
\qt@newcmd\qurantrans@ur@mmmmdvi{اور اُن کے لئے وہ سب برائیاں ظاہر ہو جائیں گی جو وہ انجام دیتے تھے اور وہ (عذاب) انہیں گھیر لے گا جِس کا وہ مذاق اڑایا کرتے تھے،\qt@no{33}}%
\qt@newcmd\qurantrans@ur@mmmmdvii{اور (اُن سے) کہا جائے گا: آج ہم تمہیں بھلائے دیتے ہیں جِس طرح تم نے اپنے اِس دن کی پیشی کو بھلا دیا تھا اور تمہارا ٹھکانا دوزخ ہے اور تمہارے لئے کوئی بھی مددگار نہ ہوگا،\qt@no{34}}%
\qt@newcmd\qurantrans@ur@mmmmdviii{یہ اس وجہ سے (ہے) کہ تم نے اللہ کی آیتوں کو مذاق بنا رکھا تھا اور دنیوی زندگی نے تمہیں دھوکہ میں ڈال دیا تھا، سو آج نہ تو وہ اُس (دوزخ) سے نکالے جائیں گے اور نہ اُن سے توبہ کے ذریعے (اللہ کی) رضاجوئی قبول کی جائے گی،\qt@no{35}}%
\qt@newcmd\qurantrans@ur@mmmmdix{پس اللہ ہی کے لئے ساری تعریفیں ہیں جو آسمانوں کا رب ہے اور زمین کا مالک ہے، سب جہانوں کا پروردگار (بھی) ہے،\qt@no{36}}%
\qt@newcmd\qurantrans@ur@mmmmdx{اور آسمانوں اور زمین میں ساری کبریائی (یعنی بڑائی) اسی کے لئے ہے اور وہی بڑا غالب بڑی حکمت والا ہے،\qt@no{37}}%
\qt@newcmd\qurantrans@ur@mmmmdxi{\basmalahur حا، میم (حقیقی معنی اﷲ اور رسول صلی اللہ علیہ وآلہ وسلم ہی بہتر جانتے ہیں)،\qt@no{1}}%
\qt@newcmd\qurantrans@ur@mmmmdxii{اس کتاب کا نازل کیا جانا اللہ کی جانب سے ہے جو غالب حکمت والا ہے،\qt@no{2}}%
\qt@newcmd\qurantrans@ur@mmmmdxiii{اور ہم نے آسمانوں کو اور زمین کو اور اس (مخلوقات) کو جو ان کے درمیان ہے پیدا نہیں کیا مگر حکمت اور مقررہ مدّت (کے تعیّن) کے ساتھ، اور جنہوں نے کفر کیا ہے انہیں جس چیز سے ڈرایا گیا اسی سے رُوگردانی کرنے والے ہیں،\qt@no{3}}%
\qt@newcmd\qurantrans@ur@mmmmdxiv{آپ فرما دیں کہ مجھے بتاؤ تو کہ جن (بتوں) کی تم اللہ کے سوا عبادت کرتے ہو مجھے دکھاؤ کہ انہوں نے زمین میں کیا چیز تخلیق کی ہے یا (یہ دکھا دو کہ) آسمانوں (کی تخلیق) میں ان کی کوئی شراکت ہے۔ تم میرے پاس اس (قرآن) سے پہلے کی کوئی کتاب یا (اگلوں کے) علم کا کوئی بقیہ حصہ (جو منقول چلا آرہا ہو ثبوت کے طور پر) پیش کرو اگر تم سچے ہو،\qt@no{4}}%
\qt@newcmd\qurantrans@ur@mmmmdxv{اور اس شخص سے بڑھ کر گمراہ کون ہوسکتا ہے جو اللہ کے سوا ایسے (بتوں) کی عبادت کرتا ہے جو قیامت کے دن تک اسے (سوال کا) جواب نہ دے سکیں اور وہ (بت) ان کی دعاء و عبادت سے (ہی) بے خبر ہیں،\qt@no{5}}%
\qt@newcmd\qurantrans@ur@mmmmdxvi{اور جب لوگ (قیامت کے دن) جمع کئے جائیں گے تو وہ (معبودانِ باطلہ) ان کے دشمن ہوں گے اور (اپنی برات کی خاطر) ان کی عبادت سے ہی منکر ہو جائیں گے،\qt@no{6}}%
\qt@newcmd\qurantrans@ur@mmmmdxvii{اور جب ان پر ہماری واضح آیتیں پڑھی جاتی ہیں (تو) جو لوگ کفر کر رہے ہیں حق (یعنی قرآن) کے بارے میں، جبکہ وہ ان کے پاس آچکا، کہتے ہیں: یہ کھلا جادو ہے،\qt@no{7}}%
\qt@newcmd\qurantrans@ur@mmmmdxviii{کیا وہ لوگ (یہ) کہتے ہیں کہ اس (قرآن) کو (پیغمبر نے) گھڑ لیا ہے۔ آپ فرما دیں: اگر اسے میں نے گھڑا ہے تو تم مجھے اللہ (کے عذاب) سے (بچانے کا) کچھ بھی اختیار نہیں رکھتے، اور وہ ان (باتوں) کو خوب جانتا ہے جو تم اس (قرآن) کے بارے میں طعنہ زنی کے طور پر کر رہے ہو۔ وہی (اللہ) میرے اور تمہارے درمیان گواہ کافی ہے، اور وہ بڑا بخشنے والا بہت رحم فرمانے والا ہے،\qt@no{8}}%
\qt@newcmd\qurantrans@ur@mmmmdxix{آپ فرما دیں کہ میں (انسانوں کی طرف) کوئی پہلا رسول نہیں آیا (کہ مجھ سے قبل رسالت کی کوئی مثال ہی نہ ہو) اور میں اَزخود (یعنی محض اپنی عقل و درایت سے) نہیں جانتا کہ میرے ساتھ کیا سلوک کیا جائے گا اور نہ وہ جو تمہارے ساتھ کیا جائے گا، (میرا علم تو یہ ہے کہ) میں صرف اس وحی کی پیروی کرتا ہوں جو میری طرف بھیجی جاتی ہے (وہی مجھے ہر شے کا علم عطا کرتی ہے) اور میں تو صرف (اس علم بالوحی کی بنا پر) واضح ڈر سنانے والا ہوں،\qt@no{9}}%
\qt@newcmd\qurantrans@ur@mmmmdxx{فرما دیجئے: ذرا بتاؤ تو اگر یہ (قرآن) اللہ کی طرف سے ہو اور تم نے اس کا انکار کر دیا ہو اور بنی اسرائیل میں سے ایک گواہ (بھی پہلی آسمانی کتابوں سے) اس جیسی کتاب (کے اترنے کے ذکر) پر گواہی دے پھر وہ (اس پر) ایمان (بھی) لایا ہو اور تم (اس کے باوجود) غرور کرتے رہے (تو تمہارا انجام کیا ہوگا؟)، بیشک اللہ ظالم قوم کو ہدایت نہیں فرماتا،\qt@no{10}}%
\qt@newcmd\qurantrans@ur@mmmmdxxi{اور کافروں نے مومنوں سے کہا: اگر یہ (دینِ محمدی صلی اللہ علیہ وآلہ وسلم) بہتر ہوتا تو یہ لوگ اس کی طرف ہم سے پہلے نہ بڑھتے (ہم خود ہی سب سے پہلے اسے قبول کر لیتے)، اور جب ان (کفار) نے (خود) اس سے ہدایت نہ پائی تو اب کہتے ہیں کہ یہ تو پرانا جھوٹ (اور بہتان) ہے،\qt@no{11}}%
\qt@newcmd\qurantrans@ur@mmmmdxxii{اور اس سے پہلے موسٰی (علیہ السلام) کی کتاب (تورات) پیشوا اور رحمت تھی، اور یہ کتاب (اس کی) تصدیق کرنے والی ہے، عربی زبان میں ہے تاکہ ان لوگوں کو ڈرائے جنہوں نے ظلم کیا ہے اور نیکوکاروں کے لئے خوشخبری ہو،\qt@no{12}}%
\qt@newcmd\qurantrans@ur@mmmmdxxiii{بیشک جن لوگوں نے کہا کہ ہمارا رب اللہ ہے پھر انہوں نے استقامت اختیار کی تو ان پر نہ کوئی خوف ہے اور نہ وہ غمگین ہوں گے،\qt@no{13}}%
\qt@newcmd\qurantrans@ur@mmmmdxxiv{یہی لوگ اہلِ جنت ہیں جو اس میں ہمیشہ رہنے والے ہیں۔ یہ ان اعمال کی جزا ہے جو وہ کیا کرتے تھے،\qt@no{14}}%
\qt@newcmd\qurantrans@ur@mmmmdxxv{اور ہم نے انسان کو اپنے والدین کے ساتھ نیک سلوک کرنے کاحکم فرمایا۔ اس کی ماں نے اس کو تکلیف سے (پیٹ میں) اٹھائے رکھا اور اسے تکلیف کے ساتھ جنا، اور اس کا (پیٹ میں) اٹھانا اور اس کا دودھ چھڑانا (یعنی زمانۂ حمل و رضاعت) تیس ماہ (پر مشتمل) ہے۔ یہاں تک کہ وہ اپنی جوانی کو پہنچ جاتا ہے اور (پھر) چالیس سال (کی پختہ عمر) کو پہنچتا ہے، تو کہتا ہے: اے میرے رب: مجھے توفیق دے کہ میں تیرے اس احسان کا شکر ادا کروں جو تو نے مجھ پر اور میرے والدین پر فرمایا ہے اور یہ کہ میں ایسے نیک اعمال کروں جن سے تو راضی ہو اور میرے لئے میری اولاد میں نیکی اور خیر رکھ دے۔ بیشک میں تیری طرف رجوع کرتا ہوں اور میں یقیناً فرمانبرداروں میں سے ہوں،\qt@no{15}}%
\qt@newcmd\qurantrans@ur@mmmmdxxvi{یہی وہ لوگ ہیں ہم جن کے نیک اعمال قبول کرتے ہیں اوران کی کوتاہیوں سے درگزر فرماتے ہیں، (یہی) اہلِ جنت ہیں۔ یہ سچا وعدہ ہے جو ان سے کیا جا رہا ہے،\qt@no{16}}%
\qt@newcmd\qurantrans@ur@mmmmdxxvii{اور جس نے اپنے والدین سے کہا: تم سے بیزاری ہے، تم مجھے (یہ) وعدہ دیتے ہو کہ میں (قبر سے دوبارہ زندہ کر کے) نکالا جاؤں گا حالانکہ مجھ سے پہلے بہت سی امتیں گزر چکیں۔ اب وہ دونوں (ماں باپ) اللہ سے فریاد کرنے لگے (اور لڑکے سے کہا:) تو ہلاک ہوگا۔ (اے لڑکے!) ایمان لے آ، بیشک اللہ کا وعدہ حق ہے۔ تو وہ (جواب میں) کہتا ہے: یہ (باتیں) اگلے لوگوں کے جھوٹے افسانوں کے سوا (کچھ) نہیں ہیں،\qt@no{17}}%
\qt@newcmd\qurantrans@ur@mmmmdxxviii{یہی وہ لوگ ہیں جن کے بارے میں فرمانِ (عذاب) ثابت ہو چکا ہے بہت سی امتوں میں جو ان سے پہلے گزر چکی ہیں جنّات کی (بھی) اور انسانوں کی (بھی)، بیشک وہ (سب) نقصان اٹھانے والے تھے،\qt@no{18}}%
\qt@newcmd\qurantrans@ur@mmmmdxxix{اور سب کے لئے ان (نیک و بد) اعمال کی وجہ سے جو انہوں نے کئے (جنت و دوزخ میں الگ الگ) درجات مقرر ہیں تاکہ (اﷲ) ان کو ان کے اعمال کا پورا پورا بدلہ دے اور ان پر کوئی ظلم نہیں کیا جائے گا،\qt@no{19}}%
\qt@newcmd\qurantrans@ur@mmmmdxxx{اور جس دن کافر لوگ آتشِ دوزخ کے سامنے پیش کئے جائیں گے (تو ان سے کہا جائے گا:) تم اپنی لذیذ و مرغوب چیزیں اپنی دنیوی زندگی میں ہی حاصل کر چکے اور ان سے (خوب) نفع اندوز بھی ہو چکے۔ پس آج کے دن تمہیں ذلت کے عذاب کی سزا دی جائے گی اس وجہ سے کہ تم زمین میں ناحق تکبر کیا کرتے تھے اور اس وجہ سے (بھی) کہ تم نافرمانی کیا کرتے تھے،\qt@no{20}}%
\qt@newcmd\qurantrans@ur@mmmmdxxxi{اور (اے حبیب!) آپ قومِ عاد کے بھائی (ہود علیہ السلام) کا ذکر کیجئے، جب انہوں نے (عُمان اور مَہرہ کے درمیان یمن کی ایک وادی) اَحقاف میں اپنی قوم کو (اَعمالِ بد کے نتائج سے) ڈرایا حالانکہ اس سے پہلے اور اس کے بعد (بھی کئی) ڈرانے والے (پیغمبر) گزر چکے تھے کہ تم اﷲ کے سوا کسی اور کی پرستش نہ کرنا، مجھے ڈر ہے کہ کہیں تم پر بڑے (ہولناک) دن کا عذاب (نہ) آجائے،\qt@no{21}}%
\qt@newcmd\qurantrans@ur@mmmmdxxxii{وہ کہنے لگے کہ کیا آپ ہمارے پاس اس لئے آئے ہیں کہ ہمیں ہمارے معبودوں سے برگشتہ کر دیں، پس وہ (عذاب) لے آئیں جس سے ہمیں ڈرا رہے ہیں اگر آپ سچوں میں سے ہیں،\qt@no{22}}%
\qt@newcmd\qurantrans@ur@mmmmdxxxiii{انہوں نے کہا کہ (اس عذاب کے وقت کا) علم تو اﷲ ہی کے پاس ہے اور میں تمہیں وہی احکام پہنچا رہا ہوں جو میں دے کر بھیجا گیا ہوں لیکن میں تمہیں دیکھ رہا ہوں کہ تم جاہل لوگ ہو،\qt@no{23}}%
\qt@newcmd\qurantrans@ur@mmmmdxxxiv{پھر جب انہوں نے اس (عذاب) کو بادل کی طرح اپنی وادیوں کے سامنے آتا ہوا دیکھا تو کہنے لگے: یہ (تو) بادل ہے جو ہم پر برسنے والا ہے، (ایسا نہیں) وہ (بادل) تو وہ (عذاب) ہے جس کی تم نے جلدی مچا رکھی تھی۔ (یہ) آندھی ہے جس میں دردناک عذاب (آرہا) ہے،\qt@no{24}}%
\qt@newcmd\qurantrans@ur@mmmmdxxxv{جو) اپنے پروردگار کے حکم سے ہر شے کو تباہ و برباد کر دے گی پس وہ ایسے (تباہ) ہو گئے کہ ان کے (مِسمار) گھروں کے سوا کچھ نظر ہی نہیں آتا تھا۔ ہم مجرم لوگوں کو اِس طرح سزا دیا کرتے ہیں،\qt@no{25}}%
\qt@newcmd\qurantrans@ur@mmmmdxxxvi{اے اہلِ مکہّ!) درحقیقت ہم نے ان کو ان امور میں طاقت و قدرت دے رکھی تھی جن میں ہم نے تم کو قدرت نہیں دی اور ہم نے انہیں سماعت اور بصارت اور دل و دماغ (کی بے بہا صلاحیتوں) سے نوازا تھا مگر نہ تو ان کے کان ہی ان کے کچھ کام آسکے اور نہ ان کی آنکھیں اور نہ (ہی) ان کے دل و دماغ جبکہ وہ اﷲ کی نشانیوں کا انکار ہی کرتے رہے اور (بالآخر) اس (عذاب) نے انہیں آگھیرا جس کا وہ مذاق اڑایا کرتے تھے،\qt@no{26}}%
\qt@newcmd\qurantrans@ur@mmmmdxxxvii{اور (اے اہلِ مکہّ!) بیشک ہم نے کتنی ہی بستیوں کو ہلاک کر ڈالا جو تمہارے اردگرد تھیں اور ہم نے اپنی نشانیاں بار بار ظاہر کیں تاکہ وہ (کفر سے) رجوع کر لیں،\qt@no{27}}%
\qt@newcmd\qurantrans@ur@mmmmdxxxviii{پھر ان (بتوں) نے ان کی مدد کیوں نہ کی جن کو انہوں نے تقرّبِ (الٰہی) کے لئے اﷲ کے سوا معبود بنا رکھا تھا، بلکہ وہ (معبودانِ باطلہ) ان سے گم ہو گئے، اور یہ (بتوں کو معبود بنانا) ان کا جھوٹ تھا اور یہی وہ بہتان (تھا) جو وہ باندھا کرتے تھے،\qt@no{28}}%
\qt@newcmd\qurantrans@ur@mmmmdxxxix{اور (اے حبیب!) جب ہم نے جنّات کی ایک جماعت کو آپ کی طرف متوجہ کیا جو قرآن غور سے سنتے تھے۔ پھر جب وہ وہاں (یعنی بارگاہِ نبوت میں) حاضر ہوئے تو انہوں نے (آپس میں) کہا: خاموش رہو، پھر جب (پڑھنا) ختم ہو گیا تو وہ اپنی قوم کی طرف ڈر سنانے والے (یعنی داعی الی الحق) بن کر واپس گئے،\qt@no{29}}%
\qt@newcmd\qurantrans@ur@mmmmdxl{انہوں نے کہا: اے ہماری قوم (یعنی اے قومِ جنّات)! بیشک ہم نے ایک (ایسی) کتاب سنی ہے جو موسٰی (علیہ السلام کی تورات) کے بعد اتاری گئی ہے (جو) اپنے سے پہلے (کی کتابوں) کی تصدیق کرنے والی ہے (وہ) سچّے (دین) اور سیدھے راستے کی طرف ہدایت کرتی ہے،\qt@no{30}}%
\qt@newcmd\qurantrans@ur@mmmmdxli{اے ہماری قوم! تم اﷲ کی طرف بلانے والے (یعنی محمد رسول اﷲ صلی اللہ علیہ وآلہ وسلم) کی بات قبول کر لو اور ان پر ایمان لے آؤ (تو) اﷲ تمہارے گناہ بخش دے گا اور تمہیں دردناک عذاب سے پناہ دے گا،\qt@no{31}}%
\qt@newcmd\qurantrans@ur@mmmmdxlii{اور جو شخص اﷲ کی طرف بلانے والے (رسول صلی اللہ علیہ وآلہ وسلم) کی بات قبول نہیں کرے گا تو وہ زمین میں (بھاگ کر اﷲ کو) عاجز نہیں کر سکے گا اور نہ ہی اس کے لئے اﷲ کے سوا کوئی مددگار ہوں گے۔ یہی لوگ کھلی گمراہی میں ہیں،\qt@no{32}}%
\qt@newcmd\qurantrans@ur@mmmmdxliii{کیا وہ نہیں جانتے کہ اﷲ جس نے آسمانوں اور زمین کو پیدا فرمایا اور وہ ان کے پیدا کرنے سے تھکا نہیں اس بات پر (بھی) قادر ہے کہ وہ مُردوں کو (دوبارہ) زندہ فرما دے۔ کیوں نہیں! بیشک وہ ہر چیز پر قدرت رکھتا ہے،\qt@no{33}}%
\qt@newcmd\qurantrans@ur@mmmmdxliv{اور جس دن وہ لوگ جنہوں نے کفر کیا آتشِ دوزخ کے سامنے پیش کئے جائیں گے (تو ان سے کہا جائے گا:) کیا یہ (عذاب) برحق نہیں ہے؟ وہ کہیں گے: کیوں نہیں! ہمارے رب کی قسم (برحق ہے)، ارشاد ہوگا: پھر عذاب کا مزہ چکھو جس کا تم انکار کیا کرتے تھے،\qt@no{34}}%
\qt@newcmd\qurantrans@ur@mmmmdxlv{اے حبیب!) پس آپ صبر کئے جائیں جس طرح (دوسرے) عالی ہمّت پیغمبروں نے صبر کیا تھا اور آپ ان (منکروں) کے لئے (طلبِ عذاب میں) جلدی نہ فرمائیں، جس دن وہ اس (عذابِ آخرت) کو دیکھیں گے جس کا ان سے وعدہ کیا جا رہا ہے تو (خیال کریں گے) گویا وہ (دنیا میں) دن کی ایک گھڑی کے سوا ٹھہرے ہی نہیں تھے، (یہ اﷲ کی طرف سے) پیغام کا پہنچایا جانا ہے، نافرمان قوم کے سوا دیگر لوگ ہلاک نہیں کئے جائیں گے،\qt@no{35}}%
\qt@newcmd\qurantrans@ur@mmmmdxlvi{\basmalahur جن لوگوں نے کفر کیا اور (دوسروں کو) اﷲ کی راہ سے روکا (تو) اﷲ نے ان کے اعمال (اخروی اجر کے لحاظ سے) برباد کر دیئے،\qt@no{1}}%
\qt@newcmd\qurantrans@ur@mmmmdxlvii{اور جو لوگ ایمان لائے اور نیک عمل کرتے رہے اور اس (کتاب) پر ایمان لائے جو محمد (صلی اللہ علیہ وآلہ وسلم) پر نازل کی گئی ہے اور وہی ان کے رب کی جانب سے حق ہے اﷲ نے ان کے گناہ ان (کے نامۂ اعمال) سے مٹا دیئے اور ان کا حال سنوار دیا،\qt@no{2}}%
\qt@newcmd\qurantrans@ur@mmmmdxlviii{یہ اس لئے کہ جن لوگوں نے کفر کیا وہ باطل کے پیچھے چلے اور جو لوگ ایمان لائے انہوں نے اپنے رب کی طرف سے (اتارے گئے) حق کی پیروی کی، اسی طرح اﷲ لوگوں کے لئے ان کے احوال بیان فرماتا ہے،\qt@no{3}}%
\qt@newcmd\qurantrans@ur@mmmmdxlix{پھر جب (میدان جنگ میں) تمہارا مقابلہ (متحارب) کافروں سے ہو تو (دورانِ جنگ) ان کی گردنیں اڑا دو، یہاں تک کہ جب تم انہیں (جنگی معرکہ میں) خوب قتل کر چکو تو (بقیہ قیدیوں کو) مضبوطی سے باندھ لو، پھر اس کے بعد یا تو (انہیں) (بلامعاوضہ) احسان کر کے (چھوڑ دو) یا فدیہ (یعنی معاوضہِء رہائی) لے کر (آزاد کر دو) یہاں تک کہ جنگ (کرنے والی مخالف فوج) اپنے ہتھیار رکھ دے (یعنی صلح و امن کا اعلان کر دے)۔ یہی (حکم) ہے، اور اگر اﷲ چاہتا تو ان سے (بغیر جنگ) انتقام لے لیتا مگر (اس نے ایسا نہیں کیا) تاکہ تم میں سے بعض کو بعض کے ذریعے آزمائے، اور جو لوگ اﷲ کی راہ میں قتل کر دیئے گئے تو وہ ان کے اعمال کو ہرگز ضائع نہ کرے گا،\qt@no{4}}%
\qt@newcmd\qurantrans@ur@mmmmdl{وہ عنقریب انہیں (جنت کی) سیدھی راہ پر ڈال دے گا اور ان کے احوالِ (اُخروی) کو خوب بہتر کر دے گا،\qt@no{5}}%
\qt@newcmd\qurantrans@ur@mmmmdli{اور (بالآخر) انہیں جنت میں داخل فرما دے گا جس کی اس نے (پہلے ہی سے) انہیں خوب پہچان کرا دی ہے،\qt@no{6}}%
\qt@newcmd\qurantrans@ur@mmmmdlii{اے ایمان والو! اگر تم اﷲ (کے دین) کی مدد کرو گے تو وہ تمہاری مدد فرمائے گا اور تمہارے قدموں کو مضبوط رکھے گا،\qt@no{7}}%
\qt@newcmd\qurantrans@ur@mmmmdliii{اور جنہوں نے کفر کیا تو ان کے لئے ہلاکت ہے اور (اﷲ نے) ان کے اعمال برباد کر دیئے،\qt@no{8}}%
\qt@newcmd\qurantrans@ur@mmmmdliv{یہ اس وجہ سے کہ انہوں نے اس (کتاب) کو ناپسند کیا جو اﷲ نے نازل فرمائی تو اس نے ان کے اعمال اکارت کر دیئے،\qt@no{9}}%
\qt@newcmd\qurantrans@ur@mmmmdlv{کیا انہوں نے زمین میں سفر و سیاحت نہیں کی کہ وہ دیکھ لیتے کہ ان لوگوں کا انجام کیسا ہوا جو ان سے پہلے تھے۔ اﷲ نے ان پر ہلاکت و بربادی ڈال دی۔ اور کافروں کے لئے اسی طرح کی بہت سی ہلاکتیں ہیں،\qt@no{10}}%
\qt@newcmd\qurantrans@ur@mmmmdlvi{یہ اس وجہ سے ہے کہ اﷲ ان لوگوں کا ولی و مددگار ہے جو ایمان لائے ہیں اور بیشک کافروں کے لئے کوئی ولی و مددگار نہیں ہے،\qt@no{11}}%
\qt@newcmd\qurantrans@ur@mmmmdlvii{بیشک اﷲ ان لوگوں کو جو ایمان لائے اور نیک اعمال کرتے رہے بہشتوں میں داخل فرمائے گا جن کے نیچے نہریں جاری ہوں گی، اور جن لوگوں نے کفر کیا اور (دنیوی) فائدے اٹھا رہے ہیں اور (اس طرح) کھا رہے ہیں جیسے چوپائے (جانور) کھاتے ہیں سو دوزخ ہی ان کا ٹھکانا ہے،\qt@no{12}}%
\qt@newcmd\qurantrans@ur@mmmmdlviii{اور (اے حبیب!) کتنی ہی بستیاں تھیں جن کے باشندے (وسائل و اقتدار میں) آپ کے اس شہر (مکّہ کے باشندوں) سے زیادہ طاقتور تھے جس (کے مقتدر وڈیروں) نے آپ کو (بصورتِ ہجرت) نکال دیا ہے، ہم نے انہیں (بھی) ہلاک کر ڈالا پھر ان کا کوئی مددگار نہ ہوا (جو انہیں بچا سکتا)،\qt@no{13}}%
\qt@newcmd\qurantrans@ur@mmmmdlix{سو کیا وہ شخص جو اپنے رب کی طرف سے واضح دلیل پر (قائم) ہو ان لوگوں کی مثل ہو سکتا ہے جن کے برے اعمال ان کے لئے آراستہ کر کے دکھائے گئے ہیں اور وہ اپنی نفسانی خواہشات کے پیچھے چل رہے ہوں،\qt@no{14}}%
\qt@newcmd\qurantrans@ur@mmmmdlx{جس جنّت کا پرہیزگاروں سے وعدہ کیا گیا ہے اس کی صفت یہ ہے کہ اس میں (ایسے) پانی کی نہریں ہوں گی جس میں کبھی (بو یا رنگت کا) تغیّر نہ آئے گا، اور (اس میں ایسے) دودھ کی نہریں ہوں گی جس کا ذائقہ اور مزہ کبھی نہ بدلے گا، اور (ایسے) شرابِ (طہور) کی نہریں ہوں گی جو پینے والوں کے لئے سراسر لذّت ہے، اور خوب صاف کئے ہوئے شہد کی نہریں ہوں گی، اور ان کے لئے اس میں ہر قسم کے پھل ہوں گے اور ان کے رب کی جانب سے (ہر طرح کی) بخشائش ہوگی، (کیا یہ پرہیزگار) ان لوگوں کی طرح ہو سکتا ہے جو ہمیشہ دوزخ میں رہنے والے ہیں اور جنہیں کھولتا ہوا پانی پلایا جائے گا تو وہ ان کی آنتوں کو کاٹ کر ٹکڑے ٹکڑے کر دے گا،\qt@no{15}}%
\qt@newcmd\qurantrans@ur@mmmmdlxi{اور ان میں سے بعض وہ لوگ بھی ہیں جو آپ کی طرف (دل اور دھیان لگائے بغیر) صرف کان لگائے سنتے رہتے ہیں یہاں تک کہ جب وہ آپ کے پاس سے نکل کر (باہر) جاتے ہیں تو ان لوگوں سے پوچھتے ہیں جنہیں علمِ (نافع) عطا کیا گیا ہے کہ ابھی انہوں نے (یعنی رسول اﷲ صلی اللہ علیہ وآلہ وسلم نے) کیا فرمایا تھا؟ یہی وہ لوگ ہیں جن کے دلوں پر اﷲ نے مہر لگا دی ہے اور وہ اپنی خواہشات کی پیروی کر رہے ہیں،\qt@no{16}}%
\qt@newcmd\qurantrans@ur@mmmmdlxii{اور جن لوگوں نے ہدایت پا لی ہے، اﷲ ان کی ہدایت کو اور زیادہ فرما دیتا ہے اور انہیں ان کے مقامِ تقوٰی سے سرفراز فرماتا ہے،\qt@no{17}}%
\qt@newcmd\qurantrans@ur@mmmmdlxiii{تو اب یہ (منکر) لوگ صرف قیامت ہی کا انتظار کر رہے ہیں کہ وہ ان پر اچانک آپہنچے؟ سو واقعی اس کی نشانیاں (قریب) آپہنچی ہیں، پھر انہیں ان کی نصیحت کہاں (مفید) ہوگی جب (خود) قیامت (ہی) آپہنچے گے،\qt@no{18}}%
\qt@newcmd\qurantrans@ur@mmmmdlxiv{پس جان لیجئے کہ اﷲ کے سوا کوئی معبود نہیں اور آپ (اظہارِ عبودیت اور تعلیمِ امت کی خاطر اﷲ سے) معافی مانگتے رہا کریں کہ کہیں آپ سے خلافِ اولیٰ (یعنی آپ کے مرتبہ عالیہ سے کم درجہ کا) فعل صادر نہ ہو جائے٭ اور مومن مردوں اور مومن عورتوں کے لئے بھی طلبِ مغفرت (یعنی ان کی شفاعت) فرماتے رہا کریں (یہی ان کا سامانِ بخشش ہے)، اور (اے لوگو!) اﷲ (دنیا میں) تمہارے چلنے پھرنے کے ٹھکانے اور (آخرت میں) تمہارے ٹھہرنے کی منزلیں (سب) جانتا ہے، ٭ (خواہ وہ فعل اپنی جگہ شرعاً جائز اور مستحسن ہی کیوں نہ ہو مگر آپ صلی اللہ علیہ وآلہ وسلم کا مقام و مرتبہ اتنا بلند اور ارفع و اعلٰی ہے کہ کئی اعمال صالحہ بھی آپ صلی اللہ علیہ وآلہ وسلم کی شان کے لحاظ سے کمتر ہیں۔)\qt@no{19}}%
\qt@newcmd\qurantrans@ur@mmmmdlxv{اور ایمان والے کہتے ہیں کہ (حکمِ جہاد سے متعلق) کوئی سورت کیوں نہیں اتاری جاتی؟ پھر جب کوئی واضح سورت نازل کی جاتی ہے اور اس میں (صریحاً) جہاد کا ذکر کیا جاتا ہے تو آپ ایسے لوگوں کو جن کے دلوں میں (نفاق کی) بیماری ہے ملاحظہ فرماتے ہیں کہ وہ آپ کی طرف (اس طرح) دیکھتے ہیں جیسے وہ شخص دیکھتا ہے جس پر موت کی غشی طاری ہو رہی ہو۔ سو ان کے لئے خرابی ہے،\qt@no{20}}%
\qt@newcmd\qurantrans@ur@mmmmdlxvi{فرمانبرداری اور اچھی گفتگو (ان کے حق میں بہتر) ہے، پھر جب حکمِ جہاد قطعی (اور پختہ) ہو گیا تو اگر وہ اﷲ سے (اپنی اطاعت اور وفاداری میں) سچے رہتے تو ان کے لئے بہتر ہوتا،\qt@no{21}}%
\qt@newcmd\qurantrans@ur@mmmmdlxvii{پس (اے منافقو!) تم سے توقع یہی ہے کہ اگر تم (قتال سے گریز کر کے بچ نکلو اور) حکومت حاصل کر لو تو تم زمین میں فساد ہی برپا کرو گے اور اپنے (ان) قرابتی رشتوں کو توڑ ڈالو گے (جن کے بارے میں اﷲ اور اس کے رسول صلی اللہ علیہ وآلہ وسلم نے مواصلت اور مُودّت کا حکم دیا ہے)،\qt@no{22}}%
\qt@newcmd\qurantrans@ur@mmmmdlxviii{یہی وہ لوگ ہیں جن پر اﷲ نے لعنت کی ہے اور ان (کے کانوں) کو بہرا کر دیا ہے اور ان کی آنکھوں کو اندھا کر دیا ہے،\qt@no{23}}%
\qt@newcmd\qurantrans@ur@mmmmdlxix{کیا یہ لوگ قرآن میں غور نہیں کرتے یا ان کے دلوں پر تالے (لگے ہوئے) ہیں،\qt@no{24}}%
\qt@newcmd\qurantrans@ur@mmmmdlxx{بیشک جو لوگ پیٹھ پھیر کر پیچھے (کفر کی طرف) لوٹ گئے اس کے بعد کہ ان پر ہدایت واضح ہو چکی تھی شیطان نے انہیں (کفر کی طرف واپس پلٹنا دھوکہ دہی سے) اچھا کر کے دکھایا، اور انہیں (دنیا میں) طویل زندگی کی امید دلائی،\qt@no{25}}%
\qt@newcmd\qurantrans@ur@mmmmdlxxi{یہ اس لئے کہ انہوں نے ان لوگوں سے کہا جو اﷲ کی نازل کردہ کتاب کو ناپسند کرتے تھے کہ ہم بعض امور میں تمہاری پیروی کریں گے، اور اﷲ ان کے خفیہ مشورہ کرنے کو خوب جانتا ہے،\qt@no{26}}%
\qt@newcmd\qurantrans@ur@mmmmdlxxii{پھر (اس وقت ان کا حشر) کیسا ہوگا جب فرشتے ان کی جان (اس حال میں) نکالیں گے کہ ان کے چہروں اور ان کی پیٹھوں پر ضربیں لگاتے ہوں گے،\qt@no{27}}%
\qt@newcmd\qurantrans@ur@mmmmdlxxiii{یہ اس وجہ سے ہے کہ انہوں نے اُس (رَوِش) کی پیروی کی جو اﷲ کو ناراض کرتی ہے اور انہوں نے اس کی رضا کو ناپسند کیا تو اس نے ان کے (جملہ) اعمال اکارت کر دیئے،\qt@no{28}}%
\qt@newcmd\qurantrans@ur@mmmmdlxxiv{کیا وہ لوگ جن کے دلوں میں (نفاق کی) بیماری ہے یہ گمان کرتے ہیں کہ اﷲ ان کے کینوں اور عداوتوں کو ہرگز ظاہر نہ فرمائے گا،\qt@no{29}}%
\qt@newcmd\qurantrans@ur@mmmmdlxxv{اور اگر ہم چاہیں تو آپ کو بلاشبہ وہ (منافق) لوگ (اس طرح) دکھا دیں کہ آپ انہیں ان کے چہروں کی علامت سے ہی پہچان لیں، اور (اسی طرح) یقیناً آپ ان کے اندازِ کلام سے بھی انہیں پہچان لیں گے، اور اﷲ تمہارے سب اعمال کو (خوب) جانتا ہے،\qt@no{30}}%
\qt@newcmd\qurantrans@ur@mmmmdlxxvi{اور ہم ضرور تمہاری آزمائش کریں گے یہاں تک کہ تم میں سے (ثابت قدمی کے ساتھ) جہاد کرنے والوں اور صبر کرنے والوں کو (بھی) ظاہر کر دیں اور تمہاری (منافقانہ بزدلی کی مخفی) خبریں (بھی) ظاہر کر دیں،\qt@no{31}}%
\qt@newcmd\qurantrans@ur@mmmmdlxxvii{بیشک جن لوگوں نے کفر کیا اور (لوگوں کو) اﷲ کی راہ سے روکا اور رسول (صلی اللہ علیہ وآلہ وسلم) کی مخالفت (اور ان سے جدائی کی راہ اختیار) کی اس کے بعد کہ ان پر ہدایت (یعنی عظمتِ رسول صلی اللہ علیہ وآلہ وسلم کی معرفت) واضح ہو چکی تھی وہ اللہ کا ہرگز کچھ نقصان نہیں کر سکیں گے (یعنی رسول صلی اللہ علیہ وآلہ وسلم کی قدر و منزلت کو گھٹا نہیں سکیں گے)، ٭ اور اﷲ ان کے (سارے) اعمال کو (مخالفتِ رسول صلی اللہ علیہ وآلہ وسلم کے باعث) نیست و نابود کر دے گا، ٭ تمام ائمہ تفسیر نے لکھا ہے: (لَن يَضُرُوا اللّہَ شَيْئًا) أی: لن یضرّوا رسولَ اﷲ صلی اللہ علیہ وآلہ وسلم بمشاقتہ و حذف المضاف لتعظیم شانہ۔ ملاحظہ فرمائیں: الطبری، البیضاوی، روح المعانی، روح البیان، الجمل، البحر المدید وغیرہ۔ اس اُسلوبِ کلام کی مثالیں قرآن مجید میں بہت ہیں جن میں سے ایک سورۃ البقرۃ کی آیت ۹: (یُخٰدِعُونَ اﷲَ وَالّذِینَ آمَنُوا) ہے۔ اس مقام پر یخٰدعون اﷲ (وہ اللہ کو دھوکہ دینا چاہتے ہیں) کہہ کر مراد یُخٰدِعُونَ رَسُولَ اﷲِ (وہ اللہ کے رسول صلی اللہ علیہ وآلہ وسلم کو دھوکہ دینا چاہتے ہیں) لیا گیا ہے۔\qt@no{32}}%
\qt@newcmd\qurantrans@ur@mmmmdlxxviii{اے ایمان والو! تم اﷲ کی اطاعت کیا کرو اور رسول (صلی اللہ علیہ وآلہ وسلم) کی اطاعت کیا کرو اور اپنے اعمال برباد مت کرو،\qt@no{33}}%
\qt@newcmd\qurantrans@ur@mmmmdlxxix{بیشک جن لوگوں نے کفر کیا اور (لوگوں کو) اﷲ کی راہ سے روکا پھر اس حال میں مر گئے کہ وہ کافر تھے تو اﷲ انہیں کبھی نہ بخشے گا،\qt@no{34}}%
\qt@newcmd\qurantrans@ur@mmmmdlxxx{اے مومنو!) پس تم ہمت نہ ہارو اور ان (متحارب کافروں) سے صلح کی درخواست نہ کرو (کہیں تمہاری کمزوری ظاہر نہ ہو)، اور تم ہی غالب رہو گے، اور اﷲ تمہارے ساتھ ہے اور وہ تمہارے اعمال (کا ثواب) ہرگز کم نہ کرے گا،\qt@no{35}}%
\qt@newcmd\qurantrans@ur@mmmmdlxxxi{بس دنیا کی زندگی تو محض کھیل اور تماشا ہے، اور اگر تم ایمان لے آؤ اور تقوٰی اختیار کرو تو وہ تمہیں تمہارے (اعمال پر کامل) ثواب عطا فرمائے گا اور تم سے تمہارے مال طلب نہیں کرے گا،\qt@no{36}}%
\qt@newcmd\qurantrans@ur@mmmmdlxxxii{اگر وہ تم سے اس مال کو طلب کر لے پھر تمہیں طلب میں تنگی دے تو تمہیں (دل میں) تنگی محسوس ہوگی (اور) تم بخل کرو گے اور (اس طرح) وہ تمہارے (دنیا پرستی کے باعث باطنی) زنگ ظاہر کر دے گا،\qt@no{37}}%
\qt@newcmd\qurantrans@ur@mmmmdlxxxiii{یاد رکھو! تم وہ لوگ ہو جنہیں اﷲ کی راہ میں خرچ کرنے کے لئے بلایا جاتا ہے تو تم میں سے بعض ایسے بھی ہیں جو بُخل کرتے ہیں، اور جو کوئی بھی بُخل کرتا ہے وہ محض اپنی جان ہی سے بخل کرتا ہے، اور اﷲ بے نیاز ہے اور تم (سب) محتاج ہو، اور اگر تم (حکمِ الٰہی سے) رُوگردانی کرو گے تو وہ تمہاری جگہ بدل کر دوسری قوم کو لے آئے گا پھر وہ تمہارے جیسے نہ ہوں گے،\qt@no{38}}%
\qt@newcmd\qurantrans@ur@mmmmdlxxxiv{\basmalahur (اے حبیبِ مکرم!) بیشک ہم نے آپ کے لئے (اسلام کی) روشن فتح (اور غلبہ) کا فیصلہ فرما دیا (اس لئے کہ آپ کی عظیم جدّ و جہد کامیابی کے ساتھ مکمل ہوجائے)،\qt@no{1}}%
\qt@newcmd\qurantrans@ur@mmmmdlxxxv{تاکہ آپ کی خاطر اللہ آپ کی امت (کے اُن تمام اَفراد) کی اگلی پچھلی خطائیں معاف فرما دے٭ (جنہوں نے آپ کے حکم پر جہاد کیے اور قربانیاں دیں) اور (یوں اسلام کی فتح اور امت کی بخشش کی صورت میں) آپ پر اپنی نعمت (ظاہراً و باطناً) پوری فرما دے اور آپ (کے واسطے سے آپ کی امت) کو سیدھے راستہ پر ثابت قدم رکھے، ٭ یہاں حذفِ مضاف واقع ہوا ہے۔ مراد ”ما تقدم من ذنب أمتک و ما تاخر“ ہے، کیونکہ آگے اُمت ہی کے لئے نزولِ سکینہ، دخولِ جنت اور بخششِ سیئات کی بشارت کا ذکر کیا گیا ہے۔ یہ مضمون آیت نمبر ۱ سے ۵ تک ملا کر پڑھیں تو معنی خود بخود واضح ہو جائے گا؛ اور مزید تفصیل تفسیر میں ملاحظہ فرمائیں۔ جیسا کہ سورۃ المؤمن کی آیت نمبر ۵۵ کے تحت مفسرین کرام نے بیان کیا ہے کہ ”لِذَنبِکَ“ میں ”امت“ مضاف ہے جو کہ محذوف ہے۔ لہٰذا اس بناء پر یہاں وَاستَغفِر لِذَنبِکَ سے مراد امت کے گناہ ہیں۔ امام نسفی، امام قرطبی اور علامہ شوکانی نے یہی معنی بیان کیا ہے۔ حوالہ جات ملاحظہ کریں:-۱: (وَاستَغفِر لِذَنبِکَ) أی لذنب أمتک یعنی اپنی امت کے گناہوں کی بخشش طلب کیجئے۔ (نسفی، مدارک التنزیل و حقائق التاویل، ۴: ۳۵۹)۔۲: (وَاستَغفِر لِذَنبِکَ) قیل: لذنب أمتک حذف المضاف و أقیم المضاف الیہ مقامہ۔ ”واستغفر لذنبک کے بارے میں کہا گیا ہے کہ اس سے مراد امت کے گناہ ہیں۔ یہاں مضاف کو حذف کر کے مضاف الیہ کو اس کا قائم مقام کر دیا گیا۔“ (قرطبی، الجامع لاحکام القرآن، ۱۵: ۳۲۴)۔ ۳: وَ قیل لذنبک لذنب أمتک فی حقک ”یہ بھی کہا گیا ہے کہ لذنبک یعنی آپ اپنے حق میں امت سے سرزد ہونے والی خطاؤں کی بخشش طلب کیجئے۔“ (ابن حیان اندلسی، البحر المحیط، ۷: ۴۷۱)۔ ۴: (وَاستَغفِر لِذَنبِکَ) قیل: المراد ذنب أمتک فھو علی حذف المضاف ”کہا گیا ہے کہ اس سے مراد امت کے گناہ ہیں اور یہ معنی مضاف کے محذوف ہونے کی بناء پر ہے۔“ (علامہ شوکانی، فتح القدیر، ۴: ۴۹۷)۔\qt@no{2}}%
\qt@newcmd\qurantrans@ur@mmmmdlxxxvi{اور اﷲ آپ کو نہایت باعزت مدد و نصرت سے نوازے،\qt@no{3}}%
\qt@newcmd\qurantrans@ur@mmmmdlxxxvii{وہی ہے جس نے مومنوں کے دلوں میں تسکین نازل فرمائی تاکہ ان کے ایمان پر مزید ایمان کا اضافہ ہو (یعنی علم الیقین، عین الیقین میں بدل جائے)، اور آسمانوں اور زمین کے سارے لشکر اﷲ ہی کے لئے ہیں، اور اﷲ خوب جاننے والا، بڑی حکمت والا ہے،\qt@no{4}}%
\qt@newcmd\qurantrans@ur@mmmmdlxxxviii{یہ سب نعمتیں اس لئے جمع کی ہیں) تاکہ وہ مومن مردوں اور مومن عورتوں کو بہشتوں میں داخل فرمائے جن کے نیچے نہریں رواں ہیں (وہ) ان میں ہمیشہ رہنے والے ہیں۔ اور (مزید یہ کہ) وہ ان کی لغزشوں کو (بھی) ان سے دور کر دے (جیسے اس نے ان کی خطائیں معاف کی ہیں)۔ اور یہ اﷲ کے نزدیک (مومنوں کی) بہت بڑی کامیابی ہے،\qt@no{5}}%
\qt@newcmd\qurantrans@ur@mmmmdlxxxix{اور (اس لئے بھی کہ ان) منافق مردوں اور منافق عورتوں اور مشرک مردوں اور مشرک عورتوں کو عذاب دے جو اﷲ کے ساتھ بُری بدگمانیاں رکھتے ہیں، انہی پر بُری گردش (مقرر) ہے، اور ان پر اﷲ نے غضب فرمایا اور ان پر لعنت فرمائی اور ان کے لئے دوزخ تیار کی، اور وہ بہت بُرا ٹھکانا ہے،\qt@no{6}}%
\qt@newcmd\qurantrans@ur@mmmmdxc{اور آسمانوں اور زمین کے سب لشکر اﷲ ہی کے لئے ہیں، اور اﷲ بڑا غالب بڑی حکمت والا ہے،\qt@no{7}}%
\qt@newcmd\qurantrans@ur@mmmmdxci{بیشک ہم نے آپ کو (روزِ قیامت گواہی دینے کے لئے اعمال و احوالِ امت کا) مشاہدہ فرمانے والا اور خوشخبری سنانے والا اور ڈر سنانے والا بنا کر بھیجا ہے،\qt@no{8}}%
\qt@newcmd\qurantrans@ur@mmmmdxcii{تاکہ (اے لوگو!) تم اﷲ اور اس کے رسول پر ایمان لاؤ اور ان (کے دین) کی مدد کرو اور ان کی بے حد تعظیم و تکریم کرو، اور (ساتھ) اﷲ کی صبح و شام تسبیح کرو،\qt@no{9}}%
\qt@newcmd\qurantrans@ur@mmmmdxciii{اے حبیب!) بیشک جو لوگ آپ سے بیعت کرتے ہیں وہ اﷲ ہی سے بیعت کرتے ہیں، ان کے ہاتھوں پر (آپ کے ہاتھ کی صورت میں) اﷲ کا ہاتھ ہے۔ پھر جس شخص نے بیعت کو توڑا تو اس کے توڑنے کا وبال اس کی اپنی جان پر ہوگا اور جس نے (اس) بات کو پورا کیا جس (کے پورا کرنے) پر اس نے اﷲ سے عہد کیا تھا تو وہ عنقریب اسے بہت بڑا اجر عطا فرمائے گا،\qt@no{10}}%
\qt@newcmd\qurantrans@ur@mmmmdxciv{عنقریب دیہاتیوں میں سے وہ لوگ جو (حدیبیہ میں شرکت سے) پیچھے رہ گئے تھے آپ سے (معذرۃً یہ) کہیں گے کہ ہمارے اموال اور اہل و عیال نے ہمیں مشغول کر رکھا تھا (اس لئے ہم آپ کی معیت سے محروم رہ گئے) سو آپ ہمارے لئے بخشش طلب کریں۔ یہ لوگ اپنی زبانوں سے وہ (باتیں) کہتے ہیں جو ان کے دلوں میں نہیں ہیں۔ آپ فرما دیں کہ کون ہے جو تمہیں اﷲ کے (فیصلے کے) خلاف بچانے کا اختیار رکھتا ہو اگر اس نے تمہارے نقصان کا ارادہ فرما لیا ہو یا تمہارے نفع کا ارادہ فرما لیا ہو، بلکہ اﷲ تمہارے کاموں سے اچھی طرح باخبر ہے،\qt@no{11}}%
\qt@newcmd\qurantrans@ur@mmmmdxcv{بلکہ تم نے یہ گمان کیا تھا کہ رسول (صلی اللہ علیہ وآلہ وسلم) اور اہلِ ایمان (یعنی صحابہ رضی اللہ عنھم) اب کبھی بھی پلٹ کر اپنے گھر والوں کی طرف نہیں آئیں گے اور یہ (گمان) تمہارے دلوں میں (تمہارے نفس کی طرف سے) خُوب آراستہ کر دیا گیا تھا اور تم نے بہت ہی برا گمان کیا، اور تم ہلاک ہونے والی قوم بن گئے،\qt@no{12}}%
\qt@newcmd\qurantrans@ur@mmmmdxcvi{اور جو اﷲ اور اس کے رسول (صلی اللہ علیہ وآلہ وسلم) پر ایمان نہ لائے تو ہم نے کافروں کے لئے دوزخ تیار کر رکھی ہے،\qt@no{13}}%
\qt@newcmd\qurantrans@ur@mmmmdxcvii{اور آسمانوں اور زمین کی باشاہت اﷲ ہی کے لئے ہے، وہ جسے چاہتا ہے بخش دیتا ہے اور جسے چاہتا ہے عذاب دیتا ہے، اور اﷲ بڑا بخشنے والا بے حد رحم فرمانے والا ہے،\qt@no{14}}%
\qt@newcmd\qurantrans@ur@mmmmdxcviii{جب تم (خیبر کے) اَموالِ غنیمت کو حاصل کرنے کی طرف چلو گے تو (سفرِ حدیبیہ میں) پیچھے رہ جانے والے لوگ کہیں گے: ہمیں بھی اجازت دو کہ ہم تمہارے پیچھے ہو کر چلیں۔ وہ چاہتے ہیں کہ اﷲ کے فرمان کو بدل دیں۔ فرما دیجئے: تم ہرگز ہمارے پیچھے نہیں آسکتے اسی طرح اﷲ نے پہلے سے فرما دیا تھا۔ سو اب وہ کہیں گے: بلکہ تم ہم سے حسد کرتے ہو، بات یہ ہے کہ یہ لوگ (حق بات کو) بہت ہی کم سمجھتے ہیں،\qt@no{15}}%
\qt@newcmd\qurantrans@ur@mmmmdxcix{آپ دیہاتیوں میں سے پیچھے رہ جانے والوں سے فرما دیں کہ تم عنقریب ایک سخت جنگ جو قوم (سے جہاد) کی طرف بلائے جاؤ گے تم ان سے جنگ کرتے رہو گے یا وہ مسلمان ہو جائیں گے، سو اگر تم حکم مان لوگے تو اﷲ تمہیں بہترین اجر عطا فرمائے گا۔ اور اگر تم رُوگردانی کرو گے جیسے تم نے پہلے رُوگردانی کی تھی تو وہ تمہیں دردناک عذاب میں مبتلا کر دے گا،\qt@no{16}}%
\qt@newcmd\qurantrans@ur@mmmmdc{جہاد سے رہ جانے میں) نہ اندھے پر کوئی گناہ ہے اور نہ لنگڑے پر کوئی گناہ ہے اور نہ (ہی) بیمار پر کوئی گناہ ہے، اور جو شخص اﷲ اور اس کے رسول (صلی اللہ علیہ وآلہ وسلم) کی اطاعت کرے گا وہ اسے بہشتوں میں داخل فرما دے گا جن کے نیچے نہریں رواں ہوں گی، اور جو شخص (اطاعت سے) منہ پھیرے گا وہ اسے درد ناک عذاب میں مبتلا کردے گا،\qt@no{17}}%
\qt@newcmd\qurantrans@ur@mmmmdci{بیشک اﷲ مومنوں سے راضی ہو گیا جب وہ (حدیبیہ میں) درخت کے نیچے آپ سے بیعت کر رہے تھے، سو جو (جذبۂ صِدق و وفا) ان کے دلوں میں تھا اﷲ نے معلوم کر لیا تو اﷲ نے ان (کے دلوں) پر خاص تسکین نازل فرمائی اور انہیں ایک بہت ہی قریب فتحِ (خیبر) کا انعام عطا کیا،\qt@no{18}}%
\qt@newcmd\qurantrans@ur@mmmmdcii{اور بہت سے اموالِ غنیمت (بھی) جو وہ حاصل کر رہے ہیں، اور اﷲ بڑا غالب بڑی حکمت والا ہے،\qt@no{19}}%
\qt@newcmd\qurantrans@ur@mmmmdciii{اور اﷲ نے (کئی فتوحات کے نتیجے میں) تم سے بہت سی غنیمتوں کا وعدہ فرمایا ہے جو تم آئندہ حاصل کرو گے مگر اس نے یہ (غنیمتِ خیبر) تمہیں جلدی عطا فرما دی اور (اہلِ مکہّ، اہلِ خیبر، قبائل بنی اسد و غطفان الغرض تمام دشمن) لوگوں کے ہاتھ تم سے روک دیئے، اور تاکہ یہ مومنوں کے لئے (آئندہ کی کامیابی و فتح یابی کی) نشانی بن جائے۔ اور تمہیں (اطمینانِ قلب کے ساتھ) سیدھے راستہ پر (ثابت قدم اور)گامزن رکھے،\qt@no{20}}%
\qt@newcmd\qurantrans@ur@mmmmdciv{اور دوسری (مکّہ، ہوازن اور حنین سے لے کر فارس اور روم تک کی بڑی فتوحات) جن پر تم قادر نہ تھے بیشک اﷲ نے (تمہارے لئے) ان کا بھی احاطہ فرما لیا ہے، اور اﷲ ہر چیز پر بڑی قدرت رکھنے والا ہے،\qt@no{21}}%
\qt@newcmd\qurantrans@ur@mmmmdcv{اور (اے مومنو!) اگر کافر لوگ (حدیبیہ میں) تم سے جنگ کرتے تو وہ ضرور پیٹھ پھیر کر بھاگ جاتے، پھر وہ نہ کوئی دوست پاتے اور نہ مددگار (مگر اﷲ کو صرف یہ ایک ہی نہیں بلکہ کئی فتوحات کا دروازہ تمہارے لئے کھولنا مقصود تھا)،\qt@no{22}}%
\qt@newcmd\qurantrans@ur@mmmmdcvi{یہ) اﷲ کی سنت ہے جو پہلے سے چلی آرہی ہے، اور آپ اﷲ کے دستور میں ہرگز کوئی تبدیلی نہیں پائیں گے،\qt@no{23}}%
\qt@newcmd\qurantrans@ur@mmmmdcvii{اور وہی ہے جس نے سرحدِ مکّہ پر (حدیبیہ کے قریب) ان (کافروں) کے ہاتھ تم سے اور تمہارے ہاتھ ان سے روک دیئے اس کے بعد کہ اس نے تمہیں ان (کے گروہ) پر غلبہ بخش دیا تھا۔ اور اﷲ ان کاموں کو جو تم کرتے ہو خوب دیکھنے والا ہے،\qt@no{24}}%
\qt@newcmd\qurantrans@ur@mmmmdcviii{یہی وہ لوگ ہیں جنھوں نے کفر کیا اور تمہیں مسجدِ حرام سے روک دیا اور قربانی کے جانوروں کو بھی، جو اپنی جگہ پہنچنے سے رکے پڑے رہے، اور اگر کئی ایسے مومن مرد اور مومن عورتیں (مکہّ میں موجود نہ ہوتیں) جنہیں تم جانتے بھی نہیں ہو کہ تم انہیں پامال کر ڈالو گے اور تمہیں بھی لاعلمی میں ان کی طرف سے کوئی سختی اور تکلیف پہنچ جائے گی (تو ہم تمہیں اِسی موقع پر ہی جنگ کی اجازت دے دیتے۔ مگر فتحِ مکّہ کو مؤخّر اس لئے کیا گیا) تاکہ اﷲ جسے چاہے (صلح کے نتیجے میں) اپنی رحمت میں داخل فرما لے۔ اگر (وہاں کے کافر اور مسلمان) الگ الگ ہو کر ایک دوسرے سے ممتاز ہو جاتے تو ہم ان میں سے کافروں کو دردناک عذاب کی سزا دیتے،\qt@no{25}}%
\qt@newcmd\qurantrans@ur@mmmmdcix{جب کافر لوگوں نے اپنے دلوں میں متکبّرانہ ہٹ دھرمی رکھ لی (جو کہ) جاہلیت کی ضِد اور غیرت (تھی) تو اﷲ نے اپنے رسول (صلی اللہ علیہ وآلہ وسلم) اور مومنوں پر اپنی خاص تسکین نازل فرمائی اور انہیں کلمہء تقوٰی پر مستحکم فرما دیا اور وہ اسی کے زیادہ مستحق تھے اور اس کے اہل (بھی) تھے، اور اﷲ ہر چیز کو خوب جاننے والا ہے،\qt@no{26}}%
\qt@newcmd\qurantrans@ur@mmmmdcx{بیشک اﷲ نے اپنے رسول (صلی اللہ علیہ وآلہ وسلم) کو حقیقت کے عین مطابق سچا خواب دکھایا تھا کہ تم لوگ، اگر اﷲ نے چاہا تو ضرور بالضرور مسجدِ حرام میں داخل ہو گے امن و امان کے ساتھ، (کچھ) اپنے سر منڈوائے ہوئے اور (کچھ) بال کتروائے ہوئے (اس حال میں کہ) تم خوفزدہ نہیں ہو گے، پس وہ (صلح حدیبیہ کو اس خواب کی تعبیر کے پیش خیمہ کے طور پر) جانتا تھا جو تم نہیں جانتے تھے سو اس نے اس (فتحِ مکہ) سے بھی پہلے ایک فوری فتح (حدیبیہ سے پلٹتے ہی فتحِ خیبر) عطا کر دی (اور اس سے اگلے سال فتحِ مکہ اور داخلۂ حرم عطا فرما دیا)،\qt@no{27}}%
\qt@newcmd\qurantrans@ur@mmmmdcxi{وہی ہے جس نے اپنے رسول (صلی اللہ علیہ وآلہ وسلم) کو ہدایت اور دینِ حق عطا فرما کر بھیجا تاکہ اسے تمام ادیان پر غالب کر دے، اور (رسول صلی اللہ علیہ وآلہ وسلم کی صداقت و حقانیت پر) اﷲ ہی گواہ کافی ہے،\qt@no{28}}%
\qt@newcmd\qurantrans@ur@mmmmdcxii{محمد (صلی اللہ علیہ وآلہ وسلم) اﷲ کے رسول ہیں، اور جو لوگ آپ (صلی اللہ علیہ وآلہ وسلم) کی معیت اور سنگت میں ہیں (وہ) کافروں پر بہت سخت اور زور آور ہیں آپس میں بہت نرم دل اور شفیق ہیں۔ آپ انہیں کثرت سے رکوع کرتے ہوئے، سجود کرتے ہوئے دیکھتے ہیں وہ (صرف) اﷲ کے فضل اور اس کی رضا کے طلب گار ہیں۔ اُن کی نشانی اُن کے چہروں پر سجدوں کا اثر ہے (جو بصورتِ نور نمایاں ہے)۔ ان کے یہ اوصاف تورات میں (بھی مذکور) ہیں اور ان کے (یہی) اوصاف انجیل میں (بھی مرقوم) ہیں۔ وہ (صحابہ ہمارے محبوبِ مکرّم کی) کھیتی کی طرح ہیں جس نے (سب سے پہلے) اپنی باریک سی کونپل نکالی، پھر اسے طاقتور اور مضبوط کیا، پھر وہ موٹی اور دبیز ہوگئی، پھر اپنے تنے پر سیدھی کھڑی ہوگئی (اور جب سرسبز و شاداب ہو کر لہلہائی تو) کاشتکاروں کو کیا ہی اچھی لگنے لگی (اﷲ نے اپنے حبیب صلی اللہ علیہ وآلہ وسلم کے صحابہ رضی اللہ عنھم کو اسی طرح ایمان کے تناور درخت بنایا ہے) تاکہ اِن کے ذریعے وہ (محمد رسول اﷲ صلی اللہ علیہ وآلہ وسلم سے جلنے والے) کافروں کے دل جلائے، اﷲ نے ان لوگوں سے جو ایمان لائے اور نیک اعمال کرتے رہے مغفرت اور اجرِ عظیم کا وعدہ فرمایا ہے،\qt@no{29}}%
\qt@newcmd\qurantrans@ur@mmmmdcxiii{\basmalahur اے ایمان والو! (کسی بھی معاملے میں) اﷲ اور اس کے رسول (صلی اللہ علیہ وآلہ وسلم) سے آگے نہ بڑھا کرو اور اﷲ سے ڈرتے رہو (کہ کہیں رسول صلی اللہ علیہ وآلہ وسلم کی بے ادبی نہ ہوجائے)، بیشک اﷲ (سب کچھ) سننے والا خوب جاننے والا ہے،\qt@no{1}}%
\qt@newcmd\qurantrans@ur@mmmmdcxiv{اے ایمان والو! تم اپنی آوازوں کو نبیِ مکرّم (صلی اللہ علیہ وآلہ وسلم) کی آواز سے بلند مت کیا کرو اور اُن کے ساتھ اِس طرح بلند آواز سے بات (بھی) نہ کیا کرو جیسے تم ایک دوسرے سے بلند آواز کے ساتھ کرتے ہو (ایسا نہ ہو) کہ تمہارے سارے اعمال ہی (ایمان سمیت) غارت ہو جائیں اور تمہیں (ایمان اور اعمال کے برباد ہوجانے کا) شعور تک بھی نہ ہو،\qt@no{2}}%
\qt@newcmd\qurantrans@ur@mmmmdcxv{بیشک جو لوگ رسول اللہ (صلی اللہ علیہ وآلہ وسلم) کی بارگاہ میں (ادب و نیاز کے باعث) اپنی آوازوں کو پست رکھتے ہیں، یہی وہ لوگ ہیں جن کے دلوں کو اﷲ نے تقوٰی کے لئے چن کر خالص کر لیا ہے۔ ان ہی کے لئے بخشش ہے اور اجرِ عظیم ہے،\qt@no{3}}%
\qt@newcmd\qurantrans@ur@mmmmdcxvi{بیشک جو لوگ آپ کو حجروں کے باہر سے پکارتے ہیں ان میں سے اکثر (آپ کے بلند مقام و مرتبہ اور آدابِ تعظیم کی) سمجھ نہیں رکھتے،\qt@no{4}}%
\qt@newcmd\qurantrans@ur@mmmmdcxvii{اور اگر وہ لوگ صبر کرتے یہاں تک کہ آپ خود ہی ان کی طرف باہر تشریف لے آتے تو یہ اُن کے لئے بہتر ہوتا، اور اﷲ بڑا بخشنے والا بہت رحم فرمانے والا ہے،\qt@no{5}}%
\qt@newcmd\qurantrans@ur@mmmmdcxviii{اے ایمان والو! اگر تمہارے پاس کوئی فاسق (شخص) کوئی خبر لائے تو خوب تحقیق کر لیا کرو (ایسا نہ ہو) کہ تم کسی قوم کو لاعلمی میں (ناحق) تکلیف پہنچا بیٹھو، پھر تم اپنے کئے پر پچھتاتے رہ جاؤ،\qt@no{6}}%
\qt@newcmd\qurantrans@ur@mmmmdcxix{اور جان لو کہ تم میں رسول اﷲ (صلی اللہ علیہ وآلہ وسلم) موجود ہیں، اگر وہ بہت سے کاموں میں تمہارا کہنا مان لیں تو تم بڑی مشکل میں پڑ جاؤ گے لیکن اللہ نے تمہیں ایمان کی محبت عطا فرمائی اور اسے تمہارے دلوں میں آراستہ فرما دیا اور کفر اور نافرمانی اور گناہ سے تمہیں متنفر کر دیا، ایسے ہی لوگ دین کی راہ پر ثابت اور گامزن ہیں،\qt@no{7}}%
\qt@newcmd\qurantrans@ur@mmmmdcxx{یہ) اﷲ کے فضل اور (اس کی) نعمت (یعنی تم میں رسولِ اُمّی صلی اللہ علیہ وآلہ وسلم کی بعثت اور موجودگی) کے باعث ہے، اور اﷲ خوب جاننے والا اور بڑی حکمت والا ہے،\qt@no{8}}%
\qt@newcmd\qurantrans@ur@mmmmdcxxi{اور اگر مسلمانوں کے دو گروہ آپس میں جنگ کریں تو اُن کے درمیان صلح کرا دیا کرو، پھر اگر ان میں سے ایک (گروہ) دوسرے پر زیادتی اور سرکشی کرے تو اس (گروہ) سے لڑو جو زیادتی کا مرتکب ہو رہا ہے یہاں تک کہ وہ اﷲ کے حکم کی طرف لوٹ آئے، پھر اگر وہ رجوع کر لے تو دونوں کے درمیان عدل کے ساتھ صلح کرا دو اور انصاف سے کام لو، بیشک اﷲ انصاف کرنے والوں کو بہت پسند فرماتا ہے،\qt@no{9}}%
\qt@newcmd\qurantrans@ur@mmmmdcxxii{بات یہی ہے کہ (سب) اہلِ ایمان (آپس میں) بھائی ہیں۔ سو تم اپنے دو بھائیوں کے درمیان صلح کرایا کرو، اور اﷲ سے ڈرتے رہو تاکہ تم پر رحم کیا جائے،\qt@no{10}}%
\qt@newcmd\qurantrans@ur@mmmmdcxxiii{اے ایمان والو! کوئی قوم کسی قوم کا مذاق نہ اڑائے ممکن ہے وہ لوگ اُن (تمسخر کرنے والوں) سے بہتر ہوں اور نہ عورتیں ہی دوسری عورتوں کا (مذاق اڑائیں) ممکن ہے وہی عورتیں اُن (مذاق اڑانے والی عورتوں) سے بہتر ہوں، اور نہ آپس میں طعنہ زنی اور الزام تراشی کیا کرو اور نہ ایک دوسرے کے برے نام رکھا کرو، کسی کے ایمان (لانے) کے بعد اسے فاسق و بدکردار کہنا بہت ہی برا نام ہے، اور جس نے توبہ نہیں کی سو وہی لوگ ظالم ہیں،\qt@no{11}}%
\qt@newcmd\qurantrans@ur@mmmmdcxxiv{اے ایمان والو! زیادہ تر گمانوں سے بچا کرو بیشک بعض گمان (ایسے) گناہ ہوتے ہیں (جن پر اُخروی سزا واجب ہوتی ہے) اور (کسی کے غیبوں اور رازوں کی) جستجو نہ کیا کرو اور نہ پیٹھ پیچھے ایک دوسرے کی برائی کیا کرو، کیا تم میں سے کوئی شخص پسند کرے گا کہ وہ اپنے مُردہ بھائی کا گوشت کھائے، سو تم اس سے نفرت کرتے ہو۔ اور (اِن تمام معاملات میں) اﷲ سے ڈرو بیشک اﷲ توبہ کو بہت قبول فرمانے والا بہت رحم فرمانے والا ہے،\qt@no{12}}%
\qt@newcmd\qurantrans@ur@mmmmdcxxv{اے لوگو! ہم نے تمہیں مرد اور عورت سے پیدا فرمایا اور ہم نے تمہیں (بڑی بڑی) قوموں اور قبیلوں میں (تقسیم) کیا تاکہ تم ایک دوسرے کو پہچان سکو۔ بیشک اﷲ کے نزدیک تم میں زیادہ باعزت وہ ہے جو تم میں زیادہ پرہیزگارہو، بیشک اﷲ خوب جاننے والا خوب خبر رکھنے والا ہے،\qt@no{13}}%
\qt@newcmd\qurantrans@ur@mmmmdcxxvi{دیہاتی لوگ کہتے ہیں کہ ہم ایمان لائے ہیں، آپ فرما دیجئے: تم ایمان نہیں لائے، ہاں یہ کہو کہ ہم اسلام لائے ہیں اور ابھی ایمان تمہارے دلوں میں داخل ہی نہیں ہوا، اور اگر تم اﷲ اور اس کے رسول (صلی اللہ علیہ وآلہ وسلم) کی اطاعت کرو تو وہ تمہارے اعمال (کے ثواب میں) سے کچھ بھی کم نہیں کرے گا، بیشک اﷲ بہت بخشنے والا بہت رحم فرمانے والا ہے،\qt@no{14}}%
\qt@newcmd\qurantrans@ur@mmmmdcxxvii{ایمان والے تو صرف وہ لوگ ہیں جو اﷲ اور اس کے رسول (صلی اللہ علیہ وآلہ وسلم) پر ایمان لائے، پھر شک میں نہ پڑے اور اﷲ کی راہ میں اپنے اموال اور اپنی جانوں سے جہاد کرتے رہے، یہی وہ لوگ ہیں جو (دعوائے ایمان میں) سچےّ ہیں،\qt@no{15}}%
\qt@newcmd\qurantrans@ur@mmmmdcxxviii{فرما دیجئے: کیا تم اﷲ کو اپنی دین داری جتلا رہے ہو، حالانکہ اﷲ اُن (تمام) چیزوں کو جانتا ہے جو آسمانوں میں ہیں اور جو زمین میں ہیں، اور اﷲ ہر چیز کا خوب علم رکھنے والا ہے،\qt@no{16}}%
\qt@newcmd\qurantrans@ur@mmmmdcxxix{یہ لوگ آپ پر احسان جتلاتے ہیں کہ وہ اسلام لے آئے ہیں۔ فرما دیجئے: تم اپنے اسلام کا مجھ پر احسان نہ جتلاؤ بلکہ اﷲ تم پر احسان فرماتا ہے کہ اس نے تمہیں ایمان کا راستہ دکھایا ہے، بشرطیکہ تم (ایمان میں) سچے ہو،\qt@no{17}}%
\qt@newcmd\qurantrans@ur@mmmmdcxxx{بیشک اﷲ آسمانوں اور زمین کے سب غیب جانتا ہے، اور اﷲ جو عمل بھی تم کرتے ہو اسے خوب دیکھنے والا ہے،\qt@no{18}}%
\qt@newcmd\qurantrans@ur@mmmmdcxxxi{\basmalahur ق (حقیقی معنی اﷲ اور رسول صلی اللہ علیہ وآلہ وسلم ہی بہتر جانتے ہیں)، قسم ہے قرآنِ مجید کی،\qt@no{1}}%
\qt@newcmd\qurantrans@ur@mmmmdcxxxii{بلکہ اُن لوگوں نے تعجب کیا کہ اُن کے پاس اُنہی میں سے ایک ڈر سنانے والا آگیا ہے، سو کافر کہتے ہیں: یہ عجیب بات ہے،\qt@no{2}}%
\qt@newcmd\qurantrans@ur@mmmmdcxxxiii{کیا جب ہم مَر جائیں گے اور ہم مٹّی ہو جائیں گے (تو پھر زندہ ہوں گے)؟ یہ پلٹنا (فہم و ادراک سے) بعید ہے،\qt@no{3}}%
\qt@newcmd\qurantrans@ur@mmmmdcxxxiv{بیشک ہم جانتے ہیں کہ زمین اُن (کے جسموں) سے (کھا کھا کر) کتنا کم کرتی ہے، اور ہمارے پاس (ایسی) کتاب ہے جس میں سب کچھ محفوظ ہے،\qt@no{4}}%
\qt@newcmd\qurantrans@ur@mmmmdcxxxv{بلکہ (عجیب اور فہم و ادراک سے بعید بات تو یہ ہے کہ) انہوں نے حق (یعنی رسول صلی اللہ علیہ وآلہ وسلم اور قرآن) کو جھٹلا دیا جب وہ اُن کے پاس آچکا سو وہ خود (ہی) الجھن اور اضطراب کی بات میں (پڑے) ہیں،\qt@no{5}}%
\qt@newcmd\qurantrans@ur@mmmmdcxxxvi{سو کیا انہوں نے آسمان کی طرف نگاہ نہیں کی جو ان کے اوپر ہے کہ ہم نے اسے کیسے بنایا ہے اور (کیسے) سجایا ہے اور اس میں کوئی شگاف (تک) نہیں ہے،\qt@no{6}}%
\qt@newcmd\qurantrans@ur@mmmmdcxxxvii{اور (اِسی طرح) ہم نے زمین کو پھیلایا اور اس میں ہم نے بہت بھاری پہاڑ رکھے اور ہم نے اس میں ہر قسم کے خوش نما پودے اُگائے،\qt@no{7}}%
\qt@newcmd\qurantrans@ur@mmmmdcxxxviii{یہ سب) بصیرت اور نصیحت (کاسامان) ہے ہر اس بندے کے لئے جو (اﷲ کی طرف) رجوع کرنے والا ہے،\qt@no{8}}%
\qt@newcmd\qurantrans@ur@mmmmdcxxxix{اور ہم نے آسمان سے بابرکت پانی برسایا پھر ہم نے اس سے باغات اگائے اور کھیتوں کا غلّہ (بھی)،\qt@no{9}}%
\qt@newcmd\qurantrans@ur@mmmmdcxl{اور لمبی لمبی کھجوریں جن کے خوشے تہ بہ تہ ہوتے ہیں،\qt@no{10}}%
\qt@newcmd\qurantrans@ur@mmmmdcxli{یہ سب کچھ اپنے) بندوں کی روزی کے لئے (کیا) اور ہم نے اس (پانی) سے مُردہ زمین کو زندہ کیا، اسی طرح (تمہارا) قبروں سے نکلنا ہوگا،\qt@no{11}}%
\qt@newcmd\qurantrans@ur@mmmmdcxlii{اِن (کفّارِ مکہ) سے پہلے قومِ نوح نے، اور (سرزمینِ یمامہ کے اندھے) کنویں والوں نے، اور (مدینہ سے شام کی طرف تبوک کے قریب بستیِ حجر میں آباد صالح علیہ السلام کی قوم) ثمود نے جھٹلایا،\qt@no{12}}%
\qt@newcmd\qurantrans@ur@mmmmdcxliii{اور (عُمان اور اَرضِ مَہرہ کے درمیان یمن کی وادئ اَحقاف میں آباد ہود علیہ السلام کی قومِ) عاد نے اور(مصر کے حکمران) فرعون نے اور (اَرضِ فلسطین میں سدوم اور عمورہ کی رہنے والی) قومِ لُوط نے،\qt@no{13}}%
\qt@newcmd\qurantrans@ur@mmmmdcxliv{اور (مَدیَن کے گھنے درختوں والے بَن) اَیکہ کے رہنے والوں نے (یہ قومِ شعیب تھی) اور (بادشاہِ یَمن اسعَد ابوکریب) تُبّع (الحِمیَری) کی قوم نے، (الغرض اِن) سب نے رسولوں کو جھٹلایا، پس (اِن پر) میرا وعدۂ عذاب ثابت ہو کر رہا،\qt@no{14}}%
\qt@newcmd\qurantrans@ur@mmmmdcxlv{سو کیا ہم پہلی بار پیدا کرنے کے باعث تھک گئے ہیں؟ (ایسا نہیں) بلکہ وہ لوگ اَزسرِنَو پیدائش کی نسبت شک میں (پڑے) ہیں،\qt@no{15}}%
\qt@newcmd\qurantrans@ur@mmmmdcxlvi{اور بیشک ہم نے انسان کو پیدا کیا ہے اور ہم اُن وسوسوں کو (بھی) جانتے ہیں جو اس کا نفس (اس کے دل و دماغ میں) ڈالتا ہے۔ اور ہم اس کی شہ رگ سے بھی زیادہ اس کے قریب ہیں،\qt@no{16}}%
\qt@newcmd\qurantrans@ur@mmmmdcxlvii{جب دو لینے والے (فرشتے اس کے ہر قول و فعل کو تحریر میں) لے لیتے ہیں (جو) دائیں طرف اور بائیں طرف بیٹھے ہوئے ہیں،\qt@no{17}}%
\qt@newcmd\qurantrans@ur@mmmmdcxlviii{وہ مُنہ سے کوئی بات نہیں کہنے پاتا مگر اس کے پاس ایک نگہبان (لکھنے کے لئے) تیار رہتا ہے،\qt@no{18}}%
\qt@newcmd\qurantrans@ur@mmmmdcxlix{اور موت کی بے ہوشی حق کے ساتھ آپہنچی۔ (اے انسان!) یہی وہ چیز ہے جس سے تو بھاگتا تھا،\qt@no{19}}%
\qt@newcmd\qurantrans@ur@mmmmdcl{اور صُور پھونکا جائے گا، یہی (عذاب ہی) وعید کا دن ہے،\qt@no{20}}%
\qt@newcmd\qurantrans@ur@mmmmdcli{اور ہر جان (ہمارے حضور اس طرح) آئے گی کہ اُس کا ایک ہانکنے والا (فرشتہ) اور (دوسرا اعمال پر) گواہ ہوگا،\qt@no{21}}%
\qt@newcmd\qurantrans@ur@mmmmdclii{حقیقت میں تُو اِس (دن) سے غفلت میں پڑا رہا سو ہم نے تیرا پردۂ (غفلت) ہٹا دیا پس آج تیری نگاہ تیز ہے،\qt@no{22}}%
\qt@newcmd\qurantrans@ur@mmmmdcliii{اور اس کے ساتھ رہنے والا (فرشتہ) کہے گا: یہ ہے جو کچھ میرے پاس تیار ہے،\qt@no{23}}%
\qt@newcmd\qurantrans@ur@mmmmdcliv{حکم ہوگا): پس تم دونوں (ایسے) ہر ناشکرگزار سرکش کو دوزخ میں ڈال دو،\qt@no{24}}%
\qt@newcmd\qurantrans@ur@mmmmdclv{جو نیکی سے روکنے والا ہے، حد سے بڑھ جانے والا ہے، شک کرنے اور ڈالنے والا ہے،\qt@no{25}}%
\qt@newcmd\qurantrans@ur@mmmmdclvi{جس نے اﷲ کے ساتھ دوسرا معبود ٹھہرا رکھا تھا سو تم اسے سخت عذاب میں ڈال دو،\qt@no{26}}%
\qt@newcmd\qurantrans@ur@mmmmdclvii{اب) اس کا (دوسرا) ساتھی (شیطان) کہے گا: اے ہمارے رب! اِسے میں نے گمراہ نہیں کیا بلکہ یہ (خود ہی) پرلے درجے کی گمراہی میں مبتلا تھا،\qt@no{27}}%
\qt@newcmd\qurantrans@ur@mmmmdclviii{ارشاد ہوگا: تم لوگ میرے حضور جھگڑا مَت کرو حالانکہ میں تمہاری طرف پہلے ہی (عذاب کی) وعید بھیج چکا ہوں،\qt@no{28}}%
\qt@newcmd\qurantrans@ur@mmmmdclix{میری بارگاہ میں فرمان بدلا نہیں جاتا اور نہ ہی میں بندوں پر ظلم کرنے والا ہوں،\qt@no{29}}%
\qt@newcmd\qurantrans@ur@mmmmdclx{اس دن ہم دوزخ سے فرمائیں گے: کیا تو بھر گئی ہے؟ اور وہ کہے گی: کیا کچھ اور زیادہ بھی ہے،\qt@no{30}}%
\qt@newcmd\qurantrans@ur@mmmmdclxi{اور جنت پرہیزگاروں کے لئے قریب کر دی جائے گے، بالکل دُور نہیں ہوگی،\qt@no{31}}%
\qt@newcmd\qurantrans@ur@mmmmdclxii{اور اُن سے ارشاد ہوگا): یہ ہے وہ جس کا تم سے وعدہ کیا گیا تھا (کہ) ہر توبہ کرنے والے (اپنے دین اور ایمان کی) حفاظت کرنے والے کے لئے (ہے)،\qt@no{32}}%
\qt@newcmd\qurantrans@ur@mmmmdclxiii{جو (خدائے) رحمان سے بِن دیکھے ڈرتا رہا اور (اﷲ کی بارگاہ میں) رجوع و اِنابت والا دل لے کر حاضر ہوا،\qt@no{33}}%
\qt@newcmd\qurantrans@ur@mmmmdclxiv{اس میں سلامتی کے ساتھ داخل ہو جاؤ، یہ ہمیشگی کا دن ہے،\qt@no{34}}%
\qt@newcmd\qurantrans@ur@mmmmdclxv{اِس (جنت) میں اُن کے لئے وہ تمام نعمتیں (موجود) ہوں گی جن کی وہ خواہش کریں گے اور ہمارے حضور میں ایک نعمت مزید بھی ہے (یا اور بھی بہت کچھ ہے، سو عاشق مَست ہوجائیں گے)،\qt@no{35}}%
\qt@newcmd\qurantrans@ur@mmmmdclxvi{اور ہم نے اُن (کفار و مشرکینِ مکہّ) سے پہلے کتنی ہی اُمتوں کو ہلاک کر دیا جو طاقت و قوّت میں ان سے کہیں بڑھ کر تھیں، چنانچہ انہوں نے (دنیا کے) شہروں کو چھان مارا تھا کہ کہیں (موت یا عذاب سے) بھاگ جانے کی کوئی جگہ ہو،\qt@no{36}}%
\qt@newcmd\qurantrans@ur@mmmmdclxvii{بیشک اس میں یقیناً انتباہ اور تذکّر ہے اس شخص کے لئے جو صاحبِ دل ہے (یعنی غفلت سے دوری اور قلبی بیداری رکھتا ہے) یا کان لگا کرسُنتا ہے (یعنی توجہ کو یک سُو اور غیر سے منقطع رکھتا ہے) اور وہ (باطنی) مشاہدہ میں ہے (یعنی حسن و جمالِ الوھیّت کی تجلّیات میں گم رہتا ہے)،\qt@no{37}}%
\qt@newcmd\qurantrans@ur@mmmmdclxviii{اور بیشک ہم نے آسمانوں اور زمین کو اور اُس (کائنات) کو جو دونوں کے درمیان ہے چھ زمانوں میں تخلیق کیا ہے، اور ہمیں کوئی تکان نہیں پہنچی،\qt@no{38}}%
\qt@newcmd\qurantrans@ur@mmmmdclxix{سو آپ اُن باتوں پر جو وہ کہتے ہیں صبر کیجئے اور اپنے رب کی حمد کے ساتھ تسبیح کیجئے طلوعِ آفتاب سے پہلے اور غروبِ آفتاب سے پہلے،\qt@no{39}}%
\qt@newcmd\qurantrans@ur@mmmmdclxx{اور رات کے بعض اوقات میں بھی اس کی تسبیح کیجئے اور نمازوں کے بعد بھی،\qt@no{40}}%
\qt@newcmd\qurantrans@ur@mmmmdclxxi{اور (اُس دِن کا حال) خوب سن لیجئے جس دن ایک پکارنے والا قریبی جگہ سے پکارے گا،\qt@no{41}}%
\qt@newcmd\qurantrans@ur@mmmmdclxxii{جس دن لوگ سخت چنگھاڑ کی آواز کو بالیقین سنیں گے، یہی قبروں سے نکلنے کا دن ہوگا،\qt@no{42}}%
\qt@newcmd\qurantrans@ur@mmmmdclxxiii{بیشک ہم ہی زندہ رکھتے ہیں اور ہم ہی موت دیتے ہیں اور ہماری ہی طرف پلٹ کر آنا ہے،\qt@no{43}}%
\qt@newcmd\qurantrans@ur@mmmmdclxxiv{جِس دن زمین اُن پر سے پھٹ جائے گی تو وہ جلدی جلدی نکل پڑیں گے، یہ حشر (پھر سے لوگوں کو جمع کرنا) ہم پر نہایت آسان ہے،\qt@no{44}}%
\qt@newcmd\qurantrans@ur@mmmmdclxxv{ہم خوب جانتے ہیں جو کچھ وہ کہتے ہیں اور آپ اُن پر جبر کرنے والے نہیں ہیں، پس قرآن کے ذریعے اس شخص کو نصیحت فرمائیے جو میرے وعدۂ عذاب سے ڈرتا ہے،\qt@no{45}}%
\qt@newcmd\qurantrans@ur@mmmmdclxxvi{\basmalahur اُڑا کر بکھیر دینے والی ہواؤں کی قَسم،\qt@no{1}}%
\qt@newcmd\qurantrans@ur@mmmmdclxxvii{اور (پانی کا) بارِ گراں اٹھانے والی بدلیوں کی قَسم،\qt@no{2}}%
\qt@newcmd\qurantrans@ur@mmmmdclxxviii{اور خراماں خراماں چلنے والی کشتیوں کی قَسم،\qt@no{3}}%
\qt@newcmd\qurantrans@ur@mmmmdclxxix{اور کام تقسیم کرنے والے فرشتوں کی قَسم،\qt@no{4}}%
\qt@newcmd\qurantrans@ur@mmmmdclxxx{بیشک (آخرت کا) جو وعدہ تم سے کیا جا رہا ہے بالکل سچا ہے،\qt@no{5}}%
\qt@newcmd\qurantrans@ur@mmmmdclxxxi{اور بیشک (اعمال کی) جزا و سزا ضرور واقع ہو کر رہے گی،\qt@no{6}}%
\qt@newcmd\qurantrans@ur@mmmmdclxxxii{اور (ستاروں اور سیّاروں کی) کہکشاؤں اور گزرگاہوں والے آسمان کی قَسم،\qt@no{7}}%
\qt@newcmd\qurantrans@ur@mmmmdclxxxiii{بیشک تم مختلف بے جوڑ باتوں میں (پڑے) ہو،\qt@no{8}}%
\qt@newcmd\qurantrans@ur@mmmmdclxxxiv{اِس (رسول صلی اللہ علیہ وآلہ وسلم اور قرآن سے) وہی پھرتا ہے جِسے (علمِ ازلی سے) پھیر دیا گیا،\qt@no{9}}%
\qt@newcmd\qurantrans@ur@mmmmdclxxxv{ظنّ و تخمین سے جھوٹ بولنے والے ہلاک ہو گئے،\qt@no{10}}%
\qt@newcmd\qurantrans@ur@mmmmdclxxxvi{جو جہالت و غفلت میں (آخرت کو) بھول جانے والے ہیں،\qt@no{11}}%
\qt@newcmd\qurantrans@ur@mmmmdclxxxvii{پوچھتے ہیں یومِ جزا کب ہو گا؟،\qt@no{12}}%
\qt@newcmd\qurantrans@ur@mmmmdclxxxviii{فرما دیجئے:) اُس دن (ہوگا جب) وہ آتشِ دوزخ میں تپائے جائیں گے،\qt@no{13}}%
\qt@newcmd\qurantrans@ur@mmmmdclxxxix{اُن سے کہا جائے گا:) اپنی سزا کا مزہ چکھو، یہی وہ عذاب ہے جسے تم جلدی مانگتے ہو،\qt@no{14}}%
\qt@newcmd\qurantrans@ur@mmmmdcxc{بیشک پرہیزگار باغوں اور چشموں میں (لطف اندوز ہوتے) ہوں گے،\qt@no{15}}%
\qt@newcmd\qurantrans@ur@mmmmdcxci{اُن نعمتوں کو (کیف و سرور) سے لیتے ہوں گے جو اُن کا رب انہیں (لطف و کرم سے) دیتا ہوگا، بیشک یہ وہ لوگ ہیں جو اس سے قبل (کی زندگی میں) صاحبانِ احسان تھے،\qt@no{16}}%
\qt@newcmd\qurantrans@ur@mmmmdcxcii{وہ راتوں کو تھوڑی سی دیر سویا کرتے تھے،\qt@no{17}}%
\qt@newcmd\qurantrans@ur@mmmmdcxciii{اور رات کے پچھلے پہروں میں (اٹھ اٹھ کر) مغفرت طلب کرتے تھے،\qt@no{18}}%
\qt@newcmd\qurantrans@ur@mmmmdcxciv{اور اُن کے اموال میں سائل اور محروم (سب حاجت مندوں) کا حق مقرر تھا،\qt@no{19}}%
\qt@newcmd\qurantrans@ur@mmmmdcxcv{اور زمین میں صاحبانِ ایقان (یعنی کامل یقین والوں) کے لئے بہت سی نشانیاں ہیں،\qt@no{20}}%
\qt@newcmd\qurantrans@ur@mmmmdcxcvi{اور خود تمہارے نفوس میں (بھی ہیں)، سو کیا تم دیکھتے نہیں ہو،\qt@no{21}}%
\qt@newcmd\qurantrans@ur@mmmmdcxcvii{اور آسمان میں تمہارا رِزق (بھی) ہے اور وہ (سب کچھ بھی) جس کا تم سے وعدہ کیا جاتا ہے،\qt@no{22}}%
\qt@newcmd\qurantrans@ur@mmmmdcxcviii{پس آسمان اور زمین کے مالک کی قَسم! یہ (ہمارا وعدہ) اسی طرح یقینی ہے جس طرح تمہارا اپنا بولنا (تمہیں اس پر کامل یقین ہوتا ہے کہ منہ سے کیا کہہ رہے ہو)،\qt@no{23}}%
\qt@newcmd\qurantrans@ur@mmmmdcxcix{کیا آپ کے پاس ابراہیم (علیہ السلام) کے معزّز مہمانوں کی خبر پہنچی ہے،\qt@no{24}}%
\qt@newcmd\qurantrans@ur@mmmmdcc{جب وہ (فرشتے) اُن کے پاس آئے تو انہوں نے سلام پیش کیا، ابراہیم (علیہ السلام) نے بھی (جواباً) سلام کہا، (ساتھ ہی دل میں سوچنے لگے کہ) یہ اجنبی لوگ ہیں،\qt@no{25}}%
\qt@newcmd\qurantrans@ur@mmmmdcci{پھر جلدی سے اپنے گھر کی طرف گئے اور ایک فربہ بچھڑے کی سجّی لے آئے،\qt@no{26}}%
\qt@newcmd\qurantrans@ur@mmmmdccii{پھر اسے ان کے سامنے پیش کر دیا، فرمانے لگے: کیا تم نہیں کھاؤ گے،\qt@no{27}}%
\qt@newcmd\qurantrans@ur@mmmmdcciii{پھر اُن (کے نہ کھانے) سے دل میں ہلکی سے گھبراہٹ محسوس کی۔ وہ (فرشتے) کہنے لگے: آپ گھبرائیے نہیں، اور اُن کو علم و دانش والے بیٹے (اسحاق علیہ السلام) کی خوشخبری سنا دی،\qt@no{28}}%
\qt@newcmd\qurantrans@ur@mmmmdcciv{پھر اُن کی بیوی (سارہ) حیرت و حسرت کی آواز نکالتے ہوئے متوجہ ہوئیں اور تعجّب سے اپنے ماتھے پر ہاتھ مارا اور کہنے لگی: (کیا) بوڑھیا بانجھ عورت (بچہ جنے گی؟)،\qt@no{29}}%
\qt@newcmd\qurantrans@ur@mmmmdccv{فرشتوں نے) کہا: ایسے ہی ہوگا، تمہارے رب نے فرمایا ہے۔ بیشک وہ بڑی حکمت والا بہت علم والا ہے،\qt@no{30}}%
\qt@newcmd\qurantrans@ur@mmmmdccvi{ابراہیم علیہ السلام نے) کہا: اے بھیجے ہوئے فرشتو! (اس بشارت کے علاوہ) تمہارا (آنے کا) بنیادی مقصد کیا ہے،\qt@no{31}}%
\qt@newcmd\qurantrans@ur@mmmmdccvii{انہوں نے کہا: ہم مجرِم قوم (یعنی قومِ لُوط) کی طرف بھیجے گئے ہیں،\qt@no{32}}%
\qt@newcmd\qurantrans@ur@mmmmdccviii{تاکہ ہم اُن پر مٹی کے پتھریلے کنکر برسائیں،\qt@no{33}}%
\qt@newcmd\qurantrans@ur@mmmmdccix{وہ پتھر جن پر) حد سے گزر جانے والوں کے لئے آپ کے رب کی طرف سے نشان لگا دیا گیا ہے،\qt@no{34}}%
\qt@newcmd\qurantrans@ur@mmmmdccx{پھر ہم نے ہر اُس شخص کو (قومِ لُوط کی بستی سے) باہر نکال دیا جو اس میں اہلِ ایمان میں سے تھا،\qt@no{35}}%
\qt@newcmd\qurantrans@ur@mmmmdccxi{سو ہم نے اُس بستی میں مسلمانوں کے ایک گھر کے سوا (اور کوئی گھر) نہیں پایا (اس میں حضرت لوط علیہ السلام اور ان کی دو صاحبزادیاں تھیں)،\qt@no{36}}%
\qt@newcmd\qurantrans@ur@mmmmdccxii{اور ہم نے اُس (بستی) میں اُن لوگوں کے لئے (عبرت کی) ایک نشانی باقی رکھی جو دردناک عذاب سے ڈرتے ہیں،\qt@no{37}}%
\qt@newcmd\qurantrans@ur@mmmmdccxiii{اور موسٰی (علیہ السلام کے واقعہ) میں (بھی نشانیاں ہیں) جب ہم نے انہیں فرعون کی طرف واضح دلیل دے کر بھیجا،\qt@no{38}}%
\qt@newcmd\qurantrans@ur@mmmmdccxiv{تو اُس نے اپنے اراکینِ سلطنت سمیت رُوگردانی کی اور کہنے لگا: (یہ) جادوگر یا دیوانہ ہے،\qt@no{39}}%
\qt@newcmd\qurantrans@ur@mmmmdccxv{پھر ہم نے اُسے اور اُس کے لشکر کو (عذاب کی) گرفت میں لے لیا اور اُن (سب) کو دریا میں غرق کر دیا اور وہ تھا ہی قابلِ ملامت کام کرنے والا،\qt@no{40}}%
\qt@newcmd\qurantrans@ur@mmmmdccxvi{اور (قومِ) عاد (کی ہلاکت) میں بھی (نشانی) ہے جبکہ ہم نے اُن پر بے خیر و برکت ہوا بھیجی،\qt@no{41}}%
\qt@newcmd\qurantrans@ur@mmmmdccxvii{وہ جس چیز پر بھی گزرتی تھی اسے ریزہ ریزہ کئے بغیر نہیں چھوڑتی تھی،\qt@no{42}}%
\qt@newcmd\qurantrans@ur@mmmmdccxviii{اور (قومِ) ثمود (کی ہلاکت) میں بھی (عبرت کی نشانی ہے) جبکہ اُن سے کہا گیا کہ تم ایک معیّنہ وقت تک فائدہ اٹھا لو،\qt@no{43}}%
\qt@newcmd\qurantrans@ur@mmmmdccxix{تو انہوں نے اپنے رب کے حکم سے سرکشی کی، پس انہیں ہولناک کڑک نے آن لیا اور وہ دیکھتے ہی رہ گئے،\qt@no{44}}%
\qt@newcmd\qurantrans@ur@mmmmdccxx{پھر وہ نہ کھڑے رہنے پر قدرت پا سکے اور نہ وہ (ہم سے) بدلہ لے سکنے والے تھے،\qt@no{45}}%
\qt@newcmd\qurantrans@ur@mmmmdccxxi{اور اس سے پہلے نُوح (علیہ السلام) کی قوم کو (بھی ہلاک کیا)، بیشک وہ سخت نافرمان لوگ تھے،\qt@no{46}}%
\qt@newcmd\qurantrans@ur@mmmmdccxxii{اور آسمانی کائنات کو ہم نے بڑی قوت کے ذریعہ سے بنایا اور یقیناً ہم (اس کائنات کو) وسعت اور پھیلاؤ دیتے جا رہے ہیں،\qt@no{47}}%
\qt@newcmd\qurantrans@ur@mmmmdccxxiii{اور (سطحِ) زمین کو ہم ہی نے (قابلِ رہائش) فرش بنایا سو ہم کیا خوب سنوارنے اور سیدھا کرنے والے ہیں،\qt@no{48}}%
\qt@newcmd\qurantrans@ur@mmmmdccxxiv{اور ہم نے ہر چیز سے دو جوڑے پیدا فرمائے تاکہ تم دھیان کرو اور سمجھو،\qt@no{49}}%
\qt@newcmd\qurantrans@ur@mmmmdccxxv{پس تم اﷲ کی طرف دوڑ چلو، بیشک میں اُس کی طرف سے تمہیں کھلا ڈر سنانے والا ہوں،\qt@no{50}}%
\qt@newcmd\qurantrans@ur@mmmmdccxxvi{اور اﷲ کے سوا کوئی دوسرا معبود نہ بناؤ، بیشک میں اس کی جانب سے تمہیں کھلا ڈر سنانے والا ہوں،\qt@no{51}}%
\qt@newcmd\qurantrans@ur@mmmmdccxxvii{اسی طرح اُن سے پہلے لوگوں کے پاس بھی کوئی رسول نہیں آیا مگر انہوں نے یہی کہا کہ (یہ) جادوگر ہے یا دیوانہ ہے،\qt@no{52}}%
\qt@newcmd\qurantrans@ur@mmmmdccxxviii{کیا وہ لوگ ایک دوسرے کواس بات کی وصیت کرتے رہے؟ بلکہ وہ (سب) سرکش و باغی لوگ تھے،\qt@no{53}}%
\qt@newcmd\qurantrans@ur@mmmmdccxxix{سو آپ اُن سے نظرِ التفات ہٹا لیں پس آپ پر (اُن کے ایمان نہ لانے کی) کوئی ملامت نہیں ہے،\qt@no{54}}%
\qt@newcmd\qurantrans@ur@mmmmdccxxx{اور آپ نصیحت کرتے رہیں کہ بیشک نصیحت مومنوں کو فائدہ دیتی ہے،\qt@no{55}}%
\qt@newcmd\qurantrans@ur@mmmmdccxxxi{اور میں نے جنّات اور انسانوں کو صرف اسی لئے پیدا کیا کہ وہ میری بندگی اختیار کریں،\qt@no{56}}%
\qt@newcmd\qurantrans@ur@mmmmdccxxxii{نہ میں اُن سے رِزق (یعنی کمائی) طلب کرتا ہوں اور نہ اس کا طلب گار ہوں کہ وہ مجھے (کھانا) کھلائیں،\qt@no{57}}%
\qt@newcmd\qurantrans@ur@mmmmdccxxxiii{بیشک اﷲ ہی ہر ایک کا روزی رساں ہے، بڑی قوت والا ہے، زبردست مضبوط ہے (اسے کسی کی مدد و تعاون کی حاجت نہیں)،\qt@no{58}}%
\qt@newcmd\qurantrans@ur@mmmmdccxxxiv{پس ان ظالموں کے لئے (بھی) حصۂ عذاب مقرّر ہے ان کے (پہلے گزرے ہوئے) ساتھیوں کے حصۂ عذاب کی طرح، سو وہ مجھ سے جلدی طلب نہ کریں،\qt@no{59}}%
\qt@newcmd\qurantrans@ur@mmmmdccxxxv{سو کافروں کے لئے اُن کے اُس دِن میں بڑی تباہی ہے جس کا اُن سے وعدہ کیا جا رہا ہے،\qt@no{60}}%
\qt@newcmd\qurantrans@ur@mmmmdccxxxvi{\basmalahur (کوہِ) طُور کی قَسم،\qt@no{1}}%
\qt@newcmd\qurantrans@ur@mmmmdccxxxvii{اور لکھی ہوئی کتاب کی قَسم،\qt@no{2}}%
\qt@newcmd\qurantrans@ur@mmmmdccxxxviii{جو) کھلے صحیفہ میں (ہے)،\qt@no{3}}%
\qt@newcmd\qurantrans@ur@mmmmdccxxxix{اور (فرشتوں سے) آباد گھر (یعنی آسمانی کعبہ) کی قَسم،\qt@no{4}}%
\qt@newcmd\qurantrans@ur@mmmmdccxl{اور اونچی چھت (یعنی بلند آسمان یا عرشِ معلٰی) کی قَسم،\qt@no{5}}%
\qt@newcmd\qurantrans@ur@mmmmdccxli{اور اُبلتے ہوئے سمندر کی قَسم،\qt@no{6}}%
\qt@newcmd\qurantrans@ur@mmmmdccxlii{بیشک آپ کے رب کا عذاب ضرور واقع ہو کر رہے گا،\qt@no{7}}%
\qt@newcmd\qurantrans@ur@mmmmdccxliii{اسے کوئی دفع کرنے والا نہیں،\qt@no{8}}%
\qt@newcmd\qurantrans@ur@mmmmdccxliv{جس دن آسمان سخت تھر تھراہٹ کے ساتھ لرزے گا،\qt@no{9}}%
\qt@newcmd\qurantrans@ur@mmmmdccxlv{اور پہاڑ (اپنی جگہ چھوڑ کر بادلوں کی طرح) تیزی سے اڑنے اور (ذرّات کی طرح) بکھرنے لگیں گے،\qt@no{10}}%
\qt@newcmd\qurantrans@ur@mmmmdccxlvi{سو اُس دن جھٹلانے والوں کے لئے بڑی تباہی ہے،\qt@no{11}}%
\qt@newcmd\qurantrans@ur@mmmmdccxlvii{جو باطل (بے ہودگی) میں پڑے غفلت کا کھیل کھیل رہے ہیں،\qt@no{12}}%
\qt@newcmd\qurantrans@ur@mmmmdccxlviii{جس دن کو وہ دھکیل دھکیل کر آتشِ دوزخ کی طرف لائے جائیں گے،\qt@no{13}}%
\qt@newcmd\qurantrans@ur@mmmmdccxlix{اُن سے کہا جائے گا:) یہ ہے وہ جہنّم کی آگ جسے تم جھٹلایا کرتے تھے،\qt@no{14}}%
\qt@newcmd\qurantrans@ur@mmmmdccl{سو کیا یہ جادو ہے یا تمہیں دکھائی نہیں دیتا،\qt@no{15}}%
\qt@newcmd\qurantrans@ur@mmmmdccli{اس میں داخل ہو جاؤ، پھر تم صبر کرو یا صبر نہ کرو، تم پر برابر ہے، تمہیں صرف انہی کاموں کا بدلہ دیا جائے گا جو تم کرتے رہے تھے،\qt@no{16}}%
\qt@newcmd\qurantrans@ur@mmmmdcclii{بیشک متّقی لوگ بہشتوں اور نعمتوں میں ہوں گے،\qt@no{17}}%
\qt@newcmd\qurantrans@ur@mmmmdccliii{خوش اور لطف اندوز ہوں گے اُن (عطاؤں) سے جن سے اُن کے رب نے انہیں نوازا ہوگا، اور اُن کا رب انہیں دوزخ کے عذاب سے محفوظ رکھے گا،\qt@no{18}}%
\qt@newcmd\qurantrans@ur@mmmmdccliv{اُن سے کہا جائے گا:) تم اُن (نیک) اعمال کے صلہ میں جو تم کرتے رہے تھے خوب مزے سے کھاؤ اور پیو،\qt@no{19}}%
\qt@newcmd\qurantrans@ur@mmmmdcclv{وہ صف در صف بچھے ہوئے تختوں پر تکیے لگائے (بیٹھے) ہوں گے، اور ہم گوری رنگت (اور) دلکش آنکھوں والی حوروں کو اُن کی زوجیت میں دے دیں گے،\qt@no{20}}%
\qt@newcmd\qurantrans@ur@mmmmdcclvi{اور جو لوگ ایمان لائے اور اُن کی اولاد نے ایمان میں اُن کی پیروی کی، ہم اُن کی اولاد کو (بھی) (درجاتِ جنت میں) اُن کے ساتھ ملا دیں گے (خواہ اُن کے اپنے عمل اس درجہ کے نہ بھی ہوں یہ صرف اُن کے صالح آباء کے اکرام میں ہوگا) اور ہم اُن (صالح آباء) کے ثوابِ اعمال سے بھی کوئی کمی نہیں کریں گے، (علاوہ اِس کے) ہر شخص اپنے ہی عمل (کی جزا و سزا) میں گرفتار ہوگا،\qt@no{21}}%
\qt@newcmd\qurantrans@ur@mmmmdcclvii{اور ہم انہیں پھل (میوے) اور گوشت، جو وہ چاہیں گے زیادہ سے زیادہ دیتے رہیں گے،\qt@no{22}}%
\qt@newcmd\qurantrans@ur@mmmmdcclviii{وہاں یہ لوگ جھپٹ جھپٹ کر (شرابِ طہور کے) جام لیں گے، اس (شرابِ جنت) میں نہ کوئی بے ہودہ گوئی ہوگی اور نہ گناہ گاری ہوگی،\qt@no{23}}%
\qt@newcmd\qurantrans@ur@mmmmdcclix{اور نوجوان (خدمت گزار) اُن کے اِردگرد گھومتے ہوں گے، گویا وہ غلاف میں چھپائے ہوئے موتی ہیں،\qt@no{24}}%
\qt@newcmd\qurantrans@ur@mmmmdcclx{اور وہ ایک دوسرے کی طرف متوجہ ہو کر باہم پرسشِ احوال کریں گے،\qt@no{25}}%
\qt@newcmd\qurantrans@ur@mmmmdcclxi{وہ کہیں گے: بیشک ہم اس سے پہلے اپنے گھروں میں (عذابِ الٰہی سے) ڈرتے رہتے تھے،\qt@no{26}}%
\qt@newcmd\qurantrans@ur@mmmmdcclxii{پس اﷲ نے ہم پر احسان فرما دیا اور ہمیں نارِ جہنّم کے عذاب سے بچا لیا،\qt@no{27}}%
\qt@newcmd\qurantrans@ur@mmmmdcclxiii{بیشک ہم پہلے سے ہی اُسی کی عبادت کیا کرتے تھے، بیشک وہ احسان فرمانے والا بڑا رحم فرمانے والا ہے،\qt@no{28}}%
\qt@newcmd\qurantrans@ur@mmmmdcclxiv{سو (اے حبیبِ مکرّم!) آپ نصیحت فرماتے رہیں پس آپ اپنے رب کے فضل و کرم سے نہ تو کاہن (یعنی جنّات کے ذریعے خبریں دینے والے) ہیں اور نہ دیوانے،\qt@no{29}}%
\qt@newcmd\qurantrans@ur@mmmmdcclxv{کیا (کفّار) کہتے ہیں: (یہ) شاعر ہیں؟ ہم اِن کے حق میں حوادثِ زمانہ کا انتظار کر رہے ہیں؟،\qt@no{30}}%
\qt@newcmd\qurantrans@ur@mmmmdcclxvi{فرما دیجئے: تم (بھی) منتظر رہو اور میں بھی تمہارے ساتھ (تمہاری ہلاکت کا) انتظار کرنے والوں میں ہوں،\qt@no{31}}%
\qt@newcmd\qurantrans@ur@mmmmdcclxvii{کیا اُن کی عقلیں انہیں یہ (بے عقلی کی باتیں) سُجھاتی ہیں یا وہ سرکش و باغی لوگ ہیں،\qt@no{32}}%
\qt@newcmd\qurantrans@ur@mmmmdcclxviii{یا وہ کہتے ہیں کہ اس (رسول) نے اس (قرآن) کو اَزخود گھڑ لیا ہے، (ایسا نہیں) بلکہ وہ (حق کو) مانتے ہی نہیں ہیں،\qt@no{33}}%
\qt@newcmd\qurantrans@ur@mmmmdcclxix{پس انہیں چاہئے کہ اِس (قرآن) جیسا کوئی کلام لے آئیں اگر وہ سچے ہیں،\qt@no{34}}%
\qt@newcmd\qurantrans@ur@mmmmdcclxx{کیا وہ کسی شے کے بغیر ہی پیدا کر دیئے گئے ہیں یا وہ خود ہی خالق ہیں،\qt@no{35}}%
\qt@newcmd\qurantrans@ur@mmmmdcclxxi{یا انہوں نے ہی آسمانوں اور زمین کو پیدا کیا ہے، (ایسا نہیں) بلکہ وہ (حق بات پر) یقین ہی نہیں رکھتے،\qt@no{36}}%
\qt@newcmd\qurantrans@ur@mmmmdcclxxii{یا اُن کے پاس آپ کے رب کے خزانے ہیں یا وہ اُن پر نگران (اور) داروغے ہیں،\qt@no{37}}%
\qt@newcmd\qurantrans@ur@mmmmdcclxxiii{یا اُن کے پاس کوئی سیڑھی ہے (جس پر چڑھ کر) وہ اُس (آسمان) میں کان لگا کر باتیں سن لیتے ہیں؟ سو جو اُن میں سے سننے والا ہے اُسے چاہئے کہ روشن دلیل لائے،\qt@no{38}}%
\qt@newcmd\qurantrans@ur@mmmmdcclxxiv{کیا اس (خدا) کے لئے بیٹیاں ہیں اور تمہارے لئے بیٹے ہیں،\qt@no{39}}%
\qt@newcmd\qurantrans@ur@mmmmdcclxxv{کیا آپ اُن سے کوئی اُجرت طلب فرماتے ہیں کہ وہ تاوان کے بوجھ سے دبے جا رہے ہیں،\qt@no{40}}%
\qt@newcmd\qurantrans@ur@mmmmdcclxxvi{کیا اُن کے پاس غیب (کا علم) ہے کہ وہ لکھ لیتے ہیں،\qt@no{41}}%
\qt@newcmd\qurantrans@ur@mmmmdcclxxvii{کیا وہ (آپ سے) کوئی چال چلنا چاہتے ہیں، تو جن لوگوں نے کفر کیا ہے وہ خود ہی اپنے دامِ فریب میں پھنسے جا رہے ہیں،\qt@no{42}}%
\qt@newcmd\qurantrans@ur@mmmmdcclxxviii{کیا اﷲ کے سوا اُن کا کوئی معبود ہے، اﷲ ہر اُس چیز سے پاک ہے جسے وہ (اﷲ کا) شریک ٹھہراتے ہیں،\qt@no{43}}%
\qt@newcmd\qurantrans@ur@mmmmdcclxxix{اور اگر وہ آسمان سے کوئی ٹکڑا (اپنے اوپر) گرتا ہوا دیکھ لیں تو (تب بھی یہ) کہیں گے کہ تہ بہ تہ (گہرا) بادل ہے،\qt@no{44}}%
\qt@newcmd\qurantrans@ur@mmmmdcclxxx{سو آپ اُن کو (اُن کے حال پر) چھوڑ دیجئے یہاں تک کہ وہ اپنے اس دن سے آملیں جس میں وہ ہلاک کر دیئے جائیں گے،\qt@no{45}}%
\qt@newcmd\qurantrans@ur@mmmmdcclxxxi{جس دِن نہ اُن کا مکر و فریب ان کے کچھ کام آئے گا اور نہ ہی اُن کی مدد کی جائے گے،\qt@no{46}}%
\qt@newcmd\qurantrans@ur@mmmmdcclxxxii{اور بیشک جو لوگ ظلم کر رہے ہیں اُن کے لئے اس عذاب کے علاوہ بھی عذاب ہے، لیکن اُن میں سے اکثر لوگ جانتے نہیں ہیں،\qt@no{47}}%
\qt@newcmd\qurantrans@ur@mmmmdcclxxxiii{اور (اے حبیبِ مکرّم! اِن کی باتوں سے غم زدہ نہ ہوں) آپ اپنے رب کے حکم کی خاطر صبر جاری رکھئے بیشک آپ (ہر وقت) ہماری آنکھوں کے سامنے (رہتے) ہیں٭ اور آپ اپنے رب کی حمد کے ساتھ تسبیح کیجئے جب بھی آپ کھڑے ہوں، ٭ اگر ان ظالموں نے نگاہیں پھیر لی ہیں تو کیا ہوا، ہم تو آپ کی طرف سے نگاہیں ہٹاتے ہی نہیں ہیں اور ہم ہر وقت آپ کو ہی تکتے رہتے ہیں۔\qt@no{48}}%
\qt@newcmd\qurantrans@ur@mmmmdcclxxxiv{اور رات کے اوقات میں بھی اس کی تسبیح کیجئے اور (پچھلی رات بھی) جب ستارے چھپتے ہیں،\qt@no{49}}%
\qt@newcmd\qurantrans@ur@mmmmdcclxxxv{\basmalahur قَسم ہے روشن ستارے (محمد صلی اللہ علیہ وآلہ وسلم) کی جب وہ (چشمِ زدن میں شبِ معراج اوپر جا کر) نیچے اترے،\qt@no{1}}%
\qt@newcmd\qurantrans@ur@mmmmdcclxxxvi{تمہیں (اپنی) صحبت سے نوازنے والے (یعنی تمہیں اپنے فیضِ صحبت سے صحابی بنانے والے رسول صلی اللہ علیہ وآلہ وسلم) نہ (کبھی) راہ بھولے اور نہ (کبھی) راہ سے بھٹکے،\qt@no{2}}%
\qt@newcmd\qurantrans@ur@mmmmdcclxxxvii{اور وہ (اپنی) خواہش سے کلام نہیں کرتے،\qt@no{3}}%
\qt@newcmd\qurantrans@ur@mmmmdcclxxxviii{اُن کا ارشاد سَراسَر وحی ہوتا ہے جو انہیں کی جاتی ہے،\qt@no{4}}%
\qt@newcmd\qurantrans@ur@mmmmdcclxxxix{ان کو بڑی قوّتوں و الے (رب) نے (براہِ راست) علمِ (کامل) سے نوازا،\qt@no{5}}%
\qt@newcmd\qurantrans@ur@mmmmdccxc{جو حسنِ مُطلَق ہے، پھر اُس (جلوۂ حُسن) نے (اپنے) ظہور کا ارادہ فرمایا،\qt@no{6}}%
\qt@newcmd\qurantrans@ur@mmmmdccxci{اور وہ (محمد صلی اللہ علیہ وآلہ وسلم شبِ معراج عالمِ مکاں کے) سب سے اونچے کنارے پر تھے (یعنی عالَمِ خلق کی انتہاء پر تھے)،\qt@no{7}}%
\qt@newcmd\qurantrans@ur@mmmmdccxcii{پھر وہ (ربّ العزّت اپنے حبیب محمد صلی اللہ علیہ وآلہ وسلم سے) قریب ہوا پھر اور زیادہ قریب ہوگیا٭، ٭ یہ معنی امام بخاری نے حضرت انس رضی اللہ عنہ سے الجامع الصحیح میں روایت کیا ہے، مزید حضرت عبد اﷲ بن عباس، امام حسن بصری، امام جعفر الصادق، محمد بن کعب القرظی التابعی، ضحّاک رضی اللہ عنہم اور دیگر کئی ائمہِ تفسیر کا قول بھی یہی ہے۔\qt@no{8}}%
\qt@newcmd\qurantrans@ur@mmmmdccxciii{پھر (جلوۂ حق اور حبیبِ مکرّم صلی اللہ علیہ وآلہ وسلم میں صرف) دو کمانوں کی مقدار فاصلہ رہ گیا یا (انتہائے قرب میں) اس سے بھی کم (ہو گیا)،\qt@no{9}}%
\qt@newcmd\qurantrans@ur@mmmmdccxciv{پس (اُس خاص مقامِ قُرب و وصال پر) اُس (اﷲ) نے اپنے عبدِ (محبوب) کی طرف وحی فرمائی جو (بھی) وحی فرمائی،\qt@no{10}}%
\qt@newcmd\qurantrans@ur@mmmmdccxcv{اُن کے) دل نے اُس کے خلاف نہیں جانا جو (اُن کی) آنکھوں نے دیکھا،\qt@no{11}}%
\qt@newcmd\qurantrans@ur@mmmmdccxcvi{کیا تم ان سے اِس پر جھگڑتے ہو کہ جو انہوں نے دیکھا،\qt@no{12}}%
\qt@newcmd\qurantrans@ur@mmmmdccxcvii{اور بیشک انہوں نے تو اُس (جلوۂ حق) کو دوسری مرتبہ (پھر) دیکھا (اور تم ایک بار دیکھنے پر ہی جھگڑ رہے ہو)٭، ٭ یہ معنی ابن عباس، ابوذر غفاری، عکرمہ التابعی، حسن البصری التابعی، محمد بن کعب القرظی التابعی، ابوالعالیہ الریاحی التابعی، عطا بن ابی رباح التابعی، کعب الاحبار التابعی، امام احمد بن حنبل اور امام ابوالحسن اشعری رضی اللہ عنہم اور دیگر ائمہ کے اَقوال پر ہے۔\qt@no{13}}%
\qt@newcmd\qurantrans@ur@mmmmdccxcviii{سِدرۃ المنتہٰی کے قریب،\qt@no{14}}%
\qt@newcmd\qurantrans@ur@mmmmdccxcix{اسی کے پاس جنت الْمَاْوٰى ہے،\qt@no{15}}%
\qt@newcmd\qurantrans@ur@mmmmdccc{جب نورِ حق کی تجلیّات سِدرَۃ (المنتہٰی) کو (بھی) ڈھانپ رہی تھیں جو کہ (اس پر) سایہ فگن تھیں٭، ٭ یہ معنی بھی امام حسن بصری رضی اللہ عنہ و دیگر ائمہ کے اقوال پر ہے۔\qt@no{16}}%
\qt@newcmd\qurantrans@ur@mmmmdccci{اور اُن کی آنکھ نہ کسی اور طرف مائل ہوئی اور نہ حد سے بڑھی (جس کو تکنا تھا اسی پر جمی رہی)،\qt@no{17}}%
\qt@newcmd\qurantrans@ur@mmmmdcccii{بیشک انہوں نے (معراج کی شب) اپنے رب کی بڑی نشانیاں دیکھیں،\qt@no{18}}%
\qt@newcmd\qurantrans@ur@mmmmdccciii{کیا تم نے لات اور عزٰی (دیویوں) پر غور کیا ہے،\qt@no{19}}%
\qt@newcmd\qurantrans@ur@mmmmdccciv{اور اُس تیسری ایک اور (دیوی) منات کو بھی (غور سے دیکھا ہے؟ تم نے انہیں اﷲ کی بیٹیاں بنا رکھا ہے؟)،\qt@no{20}}%
\qt@newcmd\qurantrans@ur@mmmmdcccv{اے مشرکو!) کیا تمہارے لئے بیٹے ہیں اور اس (اﷲ) کے لئے بیٹیاں ہیں،\qt@no{21}}%
\qt@newcmd\qurantrans@ur@mmmmdcccvi{اگر تمہارا تصور درست ہے) تب تو یہ تقسیم بڑی ناانصافی ہے،\qt@no{22}}%
\qt@newcmd\qurantrans@ur@mmmmdcccvii{مگر (حقیقت یہ ہے کہ) وہ (بت) محض نام ہی نام ہیں جو تم نے اور تمہارے باپ دادا نے رکھ لئے ہیں۔ اﷲ نے ان کی نسبت کوئی دلیل نہیں اتاری، وہ لوگ محض وہم و گمان کی اور نفسانی خواہشات کی پیروی کر رہے ہیں حالانکہ اُن کے پاس اُن کے رب کی طرف سے ہدایت آچکی ہے،\qt@no{23}}%
\qt@newcmd\qurantrans@ur@mmmmdcccviii{کیا انسان کے لئے وہ (سب کچھ) میسّر ہے جس کی وہ تمنا کرتا ہے،\qt@no{24}}%
\qt@newcmd\qurantrans@ur@mmmmdcccix{پس آخرت اور دنیا کا مالک تو اﷲ ہی ہے،\qt@no{25}}%
\qt@newcmd\qurantrans@ur@mmmmdcccx{اور آسمانوں میں کتنے ہی فرشتے ہیں (کہ کفّار و مشرکین اُن کی عبادت کرتے اور ان سے شفاعت کی امید رکھتے ہیں) جِن کی شفاعت کچھ کام نہیں آئے گی مگر اس کے بعد کہ اﷲ جسے چاہتا ہے اور پسند فرماتا ہے اُس کے لئے اِذن (جاری) فرما دیتا ہے،\qt@no{26}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxi{بیشک جو لوگ آخرت پر ایمان نہیں رکھتے وہ فرشتوں کو عورتوں کے نام سے موسوم کر دیتے ہیں،\qt@no{27}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxii{اور انہیں اِس کا کچھ بھی علم نہیں ہے، وہ صرف گمان کے پیچھے چلتے ہیں، اور بیشک گمان یقین کے مقابلے میں کسی کام نہیں آتا،\qt@no{28}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxiii{سو آپ اپنی توجّہ اس سے ہٹا لیں جو ہماری یاد سے رُوگردانی کرتا ہے اور سوائے دنیوی زندگی کے اور کوئی مقصد نہیں رکھتا،\qt@no{29}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxiv{اُن لوگوں کے علم کی رسائی کی یہی حد ہے، بیشک آپ کا رب اس شخص کو (بھی) خوب جانتا ہے جو اُس کی راہ سے بھٹک گیا ہے اور اس شخص کو (بھی) خوب جانتا ہے جِس نے ہدایت پا لی ہے،\qt@no{30}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxv{اور اﷲ ہی کے لئے ہے جو کچھ آسمانوں اور جو کچھ زمین میں ہے تاکہ جن لوگوں نے برائیاں کیں انہیں اُن کے اعمال کا بدلہ دے اور جن لوگوں نے نیکیاں کیں انہیں اچھا اجر عطا فرمائے،\qt@no{31}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxvi{جو لوگ چھوٹے گناہوں (اور لغزشوں) کے سوا بڑے گناہوں اور بے حیائی کے کاموں سے پرہیز کرتے ہیں، بیشک آپ کا رب بخشش کی بڑی گنجائش رکھنے والا ہے، وہ تمہیں خوب جانتا ہے جب اس نے تمہاری زندگی کی ابتداء اور نشو و نما زمین (یعنی مٹی) سے کی تھی اور جبکہ تم اپنی ماؤں کے پیٹ میں جَنیِن (یعنی حمل) کی صورت میں تھے، پس تم اپنے آپ کو بڑا پاک و صاف مَت جتایا کرو، وہ خوب جانتا ہے کہ (اصل) پرہیزگار کون ہے،\qt@no{32}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxvii{کیا آپ نے اس شخص کو دیکھا جس نے (حق سے) منہ پھیر لیا،\qt@no{33}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxviii{اور اس نے (راہِ حق میں) تھوڑا سا (مال) دیا اور (پھر ہاتھ) روک لیا،\qt@no{34}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxix{کیا اس کے پاس غیب کا علم ہے کہ وہ دیکھ رہا ہے،\qt@no{35}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxx{کیا اُسے اُن (باتوں) کی خبر نہیں دی گئی جو موسٰی (علیہ السلام) کے صحیفوں میں (مذکور) تھیں،\qt@no{36}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxxi{اور ابراہیم (علیہ السلام) کے (صحیفوں میں تھیں) جنہوں نے (اﷲ کے ہر امر کو) بتمام و کمال پورا کیا،\qt@no{37}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxxii{کہ کوئی بوجھ اٹھانے والا کسی دوسرے (کے گناہوں) کا بوجھ نہیں اٹھائے گا،\qt@no{38}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxxiii{اور یہ کہ انسان کو (عدل میں) وہی کچھ ملے گا جس کی اُس نے کوشش کی ہوگی (رہا فضل اس پر کسی کا حق نہیں وہ محض اﷲ کی عطاء و رضا ہے جس پر جتنا چاہے کر دے)،\qt@no{39}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxxiv{اور یہ کہ اُس کی ہر کوشش عنقریب دکھا دی جائے گی (یعنی ظاہر کر دی جائے گی)،\qt@no{40}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxxv{پھر اُسے (اُس کی ہر کوشش کا) پورا پورا بدلہ دیا جائے گا،\qt@no{41}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxxvi{اور یہ کہ (بالآخر سب کو) آپ کے رب ہی کی طرف پہنچنا ہے،\qt@no{42}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxxvii{اور یہ کہ وہی (خوشی دے کر) ہنساتا ہے اور (غم دے کر) رُلاتا ہے،\qt@no{43}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxxviii{اور یہ کہ وہی مارتا ہے اور جِلاتا ہے،\qt@no{44}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxxix{اور یہ کہ اُسی نے نَر اور مادہ دو قِسموں کو پیدا کیا،\qt@no{45}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxxx{نطفہ (ایک تولیدی قطرہ) سے جبکہ وہ (رَحمِ مادہ میں) ٹپکایا جاتا ہے،\qt@no{46}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxxxi{اور یہ کہ (مرنے کے بعد) دوبارہ زندہ کرنا (بھی) اسی پر ہے،\qt@no{47}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxxxii{اور یہ کہ وہی (بقدرِ ضرورت دے کر) غنی کر دیتا ہے اور وہی (ضرورت سے زائد دے کر) خزانے بھر دیتا ہے،\qt@no{48}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxxxiii{اور یہ کہ وہی شِعرٰی (ستارے) کا رب ہے (جس کی دورِ جاہلیت میں پوجا کی جاتی تھی)،\qt@no{49}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxxxiv{اور یہ کہ اسی نے پہلی (قومِ) عاد کو ہلاک کیا،\qt@no{50}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxxxv{اور (قومِ) ثمود کو (بھی)، پھر (ان میں سے کسی کو) باقی نہ چھوڑا،\qt@no{51}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxxxvi{اور اس سے پہلے قومِ نوح کو (بھی ہلاک کیا)، بیشک وہ بڑے ہی ظالم اور بڑے ہی سرکش تھے،\qt@no{52}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxxxvii{اور (قومِ لُوط کی) الٹی ہوئی بستیوں کو (اوپر اٹھا کر) اُسی نے نیچے دے پٹکا،\qt@no{53}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxxxviii{پس اُن کو ڈھانپ لیا جس نے ڈھانپ لیا (یعنی پھر اُن پر پتھروں کی بارش کر دی گئی)،\qt@no{54}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxxxix{سو (اے انسان!) تو اپنے پروردگار کی کن کن نعمتوں میں شک کرے گا،\qt@no{55}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxl{یہ (رسولِ اکرم صلی اللہ علیہ وآلہ وسلم بھی) اگلے ڈر سنانے والوں میں سے ایک ڈر سنانے والے ہیں،\qt@no{56}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxli{آنے والی (قیامت کی گھڑی) قریب آپہنچی،\qt@no{57}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxlii{اﷲ کے سوا اِسے کوئی ظاہر (اور قائم) کرنے والا نہیں ہے،\qt@no{58}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxliii{پس کیا تم اس کلام سے تعجب کرتے ہو،\qt@no{59}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxliv{اور تم ہنستے ہو اور روتے نہیں ہو،\qt@no{60}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxlv{اور تم (غفلت کی) کھیل میں پڑے ہو،\qt@no{61}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxlvi{سو اﷲ کے لئے سجدہ کرو اور (اُس کی) عبادت کرو،\qt@no{62}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxlvii{\basmalahur قیامت قریب آپہنچی اور چاند دو ٹکڑے ہوگیا،\qt@no{1}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxlviii{اور اگر وہ (کفّار) کوئی نشانی (یعنی معجزہ) دیکھتے ہیں تو مُنہ پھیر لیتے ہیں اور کہتے ہیں کہ (یہ تو) ہمیشہ سے چلا آنے والا طاقتور جادو ہے،\qt@no{2}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxlix{اور انہوں نے (اب بھی) جھٹلایا اور اپنی خواہشات کے پیچھے چلے اور ہر کام (جس کا وعدہ کیا گیا ہے) مقررّہ وقت پر ہونے والا ہے،\qt@no{3}}%
\qt@newcmd\qurantrans@ur@mmmmdcccl{اور بیشک اُن کے پاس (پہلی قوموں کی) ایسی خبریں آچکی ہیں جن میں (کفر و نافرمانی پر بڑی) عبرت و سرزنش ہے،\qt@no{4}}%
\qt@newcmd\qurantrans@ur@mmmmdcccli{یہ قرآن) کامل دانائی و حکمت ہے کیا پھر بھی ڈر سنانے والے کچھ فائدہ نہیں دیتے،\qt@no{5}}%
\qt@newcmd\qurantrans@ur@mmmmdccclii{سو آپ اُن سے منہ پھیر لیں، جس دن بلانے والا (فرشتہ) ایک نہایت ناگوار چیز (میدانِ حشر) کی طرف بلائے گا،\qt@no{6}}%
\qt@newcmd\qurantrans@ur@mmmmdcccliii{اپنی آنکھیں جھکائے ہوئے قبروں سے نکل پڑیں گے گویا وہ پھیلی ہوئی ٹڈیاں ہیں،\qt@no{7}}%
\qt@newcmd\qurantrans@ur@mmmmdcccliv{پکارنے والے کی طرف دوڑ کر جا رہے ہوں گے، کفّار کہتے ہوں گے: یہ بڑا سخت دِن ہے،\qt@no{8}}%
\qt@newcmd\qurantrans@ur@mmmmdccclv{اِن سے پہلے قومِ نوح نے (بھی) جھٹلایا تھا۔ سو انہوں نے ہمارے بندۂ (مُرسَل نُوح علیہ السلام) کی تکذیب کی اور کہا: (یہ) دیوانہ ہے، اور انہیں دھمکیاں دی گئیں،\qt@no{9}}%
\qt@newcmd\qurantrans@ur@mmmmdccclvi{سو انہوں نے اپنے رب سے دعا کی کہ میں (اپنی قوم کے مظالم سے) عاجز ہوں پس تو انتقام لے،\qt@no{10}}%
\qt@newcmd\qurantrans@ur@mmmmdccclvii{پھر ہم نے موسلادھار بارش کے ساتھ آسمان کے دروازے کھول دئیے،\qt@no{11}}%
\qt@newcmd\qurantrans@ur@mmmmdccclviii{اور ہم نے زمین سے چشمے جاری کر دیئے، سو (زمین و آسمان کا) پانی ایک ہی کام کے لئے جمع ہو گیا جو (اُن کی ہلاکت کے لئے) پہلے سے مقرر ہو چکا تھا،\qt@no{12}}%
\qt@newcmd\qurantrans@ur@mmmmdccclix{اور ہم نے اُن کو (یعنی نوح علیہ السلام کو) تختوں اور میخوں والی (کشتی) پر سوار کر لیا،\qt@no{13}}%
\qt@newcmd\qurantrans@ur@mmmmdccclx{جو ہماری نگاہوں کے سامنے (ہماری حفاظت میں) چلتی تھی، (یہ سب کچھ) اس (ایک) شخص (نوح علیہ السلام) کا بدلہ لینے کی خاطر تھا جس کا انکار کیا گیا تھا،\qt@no{14}}%
\qt@newcmd\qurantrans@ur@mmmmdccclxi{اور بیشک ہم نے اِس (طوفانِ نوح کے آثار) کو نشانی کے طور پر باقی رکھا تو کیا کوئی سوچنے (اور نصیحت قبول کرنے) والا ہے،\qt@no{15}}%
\qt@newcmd\qurantrans@ur@mmmmdccclxii{سو میرا عذاب اور میرا ڈرانا کیسا تھا؟،\qt@no{16}}%
\qt@newcmd\qurantrans@ur@mmmmdccclxiii{اور بیشک ہم نے قرآن کو نصیحت کے لئے آسان کر دیا ہے تو کیا کوئی نصیحت قبول کرنے والا ہے،\qt@no{17}}%
\qt@newcmd\qurantrans@ur@mmmmdccclxiv{قومِ) عاد نے بھی (پیغمبروں کو) جھٹلایا تھا سو (اُن پر) میرا عذاب اور میرا ڈرانا کیسا (عبرت ناک) رہا،\qt@no{18}}%
\qt@newcmd\qurantrans@ur@mmmmdccclxv{بیشک ہم نے اُن پر نہایت سخت آواز والی تیز آندھی (اُن کے حق میں) دائمی نحوست کے دن میں بھیجی،\qt@no{19}}%
\qt@newcmd\qurantrans@ur@mmmmdccclxvi{جو لوگوں کو (اس طرح) اکھاڑ پھینکتی تھی گویا وہ اکھڑے ہوئے کھجور کے درختوں کے تنے ہیں،\qt@no{20}}%
\qt@newcmd\qurantrans@ur@mmmmdccclxvii{پھر میرا عذاب اور میرا ڈرانا کیسا (عبرت ناک) رہا،\qt@no{21}}%
\qt@newcmd\qurantrans@ur@mmmmdccclxviii{اور بیشک ہم نے قرآن کو نصیحت کے لئے آسان کر دیا ہے سو کیا کوئی نصیحت حاصل کرنے والا ہے،\qt@no{22}}%
\qt@newcmd\qurantrans@ur@mmmmdccclxix{قومِ) ثمود نے بھی ڈرسنانے والے پیغمبروں کو جھٹلایا،\qt@no{23}}%
\qt@newcmd\qurantrans@ur@mmmmdccclxx{پس وہ کہنے لگے: کیا ایک بشر جو ہم ہی میں سے ہے، ہم اس کی پیروی کریں، تب تو ہم یقیناً گمراہی اور دیوانگی میں ہوں گے،\qt@no{24}}%
\qt@newcmd\qurantrans@ur@mmmmdccclxxi{کیا ہم سب میں سے اسی پر نصیحت (یعنی وحی) اتاری گئی ہے؟ بلکہ وہ بڑا جھوٹا، خود پسند (اور متکبّر) ہے،\qt@no{25}}%
\qt@newcmd\qurantrans@ur@mmmmdccclxxii{انہیں کل (قیامت کے دن) ہی معلوم ہو جائے گا کہ کون بڑا جھوٹا، خود پسند (اور متکبّر) ہے،\qt@no{26}}%
\qt@newcmd\qurantrans@ur@mmmmdccclxxiii{بیشک ہم اُن کی آزمائش کے لئے اونٹنی بھیجنے والے ہیں، پس (اے صالح!) اُن (کے انجام) کا انتظار کریں اور صبر جاری رکھیں،\qt@no{27}}%
\qt@newcmd\qurantrans@ur@mmmmdccclxxiv{اور انہیں اس بات سے آگاہ کر دیں کہ اُن کے (اور اونٹنی کے) درمیان پانی تقسیم کر دیا گیا ہے، ہر ایک (کو) پانی کا حصّہ اس کی باری پر حاضر کیا جائے گا،\qt@no{28}}%
\qt@newcmd\qurantrans@ur@mmmmdccclxxv{پس انہوں نے (قدار نامی) اپنے ایک ساتھی کو بلایا، اس نے (اونٹنی پر تلوار سے) وار کیا اور کونچیں کاٹ دیں،\qt@no{29}}%
\qt@newcmd\qurantrans@ur@mmmmdccclxxvi{پھر میرا عذاب اور میرا ڈرانا کیسا (عبرت ناک) ہوا؟،\qt@no{30}}%
\qt@newcmd\qurantrans@ur@mmmmdccclxxvii{بیشک ہم نے اُن پر ایک نہایت خوفناک آواز بھیجی سو وہ باڑ لگانے والے کے بچے ہوئے اور روندے گئے بھوسے کی طرح ہوگئے،\qt@no{31}}%
\qt@newcmd\qurantrans@ur@mmmmdccclxxviii{اور بیشک ہم نے قرآن کو نصیحت کے لئے آسان کر دیا ہے تو کیا کوئی نصیحت حاصل کرنے والا ہے،\qt@no{32}}%
\qt@newcmd\qurantrans@ur@mmmmdccclxxix{قومِ لُوط نے بھی ڈرسنانے والوں کو جھٹلایا،\qt@no{33}}%
\qt@newcmd\qurantrans@ur@mmmmdccclxxx{بیشک ہم نے اُن پر کنکریاں برسانے والی آندھی بھیجی سوائے اولادِ لُوط (علیہ السلام) کے، ہم نے انہیں پچھلی رات (عذاب سے) بچا لیا،\qt@no{34}}%
\qt@newcmd\qurantrans@ur@mmmmdccclxxxi{اپنی طرف سے خاص انعام کے ساتھ، اسی طرح ہم اس شخص کو جزا دیا کرتے ہیں جو شکر گزار ہوتا ہے،\qt@no{35}}%
\qt@newcmd\qurantrans@ur@mmmmdccclxxxii{اور بیشک لُوط (علیہ السلام) نے انہیں ہماری پکڑ سے ڈرایا تھا پھر اُن لوگوں نے اُن کے ڈرانے میں شک کرتے ہوئے جھٹلایا،\qt@no{36}}%
\qt@newcmd\qurantrans@ur@mmmmdccclxxxiii{اور بیشک اُن لوگوں نے لُوط (علیہ السلام) سے اُن کے مہمانوں کو چھین لینے کا ارادہ کیا سو ہم نے اُن کی آنکھوں کی ساخت مٹا کر انہیں بے نور کر دیا۔ پھر (اُن سے کہا:) میرے عذاب اور ڈرانے کا مزہ چکھو،\qt@no{37}}%
\qt@newcmd\qurantrans@ur@mmmmdccclxxxiv{اور بیشک اُن پر صبح سویرے ہی ہمیشہ قائم رہنے والا عذاب آپہنچا،\qt@no{38}}%
\qt@newcmd\qurantrans@ur@mmmmdccclxxxv{پھر (اُن سے کہا گیا:) میرے عذاب اور ڈرانے کا مزہ چکھو،\qt@no{39}}%
\qt@newcmd\qurantrans@ur@mmmmdccclxxxvi{اور بیشک ہم نے قرآن کو نصیحت کے لئے آسان کر دیا ہے تو کیا کوئی نصیحت حاصل کرنے والا ہے،\qt@no{40}}%
\qt@newcmd\qurantrans@ur@mmmmdccclxxxvii{اور بیشک قومِ فرعون کے پاس (بھی) ڈر سنانے والے آئے،\qt@no{41}}%
\qt@newcmd\qurantrans@ur@mmmmdccclxxxviii{انہوں نے ہماری سب نشانیوں کو جھٹلا دیا پھر ہم نے انہیں بڑے غالب بڑی قدرت والے کی پکڑ کی شان کے مطابق پکڑ لیا،\qt@no{42}}%
\qt@newcmd\qurantrans@ur@mmmmdccclxxxix{اے قریشِ مکہ!) کیا تمہارے کافر اُن (اگلے) لوگوں سے بہتر ہیں یا تمہارے لئے (آسمانی) کتابوں میں نجات لکھی ہوئی ہے،\qt@no{43}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxc{یا یہ (کفّار) کہتے ہیں کہ ہم (نبیِ مکرّم صلی اللہ علیہ وآلہ وسلم پر) غالب رہنے والی مضبوط جماعت ہیں،\qt@no{44}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxci{عنقریب یہ جتّھہ (میدانِ بدر میں) شکست کھائے گا اور یہ لوگ پیٹھ پھیر کر بھاگ جائیں گے،\qt@no{45}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxcii{بلکہ اُن کا (اصل) وعدہ تو قیامت ہے اور قیامت کی گھڑی بہت ہی سخت اور بہت ہی تلخ ہے،\qt@no{46}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxciii{بیشک مجرم لوگ گمراہی اور دیوانگی (یا آگ کی لپیٹ) میں ہیں،\qt@no{47}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxciv{جس دن وہ لوگ اپنے مُنہ کے بل دوزخ میں گھسیٹے جائیں گے (تو اُن سے کہا جائے گا:) آگ میں جلنے کا مزہ چکھو،\qt@no{48}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxcv{بیشک ہم نے ہر چیز کو ایک مقرّرہ اندازے کے مطابق بنایا ہے،\qt@no{49}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxcvi{اور ہمارا حکم تو فقط یک بارگی واقع ہو جاتا ہے جیسے آنکھ کا جھپکنا ہے،\qt@no{50}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxcvii{اور بیشک ہم نے تمہارے (بہت سے) گروہوں کو ہلاک کر ڈالا، سو کیا کوئی نصیحت حاصل کرنے والا ہے،\qt@no{51}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxcviii{اور جو کچھ (بھی) انہوں نے کیا اعمال ناموں میں (درج) ہے،\qt@no{52}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxcix{اور ہر چھوٹا اور بڑا (عمل) لکھ دیا گیا ہے،\qt@no{53}}%
\qt@newcmd\qurantrans@ur@mmmmcm{بیشک پرہیزگار جنتوں اور نہروں میں (لطف اندوز) ہوں گے،\qt@no{54}}%
\qt@newcmd\qurantrans@ur@mmmmcmi{پاکیزہ مجالس میں (حقیقی) اقتدار کے مالک بادشاہ کی خاص قربت میں (بیٹھے) ہوں گے،\qt@no{55}}%
\qt@newcmd\qurantrans@ur@mmmmcmii{\basmalahur (وہ) رحمان ہی ہے،\qt@no{1}}%
\qt@newcmd\qurantrans@ur@mmmmcmiii{جس نے (خود رسولِ عربی صلی اللہ علیہ وآلہ وسلم کو) قرآن سکھایا٭، ٭ کفّار و مشرکینِ مکہ کے اِس الزام کے جواب میں یہ آیت اتری کہ محمد صلی اللہ علیہ وآلہ وسلم کو (معاذ اللہ) کوئی شخص خفیہ قرآن سکھاتا ہے۔ حوالہ جات کے لئے ملاحظہ کریں: تفسیر بغوی، خازن، القشیری، البحر المحیط، الجمل، فتح القدیر، المظہری، اللباب، الصاوی، السراج المنیر، مراغی، اضواء البیان اور مجمع البیان وغیرھم۔\qt@no{2}}%
\qt@newcmd\qurantrans@ur@mmmmcmiv{اُسی نے (اِس کامل) انسان کو پیدا فرمایا،\qt@no{3}}%
\qt@newcmd\qurantrans@ur@mmmmcmv{اسی نے اِسے (یعنی نبیِ برحق صلی اللہ علیہ وآلہ وسلم کو مَا کَانَ وَ مَا یَکُونُ کا) بیان سکھایا٭، ٭ مفسرین کرام نے بیان کا معنی علمِ مَا کَانَ وَ مَا یَکُونُ بھی بیان کیا ہے۔ حوالہ جات کے لئے ملاخطہ کریں: تفسیر بغوی، خازن، جمل، المظہری، اللباب، زاد المسیر، صاوی، السراج المنیر اور مجمع البیان۔\qt@no{4}}%
\qt@newcmd\qurantrans@ur@mmmmcmvi{سورج اور چاند (اسی کے) مقررّہ حساب سے چل رہے ہیں،\qt@no{5}}%
\qt@newcmd\qurantrans@ur@mmmmcmvii{اور زمین پر پھیلنے والی بوٹیاں اور سب درخت (اسی کو) سجدہ کر رہے ہیں،\qt@no{6}}%
\qt@newcmd\qurantrans@ur@mmmmcmviii{اور اسی نے آسمان کو بلند کر رکھا ہے اور (اسی نے عدل کے لئے) ترازو قائم کر رکھی ہے،\qt@no{7}}%
\qt@newcmd\qurantrans@ur@mmmmcmix{تاکہ تم تولنے میں بے اعتدالی نہ کرو،\qt@no{8}}%
\qt@newcmd\qurantrans@ur@mmmmcmx{اور انصاف کے ساتھ وزن کو ٹھیک رکھو اور تول کو کم نہ کرو،\qt@no{9}}%
\qt@newcmd\qurantrans@ur@mmmmcmxi{زمین کو اسی نے مخلوق کے لئے بچھا دیا،\qt@no{10}}%
\qt@newcmd\qurantrans@ur@mmmmcmxii{اس میں میوے ہیں اور خوشوں والی کھجوریں ہیں،\qt@no{11}}%
\qt@newcmd\qurantrans@ur@mmmmcmxiii{اور بھوسہ والا اناج ہے اور خوشبودار (پھل) پھول ہیں،\qt@no{12}}%
\qt@newcmd\qurantrans@ur@mmmmcmxiv{پس (اے گروہِ جنّ و انسان!) تم دونوں اپنے رب کی کن کن نعمتوں کو جھٹلاؤ گے،\qt@no{13}}%
\qt@newcmd\qurantrans@ur@mmmmcmxv{اسی نے انسان کو ٹھیکری کی طرح بجتے ہوئے خشک گارے سے بنایا،\qt@no{14}}%
\qt@newcmd\qurantrans@ur@mmmmcmxvi{اور جنّات کو آگ کے شعلے سے پیدا کیا،\qt@no{15}}%
\qt@newcmd\qurantrans@ur@mmmmcmxvii{پس تم دونوں اپنے رب کی کن کن نعمتوں کو جھٹلاؤ گے،\qt@no{16}}%
\qt@newcmd\qurantrans@ur@mmmmcmxviii{وہی) دونوں مشرقوں کا مالک ہے اور (وہی) دونوں مغربوں کا مالک ہے،\qt@no{17}}%
\qt@newcmd\qurantrans@ur@mmmmcmxix{پس تم دونوں اپنے رب کی کن کن نعمتوں کو جھٹلاؤ گے،\qt@no{18}}%
\qt@newcmd\qurantrans@ur@mmmmcmxx{اسی نے دو سمندر رواں کئے جو باہم مل جاتے ہیں،\qt@no{19}}%
\qt@newcmd\qurantrans@ur@mmmmcmxxi{اُن دونوں کے درمیان ایک آڑ ہے وہ (اپنی اپنی) حد سے تجاوز نہیں کرسکتے،\qt@no{20}}%
\qt@newcmd\qurantrans@ur@mmmmcmxxii{پس تم دونوں اپنے رب کی کن کن نعمتوں کو جھٹلاؤ گے،\qt@no{21}}%
\qt@newcmd\qurantrans@ur@mmmmcmxxiii{اُن دونوں (سمندروں) سے موتی (جس کی جھلک سبز ہوتی ہے) اور مَرجان (جِس کی رنگت سرخ ہوتی ہے) نکلتے ہیں،\qt@no{22}}%
\qt@newcmd\qurantrans@ur@mmmmcmxxiv{پس تم دونوں اپنے رب کی کن کن نعمتوں کو جھٹلاؤ گے،\qt@no{23}}%
\qt@newcmd\qurantrans@ur@mmmmcmxxv{اوربلند بادبان والے بڑے بڑے جہاز (بھی) اسی کے (اختیار میں) ہیں جو پہاڑوں کی طرح سمندر میں (کھڑے ہوتے یا چلتے) ہیں،\qt@no{24}}%
\qt@newcmd\qurantrans@ur@mmmmcmxxvi{پس تم دونوں اپنے رب کی کن کن نعمتوں کو جھٹلاؤ گے،\qt@no{25}}%
\qt@newcmd\qurantrans@ur@mmmmcmxxvii{ہر کوئی جو بھی زمین پر ہے فنا ہو جانے والا ہے،\qt@no{26}}%
\qt@newcmd\qurantrans@ur@mmmmcmxxviii{اور آپ کے رب ہی کی ذات باقی رہے گی جو صاحبِ عظمت و جلال اور صاحبِ انعام و اکرام ہے،\qt@no{27}}%
\qt@newcmd\qurantrans@ur@mmmmcmxxix{پس تم دونوں اپنے رب کی کن کن نعمتوں کو جھٹلاؤ گے،\qt@no{28}}%
\qt@newcmd\qurantrans@ur@mmmmcmxxx{سب اسی سے مانگتے ہیں جو بھی آسمانوں اور زمین میں ہیں۔ وہ ہر آن نئی شان میں ہوتا ہے،\qt@no{29}}%
\qt@newcmd\qurantrans@ur@mmmmcmxxxi{پس تم دونوں اپنے رب کی کن کن نعمتوں کو جھٹلاؤ گے،\qt@no{30}}%
\qt@newcmd\qurantrans@ur@mmmmcmxxxii{اے ہر دو گروہانِ (اِنس و جِن!) ہم عنقریب تمہارے حساب کی طرف متوّجہ ہوتے ہیں،\qt@no{31}}%
\qt@newcmd\qurantrans@ur@mmmmcmxxxiii{پس تم دونوں اپنے رب کی کن کن نعمتوں کو جھٹلاؤ گے،\qt@no{32}}%
\qt@newcmd\qurantrans@ur@mmmmcmxxxiv{اے گروہِ جن و اِنس! اگر تم اِس بات پر قدرت رکھتے ہو کہ آسمانوں اور زمین کے کناروں سے باہر نکل سکو (اور تسخیرِ کائنات کرو) تو تم نکل جاؤ، تم جس (کرّۂ سماوی کے) مقام پر بھی نکل کر جاؤ گے وہاں بھی اسی کی سلطنت ہوگی،\qt@no{33}}%
\qt@newcmd\qurantrans@ur@mmmmcmxxxv{پس تم دونوں اپنے رب کی کن کن نعمتوں کو جھٹلاؤ گے،\qt@no{34}}%
\qt@newcmd\qurantrans@ur@mmmmcmxxxvi{تم دونوں پر آگ کے خالص شعلے بھیج دیئے جائیں گے اور (بغیر شعلوں کے) دھواں (بھی بھیجا جائے گا) اور تم دونوں اِن سے بچ نہ سکو گے،\qt@no{35}}%
\qt@newcmd\qurantrans@ur@mmmmcmxxxvii{پس تم دونوں اپنے رب کی کن کن نعمتوں کو جھٹلاؤ گے،\qt@no{36}}%
\qt@newcmd\qurantrans@ur@mmmmcmxxxviii{پھر جب آسمان پھٹ جائیں گے اور جلے ہوئے تیل (یا سرخ چمڑے) کی طرح گلابی ہو جائیں گے،\qt@no{37}}%
\qt@newcmd\qurantrans@ur@mmmmcmxxxix{پس تم دونوں اپنے رب کی کن کن نعمتوں کو جھٹلاؤ گے،\qt@no{38}}%
\qt@newcmd\qurantrans@ur@mmmmcmxl{سو اُس دن نہ تو کسی انسان سے اُس کے گناہ کی بابت پوچھا جائے گا اور نہ ہی کسی جِن سے،\qt@no{39}}%
\qt@newcmd\qurantrans@ur@mmmmcmxli{پس تم دونوں اپنے رب کی کن کن نعمتوں کو جھٹلاؤ گے،\qt@no{40}}%
\qt@newcmd\qurantrans@ur@mmmmcmxlii{مجرِم لوگ اپنے چہروں کی سیاہی سے پہچان لئے جائیں گے پس انہیں پیشانی کے بالوں اور پاؤں سے پکڑ کر کھینچا جائے گا،\qt@no{41}}%
\qt@newcmd\qurantrans@ur@mmmmcmxliii{پس تم دونوں اپنے رب کی کن کن نعمتوں کو جھٹلاؤ گے،\qt@no{42}}%
\qt@newcmd\qurantrans@ur@mmmmcmxliv{اُن سے کہا جائے گا:) یہی ہے وہ دوزخ جسے مجرِم لوگ جھٹلایا کرتے تھے،\qt@no{43}}%
\qt@newcmd\qurantrans@ur@mmmmcmxlv{وہ اُس (دوزخ) میں اور کھولتے گرم پانی میں گھومتے پھریں گے،\qt@no{44}}%
\qt@newcmd\qurantrans@ur@mmmmcmxlvi{پس تم دونوں اپنے رب کی کن کن نعمتوں کو جھٹلاؤ گے،\qt@no{45}}%
\qt@newcmd\qurantrans@ur@mmmmcmxlvii{اور جو شخص اپنے رب کے حضور (پیشی کے لئے) کھڑا ہونے سے ڈرتا ہے اُس کے لئے دو جنتیں ہیں،\qt@no{46}}%
\qt@newcmd\qurantrans@ur@mmmmcmxlviii{پس تم دونوں اپنے رب کی کن کن نعمتوں کو جھٹلاؤ گے،\qt@no{47}}%
\qt@newcmd\qurantrans@ur@mmmmcmxlix{جو دونوں (سرسبز و شاداب) گھنی شاخوں والی (جنتیں) ہیں،\qt@no{48}}%
\qt@newcmd\qurantrans@ur@mmmmcml{پس تم دونوں اپنے رب کی کن کن نعمتوں کو جھٹلاؤ گے،\qt@no{49}}%
\qt@newcmd\qurantrans@ur@mmmmcmli{ان دونوں میں دو چشمے بہہ رہے ہیں،\qt@no{50}}%
\qt@newcmd\qurantrans@ur@mmmmcmlii{پس تم دونوں اپنے رب کی کن کن نعمتوں کو جھٹلاؤ گے،\qt@no{51}}%
\qt@newcmd\qurantrans@ur@mmmmcmliii{ان دونوں میں ہر پھل (اور میوے) کی دو دو قِسمیں ہیں،\qt@no{52}}%
\qt@newcmd\qurantrans@ur@mmmmcmliv{پس تم دونوں اپنے رب کی کن کن نعمتوں کو جھٹلاؤ گے،\qt@no{53}}%
\qt@newcmd\qurantrans@ur@mmmmcmlv{اہلِ جنت ایسے بستروں پر تکیے لگائے بیٹھے ہوں گے جن کے استر نفِیس اور دبیز ریشم (یعنی اَطلس) کے ہوں گے، اور دونوں جنتوں کے پھل (اُن کے) قریب جھک رہے ہوں گے،\qt@no{54}}%
\qt@newcmd\qurantrans@ur@mmmmcmlvi{پس تم دونوں اپنے رب کی کن کن نعمتوں کو جھٹلاؤ گے،\qt@no{55}}%
\qt@newcmd\qurantrans@ur@mmmmcmlvii{اور اُن میں نیچی نگاہ رکھنے والی (حوریں) ہوں گی جنہیں پہلے نہ کسی انسان نے ہاتھ لگایا اور نہ کسی جِن نے،\qt@no{56}}%
\qt@newcmd\qurantrans@ur@mmmmcmlviii{پس تم دونوں اپنے رب کی کن کن نعمتوں کو جھٹلاؤ گے،\qt@no{57}}%
\qt@newcmd\qurantrans@ur@mmmmcmlix{گویا وہ (حوریں) یا قوت اور مرجان ہیں،\qt@no{58}}%
\qt@newcmd\qurantrans@ur@mmmmcmlx{پس تم دونوں اپنے رب کی کن کن نعمتوں کو جھٹلاؤ گے،\qt@no{59}}%
\qt@newcmd\qurantrans@ur@mmmmcmlxi{نیکی کا بدلہ نیکی کے سوا کچھ نہیں ہے،\qt@no{60}}%
\qt@newcmd\qurantrans@ur@mmmmcmlxii{پس تم دونوں اپنے رب کی کن کن نعمتوں کو جھٹلاؤ گے،\qt@no{61}}%
\qt@newcmd\qurantrans@ur@mmmmcmlxiii{اور (اُن کے لئے) اِن دو کے سوا دو اور بہشتیں بھی ہیں،\qt@no{62}}%
\qt@newcmd\qurantrans@ur@mmmmcmlxiv{پس تم دونوں اپنے رب کی کن کن نعمتوں کو جھٹلاؤ گے،\qt@no{63}}%
\qt@newcmd\qurantrans@ur@mmmmcmlxv{وہ دونوں گہری سبز رنگت میں سیاہی مائل لگتی ہیں،\qt@no{64}}%
\qt@newcmd\qurantrans@ur@mmmmcmlxvi{پس تم دونوں اپنے رب کی کن کن نعمتوں کو جھٹلاؤ گے،\qt@no{65}}%
\qt@newcmd\qurantrans@ur@mmmmcmlxvii{اُن دونوں میں (بھی) دو چشمے ہیں جو خوب چھلک رہے ہوں گے،\qt@no{66}}%
\qt@newcmd\qurantrans@ur@mmmmcmlxviii{پس تم دونوں اپنے رب کی کن کن نعمتوں کو جھٹلاؤ گے،\qt@no{67}}%
\qt@newcmd\qurantrans@ur@mmmmcmlxix{ان دونوں میں (بھی) پھل اور کھجوریں اور انار ہیں،\qt@no{68}}%
\qt@newcmd\qurantrans@ur@mmmmcmlxx{پس تم دونوں اپنے رب کی کن کن نعمتوں کو جھٹلاؤ گے،\qt@no{69}}%
\qt@newcmd\qurantrans@ur@mmmmcmlxxi{ان میں (بھی) خوب سیرت و خوب صورت (حوریں) ہیں،\qt@no{70}}%
\qt@newcmd\qurantrans@ur@mmmmcmlxxii{پس تم دونوں اپنے رب کی کن کن نعمتوں کو جھٹلاؤ گے،\qt@no{71}}%
\qt@newcmd\qurantrans@ur@mmmmcmlxxiii{ایسی حوریں جو خیموں میں پردہ نشین ہیں،\qt@no{72}}%
\qt@newcmd\qurantrans@ur@mmmmcmlxxiv{پس تم دونوں اپنے رب کی کن کن نعمتوں کو جھٹلاؤ گے،\qt@no{73}}%
\qt@newcmd\qurantrans@ur@mmmmcmlxxv{انہیں پہلے نہ کسی انسان ہی نے ہاتھ سے چُھوا ہے اور نہ کسی جِن نے،\qt@no{74}}%
\qt@newcmd\qurantrans@ur@mmmmcmlxxvi{پس تم دونوں اپنے رب کی کن کن نعمتوں کو جھٹلاؤ گے،\qt@no{75}}%
\qt@newcmd\qurantrans@ur@mmmmcmlxxvii{اہلِ جنت) سبز قالینوں پر اور نادر و نفیس بچھونوں پر تکیے لگائے (بیٹھے) ہوں گے،\qt@no{76}}%
\qt@newcmd\qurantrans@ur@mmmmcmlxxviii{پس تم دونوں اپنے رب کی کن کن نعمتوں کو جھٹلاؤ گے،\qt@no{77}}%
\qt@newcmd\qurantrans@ur@mmmmcmlxxix{آپ کے رب کا نام بڑی برکت والا ہے، جو صاحبِ عظمت و جلال اور صاحبِ اِنعام و اِکرام ہے،\qt@no{78}}%
\qt@newcmd\qurantrans@ur@mmmmcmlxxx{\basmalahur جب واقع ہونے والی (قیامت) واقع ہو جائے گی،\qt@no{1}}%
\qt@newcmd\qurantrans@ur@mmmmcmlxxxi{اُس کے واقع ہونے میں کوئی جھوٹ نہیں ہے،\qt@no{2}}%
\qt@newcmd\qurantrans@ur@mmmmcmlxxxii{وہ قیامت کسی کو) نیچا کر دینے والی (کسی کو) اونچا کر دینے والی (ہے)،\qt@no{3}}%
\qt@newcmd\qurantrans@ur@mmmmcmlxxxiii{جب زمین کپکپا کر شدید لرزنے لگے گی،\qt@no{4}}%
\qt@newcmd\qurantrans@ur@mmmmcmlxxxiv{اور پہاڑ ٹوٹ کر ریزہ ریزہ ہو جائیں گے،\qt@no{5}}%
\qt@newcmd\qurantrans@ur@mmmmcmlxxxv{پھر وہ غبار بن کر منتشر ہو جائیں گے،\qt@no{6}}%
\qt@newcmd\qurantrans@ur@mmmmcmlxxxvi{اور تم لوگ تین قِسموں میں بٹ جاؤ گے،\qt@no{7}}%
\qt@newcmd\qurantrans@ur@mmmmcmlxxxvii{سو (ایک) دائیں جانب والے، دائیں جانب والوں کا کیا کہنا،\qt@no{8}}%
\qt@newcmd\qurantrans@ur@mmmmcmlxxxviii{اور (دوسرے) بائیں جانب والے، کیا (ہی برے حال میں ہوں گے) بائیں جانب والے،\qt@no{9}}%
\qt@newcmd\qurantrans@ur@mmmmcmlxxxix{اور (تیسرے) سبقت لے جانے والے (یہ) پیش قدمی کرنے والے ہیں،\qt@no{10}}%
\qt@newcmd\qurantrans@ur@mmmmcmxc{یہی لوگ (اللہ کے) مقرّب ہوں گے،\qt@no{11}}%
\qt@newcmd\qurantrans@ur@mmmmcmxci{نعمتوں کے باغات میں (رہیں گے)،\qt@no{12}}%
\qt@newcmd\qurantrans@ur@mmmmcmxcii{اِن مقرّبین میں) بڑا گروہ اگلے لوگوں میں سے ہوگا،\qt@no{13}}%
\qt@newcmd\qurantrans@ur@mmmmcmxciii{اور پچھلے لوگوں میں سے (ان میں) تھوڑے ہوں گے،\qt@no{14}}%
\qt@newcmd\qurantrans@ur@mmmmcmxciv{یہ مقرّبین) زر نگار تختوں پر ہوں گے،\qt@no{15}}%
\qt@newcmd\qurantrans@ur@mmmmcmxcv{اُن پر تکیے لگائے آمنے سامنے بیٹھے ہوں گے،\qt@no{16}}%
\qt@newcmd\qurantrans@ur@mmmmcmxcvi{ہمیشہ ایک ہی حال میں رہنے والے نوجوان خدمت گار ان کے اردگرد گھومتے ہوں گے،\qt@no{17}}%
\qt@newcmd\qurantrans@ur@mmmmcmxcvii{کوزے، آفتابے اور چشموں سے بہتی ہوئی (شفاف) شرابِ (قربت) کے جام لے کر (حاضرِ خدمت رہیں گے)،\qt@no{18}}%
\qt@newcmd\qurantrans@ur@mmmmcmxcviii{انہیں نہ تو اُس (کے پینے) سے دردِ سر کی شکایت ہوگی اور نہ ہی عقل میں فتور (اور بدمستی) آئے گی،\qt@no{19}}%
\qt@newcmd\qurantrans@ur@mmmmcmxcix{اور (جنّتی خدمت گزار) پھل (اور میوے) لے کر (بھی پھر رہے ہوں گے) جنہیں وہ (مقرّبین) پسند کریں گے،\qt@no{20}}%
\qt@newcmd\qurantrans@ur@mmmmm{اور پرندوں کا گوشت بھی (دستیاب ہوگا) جِس کی وہ (اہلِ قربت) خواہش کریں گے،\qt@no{21}}%
\qt@newcmd\qurantrans@ur@mmmmmi{اور خوبصورت کشادہ آنکھوں والی حوریں بھی (اُن کی رفاقت میں ہوں گی)،\qt@no{22}}%
\qt@newcmd\qurantrans@ur@mmmmmii{جیسے محفوظ چھپائے ہوئے موتی ہوں،\qt@no{23}}%
\qt@newcmd\qurantrans@ur@mmmmmiii{یہ) اُن (نیک) اعمال کی جزا ہوگی جو وہ کرتے رہے تھے،\qt@no{24}}%
\qt@newcmd\qurantrans@ur@mmmmmiv{وہ اِس میں نہ کوئی بیہودگی سنیں گے اور نہ کوئی گناہ کی بات،\qt@no{25}}%
\qt@newcmd\qurantrans@ur@mmmmmv{مگر ایک ہی بات (کہ یہ سلام والے ہر طرف سے) سلام ہی سلام سنیں گے،\qt@no{26}}%
\qt@newcmd\qurantrans@ur@mmmmmvi{اور دائیں جانب والے، کیا کہنا دائیں جانب والوں کا،\qt@no{27}}%
\qt@newcmd\qurantrans@ur@mmmmmvii{وہ بے خار بیریوں میں،\qt@no{28}}%
\qt@newcmd\qurantrans@ur@mmmmmviii{اور تہ بہ تہ کیلوں میں،\qt@no{29}}%
\qt@newcmd\qurantrans@ur@mmmmmix{اور لمبے لمبے (پھیلے ہوئے) سایوں میں،\qt@no{30}}%
\qt@newcmd\qurantrans@ur@mmmmmx{اور بہتے چھلکتے پانیوں میں،\qt@no{31}}%
\qt@newcmd\qurantrans@ur@mmmmmxi{اور بکثرت پھلوں اور میووں میں (لطف اندوز ہوں گے)،\qt@no{32}}%
\qt@newcmd\qurantrans@ur@mmmmmxii{جو نہ (کبھی) ختم ہوں گے اور نہ اُن (کے کھانے) کی ممانعت ہوگی،\qt@no{33}}%
\qt@newcmd\qurantrans@ur@mmmmmxiii{اور (وہ) اونچے (پرشکوہ) فرشوں پر (قیام پذیر) ہوں گے،\qt@no{34}}%
\qt@newcmd\qurantrans@ur@mmmmmxiv{بیشک ہم نے اِن (حوروں) کو (حسن و لطافت کی آئینہ دار) خاص خِلقت پر پیدا فرمایا ہے،\qt@no{35}}%
\qt@newcmd\qurantrans@ur@mmmmmxv{پھر ہم نے اِن کو کنواریاں بنایا ہے،\qt@no{36}}%
\qt@newcmd\qurantrans@ur@mmmmmxvi{جو خوب محبت کرنے والی ہم عمر (ازواج) ہیں،\qt@no{37}}%
\qt@newcmd\qurantrans@ur@mmmmmxvii{یہ (حوریں اور دیگر نعمتیں) دائیں جانب والوں کے لئے ہیں،\qt@no{38}}%
\qt@newcmd\qurantrans@ur@mmmmmxviii{ان میں) بڑی جماعت اگلے لوگوں میں سے ہوگی،\qt@no{39}}%
\qt@newcmd\qurantrans@ur@mmmmmxix{اور (ان میں) پچھلے لوگوں میں سے (بھی) بڑی ہی جماعت ہوگی،\qt@no{40}}%
\qt@newcmd\qurantrans@ur@mmmmmxx{اور بائیں جانب والے، کیا (ہی برے لوگ) ہیں بائیں جانب والے،\qt@no{41}}%
\qt@newcmd\qurantrans@ur@mmmmmxxi{جو دوزخ کی سخت گرم ہوا اور کھولتے ہوئے پانی میں،\qt@no{42}}%
\qt@newcmd\qurantrans@ur@mmmmmxxii{اور سیاہ دھویں کے سایے میں ہوں گے،\qt@no{43}}%
\qt@newcmd\qurantrans@ur@mmmmmxxiii{جو نہ (کبھی) ٹھنڈا ہوگا اور نہ فرحت بخش ہوگا،\qt@no{44}}%
\qt@newcmd\qurantrans@ur@mmmmmxxiv{بیشک وہ (اہلِ دوزخ) اس سے پہلے (دنیا میں) خوش حال رہ چکے تھے،\qt@no{45}}%
\qt@newcmd\qurantrans@ur@mmmmmxxv{اور وہ گناہِ عظیم (یعنی کفر و شرک) پر اصرار کیا کرتے تھے،\qt@no{46}}%
\qt@newcmd\qurantrans@ur@mmmmmxxvi{اور کہا کرتے تھے کہ کیا جب ہم مر جائیں گے اور ہم خاک (کا ڈھیر) اور (بوسیدہ) ہڈیاں ہو جائیں گے تو کیا ہم (پھر زندہ کر کے) اٹھائے جائیں گے،\qt@no{47}}%
\qt@newcmd\qurantrans@ur@mmmmmxxvii{اور کیا ہمارے اگلے باپ دادا بھی (زندہ کئے جائیں گے)،\qt@no{48}}%
\qt@newcmd\qurantrans@ur@mmmmmxxviii{آپ فرما دیں: بیشک اگلے اور پچھلے،\qt@no{49}}%
\qt@newcmd\qurantrans@ur@mmmmmxxix{سب کے سب) ایک معیّن دِن کے مقررّہ وقت پر جمع کئے جائیں گے،\qt@no{50}}%
\qt@newcmd\qurantrans@ur@mmmmmxxx{پھر بیشک تم لوگ اے گمراہو! جھٹلانے والو،\qt@no{51}}%
\qt@newcmd\qurantrans@ur@mmmmmxxxi{تم ضرور کانٹے دار (تھوہڑ کے) درخت سے کھانے والے ہو،\qt@no{52}}%
\qt@newcmd\qurantrans@ur@mmmmmxxxii{سو اُس سے اپنے پیٹ بھرنے والے ہو،\qt@no{53}}%
\qt@newcmd\qurantrans@ur@mmmmmxxxiii{پھر اُس پر سخت کھولتا پانی پینے والے ہو،\qt@no{54}}%
\qt@newcmd\qurantrans@ur@mmmmmxxxiv{پس تم سخت پیاسے اونٹ کے پینے کی طرح پینے والے ہو،\qt@no{55}}%
\qt@newcmd\qurantrans@ur@mmmmmxxxv{یہ قیامت کے دِن اُن کی ضیافت ہوگی،\qt@no{56}}%
\qt@newcmd\qurantrans@ur@mmmmmxxxvi{ہم ہی نے تمہیں پیدا کیا تھا پھر تم (دوبارہ پیدا کئے جانے کی) تصدیق کیوں نہیں کرتے،\qt@no{57}}%
\qt@newcmd\qurantrans@ur@mmmmmxxxvii{بھلا یہ بتاؤ جو نطفہ (تولیدی قطرہ) تم (رِحم میں) ٹپکاتے ہو،\qt@no{58}}%
\qt@newcmd\qurantrans@ur@mmmmmxxxviii{تو کیا اس (سے انسان) کو تم پیدا کرتے ہو یا ہم پیدا فرمانے والے ہیں،\qt@no{59}}%
\qt@newcmd\qurantrans@ur@mmmmmxxxix{ہم ہی نے تمہارے درمیان موت کو مقرّر فرمایا ہے اور ہم (اِس کے بعد پھر زندہ کرنے سے بھی) عاجز نہیں ہیں،\qt@no{60}}%
\qt@newcmd\qurantrans@ur@mmmmmxl{اس بات سے (بھی عاجز نہیں ہیں) کہ تمہارے جیسے اوروں کو بدل (کر بنا) دیں اور تمہیں ایسی صورت میں پیدا کر دیں جسے تم جانتے بھی نہ ہو،\qt@no{61}}%
\qt@newcmd\qurantrans@ur@mmmmmxli{اور بیشک تم نے پہلے پیدائش (کی حقیقت) معلوم کر لی پھر تم نصیحت قبول کیوں نہیں کرتے،\qt@no{62}}%
\qt@newcmd\qurantrans@ur@mmmmmxlii{بھلا یہ بتاؤ جو (بیج) تم کاشت کرتے ہو،\qt@no{63}}%
\qt@newcmd\qurantrans@ur@mmmmmxliii{تو کیا اُس (سے کھیتی) کو تم اُگاتے ہو یا ہم اُگانے والے ہیں،\qt@no{64}}%
\qt@newcmd\qurantrans@ur@mmmmmxliv{اگر ہم چاہیں تو اسے ریزہ ریزہ کر دیں پھر تم تعجب اور ندامت ہی کرتے رہ جاؤ،\qt@no{65}}%
\qt@newcmd\qurantrans@ur@mmmmmxlv{اور کہنے لگو): ہم پر تاوان پڑ گیا،\qt@no{66}}%
\qt@newcmd\qurantrans@ur@mmmmmxlvi{بلکہ ہم بے نصیب ہوگئے،\qt@no{67}}%
\qt@newcmd\qurantrans@ur@mmmmmxlvii{بھلا یہ بتاؤ جو پانی تم پیتے ہو،\qt@no{68}}%
\qt@newcmd\qurantrans@ur@mmmmmxlviii{کیا اسے تم نے بادل سے اتارا ہے یا ہم اتارنے والے ہیں،\qt@no{69}}%
\qt@newcmd\qurantrans@ur@mmmmmxlix{اگر ہم چاہیں تو اسے کھاری بنا دیں، پھر تم شکر ادا کیوں نہیں کرتے،\qt@no{70}}%
\qt@newcmd\qurantrans@ur@mmmmml{بھلا یہ بتاؤ جو آگ تم سُلگاتے ہو،\qt@no{71}}%
\qt@newcmd\qurantrans@ur@mmmmmli{کیا اِس کے درخت کو تم نے پیدا کیا ہے یا ہم (اسے) پیدا فرمانے والے ہیں،\qt@no{72}}%
\qt@newcmd\qurantrans@ur@mmmmmlii{ہم ہی نے اِس (درخت کی آگ) کو (آتشِ جہنّم کی) یاد دلانے والی (نصیحت و عبرت) اور جنگلوں کے مسافروں کے لئے باعثِ منفعت بنایا ہے،\qt@no{73}}%
\qt@newcmd\qurantrans@ur@mmmmmliii{سو اپنے ربِّ عظیم کے نام کی تسبیح کیا کریں،\qt@no{74}}%
\qt@newcmd\qurantrans@ur@mmmmmliv{پس میں اُن جگہوں کی قَسم کھاتا ہوں جہاں جہاں قرآن کے مختلف حصے (رسولِ عربی صلی اللہ علیہ وآلہ وسلم پر) اترتے ہیں٭، ٭ یہ ترجمہ حضرت عبد اللہ بن عباس کے بیان کردہ معنی پر کیا گیا ہے، مزید حضرت عکرمہ، حضرت مجاہد، حضرت عبد اللہ بن جبیر، حضرت سدی، حضرت فراء اور حضرت زجاج رضی اللہ عنھم اور دیگر ائمہ تفسیر کا قول بھی یہی ہے؛ اور سیاقِ کلام بھی اسی کا تقاضا کرتا ہے۔ پیچھے سورۃ النجم میں حضور نبی اکرم صلی اللہ علیہ وآلہ وسلم کو نجم کہا گیا ہے، یہاں قرآن کی سورتوں کو نجوم کہا گیا ہے۔ حوالہ جات کے لئے ملاحظہ کریں: تفسیر بغوی، خازن، طبری، الدر المنثور، الکشاف، تفسیر ابن ابی حاتم، روح المعانی، ابن کثیر، اللباب، البحر المحیط، جمل، زاد المسیر، فتح القدیر، المظہری، البیضاوی، تفسیر ابی سعود اور مجمع البیان۔\qt@no{75}}%
\qt@newcmd\qurantrans@ur@mmmmmlv{اور اگر تم سمجھو تو بیشک یہ بہت بڑی قَسم ہے،\qt@no{76}}%
\qt@newcmd\qurantrans@ur@mmmmmlvi{بیشک یہ بڑی عظمت والا قرآن ہے (جو بڑی عظمت والے رسول صلی اللہ علیہ وآلہ وسلم پر اتر رہا ہے)،\qt@no{77}}%
\qt@newcmd\qurantrans@ur@mmmmmlvii{اس سے پہلے یہ) لوحِ محفوظ میں (لکھا ہوا) ہے،\qt@no{78}}%
\qt@newcmd\qurantrans@ur@mmmmmlviii{اس کو پاک (طہارت والے) لوگوں کے سوا کوئی نہیں چُھوئے گا،\qt@no{79}}%
\qt@newcmd\qurantrans@ur@mmmmmlix{تمام جہانوں کے ربّ کی طرف سے اتارا گیا ہے،\qt@no{80}}%
\qt@newcmd\qurantrans@ur@mmmmmlx{سو کیا تم اسی کلام کی تحقیر کرتے ہو،\qt@no{81}}%
\qt@newcmd\qurantrans@ur@mmmmmlxi{اور تم نے اپنا رِزق (اور نصیب) اسی بات کو بنا رکھا ہے کہ تم (اسے) جھٹلاتے رہو،\qt@no{82}}%
\qt@newcmd\qurantrans@ur@mmmmmlxii{پھر کیوں نہیں (روح کو واپس لوٹا لیتے) جب وہ (پرواز کرنے کے لئے) حلق تک آپہنچتی ہے،\qt@no{83}}%
\qt@newcmd\qurantrans@ur@mmmmmlxiii{اور تم اس وقت دیکھتے ہی رہ جاتے ہو،\qt@no{84}}%
\qt@newcmd\qurantrans@ur@mmmmmlxiv{اور ہم اس (مرنے والے) سے تمہاری نسبت زیادہ قریب ہوتے ہیں لیکن تم (ہمیں) دیکھتے نہیں ہو،\qt@no{85}}%
\qt@newcmd\qurantrans@ur@mmmmmlxv{پھر کیوں نہیں (ایسا کر سکتے) اگر تم کسی کی مِلک و اختیار میں نہیں ہو،\qt@no{86}}%
\qt@newcmd\qurantrans@ur@mmmmmlxvi{کہ اس (رُوح) کو واپس پھیر لو اگر تم سچّے ہو،\qt@no{87}}%
\qt@newcmd\qurantrans@ur@mmmmmlxvii{پھر اگر وہ (وفات پانے والا) مقرّبین میں سے تھا،\qt@no{88}}%
\qt@newcmd\qurantrans@ur@mmmmmlxviii{تو (اس کے لئے) سرور و فرحت اور روحانی رزق و استراحت اور نعمتوں بھری جنت ہے،\qt@no{89}}%
\qt@newcmd\qurantrans@ur@mmmmmlxix{اور اگر وہ اصحاب الیمین میں سے تھا،\qt@no{90}}%
\qt@newcmd\qurantrans@ur@mmmmmlxx{تو (اس سے کہا جائے گا:) تمہارے لئے دائیں جانب والوں کی طرف سے سلام ہے (یا اے نبی! آپ پر اصحابِ یمین کی جانب سے سلام ہے)،\qt@no{91}}%
\qt@newcmd\qurantrans@ur@mmmmmlxxi{اور اگر وہ (مرنے والا) جھٹلانے والے گمراہوں میں سے تھا،\qt@no{92}}%
\qt@newcmd\qurantrans@ur@mmmmmlxxii{تو (اس کی) سخت کھولتے ہوئے پانی سے ضیافت ہوگی،\qt@no{93}}%
\qt@newcmd\qurantrans@ur@mmmmmlxxiii{اور (اس کا انجام) دوزخ میں داخل کر دیا جانا ہے،\qt@no{94}}%
\qt@newcmd\qurantrans@ur@mmmmmlxxiv{بیشک یہی قطعی طور پر حق الیقین ہے،\qt@no{95}}%
\qt@newcmd\qurantrans@ur@mmmmmlxxv{سو آپ اپنے ربِّ عظیم کے نام کی تسبیح کیا کریں،\qt@no{96}}%
\qt@newcmd\qurantrans@ur@mmmmmlxxvi{\basmalahur اللہ ہی کی تسبیح کرتے ہیں جو بھی آسمانوں اور زمین میں ہیں، اور وہی بڑی عزت والا بڑی حکمت والا ہے،\qt@no{1}}%
\qt@newcmd\qurantrans@ur@mmmmmlxxvii{اسی کے لئے آسمانوں اور زمین کی بادشاہت ہے، وہی جِلاتا اور مارتا ہے، اور وہ ہر چیز پر بڑا قادر ہے،\qt@no{2}}%
\qt@newcmd\qurantrans@ur@mmmmmlxxviii{وہی (سب سے) اوّل اور (سب سے) آخر ہے اور (اپنی قدرت کے اعتبار سے) ظاہر اور (اپنی ذات کے اعتبار سے) پوشیدہ ہے، اور وہ ہر چیز کو خوب جاننے والا ہے،\qt@no{3}}%
\qt@newcmd\qurantrans@ur@mmmmmlxxix{وہی ہے جِس نے آسمانوں اور زمین کو چھ اَدوار میں پیدا فرمایا پھر کائنات کی مسندِ اقتدار پر جلوہ افروز ہوا (یعنی پوری کائنات کو اپنے امر کے ساتھ منظم فرمایا)، وہ جانتا ہے جو کچھ زمین میں داخل ہوتا ہے اور جو کچھ اس میں سے خارج ہوتا ہے اور جو کچھ آسمانی کرّوں سے اترتا (یا نکلتا) ہے یا جو کچھ ان میں چڑھتا (یا داخل ہوتا) ہے۔ وہ تمہارے ساتھ ہوتا ہے تم جہاں کہیں بھی ہو، اور اللہ جو کچھ تم کرتے ہو (اسے) خوب دیکھنے والا ہے،\qt@no{4}}%
\qt@newcmd\qurantrans@ur@mmmmmlxxx{آسمانوں اور زمین کی ساری سلطنت اسی کی ہے، اور اسی کی طرف سارے امور لوٹائے جاتے ہیں،\qt@no{5}}%
\qt@newcmd\qurantrans@ur@mmmmmlxxxi{وہی رات کو دن میں داخل کرتا ہے اور دن کو رات میں داخل کرتا ہے، اور وہ سینوں کی (پوشیدہ) باتوں سے بھی خوب باخبر ہے،\qt@no{6}}%
\qt@newcmd\qurantrans@ur@mmmmmlxxxii{اللہ اور اس کے رسول (صلی اللہ علیہ وآلہ وسلم) پر ایمان لاؤ اور اس (مال و دولت) میں سے خرچ کرو جس میں اس نے تمہیں اپنا نائب (و امین) بنایا ہے، پس تم میں سے جو لوگ ایمان لائے اور انہوں نے خرچ کیا اُن کے لئے بہت بڑا اَجر ہے،\qt@no{7}}%
\qt@newcmd\qurantrans@ur@mmmmmlxxxiii{اور تمہیں کیا ہوگیا ہے کہ تم اللہ پر ایمان نہیں لاتے، حالانکہ رسول (صلی اللہ علیہ وآلہ وسلم) تمہیں بلا رہے ہیں کہ تم اپنے رب پر ایمان لاؤ اور بیشک (اللہ) تم سے مضبوط عہد لے چکا ہے، اگر تم ایمان لانے والے ہو،\qt@no{8}}%
\qt@newcmd\qurantrans@ur@mmmmmlxxxiv{وہی ہے جو اپنے (برگزیدہ) بندے پر واضح نشانیاں نازل فرماتا ہے تاکہ تمہیں اندھیروں سے روشنی کی طرف نکال لے جائے، اور بیشک اللہ تم پر نہایت شفقت فرمانے والا نہایت رحم فرمانے والا ہے،\qt@no{9}}%
\qt@newcmd\qurantrans@ur@mmmmmlxxxv{اور تمہیں کیا ہوگیا ہے کہ تم اللہ کی راہ میں خرچ نہیں کرتے حالانکہ آسمانوں اور زمین کی ساری ملکیت اللہ ہی کی ہے (تم تو فقط اس مالک کے نائب ہو)، تم میں سے جن لوگوں نے فتحِ (مکّہ) سے پہلے (اللہ کی راہ میں اپنا مال) خرچ کیا اور قتال کیا وہ (اور تم) برابر نہیں ہوسکتے، وہ اُن لوگوں سے درجہ میں بہت بلند ہیں جنہوں نے بعد میں مال خرچ کیا ہے اور قتال کیا ہے، مگر اللہ نے حسنِ آخرت (یعنی جنت) کا وعدہ سب سے فرما دیا ہے، اور اللہ جو کچھ تم کرتے ہو اُن سے خوب آگاہ ہے،\qt@no{10}}%
\qt@newcmd\qurantrans@ur@mmmmmlxxxvi{کون شخص ہے جو اللہ کو قرضِ حسنہ کے طور پر قرض دے تو وہ اس کے لئے اُس (قرض) کو کئی گنا بڑھاتا رہے اور اس کے لئے بڑی عظمت والا اجر ہے،\qt@no{11}}%
\qt@newcmd\qurantrans@ur@mmmmmlxxxvii{اے حبیب!) جس دن آپ (اپنی امّت کے) مومن مَردوں اور مومن عورتوں کو دیکھیں گے کہ اُن کا نور اُن کے آگے اور اُن کی دائیں جانب تیزی سے چل رہا ہوگا (اور اُن سے کہا جائے گا:) تمہیں بشارت ہو آج (تمہارے لئے) جنتیں ہیں جن کے نیچے سے نہریں رواں ہیں (تم) ہمیشہ ان میں رہو گے، یہی بہت بڑی کامیابی ہے،\qt@no{12}}%
\qt@newcmd\qurantrans@ur@mmmmmlxxxviii{جس دن منافق مرد اور منافق عورتیں ایمان والوں سے کہیں گے: ذرا ہم پر (بھی) نظرِ (التفات) کر دو ہم تمہارے نور سے کچھ روشنی حاصل کرلیں۔ ان سے کہا جائے گا: تم اپنے پیچھے پلٹ جاؤ اور (وہاں جاکر) نور تلاش کرو (جہاں تم نور کا انکار کرتے تھے)، تو (اسی وقت) ان کے درمیان ایک دیوار کھڑی کر دی جائے گی جس میں ایک دروازہ ہوگا، اس کے اندر کی جانب رحمت ہوگی اور اس کے باہر کی جانب اُس طرف سے عذاب ہوگا،\qt@no{13}}%
\qt@newcmd\qurantrans@ur@mmmmmlxxxix{وہ (منافق) اُن (مومنوں) کو پکار کر کہیں گے: کیا ہم (دنیا میں) تمہاری سنگت میں نہ تھے؟ وہ کہیں گے: کیوں نہیں! لیکن تم نے اپنے آپ کو (منافقت کے) فتنہ میں مبتلا کر دیا تھا اور تم (ہمارے لئے برائی اور نقصان کے) منتظر رہتے تھے اور تم (نبوّتِ محمدی صلی اللہ علیہ وآلہ وسلم اور دینِ اسلام میں) شک کرتے تھے اور باطل امیدوں نے تمہیں دھوکے میں ڈال دیا، یہاں تک کہ اللہ کا اَمرِ (موت) آپہنچا اور تمہیں اللہ کے بارے میں دغا باز (شیطان) دھوکہ دیتا رہا،\qt@no{14}}%
\qt@newcmd\qurantrans@ur@mmmmmxc{پس آج کے دن (اے منافقو!) تم سے کوئی معاوضہ قبول نہیں کیا جائے گا اور نہ ہی اُن سے جنھوں نے کفر کیا تھا اور تم (سب) کا ٹھکانا دوزخ ہے، اور یہی (ٹھکانا) تمہارا مولا (یعنی ساتھی) ہے، اور وہ نہایت بری جگہ ہے (کیونکہ تم نے اُن کو مولا ماننے سے انکار کر دیا تھا جہاں سے تمہیں نورِ ایمان اور بخشش کی خیرات ملنی تھے)،\qt@no{15}}%
\qt@newcmd\qurantrans@ur@mmmmmxci{کیا ایمان والوں کے لئے (ابھی) وہ وقت نہیں آیا کہ اُن کے دل اللہ کی یاد کے لئے رِقّت کے ساتھ جھک جائیں اور اس حق کے لئے (بھی) جو نازل ہوا ہے اور اُن لوگوں کی طرح نہ ہو جائیں جنہیں اس سے پہلے کتاب دی گئی تھی پھر ان پر مدّت دراز گزر گئی تو اُن کے دل سخت ہوگئے، اور ان میں بہت سے لوگ نافرمان ہیں،\qt@no{16}}%
\qt@newcmd\qurantrans@ur@mmmmmxcii{جان لو کہ اللہ ہی زمین کو اُس کی مُردنی کے بعد زندہ کرتا ہے، اور بیشک ہم نے تمہارے لئے نشانیاں واضح کر دی ہیں تاکہ تم عقل سے کام لو،\qt@no{17}}%
\qt@newcmd\qurantrans@ur@mmmmmxciii{بیشک صدقہ و خیرات دینے والے مرد اور صدقہ و خیرات دینے والی عورتیں اور جنہوں نے اللہ کو قرضِ حسنہ کے طور پر قرض دیا ان کے لئے (صدقہ و قرضہ کا اجر) کئی گنا بڑھا دیا جائے گا اور اُن کے لئے بڑی عزت والا ثواب ہوگا،\qt@no{18}}%
\qt@newcmd\qurantrans@ur@mmmmmxciv{اور جو لوگ اللہ اور اس کے رسولوں پر ایمان لائے وہی لوگ اپنے رب کے نزدیک صدیق اور شہید ہیں، اُن کے لئے اُن کا اجر (بھی) ہے اور ان کا نور (بھی) ہے، اور جنہوں نے کفر کیا اور ہماری آیتوں کو جھٹلایا وہی لوگ دوزخی ہیں،\qt@no{19}}%
\qt@newcmd\qurantrans@ur@mmmmmxcv{جان لو کہ دنیا کی زندگی محض کھیل اور تماشا ہے اور ظاہری آرائش ہے اور آپس میں فخر اور خود ستائی ہے اور ایک دوسرے پر مال و اولاد میں زیادتی کی طلب ہے، اس کی مثال بارش کی سی ہے کہ جس کی پیداوار کسانوں کو بھلی لگتی ہے پھر وہ خشک ہو جاتی ہے پھر تم اسے پک کر زرد ہوتا دیکھتے ہو پھر وہ ریزہ ریزہ ہو جاتی ہے، اور آخرت میں (نافرمانوں کے لئے) سخت عذاب ہے اور (فرمانبرداروں کے لئے) اللہ کی جانب سے مغفرت اور عظیم خوشنودی ہے، اور دنیا کی زندگی دھوکے کی پونجی کے سوا کچھ نہیں ہے،\qt@no{20}}%
\qt@newcmd\qurantrans@ur@mmmmmxcvi{اے بندو!) تم اپنے رب کی بخشش کی طرف تیز لپکو اور جنت کی طرف (بھی) جس کی چوڑائی (ہی) آسمان اور زمین کی وسعت جتنی ہے، اُن لوگوں کیلئے تیار کی گئی ہے جو اللہ اور اُس کے رسولوں پر ایمان لائے ہیں، یہ اللہ کا فضل ہے جسے وہ چاہتا ہے اسے عطا فرما دیتا ہے، اور اللہ عظیم فضل والا ہے،\qt@no{21}}%
\qt@newcmd\qurantrans@ur@mmmmmxcvii{کوئی بھی مصیبت نہ تو زمین میں پہنچتی ہے اور نہ تمہاری زندگیوں میں مگر وہ ایک کتاب میں (یعنی لوحِ محفوظ میں جو اللہ کے علمِ قدیم کا مرتبہ ہے) اس سے قبل کہ ہم اسے پیدا کریں (موجود) ہوتی ہے، بیشک یہ (علمِ محیط و کامل) اللہ پر بہت ہی آسان ہے،\qt@no{22}}%
\qt@newcmd\qurantrans@ur@mmmmmxcviii{تاکہ تم اس چیز پر غم نہ کرو جو تمہارے ہاتھ سے جاتی رہی اور اس چیز پر نہ اِتراؤ جو اس نے تمہیں عطا کی، اور اللہ کسی تکبّر کرنے والے، فخر کرنے والے کو پسند نہیں کرتا،\qt@no{23}}%
\qt@newcmd\qurantrans@ur@mmmmmxcix{جو لوگ (خود بھی) بخل کرتے ہیں اور (دوسرے) لوگوں کو (بھی) بخل کی تلقین کرتے ہیں، اور جو شخص (احکامِ الٰہی سے) رُوگردانی کرتا ہے تو بیشک اللہ (بھی) بے پرواہ ہے بڑا قابلِ حمد و ستائِش ہے،\qt@no{24}}%
\qt@newcmd\qurantrans@ur@mmmmmc{بیشک ہم نے اپنے رسولوں کو واضح نشانیوں کے ساتھ بھیجا اور ہم نے اُن کے ساتھ کتاب اور میزانِ عدل نازل فرمائی تاکہ لوگ انصاف پر قائم ہو سکیں، اور ہم نے (معدنیات میں سے) لوہا مہیّا کیا اس میں (آلاتِ حرب و دفاع کے لئے) سخت قوّت اور لوگوں کے لئے (صنعت سازی کے کئی دیگر) فوائد ہیں اور (یہ اس لئے کیا) تاکہ اللہ ظاہر کر دے کہ کون اُس کی اور اُس کے رسولوں کی (یعنی دینِ اسلام کی) بِن دیکھے مدد کرتا ہے، بیشک اللہ (خود ہی) بڑی قوت والا بڑے غلبہ والا ہے،\qt@no{25}}%
\qt@newcmd\qurantrans@ur@mmmmmci{اور بیشک ہم نے نوح اور ابراہیم علیہما السلام کو بھیجا اور ہم نے دونوں کی اولاد میں رسالت اور کتاب مقرر فرما دی تو ان میں سے (بعض) ہدایت یافتہ ہیں، اور ان میں سے اکثر لوگ نافرمان ہیں،\qt@no{26}}%
\qt@newcmd\qurantrans@ur@mmmmmcii{پھر ہم نے ان رسولوں کے نقوشِ قدم پر (دوسرے) رسولوں کو بھیجا اور ہم نے ان کے پیچھے عیسٰی ابنِ مریم (علیہما السلام) کو بھیجا اور ہم نے انہیں انجیل عطا کی اور ہم نے اُن لوگوں کے دلوں میں جو اُن کی (یعنی عیسٰی علیہ السلام کی صحیح) پیروی کر رہے تھے شفقت اور رحمت پیدا کر دی۔ اور رہبانیت (یعنی عبادتِ الٰہی کے لئے ترکِ دنیا اور لذّتوں سے کنارہ کشی) کی بدعت انہوں نے خود ایجاد کر لی تھی، اسے ہم نے اُن پر فرض نہیں کیا تھا، مگر (انہوں نے رہبانیت کی یہ بدعت) محض اللہ کی رضا حاصل کرنے کے لئے (شروع کی تھی) پھر اس کی عملی نگہداشت کا جو حق تھا وہ اس کی ویسی نگہداشت نہ کرسکے (یعنی اسے اسی جذبہ اور پابندی سے جاری نہ رکھ سکی)، سو ہم نے اُن لوگوں کو جو ان میں سے ایمان لائے (اور بدعتِ رہبانیت کو رضائے الٰہی کے لئے جاری رکھے ہوئے) تھے، اُن کا اجر و ثواب عطا کر دیا اور ان میں سے اکثر لوگ (جو اس کے تارک ہوگئے اور بدل گئے) بہت نافرمان ہیں،\qt@no{27}}%
\qt@newcmd\qurantrans@ur@mmmmmciii{اے ایمان والو! اللہ کا تقوٰی اختیار کرو اور اُس کے رسولِ (مکرّم صلی اللہ علیہ وآلہ وسلم) پر ایمان لے آؤ وہ تمہیں اپنی رحمت کے دو حصّے عطا فرمائے گا اور تمہارے لئے نور پیدا فرما دے گا جس میں تم (دنیا اور آخرت میں) چلا کرو گے اور تمہاری مغفرت فرما دے گا، اور اللہ بہت بخشنے والا بہت رحم فرمانے والا ہے،\qt@no{28}}%
\qt@newcmd\qurantrans@ur@mmmmmciv{یہ بیان اِس لئے ہے) کہ اہلِ کتاب جان لیں کہ وہ اللہ کے فضل پر کچھ قدرت نہیں رکھتے اور (یہ) کہ سارا فضل اللہ ہی کے دستِ قدرت میں ہے وہ جِسے چاہتا ہے عطا فرماتا ہے، اور اللہ فضل والا عظمت والا ہے،\qt@no{29}}%
\qt@newcmd\qurantrans@ur@mmmmmcv{\basmalahur بیشک اللہ نے اس عورت کی بات سن لی ہے جو آپ سے اپنے شوہر کے بارے میں تکرار کر رہی تھی اور اللہ سے فریاد کر رہی تھی، اور اللہ آپ دونوں کے باہمی سوال و جواب سن رہا تھا، بیشک اللہ خوب سننے والا خوب دیکھنے والا ہے،\qt@no{1}}%
\qt@newcmd\qurantrans@ur@mmmmmcvi{تم میں سے جو لوگ اپنی بیویوں سے ظِہار کر بیٹھتے ہیں (یعنی یہ کہہ بیٹھتے ہیں کہ تم مجھ پر میری ماں کی پشت کی طرح ہو)، تو (یہ کہنے سے) وہ اُن کی مائیں نہیں (ہوجاتیں)، اُن کی مائیں تو صرف وہی ہیں جنہوں نے اُن کو جَنا ہے، اور بیشک وہ لوگ بری اور جھوٹی بات کہتے ہیں، اور بیشک اﷲ ضرور درگزر فرمانے والا بڑا بخشنے والا ہے،\qt@no{2}}%
\qt@newcmd\qurantrans@ur@mmmmmcvii{اور جو لوگ اپنی بیویوں سے ظہار کر بیٹھیں پھر جو کہا ہے اس سے پلٹنا چاہیں تو ایک گردن (غلام یا باندی) کا آزاد کرنا لازم ہے قبل اِس کے کہ وہ ایک دوسرے کو مَس کریں، تمہیں اس بات کی نصیحت کی جاتی ہے، اور اللہ اُن کاموں سے خوب آگاہ ہے جو تم کرتے ہو،\qt@no{3}}%
\qt@newcmd\qurantrans@ur@mmmmmcviii{پھر جسے (غلام یا باندی) میسّر نہ ہو تو دو ماہ متواتر روزے رکھنا (لازم ہے) قبل اِس کے کہ وہ ایک دوسرے کو مَس کریں، پھر جو شخص اِس کی (بھی) طاقت نہ رکھے تو ساٹھ مسکینوں کو کھانا کھلانا (لازم ہے)، یہ اِس لئے کہ تم اللہ اور اُس کے رسول (صلی اللہ علیہ وآلہ وسلم) پر ایمان رکھو۔ اور یہ اللہ کی (مقرر کردہ) حدود ہیں، اور کافروں کے لئے دردناک عذاب ہے،\qt@no{4}}%
\qt@newcmd\qurantrans@ur@mmmmmcix{بیشک جو لوگ اللہ اور اس کے رسول (صلی اللہ علیہ وآلہ وسلم) سے عداوت رکھتے ہیں وہ اسی طرح ذلیل کئے جائیں گے جس طرح اُن سے پہلے لوگ ذلیل کئے جاچکے ہیں اور بیشک ہم نے واضح آیتیں نازل فرما دی ہیں، اور کافروں کے لئے ذِلت انگیز عذاب ہے،\qt@no{5}}%
\qt@newcmd\qurantrans@ur@mmmmmcx{جس دن اللہ ان سب لوگوں کو (دوبارہ زندہ کر کے) اٹھائے گا پھر انہیں اُن کے اعمال سے آگاہ فرمائے گا، اللہ نے (ان کے) ہر عمل کو شمار کر رکھا ہے حالانکہ وہ اسے بھول (بھی) چکے ہیں، اور اللہ ہر چیز پر مطّلع (اور آگاہ) ہے،\qt@no{6}}%
\qt@newcmd\qurantrans@ur@mmmmmcxi{اے انسان!) کیا تجھے معلوم نہیں کہ اللہ اُن سب چیزوں کو جانتا ہے جو آسمانوں میں ہیں اور جو زمین میں ہیں، کہیں بھی تین (آدمیوں) کی کوئی سرگوشی نہیں ہوتی مگر یہ کہ وہ (اللہ اپنے محیط علم و آگہی کے ساتھ) اُن کا چوتھا ہوتا ہے اور نہ ہی کوئی پانچ (آدمیوں) کی سرگوشی ہوتی ہے مگر وہ (اپنے علمِ محیط کے ساتھ) اُن کا چھٹا ہوتا ہے، اور نہ اس سے کم (لوگوں) کی اور نہ زیادہ کی مگر وہ (ہمیشہ) اُن کے ساتھ ہوتا ہے جہاں کہیں بھی وہ ہوتے ہیں، پھر وہ قیامت کے دن انہیں اُن کاموں سے خبردار کر دے گا جو وہ کرتے رہے تھے، بیشک اللہ ہر چیز کو خوب جاننے والا ہے،\qt@no{7}}%
\qt@newcmd\qurantrans@ur@mmmmmcxii{کیا آپ نے اُن لوگوں کو نہیں دیکھا جنہیں سرگوشیوں سے منع کیا گیا تھا پھر وہ لوگ وہی کام کرنے لگے جس سے روکے گئے تھے اور وہ گناہ اور سرکشی اور نافرمانئ رسول (صلی اللہ علیہ وآلہ وسلم) سے متعلق سرگوشیاں کرتے ہیں اور جب آپ کے پاس حاضر ہوتے ہیں تو آپ کو اُن (نازیبا) کلمات کے ساتھ سلام کرتے ہیں جن سے اللہ نے آپ کو سلام نہیں فرمایا اور اپنے دلوں میں کہتے ہیں کہ (اگر یہ رسول سچے ہیں تو) اللہ ہمیں اِن (باتوں) پر عذاب کیوں نہیں دیتا جو ہم کہتے ہیں؟ انہیں دوزخ (کا عذاب) ہی کافی ہے، وہ اسی میں داخل ہوں گے، اور وہ بہت ہی برا ٹھکانا ہے،\qt@no{8}}%
\qt@newcmd\qurantrans@ur@mmmmmcxiii{اے ایمان والو! جب تم آپس میں سرگوشی کرو تو گناہ اور ظلم و سرکشی اور نافرمانئ رسالت مآب (صلی اللہ علیہ وآلہ وسلم) کی سرگوشی نہ کیا کرو اور نیکی اور پرہیزگاری کی بات ایک دوسرے کے کان میں کہہ لیا کرو، اور اللہ سے ڈرتے رہو جس کی طرف تم سب جمع کئے جاؤ گے،\qt@no{9}}%
\qt@newcmd\qurantrans@ur@mmmmmcxiv{منفی اور تخریبی) سرگوشی محض شیطان ہی کی طرف سے ہوتی ہے تاکہ وہ ایمان والوں کو پریشان کرے حالانکہ وہ (شیطان) اُن (مومنوں) کا کچھ بگاڑ نہیں سکتا مگر اللہ کے حکم سے، اور اللہ ہی پر مومنوں کو بھروسہ رکھنا چاہیے،\qt@no{10}}%
\qt@newcmd\qurantrans@ur@mmmmmcxv{اے ایمان والو! جب تم سے کہا جائے کہ (اپنی) مجلسوں میں کشادگی پیدا کرو تو کشادہ ہو جایا کرو اللہ تمہیں کشادگی عطا فرمائے گا اور جب کہا جائے کھڑے ہو جاؤ تو تم کھڑے ہوجایا کرو، اللہ اُن لوگوں کے درجات بلند فرما دے گا جو تم میں سے ایمان لائے اور جنہیں علم سے نوازا گیا، اور اللہ اُن کاموں سے جو تم کرتے ہو خوب آگاہ ہے،\qt@no{11}}%
\qt@newcmd\qurantrans@ur@mmmmmcxvi{اے ایمان والو! جب تم رسول (صلی اللہ علیہ وآلہ وسلم) سے کوئی راز کی بات تنہائی میں عرض کرنا چاہو تو اپنی رازدارانہ بات کہنے سے پہلے کچھ صدقہ و خیرات کر لیا کرو، یہ (عمل) تمہارے لئے بہتر اور پاکیزہ تر ہے، پھر اگر (خیرات کے لئے) کچھ نہ پاؤ تو بیشک اللہ بہت بخشنے والا بہت رحم فرمانے والا ہے،\qt@no{12}}%
\qt@newcmd\qurantrans@ur@mmmmmcxvii{کیا (بارگاہِ رسالت صلی اللہ علیہ وآلہ وسلم میں) تنہائی و رازداری کے ساتھ بات کرنے سے قبل صدقات و خیرات دینے سے تم گھبرا گئے؟ پھر جب تم نے (ایسا) نہ کیا اور اللہ نے تم سے باز پرس اٹھا لی (یعنی یہ پابندی اٹھا دی) تو (اب) نماز قائم رکھو اور زکوٰۃ ادا کرتے رہو اور اللہ اور اُس کے رسول (صلی اللہ علیہ وآلہ وسلم) کی اطاعت بجا لاتے رہو، اور اللہ تمہارے سب کاموں سے خوب آگاہ ہے،\qt@no{13}}%
\qt@newcmd\qurantrans@ur@mmmmmcxviii{کیا آپ نے اُن لوگوں کو نہیں دیکھا جو ایسی جماعت کے ساتھ دوستی رکھتے ہیں جن پر اللہ نے غضب فرمایا، نہ وہ تم میں سے ہیں اور نہ اُن میں سے ہیں اور جھوٹی قَسمیں کھاتے ہیں حالانکہ وہ جانتے ہیں،\qt@no{14}}%
\qt@newcmd\qurantrans@ur@mmmmmcxix{اللہ نے اُن کے لئے سخت عذاب تیار فرما رکھا ہے، بیشک وہ برا (کام) ہے جو وہ کر رہے ہیں،\qt@no{15}}%
\qt@newcmd\qurantrans@ur@mmmmmcxx{انہوں نے اپنی (جھوٹی) قَسموں کو ڈھال بنا لیا ہے سو وہ (دوسروں کو) راہِ خدا سے روکتے ہیں، پس اُن کے لئے ذِلّت انگیز عذاب ہے،\qt@no{16}}%
\qt@newcmd\qurantrans@ur@mmmmmcxxi{اللہ (کے عذاب) سے ہرگز نہ ہی اُن کے مال انہیں بچا سکیں گے اور نہ اُن کی اولاد ہی (انہیں بچا سکے گی)، یہی لوگ اہلِ دوزخ ہیں، وہ اس میں ہمیشہ رہنے والے ہیں،\qt@no{17}}%
\qt@newcmd\qurantrans@ur@mmmmmcxxii{جس دن اللہ اُن سب کو (دوبارہ زندہ کر کے) اٹھائے گا تو وہ اُس کے حضور (بھی) قَسمیں کھا جائیں گے جیسے تمہارے سامنے قَسمیں کھاتے ہیں اور وہ گمان کرتے ہیں کہ وہ کسی (اچھی) شے (یعنی روِش) پر ہیں۔ آگاہ رہو کہ یہ لوگ جھوٹے ہیں،\qt@no{18}}%
\qt@newcmd\qurantrans@ur@mmmmmcxxiii{اُن پر شیطان نے غلبہ پا لیا ہے سو اُس نے انہیں اللہ کا ذکر بھلا دیا ہے، یہی لوگ شیطان کا لشکر ہیں۔ جان لو کہ بیشک شیطانی گروہ کے لوگ ہی نقصان اٹھانے والے ہیں،\qt@no{19}}%
\qt@newcmd\qurantrans@ur@mmmmmcxxiv{بیشک جو لوگ اللہ اور اُس کے رسول (صلی اللہ علیہ وآلہ وسلم) سے عداوت رکھتے ہیں وہی ذلیل ترین لوگوں میں سے ہیں،\qt@no{20}}%
\qt@newcmd\qurantrans@ur@mmmmmcxxv{اللہ نے لکھ دیا ہے کہ یقینا میں اور میرے رسول ضرور غالب ہو کر رہیں گے، بیشک اللہ بڑی قوت والا بڑے غلبہ والا ہے،\qt@no{21}}%
\qt@newcmd\qurantrans@ur@mmmmmcxxvi{آپ اُن لوگوں کو جو اللہ پر اور یومِ آخرت پر ایمان رکھتے ہیں کبھی اس شخص سے دوستی کرتے ہوئے نہ پائیں گے جو اللہ اور اُس کے رسول (صلی اللہ علیہ وآلہ وسلم) سے دشمنی رکھتا ہے خواہ وہ اُن کے باپ (اور دادا) ہوں یا بیٹے (اور پوتے) ہوں یا اُن کے بھائی ہوں یا اُن کے قریبی رشتہ دار ہوں۔ یہی وہ لوگ ہیں جن کے دلوں میں اُس (اللہ) نے ایمان ثبت فرما دیا ہے اور انہیں اپنی روح (یعنی فیضِ خاص) سے تقویت بخشی ہے، اور انہیں (ایسی) جنتوں میں داخل فرمائے گا جن کے نیچے سے نہریں بہہ رہی ہیں، وہ اُن میں ہمیشہ رہنے والے ہیں، اللہ اُن سے راضی ہو گیا ہے اور وہ اللہ سے راضی ہو گئے ہیں، یہی اﷲ (والوں) کی جماعت ہے، یاد رکھو! بیشک اﷲ (والوں) کی جماعت ہی مراد پانے والی ہے،\qt@no{22}}%
\qt@newcmd\qurantrans@ur@mmmmmcxxvii{\basmalahur جو کچھ آسمانوں میں ہے اور جو کچھ زمین میں ہے (سب) اللہ کی تسبیح کرتے ہیں، اور وہی غالب ہے حکمت والا ہے،\qt@no{1}}%
\qt@newcmd\qurantrans@ur@mmmmmcxxviii{وہی ہے جس نے اُن کافر کتابیوں کو (یعنی بنو نضیر کو) پہلی جلاوطنی میں گھروں سے (جمع کر کے مدینہ سے شام کی طرف) نکال دیا۔ تمہیں یہ گمان (بھی) نہ تھا کہ وہ نکل جائیں گے اور انہیں یہ گمان تھا کہ اُن کے مضبوط قلعے انہیں اللہ (کی گرفت) سے بچا لیں گے پھر اللہ (کے عذاب) نے اُن کو وہاں سے آلیا جہاں سے وہ گمان (بھی) نہ کرسکتے تھے اور اس (اللہ) نے اُن کے دلوں میں رعب و دبدبہ ڈال دیا وہ اپنے گھروں کو اپنے ہاتھوں اور اہلِ ایمان کے ہاتھوں ویران کر رہے تھے۔ پس اے دیدۂ بینا والو! (اس سے) عبرت حاصل کرو،\qt@no{2}}%
\qt@newcmd\qurantrans@ur@mmmmmcxxix{اور اگر اللہ نے اُن کے حق میں جلا وطنی لکھ نہ دی ہوتی تو وہ انہیں دنیا میں (اور سخت) عذاب دیتا، اور ان کے لئے آخرت میں (بھی) دوزخ کا عذاب ہے،\qt@no{3}}%
\qt@newcmd\qurantrans@ur@mmmmmcxxx{یہ اس وجہ سے ہوا کہ انہوں نے اللہ اور اس کے رسول (صلی اللہ علیہ وآلہ وسلم) سے شدید عداوت کی (ان کا سرغنہ کعب بن اشرف بدنام گستاخِ رسول تھا)، اور جو شخص اللہ (اور رسول صلی اللہ علیہ وآلہ وسلم کی) مخالفت کرتا ہے تو بیشک اللہ سخت عذاب دینے والا ہے،\qt@no{4}}%
\qt@newcmd\qurantrans@ur@mmmmmcxxxi{اے مومنو! یہود بنو نَضیر کے محاصرہ کے دوران) جو کھجور کے درخت تم نے کاٹ ڈالے یا تم نے انہیں اُن کی جڑوں پر کھڑا چھوڑ دیا تو (یہ سب) اللہ ہی کے حکم سے تھا اور اس لئے کہ وہ نافرمانوں کو ذلیل و رسوا کرے،\qt@no{5}}%
\qt@newcmd\qurantrans@ur@mmmmmcxxxii{اور جو (اَموالِ فَے) اللہ نے اُن سے (نکال کر) اپنے رسول (صلی اللہ علیہ وآلہ وسلم) پر لَوٹا دیئے تو تم نے نہ تو اُن (کے حصول) پر گھوڑے دوڑائے تھے اور نہ اونٹ، ہاں! اللہ اپنے رسولوں کو جِس پر چاہتا ہے غلبہ و تسلّط عطا فرما دیتا ہے، اور اللہ ہر چیز پر بڑی قدرت رکھنے والا ہے،\qt@no{6}}%
\qt@newcmd\qurantrans@ur@mmmmmcxxxiii{جو (اَموالِ فَے) اللہ نے (قُرَیظہ، نَضِیر، فِدَک، خَیبر، عُرَینہ سمیت دیگر بغیر جنگ کے مفتوحہ) بستیوں والوں سے (نکال کر) اپنے رسول (صلی اللہ علیہ وآلہ وسلم) پر لوٹائے ہیں وہ اللہ اور اس کے رسول (صلی اللہ علیہ وآلہ وسلم) کے لئے ہیں اور (رسول صلی اللہ علیہ وآلہ وسلم کے) قرابت داروں (یعنی بنو ہاشم اور بنو المطّلب) کے لئے اور (معاشرے کے عام) یتیموں اور محتاجوں اور مسافروں کے لئے ہیں، (یہ نظامِ تقسیم اس لئے ہے) تاکہ (سارا مال صرف) تمہارے مال داروں کے درمیان ہی نہ گردش کرتا رہے (بلکہ معاشرے کے تمام طبقات میں گردش کرے)۔ اور جو کچھ رسول (صلی اللہ علیہ وآلہ وسلم) تمہیں عطا فرمائیں سو اُسے لے لیا کرو اور جس سے تمہیں منع فرمائیں سو (اُس سے) رُک جایا کرو، اور اللہ سے ڈرتے رہو (یعنی رسول صلی اللہ علیہ وآلہ وسلم کی تقسیم و عطا پر کبھی زبانِ طعن نہ کھولو)، بیشک اللہ سخت عذاب دینے والا ہے،\qt@no{7}}%
\qt@newcmd\qurantrans@ur@mmmmmcxxxiv{مذکورہ بالا مالِ فَے) نادار مہاجرین کے لئے (بھی) ہے جو اپنے گھروں اور اپنے اموال (اور جائیدادوں) سے باہر نکال دیئے گئے ہیں، وہ اللہ کا فضل اور اس کی رضاء و خوشنودی چاہتے ہیں اور (اپنے مال و وطن کی قربانی سے) اللہ اور اس کے رسول (صلی اللہ علیہ وآلہ وسلم) کی مدد کرتے ہیں، یہی لوگ ہی سچے مؤمن ہیں،\qt@no{8}}%
\qt@newcmd\qurantrans@ur@mmmmmcxxxv{یہ مال اُن انصار کے لئے بھی ہے) جنہوں نے اُن (مہاجرین) سے پہلے ہی شہرِ (مدینہ) اور ایمان کو گھر بنا لیا تھا۔ یہ لوگ اُن سے محبت کرتے ہیں جو اِن کی طرف ہجرت کر کے آئے ہیں۔ اور یہ اپنے سینوں میں اُس (مال) کی نسبت کوئی طلب (یا تنگی) نہیں پاتے جو اُن (مہاجرین) کو دیا جاتا ہے اور اپنی جانوں پر انہیں ترجیح دیتے ہیں اگرچہ خود اِنہیں شدید حاجت ہی ہو، اور جو شخص اپنے نفس کے بُخل سے بچا لیا گیا پس وہی لوگ ہی بامراد و کامیاب ہیں،\qt@no{9}}%
\qt@newcmd\qurantrans@ur@mmmmmcxxxvi{اور وہ لوگ (بھی) جو اُن (مہاجرین و انصار) کے بعد آئے (اور) عرض کرتے ہیں: اے ہمارے رب! ہمیں بخش دے اور ہمارے ان بھائیوں کو بھی، جو ایمان لانے میں ہم سے آگے بڑھ گئے اور ہمارے دلوں میں ایمان والوں کے لئے کوئی کینہ اور بغض باقی نہ رکھ۔ اے ہمارے رب! بیشک تو بہت شفقت فرمانے والا بہت رحم فرمانے والا ہے،\qt@no{10}}%
\qt@newcmd\qurantrans@ur@mmmmmcxxxvii{کیا آپ نے منافقوں کو نہیں دیکھا جو اپنے اُن بھائیوں سے کہتے ہیں جو اہلِ کتاب میں سے کافر ہوگئے ہیں کہ اگر تم (یہاں سے) نکالے گئے توہم بھی ضرور تمہارے ساتھ ہی نکل چلیں گے اور ہم تمہارے معاملے میں کبھی بھی کسی ایک کی بھی اطاعت نہیں کریں گے اور اگر تم سے جنگ کی گئی تو ہم ضرور بالضرور تمہاری مدد کریں گے، اور اللہ گواہی دیتا ہے کہ وہ یقیناً جھوٹے ہیں،\qt@no{11}}%
\qt@newcmd\qurantrans@ur@mmmmmcxxxviii{اگر وہ (کفّارِ یہود مدینہ سے) نکال دیئے گئے تو یہ (منافقین) اُن کے ساتھ (کبھی) نہیں نکلیں گے، اور اگر اُن سے جنگ کی گئی تو یہ اُن کی مدد نہیں کریں گے، اور اگر انہوں نے اُن کی مدد کی (بھی) تو ضرور پیٹھ پھیر کر بھاگ جائیں گے، پھر اُن کی مدد (کہیں سے) نہ ہوسکے گی،\qt@no{12}}%
\qt@newcmd\qurantrans@ur@mmmmmcxxxix{اے مسلمانو!) بیشک اُن کے دلوں میں اللہ سے (بھی) زیادہ تمہارا رعب اور خوف ہے، یہ اس وجہ سے کہ وہ ایسے لوگ ہیں جو سمجھ ہی نہیں رکھتے،\qt@no{13}}%
\qt@newcmd\qurantrans@ur@mmmmmcxl{وہ (مدینہ کے یہود اور منافقین) سب مل کر (بھی) تم سے جنگ نہ کرسکیں گے سوائے قلعہ بند شہروں میں یا دیواروں کی آڑ میں، اُن کی لڑائی اُن کے آپس میں (ہی) سخت ہے، تم انہیں اکٹھا سمجھتے ہو حالانکہ اُن کے دل باہم متفرّق ہیں، یہ اس لئے کہ وہ لوگ عقل سے کام نہیں لیتے،\qt@no{14}}%
\qt@newcmd\qurantrans@ur@mmmmmcxli{اُن کا حال) اُن لوگوں جیسا ہے جو اُن سے پہلے زمانۂ قریب میں ہی اپنی شامتِ اعمال کا مزہ چکھ چکے ہیں (یعنی بدر میں مشرکینِ مکہ، اور یہود میں سے بنو نضیر، بنو قینقاع و بنو قریظہ وغیرہ)، اور ان کے لئے (آخرت میں بھی) دردناک عذاب ہے،\qt@no{15}}%
\qt@newcmd\qurantrans@ur@mmmmmcxlii{منافقوں کی مثال) شیطان جیسی ہے جب وہ انسان سے کہتا ہے کہ تُو کافر ہو جا، پھر جب وہ کافر ہوجاتا ہے تو (شیطان) کہتا ہے: میں تجھ سے بیزار ہوں، بیشک میں اللہ سے ڈرتا ہوں جو تمام جہانوں کا رب ہے،\qt@no{16}}%
\qt@newcmd\qurantrans@ur@mmmmmcxliii{پھر ان دونوں کا انجام یہ ہوگا کہ وہ دونوں دوزخ میں ہوں گے ہمیشہ اسی میں رہیں گے، اور ظالموں کی یہی سزا ہے،\qt@no{17}}%
\qt@newcmd\qurantrans@ur@mmmmmcxliv{اے ایمان والو! تم اللہ سے ڈرتے رہو اور ہر شخص کو دیکھتے رہنا چاہئیے کہ اس نے کل (قیامت) کے لئے آگے کیا بھیجا ہے، اور تم اللہ سے ڈرتے رہو، بیشک اللہ اُن کاموں سے باخبر ہے جو تم کرتے ہو،\qt@no{18}}%
\qt@newcmd\qurantrans@ur@mmmmmcxlv{اور اُن لوگوں کی طرح نہ ہو جاؤ جو اللہ کو بھلا بیٹھے پھر اللہ نے اُن کی جانوں کو ہی اُن سے بھلا دیا (کہ وہ اپنی جانوں کے لئے ہی کچھ بھلائی آگے بھیج دیتے)، وہی لوگ نافرمان ہیں،\qt@no{19}}%
\qt@newcmd\qurantrans@ur@mmmmmcxlvi{اہلِ دوزخ اور اہلِ جنت برابر نہیں ہوسکتے، اہلِ جنت ہی کامیاب و کامران ہیں،\qt@no{20}}%
\qt@newcmd\qurantrans@ur@mmmmmcxlvii{اگر ہم یہ قرآن کسی پہاڑ پر نازل فرماتے تو (اے مخاطب!) تو اسے دیکھتا کہ وہ اﷲ کے خوف سے جھک جاتا، پھٹ کر پاش پاش ہوجاتا، اور یہ مثالیں ہم لوگوں کے لئے بیان کر رہے ہیں تاکہ وہ غور و فکر کریں،\qt@no{21}}%
\qt@newcmd\qurantrans@ur@mmmmmcxlviii{وہی اللہ ہے جس کے سوا کوئی معبود نہیں، پوشیدہ اور ظاہر کو جاننے والا ہے، وہی بے حد رحمت فرمانے والا نہایت مہربان ہے،\qt@no{22}}%
\qt@newcmd\qurantrans@ur@mmmmmcxlix{وہی اللہ ہے جس کے سوا کوئی معبود نہیں، (حقیقی) بادشاہ ہے، ہر عیب سے پاک ہے، ہر نقص سے سالم (اور سلامتی دینے والا) ہے، امن و امان دینے والا (اور معجزات کے ذریعے رسولوں کی تصدیق فرمانے والا) ہے، محافظ و نگہبان ہے، غلبہ و عزّت والا ہے، زبردست عظمت والا ہے، سلطنت و کبریائی والا ہے، اللہ ہر اُس چیز سے پاک ہے جسے وہ اُس کا شریک ٹھہراتے ہیں،\qt@no{23}}%
\qt@newcmd\qurantrans@ur@mmmmmcl{وہی اللہ ہے جو پیدا فرمانے والا ہے، عدم سے وجود میں لانے والا (یعنی ایجاد فرمانے والا) ہے، صورت عطا فرمانے والا ہے۔ (الغرض) سب اچھے نام اسی کے ہیں، اس کے لئے وہ (سب) چیزیں تسبیح کرتی ہیں جو آسمانوں اور زمین میں ہیں، اور وہ بڑی عزت والا ہے بڑی حکمت والا ہے،\qt@no{24}}%
\qt@newcmd\qurantrans@ur@mmmmmcli{\basmalahur اے ایمان والو! تم میرے اور اپنے دشمنوں کو دوست نہ بناؤ تم (اپنے) دوستی کے باعث اُن تک خبریں پہنچاتے ہو حالانکہ وہ اس حق کے ہی مُنکر ہیں جو تمہارے پاس آیا ہے، وہ رسول (صلی اللہ علیہ وآلہ وسلم) کو اور تم کو اس وجہ سے (تمہارے وطن سے) نکالتے ہیں کہ تم اللہ پر جو تمہارا پروردگار ہے، ایمان لے آئے ہو۔ اگر تم میری راہ میں جہاد کرنے اور میری رضا تلاش کرنے کے لئے نکلے ہو (تو پھر اُن سے دوستی نہ رکھو) تم اُن کی طرف دوستی کے خفیہ پیغام بھیجتے ہو حالانکہ میں خوب جانتا ہوں جو کچھ تم چھپاتے ہو اور جو کچھ تم آشکار کرتے ہو، اور جو شخص بھی تم میں سے یہ (حرکت) کرے سو وہ سیدھی راہ سے بھٹک گیا ہے،\qt@no{1}}%
\qt@newcmd\qurantrans@ur@mmmmmclii{اگر وہ تم پر قدرت پا لیں تو (دیکھنا) وہ تمہارے (کھلے) دشمن ہوں گے اور وہ اپنے ہاتھ اور اپنی زبانیں تمہاری طرف برائی کے ساتھ دراز کریں گے اور آرزو مند ہوں گے کہ تم (کسی طرح) کافر ہوجاؤ،\qt@no{2}}%
\qt@newcmd\qurantrans@ur@mmmmmcliii{تمہیں قیامت کے دن ہرگز نہ تمہاری (کافر و مشرک) قرابتیں فائدہ دیں گی اور نہ تمہاری (کافر و مشرک) اولاد، (اُس دن اللہ) تمہارے درمیان مکمل جدائی کر دے گا (مومن جنت میں اور کافر دوزخ میں بھیج دیئے جائیں گے)، اور اللہ اُن کاموں کو خوب دیکھنے والا ہے جو تم کر رہے ہو،\qt@no{3}}%
\qt@newcmd\qurantrans@ur@mmmmmcliv{بیشک تمہارے لئے ابراہیم (علیہ السلام) میں اور اُن کے ساتھیوں میں بہترین نمونۂ (اقتداء) ہے، جب انہوں نے اپنی قوم سے کہا: ہم تم سے اور اُن بتوں سے جن کی تم اللہ کے سوا پوجا کرتے ہو کلیتہً بیزار (اور لاتعلق) ہیں، ہم نے تم سب کا کھلا انکار کیا ہمارے اور تمہارے درمیان دشمنی اور نفرت و عناد ہمیشہ کے لئے ظاہر ہوچکا، یہاں تک کہ تم ایک اللہ پر ایمان لے آؤ، مگر ابراہیم (علیہ السلام) کا اپنے (پرورش کرنے والے) باپ سے یہ کہنا کہ میں تمہارے لئے ضرور بخشش طلب کروں گا، (فقط پہلے کا کیا ہوا ایک وعدہ تھا جو انہوں نے پورا کر دیا اور ساتھ یوں جتا بھی دیا) اور یہ کہ میں تمہارے لئے (تمہارے کفر و شرک کے باعث) اللہ کے حضور کسی چیز کا مالک نہیں ہوں۔ (پھر وہ یہ دعا کر کے قوم سے الگ ہوگئے:) اے ہمارے رب! ہم نے تجھ پر ہی بھروسہ کیا اور ہم نے تیری طرف ہی رجوع کیا اور (سب کو) تیری ہی طرف لوٹنا ہے،\qt@no{4}}%
\qt@newcmd\qurantrans@ur@mmmmmclv{اے ہمارے رب! تو ہمیں کافروں کے لئے سببِ آزمائش نہ بنا (یعنی انہیں ہم پر مسلّط نہ کر) اور ہمیں بخش دے، اے ہمارے پروردگار! بیشک تو ہی غلبہ و عزت والا بڑی حکمت والا ہے،\qt@no{5}}%
\qt@newcmd\qurantrans@ur@mmmmmclvi{بیشک تمہارے لئے ان میں بہترین نمونۂ (اِقتداء) ہے (خاص طور پر) ہر اس شخص کے لئے جو اللہ (کی بارگاہ میں حاضری) کی اور یومِ آخرت کی امید رکھتا ہے، اور جو شخص رُوگردانی کرتا ہے تو بیشک اللہ بے نیاز اور لائقِ ہر حمد و ثناء ہے،\qt@no{6}}%
\qt@newcmd\qurantrans@ur@mmmmmclvii{عجب نہیں کہ اللہ تمہارے اور اُن میں سے بعض لوگوں کے درمیان جن سے تمہاری دشمنی ہے (کسی وقت بعد میں) دوستی پیدا کر دے، اور اللہ بڑی قدرت والا ہے، اور اللہ بڑا بخشنے والا نہایت مہربان ہے،\qt@no{7}}%
\qt@newcmd\qurantrans@ur@mmmmmclviii{اللہ تمہیں اس بات سے منع نہیں فرماتا کہ جن لوگوں نے تم سے دین (کے بارے) میں جنگ نہیں کی اور نہ تمہیں تمہارے گھروں سے (یعنی وطن سے) نکالا ہے کہ تم ان سے بھلائی کا سلوک کرو اور اُن سے عدل و انصاف کا برتاؤ کرو، بیشک اللہ عدل و انصاف کرنے والوں کو پسند فرماتا ہے،\qt@no{8}}%
\qt@newcmd\qurantrans@ur@mmmmmclix{اللہ تو محض تمہیں ایسے لوگوں سے دوستی کرنے سے منع فرماتا ہے جنہوں نے تم سے دین (کے بارے) میں جنگ کی اور تمہیں تمہارے گھروں (یعنی وطن) سے نکالا اور تمہارے باہر نکالے جانے پر (تمہارے دشمنوں کی) مدد کی۔ اور جو شخص اُن سے دوستی کرے گا تو وہی لوگ ظالم ہیں،\qt@no{9}}%
\qt@newcmd\qurantrans@ur@mmmmmclx{اے ایمان والو! جب تمہارے پاس مومن عورتیں ہجرت کر کے آئیں تو انہیں اچھی طرح جانچ لیا کرو، اللہ اُن کے ایمان (کی حقیقت) سے خوب آگاہ ہے، پھر اگر تمہیں اُن کے مومن ہونے کا یقین ہو جائے تو انہیں کافروں کی طرف واپس نہ بھیجو، نہ یہ (مومنات) اُن (کافروں) کے لئے حلال ہیں اور نہ وہ (کفّار) اِن (مومن عورتوں) کے لئے حلال ہیں، اور اُن (کافروں) نے جو (مال بصورتِ مَہر اِن پر) خرچ کیا ہو وہ اُن کو ادا کر دو، اور تم پر اس (بات) میں کوئی گناہ نہیں کہ تم اِن سے نکاح کر لو جبکہ تم اُن (عورتوں) کا مَہر انہیں ادا کر دو، اور (اے مسلمانو!) تم بھی کافر عورتوں کو (اپنے) عقدِ نکاح میں نہ روکے رکھو اور تم (کفّار سے) وہ (مال) طلب کر لو جو تم نے (اُن عورتوں پر بصورتِ مَہر) خرچ کیا تھا اور وہ (کفّار تم سے) وہ (مال) مانگ لیں جو انہوں نے (اِن عورتوں پر بصورتِ مَہر) خرچ کیا تھا، یہی اللہ کا حکم ہے، اور وہ تمہارے درمیان فیصلہ فرما رہا ہے، اور اللہ خوب جاننے والا بڑی حکمت والا ہے،\qt@no{10}}%
\qt@newcmd\qurantrans@ur@mmmmmclxi{اور اگر تمہاری بیویوں میں سے کوئی تم سے چھوٹ کر کافروں کی طرف چلی جائے پھر (جب) تم جنگ میں غالب آجاؤ اور مالِ غنیمت پاؤ تو (اس میں سے) ان لوگوں کو جن کی عورتیں چلی گئی تھیں اس قدر (مال) ادا کر دو جتنا وہ (اُن کے مَہر میں)خرچ کر چکے تھے، اور اُس اللہ سے ڈرتے رہو جس پر تم ایمان رکھتے ہو،\qt@no{11}}%
\qt@newcmd\qurantrans@ur@mmmmmclxii{اے نبی! جب آپ کی خدمت میں مومن عورتیں اس بات پر بیعت کرنے کے لئے حاضر ہوں کہ وہ اللہ کے ساتھ کسی چیز کو شریک نہیں ٹھہرائیں گی اور چوری نہیں کریں گی اور بدکاری نہیں کریں گی اور اپنی اولاد کو قتل نہیں کریں گی اور اپنے ہاتھوں اور پاؤں کے درمیان سے کوئی جھوٹا بہتان گھڑ کر نہیں لائیں گی (یعنی اپنے شوہر کو دھوکہ دیتے ہوئے کسی غیر کے بچے کو اپنے پیٹ سے جنا ہوا نہیں بتائیں گی) اور (کسی بھی) امرِ شریعت میں آپ کی نافرمانی نہیں کریں گی، تو آپ اُن سے بیعت لے لیا کریں اور اُن کے لئے اللہ سے بخشش طلب فرمائیں، بیشک اللہ بڑا بخشنے والا نہایت مہربان ہے،\qt@no{12}}%
\qt@newcmd\qurantrans@ur@mmmmmclxiii{اے ایمان والو! ایسے لوگوں سے دوستی مت رکھو جن پر اللہ غضبناک ہوا ہے بیشک وہ آخرت سے (اس طرح) مایوس ہو چکے ہیں جیسے کفار اہلِ قبور سے مایوس ہیں،\qt@no{13}}%
\qt@newcmd\qurantrans@ur@mmmmmclxiv{\basmalahur جو کچھ آسمانوں میں ہے اور جو کچھ زمین میں ہے (سب) اللہ کی تسبیح کرتے ہیں، اور وہ بڑی عزت و غلبہ والا بڑی حکمت والا ہے،\qt@no{1}}%
\qt@newcmd\qurantrans@ur@mmmmmclxv{اے ایمان والو! تم وہ باتیں کیوں کہتے ہو جو تم کرتے نہیں ہو،\qt@no{2}}%
\qt@newcmd\qurantrans@ur@mmmmmclxvi{اللہ کے نزدیک بہت سخت ناپسندیدہ بات یہ ہے کہ تم وہ بات کہو جو خود نہیں کرتے،\qt@no{3}}%
\qt@newcmd\qurantrans@ur@mmmmmclxvii{بیشک اللہ ان لوگوں کو پسند فرماتا ہے جو اُس کی راہ میں (یوں) صف بستہ ہو کر لڑتے ہیں گویا وہ سیسہ پلائی ہوئی دیوار ہوں،\qt@no{4}}%
\qt@newcmd\qurantrans@ur@mmmmmclxviii{اور (اے حبیب! وہ وقت یاد کیجئے) جب موسٰی (علیہ السلام) نے اپنی قوم سے کہا: اے میری قوم! تم مجھے اذیت کیوں دیتے ہو حالانکہ تم جانتے ہو کہ میں تمہاری طرف اللہ کا بھیجا ہوا (رسول) ہوں۔ پھر جب انہوں نے کج روی جاری رکھی تو اللہ نے اُن کے دلوں کو ٹیڑھا کر دیا، اور اللہ نافرمان لوگوں کو ہدایت نہیں فرماتا،\qt@no{5}}%
\qt@newcmd\qurantrans@ur@mmmmmclxix{اور (وہ وقت بھی یاد کیجئے) جب عیسٰی بن مریم (علیہما السلام) نے کہا: اے بنی اسرائیل! بیشک میں تمہاری طرف اللہ کا بھیجا ہوا (رسول) ہوں، اپنے سے پہلی کتاب تورات کی تصدیق کرنے والا ہوں اور اُس رسولِ (معظّم صلی اللہ علیہ وآلہ وسلم) کی (آمد آمد) کی بشارت سنانے والا ہوں جو میرے بعد تشریف لا رہے ہیں جن کا نام (آسمانوں میں اس وقت) احمد (صلی اللہ علیہ وآلہ وسلم) ہے، پھر جب وہ (رسولِ آخر الزماں صلی اللہ علیہ وآلہ وسلم) واضح نشانیاں لے کر اُن کے پاس تشریف لے آئے تو وہ کہنے لگے: یہ تو کھلا جادو ہے،\qt@no{6}}%
\qt@newcmd\qurantrans@ur@mmmmmclxx{اور اس شخص سے بڑھ کر ظالم کون ہو سکتا ہے جو اللہ پر جھوٹا بہتان باندھے حالانکہ اسے اسلام کی طرف بلایا جا رہا ہو، اور اللہ ظالم لوگوں کو ہدایت نہیں فرماتا،\qt@no{7}}%
\qt@newcmd\qurantrans@ur@mmmmmclxxi{یہ (منکرینِ حق) چاہتے ہیں کہ وہ اللہ کے نور کو اپنے منہ (کی پھونکوں) سے بجھا دیں، جبکہ اللہ اپنے نور کو پورا فرمانے والا ہے اگرچہ کافر کتنا ہی ناپسند کریں،\qt@no{8}}%
\qt@newcmd\qurantrans@ur@mmmmmclxxii{وہی ہے جس نے اپنے رسول (صلی اللہ علیہ وآلہ وسلم) کو ہدایت اور دینِ حق دے کر بھیجا تاکہ اسے سب ادیان پر غالب و سربلند کردے خواہ مشرک کتنا ہی ناپسند کریں،\qt@no{9}}%
\qt@newcmd\qurantrans@ur@mmmmmclxxiii{اے ایمان والو! کیا میں تمہیں ایک ایسی تجارت بتا دوں جو تم کو دردناک عذاب سے بچا لے؟،\qt@no{10}}%
\qt@newcmd\qurantrans@ur@mmmmmclxxiv{وہ یہ ہے کہ) تم اللہ پر اور اُس کے رسول (صلی اللہ علیہ وآلہ وسلم) پر (کامل) ایمان رکھو اور اللہ کی راہ میں اپنے مال و جان سے جہاد کرو، یہی تمہارے حق میں بہتر ہے اگر تم جانتے ہو،\qt@no{11}}%
\qt@newcmd\qurantrans@ur@mmmmmclxxv{وہ تمہارے گناہوں کو بخش دے گا اور تمہیں جنتوں میں داخل فرمائے گا جن کے نیچے سے نہریں جاری ہوں گی اور نہایت عمدہ رہائش گاہوں میں (ٹھہرائے گا) جو جناتِ عدن (یعنی ہمیشہ رہنے کی جنتوں) میں ہیں، یہی زبردست کامیابی ہے،\qt@no{12}}%
\qt@newcmd\qurantrans@ur@mmmmmclxxvi{اور (اس اُخروی نعمت کے علاوہ) ایک دوسری (دنیوی نعمت بھی عطا فرمائے گا) جسے تم بہت چاہتے ہو، (وہ) اللہ کی جانب سے مدد اور جلد ملنے والی فتح ہے، اور (اے نبئ مکرّم!) آپ مومنوں کو خوشخبری سنا دیں (یہ فتحِ مکہ اور فارس و روم کی فتوحات کی شکل میں ظاہر ہوئی)،\qt@no{13}}%
\qt@newcmd\qurantrans@ur@mmmmmclxxvii{اے ایمان والو! تم اللہ کے مددگار بن جاؤ جیسا کہ عیسٰی ابن مریم (علیہما السلام) نے (اپنے) حواریوں سے کہا تھا: اللہ کی (راہ کی) طرف میرے مددگار کون ہیں؟ حواریوں نے کہا: ہم اللہ کے مددگار ہیں۔ پس بنی اسرائیل کا ایک گروہ ایمان لے آیا اور دوسرا گروہ کافر ہوگیا، سو ہم نے اُن لوگوں کی جو ایمان لے آئے تھے اُن کے دشمنوں پر مدد فرمائی پس وہ غالب ہوگئے،\qt@no{14}}%
\qt@newcmd\qurantrans@ur@mmmmmclxxviii{\basmalahur (ہر چیز) جو آسمانوں میں ہے اور جو زمین میں ہے اللہ کی تسبیح کرتی ہے (جو حقیقی) بادشاہ ہے، (ہر نقص و عیب سے) پاک ہے، عزت و غلبہ والا ہے بڑی حکمت والا ہے،\qt@no{1}}%
\qt@newcmd\qurantrans@ur@mmmmmclxxix{وہی ہے جس نے اَن پڑھ لوگوں میں انہی میں سے ایک (با عظمت) رسول (صلی اللہ علیہ وآلہ وسلم) کو بھیجا وہ اُن پر اُس کی آیتیں پڑھ کر سناتے ہیں اور اُن (کے ظاہر و باطن) کو پاک کرتے ہیں اور انہیں کتاب و حکمت کی تعلیم دیتے ہیں، بیشک وہ لوگ اِن (کے تشریف لانے) سے پہلے کھلی گمراہی میں تھے،\qt@no{2}}%
\qt@newcmd\qurantrans@ur@mmmmmclxxx{اور اِن میں سے دوسرے لوگوں میں بھی (اِس رسول صلی اللہ علیہ وآلہ وسلم کو تزکیہ و تعلیم کے لئے بھیجا ہے) جو ابھی اِن لوگوں سے نہیں ملے (جو اس وقت موجود ہیں یعنی اِن کے بعد کے زمانہ میں آئیں گے)، اور وہ بڑا غالب بڑی حکمت والا ہے،\qt@no{3}}%
\qt@newcmd\qurantrans@ur@mmmmmclxxxi{یہ (یعنی اس رسول صلی اللہ علیہ وآلہ وسلم کی آمد اور اِن کا فیض و ہدایت) اللہ کا فضل ہے وہ جسے چاہتا ہے اس سے نوازتا ہے، اوراللہ بڑے فضل والا ہے،\qt@no{4}}%
\qt@newcmd\qurantrans@ur@mmmmmclxxxii{اُن لوگوں کا حال جن پر تورات (کے احکام و تعلیمات) کا بوجھ ڈالا گیا پھر انہوں نے اسے نہ اٹھایا (یعنی اس میں اِس رسول صلی اللہ علیہ وآلہ وسلم کا ذکر موجود تھا مگر وہ اِن پر ایمان نہ لائے) گدھے کی مِثل ہے جو پیٹھ پر بڑی بڑی کتابیں لادے ہوئے ہو، اُن لوگوں کی مثال کیا ہی بُری ہے جنہوں نے اللہ کی آیتوں کو جھٹلایا ہے، اور اللہ ظالم لوگوں کو ہدایت نہیں فرماتا،\qt@no{5}}%
\qt@newcmd\qurantrans@ur@mmmmmclxxxiii{آپ فرما دیجئے: اے یہودیو! اگر تم یہ گمان کرتے ہو کہ سب لوگوں کو چھوڑ کر تم ہی اللہ کے دوست (یعنی اولیاء) ہو تو موت کی آرزو کرو (کیونکہ اس کے اولیاء کو تو قبر و حشر میں کوئی پریشانی نہیں ہوگی) اگر تم (اپنے خیال میں) سچے ہو،\qt@no{6}}%
\qt@newcmd\qurantrans@ur@mmmmmclxxxiv{اور یہ لوگ کبھی بھی اس کی تمنا نہیں کریں گے اُس (رسول کی تکذیب اور کفر) کے باعث جو وہ آگے بھیج چکے ہیں۔ اور اللہ ظالموں کو خُوب جانتا ہے،\qt@no{7}}%
\qt@newcmd\qurantrans@ur@mmmmmclxxxv{فرما دیجئے: جس موت سے تم بھاگتے ہو وہ ضرور تمہیں ملنے والی ہے پھر تم ہر پوشیدہ و ظاہر چیز کو جاننے والے (رب) کی طرف لوٹائے جاؤ گے، سو وہ تمہیں آگاہ کر دے گا جو کچھ تم کرتے تھے،\qt@no{8}}%
\qt@newcmd\qurantrans@ur@mmmmmclxxxvi{اے ایمان والو! جب جمعہ کے دن (جمعہ کی) نماز کے لئے اذان دی جائے تو فوراً اللہ کے ذکر (یعنی خطبہ و نماز) کی طرف تیزی سے چل پڑو اور خرید و فروخت (یعنی کاروبار) چھوڑ دو۔ یہ تمہارے حق میں بہتر ہے اگر تم علم رکھتے ہو،\qt@no{9}}%
\qt@newcmd\qurantrans@ur@mmmmmclxxxvii{پھر جب نماز ادا ہوچکے تو زمین میں منتشر ہو جاؤ اور (پھر) اللہ کا فضل (یعنی رزق) تلاش کرنے لگو اور اللہ کو کثرت سے یاد کیا کرو تاکہ تم فلاح پاؤ،\qt@no{10}}%
\qt@newcmd\qurantrans@ur@mmmmmclxxxviii{اور جب انہوں نے کوئی تجارت یا کھیل تماشا دیکھا تو (اپنی حاجت مندی اور معاشی تنگی کے باعث) اس کی طرف بھاگ کھڑے ہوئے اور آپ کو (خطبہ میں) کھڑے چھوڑ گئے، فرما دیجئے: جو کچھ اللہ کے پاس ہے وہ کھیل سے اور تجارت سے بہتر ہے، اور اللہ سب سے بہتر رزق دینے والا ہے،\qt@no{11}}%
\qt@newcmd\qurantrans@ur@mmmmmclxxxix{\basmalahur (اے حبیبِ مکرّم!) جب منافق آپ کے پاس آتے ہیں تو کہتے ہیں: ہم گواہی دیتے ہیں کہ آپ یقیناً اللہ کے رسول ہیں، اور اللہ جانتا ہے کہ یقیناً آپ اُس کے رسول ہیں، اور اللہ گواہی دیتا ہے کہ یقیناً منافق لوگ جھوٹے ہیں،\qt@no{1}}%
\qt@newcmd\qurantrans@ur@mmmmmcxc{انہوں نے اپنی قَسموں کو ڈھال بنا رکھا ہے پھر یہ (لوگوں کو) اللہ کی راہ سے روکتے ہیں، بیشک وہ بہت ہی برا (کام) ہے جو یہ لوگ کر رہے ہیں،\qt@no{2}}%
\qt@newcmd\qurantrans@ur@mmmmmcxci{یہ اِس وجہ سے کہ وہ (زبان سے) ایمان لائے پھر (دل سے) کافر رہے تو اُن کے دلوں پر مُہر لگا دی گئی سو وہ (کچھ) نہیں سمجھتے،\qt@no{3}}%
\qt@newcmd\qurantrans@ur@mmmmmcxcii{اے بندے!) جب تو انہیں دیکھے تو اُن کے جسم (اور قد و قامت) تجھے بھلے معلوم ہوں، اور اگر وہ باتیں کریں تو اُن کی گفتگو تُو غور سے سنے (یعنی تجھے یوں معقول دکھائی دیں، مگر حقیقت یہ ہے کہ) وہ لوگ گویا دیوار کے سہارے کھڑی کی ہوئی لکڑیاں ہیں، وہ ہر اونچی آواز کو اپنے اوپر (بَلا اور آفت) سمجھتے ہیں، وہی (منافق تمہارے) دشمن ہیں سو اُن سے بچتے رہو، اللہ انہیں غارت کرے وہ کہاں بہکے پھرتے ہیں،\qt@no{4}}%
\qt@newcmd\qurantrans@ur@mmmmmcxciii{اور جب اُن سے کہا جاتا ہے کہ آؤ رسول اللہ (صلی اللہ علیہ وآلہ وسلم) تمہارے لئے مغفرت طلب فرمائیں تو یہ (منافق گستاخی سے) اپنے سر جھٹک کر پھیر لیتے ہیں اور آپ انہیں دیکھتے ہیں کہ وہ تکبر کرتے ہوئے (آپ کی خدمت میں آنے سے) گریز کرتے ہیں٭، ٭ یہ آیت عبد اللہ بن اُبیّ (رئیس المنافقین) کے بارے میں نازل ہوئی، جب اسے حضور نبی اکرم صلی اللہ علیہ وآلہ وسلم کی خدمتِ اقدس میں بخشش طلبی کے لئے حاضر ہونے کا کہا گیا تو سر جھٹک کر کہنے لگا: میں نہیں جاتا، میں ایمان بھی لا چکا ہوں، ان کے کہنے پر زکوٰۃ بھی دے دی ہے۔ اب کیا باقی رہ گیا ہے فقط یہی کہ محمد صلی اللہ علیہ وآلہ وسلم کو سجدہ بھی کروں؟ (الطبری، الکشاف، نسفی، بغوی، خازن)۔\qt@no{5}}%
\qt@newcmd\qurantrans@ur@mmmmmcxciv{اِن (بدبخت گستاخانِ رسول صلی اللہ علیہ وآلہ وسلم) کے حق میں برابر ہے کہ آپ اُن کے لئے استغفار کریں یا آپ ان کے لئے استغفار نہ کریں، اللہ ان کو (تو) ہرگز نہیں بخشے گا (کیونکہ یہ آپ پر طعنہ زنی کرنے والے اور آپ سے بے رخی اور تکبّر کرنے والے لوگ ہیں)۔ بیشک اللہ نافرمان لوگوں کو ہدایت نہیں فرماتا،\qt@no{6}}%
\qt@newcmd\qurantrans@ur@mmmmmcxcv{اے حبیبِ مکرّم!) یہی وہ لوگ ہیں جو (آپ سے بُغض و عِناد کی بنا پر) یہ (بھی) کہتے ہیں کہ جو (درویش اور فقراء) رسول اللہ (صلی اللہ علیہ وآلہ وسلم) کی خدمت میں رہتے ہیں اُن پر خرچ مت کرو (یعنی ان کی مالی اعانت نہ کرو) یہاں تک کہ وہ (سب انہیں چھوڑ کر) بھاگ جائیں (منتشر ہوجائیں)، حالانکہ آسمانوں اور زمین کے سارے خزانے اللہ ہی کے ہیں لیکن منافقین نہیں سمجھتے،\qt@no{7}}%
\qt@newcmd\qurantrans@ur@mmmmmcxcvi{وہ کہتے ہیں: اگر (اب) ہم مدینہ واپس ہوئے تو (ہم) عزّت والے لوگ وہاں سے ذلیل لوگوں (یعنی مسلمانوں) کو باہر نکال دیں گے، حالانکہ عزّت تو صرف اللہ کے لئے اور اس کے رسول (صلی اللہ علیہ وآلہ وسلم) کے لئے اور مومنوں کے لئے ہے مگر منافقین (اس حقیقت کو) جانتے نہیں ہیں،\qt@no{8}}%
\qt@newcmd\qurantrans@ur@mmmmmcxcvii{اے ایمان والو! تمہارے مال اور تمہاری اولاد (کہیں) تمہیں اللہ کی یاد سے ہی غافل نہ کر دیں، اور جو شخص ایسا کرے گا تو وہی لوگ نقصان اٹھانے والے ہیں،\qt@no{9}}%
\qt@newcmd\qurantrans@ur@mmmmmcxcviii{اور تم اس (مال) میں سے جو ہم نے تمہیں عطا کیا ہے (اللہ کی راہ میں) خرچ کرو قبل اِس کے کہ تم میں سے کسی کو موت آجائے پھر وہ کہنے لگے: اے میرے رب! تو نے مجھے تھوڑی مدت تک کی مہلت اور کیوں نہ دے دی کہ میں صدقہ و خیرات کرلیتا اور نیکوکاروں میں سے ہو جاتا،\qt@no{10}}%
\qt@newcmd\qurantrans@ur@mmmmmcxcix{اور اللہ ہرگز کسی شخص کو مہلت نہیں دیتا جب اس کی موت کا وقت آجاتا ہے، اور اللہ اُن کاموں سے خوب آگاہ ہے جو تم کرتے ہو،\qt@no{11}}%
\qt@newcmd\qurantrans@ur@mmmmmcc{\basmalahur ہر وہ چیز جو آسمانوں میں ہے اور زمین میں ہے اللہ کی تسبیح کرتی ہے۔ اسی کی ساری بادشاہت ہے اور اسی کے لئے ساری تعریف ہے اور وہ ہر چیز پر بڑا قادر ہے،\qt@no{1}}%
\qt@newcmd\qurantrans@ur@mmmmmcci{وہی ہے جس نے تمہیں پیدا کیا، پس تم میں سے (کوئی) کافر ہو گیا، اور تم میں سے (کوئی) مومن ہوگیا، اور اللہ اُن کاموں کو جو تم کرتے ہو خوب دیکھنے والا ہے،\qt@no{2}}%
\qt@newcmd\qurantrans@ur@mmmmmccii{اسی نے آسمانوں اور زمین کو حکمت و مقصد کے ساتھ پیدا فرمایا اور (اسی نے) تمہاری صورتیں بنائیں پھر تمہاری صورتوں کو خوب تر کیا، اور (سب کو) اسی کی طرف لوٹ کر جانا ہے،\qt@no{3}}%
\qt@newcmd\qurantrans@ur@mmmmmcciii{جو کچھ آسمانوں اور زمین میں ہے وہ جانتا ہے اور ان باتوں کو (بھی) جانتا ہے جو تم چھپاتے ہو، اور جو ظاہر کرتے ہو اور اللہ سینوں والی (راز کی) باتوں کو (بھی) خوب جاننے والا ہے،\qt@no{4}}%
\qt@newcmd\qurantrans@ur@mmmmmcciv{کیا تمہیں اُن لوگوں کی خبر نہیں پہنچی جنہوں نے (تم سے) پہلے کفر کیا تھا تو انہوں نے (دنیا میں) اپنے کام کی سزا چکھ لی اور ان کے لئے (آخرت میں بھی) دردناک عذاب ہے،\qt@no{5}}%
\qt@newcmd\qurantrans@ur@mmmmmccv{یہ اس لئے کہ اُن کے پاس اُن کے رسول واضح نشانیاں لے کر آتے تھے تو وہ کہتے تھے: کیا (ہماری ہی مثل اور ہم جنس) بشر٭ ہمیں ہدایت کریں گے؟ سو وہ کافر ہوگئے اور انہوں نے (حق سے) رُوگردانی کی اور اللہ نے بھی (اُن کی) کچھ پرواہ نہ کی، اور اللہ بے نیاز ہے لائقِ حمد و ثنا ہے، ٭ بشر کا یہ معنی ائمہ تفاسیر کے بیان کردہ معنی کے مطابق ہے۔ حوالہ جات کے لئے دیکھیں: تفسیر طبری، الکشاف، نسفی، بغوی، خازن، جمل، مظہری اور فتح القدیر وغیرہ۔\qt@no{6}}%
\qt@newcmd\qurantrans@ur@mmmmmccvi{کافر لوگ یہ خیال کرتے ہیں کہ وہ (دوبارہ) ہرگز نہ اٹھائے جائیں گے۔ فرما دیجئے: کیوں نہیں، میرے رب کی قسم! تم ضرور اٹھائے جاؤ گے پھر تمہیں بتا دیا جائے گا جو کچھ تم نے کیا تھا، اور یہ اللہ پر بہت آسان ہے،\qt@no{7}}%
\qt@newcmd\qurantrans@ur@mmmmmccvii{پس تم اللہ اور اُس کے رسول (صلی اللہ علیہ وآلہ وسلم) پر اور اُس نور پر ایمان لاؤ جسے ہم نے نازل فرمایا ہے، اور اللہ اُن کاموں سے خوب آگاہ ہے جو تم کرتے ہو،\qt@no{8}}%
\qt@newcmd\qurantrans@ur@mmmmmccviii{جس دن وہ تمہیں جمع ہونے کے دن (میدانِ حشر میں) اکٹھا کرے گا یہ ہار اور نقصان ظاہر ہونے کا دن ہے۔ اور جو شخص اللہ پر ایمان لاتا ہے اور نیک عمل کرتا ہے تو (اللہ) اس (کے نامۂ اعمال) سے اس کی خطائیں مٹا دے گا اور اسے جنتوں میں داخل فرما دے گا جن کے نیچے سے نہریں بہہ رہی ہیں وہ ان میں ہمیشہ رہنے والے ہوں گے، یہ بہت بڑی کامیابی ہے،\qt@no{9}}%
\qt@newcmd\qurantrans@ur@mmmmmccix{اور جن لوگوں نے کفر کیا اور ہماری آیتوں کو جھٹلایا وہی لوگ دوزخی ہیں (جو) اس میں ہمیشہ رہنے والے ہیں، اور وہ کیا ہی برا ٹھکانا ہے،\qt@no{10}}%
\qt@newcmd\qurantrans@ur@mmmmmccx{کسی کو) کوئی مصیبت نہیں پہنچتی مگر اللہ کے حکم سے اور جو شخص اللہ پر ایمان لاتا ہے تو وہ اُس کے دل کو ہدایت فرما دیتا ہے، اور اللہ ہر چیز کو خوب جاننے والا ہے،\qt@no{11}}%
\qt@newcmd\qurantrans@ur@mmmmmccxi{اور تم اللہ کی اطاعت کرو اور رسول (صلی اللہ علیہ وآلہ وسلم) کی اطاعت کرو، پھر اگر تم نے رُوگردانی کی تو (یاد رکھو) ہمارے رسول (صلی اللہ علیہ وآلہ وسلم) کے ذمّہ صرف واضح طور پر (احکام کو) پہنچا دینا ہے،\qt@no{12}}%
\qt@newcmd\qurantrans@ur@mmmmmccxii{اللہ (ہی معبود) ہے اس کے سوا کوئی معبود نہیں، اور اللہ ہی پر ایمان والوں کو بھروسہ رکھنا چاہئے،\qt@no{13}}%
\qt@newcmd\qurantrans@ur@mmmmmccxiii{اے ایمان والو! بیشک تمہاری بیویوں اور تمہاری اولاد میں سے بعض تمہارے دشمن ہیں پس اُن سے ہوشیار رہو۔ اور اگر تم صرفِ نظر کر لو اور درگزر کرو اور معاف کر دو تو بیشک اللہ بڑا بخشنے والا نہایت مہربان ہے،\qt@no{14}}%
\qt@newcmd\qurantrans@ur@mmmmmccxiv{تمہارے مال اور تمہاری اولاد محض آزمائش ہی ہیں، اور اللہ کی بارگاہ میں بہت بڑا اجر ہے،\qt@no{15}}%
\qt@newcmd\qurantrans@ur@mmmmmccxv{پس تم اللہ سے ڈرتے رہو جس قدر تم سے ہوسکے اور (اُس کے احکام) سنو اور اطاعت کرو اور (اس کی راہ میں) خرچ کرو یہ تمہارے لئے بہتر ہوگا، اور جو اپنے نفس کے بخل سے بچا لیا جائے سو وہی لوگ فلاح پانے والے ہیں،\qt@no{16}}%
\qt@newcmd\qurantrans@ur@mmmmmccxvi{اگر تم اللہ کو (اخلاص اور نیک نیتی سے) اچھا قرض دوگے تو وہ اسے تمہارے لئے کئی گنا بڑھا دے گا اور تمہیں بخش دے گا، اور اللہ بڑا قدر شناس ہے بُردبار ہے،\qt@no{17}}%
\qt@newcmd\qurantrans@ur@mmmmmccxvii{ہر نہاں اور عیاں کو جاننے والا ہے، بڑے غلبہ و عزت والا بڑی حکمت والا ہے،\qt@no{18}}%
\qt@newcmd\qurantrans@ur@mmmmmccxviii{\basmalahur اے نبی! (مسلمانوں سے فرما دیں:) جب تم عورتوں کو طلاق دینا چاہو تو اُن کے طُہر کے زمانہ میں انہیں طلاق دو اور عِدّت کو شمار کرو، اور اللہ سے ڈرتے رہو جو تمہارا رب ہے، اور انہیں اُن کے گھروں سے باہر مت نکالو اور نہ وہ خود باہر نکلیں سوائے اس کے کہ وہ کھلی بے حیائی کر بیٹھیں، اور یہ اللہ کی (مقررّہ) حدیں ہیں، اور جو شخص اللہ کی حدود سے تجاوز کرے تو بیشک اُس نے اپنی جان پر ظلم کیا ہے، (اے شخص!) تو نہیں جانتا شاید اللہ اِس کے (طلاق دینے کے) بعد (رجوع کی) کوئی نئی صورت پیدا فرما دے،\qt@no{1}}%
\qt@newcmd\qurantrans@ur@mmmmmccxix{پھر جب وہ اپنی مقررہ میعاد (کے ختم ہونے) کے قریب پہنچ جائیں تو انہیں بھلائی کے ساتھ (اپنی زوجیت میں) روک لو یا انہیں بھلائی کے ساتھ جدا کردو۔ اور اپنوں میں سے دو عادل مَردوں کو گواہ بنا لو اور گواہی اللہ کے لئے قائم کیا کرو، اِن (باتوں) سے اسی شخص کو نصیحت کی جاتی ہے جو اللہ اور یومِ آخرت پر ایمان رکھتا ہے، اور جو اللہ سے ڈرتا ہے وہ اس کے لئے (دنیا و آخرت کے رنج و غم سے) نکلنے کی راہ پیدا فرما دیتا ہے،\qt@no{2}}%
\qt@newcmd\qurantrans@ur@mmmmmccxx{اور اسے ایسی جگہ سے رِزق عطا فرماتا ہے جہاں سے اس کا گمان بھی نہیں ہوتا، اور جو شخص اللہ پر توکل کرتا ہے تو وہ (اللہ) اسے کافی ہے، بیشک اللہ اپنا کام پورا کرلینے والا ہے، بیشک اللہ نے ہر شے کے لئے اندازہ مقرر فرما رکھا ہے،\qt@no{3}}%
\qt@newcmd\qurantrans@ur@mmmmmccxxi{اور تمہاری عورتوں میں سے جو حیض سے مایوس ہو چکی ہوں اگر تمہیں شک ہو (کہ اُن کی عدّت کیا ہوگی) تو اُن کی عدّت تین مہینے ہے اور وہ عورتیں جنہیں (ابھی) حیض نہیں آیا (ان کی بھی یہی عدّت ہے)، اور حاملہ عورتیں (تو) اُن کی عدّت اُن کا وضعِ حمل ہے، اور جو شخص اللہ سے ڈرتا ہے (تو) وہ اس کے کام میں آسانی فرما دیتا ہے،\qt@no{4}}%
\qt@newcmd\qurantrans@ur@mmmmmccxxii{یہ اللہ کا امر ہے جو اس نے تمہاری طرف نازل فرمایا ہے۔ اور جو شخص اللہ سے ڈرتا ہے وہ اُس کے چھوٹے گناہوں کو اس (کے نامۂ اعمال) سے مٹا دیتا ہے اور اَجر و ثواب کو اُس کے لئے بڑا کر دیتا ہے،\qt@no{5}}%
\qt@newcmd\qurantrans@ur@mmmmmccxxiii{تم اُن (مطلّقہ) عورتوں کو وہیں رکھو جہاں تم اپنی وسعت کے مطابق رہتے ہو اور انہیں تکلیف مت پہنچاؤ کہ اُن پر (رہنے کا ٹھکانا) تنگ کر دو، اور اگر وہ حاملہ ہوں تو اُن پر خرچ کرتے رہو یہاں تک کہ وہ اپنا بچہ جَن لیں، پھر اگر وہ تمہاری خاطر (بچے کو) دودھ پلائیں تو انہیں اُن کا معاوضہ ادا کرتے رہو، اور آپس میں (ایک دوسرے سے) نیک بات کا مشورہ (حسبِ دستور) کر لیا کرو، اور اگر تم باہم دشواری محسوس کرو تو اسے (اب کوئی) دوسری عورت دودھ پلائے گی،\qt@no{6}}%
\qt@newcmd\qurantrans@ur@mmmmmccxxiv{صاحبِ وسعت کو اپنی وسعت (کے لحاظ) سے خرچ کرنا چاہئے، اور جس شخص پر اُس کا رِزق تنگ کر دیا گیا ہو تو وہ اُسی (روزی) میں سے (بطورِ نفقہ) خرچ کرے جو اُسے اللہ نے عطا فرمائی ہے۔ اللہ کسی شخص کو مکلّف نہیں ٹھہراتا مگر اسی قدر جتنا کہ اُس نے اسے عطا فرما رکھا ہے، اللہ عنقریب تنگی کے بعد کشائش پیدا فرما دے گا،\qt@no{7}}%
\qt@newcmd\qurantrans@ur@mmmmmccxxv{اور کتنی ہی بستیاں ایسی تھیں جن (کے رہنے والوں) نے اپنے رب کے حکم اور اُس کے رسولوں سے سرکشی و سرتابی کی تو ہم نے اُن کا سخت حساب کی صورت میں محاسبہ کیا اور انہیں ایسے سخت عذاب میں مبتلا کیا جو نہ دیکھا نہ سنا گیا تھا،\qt@no{8}}%
\qt@newcmd\qurantrans@ur@mmmmmccxxvi{سو انہوں نے اپنے کئے کا وبال چکھ لیا اور اُن کے کام کا انجام خسارہ ہی ہوا،\qt@no{9}}%
\qt@newcmd\qurantrans@ur@mmmmmccxxvii{اللہ نے اُن کے لئے (آخرت میں بھی) سخت عذاب تیار کر رکھا ہے۔ سو اللہ سے ڈرتے رہا کرو اے عقل والو! جو ایمان لے آئے ہو، بیشک اللہ نے تمہاری (ہی) طرف نصیحتِ (قرآن) کو نازل فرمایا ہے،\qt@no{10}}%
\qt@newcmd\qurantrans@ur@mmmmmccxxviii{اور) رسول (صلی اللہ علیہ وآلہ وسلم) کو (بھی بھیجا ہے) جو تم پر اللہ کی واضح آیات پڑھ کر سناتے ہیں تاکہ اُن لوگوں کو جو ایمان لائے ہیں اور نیک اعمال کرتے ہیں تاریکیوں سے نکال کر روشنی کی طرف لے جائے، اور جو شخص اللہ پر ایمان رکھتا ہے اور نیک عمل کرتا ہے وہ اسے ان جنتوں میں داخل فرمائے گا جن کے نیچے سے نہریں رواں ہیں وہ ان میں ہمیشہ رہنے والے ہیں، بیشک اللہ نے اُس کے لئے نہایت عمدہ رزق (تیار کر) رکھا ہے،\qt@no{11}}%
\qt@newcmd\qurantrans@ur@mmmmmccxxix{اللہ (ہی) ہے جس نے سات آسمان پیدا فرمائے اور زمین (کی تشکیل) میں بھی انہی کی مِثل (تہ بہ تہ سات طبقات بنائے)، ان کے درمیان (نظامِ قدرت کی تدبیر کا) امر اترتا رہتا ہے تاکہ تم جان لو کہ اللہ ہر چیز پر بڑا قادر ہے، اور یہ کہ اللہ نے ہر چیز کا اپنے علم سے احاطہ فرما رکھا ہے (یعنی آنے والے زمانوں میں جب سائنسی اکتشافات کامل ہوں گے تو تمہیں اللہ کی قدرت اور علمِ محیط کی عظمت کا اندازہ ہو جائے گا کہ کس طرح اُس نے صدیوں قبل ان حقائق کو تمہارے لئے بیان فرما رکھا ہے)،\qt@no{12}}%
\qt@newcmd\qurantrans@ur@mmmmmccxxx{\basmalahur اے نبئ (مکرّم!) آپ خود کو اس چیز (یعنی شہد کے نوش کرنے) سے کیوں منع فرماتے ہیں جسے اللہ نے آپ کے لئے حلال فرما رکھا ہے۔ آپ اپنی ازواج کی (اس قدر) دل جوئی فرماتے ہیں، اور اللہ بڑا بخشنے والا نہایت مہربان ہے،\qt@no{1}}%
\qt@newcmd\qurantrans@ur@mmmmmccxxxi{اے مومنو!) بیشک اللہ نے تمہارے لئے تمہاری قَسموں کا (کفارہ دے کر) کھول ڈالنا مقرر فرما دیا ہے۔ اور اللہ تمہارا مددگار و کارساز ہے، اور وہ خوب جاننے والا بڑی حکمت والا ہے،\qt@no{2}}%
\qt@newcmd\qurantrans@ur@mmmmmccxxxii{اور جب نبئ (مکرّم صلی اللہ علیہ وآلہ وسلم) نے اپنی ایک زوجہ سے ایک رازدارانہ بات ارشاد فرمائی، پھر جب وہ اُس (بات) کا ذکر کر بیٹھیں اور اللہ نے نبی (صلی اللہ علیہ وآلہ وسلم) پر اسے ظاہر فرما دیا تو نبی (صلی اللہ علیہ وآلہ وسلم) نے انہیں اس کا کچھ حصہ جِتا دیا اور کچھ حصہ (بتانے) سے چشم پوشی فرمائی، پھر جب نبی (صلی اللہ علیہ وآلہ وسلم) نے انہیں اِس کی خبر دے دی (کہ آپ راز اِفشاء کر بیٹھی ہیں) تو وہ بولیں: آپ کو یہ کس نے بتا دیا ہے؟ نبی (صلی اللہ علیہ وآلہ وسلم) نے فرمایا کہ مجھے بڑے علم والے بڑی آگاہی والے (رب) نے بتا دیا ہے،\qt@no{3}}%
\qt@newcmd\qurantrans@ur@mmmmmccxxxiii{اگر تم دونوں اللہ کی بارگاہ میں توبہ کرو (تو تمہارے لئے بہتر ہے) کیونکہ تم دونوں کے دل (ایک ہی بات کی طرف) جھک گئے ہیں، اگر تم دونوں نے اس بات پر ایک دوسرے کی اعانت کی (تو یہ نبی مکرّم صلی اللہ علیہ وآلہ وسلم کے لئے باعثِ رنج ہوسکتا ہے) سو بیشک اللہ ہی اُن کا دوست و مددگار ہے، اور جبریل اور صالح مومنین بھی اور اس کے بعد (سارے) فرشتے بھی (اُن کے) مددگار ہیں،\qt@no{4}}%
\qt@newcmd\qurantrans@ur@mmmmmccxxxiv{اگر وہ تمہیں طلاق دے دیں تو عجب نہیں کہ اُن کا رب انہیں تم سے بہتر ازواج بدلہ میں عطا فرما دے (جو) فرمانبردار، ایماندار، اطاعت گزار، توبہ شعار، عبادت گزار، روزہ دار، (بعض) شوہر دیدہ اور (بعض) کنواریاں ہوں گی،\qt@no{5}}%
\qt@newcmd\qurantrans@ur@mmmmmccxxxv{اے ایمان والو! اپنے آپ کو اور اپنے اہل و عیال کو اس آگ سے بچاؤ جس کا ایندھن انسان اور پتھر ہیں، جس پر سخت مزاج طاقتور فرشتے (مقرر) ہیں جو کسی بھی امر میں جس کا وہ انہیں حکم دیتا ہے اﷲ کی نافرمانی نہیں کرتے اور وہی کام انجام دیتے ہیں جس کا انہیں حکم دیا جاتا ہے،\qt@no{6}}%
\qt@newcmd\qurantrans@ur@mmmmmccxxxvi{اے کافرو! آج کے دن کوئی عذر پیش نہ کرو، بس تمہیں اسی کا بدلہ دیا جائے گا جو کرتے رہے تھے،\qt@no{7}}%
\qt@newcmd\qurantrans@ur@mmmmmccxxxvii{اے ایمان والو! تم اللہ کے حضور رجوعِ کامل سے خالص توبہ کر لو، یقین ہے کہ تمہارا رب تم سے تمہاری خطائیں دفع فرما دے گا اور تمہیں بہشتوں میں داخل فرمائے گا جن کے نیچے سے نہریں رواں ہیں جس دن اللہ (اپنے) نبی (صلی اللہ علیہ وآلہ وسلم) کو اور اُن اہلِ ایمان کو جو اُن کی (ظاہری یا باطنی) معیّت میں ہیں رسوا نہیں کرے گا، اُن کا نور اُن کے آگے اور اُن کے دائیں طرف (روشنی دیتا ہوا) تیزی سے چل رہا ہوگا، وہ عرض کرتے ہوں گے: اے ہمارے رب! ہمارا نور ہمارے لئے مکمل فرما دے اور ہماری مغفرت فرما دے، بیشک تو ہر چیز پر بڑا قادر ہے،\qt@no{8}}%
\qt@newcmd\qurantrans@ur@mmmmmccxxxviii{اے نبئ (مکرّم!) آپ کافروں اور منافقوں سے جہاد کیجئے اور اُن پر سختی فرمائیے، اور ان کا ٹھکانا جہنم ہے، اور وہ کیا ہی برا ٹھکانا ہے،\qt@no{9}}%
\qt@newcmd\qurantrans@ur@mmmmmccxxxix{اللہ نے اُن لوگوں کے لئے جنہوں نے کفر کیا ہے نوح (علیہ السلام) کی عورت اور لوط (علیہ السلام) کی عورت (واہلہ اور واعلہ) کی مثال بیان فرمائی ہے، وہ دونوں ہمارے بندوں میں سے دو صالح بندوں کے نکاح میں تھیں، سو دونوں نے اُن سے خیانت کی پس وہ اللہ (کے عذاب) کے سامنے اُن کے کچھ کام نہ آئے اور اُن سے کہہ دیا گیا کہ تم دونوں (عورتیں) داخل ہونے والوں کے ساتھ دوزخ میں داخل ہو جاؤ،\qt@no{10}}%
\qt@newcmd\qurantrans@ur@mmmmmccxl{اور اللہ نے اُن لوگوں کے لئے جو ایمان لائے ہیں زوجۂ فرعون (آسیہ بنت مزاحم) کی مثال بیان فرمائی ہے، جب اس نے عرض کیا: اے میرے رب! تو میرے لئے بہشت میں اپنے پاس ایک گھر بنا دے اور مجھ کو فرعون اور اُس کے عملِ (بد) سے نجات دے دے اور مجھے ظالم قوم سے (بھی) بچا لے،\qt@no{11}}%
\qt@newcmd\qurantrans@ur@mmmmmccxli{اور (دوسری مثال) عمران کی بیٹی مریم کی (بیان فرمائی ہے) جس نے اپنی عصمت و عفّت کی خوب حفاظت کی تو ہم نے (اس کے) گریبان میں اپنی روح پھونک دی اور اس نے اپنے رب کے فرامین اور اس کی (نازل کردہ) کتابوں کی تصدیق کی اور وہ اطاعت گزاروں میں سے تھی،\qt@no{12}}%
\qt@newcmd\qurantrans@ur@mmmmmccxlii{\basmalahur وہ ذات نہایت بابرکت ہے جس کے دستِ (قدرت) میں (تمام جہانوں کی) سلطنت ہے، اور وہ ہر چیز پر پوری طرح قادر ہے،\qt@no{1}}%
\qt@newcmd\qurantrans@ur@mmmmmccxliii{جس نے موت اور زندگی کو (اِس لئے) پیدا فرمایا کہ وہ تمہیں آزمائے کہ تم میں سے کون عمل کے لحاظ سے بہتر ہے، اور وہ غالب ہے بڑا بخشنے والا ہے،\qt@no{2}}%
\qt@newcmd\qurantrans@ur@mmmmmccxliv{جس نے سات (یا متعدّد) آسمانی کرّے باہمی مطابقت کے ساتھ (طبق دَر طبق) پیدا فرمائے، تم (خدائے) رحمان کے نظامِ تخلیق میں کوئی بے ضابطگی اور عدمِ تناسب نہیں دیکھو گے، سو تم نگاہِ (غور و فکر) پھیر کر دیکھو، کیا تم اس (تخلیق) میں کوئی شگاف یا خلل (یعنی شکستگی یا اِنقطاع) دیکھتے ہو،\qt@no{3}}%
\qt@newcmd\qurantrans@ur@mmmmmccxlv{تم پھر نگاہِ (تحقیق) کو بار بار (مختلف زاویوں اور سائنسی طریقوں سے) پھیر کر دیکھو، (ہر بار) نظر تمہاری طرف تھک کر پلٹ آئے گی اور وہ (کوئی بھی نقص تلاش کرنے میں) ناکام ہوگی،\qt@no{4}}%
\qt@newcmd\qurantrans@ur@mmmmmccxlvi{اور بے شک ہم نے سب سے قریبی آسمانی کائنات کو (ستاروں، سیاروں، دیگر خلائی کرّوں اور ذرّوں کی شکل میں) چراغوں سے مزیّن فرما دیا ہے، اور ہم نے ان (ہی میں سے بعض) کو شیطانوں (یعنی سرکش قوتوں) کو مار بھگانے (یعنی ان کے منفی اَثرات ختم کرنے) کا ذریعہ (بھی) بنایا ہے، اور ہم نے ان (شیطانوں) کے لئے دہکتی آگ کا عذاب تیار کر رکھا ہے،\qt@no{5}}%
\qt@newcmd\qurantrans@ur@mmmmmccxlvii{اور ایسے لوگوں کے لئے جنہوں نے اپنے رب کا اِنکار کیا دوزخ کا عذاب ہے، اور وہ کیا ہی برا ٹھکانا ہے،\qt@no{6}}%
\qt@newcmd\qurantrans@ur@mmmmmccxlviii{جب وہ اس میں ڈالے جائیں گے تو اس کی خوف ناک آواز سنیں گے اور وہ (آگ) جوش مار رہی ہوگی،\qt@no{7}}%
\qt@newcmd\qurantrans@ur@mmmmmccxlix{گویا (ابھی) شدتِ غضب سے پھٹ کر پارہ پارہ ہو جائے گی، جب اس میں کوئی گروہ ڈالا جائے گا تو اس کے داروغے ان سے پوچھیں گے: کیا تمہارے پاس کوئی ڈر سنانے والا نہیں آیا تھا،\qt@no{8}}%
\qt@newcmd\qurantrans@ur@mmmmmccl{وہ کہیں گے: کیوں نہیں! بے شک ہمارے پاس ڈر سنانے والا آیا تھا تو ہم نے جھٹلا دیا اور ہم نے کہا کہ اللہ نے کوئی چیز نازل نہیں کی، تم تو محض بڑی گمراہی میں (پڑے ہوئے) ہو،\qt@no{9}}%
\qt@newcmd\qurantrans@ur@mmmmmccli{اور کہیں گے: اگر ہم (حق کو) سنتے یا سمجھتے ہوتے تو ہم (آج) اہلِ جہنم میں (شامل) نہ ہوتے،\qt@no{10}}%
\qt@newcmd\qurantrans@ur@mmmmmcclii{پس وہ اپنے گناہ کا اِعتراف کر لیں گے، سو دوزخ والوں کے لئے (رحمتِ اِلٰہی سے) دُوری (مقرر) ہے،\qt@no{11}}%
\qt@newcmd\qurantrans@ur@mmmmmccliii{بے شک جو لوگ بن دیکھے اپنے رب سے ڈرتے ہیں ان کے لئے بخشش اور بڑا اَجر ہے،\qt@no{12}}%
\qt@newcmd\qurantrans@ur@mmmmmccliv{اور تم لوگ اپنی بات چھپا کر کہو یا اُسے بلند آواز میں کہو، یقیناً وہ سینوں کی (چھپی) باتوں کو (بھی) خوب جانتا ہے،\qt@no{13}}%
\qt@newcmd\qurantrans@ur@mmmmmcclv{بھلا وہ نہیں جانتا جس نے پیدا کیا ہے؟ حالانکہ وہ بڑا باریک بین (ہر چیز سے) خبردار ہے،\qt@no{14}}%
\qt@newcmd\qurantrans@ur@mmmmmcclvi{وُہی ہے جس نے تمہارے لئے زمین کو نرم و مسخر کر دیا، سو تم اس کے راستوں میں چلو پھرو، اور اُس کے (دئیے ہوئے) رِزق میں سے کھاؤ، اور اُسی کی طرف (مرنے کے بعد) اُٹھ کر جانا ہے،\qt@no{15}}%
\qt@newcmd\qurantrans@ur@mmmmmcclvii{کیا تم آسمان والے (رب) سے بے خوف ہو گئے ہو کہ وہ تمہیں زمین میں دھنسا دے (اس طرح) کہ وہ اچانک لرزنے لگے،\qt@no{16}}%
\qt@newcmd\qurantrans@ur@mmmmmcclviii{کیا تم آسمان والے (رب) سے بے خوف ہو گئے ہو کہ وہ تم پر پتھر برسانے والی ہوا بھیج دے؟ سو تم عنقریب جان لو گے کہ میرا ڈرانا کیسا ہے،\qt@no{17}}%
\qt@newcmd\qurantrans@ur@mmmmmcclix{اور بے شک ان لوگوں نے (بھی) جھٹلایا تھا جو ان سے پہلے تھے، سو میرا اِنکار کیسا (عبرت ناک ثابت) ہوا،\qt@no{18}}%
\qt@newcmd\qurantrans@ur@mmmmmcclx{کیا اُنہوں نے پرندوں کو اپنے اوپر پر پھیلائے ہوئے اور (کبھی) پر سمیٹے ہوئے نہیں دیکھا؟ اُنہیں (فضا میں گرنے سے) کوئی نہیں روک سکتا سوائے رحمان کے (بنائے ہوئے قانون کے)، بے شک وہ ہر چیز کو خوب دیکھنے والا ہے،\qt@no{19}}%
\qt@newcmd\qurantrans@ur@mmmmmcclxi{بھلا کوئی ایسا ہے جو تمہاری فوج بن کر (خدائے) رحمان کے مقابلہ میں تمہاری مدد کرے؟ کافر محض دھوکہ میں (مبتلا) ہیں،\qt@no{20}}%
\qt@newcmd\qurantrans@ur@mmmmmcclxii{بھلا کوئی ایسا ہے جو تمہیں رِزق دے سکے اگر (اللہ تم سے) اپنا رِزق روک لے؟ بلکہ وہ سرکشی اور (حق سے) نفرت میں مضبوطی سے اَڑے ہوئے ہیں،\qt@no{21}}%
\qt@newcmd\qurantrans@ur@mmmmmcclxiii{کیا وہ شخص جو منہ کے بل اوندھا چل رہا ہے زیادہ راہِ راست پر ہے یا وہ شخص جو سیدھی حالت میں صحیح راہ پر گامزن ہے؟،\qt@no{22}}%
\qt@newcmd\qurantrans@ur@mmmmmcclxiv{آپ فرما دیجئے: وُہی (اللہ) ہے جس نے تمہیں پیدا فرمایا اور تمہارے لئے کان اور آنکھیں اور دِل بنائے، تم بہت ہی کم شکر ادا کرتے ہو،\qt@no{23}}%
\qt@newcmd\qurantrans@ur@mmmmmcclxv{فرما دیجئے: وُہی ہے جس نے تمہیں زمین میں پھیلا دیا اور تم (روزِ قیامت) اُسی کی طرف جمع کیے جاؤ گے،\qt@no{24}}%
\qt@newcmd\qurantrans@ur@mmmmmcclxvi{اور وہ کہتے ہیں: یہ (قیامت کا) وعدہ کب پورا ہوگا اگر تم سچے ہو،\qt@no{25}}%
\qt@newcmd\qurantrans@ur@mmmmmcclxvii{فرما دیجئے کہ (اُس کے وقت کا) علم تو اللہ ہی کے پاس ہے، اور میں تو صرف واضح ڈر سنانے والا ہوں (اگر وقت بتا دیا جائے تو ڈر ختم ہو جائے گا)،\qt@no{26}}%
\qt@newcmd\qurantrans@ur@mmmmmcclxviii{پھر جب اس (دن) کو قریب دیکھ لیں گے تو کافروں کے چہرے بگڑ کر سیاہ ہو جائیں گے، اور (ان سے) کہا جائے گا: یہی وہ (وعدہ) ہے جس کے (جلد ظاہر کیے جانے کے) تم بہت طلب گار تھے،\qt@no{27}}%
\qt@newcmd\qurantrans@ur@mmmmmcclxix{فرما دیجئے: بھلا یہ بتاؤ اگر اللہ مجھے موت سے ہم کنار کر دے (جیسے تم خواہش کرتے ہو) اور جو میرے ساتھ ہیں (ان کو بھی)، یا ہم پر رحم فرمائے (یعنی ہماری موت کو مؤخر کر دے) تو (ان دونوں صورتوں میں) کون ہے جو کافروں کو دردناک عذاب سے پناہ دے گا،\qt@no{28}}%
\qt@newcmd\qurantrans@ur@mmmmmcclxx{فرما دیجئے: وُہی (خدائے) رحمان ہے جس پر ہم ایمان لائے ہیں اور اُسی پر ہم نے بھروسہ کیا ہے، پس تم عنقریب جان لو گے کہ کون شخص کھلی گمراہی میں ہے،\qt@no{29}}%
\qt@newcmd\qurantrans@ur@mmmmmcclxxi{فرما دیجئے: اگر تمہارا پانی زمین میں بہت نیچے اتر جائے (یعنی خشک ہو جائے) تو کون ہے جو تمہیں (زمین پر) بہتا ہوا پانی لا دے،\qt@no{30}}%
\qt@newcmd\qurantrans@ur@mmmmmcclxxii{\basmalahur نون (حقیقی معنی اللہ اور رسول صلی اللہ علیہ وآلہ وسلم ہی بہتر جانتے ہیں)، قلم کی قَسم اور اُس (مضمون) کی قَسم جو (فرشتے) لکھتے ہیں،\qt@no{1}}%
\qt@newcmd\qurantrans@ur@mmmmmcclxxiii{اے حبیبِ مکرّم!) آپ اپنے رب کے فضل سے (ہرگز) دیوانے نہیں ہیں،\qt@no{2}}%
\qt@newcmd\qurantrans@ur@mmmmmcclxxiv{اور بے شک آپ کے لئے ایسا اَجر ہے جو کبھی ختم نہ ہوگا،\qt@no{3}}%
\qt@newcmd\qurantrans@ur@mmmmmcclxxv{اور بے شک آپ عظیم الشان خلق پر قائم ہیں (یعنی آدابِ قرآنی سے مزّین اور اَخلاقِ اِلٰہیہ سے متّصف ہیں)،\qt@no{4}}%
\qt@newcmd\qurantrans@ur@mmmmmcclxxvi{پس عنقریب آپ (بھی) دیکھ لیں گے اور وہ (بھی) دیکھ لیں گے،\qt@no{5}}%
\qt@newcmd\qurantrans@ur@mmmmmcclxxvii{کہ تم میں سے کون دیوانہ ہے،\qt@no{6}}%
\qt@newcmd\qurantrans@ur@mmmmmcclxxviii{بے شک آپ کا رب اس شخص کو (بھی) خوب جانتا ہے جو اس کی راہ سے بھٹک گیا ہے، اور وہ ان کو (بھی) خوب جانتا ہے جو ہدایت یافتہ ہیں،\qt@no{7}}%
\qt@newcmd\qurantrans@ur@mmmmmcclxxix{سو آپ جھٹلانے والوں کی بات نہ مانیں،\qt@no{8}}%
\qt@newcmd\qurantrans@ur@mmmmmcclxxx{وہ تو چاہتے ہیں کہ (دین کے معاملے میں) آپ (بے جا) نرمی اِختیار کر لیں تو وہ بھی نرم پڑ جائیں گے،\qt@no{9}}%
\qt@newcmd\qurantrans@ur@mmmmmcclxxxi{اور آپ کسی ایسے شخص کی بات نہ مانیں جو بہت قَسمیں کھانے والا اِنتہائی ذلیل ہے،\qt@no{10}}%
\qt@newcmd\qurantrans@ur@mmmmmcclxxxii{جو) طعنہ زَن، عیب جُو (ہے اور) لوگوں میں فساد انگیزی کے لئے چغل خوری کرتا پھرتا ہے،\qt@no{11}}%
\qt@newcmd\qurantrans@ur@mmmmmcclxxxiii{جو) بھلائی کے کام سے بہت روکنے والا بخیل، حد سے بڑھنے والا سرکش (اور) سخت گنہگار ہے،\qt@no{12}}%
\qt@newcmd\qurantrans@ur@mmmmmcclxxxiv{جو) بد مزاج درُشت خو ہے، مزید برآں بد اَصل (بھی) ہے٭، ٭ یہ آیات ولید بن مغیرہ کے بارے میں نازل ہوئیں۔ حضرت عبد اﷲ بن عباس رضی اﷲ عنہما فرماتے ہیں کہ جتنے ذِلت آمیز اَلقاب باری تعالیٰ نے اس بدبخت کو دئیے آج تک کلامِ اِلٰہی میں کسی اور کے لئے استعمال نہیں ہوئے۔ وجہ یہ تھی کہ اُس نے حضور نبی اکرم صلی اللہ علیہ وآلہ وسلم کی شانِ اَقدس میں گستاخی کی، جس پر غضبِ اِلٰہی بھڑک اٹھا۔ ولید نے حضور نبی اکرم صلی اللہ علیہ وآلہ وسلم کی شان میں گستاخی کا ایک کلمہ بولا تھا، جواباً باری تعالیٰ نے اُس کے دس رذائل بیان کیے اور آخر میں نطفۂ حرام ہونا بھی ظاہر کر دیا، اور اس کی ماں نے بعد ازاں اِس اَمر کی بھی تصدیق کر دی۔ (تفسیر قرطبی، رازی، نسفی وغیرھم)\qt@no{13}}%
\qt@newcmd\qurantrans@ur@mmmmmcclxxxv{اِس لئے (اس کی بات کو اہمیت نہ دیں) کہ وہ مال دار اور صاحبِ اَولاد ہے،\qt@no{14}}%
\qt@newcmd\qurantrans@ur@mmmmmcclxxxvi{جب اس پر ہماری آیتیں تلاوت کی جائیں (تو) کہتا ہے: یہ (تو) پہلے لوگوں کے اَفسانے ہیں،\qt@no{15}}%
\qt@newcmd\qurantrans@ur@mmmmmcclxxxvii{اب ہم اس کی سونڈ جیسی ناک پر داغ لگا دیں گے،\qt@no{16}}%
\qt@newcmd\qurantrans@ur@mmmmmcclxxxviii{بے شک ہم ان (اہلِ مکہ) کی (اُسی طرح) آزمائش کریں گے جس طرح ہم نے (یمن کے) ان باغ والوں کو آزمایا تھا جب انہوں نے قَسم کھائی تھی کہ ہم صبح سویرے یقیناً اس کے پھل توڑ لیں گے،\qt@no{17}}%
\qt@newcmd\qurantrans@ur@mmmmmcclxxxix{اور انہوں نے (اِن شاء اللہ کہہ کر یا غریبوں کے حصہ کا) اِستثناء نہ کیا،\qt@no{18}}%
\qt@newcmd\qurantrans@ur@mmmmmccxc{پس آپ کے رب کی جانب سے ایک پھرنے والا (عذاب رات ہی رات میں) اس (باغ) پر پھر گیا اور وہ سوتے ہی رہے،\qt@no{19}}%
\qt@newcmd\qurantrans@ur@mmmmmccxci{سو وہ (لہلہاتا پھلوں سے لدا ہوا باغ) صبح کو کٹی ہوئی کھیتی کی طرح ہوگیا،\qt@no{20}}%
\qt@newcmd\qurantrans@ur@mmmmmccxcii{پھر صبح ہوتے ہی وہ ایک دوسرے کو پکارنے لگے،\qt@no{21}}%
\qt@newcmd\qurantrans@ur@mmmmmccxciii{کہ اپنی کھیتی پر سویرے سویرے چلے چلو اگر تم پھل توڑنا چاہتے ہو،\qt@no{22}}%
\qt@newcmd\qurantrans@ur@mmmmmccxciv{سو وہ لوگ چل پڑے اور وہ آپس میں چپکے چپکے کہتے جاتے تھے،\qt@no{23}}%
\qt@newcmd\qurantrans@ur@mmmmmccxcv{کہ آج اس باغ میں تمہارے پاس ہرگز کوئی محتاج نہ آنے پائے،\qt@no{24}}%
\qt@newcmd\qurantrans@ur@mmmmmccxcvi{اور وہ صبح سویرے (پھل کاٹنے اور غریبوں کو اُن کے حصہ سے محروم کرنے کے) منصوبے پر قادِر بنتے ہوئے چل پڑے،\qt@no{25}}%
\qt@newcmd\qurantrans@ur@mmmmmccxcvii{پھر جب انہوں نے اس (ویران باغ) کو دیکھا تو کہنے لگے: ہم یقیناً راستہ بھول گئے ہیں (یہ ہمارا باغ نہیں ہے)،\qt@no{26}}%
\qt@newcmd\qurantrans@ur@mmmmmccxcviii{جب غور سے دیکھا تو پکار اٹھے: نہیں نہیں،) بلکہ ہم تو محروم ہو گئے ہیں،\qt@no{27}}%
\qt@newcmd\qurantrans@ur@mmmmmccxcix{ان کے ایک عدل پسند زِیرک شخص نے کہا: کیا میں نے تم سے نہیں کہا تھا کہ تم (اللہ کا) ذِکر و تسبیح کیوں نہیں کرتے،\qt@no{28}}%
\qt@newcmd\qurantrans@ur@mmmmmccc{تب) وہ کہنے لگے کہ ہمارا رب پاک ہے، بے شک ہم ہی ظالم تھے،\qt@no{29}}%
\qt@newcmd\qurantrans@ur@mmmmmccci{سو وہ ایک دوسرے کی طرف متوجہ ہو کر باہم ملامت کرنے لگے،\qt@no{30}}%
\qt@newcmd\qurantrans@ur@mmmmmcccii{کہنے لگے: ہائے ہماری شامت! بے شک ہم ہی سرکش و باغی تھے،\qt@no{31}}%
\qt@newcmd\qurantrans@ur@mmmmmccciii{امید ہے ہمارا رب ہمیں اس کے بدلہ میں اس سے بہتر دے گا، بے شک ہم اپنے رب کی طرف رجوع کرتے ہیں،\qt@no{32}}%
\qt@newcmd\qurantrans@ur@mmmmmccciv{عذاب اسی طرح ہوتا ہے، اور واقعی آخرت کا عذاب (اِس سے) کہیں بڑھ کر ہے، کاش! وہ لوگ جانتے ہوتے،\qt@no{33}}%
\qt@newcmd\qurantrans@ur@mmmmmcccv{بے شک پرہیزگاروں کے لئے ان کے رب کے پاس نعمتوں والے باغات ہیں،\qt@no{34}}%
\qt@newcmd\qurantrans@ur@mmmmmcccvi{کیا ہم فرمانبرداروں کو مجرموں کی طرح (محروم) کر دیں گے،\qt@no{35}}%
\qt@newcmd\qurantrans@ur@mmmmmcccvii{تمہیں کیا ہو گیا ہے، کیا فیصلہ کرتے ہو،\qt@no{36}}%
\qt@newcmd\qurantrans@ur@mmmmmcccviii{کیا تمہارے پاس کوئی کتاب ہے جس میں تم (یہ) پڑھتے ہو،\qt@no{37}}%
\qt@newcmd\qurantrans@ur@mmmmmcccix{کہ تمہارے لئے اس میں وہ کچھ ہے جو تم پسند کرتے ہو،\qt@no{38}}%
\qt@newcmd\qurantrans@ur@mmmmmcccx{یا تمہارے لئے ہمارے ذِمّہ کچھ (ایسے) پختہ عہد و پیمان ہیں جو روزِ قیامت تک باقی رہیں (جن کے ذریعے ہم پابند ہوں) کہ تمہارے لئے وہی کچھ ہوگا جس کا تم (اپنے حق میں) فیصلہ کرو گے،\qt@no{39}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxi{ان سے پوچھئے کہ ان میں سے کون اس (قسم کی بے ہودہ بات) کا ذِمّہ دار ہے،\qt@no{40}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxii{یا ان کے کچھ اور شریک (بھی) ہیں؟ تو انہیں چاہئے کہ اپنے شریکوں کو لے آئیں اگر وہ سچے ہیں،\qt@no{41}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxiii{جس دن ساق (یعنی اَحوالِ قیامت کی ہولناک شدت) سے پردہ اٹھایا جائے گا اور وہ (نافرمان) لوگ سجدہ کے لئے بلائے جائیں گے تو وہ (سجدہ) نہ کر سکیں گے،\qt@no{42}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxiv{ان کی آنکھیں (ہیبت اور ندامت کے باعث) جھکی ہوئی ہوں گی (اور) ان پر ذِلت چھا رہی ہوگی، حالانکہ وہ (دنیا میں بھی) سجدہ کے لئے بلائے جاتے تھے جبکہ وہ تندرست تھے (مگر پھر بھی سجدہ کے اِنکاری تھے)،\qt@no{43}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxv{پس (اے حبیبِ مکرم!) آپ مجھے اور اس شخص کو جو اس کلام کو جھٹلاتا ہے (اِنتقام کے لئے) چھوڑ دیں، اب ہم انہیں آہستہ آہستہ (تباہی کی طرف) اس طرح لے جائیں گے کہ انہیں معلوم تک نہ ہوگا،\qt@no{44}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxvi{اور میں اُنہیں مہلت دے رہا ہوں، بے شک میری تدبیر بہت مضبوط ہے،\qt@no{45}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxvii{کیا آپ ان سے (تبلیغِ رسالت پر) کوئی معاوضہ مانگ رہے ہیں کہ وہ تاوان (کے بوجھ) سے دبے جا رہے ہیں،\qt@no{46}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxviii{کیا ان کے پاس علمِ غیب ہے کہ وہ (اس کی بنیاد پر اپنے فیصلے) لکھتے ہیں،\qt@no{47}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxix{پس آپ اپنے رب کے حکم کے انتظار میں صبر فرمائیے اور مچھلی والے (پیغمبر یونس علیہ السلام) کی طرح (دل گرفتہ) نہ ہوں، جب انہوں نے (اللہ کو) پکارا اس حال میں کہ وہ (اپنی قوم پر) غم و غصہ سے بھرے ہوئے تھے،\qt@no{48}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxx{اگر ان کے رب کی رحمت و نعمت ان کی دستگیری نہ کرتی تو وہ ضرور چٹیل میدان میں پھینک دئیے جاتے اور وہ ملامت زدہ ہوتے (مگر اللہ نے انہیں ا س سے محفوط رکھا)،\qt@no{49}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxxi{پھر ان کے رب نے انہیں برگزیدہ بنا لیا اور انہیں (اپنے قربِ خاص سے نواز کر) کامل نیکو کاروں میں (شامل) فرما دیا،\qt@no{50}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxxii{اور بے شک کافر لوگ جب قرآن سنتے ہیں تو ایسے لگتا ہے کہ آپ کو اپنی (حاسدانہ بد) نظروں سے نقصان پہنچانا چاہتے ہیں اور کہتے ہیں کہ یہ تو دیوانہ ہے،\qt@no{51}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxxiii{اور وہ (قرآن) تو سارے جہانوں کے لئے نصیحت ہے،\qt@no{52}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxxiv{\basmalahur یقیناً واقع ہونے والی گھڑی،\qt@no{1}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxxv{کیا چیز ہے یقیناً واقع ہونے والی گھڑی،\qt@no{2}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxxvi{اور آپ کو کس چیز نے خبردار کیا کہ یقیناً واقع ہونے والی (قیامت) کیسی ہے،\qt@no{3}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxxvii{ثمود اور عاد نے (جملہ موجودات کو) باہمی ٹکراؤ سے پاش پاش کر دینے والی (قیامت) کو جھٹلایا تھا،\qt@no{4}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxxviii{پس قومِ ثمود کے لوگ! تو وہ حد سے زیادہ کڑک دار چنگھاڑ والی آواز سے ہلاک کر دئیے گئے،\qt@no{5}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxxix{اور رہے قومِ عاد کے لوگ! تو وہ (بھی) ایسی تیز آندھی سے ہلاک کر دئیے گئے جو انتہائی سرد نہایت گرج دار تھی،\qt@no{6}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxxx{اللہ نے اس (آندھی) کو ان پر مسلسل سات راتیں اور آٹھ دن مسلّط رکھا، سو تُو ان لوگوں کو اس (عرصہ) میں (اس طرح) مرے پڑے دیکھتا (تو یوں لگتا) گویا وہ کھجور کے گرے ہوئے درختوں کی کھوکھلی جڑیں ہیں،\qt@no{7}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxxxi{سو تُو کیا ان میں سے کسی کو باقی دیکھتا ہے،\qt@no{8}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxxxii{اور فرعون اور جو اُس سے پہلے تھے اور (قومِ لوط کی) اُلٹی ہوئی بستیوں (کے باشندوں) نے بڑی خطائیں کی تھیں،\qt@no{9}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxxxiii{پس انہوں نے (بھی) اپنے رب کے رسول کی نافرمانی کی، سو اللہ نے انہیں نہایت سخت گرفت میں پکڑ لیا،\qt@no{10}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxxxiv{بے شک جب (طوفانِ نوح کا) پانی حد سے گزر گیا تو ہم نے تمہیں رواں کشتی میں سوار کر لیا،\qt@no{11}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxxxv{تاکہ ہم اس (واقعہ) کو تمہارے لئے (یادگار) نصیحت بنا دیں اور محفوظ رکھنے والے کان اسے یاد رکھیں،\qt@no{12}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxxxvi{پھر جب صور میں ایک مرتبہ پھونک ماری جائے گے،\qt@no{13}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxxxvii{اور زمین اور پہاڑ (اپنی جگہوں سے) اٹھا لئے جائیں گے، پھر وہ ایک ہی بار ٹکرا کر ریزہ ریزہ کر دیے جائیں گے،\qt@no{14}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxxxviii{سو اُس وقت واقع ہونے والی (قیامت) برپا ہو جائے گے،\qt@no{15}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxxxix{اور (سب) آسمانی کرّے پھٹ جائیں گے اور یہ کائنات (ایک نظام میں مربوط اور حرکت میں رکھنے والی) قوت کے ذریعے (سیاہ) شگافوں٭ پر مشتمل ہو جائے گی، ٭ واھیۃ.... الوَھی: وَھِی، یَھِی، وَھیًا کا معنیٰ ہے: شق فی الادیم والثوب ونحوھما، یقال: وَھِیَ الثوب أی انشَقّ وَ تَخَرّقَ (چمڑے، کپڑے یا اس قسم کی دوسری چیزوں کا پھٹ جانا اور ان میں شگاف ہو جانا۔ اِسی لئے کہا جاتا ہے: کپڑا پھٹ گیا اور اس میں شگاف ہوگیا).... (المفردات، لسان العرب، قاموس المحیط، المنجد وغیرہ)۔ اسے جدید سائنس نے بلیک ہولز سے تعبیر کیا ہے۔\qt@no{16}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxl{اور فرشتے اس کے کناروں پر کھڑے ہوں گے، اور آپ کے رب کے عرش کو اس دن ان کے اوپر آٹھ (فرشتے یا فرشتوں کے طبقات) اٹھائے ہوئے ہوں گے،\qt@no{17}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxli{اُس دن تم (حساب کے لئے) پیش کیے جاؤ گے، تمہاری کوئی پوشیدہ بات چھپی نہ رہے گی،\qt@no{18}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxlii{سو وہ شخص جس کا نامۂ اَعمال اس کے دائیں ہاتھ میں دیا جائے گا تو وہ (خوشی سے) کہے گا: آؤ میرا نامۂ اَعمال پڑھ لو،\qt@no{19}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxliii{میں تو یقین رکھتا تھا کہ میں اپنے حساب کو (آسان) پانے والا ہوں،\qt@no{20}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxliv{سو وہ پسندیدہ زندگی بسر کرے گا،\qt@no{21}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxlv{بلند و بالا جنت میں،\qt@no{22}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxlvi{جس کے خوشے (پھلوں کی کثرت کے باعث) جھکے ہوئے ہوں گے،\qt@no{23}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxlvii{اُن سے کہا جائے گا:) خوب لطف اندوزی کے ساتھ کھاؤ اور پیو اُن (اَعمال) کے بدلے جو تم گزشتہ (زندگی کے) اَیام میں آگے بھیج چکے تھے،\qt@no{24}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxlviii{اور وہ شخص جس کا نامۂ اَعمال اس کے بائیں ہاتھ میں دیا جائے گا تو وہ کہے گا: ہائے کاش! مجھے میرا نامۂ اَعمال نہ دیا گیا ہوتا،\qt@no{25}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxlix{اور میں نہ جانتا کہ میرا حساب کیا ہے،\qt@no{26}}%
\qt@newcmd\qurantrans@ur@mmmmmcccl{ہائے کاش! وُہی (موت) کام تمام کر چکی ہوتی،\qt@no{27}}%
\qt@newcmd\qurantrans@ur@mmmmmcccli{آج) میرا مال مجھ سے (عذاب کو) کچھ بھی دور نہ کر سکا،\qt@no{28}}%
\qt@newcmd\qurantrans@ur@mmmmmccclii{مجھ سے میری قوت و سلطنت (بھی) جاتی رہی،\qt@no{29}}%
\qt@newcmd\qurantrans@ur@mmmmmcccliii{حکم ہوگا:) اسے پکڑ لو اور اسے طوق پہنا دو،\qt@no{30}}%
\qt@newcmd\qurantrans@ur@mmmmmcccliv{پھر اسے دوزخ میں جھونک دو،\qt@no{31}}%
\qt@newcmd\qurantrans@ur@mmmmmccclv{پھر ایک زنجیر میں جس کی لمبائی ستر گز ہے اسے جکڑ دو،\qt@no{32}}%
\qt@newcmd\qurantrans@ur@mmmmmccclvi{بے شک یہ بڑی عظمت والے اللہ پر ایمان نہیں رکھتا تھا،\qt@no{33}}%
\qt@newcmd\qurantrans@ur@mmmmmccclvii{اور نہ محتاج کو کھانا کھلانے پر رغبت دلاتا تھا،\qt@no{34}}%
\qt@newcmd\qurantrans@ur@mmmmmccclviii{سو آج کے دن نہ اس کا کوئی گرم جوش دوست ہے،\qt@no{35}}%
\qt@newcmd\qurantrans@ur@mmmmmccclix{اور نہ پیپ کے سوا (اُس کے لئے) کوئی کھانا ہے،\qt@no{36}}%
\qt@newcmd\qurantrans@ur@mmmmmccclx{جسے گنہگاروں کے سوا کوئی نہ کھائے گا،\qt@no{37}}%
\qt@newcmd\qurantrans@ur@mmmmmccclxi{سو میں قَسم کھاتا ہوں ان چیزوں کی جنہیں تم دیکھتے ہو،\qt@no{38}}%
\qt@newcmd\qurantrans@ur@mmmmmccclxii{اور ان چیزوں کی (بھی) جنہیں تم نہیں دیکھتے،\qt@no{39}}%
\qt@newcmd\qurantrans@ur@mmmmmccclxiii{بے شک یہ (قرآن) بزرگی و عظمت والے رسول (صلی اللہ علیہ وآلہ وسلم) کا (منزّل من اللہ) فرمان ہے، (جسے وہ رسالۃً اور نیابۃً بیان فرماتے ہیں)،\qt@no{40}}%
\qt@newcmd\qurantrans@ur@mmmmmccclxiv{اور یہ کسی شاعر کا کلام نہیں (کہ اَدبی مہارت سے خود لکھا گیا ہو)، تم بہت ہی کم یقین رکھتے ہو،\qt@no{41}}%
\qt@newcmd\qurantrans@ur@mmmmmccclxv{اور نہ (یہ) کسی کاہن کا کلام ہے (کہ فنی اَندازوں سے وضع کیا گیا ہو)، تم بہت ہی کم نصیحت حاصل کرتے ہو،\qt@no{42}}%
\qt@newcmd\qurantrans@ur@mmmmmccclxvi{یہ) تمام جہانوں کے رب کی طرف سے نازل شدہ ہے،\qt@no{43}}%
\qt@newcmd\qurantrans@ur@mmmmmccclxvii{اور اگر وہ ہم پر کوئی (ایک) بات بھی گھڑ کر کہہ دیتے،\qt@no{44}}%
\qt@newcmd\qurantrans@ur@mmmmmccclxviii{تو یقیناً ہم اُن کو پوری قوت و قدرت کے ساتھ پکڑ لیتے،\qt@no{45}}%
\qt@newcmd\qurantrans@ur@mmmmmccclxix{پھر ہم ضرور اُن کی شہ رگ کاٹ دیتے،\qt@no{46}}%
\qt@newcmd\qurantrans@ur@mmmmmccclxx{پھر تم میں سے کوئی بھی (ہمیں) اِس سے روکنے والا نہ ہوتا،\qt@no{47}}%
\qt@newcmd\qurantrans@ur@mmmmmccclxxi{اور پس بلاشبہ یہ (قرآن) پرہیزگاروں کے لئے نصیحت ہے،\qt@no{48}}%
\qt@newcmd\qurantrans@ur@mmmmmccclxxii{اور یقیناً ہم جانتے ہیں کہ تم میں سے بعض لوگ (اس کھلی سچائی کو) جھٹلانے والے ہیں،\qt@no{49}}%
\qt@newcmd\qurantrans@ur@mmmmmccclxxiii{اور واقعی یہ کافروں کے لئے (موجبِ) حسرت ہے،\qt@no{50}}%
\qt@newcmd\qurantrans@ur@mmmmmccclxxiv{اور بے شک یہ حق الیقین ہے،\qt@no{51}}%
\qt@newcmd\qurantrans@ur@mmmmmccclxxv{سو (اے حبیبِ مکرّم!) آپ اپنے عظمت والے رب کے نام کی تسبیح کرتے رہیں،\qt@no{52}}%
\qt@newcmd\qurantrans@ur@mmmmmccclxxvi{\basmalahur ایک سائل نے ایسا عذاب طلب کیا جو واقع ہونے والا ہے،\qt@no{1}}%
\qt@newcmd\qurantrans@ur@mmmmmccclxxvii{کافروں کے لئے جسے کوئی دفع کرنے والا نہیں،\qt@no{2}}%
\qt@newcmd\qurantrans@ur@mmmmmccclxxviii{وہ) اللہ کی جانب سے (واقع ہوگا) جو آسمانی زینوں (اور بلند مراتب درجات) کا مالک ہے،\qt@no{3}}%
\qt@newcmd\qurantrans@ur@mmmmmccclxxix{اس (کے عرش) کی طرف فرشتے اور روح الامین عروج کرتے ہیں ایک دن میں، جس کا اندازہ (دنیوی حساب سے) پچاس ہزار برس کا ہے٭، ٭ فِی یَومٍ اگر وَاقِعٍ کا صلہ ہو تو معنی ہوگا کہ جس دن (یومِ قیامت) کو عذاب واقع ہوگا اس کا دورانیہ ٥٠ ہزار برس کے قریب ہے۔ اور اگر یہ تَعرُجُ کا صلہ ہو تو معنی ہوگا کہ ملائکہ اور اَرواحِ مومنین جو عرشِ اِلٰہی کی طرف عروج کرتی ہیں ان کے عروج کی رفتار ٥٠ ہزار برس یومیہ ہے، وہ پھر بھی کتنی مدت میں منزلِ مقصود تک پہنچتے ہیں۔ واﷲ أعلم بالصواب۔ (یہاں سے نوری سال (لا‌ّّّ‎ئٹ ائیر) کے تصور کا اِستنباط ہوتا ہے۔)\qt@no{4}}%
\qt@newcmd\qurantrans@ur@mmmmmccclxxx{سو (اے حبیب!) آپ (کافروں کی باتوں پر) ہر شکوہ سے پاک صبر فرمائیں،\qt@no{5}}%
\qt@newcmd\qurantrans@ur@mmmmmccclxxxi{بے شک وہ (تو) اس (دن) کو دور سمجھ رہے ہیں،\qt@no{6}}%
\qt@newcmd\qurantrans@ur@mmmmmccclxxxii{اور ہم اسے قریب ہی دیکھتے ہیں،\qt@no{7}}%
\qt@newcmd\qurantrans@ur@mmmmmccclxxxiii{جس دن آسمان پگھلے ہوئے تانبے کی طرح ہو جائے گا،\qt@no{8}}%
\qt@newcmd\qurantrans@ur@mmmmmccclxxxiv{اور پہاڑ (دُھنکی ہوئی) رنگین اُون کی طرح ہو جائیں گے،\qt@no{9}}%
\qt@newcmd\qurantrans@ur@mmmmmccclxxxv{اور کوئی دوست کسی دوست کا پرساں نہ ہوگا،\qt@no{10}}%
\qt@newcmd\qurantrans@ur@mmmmmccclxxxvi{حالانکہ) وہ (ایک دوسرے کو) دکھائے جا رہے ہوں گے، مجرم آرزو کرے گا کہ کاش! اس دن کے عذاب (سے رہائی) کے بدلہ میں اپنے بیٹے دے دے،\qt@no{11}}%
\qt@newcmd\qurantrans@ur@mmmmmccclxxxvii{اور اپنی بیوی اور اپنا بھائی (دے ڈالے)،\qt@no{12}}%
\qt@newcmd\qurantrans@ur@mmmmmccclxxxviii{اور اپنا (تمام) خاندان جو اُسے پناہ دیتا تھا،\qt@no{13}}%
\qt@newcmd\qurantrans@ur@mmmmmccclxxxix{اور جتنے لوگ بھی زمین میں ہیں، سب کے سب (اپنی ذات کے لئے بدلہ کر دے)، پھر یہ (فدیہ) اُسے (اللہ کے عذاب سے) بچا لے،\qt@no{14}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxc{ایسا ہرگز نہ ہوگا، بے شک وہ شعلہ زن آگ ہے،\qt@no{15}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxci{سر اور تمام اَعضائے بدن کی کھال اتار دینے والی ہے،\qt@no{16}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxcii{وہ اُسے بلا رہی ہے جس نے (حق سے) پیٹھ پھیری اور رُوگردانی کی،\qt@no{17}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxciii{اور (اس نے) مال جمع کیا پھر (اسے تقسیم سے) روکے رکھا،\qt@no{18}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxciv{بے شک انسان بے صبر اور لالچی پیدا ہوا ہے،\qt@no{19}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxcv{جب اسے مصیبت (یا مالی نقصان) پہنچے تو گھبرا جاتا ہے،\qt@no{20}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxcvi{اور جب اسے بھلائی (یا مالی فراخی) حاصل ہو تو بخل کرتا ہے،\qt@no{21}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxcvii{مگر وہ نماز ادا کرنے والے،\qt@no{22}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxcviii{جو اپنی نماز پر ہمیشگی قائم رکھنے والے ہیں،\qt@no{23}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxcix{اور وہ (ایثار کیش) لوگ جن کے اَموال میں حصہ مقرر ہے،\qt@no{24}}%
\qt@newcmd\qurantrans@ur@mmmmmcd{مانگنے والے اور نہ مانگنے والے محتاج کا،\qt@no{25}}%
\qt@newcmd\qurantrans@ur@mmmmmcdi{اور وہ لوگ جو روزِ جزا کی تصدیق کرتے ہیں،\qt@no{26}}%
\qt@newcmd\qurantrans@ur@mmmmmcdii{اور وہ لوگ جو اپنے رب کے عذاب سے ڈرنے والے ہیں،\qt@no{27}}%
\qt@newcmd\qurantrans@ur@mmmmmcdiii{بے شک ان کے رب کا عذاب ایسا نہیں جس سے بے خوف ہوا جائے،\qt@no{28}}%
\qt@newcmd\qurantrans@ur@mmmmmcdiv{اور وہ لوگ جو اپنی شرم گاہوں کی حفاظت کرتے ہیں،\qt@no{29}}%
\qt@newcmd\qurantrans@ur@mmmmmcdv{سوائے اپنی منکوحہ بیویوں کے یا اپنی مملوکہ کنیزوں کے، سو (اِس میں) اُن پر کوئی ملامت نہیں،\qt@no{30}}%
\qt@newcmd\qurantrans@ur@mmmmmcdvi{سو جو ان کے علاوہ طلب کرے تو وہی لوگ حد سے گزرنے والے ہیں،\qt@no{31}}%
\qt@newcmd\qurantrans@ur@mmmmmcdvii{اور وہ لوگ جو اپنی امانتوں اور اپنے وعدوں کی نگہداشت کرتے ہیں،\qt@no{32}}%
\qt@newcmd\qurantrans@ur@mmmmmcdviii{اور وہ لوگ جو اپنی گواہیوں پر قائم رہتے ہیں،\qt@no{33}}%
\qt@newcmd\qurantrans@ur@mmmmmcdix{اور وہ لوگ جو اپنی نمازوں کی حفاظت کرتے ہیں،\qt@no{34}}%
\qt@newcmd\qurantrans@ur@mmmmmcdx{یہی لوگ ہیں جو جنتوں میں معزّز و مکرّم ہوں گے،\qt@no{35}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxi{تو کافروں کو کیا ہو گیا ہے کہ آپ کی طرف دوڑے چلے آرہے ہیں،\qt@no{36}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxii{دائیں جانب سے (بھی) اور بائیں جانب سے (بھی) گروہ در گروہ،\qt@no{37}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxiii{کیا ان میں سے ہر شخص یہ توقع رکھتا ہے کہ وہ (بغیر ایمان و عمل کے) نعمتوں والی جنت میں داخل کر دیا جائے گا؟،\qt@no{38}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxiv{ہرگز نہیں، بے شک ہم نے انہیں اس چیز سے پیدا کیا ہے جسے وہ (بھی) جانتے ہیں،\qt@no{39}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxv{سو میں مشارق اور مغارب کے رب کی قَسم کھاتا ہوں کہ بے شک ہم پوری قدرت رکھتے ہیں،\qt@no{40}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxvi{اس پر کہ ہم بدل کر ان سے بہتر لوگ لے آئیں، اور ہم ہرگز عاجز نہیں ہیں،\qt@no{41}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxvii{سو آپ انہیں چھوڑ دیجئے کہ وہ اپنی بے ہودہ باتوں اور کھیل تماشے میں پڑے رہیں یہاں تک کہ اپنے اس دن سے آملیں جس کا ان سے وعدہ کیا جا رہا ہے،\qt@no{42}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxviii{جس دن وہ قبروں سے دوڑتے ہوئے یوں نکلیں گے گویا وہ بتوں کے اَستھانوں کی طرف دوڑے جا رہے ہیں،\qt@no{43}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxix{ان کا) حال یہ ہو گا کہ ان کی آنکھیں (شرم اور خوف سے) جھک رہی ہوں گی، ذِلت ان پر چھا رہی ہوگی، یہی ہے وہ دن جس کا ان سے وعدہ کیا جاتا تھا،\qt@no{44}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxx{\basmalahur بے شک ہم نے نوح (علیہ السلام) کو ان کی قوم کی طرف بھیجا کہ آپ اپنی قوم کو ڈرائیں قبل اس کے کہ اُنہیں دردناک عذاب آپہنچے،\qt@no{1}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxxi{اُنہوں نے کہا: اے میری قوم! بے شک میں تمہیں واضح ڈر سنانے والا ہوں،\qt@no{2}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxxii{کہ تم اﷲ کی عبادت کرو اور اُس سے ڈرو اور میری اِطاعت کرو،\qt@no{3}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxxiii{وہ تمہارے گناہ بخش دے گا اور تمہیں مقررہ مدت تک مہلت عطا کرے گا، بے شک اﷲ کی (مقرر کردہ) مدت جب آجائے تو مہلت نہیں دی جاتی، کاش! تم جانتے ہوتے،\qt@no{4}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxxiv{نوح (علیہ السلام) نے عرض کیا: اے میرے رب! بے شک میں اپنی قوم کو رات دن بلاتا رہا،\qt@no{5}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxxv{لیکن میری دعوت نے ان کے لئے سوائے بھاگنے کے کچھ زیادہ نہیں کیا،\qt@no{6}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxxvi{اور میں نے جب (بھی) اُنہیں (ایمان کی طرف) بلایا تاکہ تو انہیں بخش دے تو انہوں نے اپنی انگلیاں اپنے کانوں میں دے لیں اور اپنے اوپر اپنے کپڑے لپیٹ لئے اور (کفر پر) ہٹ دھرمی کی اور شدید تکبر کیا،\qt@no{7}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxxvii{پھر میں نے انہیں بلند آواز سے دعوت دی،\qt@no{8}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxxviii{پھر میں نے انہیں اِعلانیہ (بھی) سمجھایا اور انہیں پوشیدہ رازدارانہ طور پر (بھی) سمجھایا،\qt@no{9}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxxix{پھر میں نے کہا کہ تم اپنے رب سے بخشش طلب کرو، بے شک وہ بڑا بخشنے والا ہے،\qt@no{10}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxxx{وہ تم پر بڑی زوردار بارش بھیجے گا،\qt@no{11}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxxxi{اور تمہاری مدد اَموال اور اولاد کے ذریعے فرمائے گا اور تمہارے لئے باغات اُگائے گا اور تمہارے لئے نہریں جاری کر دے گا،\qt@no{12}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxxxii{تمہیں کیا ہو گیا ہے کہ تم اﷲ کی عظمت کا اِعتقاد اور معرفت نہیں رکھتے،\qt@no{13}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxxxiii{حالانکہ اس نے تمہیں طرح طرح کی حالتوں سے پیدا فرمایا،\qt@no{14}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxxxiv{کیا تم نے نہیں دیکھا کہ اﷲ نے کس طرح سات (یا متعدّد) آسمانی کرّے باہمی مطابقت کے ساتھ (طبق در طبق) پیدا فرمائے،\qt@no{15}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxxxv{اور اس نے ان میں چاند کو روشن کیا اور اس نے سورج کو چراغ (یعنی روشنی اور حرارت کا منبع) بنایا،\qt@no{16}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxxxvi{اور اﷲ نے تمہیں زمین سے سبزے کی مانند اُگایا٭، ٭ اَرضی زندگی میں پودوں کی طرح حیاتِ اِنسانی کی اِبتداء اور نشو و نما بھی کیمیائی اور حیاتیاتی مراحل سے گزرتے ہوئے تدریجاً ہوئی، اِسی لئے اِسے اَنبَتَکُم مِّنَ الاَرضِ نَبَاتًا کے بلیغ اِستعارہ کے ذریعے بیان کیا گیا ہے۔\qt@no{17}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxxxvii{پھر تم کو اسی (زمین) میں لوٹا دے گا اور (پھر) تم کو (اسی سے دوبارہ) باہر نکالے گا،\qt@no{18}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxxxviii{اور اﷲ نے تمہارے لئے زمین کو فرش بنا دیا،\qt@no{19}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxxxix{تاکہ تم اس کے کشادہ راستوں میں چلو پھرو،\qt@no{20}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxl{نوح (علیہ السلام)نے عرض کیا: اے میرے رب! انہوں نے میری نافرمانی کی اور اُس (سرکش رؤساء کے طبقے) کی پیروی کرتے رہے جس کے مال و دولت اور اولاد نے انہیں سوائے نقصان کے اور کچھ نہیں بڑھایا،\qt@no{21}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxli{اور (عوام کو گمراہی میں رکھنے کے لئے) وہ بڑی بڑی چالیں چلتے رہے،\qt@no{22}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxlii{اور کہتے رہے کہ تم اپنے معبودوں کو مت چھوڑنا اور وَدّ اور سُوَاع اور یَغُوث اور یَعُوق اور نَسر (نامی بتوں) کو (بھی) ہرگز نہ چھوڑنا،\qt@no{23}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxliii{اور واقعی انہوں نے بہت لوگوں کو گمراہ کیا، سو (اے میرے رب!) تو (بھی ان) ظالموں کو سوائے گمراہی کے (کسی اور چیز میں) نہ بڑھا،\qt@no{24}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxliv{بالآخر) وہ اپنے گناہوں کے سبب غرق کر دئیے گئے، پھر آگ میں ڈال دئیے گئے، سو وہ اپنے لئے اﷲ کے مقابل کسی کو مددگار نہ پا سکے،\qt@no{25}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxlv{اور نوح (علیہ السلام) نے عرض کیا: اے میرے رب! زمین پر کافروں میں سے کوئی بسنے والا باقی نہ چھوڑ،\qt@no{26}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxlvi{بے شک اگر تو اُنہیں (زندہ) چھوڑے گا تو وہ تیرے بندوں کو گمراہ کرتے رہیں گے، اور وہ بدکار (اور) سخت کافر اولاد کے سوا کسی کو جنم نہیں دیں گے،\qt@no{27}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxlvii{اے میرے رب! مجھے بخش دے اور میرے والدین کو اور ہر اس شخص کو جو مومن ہو کر میرے گھر میں داخل ہوا اور (جملہ) مومن مردوں کو اور مومن عورتوں کو، اور ظالموں کے لئے سوائے ہلاکت کے کچھ (بھی) زیادہ نہ فرما،\qt@no{28}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxlviii{\basmalahur آپ فرما دیں: میری طرف وحی کی گئی ہے کہ جنات کی ایک جماعت نے (میری تلاوت کو) غور سے سنا، تو (جا کر اپنی قوم سے) کہنے لگے: بیشک ہم نے ایک عجیب قرآن سنا ہے،\qt@no{1}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxlix{جو ہدایت کی راہ دکھاتا ہے، سو ہم اس پر ایمان لے آئے ہیں، اور اپنے رب کے ساتھ کسی کو ہرگز شریک نہیں ٹھہرائیں گے،\qt@no{2}}%
\qt@newcmd\qurantrans@ur@mmmmmcdl{اور یہ کہ ہمارے رب کی شان بہت بلند ہے، اس نے نہ کوئی بیوی بنا رکھی ہے اور نہ ہی کوئی اولاد،\qt@no{3}}%
\qt@newcmd\qurantrans@ur@mmmmmcdli{اور یہ کہ ہم میں سے کوئی اَحمق ہی اللہ کے بارے میں حق سے دور حد سے گزری ہوئی باتیں کہا کرتا تھا،\qt@no{4}}%
\qt@newcmd\qurantrans@ur@mmmmmcdlii{اور یہ کہ ہم گمان کرتے تھے کہ انسان اور جنّ اللہ کے بارے میں ہر گز جھوٹ نہیں بولیں گے،\qt@no{5}}%
\qt@newcmd\qurantrans@ur@mmmmmcdliii{اور یہ کہ انسانوں میں سے کچھ لوگ جنات میں سے بعض اَفراد کی پناہ لیتے تھے، سو اُن لوگوں نے اُن جنات کی سرکشی اور بڑھا دی،\qt@no{6}}%
\qt@newcmd\qurantrans@ur@mmmmmcdliv{اور (اے گروہِ جنات!) وہ انسان بھی ایسا ہی گمان کرنے لگے جیسا گمان تم نے کیا کہ اللہ (مرنے کے بعد) ہرگز کسی کو نہیں اٹھائے گا،\qt@no{7}}%
\qt@newcmd\qurantrans@ur@mmmmmcdlv{اور یہ کہ ہم نے آسمانوں کو چھوا، اور انہیں سخت پہرہ داروں اور (اَنگاروں کی طرح) جلنے اور چمکنے والے ستاروں سے بھرا ہوا پایا،\qt@no{8}}%
\qt@newcmd\qurantrans@ur@mmmmmcdlvi{اور یہ کہ ہم (پہلے آسمانی خبریں سننے کے لئے) اس کے بعض مقامات میں بیٹھا کرتے تھے، مگر اب کوئی سننا چاہے تو وہ اپنی تاک میں آگ کا شعلہ (منتظر) پائے گا،\qt@no{9}}%
\qt@newcmd\qurantrans@ur@mmmmmcdlvii{اور یہ کہ ہم نہیں جانتے کہ (ہماری بندش سے) ان لوگوں کے حق میں جو زمین میں ہیں کسی برائی کا اِرادہ کیا گیا ہے یا ان کے رب نے ان کے ساتھ بھلائی کا اِرادہ فرمایا ہے،\qt@no{10}}%
\qt@newcmd\qurantrans@ur@mmmmmcdlviii{اور یہ کہ ہم میں سے کچھ نیک لوگ ہیں اور ہم (ہی) میں سے کچھ اس کے سوا (برے) بھی ہیں، ہم مختلف طریقوں پر (چل رہے) تھے،\qt@no{11}}%
\qt@newcmd\qurantrans@ur@mmmmmcdlix{اور ہم نے یقین کر لیا ہے کہ ہم اللہ کو ہرگز زمین میں (رہ کر) عاجز نہیں کر سکتے اور نہ ہی (زمین سے) بھاگ کر اسے عاجز کر سکتے ہیں،\qt@no{12}}%
\qt@newcmd\qurantrans@ur@mmmmmcdlx{اور یہ کہ جب ہم نے (کتابِ) ہدایت کو سنا تو ہم اس پر ایمان لے آئے، پھر جو شخص اپنے رب پر ایمان لاتا ہے تو وہ نہ نقصان ہی سے خوف زدہ ہوتا ہے اور نہ ظلم سے،\qt@no{13}}%
\qt@newcmd\qurantrans@ur@mmmmmcdlxi{اور یہ کہ ہم میں سے (بعض) فرماں بردار بھی ہیں اور ہم میں سے (بعض) ظالم بھی ہیں، پھر جو کوئی فرمانبردار ہوگیا تو ایسے ہی لوگوں نے بھلائی طلب کی،\qt@no{14}}%
\qt@newcmd\qurantrans@ur@mmmmmcdlxii{اور جو ظالم ہیں تو وہ دوزخ کا ایندھن ہوں گے،\qt@no{15}}%
\qt@newcmd\qurantrans@ur@mmmmmcdlxiii{اور یہ (وحی بھی میرے پاس آئی ہے) کہ اگر وہ طریقت (راہِ حق، طریقِ ذِکرِ اِلٰہی) پر قائم رہتے تو ہم انہیں بہت سے پانی کے ساتھ سیراب کرتے،\qt@no{16}}%
\qt@newcmd\qurantrans@ur@mmmmmcdlxiv{تاکہ ہم اس (نعمت) میں ان کی آزمائش کریں، اور جو شخص اپنے رب کے ذِکر سے منہ پھیر لے گا تو وہ اسے نہایت سخت عذاب میں داخل کر دے گا،\qt@no{17}}%
\qt@newcmd\qurantrans@ur@mmmmmcdlxv{اور یہ کہ سجدہ گاہیں اللہ کے لئے (مخصوص) ہیں، سو اللہ کے ساتھ کسی اور کی پرستش مت کیا کرو،\qt@no{18}}%
\qt@newcmd\qurantrans@ur@mmmmmcdlxvi{اور یہ کہ جب اللہ کے بندے (محمد صلی اللہ علیہ وآلہ وسلم) اس کی عبادت کرنے کھڑے ہوئے تو وہ ان پر ہجوم در ہجوم جمع ہو گئے (تاکہ ان کی قرات سن سکیں)،\qt@no{19}}%
\qt@newcmd\qurantrans@ur@mmmmmcdlxvii{آپ فرما دیں کہ میں تو صرف اپنے رب کی عبادت کرتا ہوں اور اس کے ساتھ کسی کو شریک نہیں بناتا،\qt@no{20}}%
\qt@newcmd\qurantrans@ur@mmmmmcdlxviii{آپ فرما دیں کہ میں تمہارے لئے نہ تو نقصان (یعنی کفر) کا مالک ہوں اور نہ بھلائی (یعنی ایمان) کا (گویا حقیقی مالک اللہ ہے میں تو ذریعہ اور وسیلہ ہوں)،\qt@no{21}}%
\qt@newcmd\qurantrans@ur@mmmmmcdlxix{آپ فرما دیں کہ نہ مجھے ہرگز کوئی اللہ کے (اَمر کے خلاف) عذاب سے پناہ دے سکتا ہے اور نہ ہی میں قطعاً اُس کے سوا کوئی جائے پناہ پاتا ہوں،\qt@no{22}}%
\qt@newcmd\qurantrans@ur@mmmmmcdlxx{مگر اللہ کی جانب سے اَحکامات اور اُس کے پیغامات کا پہنچانا (میری ذِمّہ داری ہے)، اور جو کوئی اللہ اور اُس کے رسول (صلی اللہ علیہ وآلہ وسلم) کی نافرمانی کرے تو بیشک اُس کے لئے دوزخ کی آگ ہے جس میں وہ ہمیشہ رہیں گے،\qt@no{23}}%
\qt@newcmd\qurantrans@ur@mmmmmcdlxxi{یہاں تک کہ جب یہ لوگ وہ (عذاب) دیکھ لیں گے جس کا ان سے وعدہ کیا جا رہا ہے تو (اُس وقت) انہیں معلوم ہوگا کہ کون مددگار کے اعتبار سے کمزور تر اور عدد کے اِعتبار سے کم تر ہے،\qt@no{24}}%
\qt@newcmd\qurantrans@ur@mmmmmcdlxxii{آپ فرما دیں: میں نہیں جانتا کہ جس (روزِ قیامت) کا تم سے وعدہ کیا جا رہا ہے وہ قریب ہے یا اس کے لئے میرے رب نے طویل مدت مقرر فرما دی ہے،\qt@no{25}}%
\qt@newcmd\qurantrans@ur@mmmmmcdlxxiii{وہ) غیب کا جاننے والا ہے، پس وہ اپنے غیب پر کسی (عام شخص) کو مطلع نہیں فرماتا،\qt@no{26}}%
\qt@newcmd\qurantrans@ur@mmmmmcdlxxiv{سوائے اپنے پسندیدہ رسولوں کے (اُنہی کو مطلع علی الغیب کرتا ہے کیونکہ یہ خاصۂ نبوت اور معجزۂ رسالت ہے)، تو بے شک وہ اس (رسول صلی اللہ علیہ وآلہ وسلم) کے آگے اور پیچھے (علمِ غیب کی حفاظت کے لئے) نگہبان مقرر فرما دیتا ہے،\qt@no{27}}%
\qt@newcmd\qurantrans@ur@mmmmmcdlxxv{تاکہ اللہ (اس بات کو) ظاہر فرما دے کہ بے شک ان (رسولوں) نے اپنے رب کے پیغامات پہنچا دئیے، اور (اَحکاماتِ اِلٰہیہ اور علومِ غیبیہ میں سے) جو کچھ ان کے پاس ہے اللہ نے (پہلے ہی سے) اُس کا اِحاطہ فرما رکھا ہے، اور اُس نے ہر چیز کی گنتی شمار کر رکھی ہے،\qt@no{28}}%
\qt@newcmd\qurantrans@ur@mmmmmcdlxxvi{\basmalahur اے کملی کی جھرمٹ والے (حبیب!)،\qt@no{1}}%
\qt@newcmd\qurantrans@ur@mmmmmcdlxxvii{آپ رات کو (نماز میں) قیام فرمایا کریں مگر تھوڑی دیر (کے لئے)،\qt@no{2}}%
\qt@newcmd\qurantrans@ur@mmmmmcdlxxviii{آدھی رات یا اِس سے تھوڑا کم کر دیں،\qt@no{3}}%
\qt@newcmd\qurantrans@ur@mmmmmcdlxxix{یا اس پر کچھ زیادہ کر دیں اور قرآن خوب ٹھہر ٹھہر کر پڑھا کریں،\qt@no{4}}%
\qt@newcmd\qurantrans@ur@mmmmmcdlxxx{ہم عنقریب آپ پر ایک بھاری فرمان نازل کریں گے،\qt@no{5}}%
\qt@newcmd\qurantrans@ur@mmmmmcdlxxxi{بے شک رات کا اُٹھنا (نفس کو) سخت پامال کرتا ہے اور (دِل و دِماغ کی یک سُوئی کے ساتھ) زبان سے سیدھی بات نکالتا ہے،\qt@no{6}}%
\qt@newcmd\qurantrans@ur@mmmmmcdlxxxii{بے شک آپ کے لئے دن میں بہت سی مصروفیات ہوتی ہیں،\qt@no{7}}%
\qt@newcmd\qurantrans@ur@mmmmmcdlxxxiii{اور آپ اپنے رب کے نام کا ذِکر کرتے رہیں اور (اپنے قلب و باطن میں) ہر ایک سے ٹوٹ کر اُسی کے ہو رہیں،\qt@no{8}}%
\qt@newcmd\qurantrans@ur@mmmmmcdlxxxiv{وہ مشرق و مغرب کا مالک ہے، اُس کے سوا کوئی معبود نہیں، سو اُسی کو (اپنا) کارساز بنا لیں،\qt@no{9}}%
\qt@newcmd\qurantrans@ur@mmmmmcdlxxxv{اور آپ ان (باتوں) پر صبر کریں جو کچھ وہ (کفار) کہتے ہیں، اور نہایت خوبصورتی کے ساتھ ان سے کنارہ کش ہو جائیں،\qt@no{10}}%
\qt@newcmd\qurantrans@ur@mmmmmcdlxxxvi{اور آپ مجھے اور جھٹلانے والے سرمایہ داروں کو (اِنتقام لینے کے لئے) چھوڑ دیں اور انہیں تھوڑی سی مہلت دے دیں (تاکہ اُن کے اَعمالِ بد اپنی اِنتہاء کو پہنچ جائیں)،\qt@no{11}}%
\qt@newcmd\qurantrans@ur@mmmmmcdlxxxvii{بیشک ہمارے پاس بھاری بیڑیاں اور (دوزخ کی) بھڑکتی ہوئی آگ ہے،\qt@no{12}}%
\qt@newcmd\qurantrans@ur@mmmmmcdlxxxviii{اور حلق میں اٹک جانے والا کھانا اور نہایت دردناک عذاب ہے،\qt@no{13}}%
\qt@newcmd\qurantrans@ur@mmmmmcdlxxxix{جس دن زمین اورپہاڑ زور سے لرزنے لگیں گے اور پہاڑ بکھرتی ریت کے ٹیلے ہو جائیں گے،\qt@no{14}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxc{بے شک ہم نے تمہاری طرف ایک رسول (صلی اللہ علیہ وآلہ وسلم) بھیجا ہے جو تم پر (اَحوال کا مشاہدہ فرما کر) گواہی دینے والا ہے، جیسا کہ ہم نے فرعون کی طرف ایک رسول کو بھیجا تھا،\qt@no{15}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxci{پس فرعون نے اس رسول (علیہ السلام) کی نافرمانی کی، سو ہم نے اس کو ہلاکت انگیز گرفت میں پکڑ لیا،\qt@no{16}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxcii{اگر تم کفر کرتے رہو تو اُس دن (کے عذاب) سے کیسے بچو گے جو بچوں کو بوڑھا کردے گا،\qt@no{17}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxciii{جس دن کی) شدت کے باعث آسمان پھٹ جائے گا، اُس کا وعدہ پورا ہو کر رہے گا،\qt@no{18}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxciv{بے شک یہ (قرآن) نصیحت ہے، پس جو شخص چاہے اپنے رب تک پہنچنے کا راستہ اِختیار کر لے،\qt@no{19}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxcv{بے شک آپ کا رب جانتا ہے کہ آپ (کبھی) دو تہائی شب کے قریب اور (کبھی) نصف شب اور (کبھی) ایک تہائی شب (نماز میں) قیام کرتے ہیں، اور اُن لوگوں کی ایک جماعت (بھی) جو آپ کے ساتھ ہیں (قیام میں شریک ہوتی ہے)، اور اﷲ ہی رات اور دن (کے گھٹنے اور بڑھنے) کا صحیح اندازہ رکھتا ہے، وہ جانتا ہے کہ تم ہرگز اُس کے اِحاطہ کی طاقت نہیں رکھتے، سو اُس نے تم پر (مشقت میں تخفیف کر کے) معافی دے دی، پس جتنا آسانی سے ہو سکے قرآن پڑھ لیا کرو، وہ جانتا ہے کہ تم میں سے (بعض لوگ) بیمار ہوں گے اور (بعض) دوسرے لوگ زمین میں سفر کریں گے تاکہ اﷲ کا فضل تلاش کریں اور (بعض) دیگر اﷲ کی راہ میں جنگ کریں گے، سو جتنا آسانی سے ہو سکے اُتنا (ہی) پڑھ لیا کرو، اور نماز قائم رکھو اور زکوٰۃ دیتے رہو اور اﷲ کو قرضِ حسن دیا کرو، اور جو بھلائی تم اپنے لئے آگے بھیجو گے اُسے اﷲ کے حضور بہتر اور اَجر میں بزرگ تر پا لوگے، اور اﷲ سے بخشش طلب کرتے رہو، اﷲ بہت بخشنے والا بے حد رحم فرمانے والا ہے،\qt@no{20}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxcvi{\basmalahur اے چادر اوڑھنے والے (حبیب!)،\qt@no{1}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxcvii{اُٹھیں اور (لوگوں کو اللہ کا) ڈر سنائیں،\qt@no{2}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxcviii{اور اپنے رب کی بڑائی (اور عظمت) بیان فرمائیں،\qt@no{3}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxcix{اور اپنے (ظاہر و باطن کے) لباس (پہلے کی طرح ہمیشہ) پاک رکھیں،\qt@no{4}}%
\qt@newcmd\qurantrans@ur@mmmmmd{اور (حسبِ سابق گناہوں اور) بتوں سے الگ رہیں،\qt@no{5}}%
\qt@newcmd\qurantrans@ur@mmmmmdi{اور (اس غرض سے کسی پر) احسان نہ کریں کہ اس سے زیادہ کے طالب ہوں،\qt@no{6}}%
\qt@newcmd\qurantrans@ur@mmmmmdii{اور آپ اپنے رب کے لئے صبر کیا کریں،\qt@no{7}}%
\qt@newcmd\qurantrans@ur@mmmmmdiii{پھر جب (دوبارہ) صور میں پھونک ماری جائے گی،\qt@no{8}}%
\qt@newcmd\qurantrans@ur@mmmmmdiv{سو وہ دن (یعنی روزِ قیامت) بڑا ہی سخت دن ہوگا،\qt@no{9}}%
\qt@newcmd\qurantrans@ur@mmmmmdv{کافروں پر ہرگز آسان نہ ہوگا،\qt@no{10}}%
\qt@newcmd\qurantrans@ur@mmmmmdvi{آپ مجھے اور اس شخص کو جسے میں نے اکیلا پیدا کیا (اِنتقام لینے کے لئے) چھوڑ دیں،\qt@no{11}}%
\qt@newcmd\qurantrans@ur@mmmmmdvii{اور میں نے اسے بہت وسیع مال مہیا کیا تھا،\qt@no{12}}%
\qt@newcmd\qurantrans@ur@mmmmmdviii{اور (اس کے سامنے) حاضر رہنے والے بیٹے (دئیے) تھے،\qt@no{13}}%
\qt@newcmd\qurantrans@ur@mmmmmdix{اور میں نے اسے (سامانِ عیش و عشرت میں) خوب وُسعت دی تھی،\qt@no{14}}%
\qt@newcmd\qurantrans@ur@mmmmmdx{پھر (بھی) وہ حرص رکھتا ہے کہ میں اور زیادہ کروں،\qt@no{15}}%
\qt@newcmd\qurantrans@ur@mmmmmdxi{ہرگز (ایسا) نہ ہوگا، بے شک وہ ہماری آیتوں کا دشمن رہا ہے،\qt@no{16}}%
\qt@newcmd\qurantrans@ur@mmmmmdxii{عنقریب میں اسے سخت مشقت (کے عذاب) کی تکلیف دوں گا،\qt@no{17}}%
\qt@newcmd\qurantrans@ur@mmmmmdxiii{بے شک اس نے سوچ بچار کی اور (دِل میں) ایک تجویز مقرر کر لی،\qt@no{18}}%
\qt@newcmd\qurantrans@ur@mmmmmdxiv{بس اس پر (اللہ کی) مار (یعنی لعنت) ہو، اس نے کیسی تجویز کی،\qt@no{19}}%
\qt@newcmd\qurantrans@ur@mmmmmdxv{اس پر پھر (اللہ کی) مار (یعنی لعنت) ہو، اس نے کیسی تجویز کی،\qt@no{20}}%
\qt@newcmd\qurantrans@ur@mmmmmdxvi{پھر اس نے (اپنی تجویز پر دوبارہ) غور کیا،\qt@no{21}}%
\qt@newcmd\qurantrans@ur@mmmmmdxvii{پھر تیوری چڑھائی اور منہ بگاڑا،\qt@no{22}}%
\qt@newcmd\qurantrans@ur@mmmmmdxviii{پھر (حق سے) پیٹھ پھیر لی اور تکبّر کیا،\qt@no{23}}%
\qt@newcmd\qurantrans@ur@mmmmmdxix{پھر کہنے لگا کہ یہ (قرآن) جادو کے سوا کچھ نہیں جو (اگلے جادوگروں سے) نقل ہوتا چلا آرہا ہے،\qt@no{24}}%
\qt@newcmd\qurantrans@ur@mmmmmdxx{یہ (قرآن) بجز اِنسان کے کلام کے (اور کچھ) نہیں،\qt@no{25}}%
\qt@newcmd\qurantrans@ur@mmmmmdxxi{میں عنقریب اسے دوزخ میں جھونک دوں گا،\qt@no{26}}%
\qt@newcmd\qurantrans@ur@mmmmmdxxii{اور آپ کو کس نے بتایا ہے کہ سَقَر کیا ہے،\qt@no{27}}%
\qt@newcmd\qurantrans@ur@mmmmmdxxiii{وہ (ایسی آگ ہے جو) نہ باقی رکھتی ہے اور نہ چھوڑتی ہے،\qt@no{28}}%
\qt@newcmd\qurantrans@ur@mmmmmdxxiv{وہ) جسمانی کھال کو جھلسا کر سیاہ کر دینے والی ہے،\qt@no{29}}%
\qt@newcmd\qurantrans@ur@mmmmmdxxv{اس پر اُنیس (١٩ فرشتے داروغے مقرر) ہیں،\qt@no{30}}%
\qt@newcmd\qurantrans@ur@mmmmmdxxvi{اور ہم نے دوزخ کے داروغے صرف فرشتے ہی مقرر کئے ہیں اور ہم نے ان کی گنتی کافروں کے لئے محض آزمائش کے طور پر مقرر کی ہے تاکہ اہلِ کتاب یقین کر لیں (کہ قرآن اور نبوتِ محمدی صلی اللہ علیہ وآلہ وسلم حق ہے کیونکہ ان کی کتب میں بھی یہی تعداد بیان کی گئی تھی) اور اہلِ ایمان کا ایمان (اس تصدیق سے) مزید بڑھ جائے، اور اہلِ کتاب اور مومنین (اس کی حقانیت میں) شک نہ کر سکیں، اور تاکہ وہ لوگ جن کے دلوں میں (نفاق کی) بیماری ہے اور کفار یہ کہیں کہ اس (تعداد کی) مثال سے اللہ کی مراد کیا ہے؟ اسی طرح اللہ (ایک ہی بات سے) جسے چاہتا ہے گمراہ ٹھہراتا ہے اور جسے چاہتا ہے ہدایت فرماتا ہے، اور آپ کے رب کے لشکروں کو اس کے سوا کوئی نہیں جانتا، اور یہ (دوزخ کا بیان) اِنسان کی نصیحت کے لئے ہی ہے،\qt@no{31}}%
\qt@newcmd\qurantrans@ur@mmmmmdxxvii{ہاں، چاند کی قَسم (جس کا گھٹنا، بڑھنا اور غائب ہو جانا گواہی ہے)،\qt@no{32}}%
\qt@newcmd\qurantrans@ur@mmmmmdxxviii{اور رات کی قَسم جب وہ پیٹھ پھیر کر رخصت ہونے لگے،\qt@no{33}}%
\qt@newcmd\qurantrans@ur@mmmmmdxxix{اور صبح کی قَسم جب وہ روشن ہو جائے،\qt@no{34}}%
\qt@newcmd\qurantrans@ur@mmmmmdxxx{بے شک یہ (دوزخ) بہت بڑی آفتوں میں سے ایک ہے،\qt@no{35}}%
\qt@newcmd\qurantrans@ur@mmmmmdxxxi{انسان کو ڈرانے والی ہے،\qt@no{36}}%
\qt@newcmd\qurantrans@ur@mmmmmdxxxii{یعنی) اس شخص کے لئے جو تم میں سے (نیکی میں) آگے بڑھنا چاہے یا جو (بدی میں پھنس کر) پیچھے رہ جائے،\qt@no{37}}%
\qt@newcmd\qurantrans@ur@mmmmmdxxxiii{ہر شخص اُن (اَعمال) کے بدلے جو اُس نے کما رکھے ہیں گروی ہے،\qt@no{38}}%
\qt@newcmd\qurantrans@ur@mmmmmdxxxiv{سوائے دائیں جانب والوں کے،\qt@no{39}}%
\qt@newcmd\qurantrans@ur@mmmmmdxxxv{وہ) باغات میں ہوں گے، اور آپس میں پوچھتے ہوں گے،\qt@no{40}}%
\qt@newcmd\qurantrans@ur@mmmmmdxxxvi{مجرموں کے بارے میں،\qt@no{41}}%
\qt@newcmd\qurantrans@ur@mmmmmdxxxvii{اور کہیں گے:) تمہیں کیا چیز دوزخ میں لے گئی،\qt@no{42}}%
\qt@newcmd\qurantrans@ur@mmmmmdxxxviii{وہ کہیں گے: ہم نماز پڑھنے والوں میں نہ تھے،\qt@no{43}}%
\qt@newcmd\qurantrans@ur@mmmmmdxxxix{اور ہم محتاجوں کو کھانا نہیں کھلاتے تھے،\qt@no{44}}%
\qt@newcmd\qurantrans@ur@mmmmmdxl{اور بیہودہ مشاغل والوں کے ساتھ (مل کر) ہم بھی بیہودہ مشغلوں میں پڑے رہتے تھے،\qt@no{45}}%
\qt@newcmd\qurantrans@ur@mmmmmdxli{اور ہم روزِ جزا کو جھٹلایا کرتے تھے،\qt@no{46}}%
\qt@newcmd\qurantrans@ur@mmmmmdxlii{یہاں تک کہ ہم پر جس کا آنا یقینی تھا (وہ موت) آپہنچی،\qt@no{47}}%
\qt@newcmd\qurantrans@ur@mmmmmdxliii{سو (اب) شفاعت کرنے والوں کی شفاعت انہیں کوئی نفع نہیں پہنچائے گی،\qt@no{48}}%
\qt@newcmd\qurantrans@ur@mmmmmdxliv{تو ان (کفّار) کو کیا ہوگیا ہے کہ (پھر بھی) نصیحت سے رُوگردانی کئے ہوئے ہیں،\qt@no{49}}%
\qt@newcmd\qurantrans@ur@mmmmmdxlv{گویا وہ بِدکے ہوئے (وحشی) گدھے ہیں،\qt@no{50}}%
\qt@newcmd\qurantrans@ur@mmmmmdxlvi{جو شیر سے بھاگ کھڑے ہوئے ہیں،\qt@no{51}}%
\qt@newcmd\qurantrans@ur@mmmmmdxlvii{بلکہ ان میں سے ہر ایک شخص یہ چاہتا ہے کہ اُسے (براہِ راست) کھلے ہوئے (آسمانی) صحیفے دے دئیے جائیں،\qt@no{52}}%
\qt@newcmd\qurantrans@ur@mmmmmdxlviii{ایسا ہرگز ممکن نہیں، بلکہ (حقیقت یہ ہے کہ) وہ لوگ آخرت سے ڈرتے ہی نہیں،\qt@no{53}}%
\qt@newcmd\qurantrans@ur@mmmmmdxlix{کچھ شک نہیں کہ یہ (قرآن) نصیحت ہے،\qt@no{54}}%
\qt@newcmd\qurantrans@ur@mmmmmdl{پس جو چاہے اِسے یاد رکھے،\qt@no{55}}%
\qt@newcmd\qurantrans@ur@mmmmmdli{اور یہ لوگ (اِسے) یاد نہیں رکھیں گے مگر جب اللہ چاہے گا، وُہی تقوٰی (و پرہیزگاری) کا مستحق ہے اور مغفرت کا مالک ہے،\qt@no{56}}%
\qt@newcmd\qurantrans@ur@mmmmmdlii{\basmalahur میں قسم کھاتا ہوں روزِ قیامت کی،\qt@no{1}}%
\qt@newcmd\qurantrans@ur@mmmmmdliii{اور میں قسم کھاتا ہوں (برائیوں پر) ملامت کرنے والے نفس کی،\qt@no{2}}%
\qt@newcmd\qurantrans@ur@mmmmmdliv{کیا انسان یہ خیال کرتا ہے کہ ہم اُس کی ہڈیوں کو (جو مرنے کے بعد ریزہ ریزہ ہو کر بکھر جائیں گی) ہرگز اِکٹھا نہ کریں گے،\qt@no{3}}%
\qt@newcmd\qurantrans@ur@mmmmmdlv{کیوں نہیں! ہم تو اس بات پر بھی قادر ہیں کہ اُس کی اُنگلیوں کے ایک ایک جوڑ اور پوروں تک کو درست کر دیں،\qt@no{4}}%
\qt@newcmd\qurantrans@ur@mmmmmdlvi{بلکہ انسان یہ چاہتا ہے کہ اپنے آگے (کی زندگی میں) بھی گناہ کرتا رہے،\qt@no{5}}%
\qt@newcmd\qurantrans@ur@mmmmmdlvii{وہ (بہ اَندازِ تمسخر) پوچھتا ہے کہ قیامت کا دن کب ہوگا،\qt@no{6}}%
\qt@newcmd\qurantrans@ur@mmmmmdlviii{پھر جب آنکھیں چوندھیا جائیں گی،\qt@no{7}}%
\qt@newcmd\qurantrans@ur@mmmmmdlix{اور چاند (اپنی) روشنی کھو دے گا،\qt@no{8}}%
\qt@newcmd\qurantrans@ur@mmmmmdlx{اور سورج اور چاند اِکٹھے (بے نور) ہو جائیں گے،\qt@no{9}}%
\qt@newcmd\qurantrans@ur@mmmmmdlxi{اُس وقت انسان پکار اٹھے گا کہ بھاگ جانے کا ٹھکانا کہاں ہے،\qt@no{10}}%
\qt@newcmd\qurantrans@ur@mmmmmdlxii{ہرگز نہیں! کوئی جائے پناہ نہیں ہے،\qt@no{11}}%
\qt@newcmd\qurantrans@ur@mmmmmdlxiii{اُس دن آپ کے رب ہی کے پاس قرارگاہ ہوگی،\qt@no{12}}%
\qt@newcmd\qurantrans@ur@mmmmmdlxiv{اُس دن اِنسان اُن (اَعمال) سے خبردار کیا جائے گا جو اُس نے آگے بھیجے تھے اور جو (اَثرات اپنی موت کے بعد) پیچھے چھوڑے تھے،\qt@no{13}}%
\qt@newcmd\qurantrans@ur@mmmmmdlxv{بلکہ اِنسان اپنے (اَحوالِ) نفس پر (خود ہی) آگاہ ہوگا،\qt@no{14}}%
\qt@newcmd\qurantrans@ur@mmmmmdlxvi{اگرچہ وہ اپنے تمام عذر پیش کرے گا،\qt@no{15}}%
\qt@newcmd\qurantrans@ur@mmmmmdlxvii{اے حبیب!) آپ (قرآن کو یاد کرنے کی) جلدی میں (نزولِ وحی کے ساتھ) اپنی زبان کو حرکت نہ دیا کریں،\qt@no{16}}%
\qt@newcmd\qurantrans@ur@mmmmmdlxviii{بے شک اسے (آپ کے سینہ میں) جمع کرنا اور اسے (آپ کی زبان سے) پڑھانا ہمارا ذِمّہ ہے،\qt@no{17}}%
\qt@newcmd\qurantrans@ur@mmmmmdlxix{پھر جب ہم اسے (زبانِ جبریل سے) پڑھ چکیں تو آپ اس پڑھے ہوئے کی پیروی کیا کریں،\qt@no{18}}%
\qt@newcmd\qurantrans@ur@mmmmmdlxx{پھر بے شک اس (کے معانی) کا کھول کر بیان کرنا ہمارا ہی ذِمّہ ہے،\qt@no{19}}%
\qt@newcmd\qurantrans@ur@mmmmmdlxxi{حقیقت یہ ہے (اے کفّار!) تم جلد ملنے والی (دنیا) کو محبوب رکھتے ہو،\qt@no{20}}%
\qt@newcmd\qurantrans@ur@mmmmmdlxxii{اور تم آخرت کو چھوڑے ہوئے ہو،\qt@no{21}}%
\qt@newcmd\qurantrans@ur@mmmmmdlxxiii{بہت سے چہرے اُس دن شگفتہ و تروتازہ ہوں گے،\qt@no{22}}%
\qt@newcmd\qurantrans@ur@mmmmmdlxxiv{اور (بلا حجاب) اپنے رب (کے حسن و جمال) کو تک رہے ہوں گے،\qt@no{23}}%
\qt@newcmd\qurantrans@ur@mmmmmdlxxv{اور کتنے ہی چہرے اُس دن بگڑی ہوئی حالت میں (مایوس اور سیاہ) ہوں گے،\qt@no{24}}%
\qt@newcmd\qurantrans@ur@mmmmmdlxxvi{یہ گمان کرتے ہوں گے کہ اُن کے ساتھ ایسی سختی کی جائے گی جو اُن کی کمر توڑ دے گی،\qt@no{25}}%
\qt@newcmd\qurantrans@ur@mmmmmdlxxvii{نہیں نہیں، جب جان گلے تک پہنچ جائے،\qt@no{26}}%
\qt@newcmd\qurantrans@ur@mmmmmdlxxviii{اور کہا جا رہا ہو کہ (اِس وقت) کون ہے جھاڑ پھونک سے علاج کرنے والا (جس سے شفایابی کرائیں)،\qt@no{27}}%
\qt@newcmd\qurantrans@ur@mmmmmdlxxix{اور (جان دینے والا) سمجھ لے کہ (اب سب سے) جدائی ہے،\qt@no{28}}%
\qt@newcmd\qurantrans@ur@mmmmmdlxxx{اور پنڈلی سے پنڈلی لپٹنے لگے،\qt@no{29}}%
\qt@newcmd\qurantrans@ur@mmmmmdlxxxi{تو اس دن آپ کے رب کی طرف جانا ہوتا ہے،\qt@no{30}}%
\qt@newcmd\qurantrans@ur@mmmmmdlxxxii{تو (کتنی بد نصیبی ہے کہ) اس نے نہ (رسول صلی اللہ علیہ وآلہ وسلم کی باتوں کی) تصدیق کی نہ نماز پڑھی،\qt@no{31}}%
\qt@newcmd\qurantrans@ur@mmmmmdlxxxiii{بلکہ وہ جھٹلاتا رہا اور رُوگردانی کرتا رہا،\qt@no{32}}%
\qt@newcmd\qurantrans@ur@mmmmmdlxxxiv{پھر اپنے اہلِ خانہ کی طرف اکڑ کر چل دیا،\qt@no{33}}%
\qt@newcmd\qurantrans@ur@mmmmmdlxxxv{تمہارے لئے (مرتے وقت) تباہی ہے، پھر (قبر میں) تباہی ہے،\qt@no{34}}%
\qt@newcmd\qurantrans@ur@mmmmmdlxxxvi{پھر تمہارے لئے (روزِ قیامت) ہلاکت ہے، پھر (دوزخ کی) ہلاکت ہے،\qt@no{35}}%
\qt@newcmd\qurantrans@ur@mmmmmdlxxxvii{کیا اِنسان یہ خیال کرتا ہے کہ اُسے بے کار (بغیر حساب و کتاب کے) چھوڑ دیا جائے گا،\qt@no{36}}%
\qt@newcmd\qurantrans@ur@mmmmmdlxxxviii{کیا وہ (اپنی اِبتداء میں) منی کا ایک قطرہ نہ تھا جو (عورت کے رحم میں) ٹپکا دیا جاتا ہے،\qt@no{37}}%
\qt@newcmd\qurantrans@ur@mmmmmdlxxxix{پھر وہ (رحم میں جال کی طرح جما ہوا) ایک معلّق وجود بن گیا، پھر اُس نے (تمام جسمانی اَعضاء کی اِبتدائی شکل کو اس وجود میں) پیدا فرمایا، پھر اس نے (انہیں) درست کیا،\qt@no{38}}%
\qt@newcmd\qurantrans@ur@mmmmmdxc{پھر یہ کہ اس نے اسی نطفہ ہی کے ذریعہ دو قِسمیں بنائیں: مرد اور عورت،\qt@no{39}}%
\qt@newcmd\qurantrans@ur@mmmmmdxci{تو کیا وہ اس بات پر قادر نہیں کہ مُردوں کو پھر سے زندہ کر دے،\qt@no{40}}%
\qt@newcmd\qurantrans@ur@mmmmmdxcii{\basmalahur بے شک انسان پر زمانے کا ایک ایسا وقت بھی گزر چکا ہے کہ وہ کوئی قابلِ ذِکر چیز ہی نہ تھا،\qt@no{1}}%
\qt@newcmd\qurantrans@ur@mmmmmdxciii{بے شک ہم نے انسان کو مخلوط نطفہ سے پیدا فرمایا جسے ہم (تولّد تک ایک مرحلہ سے دوسرے مرحلہ کی طرف) پلٹتے اور جانچتے رہتے ہیں، پس ہم نے اسے (ترتیب سے) سننے والا (پھر) دیکھنے والا بنایا ہے،\qt@no{2}}%
\qt@newcmd\qurantrans@ur@mmmmmdxciv{بے شک ہم نے اسے (حق و باطل میں تمیز کرنے کے لئے شعور و بصیرت کی) راہ بھی دکھا دی، (اب) خواہ وہ شکر گزار ہو جائے یا ناشکر گزار رہے،\qt@no{3}}%
\qt@newcmd\qurantrans@ur@mmmmmdxcv{بیشک ہم نے کافروں کے لئے (پاؤں کی) زنجیریں اور (گردن کے) طوق اور (دوزخ کی) دہکتی آگ تیار کر رکھی ہے،\qt@no{4}}%
\qt@newcmd\qurantrans@ur@mmmmmdxcvi{بیشک مخلص اِطاعت گزار (شرابِ طہور کے) ایسے جام پئیں گے جس میں (خوشبو، رنگت اور لذت بڑھانے کے لئے) کافور کی آمیزش ہوگی،\qt@no{5}}%
\qt@newcmd\qurantrans@ur@mmmmmdxcvii{کافور جنت کا) ایک چشمہ ہے جس سے (خاص) بندگانِ خدا (یعنی اَولیاء اللہ) پیا کریں گے (اور) جہاں چاہیں گے (دوسروں کو پلانے کے لئے) اسے چھوٹی چھوٹی نہروں کی شکل میں بہا کر (بھی) لے جائیں گے،\qt@no{6}}%
\qt@newcmd\qurantrans@ur@mmmmmdxcviii{یہ بندگانِ خاص وہ ہیں) جو (اپنی) نذریں پوری کرتے ہیں اور اس دن سے ڈرتے ہیں جس کی سختی خوب پھیل جانے والی ہے،\qt@no{7}}%
\qt@newcmd\qurantrans@ur@mmmmmdxcix{اور (اپنا) کھانا اﷲ کی محبت میں (خود اس کی طلب و حاجت ہونے کے باوُجود اِیثاراً) محتاج کو اور یتیم کو اور قیدی کو کھلا دیتے ہیں،\qt@no{8}}%
\qt@newcmd\qurantrans@ur@mmmmmdc{اور کہتے ہیں کہ) ہم تو محض اللہ کی رضا کے لئے تمہیں کھلا رہے ہیں، نہ تم سے کسی بدلہ کے خواست گار ہیں اور نہ شکرگزاری کے (خواہش مند) ہیں،\qt@no{9}}%
\qt@newcmd\qurantrans@ur@mmmmmdci{ہمیں تو اپنے ربّ سے اُس دن کا خوف رہتا ہے جو (چہروں کو) نہایت سیاہ (اور) بدنما کر دینے والا ہے،\qt@no{10}}%
\qt@newcmd\qurantrans@ur@mmmmmdcii{پس اللہ انہیں (خوفِ اِلٰہی کے سبب سے) اس دن کی سختی سے بچا لے گا اور انہیں (چہروں پر) رونق و تازگی اور (دلوں میں) سرور و مسرّت بخشے گا،\qt@no{11}}%
\qt@newcmd\qurantrans@ur@mmmmmdciii{اور اِس بات کے عوض کہ انہوں نے صبر کیا ہے (رہنے کو) جنت اور (پہننے کو) ریشمی پوشاک عطا کرے گا،\qt@no{12}}%
\qt@newcmd\qurantrans@ur@mmmmmdciv{یہ لوگ اس میں تختوں پر تکیے لگائے بیٹھے ہوں گے، نہ وہاں دھوپ کی تپش پائیں گے اور نہ سردی کی شدّت،\qt@no{13}}%
\qt@newcmd\qurantrans@ur@mmmmmdcv{اور (جنت کے درختوں کے) سائے ان پر جھک رہے ہوں گے اور ان کے (میووں کے) گچھے جھک کر لٹک رہے ہوں گے،\qt@no{14}}%
\qt@newcmd\qurantrans@ur@mmmmmdcvi{اور (خُدام) ان کے گرد چاندی کے برتن اور (صاف ستھرے) شیشے کے گلاس لئے پھرتے ہوں گے،\qt@no{15}}%
\qt@newcmd\qurantrans@ur@mmmmmdcvii{اور شیشے بھی چاندی کے (بنے) ہوں گے جنہیں انہوں نے (ہر ایک کی طلب کے مطابق) ٹھیک ٹھیک اندازہ سے بھرا ہوگا،\qt@no{16}}%
\qt@newcmd\qurantrans@ur@mmmmmdcviii{اور انہیں وہاں (شرابِ طہور کے) ایسے جام پلائے جائیں گے جن میں زنجبیل کی آمیزش ہوگی،\qt@no{17}}%
\qt@newcmd\qurantrans@ur@mmmmmdcix{زنجبیل) اس (جنت) میں ایک ایسا چشمہ ہے جس کا نام ``سلسبیل" رکھا گیا ہے،\qt@no{18}}%
\qt@newcmd\qurantrans@ur@mmmmmdcx{اور ان کے اِرد گرد ایسے (معصوم) بچے گھومتے رہیں گے، جو ہمیشہ اسی حال میں رہیں گے، جب آپ انہیں دیکھیں گے تو انہیں بکھرے ہوئے موتی گمان کریں گے،\qt@no{19}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxi{اور جب آپ (بہشت پر) نظر ڈالیں گے تو وہاں (کثرت سے) نعمتیں اور (ہر طرف) بڑی سلطنت دیکھیں گے،\qt@no{20}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxii{ان (کے جسموں) پر باریک ریشم کے سبز اور دبیز اطلس کے کپڑے ہوں گے، اور انہیں چاندی کے کنگن پہنائے جائیں گے اور ان کا ربّ انہیں پاکیزہ شراب پلائے گا،\qt@no{21}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxiii{بے شک یہ تمہارا صلہ ہوگا اور تمہاری محنت مقبول ہوچکی،\qt@no{22}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxiv{بے شک ہم نے آپ پر قرآن تھوڑا تھوڑا کر کے نازل فرمایا ہے،\qt@no{23}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxv{سو آپ اپنے ربّ کے حکم کی خاطر صبر (جاری) رکھیں اور ان میں سے کسی کاذب و گنہگار یا کافر و ناشکرگزار کی بات پر کان نہ دھریں،\qt@no{24}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxvi{اور صبح و شام اپنے رب کے نام کا ذکر کیا کریں،\qt@no{25}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxvii{اور رات کی کچھ گھڑیاں اس کے حضور سجدہ ریزی کیا کریں اور رات کے (بقیہ) طویل حصہ میں اس کی تسبیح کیا کریں،\qt@no{26}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxviii{بے شک یہ (طالبانِ دنیا) جلد ملنے والے مفاد کو عزیز رکھتے ہیں اور سخت بھاری دن (کی یاد) کو اپنے پسِ پشت چھوڑے ہوئے ہیں،\qt@no{27}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxix{وہ نہیں سوچتے کہ) ہم ہی نے انہیں پیدا فرمایا ہے اور ان کے جوڑ جوڑ کو مضبوط بنایا ہے، اور ہم جب چاہیں (انہیں) انہی جیسے لوگوں سے بدل ڈالیں،\qt@no{28}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxx{بے شک یہ (قرآن) نصیحت ہے، سو جو کوئی چاہے اپنے رب کی طرف (پہنچنے کا) راستہ اِختیار کر لے،\qt@no{29}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxxi{اور تم خود کچھ نہیں چاہ سکتے سوائے اس کے جو اللہ چاہے، بے شک اللہ خوب جاننے والا بڑی حکمت والا ہے،\qt@no{30}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxxii{وہ جسے چاہتا ہے اپنی رحمت (کے دائرے) میں داخل فرما لیتا ہے، اور ظالموں کے لئے اس نے دردناک عذاب تیار کر رکھا ہے،\qt@no{31}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxxiii{\basmalahur نرم و خوش گوار ہواؤں کی قَسم جو پے در پے چلتی ہیں،\qt@no{1}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxxiv{پھر تند و تیز ہواؤں کی قَسم جو شدید جھونکوں سے چلتی ہیں،\qt@no{2}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxxv{اور ان کی قَسم جو بادلوں کو ہر طرف پھیلا دیتی ہیں،\qt@no{3}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxxvi{پھر ان کی قَسم جو (اُنہیں) پھاڑ کر جدا جدا کر دیتی ہیں،\qt@no{4}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxxvii{پھر ان کی قَسم جو نصیحت لانے والی ہیں،\qt@no{5}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxxviii{حجت تمام کرنے یا ڈرانے کے لئے،\qt@no{6}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxxix{بیشک جو وعدۂ (قیامت) تم سے کیا جا رہا ہے وہ ضرور پورا ہو کر رہے گا،\qt@no{7}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxxx{پھر جب ستاروں کی روشنی زائل کر دی جائے گی،\qt@no{8}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxxxi{اور جب آسمانی کائنات میں شگاف ہو جائیں گے،\qt@no{9}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxxxii{اور جب پہاڑ (ریزہ ریزہ کر کے) اُڑا دیے جائیں گے،\qt@no{10}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxxxiii{اور جب پیغمبر وقتِ مقررہ پر (اپنی اپنی اُمتوں پر گواہی کے لئے) جمع کئے جائیں گے،\qt@no{11}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxxxiv{بھلا کس دن کے لئے (ان سب اُمور کی) مدت مقرر کی گئی ہے،\qt@no{12}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxxxv{فیصلہ کے دن کے لئے،\qt@no{13}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxxxvi{اور آپ کو کس نے بتایا کہ فیصلہ کا دن کیا ہے،\qt@no{14}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxxxvii{اس دن جھٹلانے والوں کے لئے خرابی (و تباہی) ہے،\qt@no{15}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxxxviii{کیا ہم نے اگلے (جھٹلانے والے) لوگوں کو ہلاک نہیں کر ڈالا تھا،\qt@no{16}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxxxix{پھر ہم بعد کے لوگوں کو بھی (ہلاکت میں) ان کے پیچھے چلائے دیتے ہیں،\qt@no{17}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxl{ہم مجرموں کے ساتھ اِسی طرح (کا معاملہ) کرتے ہیں،\qt@no{18}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxli{اُس دن جھٹلانے والوں کے لئے بڑی خرابی ہے،\qt@no{19}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxlii{کیا ہم نے تمہیں حقیر پانی (کی ایک بوند) سے پیدا نہیں کیا،\qt@no{20}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxliii{پھر اس کو محفوظ جگہ (یعنی رحمِ مادر) میں رکھا،\qt@no{21}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxliv{وقت کے) ایک معیّن اندازے تک،\qt@no{22}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxlv{پھر ہم نے (نطفہ سے تولّد تک تمام مراحل کے لئے) وقت کے اندازے مقرر کئے، پس (ہم) کیا ہی خوب اندازے مقرر کرنے والے ہیں،\qt@no{23}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxlvi{اُس دن جھٹلانے والوں کے لئے بڑی تباہی ہے،\qt@no{24}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxlvii{کیا ہم نے زمین کو سمیٹ لینے والی نہیں بنایا،\qt@no{25}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxlviii{جو سمیٹتی ہے) زندوں کو (بھی) اور مُردوں کو (بھی)،\qt@no{26}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxlix{ہم نے اس پر بلند و مضبوط پہاڑ رکھ دئیے اور ہم نے تمہیں (شیریں چشموں کے ذریعے) میٹھا پانی پلایا،\qt@no{27}}%
\qt@newcmd\qurantrans@ur@mmmmmdcl{اس دن جھٹلانے والوں کے لئے بڑی بربادی ہوگی،\qt@no{28}}%
\qt@newcmd\qurantrans@ur@mmmmmdcli{اب) تم اس (عذاب) کی طرف چلو جسے تم جھٹلایا کرتے تھے،\qt@no{29}}%
\qt@newcmd\qurantrans@ur@mmmmmdclii{تم (دوزخ کے دھویں پر مبنی) اس سائے کی طرف چلو جس کے تین حصے ہیں،\qt@no{30}}%
\qt@newcmd\qurantrans@ur@mmmmmdcliii{جو نہ (تو) ٹھنڈا سایہ ہے اور نہ ہی آگ کی تپش سے بچانے والا ہے،\qt@no{31}}%
\qt@newcmd\qurantrans@ur@mmmmmdcliv{بیشک وہ (دوزخ) اونچے محل کی طرح (بڑے بڑے) شعلے اور چنگاریاں اڑاتی ہے،\qt@no{32}}%
\qt@newcmd\qurantrans@ur@mmmmmdclv{یوں بھی لگتا ہے) گویا وہ (چنگاریاں) زرد رنگ والے اونٹ ہیں،\qt@no{33}}%
\qt@newcmd\qurantrans@ur@mmmmmdclvi{اس دن جھٹلانے والوں کے لئے بڑی تباہی ہے،\qt@no{34}}%
\qt@newcmd\qurantrans@ur@mmmmmdclvii{یہ ایسا دن ہے کہ وہ (اس میں) بول بھی نہ سکیں گے،\qt@no{35}}%
\qt@newcmd\qurantrans@ur@mmmmmdclviii{اور نہ ہی انہیں اجازت دی جائے گی کہ وہ معذرت کرسکیں،\qt@no{36}}%
\qt@newcmd\qurantrans@ur@mmmmmdclix{اُس دن جھٹلانے والوں کے لئے بڑی ہلاکت ہے،\qt@no{37}}%
\qt@newcmd\qurantrans@ur@mmmmmdclx{یہ فیصلے کا دن ہے (جس میں) ہم تمہیں اور (سب) پہلے لوگوں کو جمع کریں گے،\qt@no{38}}%
\qt@newcmd\qurantrans@ur@mmmmmdclxi{پھر اگر تمہارے پاس (عذاب سے بچنے کا) کوئی حیلہ (اور داؤ) ہے تو (وہ) داؤ مجھ پر چلا لو،\qt@no{39}}%
\qt@newcmd\qurantrans@ur@mmmmmdclxii{اس دن جھٹلانے والوں کے لئے بڑا افسوس ہے،\qt@no{40}}%
\qt@newcmd\qurantrans@ur@mmmmmdclxiii{بیشک پرہیزگار ٹھنڈے سایوں اور چشموں میں (عیش و راحت کے ساتھ) ہوں گے،\qt@no{41}}%
\qt@newcmd\qurantrans@ur@mmmmmdclxiv{اور پھل اور میوے جس کی بھی وہ خواہش کریں گے (ان کے لئے موجود ہوں گے)،\qt@no{42}}%
\qt@newcmd\qurantrans@ur@mmmmmdclxv{ان سے کہا جائے گا:) تم خوب مزے سے کھاؤ پیو اُن اَعمالِ (صالحہ) کے عوض جو تم کرتے رہے تھے،\qt@no{43}}%
\qt@newcmd\qurantrans@ur@mmmmmdclxvi{بے شک ہم اِسی طرح نیکو کاروں کو جزا دیا کرتے ہیں،\qt@no{44}}%
\qt@newcmd\qurantrans@ur@mmmmmdclxvii{اس دن جھٹلانے والوں کے لئے بڑی خرابی ہے،\qt@no{45}}%
\qt@newcmd\qurantrans@ur@mmmmmdclxviii{اے حق کے منکرو!) تم تھوڑا عرصہ کھا لو اور فائدہ اٹھا لو، بے شک تم مجرم ہو،\qt@no{46}}%
\qt@newcmd\qurantrans@ur@mmmmmdclxix{اس دن جھٹلانے والوں کے لئے بڑی خرابی ہے،\qt@no{47}}%
\qt@newcmd\qurantrans@ur@mmmmmdclxx{اور جب ان سے کہا جاتا ہے کہ تم (اﷲ کے حضور) جھکو تو وہ نہیں جھکتے،\qt@no{48}}%
\qt@newcmd\qurantrans@ur@mmmmmdclxxi{اس دن جھٹلانے والوں کے لئے بڑی تباہی ہے،\qt@no{49}}%
\qt@newcmd\qurantrans@ur@mmmmmdclxxii{پھر وہ اِس (قرآن) کے بعد کس کلام پر ایمان لائیں گے؟،\qt@no{50}}%
\qt@newcmd\qurantrans@ur@mmmmmdclxxiii{\basmalahur یہ لوگ آپس میں کس (چیز) سے متعلق سوال کرتے ہیں،\qt@no{1}}%
\qt@newcmd\qurantrans@ur@mmmmmdclxxiv{کیا) اس عظیم خبر سے متعلق (پوچھ گچھ کر رہے ہیں)،\qt@no{2}}%
\qt@newcmd\qurantrans@ur@mmmmmdclxxv{جس کے بارے میں وہ اختلاف کرتے ہیں،\qt@no{3}}%
\qt@newcmd\qurantrans@ur@mmmmmdclxxvi{ہرگز (وہ خبر لائقِ انکار) نہیں! وہ عنقریب (اس حقیقت کو) جان جائیں گے،\qt@no{4}}%
\qt@newcmd\qurantrans@ur@mmmmmdclxxvii{ہم) پھر (کہتے ہیں: اختلاف و انکار) ہرگز (درست) نہیں! وہ عنقریب جان جائیں گے،\qt@no{5}}%
\qt@newcmd\qurantrans@ur@mmmmmdclxxviii{کیا ہم نے زمین کو (زندگی کے) قیام اور کسب و عمل کی جگہ نہیں بنایا،\qt@no{6}}%
\qt@newcmd\qurantrans@ur@mmmmmdclxxix{اور (کیا) پہاڑوں کو (اس میں) ابھار کر کھڑا (نہیں) کیا،\qt@no{7}}%
\qt@newcmd\qurantrans@ur@mmmmmdclxxx{اور (غور کرو) ہم نے تمہیں (فروغِ نسل کے لئے) جوڑا جوڑا پیدا فرمایا (ہے)،\qt@no{8}}%
\qt@newcmd\qurantrans@ur@mmmmmdclxxxi{اور ہم نے تمہاری نیند کو (جسمانی) راحت (کا سبب) بنایا (ہے)،\qt@no{9}}%
\qt@newcmd\qurantrans@ur@mmmmmdclxxxii{اور ہم نے رات کو (اس کی تاریکی کے باعث) پردہ پوش بنایا (ہے)،\qt@no{10}}%
\qt@newcmd\qurantrans@ur@mmmmmdclxxxiii{اور ہم نے دن کو (کسبِ) معاش (کا وقت) بنایا (ہے)،\qt@no{11}}%
\qt@newcmd\qurantrans@ur@mmmmmdclxxxiv{اور (اب خلائی کائنات میں بھی غور کرو) ہم نے تمہارے اوپر سات مضبوط (طبقات) بنائے،\qt@no{12}}%
\qt@newcmd\qurantrans@ur@mmmmmdclxxxv{اور ہم نے (سورج کو) روشنی اور حرارت کا (زبردست) منبع بنایا،\qt@no{13}}%
\qt@newcmd\qurantrans@ur@mmmmmdclxxxvi{اور ہم نے بھرے بادلوں سے موسلادھار پانی برسایا،\qt@no{14}}%
\qt@newcmd\qurantrans@ur@mmmmmdclxxxvii{تاکہ ہم اس (بارش) کے ذریعے (زمین سے) اناج اور سبزہ نکالیں،\qt@no{15}}%
\qt@newcmd\qurantrans@ur@mmmmmdclxxxviii{اور گھنے گھنے باغات (اگائیں)،\qt@no{16}}%
\qt@newcmd\qurantrans@ur@mmmmmdclxxxix{ہماری قدرت کی ان نشانیوں کو دیکھ کر جان لو کہ) بیشک فیصلہ کا دن (قیامت بھی) ایک مقررہ وقت ہے،\qt@no{17}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxc{جس دن صور پھونکا جائے گا تو تم گروہ در گروہ (اﷲ کے حضور) چلے آؤ گے،\qt@no{18}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxci{اور آسمان (کے طبقات) پھاڑ دیئے جائیں گے تو (پھٹنے کے باعث گویا) وہ دروازے ہی دروازے ہو جائیں گے،\qt@no{19}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxcii{اور پہاڑ (غبار بنا کر فضا میں) اڑا دیئے جائیں گے، سو وہ سراب (کی طرح کالعدم) ہو جائیں گے،\qt@no{20}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxciii{بیشک دوزخ ایک گھات ہے،\qt@no{21}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxciv{وہ) سرکشوں کا ٹھکانا ہے،\qt@no{22}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxcv{وہ ختم نہ ہونے والی پے در پے مدتیں اسی میں پڑے رہیں گے،\qt@no{23}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxcvi{نہ وہ اس میں (کسی قسم کی) ٹھنڈک کا مزہ چکھیں گے اور نہ کسی پینے کی چیز کا،\qt@no{24}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxcvii{سوائے کھولتے ہوئے گرم پانی اور (دوزخیوں کے زخموں سے) بہتی ہوئی پیپ کے،\qt@no{25}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxcviii{یہی ان کی سرکشی کے) موافق بدلہ ہے،\qt@no{26}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxcix{اس لئے کہ وہ قطعًا حسابِ (آخرت) کا خوف نہیں رکھتے تھے،\qt@no{27}}%
\qt@newcmd\qurantrans@ur@mmmmmdcc{اور وہ ہماری آیتوں کو خوب جھٹلایا کرتے تھے،\qt@no{28}}%
\qt@newcmd\qurantrans@ur@mmmmmdcci{اور ہم نے ہر (چھوٹی بڑی) چیز کو لکھ کر محفوظ کر رکھا ہے،\qt@no{29}}%
\qt@newcmd\qurantrans@ur@mmmmmdccii{اے منکرو!) اب تم (اپنے کئے کا) مزہ چکھو (تم دنیا میں کفر و سرکشی میں بڑھتے گئے) اب ہم تم پر عذاب ہی کو بڑھاتے جائیں گے،\qt@no{30}}%
\qt@newcmd\qurantrans@ur@mmmmmdcciii{بیشک پرہیزگاروں کے لئے کامیابی ہے،\qt@no{31}}%
\qt@newcmd\qurantrans@ur@mmmmmdcciv{ان کے لئے) باغات اور انگور (ہوں گے)،\qt@no{32}}%
\qt@newcmd\qurantrans@ur@mmmmmdccv{اور جواں سال ہم عمر دوشیزائیں (ہوں گی)،\qt@no{33}}%
\qt@newcmd\qurantrans@ur@mmmmmdccvi{اور (شرابِ طہور کے) چھلکتے ہوئے جام (ہوں گے)،\qt@no{34}}%
\qt@newcmd\qurantrans@ur@mmmmmdccvii{وہاں یہ (لوگ) نہ کوئی بے ہودہ بات سنیں گے اور نہ (ایک دوسرے کو) جھٹلانا (ہوگا)،\qt@no{35}}%
\qt@newcmd\qurantrans@ur@mmmmmdccviii{یہ آپ کے رب کی طرف سے صلہ ہے جو (اعمال کے حساب سے) کافی (بڑی) عطا ہے،\qt@no{36}}%
\qt@newcmd\qurantrans@ur@mmmmmdccix{وہ) آسمانوں اور زمین کا اور جو کچھ ان دونوں کے درمیان ہے (سب) کا پروردگار ہے، بڑی ہی رحمت والا ہے (مگر روزِ قیامت اس کے رعب و جلال کا عالم یہ ہوگا کہ) اس سے بات کرنے کا (مخلوقات میں سے) کسی کو (بھی) یارا نہ ہوگا،\qt@no{37}}%
\qt@newcmd\qurantrans@ur@mmmmmdccx{جس دن جبرائیل (روح الامین) اور (تمام) فرشتے صف بستہ کھڑے ہوں گے، کوئی لب کشائی نہ کر سکے گا، سوائے اس شخص کے جسے خدائے رحمان نے اِذنِ (شفاعت) دے رکھا تھا اور اس نے (زندگی میں تعلیماتِ اسلام کے مطابق) بات بھی درست کہی تھی،\qt@no{38}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxi{یہ روزِ حق ہے، پس جو شخص چاہے اپنے رب کے حضور (رحمت و قربت کا) ٹھکانا بنا لے،\qt@no{39}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxii{بلا شبہ ہم نے تمہیں عنقریب آنے والے عذاب سے ڈرا دیا ہے، اس دن ہر آدمی ان (اعمال) کو جو اس نے آگے بھیجے ہیں دیکھ لے گا، اور (ہر) کافر کہے گا: اے کاش! میں مٹی ہوتا (اور اس عذاب سے بچ جاتا)،\qt@no{40}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxiii{\basmalahur ان (فرشتوں) کی قَسم جو (کافروں کی جان ان کے جسموں کے ایک ایک انگ میں سے) نہایت سختی سے کھینچ لاتے ہیں۔ (یا:- توانائی کی ان لہروں کی قَسم جو مادہ کے اندر گھس کر کیمیائی جوڑوں کو سختی سے توڑ پھوڑ دیتی ہیں)،\qt@no{1}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxiv{اور ان (فرشتوں) کی قَسم جو (مومنوں کی جان کے) بند نہایت نرمی سے کھول دیتے ہیں۔ (یا:- توانائی کی ان لہروں کی قَسم جو مادہ کے اندر سے کیمیائی جوڑوں کو نہایت نرمی اور آرام سے توڑ دیتی ہیں)،\qt@no{2}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxv{اور ان (فرشتوں) کی قَسم جو (زمین و آسمان کے درمیان) تیزی سے تیرتے پھرتے ہیں۔ (یا:- توانائی کی ان لہروں کی قَسم جو آسمانی خلا و فضا میں بلا روک ٹوک چلتی پھرتی ہیں)،\qt@no{3}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxvi{پھر ان (فرشتوں) کی قَسم جو لپک کر (دوسروں سے) آگے بڑھ جاتے ہیں۔ (یا:- پھر توانائی کی ان لہروں کی قَسم جو رفتار، طاقت اور جاذبیت کے لحاظ سے دوسری لہروں پر سبقت لے جاتی ہیں)،\qt@no{4}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxvii{پھر ان (فرشتوں) کی قَسم جو مختلف اُمور کی تدبیر کرتے ہیں۔ (یا:- پھر توانائی کی ان لہروں کی قَسم جو باہمی تعامل سے کائناتی نظام کی بقا کے لئے توازن و تدبیر قائم رکھتی ہیں)،\qt@no{5}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxviii{جب انہیں اس نظامِ کائنات کے درہم برہم کردینے کا حکم ہوگا تو) اس دن (کائنات کی) ہر متحرک چیز شدید حرکت میں آجائے گی،\qt@no{6}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxix{پیچھے آنے والا ایک اور زلزلہ اس کے پیچھے آئے گا،\qt@no{7}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxx{اس دن (لوگوں کے) دل خوف و اضطراب سے دھڑکتے ہوں گے،\qt@no{8}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxxi{ان کی آنکھیں (خوف و ہیبت سے) جھکی ہوں گی،\qt@no{9}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxxii{کفّار) کہتے ہیں: کیا ہم پہلی زندگی کی طرف پلٹائے جائیں گے،\qt@no{10}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxxiii{کیا جب ہم بوسیدہ (کھوکھلی) ہڈیاں ہو جائیں گے (تب بھی زندہ کیے جائیں گے)،\qt@no{11}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxxiv{وہ کہتے ہیں: یہ (لوٹنا) تو اس وقت بڑے خسارے کا لوٹنا ہوگا،\qt@no{12}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxxv{پھر تو یہ ایک ہی بار شدید ہیبت ناک آواز کے ساتھ (کائنات کے تمام اَجرام کا) پھٹ جانا ہوگا،\qt@no{13}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxxvi{پھر وہ (سب لوگ) یکایک کھلے میدانِ (حشر) میں آموجود ہوں گے،\qt@no{14}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxxvii{کیا آپ کے پاس موسٰی (علیہ السلام) کی خبر پہنچی ہے،\qt@no{15}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxxviii{جب ان کے رب نے طوٰی کی مقدّس وادی میں انہیں پکارا تھا،\qt@no{16}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxxix{اور حکم دیا تھا کہ) فرعون کے پاس جاؤ وہ سرکش ہو گیا ہے،\qt@no{17}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxxx{پھر (اس سے) کہو: کیا تیری خواہش ہے کہ تو پاک ہو جائے،\qt@no{18}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxxxi{اور (کیا تو چاہتا ہے کہ) میں تیرے رب کی طرف تیری رہنمائی کروں تاکہ تو (اس سے) ڈرنے لگے،\qt@no{19}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxxxii{پھر موسٰی (علیہ السلام) نے اسے بڑی نشانی دکھائی،\qt@no{20}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxxxiii{تو اس نے جھٹلا دیا اور نافرمانی کی،\qt@no{21}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxxxiv{پھر وہ (حق سے) رُوگرداں ہو کر (موسٰی علیہ السلام کی مخالفت میں) سعی و کاوش کرنے لگا،\qt@no{22}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxxxv{پھر اس نے (لوگوں کو) جمع کیا اور پکارنے لگا،\qt@no{23}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxxxvi{پھر اس نے کہا: میں تمہارا سب سے بلند و بالا رب ہوں،\qt@no{24}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxxxvii{تو اللہ نے اسے آخرت اور دنیا کی (دوہری) سزا میں پکڑ لیا،\qt@no{25}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxxxviii{بیشک اس (واقعہ) میں اس شخص کے لئے بڑی عبرت ہے جو (اللہ سے) ڈرتا ہے،\qt@no{26}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxxxix{کیا تمہارا پیدا کرنا زیادہ مشکل ہے یا (پوری) سماوی کائنات کا، جسے اس نے بنایا،\qt@no{27}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxl{اس نے آسمان کے تمام کرّوں (ستاروں) کو (فضائے بسیط میں پیدا کر کے) بلند کیا، پھر ان (کی ترکیب و تشکیل اور افعال و حرکات) میں اعتدال، توازن اور استحکام پیدا کر دیا،\qt@no{28}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxli{اور اُسی نے آسمانی خلا کی رات کو (یعنی سارے خلائی ماحول کو مثلِ شب) تاریک بنایا، اور (اِس خلا سے) ان (ستاروں) کی روشنی (پیدا کر کے) نکالی،\qt@no{29}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxlii{اور اُسی نے زمین کو اِس (ستارے: سورج کے وجود میں آجانے) کے بعد (اِس سے) الگ کر کے زور سے پھینک دیا (اور اِسے قابلِ رہائش بنانے کے لئے بچھا دیا)،\qt@no{30}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxliii{اسی نے زمین میں سے اس کا پانی (الگ) نکال لیا اور (بقیہ خشک قطعات میں) اس کی نباتات نکالیں،\qt@no{31}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxliv{اور اسی نے (بعض مادوں کو باہم ملا کر) زمین سے محکم پہاڑوں کو ابھار دیا،\qt@no{32}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxlv{یہ سب کچھ) تمہارے اور تمہارے چوپایوں کے فائدہ کے لئے (کیا)،\qt@no{33}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxlvi{پھر اس وقت (کائنات کے) بڑھتے بڑھتے (اس کی انتہا پر) ہر چیز پر غالب آجانے والی بہت سخت آفتِ (قیامت) آئے گی،\qt@no{34}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxlvii{اُس دن انسان اپنی (ہر) کوشش و عمل کو یاد کرے گا،\qt@no{35}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxlviii{اور ہر دیکھنے والے کے لئے دوزخ ظاہر کر دی جائے گی،\qt@no{36}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxlix{پھر جس شخص نے سرکشی کی ہوگی،\qt@no{37}}%
\qt@newcmd\qurantrans@ur@mmmmmdccl{اور دنیاوی زندگی کو (آخرت پر) ترجیح دی ہوگی،\qt@no{38}}%
\qt@newcmd\qurantrans@ur@mmmmmdccli{تو بیشک دوزخ ہی (اُس کا) ٹھکانا ہوگا،\qt@no{39}}%
\qt@newcmd\qurantrans@ur@mmmmmdcclii{اور جو شخص اپنے رب کے حضور کھڑا ہونے سے ڈرتا رہا اور اُس نے (اپنے) نفس کو (بری) خواہشات و شہوات سے باز رکھا،\qt@no{40}}%
\qt@newcmd\qurantrans@ur@mmmmmdccliii{تو بیشک جنت ہی (اُس کا) ٹھکانا ہوگا،\qt@no{41}}%
\qt@newcmd\qurantrans@ur@mmmmmdccliv{کفّار) آپ سے قیامت کے بارے میں پوچھتے ہیں کہ اس کا وقوع کب ہوگا،\qt@no{42}}%
\qt@newcmd\qurantrans@ur@mmmmmdcclv{تو آپ کو اس کے (وقت کے) ذکر سے کیا غرض،\qt@no{43}}%
\qt@newcmd\qurantrans@ur@mmmmmdcclvi{اس کی انتہا تو آپ کے رب تک ہے (یعنی ابتداء کی طرح انتہاء میں بھی صرف وحدت رہ جائے گی)،\qt@no{44}}%
\qt@newcmd\qurantrans@ur@mmmmmdcclvii{آپ تو محض اس شخص کو ڈر سنانے والے ہیں جو اس سے خائف ہے،\qt@no{45}}%
\qt@newcmd\qurantrans@ur@mmmmmdcclviii{گویا وہ جس دن اسے دیکھ لیں گے تو (یہ خیال کریں گے کہ) وہ (دنیا میں) ایک شام یا اس کی صبح کے سوا ٹھہرے ہی نہ تھے،\qt@no{46}}%
\qt@newcmd\qurantrans@ur@mmmmmdcclix{\basmalahur ان کے چہرۂ (اقدس) پر ناگواری آئی اور رخِ (انور) موڑ لیا،\qt@no{1}}%
\qt@newcmd\qurantrans@ur@mmmmmdcclx{اس وجہ سے کہ ان کے پاس ایک نابینا آیا (جس نے آپ کی بات کو ٹوکا)،\qt@no{2}}%
\qt@newcmd\qurantrans@ur@mmmmmdcclxi{اور آپ کو کیا خبر شاید وہ (آپ کی توجہ سے مزید) پاک ہو جاتا،\qt@no{3}}%
\qt@newcmd\qurantrans@ur@mmmmmdcclxii{یا (آپ کی) نصیحت قبول کرتا تو نصیحت اس کو (اور) فائدہ دیتی،\qt@no{4}}%
\qt@newcmd\qurantrans@ur@mmmmmdcclxiii{لیکن جو شخص (دین سے) بے پروا ہے،\qt@no{5}}%
\qt@newcmd\qurantrans@ur@mmmmmdcclxiv{تو آپ اس کے (قبولِ اسلام کے) لیے زیادہ اہتمام فرماتے ہیں،\qt@no{6}}%
\qt@newcmd\qurantrans@ur@mmmmmdcclxv{حالانکہ آپ پر کوئی ذمہ داری (کا بوجھ) نہیں اگرچہ وہ پاکیزگی (ایمان) اختیار نہ بھی کرے،\qt@no{7}}%
\qt@newcmd\qurantrans@ur@mmmmmdcclxvi{اور وہ جو آپ کے پا س (خود طلبِ خیر کی) کوشش کرتا ہوا آیا،\qt@no{8}}%
\qt@newcmd\qurantrans@ur@mmmmmdcclxvii{اور وہ (اپنے رب سے) ڈرتا بھی ہے،\qt@no{9}}%
\qt@newcmd\qurantrans@ur@mmmmmdcclxviii{تو آپ اُس سے بے توجہی فرما رہے ہیں،\qt@no{10}}%
\qt@newcmd\qurantrans@ur@mmmmmdcclxix{اے حبیبِ مکرّم!) یوں نہیں بیشک یہ (آیاتِ قرآنی) تو نصیحت ہیں،\qt@no{11}}%
\qt@newcmd\qurantrans@ur@mmmmmdcclxx{جو شخص چاہے اسے قبول (و اَزبر) کر لے،\qt@no{12}}%
\qt@newcmd\qurantrans@ur@mmmmmdcclxxi{یہ) معزّز و مکرّم اوراق میں (لکھی ہوئی) ہیں،\qt@no{13}}%
\qt@newcmd\qurantrans@ur@mmmmmdcclxxii{جو نہایت بلند مرتبہ (اور) پاکیزہ ہیں،\qt@no{14}}%
\qt@newcmd\qurantrans@ur@mmmmmdcclxxiii{ایسے سفیروں (اور کاتبوں) کے ہاتھوں سے (آگے پہنچی) ہیں،\qt@no{15}}%
\qt@newcmd\qurantrans@ur@mmmmmdcclxxiv{جو بڑے صاحبانِ کرامت (اور) پیکرانِ طاعت ہیں،\qt@no{16}}%
\qt@newcmd\qurantrans@ur@mmmmmdcclxxv{ہلاک ہو (وہ بد بخت منکر) انسان کیسا نا شکرا ہے (جو اتنی عظیم نعمت پا کر بھی اس کی قدر نہیں کرتا)،\qt@no{17}}%
\qt@newcmd\qurantrans@ur@mmmmmdcclxxvi{اللہ نے اسے کس چیز سے پیدا فرمایا ہے،\qt@no{18}}%
\qt@newcmd\qurantrans@ur@mmmmmdcclxxvii{نطفہ میں سے اس کو پیدا فرمایا، پھر ساتھ ہی اس کا (خواص و جنس کے لحاظ سے) تعین فرما دیا،\qt@no{19}}%
\qt@newcmd\qurantrans@ur@mmmmmdcclxxviii{پھر (تشکیل، ارتقاء اور تکمیل کے بعد بطنِ مادر سے نکلنے کی) راہ اس کے لئے آسان فرما دی،\qt@no{20}}%
\qt@newcmd\qurantrans@ur@mmmmmdcclxxix{پھر اسے موت دی، پھر اسے قبر میں (دفن) کر دیا گیا،\qt@no{21}}%
\qt@newcmd\qurantrans@ur@mmmmmdcclxxx{پھر جب وہ چاہے گا اسے (دوبارہ زندہ کر کے) کھڑا کرے گا،\qt@no{22}}%
\qt@newcmd\qurantrans@ur@mmmmmdcclxxxi{یقیناً اس (نافرمان انسان) نے وہ (حق) پورا نہ کیا جس کا اسے (اللہ نے) حکم دیا تھا،\qt@no{23}}%
\qt@newcmd\qurantrans@ur@mmmmmdcclxxxii{پس انسان کو چاہیے کہ اپنی غذا کی طرف دیکھے (اور غور کرے)،\qt@no{24}}%
\qt@newcmd\qurantrans@ur@mmmmmdcclxxxiii{بیشک ہم نے خوب زور سے پانی برسایا،\qt@no{25}}%
\qt@newcmd\qurantrans@ur@mmmmmdcclxxxiv{پھر ہم نے زمین کو پھاڑ کر چیر ڈالا،\qt@no{26}}%
\qt@newcmd\qurantrans@ur@mmmmmdcclxxxv{پھر ہم نے اس میں اناج اگایا،\qt@no{27}}%
\qt@newcmd\qurantrans@ur@mmmmmdcclxxxvi{اور انگور اور ترکاری،\qt@no{28}}%
\qt@newcmd\qurantrans@ur@mmmmmdcclxxxvii{اور زیتون اور کھجور،\qt@no{29}}%
\qt@newcmd\qurantrans@ur@mmmmmdcclxxxviii{اور گھنے گھنے باغات،\qt@no{30}}%
\qt@newcmd\qurantrans@ur@mmmmmdcclxxxix{اور (طرح طرح کے) پھل میوے اور (جانوروں کا) چارہ،\qt@no{31}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxc{خود تمہارے اور تمہارے مویشیوں کے لئے متاعِ (زیست)،\qt@no{32}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxci{پھر جب کان پھاڑ دینے والی آواز آئے گی،\qt@no{33}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxcii{اُس دن آدمی اپنے بھائی سے بھاگے گا،\qt@no{34}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxciii{اور اپنی ماں اور اپنے باپ سے (بھی)،\qt@no{35}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxciv{اور اپنی بیوی اور اپنی اولاد سے (بھی)،\qt@no{36}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxcv{اس دن ہر شخص کو ایسی (پریشان کن) حالت لاحق ہوگی جو اسے (ہر دوسرے سے) بے پروا کر دے گی،\qt@no{37}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxcvi{اسی دن بہت سے چہرے (ایسے بھی ہوں گے جو نور سے) چمک رہے ہوں گے،\qt@no{38}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxcvii{وہ) مسکراتے ہنستے (اور) خوشیاں مناتے ہوں گے،\qt@no{39}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxcviii{اور بہت سے چہرے ایسے ہوں گے جن پر اس دن گرد پڑی ہوگی،\qt@no{40}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxcix{مزید) ان (چہروں) پر سیاہی چھائی ہوگی،\qt@no{41}}%
\qt@newcmd\qurantrans@ur@mmmmmdccc{یہی لوگ کافر (اور) فاجر (بدکردار) ہوں گے،\qt@no{42}}%
\qt@newcmd\qurantrans@ur@mmmmmdccci{\basmalahur جب سورج لپیٹ کر بے نور کر دیا جائے گا،\qt@no{1}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccii{اور جب ستارے (اپنی کہکشاؤں سے) گر پڑیں گے،\qt@no{2}}%
\qt@newcmd\qurantrans@ur@mmmmmdccciii{اور جب پہاڑ (غبار بنا کر فضا میں) چلا دیئے جائیں گے،\qt@no{3}}%
\qt@newcmd\qurantrans@ur@mmmmmdccciv{اور جب حاملہ اونٹنیاں بے کار چھوٹی پھریں گی (کوئی ان کا خبر گیر نہ ہوگا)،\qt@no{4}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccv{اور جب وحشی جانور (خوف کے مارے) جمع کر دیئے جائیں گے،\qt@no{5}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccvi{جب سمندر اور دریا (سب) ابھار دیئے جائیں گے،\qt@no{6}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccvii{اور جب روحیں (بدنوں سے) ملا دی جائیں گی،\qt@no{7}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccviii{اور جب زندہ دفن کی ہوئی لڑکی سے پوچھا جائے گا،\qt@no{8}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccix{کہ وہ کس گناہ کے باعث قتل کی گئی تھی،\qt@no{9}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccx{اور جب اَعمال نامے کھول دیئے جائیں گے،\qt@no{10}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxi{اور جب سماوی طبقات کو پھاڑ کر اپنی جگہوں سے ہٹا دیا جائے گا،\qt@no{11}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxii{اور جب دوزخ (کی آگ) بھڑکائی جائے گی،\qt@no{12}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxiii{اور جب جنت قریب کر دی جائے گی،\qt@no{13}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxiv{ہر شخص جان لے گا جو کچھ اس نے حاضر کیا ہے،\qt@no{14}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxv{تو میں قَسم کھاتا ہوں ان (آسمانی کرّوں) کی جو (ظاہر ہونے کے بعد) پیچھے ہٹ جاتے ہیں،\qt@no{15}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxvi{جو بلا روک ٹوک چلتے رہتے ہیں (پھر ظاہر ہو کر) چھپ جاتے ہیں،\qt@no{16}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxvii{اور رات کی قَسم جب اس کی تاریکی جانے لگے،\qt@no{17}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxviii{اور صبح کی قَسم جب اس کی روشنی آنے لگے،\qt@no{18}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxix{بیشک یہ (قرآن) بڑی عزت و بزرگی والے رسول کا (پڑھا ہوا) کلام ہے،\qt@no{19}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxx{جو (دعوتِ حق، تبلیغِ رسالت اور روحانی استعداد میں) قوت و ہمت والے ہیں (اور) مالکِ عرش کے حضور بڑی قدر و منزلت (اور جاہ و عظمت) والے ہیں،\qt@no{20}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxxi{تمام جہانوں کے لئے) واجب الاطاعت ہیں (کیونکہ ان کی اطاعت ہی اللہ کی اطاعت ہے)، امانت دار ہیں (وحی اور زمین و آسمان کے سب اُلوہی رازوں کے حامل ہیں)،\qt@no{21}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxxii{اور (اے لوگو!) یہ تمہیں اپنی صحبت سے نوازنے والے (محمد صلی اللہ علیہ وآلہ وسلم) دیوانے نہیں ہیں (جو فرماتے ہیں وہ حق ہوتا ہے)،\qt@no{22}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxxiii{اور بیشک انہوں نے اس (مالکِ عرش کے حُسنِ مطلق) کو (لامکاں کے) روشن کنارے پر دیکھا ہے٭، ٭ یہ ترجمہ حضرت عبد اللہ بن عباس، انس بن مالک، عکرمہ، ابو سلمہ، ضحّاک، ابو العالیہ، حسن، کعب الاحبار، شریک بن عبد اللہ اور شعبی و غیرھم رضی اللہ عنھم کے اَقوال پر کیا گیا ہے جنہیں بخاری، مسلم، ترمذی، ابن جریر، بغوی اور کئی ائمہ حدیث نے روایت کیا ہے اور کثیر ائمہ تفسیر نے بھی اسے اختیار کیا ہے۔\qt@no{23}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxxiv{اور وہ (یعنی نبئ اکرم صلی اللہ علیہ وآلہ وسلم) غیب (کے بتانے) پر بالکل بخیل نہیں ہیں (مالکِ عرش نے ان کے لئے کوئی کمی نہیں چھوڑی)،\qt@no{24}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxxv{اور وہ (قرآن) ہرگز کسی شیطان مردود کا کلام نہیں ہے،\qt@no{25}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxxvi{پھر (اے بدبختو!) تم (اتنے بڑے خزانے کو چھوڑ کر) کدھر چلے جا رہے ہو،\qt@no{26}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxxvii{یہ (قرآن) تو تمام جہانوں کے لئے (صحیفۂ) نصیحت ہے،\qt@no{27}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxxviii{تم میں سے ہر اس شخص کے لئے (اس چشمہ سے ہدایت میسر آسکتی ہے) جو سیدھی راہ چلنا چاہے،\qt@no{28}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxxix{اور تم وہی کچھ چاہ سکتے ہو جو اللہ چاہے جو تمام جہانوں کا رب ہے،\qt@no{29}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxxx{\basmalahur جب (سب) آسمانی کرّے پھٹ جائیں گے،\qt@no{1}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxxxi{اور جب سیارے گر کر بکھر جائیں گے،\qt@no{2}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxxxii{اور جب سمندر (اور دریا) ابھر کر بہہ جائیں گے،\qt@no{3}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxxxiii{اور جب قبریں زیر و زبر کر دی جائیں گی،\qt@no{4}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxxxiv{تو ہر شخص جان لے گا کہ کیا عمل اس نے آگے بھیجا اور (کیا) پیچھے چھوڑ آیا تھا،\qt@no{5}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxxxv{اے انسان! تجھے کس چیز نے اپنے ربِ کریم کے بارے میں دھوکے میں ڈال دیا،\qt@no{6}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxxxvi{جس نے (رحم مادر کے اندر ایک نطفہ میں سے) تجھے پیدا کیا، پھر اس نے تجھے (اعضا سازی کے لئے ابتداءً) درست اور سیدھا کیا، پھر وہ تیری ساخت میں متناسب تبدیلی لایا،\qt@no{7}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxxxvii{جس صورت میں بھی چاہا اس نے تجھے ترکیب دے دیا،\qt@no{8}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxxxviii{حقیقت تو یہ ہے (اور) تم اِس کے برعکس روزِ جزا کو جھٹلاتے ہو،\qt@no{9}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxxxix{حالانکہ تم پر نگہبان فرشتے مقرر ہیں،\qt@no{10}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxl{جو) بہت معزز ہیں (تمہارے اعمال نامے) لکھنے والے ہیں،\qt@no{11}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxli{وہ ان (تمام کاموں) کو جانتے ہیں جو تم کرتے ہو،\qt@no{12}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxlii{بیشک نیکوکار جنّتِ نعمت میں ہوں گے،\qt@no{13}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxliii{اور بیشک بدکار دوزخِ (سوزاں) میں ہوں گے،\qt@no{14}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxliv{وہ اس میں قیامت کے روز داخل ہوں گے،\qt@no{15}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxlv{اور وہ اس (دوزخ) سے (کبھی بھی) غائب نہ ہو سکیں گے،\qt@no{16}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxlvi{اور آپ نے کیا سمجھا کہ روزِ جزا کیا ہے،\qt@no{17}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxlvii{پھر آپ نے کیا جانا کہ روزِ جزا کیا ہے،\qt@no{18}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxlviii{یہ) وہ دن ہے جب کوئی شخص کسی کے لئے کسی چیز کا مالک نہ ہوگا، اور حکم فرمائی اس دن اللہ ہی کی ہوگی،\qt@no{19}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxlix{\basmalahur بربادی ہے ناپ تول میں کمی کرنے والوں کے لئے،\qt@no{1}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccl{یہ لوگ جب (دوسرے) لوگوں سے ناپ لیتے ہیں تو (ان سے) پورا لیتے ہیں،\qt@no{2}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccli{اور جب انہیں (خود) ناپ کر یا تول کر دیتے ہیں تو گھٹا کر دیتے ہیں،\qt@no{3}}%
\qt@newcmd\qurantrans@ur@mmmmmdccclii{کیا یہ لوگ اس بات کا یقین نہیں رکھتے کہ وہ (مرنے کے بعد دوبارہ) اٹھائے جائیں گے،\qt@no{4}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccliii{ایک بڑے سخت دن کے لئے،\qt@no{5}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccliv{جس دن سب لوگ تمام جہانوں کے رب کے حضور کھڑے ہوں گے،\qt@no{6}}%
\qt@newcmd\qurantrans@ur@mmmmmdccclv{یہ حق ہے کہ بدکرداروں کا نامۂ اعمال سجین (یعنی دیوان خانۂ جہنم) میں ہے،\qt@no{7}}%
\qt@newcmd\qurantrans@ur@mmmmmdccclvi{اور آپ نے کیا جانا کہ سجین کیا ہے،\qt@no{8}}%
\qt@newcmd\qurantrans@ur@mmmmmdccclvii{یہ قید خانۂ دوزخ میں اس بڑے دیوان کے اندر) لکھی ہوئی (ایک) کتاب ہے (جس میں ہر جہنمی کا نام اور اس کے اعمال درج ہیں)،\qt@no{9}}%
\qt@newcmd\qurantrans@ur@mmmmmdccclviii{اس دن جھٹلانے والوں کے لئے تباہی ہوگی،\qt@no{10}}%
\qt@newcmd\qurantrans@ur@mmmmmdccclix{جو لوگ روزِ جزا کو جھٹلاتے ہیں،\qt@no{11}}%
\qt@newcmd\qurantrans@ur@mmmmmdccclx{اور اسے کوئی نہیں جھٹلاتا سوائے ہر اس شخص کے جو سرکش و گنہگار ہے،\qt@no{12}}%
\qt@newcmd\qurantrans@ur@mmmmmdccclxi{جب اس پر ہماری آیتیں پڑھ کر سنائی جاتی ہیں تو کہتا (یا سمجھتا) ہے کہ (یہ تو) اگلے لوگوں کی کہانیاں ہیں،\qt@no{13}}%
\qt@newcmd\qurantrans@ur@mmmmmdccclxii{ایسا) ہرگز نہیں بلکہ (حقیقت یہ ہے کہ) ان کے دلوں پر ان اَعمالِ (بد) کا زنگ چڑھ گیا ہے جو وہ کمایا کرتے تھے (اس لیے آیتیں ان کے دل پر اثر نہیں کرتیں)،\qt@no{14}}%
\qt@newcmd\qurantrans@ur@mmmmmdccclxiii{حق یہ ہے کہ بیشک اس دن انہیں اپنے ر ب کے دیدار سے (محروم کرنے کے لئے) پسِ پردہ کر دیا جائے گا،\qt@no{15}}%
\qt@newcmd\qurantrans@ur@mmmmmdccclxiv{پھر وہ دوزخ میں جھونک دیئے جائیں گے،\qt@no{16}}%
\qt@newcmd\qurantrans@ur@mmmmmdccclxv{پھر ان سے کہا جائے گا: یہ وہ (عذابِ جہنم) ہے جسے تم جھٹلایا کرتے تھے،\qt@no{17}}%
\qt@newcmd\qurantrans@ur@mmmmmdccclxvi{یہ (بھی) حق ہے کہ بیشک نیکوکاروں کا نوشتہ اعمال علّیّین (یعنی دیوان خانۂ جنت) میں ہے،\qt@no{18}}%
\qt@newcmd\qurantrans@ur@mmmmmdccclxvii{اور آپ نے کیا جانا کہ علّیّین کیا ہے،\qt@no{19}}%
\qt@newcmd\qurantrans@ur@mmmmmdccclxviii{یہ جنت کے اعلیٰ درجہ میں اس بڑے دیوان کے اندر) لکھی ہوئی (ایک) کتاب ہے (جس میں ان جنتیوں کے نام اور اَعمال درج ہیں جنہیں اعلیٰ مقامات دئیے جائیں گے)،\qt@no{20}}%
\qt@newcmd\qurantrans@ur@mmmmmdccclxix{اس جگہ (اللہ کے) مقرب فرشتے حاضر رہتے ہیں،\qt@no{21}}%
\qt@newcmd\qurantrans@ur@mmmmmdccclxx{بیشک نیکوکار (راحت و مسرت سے) نعمتوں والی جنت میں ہوں گے،\qt@no{22}}%
\qt@newcmd\qurantrans@ur@mmmmmdccclxxi{تختوں پر بیٹھے نظارے کر رہے ہوں گے،\qt@no{23}}%
\qt@newcmd\qurantrans@ur@mmmmmdccclxxii{آپ ان کے چہروں سے ہی نعمت و راحت کی رونق اور شگفتگی معلوم کر لیں گے،\qt@no{24}}%
\qt@newcmd\qurantrans@ur@mmmmmdccclxxiii{انہیں سر بہ مہر بڑی لذیذ شرابِ طہور پلائی جائے گی،\qt@no{25}}%
\qt@newcmd\qurantrans@ur@mmmmmdccclxxiv{اس کی مُہر کستوری کی ہوگی، اور (یہی وہ شراب ہے) جس کے حصول میں شائقین کو جلد کوشش کر کے سبقت لینی چاہیے (کوئی شرابِ نعمت کا طالب و شائق ہے، کوئی شرابِ قربت کا اور کوئی شرابِ دیدار کا۔ ہر کسی کو اس کے شوق کے مطابق پلائی جائے گی)،\qt@no{26}}%
\qt@newcmd\qurantrans@ur@mmmmmdccclxxv{اور اس (شراب) میں آبِ تسنیم کی آمیزش ہوگی،\qt@no{27}}%
\qt@newcmd\qurantrans@ur@mmmmmdccclxxvi{یہ تسنیم) ایک چشمہ ہے جہاں سے صرف اہلِ قربت پیتے ہیں،\qt@no{28}}%
\qt@newcmd\qurantrans@ur@mmmmmdccclxxvii{بیشک مجرم لوگ ایمان والوں کا (دنیا میں) مذاق اڑایا کرتے تھے،\qt@no{29}}%
\qt@newcmd\qurantrans@ur@mmmmmdccclxxviii{اور جب ان کے پاس سے گزرتے تو آپس میں آنکھوں سے اشارہ بازی کرتے تھے،\qt@no{30}}%
\qt@newcmd\qurantrans@ur@mmmmmdccclxxix{اور جب اپنے گھر والوں کی طرف لوٹتے تو (مومنوں کی تنگ دستی اور اپنی خوش حالی کا موازنہ کر کے) اِتراتے اور دل لگی کرتے ہوئے پلٹتے تھے،\qt@no{31}}%
\qt@newcmd\qurantrans@ur@mmmmmdccclxxx{اور جب یہ (مغرور لوگ) ان (کمزور حال مومنوں) کو دیکھتے تو کہتے: یقیناً یہ لوگ راہ سے بھٹک گئے ہیں (یعنی یہ دنیا گنوا بیٹھے ہیں اور آخرت تو ہے ہی فقط افسانہ)،\qt@no{32}}%
\qt@newcmd\qurantrans@ur@mmmmmdccclxxxi{حالانکہ وہ ان (کے حال) پر نگہبان بنا کر نہیں بھیجے گئے تھے،\qt@no{33}}%
\qt@newcmd\qurantrans@ur@mmmmmdccclxxxii{پس آج (دیکھو) اہلِ ایمان کافروں پر ہنس رہے ہیں،\qt@no{34}}%
\qt@newcmd\qurantrans@ur@mmmmmdccclxxxiii{سجے ہوئے تختوں پر بیٹھے (اپنی خوش حالی اور کافروں کی بدحالی کا) نظارہ کر رہے ہیں،\qt@no{35}}%
\qt@newcmd\qurantrans@ur@mmmmmdccclxxxiv{سو کیا کافروں کو اس (مذاق) کا پورا بدلہ دے دیا گیا جو وہ (مسلمانوں سے) کیا کرتے تھے،\qt@no{36}}%
\qt@newcmd\qurantrans@ur@mmmmmdccclxxxv{\basmalahur جب (سب) آسمانی کرّے پھٹ جائیں گے،\qt@no{1}}%
\qt@newcmd\qurantrans@ur@mmmmmdccclxxxvi{اور اپنے رب کا حکمِ (اِنشقاق) بجا لائیں گے اور (یہی تعمیلِ اَمر) اُس کے لائق ہے،\qt@no{2}}%
\qt@newcmd\qurantrans@ur@mmmmmdccclxxxvii{اور جب زمین (ریزہ ریزہ کر کے) پھیلا دی جائے گی،\qt@no{3}}%
\qt@newcmd\qurantrans@ur@mmmmmdccclxxxviii{اور جو کچھ اس کے اندر ہے وہ اسے نکال باہر پھینکے گی اور خالی ہو جائے گی،\qt@no{4}}%
\qt@newcmd\qurantrans@ur@mmmmmdccclxxxix{اور (وہ بھی) اپنے رب کا حکمِ (اِنشقاق) بجا لائے گی اور (یہی اِطاعت) اُس کے لائق ہے،\qt@no{5}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxc{اے انسان! تو اپنے رب تک پہنچنے میں سخت مشقتیں برداشت کرتا ہے بالآخر تجھے اسی سے جا ملنا ہے،\qt@no{6}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxci{پس جس شخص کا نامۂ اعمال اس کے داہنے ہاتھ میں دیا جائے گا،\qt@no{7}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxcii{تو عنقریب اس سے آسان سا حساب لیا جائے گا،\qt@no{8}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxciii{اور وہ اپنے اہلِ خانہ کی طرف مسرور و شاداں پلٹے گا،\qt@no{9}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxciv{اور البتہ وہ شخص جس کا نامۂ اعمال اس کی پیٹھ کے پیچھے سے دیا جائے گا،\qt@no{10}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxcv{تو وہ عنقریب موت کو پکارے گا،\qt@no{11}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxcvi{اور وہ دوزخ کی بھڑکتی ہوئی آگ میں داخل ہوگا،\qt@no{12}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxcvii{بیشک وہ (دنیا میں) اپنے اہلِ خانہ میں خوش و خرم رہتا تھا،\qt@no{13}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxcviii{بیشک اس نے یہ گمان کر لیا تھا کہ وہ حساب کے لئے (اللہ کے پاس) ہرگز لوٹ کر نہ جائے گا،\qt@no{14}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxcix{کیوں نہیں! بیشک اس کا رب اس کو خوب دیکھنے والا ہے،\qt@no{15}}%
\qt@newcmd\qurantrans@ur@mmmmmcm{سو مجھے قَسم ہے شفق (یعنی شام کی سرخی یا اس کے بعد کے اُجالے) کی،\qt@no{16}}%
\qt@newcmd\qurantrans@ur@mmmmmcmi{اور رات کی اور ان چیزوں کی جنہیں وہ (اپنے دامن میں) سمیٹ لیتی ہے،\qt@no{17}}%
\qt@newcmd\qurantrans@ur@mmmmmcmii{اور چاند کی جب وہ پورا دکھائی دیتا ہے،\qt@no{18}}%
\qt@newcmd\qurantrans@ur@mmmmmcmiii{تم یقیناً طبق در طبق ضرور سواری کرتے ہوئے جاؤ گے،\qt@no{19}}%
\qt@newcmd\qurantrans@ur@mmmmmcmiv{تو انہیں کیا ہو گیا ہے کہ (قرآنی پیشین گوئی کی صداقت دیکھ کر بھی) ایمان نہیں لاتے،\qt@no{20}}%
\qt@newcmd\qurantrans@ur@mmmmmcmv{اور جب ان پر قرآن پڑھا جاتا ہے تو (اللہ کے حضور) سجدہ ریز نہیں ہوتے،\qt@no{21}}%
\qt@newcmd\qurantrans@ur@mmmmmcmvi{بلکہ کافر لوگ (اسے مزید) جھٹلا رہے ہیں،\qt@no{22}}%
\qt@newcmd\qurantrans@ur@mmmmmcmvii{اور اللہ (کفر و عداوت کے اس سامان کو) خوب جانتا ہے جو وہ جمع کر رہے ہیں،\qt@no{23}}%
\qt@newcmd\qurantrans@ur@mmmmmcmviii{سو آپ انہیں دردناک عذاب کی بشارت دے دیں،\qt@no{24}}%
\qt@newcmd\qurantrans@ur@mmmmmcmix{مگر جو لوگ ایمان لائے اور نیک عمل کرتے ہیں ان کے لئے غیر منقطع (دائمی) ثواب ہے،\qt@no{25}}%
\qt@newcmd\qurantrans@ur@mmmmmcmx{\basmalahur برجوں (یعنی کہکشاؤں) والے آسمان کی قَسم،\qt@no{1}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxi{اور اس دن کی قَسم جس کا وعدہ کیا گیا ہے،\qt@no{2}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxii{جو (اس دن) حاضر ہوگا اس کی قَسم اور جو کچھ حاضر کیا جائے گا اس کی قَسم،\qt@no{3}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxiii{خندقوں والے (لوگ) ہلاک کر دیے گئے،\qt@no{4}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxiv{یعنی) اس بھڑکتی آگ (والے) جو بڑے ایندھن سے (جلائی گئی) تھی،\qt@no{5}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxv{جب وہ اس کے کناروں پر بیٹھے تھے،\qt@no{6}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxvi{اور وہ خود گواہ ہیں جو کچھ وہ اہلِ ایمان کے ساتھ کر رہے تھے (یعنی انہیں آگ میں پھینک پھینک کر جلا رہے تھے)،\qt@no{7}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxvii{اور انہیں ان (مومنوں) کی طرف سے اور کچھ (بھی) ناگوار نہ تھا سوائے اس کے کہ وہ اللہ پر ایمان لے آئے تھے جو غالب (اور) لائقِ حمد و ثنا ہے،\qt@no{8}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxviii{جس کے لئے آسمانوں اور زمین کی (ساری) بادشاہت ہے، اور اللہ ہر چیز پر گواہ ہے،\qt@no{9}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxix{بیشک جن لوگوں نے مومن مردوں اور مومن عورتوں کو اذیت دی پھر توبہ (بھی) نہ کی تو ان کے لئے عذابِ جہنم ہے اور ان کے لئے (بالخصوص) آگ میں جلنے کا عذاب ہے،\qt@no{10}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxx{بیشک جو لوگ ایمان لائے اور نیک عمل کرتے رہے ان کے لئے جنتیں ہیں جن کے نیچے سے نہریں جاری ہیں، یہی بڑی کامیابی ہے،\qt@no{11}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxxi{بیشک آپ کے رب کی پکڑ بہت سخت ہے،\qt@no{12}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxxii{بیشک وہی پہلی بار پیدا فرماتا ہے اور وہی دوبارہ پیدا فرمائے گا،\qt@no{13}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxxiii{اور وہ بڑا بخشنے والا بہت محبت فرمانے والا ہے،\qt@no{14}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxxiv{مالکِ عرش (یعنی پوری کائنات کے تختِ اقتدار کا مالک) بڑی شان والا ہے،\qt@no{15}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxxv{وہ جو بھی ارادہ فرماتا ہے (اسے) خوب کر دینے والا ہے،\qt@no{16}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxxvi{کیا آپ کے پاس لشکروں کی خبر پہنچی ہے،\qt@no{17}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxxvii{فرعون اور ثمود (کے لشکروں) کے،\qt@no{18}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxxviii{بلکہ ایسے کافر (ہمیشہ حق کو) جھٹلانے میں (ہی کوشاں رہتے) ہیں،\qt@no{19}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxxix{اور اللہ اُن کے گرد و پیش سے (انہیں) گھیرے ہوئے ہے،\qt@no{20}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxxx{بلکہ یہ بڑی عظمت والا قرآن ہے،\qt@no{21}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxxxi{جو) لوحِ محفوظ میں (لکھا ہوا) ہے،\qt@no{22}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxxxii{\basmalahur آسمان (کی فضائے بسیط اور خلائے عظیم) کی قَسم اور رات کو (نظر) آنے والے کی قَسم،\qt@no{1}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxxxiii{اور آپ کو کیا معلوم کہ رات کو (نظر) آنے والا کیا ہے،\qt@no{2}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxxxiv{اس سے مراد) ہر وہ آسمانی کرّہ ہے (خواہ وہ ستارہ ہو یا سیارہ یا اَجرامِ سماوی کا کوئی اور کرّہ) جو چمک کر (فضا کو) روشن کر دیتا ہے٭، ٭ النجم الثاقب سے مراد ذاتِ محمد مصطفی صلی اللہ علیہ وآلہ وسلم بھی ہے، جس نے سراجاً منیراً کی شان کے ساتھ آسمانِ رسالت پر چمک کر ظلمت بھری کائنات کو نورِ ایمان سے روشن کر دیا ہے۔ (الشفاء)\qt@no{3}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxxxv{کوئی شخص ایسا نہیں جس پر ایک نگہبان (مقرر) نہیں ہے،\qt@no{4}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxxxvi{پس انسان کو غور (و تحقیق) کرنا چاہیے کہ وہ کس چیز سے پیدا کیا گیا ہے،\qt@no{5}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxxxvii{وہ قوت سے اچھلنے والے پانی (یعنی قوی اور متحرک مادۂ تولید) میں سے پیدا کیا گیا ہے،\qt@no{6}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxxxviii{جو پیٹھ اور کولہے کی ہڈیوں کے درمیان (پیڑو کے حلقہ میں) سے گزر کر باہر نکلتا ہے،\qt@no{7}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxxxix{بیشک وہ اس (زندگی) کو پھر واپس لانے پر بھی قادر ہے،\qt@no{8}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxl{جس دن سب راز ظاہر کر دیے جائیں گے،\qt@no{9}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxli{پھر انسان کے پاس نہ (خود) کوئی قوت ہوگی اور نہ کوئی (اس کا) مددگار ہوگا،\qt@no{10}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxlii{اس آسمانی کائنات کی قَسم جو پھر اپنی ابتدائی حالت میں پلٹ جانے والی ہے،\qt@no{11}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxliii{اس زمین کی قَسم جو پھٹ (کر ریزہ ریزہ ہو) جانے والی ہے،\qt@no{12}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxliv{بیشک یہ فیصلہ کن (قطعی) فرمان ہے،\qt@no{13}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxlv{اور یہ ہنسی کی بات نہیں ہے،\qt@no{14}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxlvi{بیشک وہ (کافر) پُر فریب تدبیروں میں لگے ہوئے ہیں،\qt@no{15}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxlvii{اور میں اپنی تدبیر فرما رہا ہوں،\qt@no{16}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxlviii{پس آپ کافروں کو (ذرا) مہلت دے دیجئے، (زیادہ نہیں بس) انہیں تھوڑی سی ڈھیل (اور) دے دیجئے،\qt@no{17}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxlix{\basmalahur اپنے رب کے نام کی تسبیح کریں جو سب سے بلند ہے،\qt@no{1}}%
\qt@newcmd\qurantrans@ur@mmmmmcml{جس نے (کائنات کی ہر چیز کو) پیدا کیا پھر اسے (جملہ تقاضوں کی تکمیل کے ساتھ) درست توازن دیا،\qt@no{2}}%
\qt@newcmd\qurantrans@ur@mmmmmcmli{اور جس نے (ہر ہر چیز کے لئے) قانون مقرر کیا پھر (اسے اپنے اپنے نظام کے مطابق رہنے اور چلنے کا) راستہ بتایا،\qt@no{3}}%
\qt@newcmd\qurantrans@ur@mmmmmcmlii{اور جس نے (زمین سے) چارہ نکالا،\qt@no{4}}%
\qt@newcmd\qurantrans@ur@mmmmmcmliii{پھر اسے سیاہی مائل خشک کردیا،\qt@no{5}}%
\qt@newcmd\qurantrans@ur@mmmmmcmliv{اے حبیبِ مکرّم!) ہم آپ کو خود (ایسا) پڑھائیں گے کہ آپ (کبھی) نہیں بھولیں گے،\qt@no{6}}%
\qt@newcmd\qurantrans@ur@mmmmmcmlv{مگر جو اﷲ چاہے، بیشک وہ جہر اور خفی (یعنی ظاہر و پوشیدہ اور بلند و آہستہ) سب باتوں کو جانتا ہے،\qt@no{7}}%
\qt@newcmd\qurantrans@ur@mmmmmcmlvi{اور ہم آپ کو اس آسان (شریعت پر عمل پیرا ہونے) کے لئے (بھی) سہولت فراہم فرمائیں گے،\qt@no{8}}%
\qt@newcmd\qurantrans@ur@mmmmmcmlvii{پس آپ نصیحت فرماتے رہیے بشرطیکہ نصیحت (سننے والوں کو) فائدہ دے،\qt@no{9}}%
\qt@newcmd\qurantrans@ur@mmmmmcmlviii{البتہ وہی نصیحت قبول کرے گا جو اﷲ سے ڈرتا ہوگا،\qt@no{10}}%
\qt@newcmd\qurantrans@ur@mmmmmcmlix{اور بدبخت اس (نصیحت) سے پہلو تہی کرے گا،\qt@no{11}}%
\qt@newcmd\qurantrans@ur@mmmmmcmlx{جو (قیامت کے دن) سب سے بڑی آگ میں داخل ہوگا،\qt@no{12}}%
\qt@newcmd\qurantrans@ur@mmmmmcmlxi{پھر وہ اس میں نہ مرے گا اور نہ جیئے گا،\qt@no{13}}%
\qt@newcmd\qurantrans@ur@mmmmmcmlxii{بیشک وہی بامراد ہوا جو (نفس کی آفتوں اور گناہ کی آلودگیوں سے) پاک ہوگیا،\qt@no{14}}%
\qt@newcmd\qurantrans@ur@mmmmmcmlxiii{اور وہ اپنے رب کے نام کا ذکر کرتا رہا اور (کثرت و پابندی سے) نماز پڑھتا رہا،\qt@no{15}}%
\qt@newcmd\qurantrans@ur@mmmmmcmlxiv{بلکہ تم (اﷲ کی طرف رجوع کرنے کی بجائے) دنیاوی زندگی (کی لذتوں) کو اختیار کرتے ہو،\qt@no{16}}%
\qt@newcmd\qurantrans@ur@mmmmmcmlxv{حالانکہ آخرت (کی لذت و راحت) بہتر اور ہمیشہ باقی رہنے والی ہے،\qt@no{17}}%
\qt@newcmd\qurantrans@ur@mmmmmcmlxvi{بیشک یہ (تعلیم) اگلے صحیفوں میں (بھی مذکور) ہے،\qt@no{18}}%
\qt@newcmd\qurantrans@ur@mmmmmcmlxvii{جو) ابراہیم اور موسٰی (علیہما السلام) کے صحائف ہیں،\qt@no{19}}%
\qt@newcmd\qurantrans@ur@mmmmmcmlxviii{\basmalahur کیا آپ کو (ہر چیز پر) چھا جانے والی قیامت کی خبر پہنچی ہے،\qt@no{1}}%
\qt@newcmd\qurantrans@ur@mmmmmcmlxix{اس دن کتنے ہی چہرے ذلیل و خوار ہوں گے،\qt@no{2}}%
\qt@newcmd\qurantrans@ur@mmmmmcmlxx{اﷲ کو بھول کر دنیاوی) محنت کرنے والے (چند روزہ عیش و آرام کی خاطر سخت) مشقتیں جھیلنے والے،\qt@no{3}}%
\qt@newcmd\qurantrans@ur@mmmmmcmlxxi{دہکتی ہوئی آگ میں جا گریں گے،\qt@no{4}}%
\qt@newcmd\qurantrans@ur@mmmmmcmlxxii{انہیں) کھولتے ہوئے چشمہ سے (پانے) پلایا جائے گا،\qt@no{5}}%
\qt@newcmd\qurantrans@ur@mmmmmcmlxxiii{ان کے لئے خاردار خشک زہریلی جھاڑیوں کے سوا کچھ کھانا نہ ہوگا،\qt@no{6}}%
\qt@newcmd\qurantrans@ur@mmmmmcmlxxiv{یہ کھانا) نہ فربہ کرے گا اور نہ بھوک ہی دور کرے گا،\qt@no{7}}%
\qt@newcmd\qurantrans@ur@mmmmmcmlxxv{اس کے برعکس) اس دن بہت سے چہرے (حسین) بارونق اور ترو تازہ ہوں گے،\qt@no{8}}%
\qt@newcmd\qurantrans@ur@mmmmmcmlxxvi{اپنی (نیک) کاوشوں کے باعث خوش و خرم ہوں گے،\qt@no{9}}%
\qt@newcmd\qurantrans@ur@mmmmmcmlxxvii{عالی شان جنت میں (قیام پذیر) ہوں گے،\qt@no{10}}%
\qt@newcmd\qurantrans@ur@mmmmmcmlxxviii{اس میں کوئی لغو بات نہ سنیں گے (جیسے اہلِ باطل ان سے دنیا میں کیا کرتے تھے)،\qt@no{11}}%
\qt@newcmd\qurantrans@ur@mmmmmcmlxxix{اس میں بہتے ہوئے چشمے ہوں گے،\qt@no{12}}%
\qt@newcmd\qurantrans@ur@mmmmmcmlxxx{اس میں اونچے (بچھے ہوئے) تخت ہوں گے،\qt@no{13}}%
\qt@newcmd\qurantrans@ur@mmmmmcmlxxxi{اور جام (بڑے قرینے سے) رکھے ہوئے ہوں گے،\qt@no{14}}%
\qt@newcmd\qurantrans@ur@mmmmmcmlxxxii{اور غالیچے اور گاؤ تکیے قطار در قطار لگے ہوں گے،\qt@no{15}}%
\qt@newcmd\qurantrans@ur@mmmmmcmlxxxiii{اور نرم و نفیس قالین اور مَسندیں بچھی ہوں گی،\qt@no{16}}%
\qt@newcmd\qurantrans@ur@mmmmmcmlxxxiv{منکرین تعجب کرتے ہیں کہ جنت میں یہ سب کچھ کیسے بن جائے گا! تو) کیا یہ لوگ اونٹ کی طرف نہیں دیکھتے کہ وہ کس طرح (عجیب ساخت پر) بنایا گیا ہے،\qt@no{17}}%
\qt@newcmd\qurantrans@ur@mmmmmcmlxxxv{اور آسمان کی طرف (نگاہ نہیں کرتے) کہ وہ کیسے (عظیم وسعتوں کے ساتھ) اٹھایا گیا ہے،\qt@no{18}}%
\qt@newcmd\qurantrans@ur@mmmmmcmlxxxvi{اور پہاڑوں کو (نہیں دیکھتے) کہ وہ کس طرح (زمین سے ابھار کر) کھڑے کئے گئے ہیں،\qt@no{19}}%
\qt@newcmd\qurantrans@ur@mmmmmcmlxxxvii{اور زمین کو (نہیں دیکھتے) کہ وہ کس طرح (گولائی کے باوجود) بچھائی گئی ہے،\qt@no{20}}%
\qt@newcmd\qurantrans@ur@mmmmmcmlxxxviii{پس آپ نصیحت فرماتے رہئے، آپ تو نصیحت ہی فرمانے والے ہیں،\qt@no{21}}%
\qt@newcmd\qurantrans@ur@mmmmmcmlxxxix{آپ ان پر جابر و قاہر (کے طور پر) مسلط نہیں ہیں،\qt@no{22}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxc{مگر جو رُوگردانی کرے اور کفر کرے،\qt@no{23}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxci{تو اسے اﷲ سب سے بڑا عذاب دے گا،\qt@no{24}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxcii{بیشک (بالآخر) ہماری ہی طرف ان کا پلٹنا ہے،\qt@no{25}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxciii{پھر یقیناً ہمارے ہی ذمہ ان کا حساب (لینا) ہے،\qt@no{26}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxciv{\basmalahur اس صبح کی قَسم (جس سے ظلمتِ شب چھٹ گئی)٭، ٭ مراد ہر روز کی صبح یا نمازِ فجر ہے یا بطورِ خاص ماہ ذی الحجہ کی پہلی صبح یا یکم محرم کی صبح ہے یا عید الاضحٰی کی صبح۔ اس سے مراد سیدنا محمد مصطفی صلی اللہ علیہ وآلہ وسلم کی ذاتِ گرامی بھی ہے جن کی بعثت سے شبِ ظلمت کا خاتمہ ہوا اور صبحِ ایمان پھوٹی۔\qt@no{1}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxcv{اور دس (مبارک) راتوں کی قَسم٭، ٭ مراد ماہِ رمضان کے آخری عشرہ کی راتیں یا پہلے عشرۂ محرّم کی راتیں ہیں یا اوّل عشرۂ ذی الحجہ کی راتیں ہیں جو برکات و درجات سے معمور ہیں۔\qt@no{2}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxcvi{اور جفت کی قَسم اور طاق کی قَسم٭، ٭ جفت (جوڑا) سے مراد کل مخلوق ہے جو جوڑوں کی صورت میں پیدا کی گئی ہے، اور طاق (فرد و تنہا) سے مراد خالق ہے جو وحدہ لا شریک ہے۔ یا شَفع یومِ نحر (قربانی) اور وَتر یومِ عرفہ (حج) ہے، یا شَفع سے مراد دنیا کے شب و روز ہیں اور وَتر سے مراد یومِ قیامت ہے جس کی کوئی شب نہ ہوگی۔ یا شَفع سے مراد سال بھر کی عام جفت راتیں ہیں اور وَتر سے مراد سال بھر کی برکت والی طاق راتیں ہیں، مثلاً شبِ معراج، شبِ برات اور شبِ قدر وغیرہ جو پے در پے رجب، شعبان اور رمضان میں آتی ہیں۔ یا شَفع سے مراد حضرت آدم علیہ السلام اور حضرت حواء علیہا السلام کا پہلا جوڑا ہے اور وَتر سے مراد تنہا حضرت آدم علیہ السلام، جن سے تخلیقِ انسانیت کی ابتداء ہوئی۔\qt@no{3}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxcvii{اور رات کی قسم جب گزر چلے (مراد ہر شب ہے یا بطورِ خاص شبِ مزدلفہ یا شبِ قدر)،\qt@no{4}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxcviii{بیشک ان میں عقل مند کے لئے بڑی قسم ہے،\qt@no{5}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxcix{کیا آپ نے نہیں دیکھا کہ آپ کے رب نے (قومِ) عاد کے ساتھ کیسا (سلوک) کیا؟،\qt@no{6}}%
\qt@newcmd\qurantrans@ur@mmmmmm{جو اہلِ) اِرم تھے (اور) بڑے بڑے ستونوں (کی طرح دراز قد اور اونچے محلات) والے تھے،\qt@no{7}}%
\qt@newcmd\qurantrans@ur@mmmmmmi{جن کا مثل (دنیا کے) ملکوں میں (کوئی بھی) پیدا نہیں کیا گیا،\qt@no{8}}%
\qt@newcmd\qurantrans@ur@mmmmmmii{اور ثمود (کے ساتھ کیا سلوک ہوا) جنہوں نے وادئ (قری) میں چٹانوں کو کاٹ (کر پتھروں سے سینکڑوں شہروں کو تعمیر کر) ڈالا تھا،\qt@no{9}}%
\qt@newcmd\qurantrans@ur@mmmmmmiii{اور فرعون (کا کیا حشر ہوا) جو بڑے لشکروں والا (یا لوگوں کو میخوں سے سزا دینے والا) تھا،\qt@no{10}}%
\qt@newcmd\qurantrans@ur@mmmmmmiv{یہ) وہ لوگ (تھے) جنہوں نے (اپنے اپنے) ملکوں میں سرکشی کی تھی،\qt@no{11}}%
\qt@newcmd\qurantrans@ur@mmmmmmv{پھر ان میں بڑی فساد انگیزی کی تھی،\qt@no{12}}%
\qt@newcmd\qurantrans@ur@mmmmmmvi{تو آپ کے رب نے ان پر عذاب کا کوڑا برسایا،\qt@no{13}}%
\qt@newcmd\qurantrans@ur@mmmmmmvii{بیشک آپ کا رب (سرکشوں اور نافرمانوں کی) خوب تاک میں ہے،\qt@no{14}}%
\qt@newcmd\qurantrans@ur@mmmmmmviii{مگر انسان (ایسا ہے) کہ جب اس کا رب اسے (راحت و آسائش دے کر) آزماتا ہے اور اسے عزت سے نوازتا ہے اور اسے نعمتیں بخشتا ہے تو وہ کہتا ہے: میرے رب نے مجھ پر کرم فرمایا،\qt@no{15}}%
\qt@newcmd\qurantrans@ur@mmmmmmix{لیکن جب وہ اسے (تکلیف و مصیبت دے کر) آزماتا ہے اور اس پر اس کا رزق تنگ کرتا ہے تو وہ کہتا ہے: میرے رب نے مجھے ذلیل کر دیا،\qt@no{16}}%
\qt@newcmd\qurantrans@ur@mmmmmmx{یہ بات نہیں بلکہ (حقیقت یہ ہے کہ عزت اور مال و دولت کے ملنے پر) تم یتیموں کی قدر و اِکرام نہیں کرتے،\qt@no{17}}%
\qt@newcmd\qurantrans@ur@mmmmmmxi{اور نہ ہی تم مسکینوں (یعنی غریبوں اور محتاجوں) کو کھانا کھلانے کی (معاشرے میں) ایک دوسرے کو ترغیب دیتے ہو،\qt@no{18}}%
\qt@newcmd\qurantrans@ur@mmmmmmxii{اور وراثت کا سارا مال سمیٹ کر (خود ہی) کھا جاتے ہو (اس میں سے افلاس زدہ لوگوں کا حق نہیں نکالتے)،\qt@no{19}}%
\qt@newcmd\qurantrans@ur@mmmmmmxiii{اور تم مال و دولت سے حد درجہ محبت رکھتے ہو،\qt@no{20}}%
\qt@newcmd\qurantrans@ur@mmmmmmxiv{یقیناً جب زمین پاش پاش کر کے ریزہ ریزہ کر دی جائے گی،\qt@no{21}}%
\qt@newcmd\qurantrans@ur@mmmmmmxv{اور آپ کا رب جلوہ فرما ہوگا اور فرشتے قطار در قطار (اس کے حضور) حاضر ہوں گے،\qt@no{22}}%
\qt@newcmd\qurantrans@ur@mmmmmmxvi{اور اس دن دوزخ پیش کی جائے گی، اس دن انسان کو سمجھ آجائے گی مگر (اب) اسے نصیحت کہاں (فائدہ مند) ہوگی،\qt@no{23}}%
\qt@newcmd\qurantrans@ur@mmmmmmxvii{وہ کہے گا: اے کاش! میں نے اپنی (اس اصل) زندگی کے لئے (کچھ) آگے بھیج دیا ہوتا (جو آج میرے کام آتا)،\qt@no{24}}%
\qt@newcmd\qurantrans@ur@mmmmmmxviii{سو اس دن نہ اس کے عذاب کی طرح کوئی عذاب دے سکے گا،\qt@no{25}}%
\qt@newcmd\qurantrans@ur@mmmmmmxix{اور نہ اس کے جکڑنے کی طرح کوئی جکڑ سکے گا،\qt@no{26}}%
\qt@newcmd\qurantrans@ur@mmmmmmxx{اے اطمینان پا جانے والے نفس،\qt@no{27}}%
\qt@newcmd\qurantrans@ur@mmmmmmxxi{تو اپنے رب کی طرف اس حال میں لوٹ آکہ تو اس کی رضا کا طالب بھی ہو اور اس کی رضا کا مطلوب بھی (گویا اس کی رضا تیری مطلوب ہو اور تیری رضا اس کی مطلوب)،\qt@no{28}}%
\qt@newcmd\qurantrans@ur@mmmmmmxxii{پس تو میرے (کامل) بندوں میں شامل ہو جا،\qt@no{29}}%
\qt@newcmd\qurantrans@ur@mmmmmmxxiii{اور میری جنتِ (قربت و دیدار) میں داخل ہو جا،\qt@no{30}}%
\qt@newcmd\qurantrans@ur@mmmmmmxxiv{\basmalahur میں اس شہر (مکہ) کی قَسم کھاتا ہوں،\qt@no{1}}%
\qt@newcmd\qurantrans@ur@mmmmmmxxv{اے حبیبِ مکرّم!) اس لئے کہ آپ اس شہر میں تشریف فرما ہیں٭، ٭ یہ ترجمہ ”لا زائدہ“ کے اعتبار سے ہے۔ لا ”نفئ صحیح“ کے لئے ہو تو ترجمہ یوں ہوگا: میں (اس وقت) اس شہر کی قَسم نہیں کھاؤں گا (اے حبیب!) جب آپ اس شہر سے رخصت ہو جائیں گے۔\qt@no{2}}%
\qt@newcmd\qurantrans@ur@mmmmmmxxvi{اے حبیبِ مکرّم! آپ کے) والد (آدم یا ابراہیم علیہما السلام) کی قَسم اور (ان کی) قَسم جن کی ولادت ہوئی٭، ٭ یعنی آدم علیہ السلام کی ذریّتِ صالحہ یا آپ ہی کی ذات گرامی جن کے باعث یہ شہرِ مکہ بھی لائقِ قَسم ٹھہرا ہے۔\qt@no{3}}%
\qt@newcmd\qurantrans@ur@mmmmmmxxvii{بیشک ہم نے انسان کو مشقت میں (مبتلا رہنے والا) پیدا کیا ہے،\qt@no{4}}%
\qt@newcmd\qurantrans@ur@mmmmmmxxviii{کیا وہ یہ گمان کرتا ہے کہ اس پر ہرگز کوئی بھی قابو نہ پا سکے گا؟،\qt@no{5}}%
\qt@newcmd\qurantrans@ur@mmmmmmxxix{وہ (بڑے فخر سے) کہتا ہے کہ میں نے ڈھیروں مال خرچ کیا ہے،\qt@no{6}}%
\qt@newcmd\qurantrans@ur@mmmmmmxxx{کیا وہ یہ خیال کرتا ہے کہ اسے (یہ فضول خرچیاں کرتے ہوئے) کسی نے نہیں دیکھا،\qt@no{7}}%
\qt@newcmd\qurantrans@ur@mmmmmmxxxi{کیا ہم نے اس کے لئے دو آنکھیں نہیں بنائیں،\qt@no{8}}%
\qt@newcmd\qurantrans@ur@mmmmmmxxxii{اور (اسے) ایک زبان اور دو ہونٹ (نہیں دئیے)،\qt@no{9}}%
\qt@newcmd\qurantrans@ur@mmmmmmxxxiii{اور ہم نے اسے (خیر و شر کے) دو نمایاں راستے (بھی) دکھا دیئے،\qt@no{10}}%
\qt@newcmd\qurantrans@ur@mmmmmmxxxiv{وہ تو (دینِ حق اور عملِ خیر کی) دشوار گزار گھاٹی میں داخل ہی نہیں ہوا،\qt@no{11}}%
\qt@newcmd\qurantrans@ur@mmmmmmxxxv{اور آپ کیا سمجھے ہیں کہ وہ (دینِ حق کے مجاہدہ کی) گھاٹی کیا ہے،\qt@no{12}}%
\qt@newcmd\qurantrans@ur@mmmmmmxxxvi{وہ (غلامی و محکومی کی زندگی سے) کسی گردن کا آزاد کرانا ہے،\qt@no{13}}%
\qt@newcmd\qurantrans@ur@mmmmmmxxxvii{یا بھوک والے دن (یعنی قحط و اَفلاس کے دور میں غریبوں اور محروم المعیشت لوگوں کو) کھانا کھلانا ہے (یعنی ان کے معاشی تعطل اور ابتلاء کو ختم کرنے کی جدّ و جہد کرنا ہے)،\qt@no{14}}%
\qt@newcmd\qurantrans@ur@mmmmmmxxxviii{قرابت دار یتیم کو،\qt@no{15}}%
\qt@newcmd\qurantrans@ur@mmmmmmxxxix{یا شدید غربت کے مارے ہوئے محتاج کو جو محض خاک نشین (اور بے گھر) ہے،\qt@no{16}}%
\qt@newcmd\qurantrans@ur@mmmmmmxl{پھر (شرط یہ ہے کہ ایسی جدّ و جہد کرنے والا) وہ شخص ان لوگوں میں سے ہو جو ایمان لائے ہیں اور ایک دوسرے کو صبر و تحمل کی نصیحت کرتے ہیں اور باہم رحمت و شفقت کی تاکید کرتے ہیں،\qt@no{17}}%
\qt@newcmd\qurantrans@ur@mmmmmmxli{یہی لوگ دائیں طرف والے (یعنی اہلِ سعادت و مغفرت) ہیں،\qt@no{18}}%
\qt@newcmd\qurantrans@ur@mmmmmmxlii{اور جن لوگوں نے ہماری آیتوں کا انکار کیا وہ بائیں طرف والے ہیں (یعنی اہلِ شقاوت و عذاب) ہیں،\qt@no{19}}%
\qt@newcmd\qurantrans@ur@mmmmmmxliii{ان پر (ہر طرف سے) بند کی ہوئی آگ (چھائی) ہوگی،\qt@no{20}}%
\qt@newcmd\qurantrans@ur@mmmmmmxliv{\basmalahur سورج کی قَسم اور اس کی روشنی کی قَسم،\qt@no{1}}%
\qt@newcmd\qurantrans@ur@mmmmmmxlv{اور چاند کی قَسم جب وہ سورج کی پیروی کرے (یعنی اس کی روشنی سے چمکے)،\qt@no{2}}%
\qt@newcmd\qurantrans@ur@mmmmmmxlvi{اور دن کی قَسم جب وہ سورج کو ظاہر کرے (یعنی اسے روشن دکھائے)،\qt@no{3}}%
\qt@newcmd\qurantrans@ur@mmmmmmxlvii{اور رات کی قَسم جب وہ سورج کو (زمین کی ایک سمت سے) ڈھانپ لے،\qt@no{4}}%
\qt@newcmd\qurantrans@ur@mmmmmmxlviii{اور آسمان کی قَسم اور اس (قوت) کی قَسم جس نے اسے (اذنِ الٰہی سے ایک وسیع کائنات کی شکل میں) تعمیر کیا،\qt@no{5}}%
\qt@newcmd\qurantrans@ur@mmmmmmxlix{اور زمین کی قَسم اور اس (قوت) کی قَسم جو اسے (امرِ الٰہی سے سورج سے کھینچ دور) لے گئی،\qt@no{6}}%
\qt@newcmd\qurantrans@ur@mmmmmml{اور انسانی جان کی قَسم اور اسے ہمہ پہلو توازن و درستگی دینے والے کی قَسم،\qt@no{7}}%
\qt@newcmd\qurantrans@ur@mmmmmmli{پھر اس نے اسے اس کی بدکاری اور پرہیزگاری (کی تمیز) سمجھا دی،\qt@no{8}}%
\qt@newcmd\qurantrans@ur@mmmmmmlii{بیشک وہ شخص فلاح پا گیا جس نے اس (نفس) کو (رذائل سے) پاک کر لیا (اور اس میں نیکی کی نشو و نما کی)،\qt@no{9}}%
\qt@newcmd\qurantrans@ur@mmmmmmliii{اور بیشک وہ شخص نامراد ہوگیا جس نے اسے (گناہوں میں) ملوث کر لیا (اور نیکی کو دبا دیا)،\qt@no{10}}%
\qt@newcmd\qurantrans@ur@mmmmmmliv{ثمود نے اپنی سرکشی کے باعث (اپنے پیغمبر صالح علیہ السلام کو) جھٹلایا،\qt@no{11}}%
\qt@newcmd\qurantrans@ur@mmmmmmlv{جبکہ ان میں سے ایک بڑا بد بخت اٹھا،\qt@no{12}}%
\qt@newcmd\qurantrans@ur@mmmmmmlvi{ان سے اﷲ کے رسول نے فرمایا: اﷲ کی (اس) اونٹنی اور اس کو پانی پلانے (کے دن) کی حفاظت کرنا،\qt@no{13}}%
\qt@newcmd\qurantrans@ur@mmmmmmlvii{تو انہوں نے اس (رسول) کو جھٹلا دیا، پھر اس (اونٹنی) کی کونچیں کاٹ ڈالیں تو ان کے رب نے ان کے گناہ کی وجہ سے ان پر ہلاکت نازل کر دی، پھر (پوری) بستی کو (تباہ کر کے عذاب میں سب کو) برابر کر دیا،\qt@no{14}}%
\qt@newcmd\qurantrans@ur@mmmmmmlviii{اور اﷲ کو اس (ہلاکت) کے انجام کا کوئی خوف نہیں ہوتا،\qt@no{15}}%
\qt@newcmd\qurantrans@ur@mmmmmmlix{\basmalahur رات کی قَسم جب وہ چھا جائے (اور ہر چیز کو اپنی تاریکی میں چھپا لے)،\qt@no{1}}%
\qt@newcmd\qurantrans@ur@mmmmmmlx{اور دن کی قَسم جب وہ چمک اٹھے،\qt@no{2}}%
\qt@newcmd\qurantrans@ur@mmmmmmlxi{اور اس ذات کی (قَسم) جس نے (ہر چیز میں) نر اور مادہ کو پیدا فرمایا،\qt@no{3}}%
\qt@newcmd\qurantrans@ur@mmmmmmlxii{بیشک تمہاری کوشش مختلف (اور جداگانہ) ہے،\qt@no{4}}%
\qt@newcmd\qurantrans@ur@mmmmmmlxiii{پس جس نے (اپنا مال اﷲ کی راہ میں) دیا اور پرہیزگاری اختیار کی،\qt@no{5}}%
\qt@newcmd\qurantrans@ur@mmmmmmlxiv{اور اس نے (اِنفاق و تقوٰی کے ذریعے) اچھائی (یعنی دینِ حق اور آخرت) کی تصدیق کی،\qt@no{6}}%
\qt@newcmd\qurantrans@ur@mmmmmmlxv{تو ہم عنقریب اسے آسانی (یعنی رضائے الٰہی) کے لئے سہولت فراہم کر دیں گے،\qt@no{7}}%
\qt@newcmd\qurantrans@ur@mmmmmmlxvi{اور جس نے بخل کیا اور (راہِ حق میں مال خرچ کرنے سے) بے پروا رہا،\qt@no{8}}%
\qt@newcmd\qurantrans@ur@mmmmmmlxvii{اور اس نے (یوں) اچھائی (یعنی دینِ حق اور آخرت) کو جھٹلایا،\qt@no{9}}%
\qt@newcmd\qurantrans@ur@mmmmmmlxviii{تو ہم عنقریب اسے سختی (یعنی عذاب کی طرف بڑھنے) کے لئے سہولت فراہم کر دیں گے (تاکہ وہ تیزی سے مستحقِ عذاب ٹھہرے)،\qt@no{10}}%
\qt@newcmd\qurantrans@ur@mmmmmmlxix{اور اس کا مال اس کے کسی کام نہیں آئے گا جب وہ ہلاکت (کے گڑھے) میں گرے گا،\qt@no{11}}%
\qt@newcmd\qurantrans@ur@mmmmmmlxx{بیشک راہِ (حق) دکھانا ہمارے ذمہ ہے،\qt@no{12}}%
\qt@newcmd\qurantrans@ur@mmmmmmlxxi{اور بیشک ہم ہی آخرت اور دنیا کے مالک ہیں،\qt@no{13}}%
\qt@newcmd\qurantrans@ur@mmmmmmlxxii{سو میں نے تمہیں (دوزخ کی) آگ سے ڈرا دیا ہے جو بھڑک رہی ہے،\qt@no{14}}%
\qt@newcmd\qurantrans@ur@mmmmmmlxxiii{جس میں انتہائی بدبخت کے سوا کوئی داخل نہیں ہوگا،\qt@no{15}}%
\qt@newcmd\qurantrans@ur@mmmmmmlxxiv{جس نے (دینِ حق کو) جھٹلایا اور (رسول کی اطاعت سے) منہ پھیر لیا،\qt@no{16}}%
\qt@newcmd\qurantrans@ur@mmmmmmlxxv{اور اس (آگ) سے اس بڑے پرہیزگار شخص کو بچا لیا جائے گا،\qt@no{17}}%
\qt@newcmd\qurantrans@ur@mmmmmmlxxvi{جو اپنا مال (اﷲ کی راہ میں) دیتا ہے کہ (اپنے جان و مال کی) پاکیزگی حاصل کرے،\qt@no{18}}%
\qt@newcmd\qurantrans@ur@mmmmmmlxxvii{اور کسی کا اس پر کوئی احسان نہیں کہ جس کا بدلہ دیا جا رہا ہو،\qt@no{19}}%
\qt@newcmd\qurantrans@ur@mmmmmmlxxviii{مگر (وہ) صرف اپنے ربِ عظیم کی رضا جوئی کے لئے (مال خرچ کر رہا ہے)،\qt@no{20}}%
\qt@newcmd\qurantrans@ur@mmmmmmlxxix{اور عنقریب وہ (اﷲ کی عطا سے اور اﷲ اس کی وفا سے) راضی ہو جائے گا،\qt@no{21}}%
\qt@newcmd\qurantrans@ur@mmmmmmlxxx{\basmalahur قَسم ہے چاشت کے وقت کی (جب آفتاب بلند ہو کر اپنا نور پھیلاتا ہے)۔ (یا:- اے حبیبِ مکرّم!) قَسم ہے چاشت (کی طرح آپ کے چہرۂ انور) کی (جس کی تابانی نے تاریک روحوں کو روشن کر دیا)۔ (یا:- قَسم ہے وقتِ چاشت (کی طرح آپ کے آفتابِ رِسالت کے بلند ہونے) کی (جس کے نور نے گمراہی کے اندھیروں کو اجالے سے بدل دیا)،\qt@no{1}}%
\qt@newcmd\qurantrans@ur@mmmmmmlxxxi{اور قَسم ہے رات کی جب وہ چھا جائے۔ (یا:- اے حبیبِ مکرّم!) قَسم ہے سیاہ رات کی (طرح آپ کی زلفِ عنبریں کی) جب وہ (آپ کے رُخ زیبا یا شانوں پر) چھا جائے)۔ (یا:- قَسم ہے رات کی (طرح آپ کے حجابِ ذات کی) جب کہ وہ (آپ کے نورِ حقیقت کو کئی پردوں میں) چھپائے ہوئے ہے)،\qt@no{2}}%
\qt@newcmd\qurantrans@ur@mmmmmmlxxxii{آپ کے رب نے (جب سے آپ کو منتخب فرمایا ہے) آپ کو نہیں چھوڑا اور نہ ہی (جب سے آپ کو محبوب بنایا ہے) ناراض ہوا ہے،\qt@no{3}}%
\qt@newcmd\qurantrans@ur@mmmmmmlxxxiii{اور بیشک (ہر) بعد کی گھڑی آپ کے لئے پہلے سے بہتر (یعنی باعثِ عظمت و رفعت) ہے،\qt@no{4}}%
\qt@newcmd\qurantrans@ur@mmmmmmlxxxiv{اور آپ کا رب عنقریب آپ کو (اتنا کچھ) عطا فرمائے گا کہ آپ راضی ہو جائیں گے،\qt@no{5}}%
\qt@newcmd\qurantrans@ur@mmmmmmlxxxv{اے حبیب!) کیا اس نے آپ کو یتیم نہیں پایا پھر اس نے (آپ کو معزّز و مکرّم) ٹھکانا دیا۔ یا- کیا اس نے آپ کو (مہربان) نہیں پایا پھر اس نے (آپ کے ذریعے) یتیموں کو ٹھکانا دیا)٭، ٭ اِس ترجہ میں یتیماً کو فاٰوٰی کا مفعولِ مقدّم قرار دیا گیا ہے۔ (ملاحظہ ہو: التفسیر الکبیر، القرطبی، البحر المحیط، روح البیان، الشفاء اور شرح خفاجی)\qt@no{6}}%
\qt@newcmd\qurantrans@ur@mmmmmmlxxxvi{اور اس نے آپ کو اپنی محبت میں خود رفتہ و گم پایا تو اس نے مقصود تک پہنچا دیا۔ یا- اور اس نے آپ کو بھٹکی ہوئی قوم کے درمیان (رہنمائی فرمانے والا) پایا تو اس نے (انہیں آپ کے ذریعے) ہدایت دے دی۔٭، ٭ اِس ترجہ میں ضالاً کو فَھَدٰی کا مفعولِ مقدم قرار دیا گیا ہے۔ (ملاحظہ ہو: التفسیر الکبیر، القرطبی، البحر المحیط، روح البیان، الشفاء اور شرح خفاجی)\qt@no{7}}%
\qt@newcmd\qurantrans@ur@mmmmmmlxxxvii{اور اس نے آپ کو (وصالِ حق کا) حاجت مند پایا تو اس نے (اپنی لذتِ دید سے نواز کر ہمیشہ کے لئے ہر طلب سے) بے نیاز کر دیا۔ (یا:- اور اس نے آپ کو (جوّاد و کریم) پایا تو اس نے (آپ کے ذریعے) محتاجوں کو غنی کر دیا۔٭، ٭ ان تینوں تراجم میں یَتِیماً کو فَاٰوٰی کا، ضآلًّا کو فَھَدٰی کا اور عائِلًا کو فَاَغنٰی کا مفعولِ مقدم قرار دیا ہے۔ (ملاحظہ ہو: التفسیر الکبیر، القرطبی، البحر المحیط، روح البیان، الشفاء اور شرح خفاجی)\qt@no{8}}%
\qt@newcmd\qurantrans@ur@mmmmmmlxxxviii{سو آپ بھی کسی یتیم پر سختی نہ فرمائیں،\qt@no{9}}%
\qt@newcmd\qurantrans@ur@mmmmmmlxxxix{اور (اپنے در کے) کسی منگتے کو نہ جھڑکیں،\qt@no{10}}%
\qt@newcmd\qurantrans@ur@mmmmmmxc{اور اپنے رب کی نعمتوں کا (خوب) تذکرہ کریں،\qt@no{11}}%
\qt@newcmd\qurantrans@ur@mmmmmmxci{\basmalahur کیا ہم نے آپ کی خاطر آپ کا سینہ (انوارِ علم و حکمت اور معرفت کے لئے) کشادہ نہیں فرما دیا،\qt@no{1}}%
\qt@newcmd\qurantrans@ur@mmmmmmxcii{اور ہم نے آپ کا (غمِ امت کا وہ) بار آپ سے اتار دیا،\qt@no{2}}%
\qt@newcmd\qurantrans@ur@mmmmmmxciii{جو آپ کی پشتِ (مبارک) پر گراں ہو رہا تھا،\qt@no{3}}%
\qt@newcmd\qurantrans@ur@mmmmmmxciv{اور ہم نے آپ کی خاطر آپ کا ذکر (اپنے ذکر کے ساتھ ملا کر دنیا و آخرت میں ہر جگہ) بلند فرما دیا،\qt@no{4}}%
\qt@newcmd\qurantrans@ur@mmmmmmxcv{سو بیشک ہر دشواری کے ساتھ آسانی (آتی) ہے،\qt@no{5}}%
\qt@newcmd\qurantrans@ur@mmmmmmxcvi{یقیناً (اس) دشواری کے ساتھ آسانی (بھی) ہے،\qt@no{6}}%
\qt@newcmd\qurantrans@ur@mmmmmmxcvii{پس جب آپ (تعلیمِ امت، تبلیغ و جہاد اور ادائیگیِ فرائض سے) فارغ ہوں تو (ذکر و عبادت میں) محنت فرمایا کریں،\qt@no{7}}%
\qt@newcmd\qurantrans@ur@mmmmmmxcviii{اور اپنے رب کی طرف راغب ہو جایا کریں،\qt@no{8}}%
\qt@newcmd\qurantrans@ur@mmmmmmxcix{\basmalahur انجیر کی قَسم اور زیتون کی قَسم،\qt@no{1}}%
\qt@newcmd\qurantrans@ur@mmmmmmc{اور سینا کے (پہاڑ) طور کی قَسم،\qt@no{2}}%
\qt@newcmd\qurantrans@ur@mmmmmmci{اور اس امن والے شہر (مکہ) کی قَسم،\qt@no{3}}%
\qt@newcmd\qurantrans@ur@mmmmmmcii{بیشک ہم نے انسان کو بہترین (اعتدال اور توازن والی) ساخت میں پیدا فرمایا ہے،\qt@no{4}}%
\qt@newcmd\qurantrans@ur@mmmmmmciii{پھر ہم نے اسے پست سے پست تر حالت میں لوٹا دیا،\qt@no{5}}%
\qt@newcmd\qurantrans@ur@mmmmmmciv{سوائے ان لوگوں کے جو ایمان لائے اور نیک عمل کرتے رہے تو ان کے لئے ختم نہ ہونے والا (دائمی) اجر ہے،\qt@no{6}}%
\qt@newcmd\qurantrans@ur@mmmmmmcv{پھر اس کے بعد کون ہے جو آپ کو دین (یا قیامت اور جزا و سزا) کے بارے میں جھٹلاتا ہے،\qt@no{7}}%
\qt@newcmd\qurantrans@ur@mmmmmmcvi{کیا اﷲ سب حاکموں سے بڑا حاکم نہیں ہے،\qt@no{8}}%
\qt@newcmd\qurantrans@ur@mmmmmmcvii{\basmalahur (اے حبیب!) اپنے رب کے نام سے (آغاز کرتے ہوئے) پڑھئے جس نے (ہر چیز کو) پیدا فرمایا،\qt@no{1}}%
\qt@newcmd\qurantrans@ur@mmmmmmcviii{اس نے انسان کو (رحمِ مادر میں) جونک کی طرح معلّق وجود سے پیدا کیا،\qt@no{2}}%
\qt@newcmd\qurantrans@ur@mmmmmmcix{پڑھیئے اور آپ کا رب بڑا ہی کریم ہے،\qt@no{3}}%
\qt@newcmd\qurantrans@ur@mmmmmmcx{جس نے قلم کے ذریعے (لکھنے پڑھنے کا) علم سکھایا،\qt@no{4}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxi{جس نے انسان کو (اس کے علاوہ بھی) وہ (کچھ) سکھا دیا جو وہ نہیں جانتا تھا۔ (یا- جس نے (سب سے بلند رتبہ) انسان (محمد مصطفی صلی اللہ علیہ وآلہ وسلم) کو (بغیر ذریعۂ قلم کے) وہ سارا علم عطا فرما دیا جو وہ پہلے نہ جانتے تھے،\qt@no{5}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxii{مگر) حقیقت یہ ہے کہ (نافرمان) انسان سر کشی کرتا ہے،\qt@no{6}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxiii{اس بنا پر کہ وہ اپنے آپ کو (دنیا میں ظاہراً) بے نیاز دیکھتا ہے،\qt@no{7}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxiv{بیشک (ہر انسان کو) آپ کے رب ہی کی طرف لوٹنا ہے،\qt@no{8}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxv{کیا آپ نے اس شخص کو دیکھا جو منع کرتا ہے،\qt@no{9}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxvi{اﷲ کے) بندے کو جب وہ نماز پڑھتا ہے۔ (یا:- (اللہ کے محبوب و برگزیدہ) بندے (محمد مصطفی صلی اللہ علیہ وآلہ وسلم) کو جب وہ نماز پڑھتے ہیں)،\qt@no{10}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxvii{بھلا دیکھئے تو اگر وہ ہدایت پر ہوتا،\qt@no{11}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxviii{یا وہ (لوگوں کو) پرہیزگاری کا حکم دیتا (تو کیا خوب ہوتا)،\qt@no{12}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxix{اب بتائیے! اگر اس نے (دینِ حق کو) جھٹلایا ہے اور (آپ سے) منہ پھیر لیا ہے (تو اس کا کیا حشر ہوگا)،\qt@no{13}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxx{کیا وہ نہیں جانتا کہ اﷲ (اس کے سارے کردار کو) دیکھ رہا ہے،\qt@no{14}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxxi{خبر دار! اگر وہ (گستاخئ رسالت اور دینِ حق کی عداوت سے) باز نہ آیا تو ہم ضرور (اسے) پیشانی کے بالوں سے پکڑ کر گھسیٹیں گے،\qt@no{15}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxxii{وہ پیشانی جو جھوٹی (اور) خطا کار ہے،\qt@no{16}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxxiii{پس وہ اپنے ہم نشینوں کو (مدد کے لئے) بلا لے،\qt@no{17}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxxiv{ہم بھی عنقریب (اپنے) سپاہیوں (یعنی دوزخ کے عذاب پر مقرر فرشتوں) کو بلا لیں گے،\qt@no{18}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxxv{ہرگز نہیں! آپ اس کے کئے کی پرواہ نہ کیجئے، اور (اے حبیبِ مکرّم!) آپ سر بسجود رہئے اور (ہم سے مزید) قریب ہوتے جائیے،\qt@no{19}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxxvi{\basmalahur بیشک ہم نے اس (قرآن) کو شبِ قدر میں اتارا ہے،\qt@no{1}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxxvii{اور آپ کیا سمجھے ہیں (کہ) شبِ قدر کیا ہے،\qt@no{2}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxxviii{شبِ قدر (فضیلت و برکت اور اَجر و ثواب میں) ہزار مہینوں سے بہتر ہے،\qt@no{3}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxxix{اس (رات) میں فرشتے اور روح الامین (جبرائیل) اپنے رب کے حکم سے (خیر و برکت کے) ہر امر کے ساتھ اترتے ہیں،\qt@no{4}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxxx{یہ (رات) طلوعِ فجر تک (سراسر) سلامتی ہے،\qt@no{5}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxxxi{\basmalahur اہلِ کتاب میں سے جو لوگ کافر ہو گئے اور مشرکین اس قت تک (کفر سے) الگ ہونے والے نہ تھے جب تک ان کے پاس روشن دلیل (نہ) آجاتی،\qt@no{1}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxxxii{وہ دلیل) اﷲ کی طرف سے رسول (آخر الزماں صلی اللہ علیہ وآلہ وسلم) ہیں جو (ان پر) پاکیزہ اوراقِ (قرآن) کی تلاوت فرماتے ہیں،\qt@no{2}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxxxiii{جن میں درست اور مستحکم احکام (درج) ہیں،\qt@no{3}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxxxiv{ان) اہل کتاب میں (نبی آخر الزماں صلی اللہ علیہ وآلہ وسلم کی نبوت و رسالت پر ایمان لانے اور آپ کی شانِ اقدس کو پہچاننے کے بارے میں پہلے) کوئی پھوٹ نہ پڑی تھی مگر اس کے بعد کہ جب (بعثتِ محمدی صلی اللہ علیہ وآلہ وسلم کی) روشن دلیل ان کے پاس آگئی (تو وہ باہم بٹ گئے کوئی ان پر ایمان لے آیا اور کوئی حسد کے باعث منکر و کافر ہوگیا)،\qt@no{4}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxxxv{حالانکہ انہیں فقط یہی حکم دیا گیا تھا کہ صرف اسی کے لئے اپنے دین کو خالص کرتے ہوئے اﷲ کی عبادت کریں، (ہر باطل سے جدا ہو کر) حق کی طرف یک سُوئی پیدا کریں اور نماز قائم کریں اور زکوٰۃ دیا کریں اور یہی سیدھا اور مضبوط دین ہے،\qt@no{5}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxxxvi{بیشک جو لوگ اہلِ کتاب میں سے کافر ہوگئے اور مشرکین (سب) دوزخ کی آگ میں (پڑے) ہوں گے وہ ہمیشہ اسی میں رہنے والے ہیں، یہی لوگ بد ترین مخلوق ہیں،\qt@no{6}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxxxvii{بیشک جو لوگ ایمان لائے اور نیک عمل کرتے رہے وہی لوگ ساری مخلوق سے بہتر ہیں،\qt@no{7}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxxxviii{ان کی جزا ان کے رب کے حضور دائمی رہائش کے باغات ہیں جن کے نیچے سے نہریں رواں ہیں، وہ ان میں ہمیشہ ہمیشہ رہیں گے، اﷲ اُن سے راضی ہوگیا ہے اور وہ لوگ اس سے راضی ہیں، یہ (مقام) اس شخص کے لئے ہے جو اپنے رب سے خائف رہا،\qt@no{8}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxxxix{\basmalahur جب زمین اپنے سخت بھونچال سے بڑی شدت کے ساتھ تھرتھرائی جائے گی،\qt@no{1}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxl{اور زمین اپنے (سب) بوجھ نکال باہر پھینکے گی،\qt@no{2}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxli{اور انسان (حیران و ششدر ہو کر) کہے گا: اسے کیا ہوگیا ہے،\qt@no{3}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxlii{اس دن وہ اپنے حالات خود ظاہر کر دے گی،\qt@no{4}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxliii{اس لئے کہ آپ کے رب نے اس کے لئے تیز اشاروں (کی زبان) کو مسخر فرما دیا ہوگا،\qt@no{5}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxliv{اس دن لوگ مختلف گروہ بن کر (جدا جدا حالتوں کے ساتھ) نکلیں گے تاکہ انہیں ان کے اَعمال دکھائے جائیں،\qt@no{6}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxlv{تو جس نے ذرہ بھر نیکی کی ہوگی وہ اسے دیکھ لے گا،\qt@no{7}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxlvi{اور جس نے ذرہ بھر برائی کی ہوگی وہ اسے (بھی) دیکھ لے گا،\qt@no{8}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxlvii{\basmalahur (میدانِ جہاد میں) تیز دوڑنے والے گھوڑوں کی قَسم جو ہانپتے ہیں،\qt@no{1}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxlviii{پھر جو پتھروں پر سُم مار کر چنگاریاں نکالتے ہیں،\qt@no{2}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxlix{پھر جو صبح ہوتے ہی (دشمن پر) اچانک حملہ کر ڈالتے ہیں،\qt@no{3}}%
\qt@newcmd\qurantrans@ur@mmmmmmcl{پھر وہ اس (حملے والی) جگہ سے گرد و غبار اڑاتے ہیں،\qt@no{4}}%
\qt@newcmd\qurantrans@ur@mmmmmmcli{پھر وہ اسی وقت (دشمن کے) لشکر میں گھس جاتے ہیں،\qt@no{5}}%
\qt@newcmd\qurantrans@ur@mmmmmmclii{بیشک انسان اپنے رب کا بڑا ہی ناشکرا ہے،\qt@no{6}}%
\qt@newcmd\qurantrans@ur@mmmmmmcliii{اور یقیناً وہ اس (ناشکری) پر خود گواہ ہے،\qt@no{7}}%
\qt@newcmd\qurantrans@ur@mmmmmmcliv{اور بیشک وہ مال کی محبت میں بہت سخت ہے،\qt@no{8}}%
\qt@newcmd\qurantrans@ur@mmmmmmclv{تو کیا اسے معلوم نہیں جب وہ (مُردے) اٹھائے جائیں گے جو قبروں میں ہیں،\qt@no{9}}%
\qt@newcmd\qurantrans@ur@mmmmmmclvi{اور (راز) ظاہر کر دیئے جائیں گے جو سینوں میں ہیں،\qt@no{10}}%
\qt@newcmd\qurantrans@ur@mmmmmmclvii{بیشک ان کا رب اس دن ان (کے اعمال) سے خوب خبردار ہوگا،\qt@no{11}}%
\qt@newcmd\qurantrans@ur@mmmmmmclviii{\basmalahur (زمین و آسمان کی ساری کائنات کو) کھڑکھڑا دینے والا شدید جھٹکا اور کڑک،\qt@no{1}}%
\qt@newcmd\qurantrans@ur@mmmmmmclix{وہ (ہر شے کو) کھڑ کھڑا دینے والا شدید جھٹکا اور کڑک کیا ہے،\qt@no{2}}%
\qt@newcmd\qurantrans@ur@mmmmmmclx{اور آپ کیا سمجھے ہیں کہ (ہر شے کو) کھڑ کھڑا دینے والے شدید جھٹکے اور کڑک سے مراد کیا ہے،\qt@no{3}}%
\qt@newcmd\qurantrans@ur@mmmmmmclxi{اس سے مراد) وہ یومِ قیامت ہے جس دن (سارے) لوگ بکھرے ہوئے پروانوں کی طرح ہو جائیں گے،\qt@no{4}}%
\qt@newcmd\qurantrans@ur@mmmmmmclxii{اور پہاڑ رنگ برنگ دھنکی ہوئی اُون کی طرح ہو جائیں گے،\qt@no{5}}%
\qt@newcmd\qurantrans@ur@mmmmmmclxiii{پس وہ شخص کہ جس (کے اعمال) کے پلڑے بھاری ہوں گے،\qt@no{6}}%
\qt@newcmd\qurantrans@ur@mmmmmmclxiv{تو وہ خوش گوار عیش و مسرت میں ہوگا،\qt@no{7}}%
\qt@newcmd\qurantrans@ur@mmmmmmclxv{اور جس شخص کے (اعمال کے) پلڑے ہلکے ہوں گے،\qt@no{8}}%
\qt@newcmd\qurantrans@ur@mmmmmmclxvi{تو اس کا ٹھکانا ہاویہ (جہنم کا گڑھا) ہوگا،\qt@no{9}}%
\qt@newcmd\qurantrans@ur@mmmmmmclxvii{اور آپ کیا سمجھے ہیں کہ ہاویہ کیا ہے،\qt@no{10}}%
\qt@newcmd\qurantrans@ur@mmmmmmclxviii{وہ جہنم کی) سخت دہکتی آگ (کا انتہائی گہرا گڑھا) ہے،\qt@no{11}}%
\qt@newcmd\qurantrans@ur@mmmmmmclxix{\basmalahur تمہیں کثرتِ مال کی ہوس اور فخر نے (آخرت سے) غافل کر دیا،\qt@no{1}}%
\qt@newcmd\qurantrans@ur@mmmmmmclxx{یہاں تک کہ تم قبروں میں جا پہنچے،\qt@no{2}}%
\qt@newcmd\qurantrans@ur@mmmmmmclxxi{ہرگز نہیں! (مال و دولت تمہارے کام نہیں آئیں گے) تم عنقریب (اس حقیقت کو) جان لو گے،\qt@no{3}}%
\qt@newcmd\qurantrans@ur@mmmmmmclxxii{پھر (آگاہ کیا جاتا ہے:) ہرگز نہیں! عنقریب تمہیں (اپنا انجام) معلوم ہو جائے گا،\qt@no{4}}%
\qt@newcmd\qurantrans@ur@mmmmmmclxxiii{ہاں ہاں! کاش تم (مال و زَر کی ہوس اور اپنی غفلت کے انجام کو) یقینی علم کے ساتھ جانتے (تو دنیا میں کھو کر آخرت کو اس طرح نہ بھولتے)،\qt@no{5}}%
\qt@newcmd\qurantrans@ur@mmmmmmclxxiv{تم (اپنی حرص کے نتیجے میں) دوزخ کو ضرور دیکھ کر رہو گے،\qt@no{6}}%
\qt@newcmd\qurantrans@ur@mmmmmmclxxv{پھر تم اسے ضرور یقین کی آنکھ سے دیکھ لو گے،\qt@no{7}}%
\qt@newcmd\qurantrans@ur@mmmmmmclxxvi{پھر اس دن تم سے (اﷲ کی) نعمتوں کے بارے میں ضرور پوچھا جائے گا (کہ تم نے انہیں کہاں کہاں اور کیسے کیسے خرچ کیا تھا)،\qt@no{8}}%
\qt@newcmd\qurantrans@ur@mmmmmmclxxvii{\basmalahur زمانہ کی قَسم (جس کی گردش انسانی حالات پر گواہ ہے)۔ (یا- نمازِ عصر کی قَسم (کہ وہ سب نمازوں کا وسط ہے)۔ (یا- وقتِ عصر کی قَسم (جب دن بھر چمکنے والا سورج خود ڈوبنے کا منظر پیش کرتا ہے)۔ (یا- زمانۂ بعثتِ مصطفیٰ (صلی اللہ علیہ وآلہ وسلم) کی قَسم (جو سارے زمانوں کا ماحصل اور مقصود ہے)،\qt@no{1}}%
\qt@newcmd\qurantrans@ur@mmmmmmclxxviii{بیشک انسان خسارے میں ہے (کہ وہ عمرِ عزیز گنوا رہا ہے)،\qt@no{2}}%
\qt@newcmd\qurantrans@ur@mmmmmmclxxix{سوائے ان لوگوں کے جو ایمان لے آئے اور نیک عمل کرتے رہے اور (معاشرے میں) ایک دوسرے کو حق کی تلقین کرتے رہے اور (تبلیغِ حق کے نتیجے میں پیش آمدہ مصائب و آلام میں) باہم صبر کی تاکید کرتے رہے،\qt@no{3}}%
\qt@newcmd\qurantrans@ur@mmmmmmclxxx{\basmalahur ہر اس شخص کے لئے ہلاکت ہے جو (روبرو) طعنہ زنی کرنے والا ہے (اور پسِ پشت) عیب جوئی کرنے والا ہے،\qt@no{1}}%
\qt@newcmd\qurantrans@ur@mmmmmmclxxxi{خرابی و تباہی ہے اس شخص کے لئے) جس نے مال جمع کیا اور اسے گن گن کر رکھتا ہے،\qt@no{2}}%
\qt@newcmd\qurantrans@ur@mmmmmmclxxxii{وہ یہ گمان کرتا ہے کہ اس کی دولت اسے ہمیشہ زندہ رکھے گی،\qt@no{3}}%
\qt@newcmd\qurantrans@ur@mmmmmmclxxxiii{ہرگز نہیں! وہ ضرور حطمہ (یعنی چورا چورا کر دینے والی آگ) میں پھینک دیا جائے گا،\qt@no{4}}%
\qt@newcmd\qurantrans@ur@mmmmmmclxxxiv{اور آپ کیا سمجھے ہیں کہ حطمہ (چورا چورا کر دینے والی آگ) کیا ہے،\qt@no{5}}%
\qt@newcmd\qurantrans@ur@mmmmmmclxxxv{یہ) اﷲ کی بھڑکائی ہوئی آگ ہے،\qt@no{6}}%
\qt@newcmd\qurantrans@ur@mmmmmmclxxxvi{جو دلوں پر (اپنی اذیت کے ساتھ) چڑھ جائے گی،\qt@no{7}}%
\qt@newcmd\qurantrans@ur@mmmmmmclxxxvii{بیشک وہ (آگ) ان لوگوں پر ہر طرف سے بند کر دی جائے گی،\qt@no{8}}%
\qt@newcmd\qurantrans@ur@mmmmmmclxxxviii{بھڑکتے شعلوں کے) لمبے لمبے ستونوں میں (اور ان لوگوں کے لئے کوئی راہِ فرار نہ رہے گی)،\qt@no{9}}%
\qt@newcmd\qurantrans@ur@mmmmmmclxxxix{\basmalahur کیا آپ نے نہیں دیکھا کہ آپ کے رب نے ہاتھی والوں کے ساتھ کیا سلوک کیا،\qt@no{1}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxc{کیا اس نے ان کے مکر و فریب کو باطل و ناکام نہیں کر دیا،\qt@no{2}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxci{اور اس نے ان پر (ہر سمت سے) پرندوں کے جھنڈ کے جھنڈ بھیج دیئے،\qt@no{3}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxcii{جو ان پر کنکریلے پتھر مارتے تھے،\qt@no{4}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxciii{پھر (اﷲ نے) ان کو کھائے ہوئے بھوسے کی طرح (پامال) کر دیا،\qt@no{5}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxciv{\basmalahur قریش کو رغبت دلانے کے سبب سے،\qt@no{1}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxcv{انہیں سردیوں اور گرمیوں کے (تجارتی) سفر سے مانوس کر دیا،\qt@no{2}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxcvi{پس انہیں چاہئے کہ اس گھر (خانہ کعبہ) کے رب کی عبادت کریں (تاکہ اس کی شکر گزاری ہو)،\qt@no{3}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxcvii{جس نے انہیں بھوک (یعنی فقر و فاقہ کے حالات) میں کھانا دیا (یعنی رِزق فراہم کیا) اور (دشمنوں کے) خوف سے امن بخشا (یعنی محفوظ و مامون زندگی سے نوازا)،\qt@no{4}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxcviii{\basmalahur کیا آپ نے اس شخص کو دیکھا جو دین کو جھٹلاتا ہے،\qt@no{1}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxcix{تو یہ وہ شخص ہے جو یتیم کو دھکے دیتا ہے (یعنی یتیموں کی حاجات کو ردّ کرتا اور انہیں حق سے محروم رکھتا ہے)،\qt@no{2}}%
\qt@newcmd\qurantrans@ur@mmmmmmcc{اور محتاج کو کھانا کھلانے کی ترغیب نہیں دیتا (یعنی معاشرے سے غریبوں اور محتاجوں کے معاشی اِستحصال کے خاتمے کی کوشش نہیں کرتا)،\qt@no{3}}%
\qt@newcmd\qurantrans@ur@mmmmmmcci{پس افسوس (اور خرابی) ہے ان نمازیوں کے لئے،\qt@no{4}}%
\qt@newcmd\qurantrans@ur@mmmmmmccii{جو اپنی نماز (کی روح) سے بے خبر ہیں (یعنی انہیں محض حقوق اﷲ یاد ہیں حقوق العباد بھلا بیٹھے ہیں)،\qt@no{5}}%
\qt@newcmd\qurantrans@ur@mmmmmmcciii{وہ لوگ (عبادت میں) دکھلاوا کرتے ہیں (کیونکہ وہ خالق کی رسمی بندگی بجا لاتے ہیں اور پسی ہوئی مخلوق سے بے پرواہی برت رہے ہیں)،\qt@no{6}}%
\qt@newcmd\qurantrans@ur@mmmmmmcciv{اور وہ برتنے کی معمولی سی چیز بھی مانگے نہیں دیتے،\qt@no{7}}%
\qt@newcmd\qurantrans@ur@mmmmmmccv{\basmalahur بیشک ہم نے آپ کو (ہر خیر و فضیلت میں) بے انتہا کثرت بخشی ہے٭، ٭ کوثر سے مراد حوضِ کوثر یا نہرِ جنت بھی ہے اور قرآن اور نبوت و حکمت بھی، فضائل و معجزات کی کثرت یا اصحاب و اتباع اور امت کی کثرت بھی مراد لی گئی ہے۔ رفعتِ ذکر اور خلقِ عظیم بھی مراد ہے اور دنیا و آخرت کی نعمتیں بھی، نصرتِ الٰہیہ اور کثرتِ فتوحات بھی مراد ہیں اور روزِ قیامت مقامِ محمود اور شفاعتِ عظمیٰ بھی مراد لی گئی ہے۔\qt@no{1}}%
\qt@newcmd\qurantrans@ur@mmmmmmccvi{پس آپ اپنے رب کے لئے نماز پڑھا کریں اور قربانی دیا کریں (یہ ہدیۂ تشکرّ ہے)،\qt@no{2}}%
\qt@newcmd\qurantrans@ur@mmmmmmccvii{بیشک آپ کا دشمن ہی بے نسل اور بے نام و نشاں ہوگا،\qt@no{3}}%
\qt@newcmd\qurantrans@ur@mmmmmmccviii{\basmalahur آپ فرما دیجئے: اے کافرو!،\qt@no{1}}%
\qt@newcmd\qurantrans@ur@mmmmmmccix{میں ان (بتوں) کی عبادت نہیں کرتا جنہیں تم پوجتے ہو،\qt@no{2}}%
\qt@newcmd\qurantrans@ur@mmmmmmccx{اور نہ تم اس (رب) کی عبادت کرنے والے ہو جس کی میں عبادت کرتا ہوں،\qt@no{3}}%
\qt@newcmd\qurantrans@ur@mmmmmmccxi{اور نہ (ہی) میں (آئندہ کبھی) ان کی عبادت کرنے والا ہوں جن (بتوں) کی تم پرستش کرتے ہو،\qt@no{4}}%
\qt@newcmd\qurantrans@ur@mmmmmmccxii{اور نہ (ہی) تم اس کی عبادت کرنے والے ہو جس (رب) کی میں عبادت کرتا ہوں،\qt@no{5}}%
\qt@newcmd\qurantrans@ur@mmmmmmccxiii{سو) تمہارا دین تمہارے لئے اور میرا دین میرے لئے ہے،\qt@no{6}}%
\qt@newcmd\qurantrans@ur@mmmmmmccxiv{\basmalahur جب اﷲ کی مدد اور فتح آپہنچے،\qt@no{1}}%
\qt@newcmd\qurantrans@ur@mmmmmmccxv{اور آپ لوگوں کو دیکھ لیں (کہ) وہ اﷲ کے دین میں جوق دَر جوق داخل ہو رہے ہیں،\qt@no{2}}%
\qt@newcmd\qurantrans@ur@mmmmmmccxvi{تو آپ (تشکراً) اپنے رب کی حمد کے ساتھ تسبیح فرمائیں اور (تواضعاً) اس سے استغفار کریں، بیشک وہ بڑا ہی توبہ قبول فرمانے والا (اور مزید رحمت کے ساتھ رجوع فرمانے والا) ہے،\qt@no{3}}%
\qt@newcmd\qurantrans@ur@mmmmmmccxvii{\basmalahur ابولہب کے دونوں ہاتھ ٹوٹ جائیں اور وہ تباہ ہو جائے (اس نے ہمارے حبیب پر ہاتھ اٹھانے کی کوشش کی ہے)،\qt@no{1}}%
\qt@newcmd\qurantrans@ur@mmmmmmccxviii{اسے اس کے (موروثی) مال نے کچھ فائدہ نہ پہنچایا اور نہ ہی اس کی کمائی نے،\qt@no{2}}%
\qt@newcmd\qurantrans@ur@mmmmmmccxix{عنقریب وہ شعلوں والی آگ میں جا پڑے گا،\qt@no{3}}%
\qt@newcmd\qurantrans@ur@mmmmmmccxx{اور اس کی (خبیث) عورت (بھی) جو (کانٹے دار) لکڑیوں کا بوجھ (سر پر) اٹھائے پھرتی ہے، (اور ہمارے حبیب کے تلووں کو زخمی کرنے کے لئے رات کو ان کی راہوں میں بچھا دیتی ہے)،\qt@no{4}}%
\qt@newcmd\qurantrans@ur@mmmmmmccxxi{اس کی گردن میں کھجور کی چھال کا (وہی) رسّہ ہوگا (جس سے کانٹوں کا گٹھا باندھتی ہے)،\qt@no{5}}%
\qt@newcmd\qurantrans@ur@mmmmmmccxxii{\basmalahur (اے نبئ مکرّم!) آپ فرما دیجئے: وہ اﷲ ہے جو یکتا ہے،\qt@no{1}}%
\qt@newcmd\qurantrans@ur@mmmmmmccxxiii{اﷲ سب سے بے نیاز، سب کی پناہ اور سب پر فائق ہے،\qt@no{2}}%
\qt@newcmd\qurantrans@ur@mmmmmmccxxiv{نہ اس سے کوئی پیدا ہوا ہے اور نہ ہی وہ پیدا کیا گیا ہے،\qt@no{3}}%
\qt@newcmd\qurantrans@ur@mmmmmmccxxv{اور نہ ہی اس کا کوئی ہمسر ہے،\qt@no{4}}%
\qt@newcmd\qurantrans@ur@mmmmmmccxxvi{\basmalahur آپ عرض کیجئے کہ میں (ایک) دھماکے سے انتہائی تیزی کے ساتھ (کائنات کو) وجود میں لانے والے رب کی پناہ مانگتا ہوں،\qt@no{1}}%
\qt@newcmd\qurantrans@ur@mmmmmmccxxvii{ہر اس چیز کے شر (اور نقصان) سے جو اس نے پیدا فرمائی ہے،\qt@no{2}}%
\qt@newcmd\qurantrans@ur@mmmmmmccxxviii{اور (بالخصوص) اندھیری رات کے شر سے جب (اس کی) ظلمت چھا جائے،\qt@no{3}}%
\qt@newcmd\qurantrans@ur@mmmmmmccxxix{اور گرہوں میں پھونک مارنے والی جادوگرنیوں (اور جادوگروں) کے شر سے،\qt@no{4}}%
\qt@newcmd\qurantrans@ur@mmmmmmccxxx{اور ہر حسد کرنے والے کے شر سے جب وہ حسد کرے،\qt@no{5}}%
\qt@newcmd\qurantrans@ur@mmmmmmccxxxi{\basmalahur آپ عرض کیجئے کہ میں (سب) انسانوں کے رب کی پناہ مانگتا ہوں،\qt@no{1}}%
\qt@newcmd\qurantrans@ur@mmmmmmccxxxii{جو (سب) لوگوں کا بادشاہ ہے،\qt@no{2}}%
\qt@newcmd\qurantrans@ur@mmmmmmccxxxiii{جو (ساری) نسلِ انسانی کا معبود ہے،\qt@no{3}}%
\qt@newcmd\qurantrans@ur@mmmmmmccxxxiv{وسوسہ انداز (شیطان) کے شر سے جو (اﷲ کے ذکر کے اثر سے) پیچھے ہٹ کر چھپ جانے والا ہے،\qt@no{4}}%
\qt@newcmd\qurantrans@ur@mmmmmmccxxxv{جو لوگوں کے دلوں میں وسوسہ ڈالتا ہے،\qt@no{5}}%
\qt@newcmd\qurantrans@ur@mmmmmmccxxxvi{خواہ وہ (وسوسہ انداز شیطان) جنات میں سے ہو یا انسانوں میں سے،\qt@no{6}}%
%% End of file `qurantext-urviii.translation.def'.
