\qt@newcmd\qurantrans@id@i{%
(Dengan nama Allah Yang Maha Pemurah lagi Maha Penyayang)\qt@no{1}}%
\qt@newcmd\qurantrans@id@ii{%
(Segala puji bagi Allah) Lafal ayat ini merupakan kalimat berita, dimaksud sebagai ungkapan pujian kepada Allah berikut pengertian yang terkandung di dalamnya, yaitu bahwa Allah Taala adalah yang memiliki semua pujian yang diungkapkan oleh semua hamba-Nya. Atau makna yang dimaksud ialah bahwa Allah Taala itu adalah Zat yang harus mereka puji. Lafal Allah merupakan nama bagi Zat yang berhak untuk disembah. (Tuhan semesta alam) artinya Allah adalah yang memiliki pujian semua makhluk-Nya, yaitu terdiri dari manusia, jin, malaikat, hewan-hewan melata dan lain-lainnya. Masing-masing mereka disebut alam. Oleh karenanya ada alam manusia, alam jin dan lain sebagainya. Lafal 'al-`aalamiin' merupakan bentuk jamak dari lafal '`aalam', yaitu dengan memakai huruf ya dan huruf nun untuk menekankan makhluk berakal/berilmu atas yang lainnya. Kata 'aalam berasal dari kata `alaamah (tanda) mengingat ia adalah tanda bagi adanya yang menciptakannya.\qt@no{2}}%
\qt@newcmd\qurantrans@id@iii{%
(Yang Maha Pemurah lagi Maha Penyayang) yaitu yang mempunyai rahmat. Rahmat ialah menghendaki kebaikan bagi orang yang menerimanya.\qt@no{3}}%
\qt@newcmd\qurantrans@id@iv{%
(Yang menguasai hari pembalasan) di hari kiamat kelak. Lafal 'yaumuddiin' disebutkan secara khusus, karena di hari itu tiada seorang pun yang mempunyai kekuasaan, kecuali hanya Allah Taala semata, sesuai dengan firman Allah Taala yang menyatakan, ``Kepunyaan siapakah kerajaan pada hari ini (hari kiamat)? Kepunyaan Allah Yang Maha Esa lagi Maha Mengalahkan." (Q.S. Al-Mukmin 16) Bagi orang yang membacanya 'maaliki' maknanya menjadi ``Dia Yang memiliki semua perkara di hari kiamat". Atau Dia adalah Zat yang memiliki sifat ini secara kekal, perihalnya sama dengan sifat-sifat-Nya yang lain, yaitu seperti 'ghaafiruz dzanbi' (Yang mengampuni dosa-dosa). Dengan demikian maka lafal 'maaliki yaumiddiin' ini sah menjadi sifat bagi Allah, karena sudah ma`rifah (dikenal).\qt@no{4}}%
\qt@newcmd\qurantrans@id@v{%
(Hanya Engkaulah yang kami sembah dan hanya kepada Engkaulah kami memohon pertolongan) Artinya kami beribadah hanya kepada-Mu, seperti mengesakan dan lain-lainnya, dan kami memohon pertolongan hanya kepada-Mu dalam menghadapi semua hamba-Mu dan lain-lainnya.\qt@no{5}}%
\qt@newcmd\qurantrans@id@vi{%
(Tunjukilah kami ke jalan yang lurus) Artinya bimbinglah kami ke jalan yang lurus, kemudian dijelaskan pada ayat berikutnya, yaitu:\qt@no{6}}%
\qt@newcmd\qurantrans@id@vii{%
(Jalan orang-orang yang telah Engkau anugerahkan nikmat kepada mereka), yaitu melalui petunjuk dan hidayah-Mu. Kemudian diperjelas lagi maknanya oleh ayat berikut: (Bukan (jalan) mereka yang dimurkai) Yang dimaksud adalah orang-orang Yahudi. (Dan bukan pula) dan selain (mereka yang sesat.) Yang dimaksud adalah orang-orang Kristen. Faedah adanya penjelasan tersebut tadi mempunyai pengertian bahwa orang-orang yang mendapat hidayah itu bukanlah orang-orang Yahudi dan bukan pula orang-orang Kristen. Hanya Allahlah Yang Maha Mengetahui dan hanya kepada-Nyalah dikembalikan segala sesuatu. Semoga selawat dan salam-Nya dicurahkan kepada junjungan kita Nabi Muhammad saw. beserta keluarga dan para sahabatnya, selawat dan salam yang banyak untuk selamanya. Cukuplah bagi kita Allah sebagai penolong dan Dialah sebaik-baik penolong. Tiada daya dan tiada kekuatan melainkan hanya berkat pertolongan Allah Yang Maha Tinggi lagi Maha Besar.\qt@no{7}}%
\qt@newcmd\qurantrans@id@viii{%
\basmalahid (Alif laam miim) Allah yang lebih mengetahui akan maksudnya.\qt@no{1}}%
\qt@newcmd\qurantrans@id@ix{%
(Kitab ini) yakni yang dibaca oleh Muhammad saw. (tidak ada keraguan) atau kebimbangan (padanya) bahwa ia benar-benar dari Allah swt. Kalimat negatif menjadi predikat dari subyek 'Kitab ini', sedangkan kata-kata isyarat 'ini' dipakai sebagai penghormatan. (menjadi petunjuk) sebagai predikat kedua, artinya menjadi penuntun (bagi orang-orang yang bertakwa) maksudnya orang-orang yang mengusahakan diri mereka supaya menjadi takwa dengan jalan mengikuti perintah dan menjauhi larangan demi menjaga diri dari api neraka.\qt@no{2}}%
\qt@newcmd\qurantrans@id@x{%
(Orang-orang yang beriman) yang membenarkan (kepada yang gaib) yaitu yang tidak kelihatan oleh mereka, seperti kebangkitan, surga dan neraka (dan mendirikan salat) artinya melakukannya sebagaimana mestinya (dan sebagian dari yang Kami berikan kepada mereka) yang Kami anugerahkan kepada mereka sebagai rezeki (mereka nafkahkan) mereka belanjakan untuk jalan menaati Allah.\qt@no{3}}%
\qt@newcmd\qurantrans@id@xi{%
(Dan orang-orang yang beriman pada apa yang diturunkan kepadamu) maksudnya Alquran, (dan apa yang diturunkan sebelummu) yaitu Taurat, Injil dan selainnya (serta mereka yakin akan hari akhirat), artinya mengetahui secara pasti.\qt@no{4}}%
\qt@newcmd\qurantrans@id@xii{%
(Merekalah), yakni orang-orang yang memenuhi sifat-sifat yang disebutkan di atas (yang beroleh petunjuk dari Tuhan mereka dan merekalah orang-orang yang beruntung) yang akan berhasil meraih surga dan terlepas dari siksa neraka.\qt@no{5}}%
\qt@newcmd\qurantrans@id@xiii{%
(Sesungguhnya orang-orang kafir) seperti Abu Jahal, Abu Lahab dan lainnya (sama saja bagi mereka, apakah kamu beri peringatan) dibaca, a-andzartahum, yakni dengan dua buah hamzah secara tegas. Dapat pula hamzah yang kedua dilebur menjadi alif hingga hanya tinggal satu hamzah saja yang dibaca panjang (atau tidak kamu beri peringatan, mereka tidak juga akan beriman.) Hal itu telah diketahui oleh Allah, maka janganlah kamu berharap mereka akan beriman. 'Indzar' atau peringatan, artinya pemberitahuan disertai ancaman.\qt@no{6}}%
\qt@newcmd\qurantrans@id@xiv{%
(Allah mengunci mati hati mereka) maksudnya menutup rapat hati mereka sehingga tidak dapat dimasuki oleh kebaikan (begitu pun pendengaran mereka) maksudnya alat-alat atau sumber-sumber pendengaran mereka dikunci sehingga mereka tidak memperoleh manfaat dari kebenaran yang mereka terima (sedangkan penglihatan mereka ditutup) dengan penutup yang menutupinya sehingga mereka tidak dapat melihat kebenaran (dan bagi mereka siksa yang besar) yang berat lagi tetap. Terhadap orang-orang munafik diturunkan:\qt@no{7}}%
\qt@newcmd\qurantrans@id@xv{%
(Di antara manusia ada orang yang mengatakan, ``Kami beriman kepada Allah dan hari akhir.") yaitu hari kiamat, karena hari itu adalah hari terakhir. (Padahal mereka bukan orang-orang yang beriman). Di sini ditekankan arti kata 'orang', jika kata ganti yang disebutkan lafalnya, yakni 'mereka'.\qt@no{8}}%
\qt@newcmd\qurantrans@id@xvi{%
(Mereka hendak menipu Allah dan orang-orang yang beriman) yakni dengan berpura-pura beriman dan menyembunyikan kekafiran guna melindungi diri mereka dari hukum-hukum duniawi (padahal mereka hanya menipu diri mereka sendiri) karena bencana tipu daya itu akan kembali menimpa diri mereka sendiri. Di dunia, rahasia mereka akan diketahui juga dengan dibuka Allah kepada Nabi-Nya, sedangkan di akhirat mereka akan menerima hukuman setimpal (tetapi mereka tidak menyadari) dan tidak menginsafi bahwa tipu daya mereka itu menimpa diri mereka sendiri. Mukhada`ah atau tipu-menipu di sini muncul dari satu pihak, jadi bukan berarti berserikat di antara dua belah pihak. Contoh yang lainnya mu`aqabatul lish yang berarti menghukum pencuri. Menyebutkan Allah di sana hanya merupakan salah satu dari gaya bahasa saja. Menurut suatu qiraat tidak tercantum 'wamaa yasy`uruuna' tetapi 'wamaa yakhda`uuna', artinya 'tetapi mereka tidak berhasil menipu'.\qt@no{9}}%
\qt@newcmd\qurantrans@id@xvii{%
(Dalam hati mereka ada penyakit) berupa keragu-raguan dan kemunafikan yang menyebabkan sakit atau lemahnya hati mereka. (Lalu ditambah Allah penyakit mereka) dengan menurunkan Alquran yang mereka ingkari itu. (Dan bagi mereka siksa yang pedih) yang menyakitkan (disebabkan kedustaan mereka.) Yukadzdzibuuna dibaca pakai tasydid, artinya amat mendustakan, yakni terhadap Nabi Allah dan tanpa tasydid 'yakdzibuuna' yang berarti berdusta, yakni dengan mengakui beriman padahal tidak.\qt@no{10}}%
\qt@newcmd\qurantrans@id@xviii{%
(Dan jika dikatakan kepada mereka,) maksudnya kepada orang-orang munafik tadi ("Janganlah kamu membuat kerusakan di muka bumi!") yakni dengan kekafiran dan menyimpang dari keimanan. (Jawab mereka, ``Sesungguhnya kami ini berbuat kebaikan.") dan tidak dijumpai pada perbuatan kami hal-hal yang menjurus pada kebinasaan. Maka Allah swt. berfirman sebagai sanggahan atas ucapan mereka itu:\qt@no{11}}%
\qt@newcmd\qurantrans@id@xix{%
(Ingatlah!) Seruan untuk membangkitkan perhatian. (Sesungguhnya mereka itulah yang membuat kerusakan, tetapi mereka tidak sadar) akan kenyataan itu.\qt@no{12}}%
\qt@newcmd\qurantrans@id@xx{%
(Apabila dikatakan kepada mereka, ``Berimanlah kamu sebagaimana orang-orang lain beriman!") yakni sebagaimana berimannya para sahabat Nabi. (Jawab mereka, ``Apakah kami akan beriman sebagaimana berimannya orang-orang yang bodoh?") Artinya kami tidak akan melakukan seperti yang dilakukan oleh orang-orang yang bodoh itu. Maka firman Allah menolak ucapan mereka itu: (Ketahuilah, merekalah orang-orang bodoh tetapi mereka tidak tahu) akan hal itu.\qt@no{13}}%
\qt@newcmd\qurantrans@id@xxi{%
(Dan jika mereka berjumpa) asalnya 'laqiyuu' lalu damah pada ya dibuang karena beratnya pada lidah berikut ya itu sendiri karena bertemunya dalam keadaan sukun dengan wau sehingga menjadi 'laquu' (dengan orang yang beriman, mereka berkata, ``Kami telah beriman." Dan bila mereka telah berpisah) dengan orang-orang yang beriman dan kembali (kepada setan-setan mereka) maksudnya pemimpin-pemimpin mereka. (Kata mereka, ``Sesungguhnya kami ini bersama kamu) maksudnya sependirian dengan kamu dalam keagamaan, (kami ini hanya berolok-olok.") dengan berpura-pura beriman.\qt@no{14}}%
\qt@newcmd\qurantrans@id@xxii{%
(Allahlah yang memperolok-olokkan mereka) artinya membalas olok-olokkan itu dengan memperolok-olokkan mereka pula (dan membiarkan mereka) terpedaya (dalam kesesatan mereka) yakni melanggar batas disebabkan kekafiran (terumbang-ambing) dalam keadaan bingung tanpa tujuan atau pegangan.\qt@no{15}}%
\qt@newcmd\qurantrans@id@xxiii{%
(Mereka itulah orang-orang yang membeli kesesatan dengan petunjuk) artinya mengambil kesesatan sebagai pengganti petunjuk (maka tidaklah beruntung perniagaan mereka) bahkan sebaliknya mereka merugi, karena membawa mereka ke dalam neraka yang menjadi tempat kediaman mereka untuk selama-lamanya. (Dan tidaklah mereka mendapat petunjuk) disebabkan perbuatan mereka itu.\qt@no{16}}%
\qt@newcmd\qurantrans@id@xxiv{%
(Perumpamaan mereka) sifat mereka dalam kemunafikannya itu, (seperti orang yang menyalakan) atau menghidupkan (api) dalam kegelapan (dan setelah api itu menerangi) atau menyinari (apa yang di sekelilingnya) hingga ia dapat melihat, berdiang dan merasa aman dari apa yang ditakutinya (Allah pun menghilangkan cahaya yang menyinari mereka) yaitu dengan memadamkannya. Kata ganti orang dijadikan jamak 'him' merujuk kepada makna 'alladzii' (dan meninggalkan mereka dalam kegelapan tidak dapat melihat) apa yang terdapat di sekeliling mereka, sehingga tidak tahu jalan dan mereka dalam keadaan kecemasan. Demikianlah halnya orang-orang munafik yang mengucapkan kata-kata beriman, bila mereka mati mereka akan ditimpa ketakutan dan azab.\qt@no{17}}%
\qt@newcmd\qurantrans@id@xxv{%
(Mereka tuli) terhadap kebenaran, maksudnya tidak mau menerima kebenaran yang didengarnya (bisu) terhadap kebaikan hingga tidak mampu mengucapkannya (buta) terhadap jalan kebenaran dan petunjuk Allah sehingga tidak dapat melihatnya, (maka mereka tidaklah akan kembali) dari kesesatan.\qt@no{18}}%
\qt@newcmd\qurantrans@id@xxvi{%
(Atau) perumpamaan mereka itu, (seperti hujan lebat) maksudnya seperti orang-orang yang ditimpa hujan lebat; asal kata shayyibin dari shaaba-yashuubu, artinya turun (dari langit) maksudnya dari awan (padanya) yakni pada awan itu (kegelapan) yang tebal, (dan guruh) maksudnya malaikat yang mengurusnya. Ada pula yang mengatakan suara dari malaikat itu, (dan kilat) yakni kilatan suara yang dikeluarkannya untuk menghardik, (mereka menaruh) maksudnya orang-orang yang ditimpa hujan lebat tadi (jari-jemari mereka) maksudnya dengan ujung jari, (pada telinga mereka, dari) maksudnya disebabkan (bunyi petir) yang amat keras itu supaya tidak kedengaran karena (takut mati) bila mendengarnya. Demikianlah orang-orang tadi, jika diturunkan kepada mereka Alquran disebutkan kekafiran yang diserupakan dengan gelap gulita, ancaman yang dibandingkan dengan guruh serta keterangan-keterangan nyata yang disamakan dengan kilat, mereka menyumbat anak-anak telinga mereka agar tidak mendengarnya, karena takut akan terpengaruh lalu cenderung kepada keimanan yang akan menyebabkan mereka meninggalkan agama mereka, yang bagi mereka sama artinya dengan kematian. (Dan Allah meliputi orang-orang kafir) baik dengan ilmu maupun dengan kekuasaan-Nya hingga tidak sesuatu pun yang luput dari-Nya.\qt@no{19}}%
\qt@newcmd\qurantrans@id@xxvii{%
(Hampir saja) maksudnya mendekati (kilat menyambar penglihatan mereka) merebutnya dengan cepat. (Setiap kali kilat itu menyinari mereka, mereka berjalan padanya) maksudnya pada cahaya atau di bawah sinarnya, (dan bila gelap menimpa mereka, mereka pun berhenti) sebagai tamsil dari bukti-bukti keterangan ayat-ayat Alquran yang mengejutkan hati mereka. Mereka membenarkannya setelah mendengar padanya hal-hal yang mereka senangi sehingga mereka berhenti dari apa-apa yang dibencinya. (Sekiranya Allah menghendaki, niscaya dilenyapkan-Nya pendengaran dan penglihatan mereka) baik yang lahir maupun yang batin (Sesungguhnya Allah Maha Kuasa atas segala sesuatu) yang dikehendaki-Nya, termasuk apa-apa yang telah disebutkan tadi.\qt@no{20}}%
\qt@newcmd\qurantrans@id@xxviii{%
(Hai manusia!) Maksudnya warga Mekah, (Sembahlah olehmu) dengan bertauhid atau mengesakan (Tuhanmu yang telah menciptakanmu) padahal sebelum itu kamu dalam keadaan tiada (dan) diciptakan-Nya pula (orang-orang yang sebelum kamu, agar kamu bertakwa), artinya terpelihara dari siksa dan azab-Nya yakni dengan jalan beribadah kepada-Nya. Pada asalnya 'la`alla' mengungkapkan harapan, tetapi pada firman Allah berarti menyatakan kepastian.\qt@no{21}}%
\qt@newcmd\qurantrans@id@xxix{%
(Dialah yang telah menjadikan) menciptakan (bagimu bumi sebagai hamparan), yakni hamparan yang tidak begitu keras dan tidak pula begitu lunak sehingga tidak mungkin didiami secara tetap (dan langit sebagai naungan) sebagai atap (dan diturunkan-Nya dari langit air hujan lalu dikeluarkan-Nya daripadanya) maksudnya bermacam (buah-buahan sebagai rezeki bagi kamu) buat kamu makan dan kamu berikan rumputnya pada binatang ternakmu (maka janganlah kamu adakan sekutu-sekutu bagi Allah), artinya serikat-serikat-Nya dalam pengabdian (padahal kamu mengetahui) bahwa Dia adalah pencipta, sedangkan mereka itu tidak dapat menciptakan apa-apa, maka tidaklah layak disebut dan dikatakan tuhan.\qt@no{22}}%
\qt@newcmd\qurantrans@id@xxx{%
(Sekiranya kamu merasa ragu) atau bimbang (tentang apa yang Kami turunkan kepada hamba Kami) maksudnya tentang Alquran yang Kami wahyukan kepada Muhammad, bahwa itu benar-benar dari Allah, (maka buatlah sebuah surah yang sebanding dengannya) dengan surah yang diwahyukan itu. 'Min mitslihi', min yang berarti dari, maksudnya di sini ialah untuk menjadi keterangan atau penjelasan, hingga artinya ialah yang sebanding dengannya, baik dalam kedalaman makna maupun dalam keindahan susunan kata serta pemberitaan tentang hal-hal gaib dan sebagainya. Yang dimaksud dengan 'surah' ialah suatu penggal perkataan yang mempunyai permulaan kesudahan dan sekurang-kurangnya terdiri dari tiga ayat. (Dan ajaklah saksi-saksimu) maksudnya tuhan-tuhanmu yang kamu sembah itu (selain dari Allah) untuk menjadi penolong-penolongmu, (jika kamu orang-orang yang benar) bahwa Alquran itu hanyalah buatan dan ucapan Muhammad belaka, maka cobalah lakukan demikian, bukankah kamu orang-orang yang berlidah fasih seperti Muhammad pula?\qt@no{23}}%
\qt@newcmd\qurantrans@id@xxxi{%
Tatkala mereka tidak mampu memenuhi permintaan itu, maka Allah swt. berfirman, (Dan jika kamu tidak dapat melakukan) apa yang disebutkan itu disebabkan kelemahan dan ketidakmampuanmu (dan kamu pasti tidak akan dapat melakukannya) demikian itu untuk selama-lamanya disebabkan terhalang mukjizat Alquran itu, (maka jagalah dirimu dari neraka) dengan jalan beriman kepada Allah dan meyakini bahwa Alquran itu bukanlah ucapan manusia (yang kayu apinya terdiri dari manusia), yakni orang-orang kafir (dan batu), misalnya yang dipakai untuk membuat patung-patung atau berhala-berhala mereka. Maksudnya api neraka itu amat panas dan tambah menyala dengan bahan bakar manusia dan batu jadi bukan seperti api dunia yang hanya dapat dinyalakan dengan kayu bakar atau yang lainnya (yang disediakan bagi orang-orang kafir) sebagai alat untuk menyiksa mereka. Kalimat belakang ini dapat menjadi kalimat baru atau menunjukkan keadaan yang lazim.\qt@no{24}}%
\qt@newcmd\qurantrans@id@xxxii{%
(Dan sampaikanlah berita gembira) kabarkanlah (kepada orang-orang yang beriman) yang membenarkan Allah (dan mengerjakan kebaikan), baik yang fardu atau yang sunah (bahwa bagi mereka disediakan surga-surga), yaitu taman-taman yang ada pepohonan dan tempat-tempat kediaman (yang mengalir di bawahnya) maksudnya di bawah kayu-kayuan dan mahligai-mahligainya (sungai-sungai) maksudnya air yang berada di sungai-sungai itu, karena sungai artinya ialah galian tempat mengalirnya air, sebab airlah yang telah menggali atau menjadikannya 'nahr' dan menisbatkan 'mengalir' pada selokan disebut 'majaz' atau simbolisme. (Setiap mereka diberi rezeki di dalam surga itu) maksudnya diberi makanan (berupa buah-buahan, mereka mengatakan, ``Inilah yang pernah) maksudnya seperti inilah yang pernah (diberikan kepada kami dulu"), yakni sebelum masuk surga, karena buah-buahan itu seperti itu pula ciri masing-masingnya, hampir serupa. (Mereka disuguhi) atau dipetikkan buah itu (dalam keadaan serupa), yakni warnanya tetapi berbeda rasanya, (dan diberi istri-istri) berupa wanita-wanita cantik dan selainnya, (yang suci) suci dari haid dan dari kotoran lainnya, (dan mereka kekal di dalamnya) untuk selama-lamanya, hingga mereka tak pernah fana dan tidak pula dikeluarkan dari dalamnya.\qt@no{25}}%
\qt@newcmd\qurantrans@id@xxxiii{%
Untuk menolak perkataan orang-orang Yahudi, ``Apa maksud Allah menyebutkan barang-barang hina ini", yakni ketika Allah mengambil perbandingan pada lalat dalam firman-Nya, ``... dan sekiranya lalat mengambil sesuatu dari mereka" dan pada laba-laba dalam firman-Nya, ``Tak ubahnya seperti laba-laba," Allah menurunkan: (Sesungguhnya Allah tidak segan membuat) atau mengambil (perbandingan) berfungsi sebagai maf`ul awal atau obyek pertama, sedangkan (apa juga) kata penyerta yang diberi keterangan dengan kata-kata yang di belakangnya menjadi maf`ul tsani atau obyek kedua hingga berarti tamsil perbandingan apa pun jua. Atau dapat juga sebagai tambahan untuk memperkuat kehinaan, sedangkan kata-kata di belakangnya menjadi maf`ul tsani (seekor nyamuk) yakni serangga kecil, (atau yang lebih atas dari itu) artinya yang lebih besar dari itu, maksudnya Allah tak hendak mengabaikan hal-hal tersebut, karena mengandung hukum yang perlu diterangkan-Nya. (Ada pun orang-orang yang beriman, maka mereka yakin bahwa ia), maksudnya perumpamaan itu (benar), tepat dan cocok dengan situasinya (dari Tuhan mereka, tetapi orang-orang kafir mengatakan, ``Apakah maksud Allah menjadikan ini sebagai perumpamaan?") Matsalan atau perumpamaan itu berfungsi sebagai tamyiz hingga berarti dengan perumpamaan ini. 'Ma' yang berarti 'apakah' merupakan kata-kata pertanyaan disertai kecaman dan berfungsi sebagai mubtada atau subyek. Sedangkan 'dza' berarti yang berikut shilahnya atau kata-kata pelengkapnya menjadi khabar atau predikat, hingga maksudnya ialah 'apa gunanya?' Sebagai jawaban terhadap mereka Allah berfirman: (Allah menyesatkan dengannya), maksudnya dengan tamsil perbandingan ini, (banyak manusia) berpaling dari kebenaran disebabkan kekafiran mereka terhadapnya, (dan dengan perumpamaan itu, banyak pula orang yang diberi-Nya petunjuk), yaitu dari golongan orang-orang beriman disebabkan mereka membenarkan dan mempercayainya (Tetapi yang disesatkan-Nya itu hanyalah orang-orang yang fasik), yakni yang menyimpang dan tak mau menaati-Nya.\qt@no{26}}%
\qt@newcmd\qurantrans@id@xxxiv{%
(Orang-orang yang) merupakan 'na`at' atau sifat (melanggar janji Allah) melanggar kewajiban yang ditugaskan Allah kepada mereka dalam Kitab-Kitab Suci berupa keimanan kepada Nabi Muhammad saw. (setelah teguhnya) setelah kukuhnya perjanjian itu, (dan memutus apa yang diperintahkan Allah dengannya untuk dihubungkan), yakni beriman dan menghubungkan silaturahmi dengan Nabi saw. serta lain-lainnya. Anak kalimat 'untuk dihubungkan' menjadi kata ganti dari 'dengannya', (dan membuat kerusakan di muka bumi) dengan melakukan maksiat serta menyimpang dari keimanan (merekalah) orang-orang yang mempunyai sifat seperti yang dilukiskan itu (orang-orang yang rugi) karena mereka dimasukkan ke dalam neraka untuk selama-lamanya.\qt@no{27}}%
\qt@newcmd\qurantrans@id@xxxv{%
(Mengapa kamu kafir) hai warga Mekah? (kepada Allah, padahal) sesungguhnya (tadinya kamu mati) yakni ketika masih menjadi mani dalam sulbi bapakmu (lalu kamu dihidupkan-Nya) dalam rahim ibumu dan di dunia dengan jalan meniupkan roh pada tubuhmu. Pertanyaan di sini untuk menyatakan keheranan atas kekafiran mereka padahal bukti-bukti cukup ada atau dapat juga sebagai celaan dan kecaman terhadap mereka, (kemudian dimatikan-Nya) ketika sampainya ajalmu (lalu dihidupkan-Nya kembali) pada saat berbangkit (kemudian kamu dikembalikan kepada-Nya) yakni setelah berbangkit itu lalu dibalas-Nya amal perbuatanmu. Sebagai alasan kemungkinan saat berbangkit, Allah berfirman,\qt@no{28}}%
\qt@newcmd\qurantrans@id@xxxvi{%
(Dialah yang telah menciptakan bagimu segala yang terdapat di muka bumi) yaitu menciptakan bumi beserta isinya, (kesemuanya) agar kamu memperoleh manfaat dan mengambil perbandingan darinya, (kemudian Dia hendak menyengaja hendak menciptakan) artinya setelah menciptakan bumi tadi Dia bermaksud hendak menciptakan pula (langit, maka dijadikan-Nya langit itu) 'hunna' sebagai kata ganti benda yang dimaksud adalah langit itu. Maksudnya ialah dijadikan-Nya, sebagaimana didapati pada ayat yang lain, 'faqadhaahunna,' yang berarti maka ditetapkan-Nya mereka, (tujuh langit dan Dia Maha Mengetahui atas segala sesuatu) dikemukakan secara 'mujmal' ringkas atau secara mufasshal terinci, maksudnya, ``Tidakkah Allah yang mampu menciptakan semua itu dari mula pertama, padahal Dia lebih besar dan lebih hebat daripada kamu, akan mampu pula menghidupkan kamu kembali?"\qt@no{29}}%
\qt@newcmd\qurantrans@id@xxxvii{%
(Dan) ingatlah, hai Muhammad! (Ketika Tuhanmu berfirman kepada para malaikat, ``Sesungguhnya Aku hendak menjadikan seorang khalifah di muka bumi") yang akan mewakili Aku dalam melaksanakan hukum-hukum atau peraturan-peraturan-Ku padanya, yaitu Adam. (Kata mereka, ``Kenapa hendak Engkau jadikan di bumi itu orang yang akan berbuat kerusakan padanya) yakni dengan berbuat maksiat (dan menumpahkan darah) artinya mengalirkan darah dengan jalan pembunuhan sebagaimana dilakukan oleh bangsa jin yang juga mendiami bumi? Tatkala mereka telah berbuat kerusakan, Allah mengirim malaikat kepada mereka, maka dibuanglah mereka ke pulau-pulau dan ke gunung-gunung (padahal kami selalu bertasbih) maksudnya selalu mengucapkan tasbih (dengan memuji-Mu) yakni dengan membaca 'subhaanallaah wabihamdih', artinya 'Maha suci Allah dan aku memuji-Nya'. (dan menyucikan-Mu) membersihkan-Mu dari hal-hal yang tidak layak bagi-Mu. Huruf lam pada 'laka' itu hanya sebagai tambahan saja, sedangkan kalimat semenjak 'padahal' berfungsi sebagai 'hal' atau menunjukkan keadaan dan maksudnya adalah, 'padahal kami lebih layak untuk diangkat sebagai khalifah itu!'" (Allah berfirman,) ("Sesungguhnya Aku mengetahui apa yang tidak kamu ketahui") tentang maslahat atau kepentingan mengenai pengangkatan Adam dan bahwa di antara anak cucunya ada yang taat dan ada pula yang durhaka hingga terbukti dan tampaklah keadilan di antara mereka. Jawab mereka, ``Tuhan tidak pernah menciptakan makhluk yang lebih mulia dan lebih tahu dari kami, karena kami lebih dulu dan melihat apa yang tidak dilihatnya." Maka Allah Taala pun menciptakan Adam dari tanah atau lapisan bumi dengan mengambil dari setiap corak atau warnanya barang segenggam, lalu diaduk-Nya dengan bermacam-macam jenis air lalu dibentuk dan ditiupkan-Nya roh hingga menjadi makhluk yang dapat merasa, setelah sebelumnya hanya barang beku dan tidak bernyawa.\qt@no{30}}%
\qt@newcmd\qurantrans@id@xxxviii{%
(Dan diajarkan-Nya kepada Adam nama-nama) maksudnya nama-nama benda (kesemuanya) dengan jalan memasukkan ke dalam kalbunya pengetahuan tentang benda-benda itu (kemudian dikemukakan-Nya mereka) maksudnya benda-benda tadi yang ternyata bukan saja benda-benda mati, tetapi juga makhluk-makhluk berakal, (kepada para malaikat, lalu Allah berfirman) untuk memojokkan mereka, ("Beritahukanlah kepada-Ku) sebutkanlah (nama-nama mereka) yakni nama-nama benda itu (jika kamu memang benar.") bahwa tidak ada yang lebih tahu daripada kamu di antara makhluk-makhluk yang Kuciptakan atau bahwa kamulah yang lebih berhak untuk menjadi khalifah. Sebagai 'jawab syarat' ditunjukkan oleh kalimat sebelumnya.\qt@no{31}}%
\qt@newcmd\qurantrans@id@xxxix{%
(Jawab mereka, ``Maha suci Engkau!) artinya tidak sepatutnya kami akan menyanggah kehendak dan rencana-Mu (Tak ada yang kami ketahui, kecuali sekadar yang telah Engkau ajarkan kepada kami) mengenai benda-benda tersebut. (Sesungguhnya Engkaulah) sebagai 'taukid' atau penguat bagi Engkau yang pertama, (Yang Maha Tahu lagi Maha Bijaksana.") hingga tidak seorang pun yang lepas dari pengetahuan serta hikmah kebijaksanaan-Mu.\qt@no{32}}%
\qt@newcmd\qurantrans@id@xl{%
(Allah berfirman, ``Hai Adam! Beritahukanlah kepada mereka) maksudnya kepada para malaikat itu (nama mereka") yakni benda-benda itu. Maka disebutnya satu persatu menurut nama masing-masing berikut hikmah diciptakannya oleh Allah. (Maka setelah diberitahukannya kepada mereka nama benda-benda itu, Allah berfirman) kepada mereka guna mencela mereka, ("Bukankah sudah Kukatakan kepada kalian bahwa Aku mengetahui rahasia langit dan bumi) maksudnya mengetahui barang yang tersembunyi pada keduanya, (dan mengetahui apa yang kamu lahirkan) yaitu ucapan yang kamu keluarkan, yaitu, 'Kenapa hendak Engkau jadikan... dan seterusnya' (dan apa yang kamu sembunyikan.") yaitu ucapan yang kamu sembunyikan, seperti ``Allah tidak pernah menciptakan makhluk yang lebih mulia dan lebih pandai dari kami."\qt@no{33}}%
\qt@newcmd\qurantrans@id@xli{%
(Dan) ingatlah! (Ketika Kami berfirman kepada para malaikat, ``Sujudlah kalian kepada Adam!") Maksudnya sujud sebagai penghormatan dengan cara membungkukkan badan, (maka mereka pun sujud, kecuali Iblis) yakni nenek moyang bangsa jin yang ada di antara para malaikat, (ia enggan) tak hendak sujud (dan menyombongkan diri) dengan mengatakan bahwa ia lebih mulia daripada Adam (dan Iblis termasuk golongan yang kafir) dalam ilmu Allah Taala.\qt@no{34}}%
\qt@newcmd\qurantrans@id@xlii{%
(Dan Kami berfirman, ``Hai Adam! Berdiamlah kamu) yakni kamu sendiri 'kamu' yang kedua berfungsi sebagai penguat bagi yang pertama dan dihubungkan dengannya yang ditampilkan sebagai dhamir atau kata ganti yang tersembunyi (bersama istrimu) yakni Hawa yang diciptakan dari tulang rusuk Adam yang sebelah kiri (dalam surga ini dan makanlah di antara makanan-makanannya) (yang banyak) dan tidak dilarang (di mana saja kamu sukai, tetapi janganlah kamu dekati pohon ini) pohon anggur atau batang gandum ini atau lain-lainnya, maksudnya jangan memakan buahnya (hingga kamu menjadi orang-orang yang lalim.") atau durhaka.\qt@no{35}}%
\qt@newcmd\qurantrans@id@xliii{%
(Lalu keduanya digelincirkan oleh setan) oleh Iblis dan menurut suatu qiraat 'fa-azaalahumaa', artinya maka Iblis pun menyingkirkan keduanya (daripadanya), maksudnya dari dalam surga dengan memperdayakan serta mengatakan kepada mereka, ``Maukah kalian saya tunjukkan suatu macam pohon kekal yang akan mengekalkan kehidupan kalian? Itulah dia syajaratul khuldi atau pohon keabadian?" Ia tidak lupa bersumpah atas nama Allah bahwa mereka hanyalah hendak menyampaikan nasihat dan anjuran baik belaka. Maka Adam dan Hawa pun memakan buah itu, (dan Allah mengeluarkan mereka dari keadaan yang mereka alami semula), yakni dari nikmat surga (dan firman Kami, ``Turunlah kalian!") maksudnya ke bumi, yakni kalian berdua bersama anak cucu kalian itu (menjadi musuh bagi yang lain) disebabkan penganiayaan sebagian kalian terhadap lainnya, (dan bagi kalian tersedia tempat kediaman di bumi), artinya tempat menetap (dan kesenangan) berupa hasil tumbuh-tumbuhan yang kalian senangi dan dapat kalian nikmati (sampai waktu tertentu) maksudnya hingga saat datangnya ajal kalian nanti.\qt@no{36}}%
\qt@newcmd\qurantrans@id@xliv{%
(Kemudian Adam menerima beberapa kalimat dari Tuhannya), yakni dengan diilhamkan-Nya kepadanya, menurut suatu qiraat 'Adama' dibaca nashab, sedangkan 'kalimatun' dibaca rafa`, sehingga arti kalimat menjadi, ``maka datanglah kepada Adam kalimat dari Tuhannya", yakni yang berbunyi ``rabbanaa zhalamnaa anfusanaa", artinya ``Ya Tuhan kami, kami telah berbuat aniaya kepada diri kami... dan seterusnya". Maka Adam pun menyampaikan doanya dengan ayat tersebut. (maka Allah menerima tobatnya), artinya mengampuni dosanya (Sesungguhnya Dia Maha Penerima tobat) terhadap hamba-hamba-Nya (lagi Maha Penyayang) terhadap mereka.\qt@no{37}}%
\qt@newcmd\qurantrans@id@xlv{%
(Kami berfirman, ``Turunlah kalian daripadanya") maksudnya dari surga (semuanya) diulanginya dan dihubungkan-Nya dengan kalimat yang mula-mula tadi (kemudian jika) asalnya dari 'in maa' yang diidgamkan menjadi 'immaa' yang berarti jika; 'in' huruf syarat dan 'maa' sebagai tambahan. (datang petunjuk-Ku kepada kalian) berupa Kitab dan rasul, (maka barang siapa yang mengikuti petunjuk-Ku) lalu ia beriman kepada-Ku dan beramal serta taat kepada-Ku (niscaya tak ada kekhawatiran atas mereka dan tidak pula mereka berduka cita), yakni di akhirat kelak, karena mereka akan masuk surga.\qt@no{38}}%
\qt@newcmd\qurantrans@id@xlvi{%
(Adapun orang-orang yang kafir dan mendustakan ayat-ayat Kami) mendustakan kitab-kitab suci Kami (mereka itu penghuni neraka, mereka kekal di dalamnya) mereka tetap tinggal di sana untuk selama-lamanya, tidak akan mati dan tidak pula akan keluar.\qt@no{39}}%
\qt@newcmd\qurantrans@id@xlvii{%
(Hai Bani Israel!) maksudnya ialah anak cucu Yakub (Ingatlah akan nikmat karunia-Ku yang telah Kuberikan kepada kalian) maksudnya kepada nenek moyang kalian, berupa menyelamatkan kalian dari kejaran Firaun, membelah lautan, menaungkan awan dan lain-lain, yaitu mensyukurinya dengan jalan taat kepada-Ku, (dan penuhilah janji kalian kepada-Ku) yang telah kalian janjikan dulu, berupa keimanan kepada Muhammad (niscaya Kupenuhi pula janji-Ku kepada kalian) berupa pemberian pahala dan masuk surga (dan hanya kepada-Kulah kalian harus takut) hingga kalian tidak berani menyalahi janji itu, dan kalian tidak perlu takut kepada pihak lain.\qt@no{40}}%
\qt@newcmd\qurantrans@id@xlviii{%
(Dan berimanlah kalian pada apa yang Kuturunkan), yakni Alquran (yang membenarkan apa yang ada beserta kalian), yaitu Taurat berupa kesamaan dalam ketauhidan kenabian Muhammad (dan janganlah kalian menjadi orang yang pertama kafir kepadanya), yakni dari golongan Ahlul Kitab karena orang-orang yang di belakang itu hanya akan mengikuti sikap dan tindakan kalian, sehingga dosa kekafiran mereka akan terpikul di atas pundak kalian (dan janganlah kalian jual) janganlah kalian tukar (ayat-ayat-Ku) yang terdapat dalam Kitab Suci kalian tentang sifat-sifat dan ciri-ciri Muhammad (dengan harga yang rendah) dengan pengganti yang rendah nilainya berupa harta dunia. Maksudnya janganlah kalian sembunyikan karena khawatir tidak akan memperoleh lagi keuntungan-keuntungan yang kalian dapatkan selama ini dari nenek moyang kalian (dan hanya kepada-Kulah kalian harus bertakwa) maksudnya harus takut dalam hal itu dan bukan kepada selain-Ku.\qt@no{41}}%
\qt@newcmd\qurantrans@id@xlix{%
(Dan janganlah kalian campur aduk) (barang yang hak) yang telah Kuturunkan kepada kalian (dengan yang batil) yang kamu ada-adakan (dan) jangan pula (kalian sembunyikan yang hak itu) berupa sifat dan ciri-ciri Muhammad (sedangkan kalian mengetahui) bahwa ia hak adanya.\qt@no{42}}%
\qt@newcmd\qurantrans@id@l{%
(Dan dirikanlah salat, bayarkan zakat dan rukuklah bersama orang-orang yang rukuk) artinya salatlah bersama Muhammad dan para sahabatnya. Lalu Allah Taala menunjukkan kepada para ulama mereka yang pernah memesankan kepada kaum kerabat mereka yang masuk Islam, ``Tetaplah kalian dalam agama Muhammad, karena ia adalah agama yang benar!"\qt@no{43}}%
\qt@newcmd\qurantrans@id@li{%
(Mengapa kamu menyuruh orang lain berbuat kebaikan), yaitu beriman pada kerasulan Muhammad (sedang kamu melupakan dirimu sendiri) hingga kamu mengabaikannya dan tak mau beriman kepadanya (padahal kamu membaca Kitab), yakni Taurat, di dalamnya tercantum ancaman atau siksaan terhadap orang yang tidak sesuai perkataan dengan perbuatannya! (Tidaklah kamu pikirkan?) akan akibat jelek perbuatanmu agar kamu insaf? Yang menjadi bahan pertanyaan dan kecaman ialah kalimat ``sedang kamu melupakan..... dan seterusnya".\qt@no{44}}%
\qt@newcmd\qurantrans@id@lii{%
(Mintalah pertolongan) dalam menghadapi urusan atau kesulitan-kesulitanmu (dengan jalan bersabar) menahan diri dari hal-hal yang tidak baik (dengan salat). Khusus disebutkan di sini untuk menyatakan bagaimana pentingnya salat itu. Dalam sebuah hadis disebutkan bahwa jika Nabi saw. hatinya risau disebabkan sesuatu masalah, maka beliau segera melakukan salat. Ada pula yang mengatakan bahwa perkataan ini ditujukan kepada orang-orang Yahudi yang terhalang beriman disebabkan ketamakan dan ingin kedudukan. Maka mereka disuruh bersabar yang maksudnya ialah berpuasa, karena berpuasa dapat melenyapkan itu. Salat, karena dapat menimbulkan kekhusyukan dan membasmi ketakaburan. (Dan sesungguhnya ia) maksudnya salat (amat berat) akan terasa berat (kecuali bagi orang-orang yang khusyuk) yang cenderung kepada berbuat taat.\qt@no{45}}%
\qt@newcmd\qurantrans@id@liii{%
(Orang-orang yang yakin) (bahwa mereka akan menemui Tuhan mereka) ketika berbangkit (dan bahwa mereka akan kembali kepada-Nya), yaitu di akhirat dan bahwa Dia akan membalas segala perbuatan mereka.\qt@no{46}}%
\qt@newcmd\qurantrans@id@liv{%
(Hai Bani Israel! Ingatlah akan nikmat-Ku yang telah Kuanugerahkan kepadamu), yaitu mensyukurinya dengan jalan menaati-Ku (dan ingatlah pula bahwa Aku telah mengistimewakan kamu) maksudnya nenek moyangmu (atas penduduk dunia) maksudnya penduduk di zaman mereka itu.\qt@no{47}}%
\qt@newcmd\qurantrans@id@lv{%
(Dan takutlah olehmu) (suatu hari, yang pada hari itu tidak dapat membela) (seseorang atas orang lainnya walau sedikit pun) yakni pada hari kiamat (dan tidak diterima) ada yang membaca tuqbalu dengan ta dan ada pula yuqbalu dengan ya (daripadanya syafaat) artinya pada hari kiamat tidak ada perantara dan tak ada orang yang dapat dijadikan sebagai perantara (dan tidak pula tebusan) (dan tidaklah mereka akan ditolong) artinya dibebaskan dari azab Allah.\qt@no{48}}%
\qt@newcmd\qurantrans@id@lvi{%
(Dan) ingatlah (ketika Kami membebaskan kamu) maksudnya nenek moyangmu, ucapan ini dan yang berikutnya ditujukan kepada generasi yang terdapat di masa nabi kita, mengenai nikmat karunia yang dilimpahkan kepada nenek moyang mereka itu, agar mereka ingat kepadanya dan beriman kepada Allah Taala (dari kaum keluarga Firaun yang merasakan kepadamu) maksudnya menimpakan (sejelek-jelek siksaan) artinya siksaan yang amat berat. Kalimat itu merupakan 'hal' bagi kata ganti orang yang terdapat pada 'membebaskan kamu'. (Mereka menyembelih) merupakan penjelasan bagi kalimat yang sebelumnya (anak-anak lelakimu) (dan membiarkan hidup) artinya tidak membunuh (anak-anak perempuanmu). Hal ini disebabkan ramalan tukang tenung bahwa akan ada seorang anak lelaki kelahiran Bani Israel yang akan menjadi penyebab lenyapnya kerajaan Firaun itu. (Dan hal yang demikian itu) yakni siksaan atau pembebasan (menjadi cobaan) ujian atau pemberian nikmat (yang amat besar dari Tuhanmu)?\qt@no{49}}%
\qt@newcmd\qurantrans@id@lvii{%
(Dan) ingatlah (ketika Kami pisah) Kami belah (demi karenamu) (lautan) sehingga kamu dapat masuk dan melintasinya ketika melarikan diri dari musuhmu (lalu Kami selamatkan kamu) dari bahaya tenggelam, (dan Kami tenggelamkan keluarga Firaun) beserta kaumnya (sedang kamu sendiri menyaksikan) hal itu, yaitu bertautnya lautan yang menyungkup mereka.\qt@no{50}}%
\qt@newcmd\qurantrans@id@lviii{%
(Dan ingatlah ketika Kami menjanjikan) dalam sekian masa (kepada Musa selama empat puluh malam) maksudnya Kami janjikan akan memberinya Taurat setelah 40 malam untuk menjadi pedoman bagi kamu (lalu kamu ambil anak lembu) maksudnya patung anak lembu yang ditempa oleh Samiri menjadi tuhan (sepeninggalnya) artinya setelah ia pergi memenuhi perjanjian dengan Kami itu, (dan kamu adalah orang-orang aniaya) disebabkan menaruh sesuatu bukan pada tempatnya, yaitu mengambil anak lembu itu sebagai sembahan.\qt@no{51}}%
\qt@newcmd\qurantrans@id@lix{%
(Kemudian Kami maafkan kamu) Kami hapus dan ampuni kesalahanmu (setelah itu) setelah pengambilan patung menjadi tuhan (agar kamu bersyukur) dan menyadari nikmat karunia Kami kepadamu.\qt@no{52}}%
\qt@newcmd\qurantrans@id@lx{%
(Dan ingatlah ketika Kami berikan kepada Musa Alkitab) yakni kitab Taurat (dan pemisah) merupakan 'athaf tafsir' hubungan sebagai penjelasan bagi Taurat yang menjadi pemisah di antara yang hak dengan yang batil, yang halal dengan yang haram (agar kamu peroleh petunjuk) dengannya dari kesesatan.\qt@no{53}}%
\qt@newcmd\qurantrans@id@lxi{%
(Dan ketika Musa berkata kepada kaumnya) yang telah menyembah patung anak lembu itu ("Hai kaumku! Sesungguhnya kamu telah menganiaya dirimu karena kamu telah mengambil anak lembu) sebagai sembahan, (maka bertobatlah kamu kepada Tuhanmu) yang telah menciptakanmu atas kesalahanmu tidak menyembah kepada-Nya, (maka bunuhlah dirimu) maksudnya hendaklah yang tidak bersalah di antaramu membunuh yang bersalah. (Demikian itu) yakni membunuh itu (lebih baik bagimu di sisi Tuhanmu) hingga dituntun-Nya kamu untuk melakukannya dan dikirim-Nya awan hitam agar sebagian kamu tidak melihat lainnya yang akan menyebabkan timbulnya rasa kasihan di antara kamu yang akan menghalangi pembunuhan ini. Maka berhasillah pembunuhan masal itu sehingga yang tewas di antara kamu tidak kurang dari tujuh puluh ribu orang banyaknya. (Maka Allah menerima tobatmu. Sesungguhnya Dia Maha Penerima Tobat lagi Maha Penyayang").\qt@no{54}}%
\qt@newcmd\qurantrans@id@lxii{%
(Dan ketika kamu berkata) yaitu setelah kamu pergi bersama Musa untuk memohon ampun kepada Allah sebab menyembah patung anak lembu dan telah kamu dengar pula firman-Nya. ("Hai Musa! Kami tidak akan beriman kepadamu sebelum kami melihat Allah secara terang!") secara nyata. (Sebab itu kamu disambar petir) atau halilintar hingga kamu tewas (sedang kamu menyaksikannya) atas peristiwa yang menimpa dirimu itu.\qt@no{55}}%
\qt@newcmd\qurantrans@id@lxiii{%
(Setelah itu Kami bangkitkan kamu) maksudnya Kami hidupkan kembali kamu, (setelah kematian kamu agar kamu bersyukur) atas nikmat karunia Kami itu.\qt@no{56}}%
\qt@newcmd\qurantrans@id@lxiv{%
(Dan Kami naungi kamu dengan awan), artinya Kami taruh awan tipis di atas kepalamu agar kamu terlindung dari panasnya cahaya matahari di padang Tih, (dan Kami turunkan padamu) di padang Tih itu (manna dan salwa) yakni makanan manis seperti madu dan daging burung sebangsa puyuh dan firman Kami, ("Makanlah di antara makanan yang baik yang Kami karuniakan kepadamu.") dan janganlah kamu simpan! Tetapi mereka mengingkari nikmat itu dan mereka menyimpannya. Maka Allah pun menghentikan rezeki itu atas mereka (dan tidaklah mereka menganiaya Kami) dengan perbuatan itu, (tetapi mereka menganiaya diri mereka sendiri) karena bencananya kembali kepada mereka juga.\qt@no{57}}%
\qt@newcmd\qurantrans@id@lxv{%
(Dan ingatlah ketika Kami berfirman,) kepada mereka setelah mereka keluar dari bukit Tih, ("Masuklah kamu ke negeri ini"), yakni Baitulmakdis atau Yerusalem dan ada pula yang mengatakannya 'Ariha' (Maka makanlah di antara makanannya yang baik lagi enak mana yang kamu sukai) tanpa ada larangan (dan masukilah pintu gerbangnya) (dalam keadaan bersujud) artinya menundukkan diri (dan ucapkanlah) sebagai permohonan, ("Bebaskanlah kami dari dosa!") (niscaya Kami ampuni) menurut suatu qiraat 'yughfar', sedangkan menurut suatu qiraat lainnya 'tughfar', keduanya kata kerja pasif yang berarti 'diampuni' (bagimu kesalahan-kesalahanmu dan akan Kami tambah pula pemberian Kami kepada orang-orang yang berbuat baik) maksudnya diampuni karena berlaku taat, diberi tambahan, yakni pahalanya.\qt@no{58}}%
\qt@newcmd\qurantrans@id@lxvi{%
(Lalu orang-orang yang aniaya mengubah) di antara mereka (perintah yang tidak dititahkan kepada mereka) mereka mengatakan, habbatun fi sya`ratin, bahkan mereka memasukinya bukan dengan bersujud tetapi merangkak di atas pantat mereka. (Maka Kami timpakan atas orang-orang yang aniaya itu) di sini disebutkan ``atas orang-orang yang aniaya itu", yang sebenarnya cukup dengan kata ganti 'mereka' saja, dengan maksud sebagai kecaman (siksa) berupa penyakit taun (dari langit disebabkan kefasikan mereka) disebabkan mereka melanggar ketaatan. Maka dalam waktu satu jam ada 70 ribu orang atau mendekati jumlah itu di antara mereka yang mati.\qt@no{59}}%
\qt@newcmd\qurantrans@id@lxvii{%
(Dan) ingatlah (ketika Musa memohon air) (untuk kaumnya) yakni ketika mereka telah kehausan di padang Tih (lalu firman Kami, ``Pukulkanlah tongkatmu ke atas batu itu!") yaitu batu yang pernah membawa lari pakaiannya, bentuknya tipis persegi empat sebesar kepala manusia, batu lunak atau seperti keduanya lalu dipukulkannya (maka terpancarlah) terbelahlah batu itu lalu keluar air (daripadanya dua belas mata air) yaitu sebanyak jumlah suku Bani Israel (sesungguhnya telah mengetahui tiap-tiap suku) yakni tiap-tiap suku di antara mereka (tempat minum mereka) masing-masing hingga mereka tidak saling berebut. Lalu firman Kami kepada mereka, ("Makan dan minumlah rezeki yang diberikan Allah dan janganlah kamu berbuat keonaran di muka bumi dengan melakukan pengrusakan!") 'Mufsidiin' menjadi 'hal' yang memperkuat perbuatan pelaku '`atsiya' yang berarti berbuat keonaran.\qt@no{60}}%
\qt@newcmd\qurantrans@id@lxviii{%
(Dan ketika kamu berkata, ``Hai Musa! Kami tidak bisa tahan dengan satu makanan saja!") maksudnya satu macam saja, yaitu manna dan salwa. (Oleh sebab itu mohonkanlah untuk kami kepada Tuhanmu, agar Dia mengeluarkan bagi kami) sesuatu (dari apa yang ditumbuhkan bumi berupa) sebagai penjelasan (sayur-mayur, ketimun, bawang putih) (kacang adas dan bawang merah, maka jawabnya) yaitu jawab Musa kepada mereka, ("Maukah kamu mengambil sesuatu yang lebih rendah atau lebih jelek sebagai pengganti) (dari yang lebih baik) atau lebih utama?" Pertanyaan ini berarti penolakan, tetapi mereka tidak mau menarik permintaan itu hingga Musa pun berdoa kepada Allah, maka Allah Taala berfirman, ("Turunlah kamu) pergilah (ke salah satu kota) di antara kota-kota (pastilah kamu akan memperoleh) di sana (apa yang kamu minta") dari tumbuh-tumbuhan itu. (Lalu dipukulkan) ditimpakan (atas mereka kenistaan) kehinaan dan kenistaan (dan kemiskinan) yakni bekas-bekas dan pengaruh kemiskinan berupa sikap statis dan rendah diri yang akan selalu menyertai mereka walaupun mereka kaya, tak ubahnya bagai mata uang yang selalu menurut dan tidak akan lepas dari cetakannya, (dan kembalilah mereka) (membawa kemurkaan dari Allah, demikian itu), yakni pukulan dan kemurkaan Allah itu (disebabkan mereka) (mengingkari ayat-ayat Allah dan membunuh para nabi) seperti Nabi Zakaria dan Yahya (tanpa hak) hanya karena keaniayaan semata. (Demikian itu terjadi karena mereka selalu berbuat kedurhakaan dan karena mereka melanggar batas) artinya batas-batas peraturan hingga jatuh ke dalam maksiat. Kalimat pertama diulangnya untuk memperkuatnya.\qt@no{61}}%
\qt@newcmd\qurantrans@id@lxix{%
(Sesungguhnya orang-orang yang beriman) kepada para nabi di masa lalu (dan orang-orang Yahudi) (orang-orang Kristen dan orang-orang Shabiin) yakni segolongan dari orang-orang Yahudi atau Nasrani (siapa saja yang beriman) di antara mereka (kepada Allah dan hari akhir) di masa nabi kita (serta mengerjakan amal saleh) yaitu syariatnya (mereka akan memperoleh pahala) sebagai ganjaran dari amal perbuatan mereka itu (di sisi Tuhan mereka, tak ada kekhawatiran terhadap mereka dan tidak pula mereka berduka cita). Dhamir atau kata ganti orang pada 'aamana', 'amila' dan sesudahnya hendaklah diartikan secara umum atau siapa saja.\qt@no{62}}%
\qt@newcmd\qurantrans@id@lxx{%
(Dan) ingatlah (ketika Kami mengambil ikrar darimu) yakni ikrar bahwa kamu akan melakukan ajaran-ajaran yang terdapat dalam Taurat. (dan) sesungguhnya (Kami angkat gunung Thursina ke atasmu) artinya Kami cabut dari dasarnya untuk ditimpakan kepadamu, yakni tatkala kamu tidak mau berikrar seraya Kami berfirman, ("Peganglah dengan teguh apa yang Kami berikan kepadamu ini!) maksudnya secara giat dan sungguh-sungguh (dan ingatlah baik-baik apa yang ada di dalamnya) yakni dengan mengamalkannya (agar kamu termasuk orang-orang yang bertakwa.") Artinya terpelihara dirimu dari api neraka dan perbuatan durhaka.\qt@no{63}}%
\qt@newcmd\qurantrans@id@lxxi{%
(Kemudian kamu berpaling) menyalahi ikrar (setelah itu) maksudnya setelah berikrar tadi (maka kalau tidak ada karunia Allah dan rahmat-Nya kepadamu) yaitu dengan menerima tobatnya atau menangguhkan siksa terhadapmu (niscayalah kamu akan termasuk orang-orang yang merugi) atau celaka.\qt@no{64}}%
\qt@newcmd\qurantrans@id@lxxii{%
(Dan sesungguhnya) lam-nya 'lam qasam' menyatakan bersumpah artinya 'demi' (kamu telah mengetahui) (orang-orang yang melanggar) peraturan (di antaramu pada hari Sabtu) yakni dengan menangkap ikan padahal Kami telah melarangmu dari demikian; dan mereka ini ialah penduduk Eilat atau Ayilah (lalu Kami titahkan kepada mereka, ``Jadilah kalian kera yang hina!") artinya yang terkucil. Apa yang dikehendaki Allah itu pun terlaksana dan setelah masa tiga hari mereka menemui kematian.\qt@no{65}}%
\qt@newcmd\qurantrans@id@lxxiii{%
(Maka Kami jadikan dia) maksudnya hukuman tersebut (sebagai peringatan) cermin perbandingan hingga mereka tidak melakukannya lagi (bagi umat-umat di masa itu dan bagi mereka yang datang kemudian) (serta menjadi pengajaran bagi orang-orang yang bertakwa) kepada Allah Taala. Dikhususkan bagi orang-orang ini, karena hanya merekalah yang dapat mengambil manfaat darinya sedangkan orang lain tidak.\qt@no{66}}%
\qt@newcmd\qurantrans@id@lxxiv{%
(Dan) ingatlah (ketika Musa berkata kepada kaumnya,) yakni ketika ada di antara mereka itu seseorang yang terbunuh sedangkan mereka tidak tahu siapa pembunuhnya, lalu mereka minta kepada Musa untuk memohonkan kepada Allah agar Dia dapat memberitahukan siapa pembunuhnya itu. Maka dia memohon, lalu katanya, ("Sesungguhnya Allah menyuruh kamu menyembelih seekor sapi betina." Jawab mereka, ``Apakah kamu hendak menjadikan kami sebagai bahan ejekan?") artinya suruhan kamu itu akan menyebabkan kami menjadi sasaran olok-olok dan tertawaan orang. (Jawab Musa, ``Aku berlindung) maksudnya aku tidak sudi (kepada Allah) akan (menjadi golongan orang-orang yang jahil.") yang suka berolok-olok. Tatkala mereka ketahui bahwa Musa bersungguh-sungguh.\qt@no{67}}%
\qt@newcmd\qurantrans@id@lxxv{%
(Mereka bertanya, ``Mohonkanlah kepada Tuhanmu agar Dia menjelaskan kepada kami, sapi betina yang manakah itu?") maksudnya tentang usianya, apakah yang tua atau yang muda? (Jawab Musa, ``Allah berfirman bahwa sapi itu ialah sapi betina yang tidak tua) berusia lanjut (dan tidak pula muda) atau terlalu kecil, tetapi (pertengahan) (di antara demikian), yakni di antara tua dan muda tadi (maka lakukanlah apa yang diperintahkan kepadamu.") yaitu supaya menyembelih sapi yang telah dijelaskan itu.\qt@no{68}}%
\qt@newcmd\qurantrans@id@lxxvi{%
(Kata mereka, ``Mohonkanlah kepada Tuhanmu untuk kami agar dijelaskan-Nya kepada kami apa warnanya!" Jawab Musa, ``Allah berfirman bahwa sapi betina itu ialah sapi betina yang kuning, yakni yang kuning tua warnanya, maksudnya yang kuning pekat (yang menyenangkan orang-orang yang memandang.") artinya menarik hati mereka disebabkan keelokannya.\qt@no{69}}%
\qt@newcmd\qurantrans@id@lxxvii{%
(Kata mereka, ``Mohonkanlah kepada Tuhanmu untuk kami agar dijelaskan-Nya bagi kami hakikat sapi betina itu) apakah yang dimanjakan ataukah yang dipekerjakan? (karena sesungguhnya sapi itu) yakni kalau jenisnya baru yang disebutkan sifatnya itu (masih samar bagi kami) karena banyaknya hingga kami tidak mengetahui mana yang dimaksud (dan sesungguhnya kami insya Allah akan memperoleh petunjuk.") untuk mendapatkannya. Dalam sebuah hadis disebutkan bahwa sekiranya mereka tidak mengucapkan insya Allah, tidaklah akan dijelaskan kepada mereka untuk selama-lamanya.\qt@no{70}}%
\qt@newcmd\qurantrans@id@lxxviii{%
(Kata Musa, ``Allah berfirman bahwa sapi betina itu ialah sapi betina yang belum pernah dipakai untuk bekerja) (membajak tanah) untuk ditanami. Kalimat belakang ini menjadi sifat bagi 'dipakai untuk bekerja' dan termasuk barang yang dinafikan. (dan tidak pula untuk mengairi tanaman) atau tanah yang dipersiapkan untuk ditanami tumbuh-tumbuhan (tidak bercacat) bebas dari aib dan bekas-bekas bekerja berat (tidak ada belangnya.") tidak ada warna lain dari warna aslinya. (Kata mereka, ``Sekarang barulah kamu mengatakan kebenaran.") Maksudnya memberikan penjelasan yang cukup jelas tentang sapi yang dimaksud. Mereka cari sapi tersebut dan kebetulan ditemukan pada seorang anak muda yang berbakti kepada ibunya, lalu mereka beli dengan emas sepenuh bungkusan yang terbuat dari kulit sapi itu. (Lalu mereka menyembelihnya dan hampir saja mereka tidak melaksanakannya) karena harganya yang tinggi. Dalam sebuah hadis disebutkan, seandainya mereka segera menyembelih seekor sapi betina yang ada tanpa banyak tanya, yang demikian itu akan mencukupi. Tetapi mereka menyusahkan diri mereka sendiri sehingga dipersulit oleh Allah.\qt@no{71}}%
\qt@newcmd\qurantrans@id@lxxix{%
(Dan ketika kamu membunuh seorang manusia, lalu kamu tuduh-menuduh tentang hal itu) asalnya fatadaara'tum, lalu ta diidgamkan ke dal yang berarti bertengkar dan saling menuduh (sedangkan Allah menyingkapkan) atau memperlihatkan (apa yang kamu sembunyikan) tentang persoalan tersebut. Kalimat ini adalah suatu interupsi dan merupakan awal kisah\qt@no{72}}%
\qt@newcmd\qurantrans@id@lxxx{%
(Lalu firman Kami, ``Pukullah dia) maksudnya mayat dari orang yang terbunuh tadi (dengan salah satu anggota badan sapi betina itu!") Lalu mereka pukul dengan lidah atau pangkal ekornya sehingga ia pun hidup kembali dan mengatakan siapa pembunuhnya yang tiada lain dari dua orang saudara sepupunya yang disebutkan namanya masing-masing. Kemudian ia menjadi mayat kembali, maka kedua pembunuhnya tidak diperbolehkan untuk mendapatkan harta warisan, bahkan mereka pun dibunuh pula lalu firman Allah Taala, ("Demikianlah) maksudnya caranya (Allah menghidupkan kembali orang-orang yang telah mati dan memperlihatkan kepadamu tanda-tanda-Nya) bukti-bukti kekuasaan-Nya (agar kamu memikirkan") dan merenungkannya sehingga mengerti dan mengimani Allah yang kuasa menghidupkan seorang manusia yang telah meninggal juga sanggup menghidupkan berjuta-juta manusia lainnya.\qt@no{73}}%
\qt@newcmd\qurantrans@id@lxxxi{%
(Kemudian hatimu menjadi keras) ditujukan kepada orang-orang Yahudi hingga tak dapat dimasuki kebenaran (setelah itu) yakni setelah peristiwa dihidupkannya orang yang telah mati dan kejadian-kejadian sebelumnya, (maka ia adalah seperti batu) dalam kerasnya (atau lebih keras lagi) daripada batu. (Padahal di antara batu-batu itu sesungguhnya ada yang mengalir anak-anak sungai daripadanya dan di antaranya ada pula yang terbelah) asalnya 'yatasyaqqaqu' lalu ta diidgamkan pada syin hingga menjadi 'yasysyaqqaqu' (lalu keluarlah air daripadanya dan sesungguhnya di antaranya ada pula yang jatuh meluncur) dari atas ke bawah (karena takut kepada Allah) sebaliknya hatimu tidak terpengaruh karenanya serta tidak pula menjadi lunak atau tunduk. (Dan Allah sekali-kali tidak lengah terhadap apa yang kamu kerjakan) hanya ditangguhkan-Nya menjatuhkan hukuman hingga saatnya nanti. Menurut satu qiraat bukan 'ta`maluun' tetapi 'ya`maluun', artinya 'yang mereka kerjakan,' sehingga berarti mengalihkan arah pembicaraan.\qt@no{74}}%
\qt@newcmd\qurantrans@id@lxxxii{%
(Apakah masih kamu harapkan) hai orang beriman (bahwa mereka akan beriman) yakni orang-orang Yahudi itu (kepadamu, sedangkan sebagian) atau satu golongan (di antara mereka) yakni pendeta-pendeta mereka (mendengar firman Allah) yaitu Taurat (lalu mengubahnya) (setelah mereka memahaminya) (padahal mereka mengetahui) bahwa sebenarnya mereka mengada-ada. Pertanyaan di sini berarti sanggahan terhadap orang-orang beriman hingga berarti, ``Tak usah kamu harapkan mereka akan beriman karena dulu mereka juga sudah kafir!"\qt@no{75}}%
\qt@newcmd\qurantrans@id@lxxxiii{%
(Dan jika mereka berjumpa) maksudnya jika orang-orang Yahudi dan orang-orang munafik itu bertemu dengan (orang-orang beriman, mereka mengatakan, ``Kami pun telah beriman") bahwa Muhammad itu adalah seorang nabi yang telah diberitakan kedatangannya dalam kitab suci kami, (tetapi bila mereka telah kembali) atau berada (sesama mereka, maka kata mereka) yakni para pemimpin mereka yang bukan munafik kepada yang munafik itu, ("Apakah kamu hendak menceritakan kepada mereka) maksudnya kepada orang-orang mukmin (tentang apa yang telah dibukakan Allah kepada kamu) artinya tentang hal-hal yang telah diberitahukan Allah kepadamu dalam Taurat mengenai sifat-sifat dan ciri-ciri Muhammad (sehingga dengan demikian mereka dapat mematahkan alasanmu) 'lam' di sini berarti 'mengakibatkan' (dengannya di sisi Tuhanmu) yakni di akhirat kelak, di mana mereka akan dapat mengajukan bukti penyelewenganmu, yaitu tak hendak mengikuti Muhammad padahal mengetahui kebenarannya. (Tidaklah kamu mengerti?") bahwa mereka akan dapat mematahkan alasanmu jika kamu menyebut-nyebut soal itu? Dari itu hentikanlah tindakanmu itu!\qt@no{76}}%
\qt@newcmd\qurantrans@id@lxxxiv{%
(Tidakkah mereka ketahui) Pertanyaan di sini menunjukkan pengakuan, sehingga kalimat ini berarti bahwa mereka benar tidak mengetahui sedangkan wau yang terletak di depan menyatakan athaf atau adanya hubungan (bahwa Allah mengetahui apa yang mereka rahasiakan dan apa yang mereka lahirkan) tentang masalah-masalah tersebut hingga seharusnya mereka akan lebih hati-hati dan waspada.\qt@no{77}}%
\qt@newcmd\qurantrans@id@lxxxv{%
(Dan di antara mereka) di antara orang-orang Yahudi itu (ada yang buta huruf) atau orang-orang awam yang (tidak mengetahui Alkitab) maksudnya Taurat (kecuali) (angan-angan) atau kebohongan belaka, yakni yang mereka dengar dari para pemimpin mereka lalu mereka terima dan percayai. (Dan tiadalah) (mereka) yakni dalam menentang kenabian Muhammad dan soal-soal lainnya yang mereka buat-buat itu (kecuali hanyalah menduga-duga belaka) yakni dugaan yang tidak berdasarkan ilmu.\qt@no{78}}%
\qt@newcmd\qurantrans@id@lxxxvi{%
(Maka kecelakaan besarlah) atau siksaan berat (bagi orang-orang yang menulis Alkitab dengan tangan mereka sendiri) artinya membuat-buatnya menurut kemauan mereka (lalu mereka katakan, ``Ini dari Allah," dengan maksud untuk memperdagangkannya dengan harga murah) dengan tujuan untuk memperoleh keuntungan yang sedikit berupa harta dunia. Mereka ini ialah orang-orang Yahudi yang mengubah-ubah sifat-sifat nabi yang tercantum dalam Taurat, begitu pun ayat rajam dan lain-lain yang mereka tulis lain daripada yang dimaksud. (Maka siksaan beratlah bagi mereka karena apa yang ditulis oleh tangan mereka) disebabkan mereka mengada-ada yang tidak ada (dan siksaan beratlah bagi mereka, disebabkan apa yang mereka kerjakan) yakni melakukan penyelewengan dan kecurangan.\qt@no{79}}%
\qt@newcmd\qurantrans@id@lxxxvii{%
(Dan mereka berkata) yakni tatkala Nabi mengancam mereka dengan neraka, ("Kami sekali-kali takkan disentuh) tidak akan ditimpa sama sekali (oleh api neraka, kecuali selama hari-hari yang berbilang") maksudnya selama beberapa hari saja, yaitu selama 40 hari yakni selama waktu nenek moyang mereka menyembah patung lembu, kemudian siksaan itu akan berhenti. (Katakanlah) kepada mereka hai Muhammad, ("Apakah kamu telah menerima) hamzah washalnya dibuang karena cukup dengan adanya hamzah istifham (janji dari Allah) atau ikrar mengenai hal tersebut? (Sehingga Allah tidak akan menyalahi janji-Nya?) Tidak, bukan? (Ataukah) bahkan (kamu hanya mengatakan terhadap Allah apa yang tidak kamu ketahui").\qt@no{80}}%
\qt@newcmd\qurantrans@id@lxxxviii{%
(Tidak demikian yang sebenarnya) tetapi kamu pasti akan masuk neraka dan kekal di dalamnya. (Barang siapa yang berbuat kejahatan) atau kemusyrikan (dan ia dilingkungi oleh dosanya) dapat secara tunggal dan dapat pula secara jamak, maksudnya dosanya itu telah meliputi dan melingkunginya dari segala penjuru disebabkan kematiannya dalam keadaan musyrik (mereka itulah penghuni neraka, mereka kekal di dalamnya). Di sini dipakai jamak, dengan menitikberatkan arti 'man' atau 'barang siapa'.\qt@no{81}}%
\qt@newcmd\qurantrans@id@lxxxix{%
(Sebaliknya orang-orang yang beriman dan beramal saleh mereka itu penduduk surga, kekal mereka di dalamnya.)\qt@no{82}}%
\qt@newcmd\qurantrans@id@xc{%
(Dan) ingatlah (ketika Kami mengambil ikrar dari Bani Israel) maksudnya dalam Taurat, dan Kami katakan, ("Janganlah kamu menyembah) ada yang membaca dengan 'ta' dan ada pula dengan 'ya', yaitu 'laa ya`buduuna', artinya mereka tidak akan menyembah (kecuali kepada Allah). Kalimat ini merupakan kalimat berita tetapi berarti larangan. Ada pula yang membaca 'laa ta`buduu', artinya 'janganlah kamu sembah!' (Dan) berbuat kebaikanlah! (kepada kedua orang tua dengan sebaik-baiknya) maksudnya berbakti selain itu juga (kaum kerabat) athaf pada al-waalidain (anak-anak yatim dan orang-orang miskin serta ucapkanlah kepada manusia) kata-kata (yang baik) misalnya menyuruh pada yang baik dan melarang dari yang mungkar, berkata jujur mengenai diri Muhammad dan ramah tamah terhadap sesama manusia. Menurut suatu qiraat 'husna' dengan 'ha' baris di depan dan 'sin' sukun yang merupakan mashdar atau kata benda dan dipergunakan sebagai sifat dengan maksud untuk menyatakan 'teramat' artinya teramat baik. (Dan dirikanlah salat serta bayarkan zakat!) Sesungguhnya kamu telah memberikan ikrar tersebut. (Kemudian kamu tidak memenuhi) janji itu. Di sini tidak disebut-sebut orang ketiga, yaitu nenek moyang mereka (kecuali sebagian kecil dari kamu, dan kamu juga berpaling.") seperti halnya nenek moyangmu.\qt@no{83}}%
\qt@newcmd\qurantrans@id@xci{%
(Dan ingatlah ketika Kami menerima perjanjian pula darimu) dan firman Kami, ("Kamu tidak akan menumpahkan darahmu) artinya mengalirkannya dengan berbunuhan sesamamu (dan tidak akan mengeluarkan dirimu dari kampung halamanmu) dari negerimu. (Kemudian kamu berikrar) akan menepati perjanjian tersebut (sedangkan kamu mempersaksikan.") atas diri kamu sendiri.\qt@no{84}}%
\qt@newcmd\qurantrans@id@xcii{%
(Kemudian kamu) hai (Bani Israel, kamu bunuh dirimu) dengan berbunuhan sesamamu (dan kamu usir sebagian kamu dari kampung halaman mereka, kamu bertolong-tolongan) ta asalnya diidgamkan pada zha sehingga dibaca 'tazhzhaaharuuna', tetapi pada satu qiraat diringankan dengan membuangnya sehingga bacaannya menjadi 'tazhaaharuuna' dengan membuang zha yang berarti tolong-menolong (terhadap mereka dengan berbuat dosa) maksiat (dan permusuhan) atau penganiayaan. (Tetapi jika mereka datang kepadamu sebagai orang-orang tawanan) pada satu qiraat tercantum 'asra' (kamu tebus mereka) ada pula yang membaca 'tafduuhum', artinya kamu bebaskan mereka dari tawanan dengan harta atau lainnya dan ini termasuk kebiasaan yang berlaku di kalangan orang-orang Yahudi (padahal dia) artinya kenyataannya (mengusir mereka itu diharamkan bagimu). Kalimat ini berhubungan dengan firman-Nya, ``dan kamu usir," sedangkan kalimat-kalimat yang terdapat di antara keduanya merupakan 'jumlah mu`taridhah' atau interupsi, artinya sebagaimana diharamkannya mengabaikan tebusan. Selama ini suku Quraizhah mengadakan persekutuan dengan Aus, sedangkan Nadhir dengan Khajraj. Setiap suku ikut berperang bersama sekutu mereka, bahkan sampai menghancurkan dan mengusir pihak lawan walaupun sama-sama Yahudi. Tetapi jika Yahudi pihak lawan itu tertawan, maka mereka tebus. Jika ditanyakan kepada mereka, kenapa kamu perangi dan kamu tebus mereka, maka jawab mereka, ``Karena kami diminta mereka untuk memberikan tebusan." Jika ditanyakan, ``Kenapa pula kamu perangi mereka?" Jawab mereka, ``Karena kami merasa malu jika sekutu-sekutu kami menderita kekalahan!" Firman Allah Taala, ("Apakah kamu beriman pada sebagian Alkitab) yakni soal menebus tawanan (dan ingkar terhadap sebagian yang lain) agar tidak membunuh, tidak mengusir dan tidak bantu-membantu berbuat dosa dan penganiayaan. (Tidak ada balasan bagi orang yang berbuat demikian di antaramu kecuali kehinaan) atau kenistaan (dalam kehidupan dunia) kehinaan ini telah dialami oleh Bani Quraizhah dengan dibunuh dan dibasminya golongan laki-laki mereka, dan juga oleh Bani Nadhir yang diusir ke Syam dan diwajibkan membayar upeti. (Dan pada hari kiamat mereka dikembalikan pada siksaan yang amat berat dan Allah tidak lengah dari apa yang kamu kerjakan). Ada yang membaca dengan ta dan ada pula yang dengan ya.\qt@no{85}}%
\qt@newcmd\qurantrans@id@xciii{%
(Merekalah orang-orang yang membeli kehidupan dunia dengan kehidupan akhirat) artinya lebih mengutamakan dunia daripada akhirat (maka tidaklah akan diringankan siksa terhadap mereka dan tidaklah mereka akan beroleh bantuan") untuk menghindarkan siksaan itu.\qt@no{86}}%
\qt@newcmd\qurantrans@id@xciv{%
(Sesungguhnya Kami telah mendatangkan Alkitab kepada Musa) yakni Taurat, (lalu Kami susul setelah itu dengan para rasul) secara berturut-turut, artinya Kami kirim seorang rasul sesudah yang lain, (dan Kami berikan kepada Isa putra Maryam bukti-bukti kebenaran) yakni mukjizat menghidupkan mayat, menyembuhkan orang yang buta dan berpenyakit kusta. (Dan Kami perkuat ia dengan Roh Kudus) merupakan 'idhafat maushuf pada sifat' maksudnya ialah Roh yang disucikan yakni Jibril, sehingga karena kesuciannya ikut mengiringkannya ke mana pergi. Namun kamu tidak juga hendak mengikuti jalan yang benar! (Apakah setiap datang kepadamu seorang rasul dengan membawa apa yang tidak diingini) atau disukai (dirimu) berupa kebenaran (kamu menjadi takabur) atau menyombongkan diri, tak mau mengikutinya. Kalimat ini merupakan jawaban bagi 'setiap', dan dialah yang menjadi sasaran pertanyaan, sedangkan tujuannya tidak lain dari celaan dan kecaman, (maka sebagian) di antara mereka (kamu dustakan) seperti Nabi Isa (dan sebagian lagi kamu bunuh) kata kerja 'mudhari'' atau masa sekarang untuk menunjukkan peristiwa di masa lampau, artinya telah kamu bunuh Zakaria dan Yahya.\qt@no{87}}%
\qt@newcmd\qurantrans@id@xcv{%
(Dan mereka berkata) kepada nabi untuk berolok-olok, ("Hati kami tertutup") jamak dari 'aghlaf' yang berarti dibungkus tertutup rapat, sehingga tak dapat mendengar apa yang dikatakan orang. Firman Allah Taala, ("Tetapi) menegaskan kenyataan sebenarnya (Allah telah mengutuk mereka) menjauhkan mereka dari rahmat-Nya dengan menolak permohonan mereka sehingga mereka menjadi putus asa (disebabkan kekafiran mereka) jadi bukanlah karena cacat pada hati mereka, (maka hanya sedikit sekali mereka yang beriman"). 'Maa' merupakan tambahan untuk menunjukkan teramat sedikitnya mereka yang beriman itu.\qt@no{88}}%
\qt@newcmd\qurantrans@id@xcvi{%
(Dan tatkala datang kepada mereka Alquran dari Allah yang membenarkan apa yang ada pada mereka) yakni Taurat (padahal sebelumnya mereka) maksudnya sebelum datangnya Alquran itu (memohon pertolongan) agar beroleh kemenangan (atas orang-orang yang kafir) dengan mengucapkan, ``Ya Allah, tolonglah kami dengan nabi yang akan dibangkitkan di akhir zaman." (Maka setelah datang kepada mereka apa yang telah mereka ketahui) yaitu berupa kebenaran dengan diutusnya Nabi Muhammad itu (mereka lalu ingkar kepadanya) disebabkan kedengkian dan takut kehilangan pengaruh. Jawaban bagi 'lammaa' atau 'tatkala' yang pertama, ditunjukkan oleh jawaban 'lammaa' yang kedua (maka laknat Allahlah atas orang-orang yang kafir itu).\qt@no{89}}%
\qt@newcmd\qurantrans@id@xcvii{%
(Alangkah buruknya perbuatan mereka menjual) (diri mereka sendiri) maksudnya bagian pahala mereka. 'Ma' pada kata-kata 'bi'samaa' adalah kata 'nakirah' atau 'tidak tentu' (indefinit) dan berarti 'sesuatu', merupakan 'tamyiz' bagi pelaku kata kerja 'bi'sa' yang dikhususkan untuk celaan. (bahwa mereka kafir) artinya dengan kekafiran mereka (terhadap apa yang diturunkan Allah) berupa Alquran (disebabkan kedengkian) berfungsi sebagai 'maf`ul liajlih' menunjukkan motif bagi kekafiran mereka itu. (bahwa Allah menurunkan) ada yang membaca 'yunzila' dan ada pula 'yunazzila' (karunia-Nya) maksudnya wahyu (kepada siapa yang dikehendaki-Nya) untuk menjadi rasul (di antara hamba-hamba-Nya. Karena itu mereka kembali) (dengan kemurkaan) dari Allah disebabkan kekafiran mereka terhadap wahyu yang diturunkan itu. Celaan ini menyatakan betapa besarnya kesalahan yang mereka perbuat (di atas kemurkaan) artinya yang bertimpa-timpa yakni setelah kemurkaan yang selayaknya mereka terima sebelum itu, dengan menyia-nyiakan kitab Taurat serta menolak Nabi Isa. (Dan bagi orang-orang kafir disediakan siksaan yang menghinakan).\qt@no{90}}%
\qt@newcmd\qurantrans@id@xcviii{%
(Dan apabila dikatakan kepada mereka, ``Berimanlah kamu kepada apa yang diturunkan Allah!") yakni Alquran dan lain-lain (Mereka berkata, ``Kami beriman kepada apa yang diturunkan kepada kami.") yakni Taurat. Maka firman Allah Taala, (Sedangkan mereka kafir) 'wau' di sini menunjukkan 'hal' sehingga berarti 'sedangkan' (terhadap yang turun di belakangnya) atau selain dari itu seperti Alquran (padahal Alquran itulah yang hak) kalimat ini menjadi 'hal' (membenarkan) menjadi 'hal' yang kedua yang memperkuat (apa yang ada pada mereka. Katakanlah,) kepada mereka ("Kenapa kamu bunuh) (nabi-nabi Allah dulu, jika kamu benar-benar beriman?") pada Taurat, di mana padanya terdapat larangan membunuh mereka. Pertanyaan ini ditujukan kepada orang-orang Yahudi yang ada di masa nabi kita mengenai perbuatan nenek moyang mereka yang nyata-nyata mereka setujui.\qt@no{91}}%
\qt@newcmd\qurantrans@id@xcix{%
(Dan sesungguhnya telah datang kepada kamu sekalian Musa dengan membawa bukti-bukti kebenaran) maksudnya mukjizat seperti tongkat, tangan dan terbelahnya lautan (kemudian kamu ambil anak sapi) sebagai sembahan (sesudahnya) maksudnya sesudah kepergiannya ke mikat (bahkan kamu adalah orang-orang yang aniaya.) Karena telah menjadikan anak sapi sebagai sembahan.\qt@no{92}}%
\qt@newcmd\qurantrans@id@c{%
(Dan ketika Kami mengambil ikrar darimu) untuk mengamalkan apa yang terdapat dalam Taurat (dan) sungguh (Kami angkat bukit di atasmu) maksudnya bukit Sinai, yakni untuk dijatuhkan di atasmu karena kamu menolak untuk berikrar itu, seraya Kami berfirman, ("Peganglah apa yang Kami berikan padamu) maksudnya taatilah dengan serius dan bersungguh-sungguh (dan dengarkanlah!") Apa yang akan dititahkan kepadamu dengan patuh (Mereka menjawab, ``Kami dengar) firman-Mu (tetapi tak hendak kami patuhi.") perintah-Mu itu (dan diminumkan ke dalam hati mereka anak sapi) artinya diresapkan ke dalam hati mereka itu kecintaan menyembah anak sapi tak ubah bagai meresapnya minuman (karena kekafiran mereka. Katakanlah) kepada mereka, ("Teramat jahatlah apa) maksudnya sesuatu (yang diperintahkan oleh keimananmu) terhadap Taurat itu, yaitu pemujaan anak sapi (jika kamu benar-benar beriman.") kepadanya sebagai pengakuanmu itu! Maksud ayat, sebenarnya kamu tidak beriman, karena beriman yang sesungguhnya tidak mungkin menyuruh orang untuk menyembah anak sapi. Yang diceritakan di sini nenek moyang mereka, tetapi yang dituju ialah mereka sendiri seolah-olah Allah berfirman, ``Demikian pula halnya kamu tidak beriman pada Taurat, karena kamu mendustakan Muhammad, padahal keimanan pada kitab suci itu tak mungkin akan berakibat mendustakannya!"\qt@no{93}}%
\qt@newcmd\qurantrans@id@ci{%
(Katakanlah) kepada mereka, ("Jika kampung akhirat itu untukmu) maksudnya surga (khusus di sisi Allah) hanya untuk kamu (bukan untuk orang lain) seperti pengakuanmu (maka inginilah kematian jika kamu memang benar!") Dalam mengingini kematian itu bergantung dua syarat dengan ketentuan; yang pertama dikaitkan pada yang kedua, maksudnya, jika pengakuanmu benar bahwa surga itu hanya milikmu khusus, sedangkan menurut kebiasaan, seseorang ingin segera menemukan miliknya itu dan jalan untuk mendapatkan tiada lain hanya kematian, maka inginilah segera kematian itu olehmu!\qt@no{94}}%
\qt@newcmd\qurantrans@id@cii{%
(Dan mereka sekali-kali tak akan menginginkan kematian itu disebabkan kesalahan-kesalahan yang telah diperbuat oleh tangan mereka) berupa kekafiran kepada nabi sebagai akibat dari mendustakannya (dan Allah Maha Mengetahui terhadap orang-orang yang aniaya) yaitu orang-orang yang kafir, karenanya Allah pasti akan membalas mereka.\qt@no{95}}%
\qt@newcmd\qurantrans@id@ciii{%
(Dan demi sesungguhnya, akan kamu jumpai mereka itu) 'lam' menunjukkan sumpah (setamak-tamak manusia atas kehidupan dunia dan) lebih tamak lagi (dari orang-orang musyrik) yakni yang mengingkari hari berbangkit. Mereka tahu bahwa tempat kediaman mereka itu neraka; berbeda halnya dengan orang-orang musyrik yang mengingkari adanya hari akhirat itu. (Masing-masing mereka menginginkan) atau mengharapkan (agar diberi umur seribu tahun) 'lau' mashdariyah sama artinya dengan 'an' atau 'agar' dan dengan 'shilah-nya' ditakwilkan sebagai 'mashdar' atau 'kata benda', menjadi 'maf`ul bih' atau 'obyek penderita' dari 'yawaddu'. (Dan tidaklah dia) maksudnya masing-masing dari mereka (akan menjauhkannya) menyelamatkan dirinya (dari siksa) maksudnya neraka (karena ia diberi umur panjang itu). 'An' bersama shilahnya ini menjadi 'fa`il' atau 'pelaku' dari 'muzahzihihi'. (Dan Allah Maha Melihat akan apa yang mereka kerjakan) karena itu Allah akan membalasnya. Ada yang membaca dengan ya dan ada pula dengan ta. Ibnu Shuriya bertanya kepada Nabi saw. atau Umar, ``Siapakah di antara malaikat yang menyampaikan wahyu?" Jawabnya, 'Jibril.' Kata Ibnu Shuriya, ``Dia musuh kami yang selalu mendatangkan siksa atau kesengsaraan. Kalau saja Mikail, tentu kami akan beriman, karena dia yang membawa kemakmuran dan kedamaian." Lalu turunlah ayat berikutnya,\qt@no{96}}%
\qt@newcmd\qurantrans@id@civ{%
(Katakanlah) kepada mereka, ("Barang siapa yang menjadi musuh Jibril) maka silakan ia binasa dengan kebenciannya itu! (Maka sesungguhnya Jibril itu menurunkannya) maksudnya Alquran (ke dalam hatimu dengan seizin) atau perintah (Allah, membenarkan apa-apa yang berada di hadapannya) yaitu kitab-kitab suci yang turun sebelumnya (dan menjadi petunjuk) dari kesesatan (serta berita gembira) berupa surga (bagi orang-orang yang beriman).\qt@no{97}}%
\qt@newcmd\qurantrans@id@cv{%
(Barang siapa yang menjadi musuh Allah, malaikat-malaikat-Nya, rasul-rasul-Nya dan Jibril) ada yang membaca Jibriil ada pula yang membaca Jabriil atau Jabrail (dan Mikail) diathaf atau dihubungkan kepada malaikat dari jenis mengathafkan yang khas kepada yang umum. Ada pula yang membaca Mikail yaitu dengan hamzah serta ya dan ada pula Mikail dengan tambahan hamzah saja, (maka sesungguhnya Allah menjadi musuh bagi orang-orang yang kafir"). Orang itu ditempatkan pada suatu posisi untuk menyatakan keadaannya.\qt@no{98}}%
\qt@newcmd\qurantrans@id@cvi{%
(Dan sungguh, telah kami turunkan kepadamu) hai Muhammad (ayat-ayat yang jelas) atau terang, menjadi 'hal' sebagai sanggahan terhadap ucapan Ibnu Shuriya yang mengatakan kepada Nabi saw., ``Kamu datang kepada kami tanpa membawa sesuatu apa pun!" (Dan tak ada yang ingkar kepadanya kecuali orang-orang yang fasik)\qt@no{99}}%
\qt@newcmd\qurantrans@id@cvii{%
(Patutkah) mereka ingkar kepadanya (dan setiap mereka menjanjikan) kepada Allah (suatu janji) akan beriman kepada nabi jika telah dibangkitkan atau menjanjikan kepada nabi tidak akan membantu orang-orang yang musyrik untuk menentangnya (melemparkannya) yakni menjauhkannya (segolongan di antara mereka) yaitu dengan cara melanggarnya. Kalimat ini merupakan jawab dari 'kullamaa' atau setiap dan yang menjadi pertanyaan serta sanggahan (bahkan) lebih dari itu lagi (sebagian besar dari mereka tidak beriman).\qt@no{100}}%
\qt@newcmd\qurantrans@id@cviii{%
(Dan tatkala datang kepada mereka seorang rasul dari sisi Allah) yakni Muhammad saw. (yang membenarkan kitab yang ada pada mereka, sebagian dari orang-orang yang diberi kitab melemparkan kitab Allah) yakni Taurat (ke belakang punggung mereka) artinya mereka tidak mau mengamalkan isinya berupa keimanan kepada rasul dan lain-lain (seolah-olah mereka tidak mengetahui) akan isinya bahwa beliau adalah nabi yang sebenarnya atau bahwa Taurat itu adalah kitab Allah.\qt@no{101}}%
\qt@newcmd\qurantrans@id@cix{%
(Dan mereka mengikuti) diathafkan pada 'nabadza' (apa yang dibaca) dulu (oleh setan-setan pada) masa (kerajaan Sulaiman) berupa buku-buku sihir yang mereka pendam di bawah singgasananya ketika kerajaannya runtuh. Atau mungkin juga setan-setan itu mencari dengar lalu mencampurkan ke buku-buku itu kebohongan-kebohongan dan memberikannya kepada tukang-tukang tenung yang membukukannya sehingga tersebar berita bahwa jin mengajarkan hal-hal gaib. Sulaiman pun mengumpulkan buku-buku itu lalu menguburkannya. Tatkala ia mangkat, setan-setan pun menunjukkannya kepada manusia dan ketika mereka bongkar ternyata di dalamnya ada ilmu sihir. Kata mereka, ``Kerajaan kamu berdirinya adalah dengan ini!" Lalu mereka pelajari ilmu sihir itu dan mereka tolak buku-buku nabi-nabi mereka. Ketika orang-orang Yahudi mengatakan, ``Lihat itu Muhammad, disebutkannya Sulaiman itu seorang nabi, padahal ia tidak lebih dari seorang tukang sihir", maka Allah pun berfirman untuk membuktikan kebenaran Sulaiman dan menyangkal orang-orang Yahudi itu, (padahal Sulaiman tidaklah kafir) maksudnya ia tidak melakukan sihir, sebab sihir adalah perbuatan kafir (hanya) ada yang membaca 'lakinna' dan ada yang membaca 'lakin' (setan-setanlah yang kafir. Mereka mengajarkan sihir kepada manusia). Kalimat ini menjadi hal bagi kata ganti yang terdapat pada 'kafaruu' (dan) mengajarkan pula kepada mereka (apa yang diturunkan kepada dua malaikat) artinya ilmu sihir yang diilhamkan kepada mereka. Ada pula yang membaca 'al-malikain' dengan lam berbaris bawah sehingga berarti dua orang raja, yaitu yang berada (di Babilon) suatu negeri di tanah subur Irak. (Harut dan Marut) merupakan 'badal' atau nama dan kata ganti dari kedua malaikat itu, atau athaf bayan, artinya hubungan yang memberi penjelasan. Menurut Ibnu Abbas, kedua mereka itu adalah tukang sihir yang mengajarkan ilmu sihir dan ada pula yang mengatakan bahwa mereka adalah dua orang malaikat yang sengaja diturunkan Allah untuk menyebarkannya sebagai ujian dari Allah terhadap umat manusia. (Sedangkan keduanya tidaklah mengajarkan kepada) 'min' merupakan tambahan (seorang pun sebelum mengatakan) atau menyampaikan nasihat lebih dahulu ("Sesungguhnya kami ini hanya cobaan) ujian dari Allah terhadap manusia dengan mengajarkannya, siapa yang mempelajarinya, ia jatuh kafir dan siapa yang meninggalkannya ia mukmin, (sebab itu janganlah kamu kafir!") Jika ia masih mendesak untuk mempelajarinya barulah mereka mengajarkannya. (Maka mereka mempelajari dari kedua malaikat itu apa yang dapat menceraikan antara seorang laki-laki dengan istrinya) misalnya dengan membangkitkan marah dan kebencian satu pihak terhadap lainnya. (Dan tidaklah mereka) yakni ahli-ahli sihir itu (dapat memberi mudarat dengannya) maksudnya dengan ilmu sihir itu (dari) 'min' di sini hanya sebagai tambahan (kepada seorang pun kecuali dengan izin Allah) atau kehendak-Nya (Dan mereka pelajari apa yang memberi mudarat kepada mereka), yakni di akhirat (dan yang tidak memberi manfaat) yakni sihir. (Dan sesungguhnya) 'lam' menunjukkan sumpah (mereka sebenarnya tahu) yakni orang-orang Yahudi itu sebenarnya yakin (bahwa barang siapa) 'lam' merupakan lam ibtida yang menghubungkan dengan kalimat sebelumnya, sedangkan 'man' isim maushul (yang menukarnya) atau menggantinya (sihir) dengan Kitabullah, (tiadalah baginya bagian di akhirat) atau keberuntungan dalam surga, (dan amat buruklah sesuatu) maksudnya perbuatan mereka (menjual) menukarkan (diri mereka dengannya) yakni menjual kebahagiaannya di akhirat dengan mempelajari sihir karena telah pasti akan menjerumuskan mereka ke dalam neraka, (seandainya mereka menyadarinya) jika mereka benar-benar tahu atau menyadari hakikat siksaan yang akan mereka jalani di akhirat kelak, niscaya mereka tidak mau mempelajarinya.\qt@no{102}}%
\qt@newcmd\qurantrans@id@cx{%
(Dan seandainya mereka) orang-orang Yahudi (beriman) terhadap Nabi dan Alquran (dan menjaga diri mereka) dari siksa Allah dengan meninggalkan maksiat, seperti sihir. Jawaban dari 'lau' ini dibuang. Atau tentulah mereka akan diberi pahala. Hal ini ditunjukkan oleh (maka sesungguhnya pahala) 'matsuubatun' menjadi mubtada, sedangkan 'lam' menunjukkan sumpah (di sisi Allah itu lebih baik) 'khairun' menjadi khabar, artinya 'lebih baik' yakni lebih baik dari hasil penjualan diri mereka itu (seandainya mereka mengetahuinya) seandainya mereka tahu bahwa pahala itu lebih baik, tentulah mereka tak akan mementingkan yang lain darinya.\qt@no{103}}%
\qt@newcmd\qurantrans@id@cxi{%
(Hai orang-orang yang beriman, janganlah kamu katakan) kepada Nabi (raa`inaa) artinya perhatikanlah kami; 'raa'inaa' diambil dari kata 'muraa`ah', tetapi orang-orang Yahudi biasa mengatakan 'raa`unah' yang dalam bahasa mereka berarti 'teramat bodoh' sebagai ejekan kepada Nabi, maka orang-orang mukmin dilarang mengucapkan kata-kata itu, (dan katakanlah) yakni sebagai gantinya, (unzhurnaa) artinya lihatlah kami; (dan dengarlah olehmu) apa-apa yang dititahkan dengan kesediaan untuk mematuhinya (dan bagi orang-orang kafir disediakan siksaan pedih) yang menyakitkan sekali, yaitu neraka.\qt@no{104}}%
\qt@newcmd\qurantrans@id@cxii{%
(Orang-orang kafir dan golongan Ahli Kitab dan orang-orang musyrik tidak menginginkan) orang-orang musyrik di sini ialah dari kalangan Arab, dihubungkan kepada Ahli Kitab, sedangkan 'min' atau 'dari' untuk penjelasan (diturunkannya kebaikan kepadamu) 'min' di sini hanya sebagai tambahan; sedangkan 'kebaikan' maksudnya ialah wahyu, (dari Tuhan) disebabkan iri hati atau dengki kepadamu. (Sedangkan Allah menentukan rahmat-Nya) atau kenabian-Nya (kepada siapa yang dikehendaki-Nya; dan Allah mempunyai karunia yang maha besar).\qt@no{105}}%
\qt@newcmd\qurantrans@id@cxiii{%
Tatkala orang-orang kafir mengecam tentang nasakh/penghapusan atau pergantian hukum dan menuduh bahwa Muhammad menyuruh sahabat-sahabatnya untuk mengerjakan sesuatu pada hari ini lalu melarangnya esok, maka turunlah ayat, (Apa saja) disebut 'syarthiyah' yang membutuhkan jawaban (ayat yang Kami hapus) baik hukumnya itu pada mulanya turun bersama lafalnya atau tidak dan menurut satu qiraat 'nunsikh', artinya Kami titah kamu atau Jibril untuk menghapusnya (atau Kami tangguhkan) Kami undurkan sehingga hukumnya tidak turun dan bacaannya Kami tangguhkan di Lohmahfuz. Menurut satu qiraat tanpa hamzah, berasal dari kata-kata 'nisyaan' artinya 'lupa', sehingga artinya ialah Kami kikis atau hapus dari dalam kalbumu sehingga kamu melupakannya. Jawab syaratnya ialah (Kami datangkan yang lebih baik daripadanya) artinya lebih menguntungkan bagi hamba, baik dalam kemudahannya maupun dalam besar pahalanya (atau yang sebanding dengannya) dalam beban yang harus dipikul atau dalam ganjarannya. (Tidakkah kamu ketahui bahwa sesungguhnya Allah Maha Kuasa atas segala sesuatu?) Termasuk dalam kekuasaan-Nya itu nasakh, yaitu menghapus hukum dan mengubahnya, dan mengenai pertanyaan di sini maksudnya ialah untuk mengukuhkan.\qt@no{106}}%
\qt@newcmd\qurantrans@id@cxiv{%
(Tidakkah kamu ketahui bahwa milik Allahlah kerajaan langit dan bumi) sehingga Dia dapat berbuat terhadap keduanya menurut yang dikehendaki-Nya. (Dan tiada bagimu selain Allah) (dari) hanya sebagai tambahan (seorang wali) seorang pelindung yang akan melindungimu (dan tidak pula seorang pembela) yang akan menghindarkan siksaan jika datang menimpa.\qt@no{107}}%
\qt@newcmd\qurantrans@id@cxv{%
Tatkala warga Mekah meminta kepada Nabi saw. agar kota mereka diperluas dan bukit Shafa dijadikan sebuah bukit emas turunlah, (Atau) apakah (kamu menghendaki untuk meminta kepada Rasulmu seperti yang diminta kepada Musa) maksudnya kaum Nabi Musa telah meminta kepadanya (dulu) seperti kata mereka, ``Perlihatkanlah Allah kepada kami secara nyata!" Dan lain-lain. (Dan barang siapa yang menukar iman dengan kekafiran) artinya mengambil kekafiran sebagai ganti keimanan disebabkan tidak mau memperhatikan ayat-ayat yang jelas dan lebih memilih yang lainnya (maka sungguh ia telah sesat dari jalan yang benar) 'sawa' asalnya 'wasath', artinya pertengahan.\qt@no{108}}%
\qt@newcmd\qurantrans@id@cxvi{%
(Sebagian besar Ahli Kitab menginginkan agar) 'lau' atau 'agar' mashdariyah, artinya melebur kalimat sesudahnya menjadi mashdar (mereka dapat mengembalikan kamu pada kekafiran setelah kamu beriman disebabkan kedengkian) 'maf`ul lah' menunjukkan motif dari keinginan mereka itu (dari diri mereka sendiri) maksudnya timbul dan didorong oleh jiwa mereka yang kotor (setelah nyata bagi mereka) dalam Taurat (kebenaran) mengenai diri Nabi. (Maka biarkanlah mereka) tinggalkan (dan berpalinglah) tak usah dilayani mereka itu, (sampai Allah mendatangkan perintah-Nya) tentang mereka dengan menyuruh memerangi mereka. (Sesungguhnya Allah Maha Kuasa atas segala sesuatu).\qt@no{109}}%
\qt@newcmd\qurantrans@id@cxvii{%
(Dan dirikanlah salat serta bayarkanlah zakat dan apa-apa yang kamu persembahkan buat dirimu berupa kebaikan) artinya ketaatan seperti sedekah dan menghubungkan silaturahmi, (tentulah kamu akan mendapatinya) maksudnya pahalanya (di sisi Allah, sesungguhnya Allah Maha Melihat akan apa-apa yang kamu kerjakan) sehingga kamu akan menerima balasan daripadanya.\qt@no{110}}%
\qt@newcmd\qurantrans@id@cxviii{%
(Dan mereka, orang-orang Yahudi dan Kristen, mengatakan, ``Sekali-kali tidak akan masuk surga kecuali orang-orang yang beragama Yahudi atau Kristen.") Ucapan ini dikeluarkan oleh orang-orang Yahudi Madinah dan Kristen Najran tatkala mereka berbantahan di hadapan Nabi saw. Kata Yahudi, ``Hanya orang Yahudilah yang akan masuk ke dalamnya." Orang Kristen menjawab, ``Surga itu tidak akan dimasuki, kecuali oleh orang Kristen." (Demikianlah itu) yakni ucapan mereka itu (hanyalah angan-angan mereka saja) artinya keinginan kosong belaka. (Katakanlah) kepada mereka, (Tunjukkanlah bukti kebenaranmu) yaitu hujah atas yang demikian itu (jika kamu orang yang benar) mengenai hal tersebut.\qt@no{111}}%
\qt@newcmd\qurantrans@id@cxix{%
(Tidak demikian) bahkan yang akan masuk surga itu ialah selain mereka (barang siapa yang menyerahkan wajahnya kepada Allah) maksudnya tunduk pada perintah-Nya. Ditekankan menyerahkan 'wajah' atau 'muka' karena merupakan anggota tubuh yang paling mulia, maka anggota tubuh yang lainnya harus lebih tunduk lagi (sedangkan ia berbuat kebaikan) terutama bertauhid, (maka baginya pahala di sisi Tuhannya) artinya sebagai ganjaran amal perbuatannya itu ialah surga. (Tidak ada kekhawatiran terhadap mereka dan tidak pula mereka akan berduka cita) yakni di akhirat kelak.\qt@no{112}}%
\qt@newcmd\qurantrans@id@cxx{%
(Dan orang-orang Yahudi berkata, ``Orang-orang Nasrani tidak mempunyai sesuatu pegangan") yakni sesuatu yang dapat diakui di samping mereka tidak pula beriman kepada Isa. (Sebaliknya orang-orang Nasrani mengatakan, ``Orang Yahudi tidak mempunyai sesuatu pegangan,") yang dapat dipercaya dan mereka kafir pula kepada Nabi Musa (padahal mereka) kedua golongan tersebut (sama-sama membaca Alkitab) yang diturunkan kepada mereka. Di dalam kitab suci orang Yahudi terdapat pengukuhan terhadap Nabi Isa dan dalam kitab suci orang Kristen terdapat pengukuhan terhadap Nabi Musa. Kalimat yang belakangan ini menjadi 'hal'. (Demikian pula) maksudnya seperti yang mereka katakan itu (dikatakan oleh orang-orang yang tidak mengetahui) yakni orang-orang musyrik dari golongan Arab dan lainnya (seperti ucapan mereka itu) penjelasan bagi makna 'demikian pula', artinya kepada setiap penganut agama lain, mereka katakan bahwa mereka tidak mempunyai dasar atau pedoman. (Maka Allah akan mengadili di antara mereka pada hari kiamat mengenai apa yang mereka persengketakan itu) yakni tentang urusan agama, sehingga semua pihak yang membenarkannya akan masuk surga dan sebaliknya orang yang menyangkalnya akan masuk neraka.\qt@no{113}}%
\qt@newcmd\qurantrans@id@cxxi{%
(Dan siapakah yang melarang menyebut nama Allah dalam mesjid-mesjid-Nya) misalnya salat dan bertasbih (dan berusaha untuk merobohkannya) baik dengan jalan meruntuhkan mesjid itu maupun dengan menggagalkan orang untuk mengunjungi dan memasukinya. Ayat ini turun menceritakan perbuatan orang-orang Romawi yang telah merobohkan Baitulmakdis atau orang-orang musyrik Mekah yang menghalang-halangi Nabi saw. ketika mengunjungi Baitullah pada tahun perjanjian Hudaibiah. (Mereka itu tidak sepatutnya memasukinya kecuali dengan rasa takut). Kalimat ini kalimat berita dengan arti perintah, artinya ancamlah mereka itu dengan jihad, sehingga tidak seorang pun masuk ke dalamnya dengan rasa aman. (Mereka di dunia mendapat kehinaan) atau kenistaan disebabkan terbunuh, ditawan atau membayar upeti (dan di akhirat mereka mendapat siksa yang besar) neraka.\qt@no{114}}%
\qt@newcmd\qurantrans@id@cxxii{%
Ketika orang-orang Yahudi mengecam penggantian kiblat atau tentang salat sunah di atas kendaraan selama dalam perjalanan dengan menghadap ke arah yang dituju, turunlah ayat, (Dan milik Allahlah timur dan barat) karena keduanya merupakan ujung dan pangkalnya, (maka ke mana saja kamu menghadap) maksudnya menghadapkan mukamu di waktu salat atas titah-Nya, (maka di sanalah) di arah sanalah (wajah Allah) maksudnya kiblat yang diridai-Nya. (Sesungguhnya Allah Maha Luas) maksudnya kemurahan-Nya meliputi segala sesuatu (lagi Maha Mengetahui) tentang pengaturan makhluk-Nya.\qt@no{115}}%
\qt@newcmd\qurantrans@id@cxxiii{%
(Dan mereka berkata) dengan wau atau tanpa wau, maksudnya orang-orang Yahudi dan Kristen serta orang-orang yang mengakui bahwa malaikat-malaikat itu anak-anak perempuan Allah, ('Allah mempunyai anak.') Allah berfirman, ("Maha Suci Dia) menyucikan-Nya dari pernyataan tersebut, (bahkan apa-apa yang ada di langit dan di bumi kepunyaan-Nya belaka) baik sebagai hak milik, sebagai makhluk, maupun sebagai hamba. Pemilikan itu bertentangan dengan pengambilan atau mempunyai anak. Di sini dipakai 'maa' artinya 'apa-apa untuk yang tidak berakal' karena 'taghlib', artinya untuk mengambil yang lebih banyak. (semua tunduk kepada-Nya.") Artinya menaatinya, masing-masing sesuai dengan tujuan diciptakan-Nya. Di sini lebih ditekankan kepada makhluk yang berakal.\qt@no{116}}%
\qt@newcmd\qurantrans@id@cxxiv{%
(Penemu langit dan bumi) maksudnya penciptanya tanpa meniru pada contoh-contoh yang lain (dan bila Dia berkehendak) (akan sesuatu perkara) artinya menciptakannya (maka Dia hanya mengucapkan kepadanya, ``Jadilah kamu!" Lalu jadilah ia) artinya sesuatu itu pun terjadilah. Menurut satu qiraat 'fayakuuna' dengan baris di atas sebagai 'jawaabul amr'.\qt@no{117}}%
\qt@newcmd\qurantrans@id@cxxv{%
(Dan berkatalah orang-orang yang tidak mengetahui) yakni kaum kafir Mekah kepada Nabi saw., ("Mengapa Allah tidak berbicara dengan kami) bahwa kamu adalah Rasul-Nya (atau datang kepada kami suatu tanda) atau bukti yang kami usulkan untuk menunjukkan kebenaranmu?" (Demikian pulalah) artinya seperti yang mereka ucapkan itu (dikatakan kepada orang-orang yang sebelum mereka) yakni umat-umat yang kafir terhadap nabi mereka masing-masing (seperti ucapan mereka) berupa pembangkangan dan permintaan mukjizat-mukjizat, (hati mereka serupa) yakni dalam kekafiran dan pembangkangan. Ini menjadi hiburan dan bujukan bagi Nabi saw. (Sesungguhnya Kami telah menjelaskan tanda kekuasaan Kami kepada kaum yang yakin) yang mengetahui bahwa ia adalah ayat atau tanda, sehingga mereka beriman. Maka mengusulkan ayat atau tanda-tanda lain merupakan dosa atau kesalahan.\qt@no{118}}%
\qt@newcmd\qurantrans@id@cxxvi{%
(Sesungguhnya Kami telah mengutusmu) hai Muhammad (dengan kebenaran) maksudnya dengan petunjuk (sebagai pembawa berita gembira) bahwa barang siapa yang memenuhinya, ia akan mendapat surga (dan pembawa peringatan) bahwa barang siapa yang menolaknya akan masuk neraka. (Dan kamu tidak akan dimintai pertanggungjawaban tentang penghuni-penghuni neraka) maksudnya orang-orang kafir. Tidak menjadi soal bagimu jika mereka tidak beriman, karena kewajibanmu hanyalah menyampaikan. Menurut satu riwayat dibaca 'tas-al', yaitu dengan sukun atau baris mati, menunjukkan larangan.\qt@no{119}}%
\qt@newcmd\qurantrans@id@cxxvii{%
(Orang-orang Yahudi dan Kristen tidak akan senang kepadamu hingga kamu mengikuti millah mereka) maksudnya agama mereka. (Katakanlah, ``Sesungguhnya petunjuk Allah) yaitu agama Islam (itulah petunjuk) yang sesungguhnya, sedangkan yang selainnya hanyalah kesesatan belaka. (Sesungguhnya, jika) 'lam' menunjukkan sumpah (kamu ikuti keinginan mereka) yakni apa-apa yang mereka anjurkan (setelah datangnya pengetahuan kepadamu) maksudnya wahyu dari Allah (maka Allah tidak lagi menjadi pelindung) yang akan melindungimu (dan tidak pula menolong.") yang akan menghindarkanmu dari bahaya.\qt@no{120}}%
\qt@newcmd\qurantrans@id@cxxviii{%
(Orang-orang yang telah Kami beri Alkitab) merupakan subjek (sedangkan mereka membacanya dengan bacaan yang sebenarnya) artinya membacanya sebagaimana diturunkan dan digabungkan dengan kalimat ini menjadi 'hal'; 'haqqa' mendapat baris di atas sebagai mashdar atau maf`ul muthlak, sedangkan yang menjadi khabarnya ialah, (mereka itulah yang beriman kepadanya). Ayat ini diturunkan menceritakan segolongan orang yang datang dari Abessinia lalu masuk Islam. (Dan barang siapa yang ingkar terhadapnya) artinya terhadap kitab yang diturunkan itu, misalnya dengan mengubahnya dari yang asli (maka merekalah orang-orang yang rugi) disebabkan mereka disediakan tempat di neraka yang kekal lagi abadi.\qt@no{121}}%
\qt@newcmd\qurantrans@id@cxxix{%
(Hai Bani Israel! Ingatlah akan nikmat-Ku yang telah Aku berikan kepadamu dan sesungguhnya Aku telah mengutamakan kamu dari segala umat). Ayat seperti ini telah kita temui di muka.\qt@no{122}}%
\qt@newcmd\qurantrans@id@cxxx{%
(Dan takutlah kamu akan) (suatu hari di waktu tidak dapat menggantikan) (seseorang atas orang yang lainnya) padanya (sedikit pun dan tidak diterima suatu tebusan darinya) (dan tidak akan memberi manfaat kepadanya suatu syafaat dan tidak pula akan ditolong) atau dihindarkan dari azab Allah.\qt@no{123}}%
\qt@newcmd\qurantrans@id@cxxxi{%
(Dan) ingatlah (ketika Ibrahim mendapat ujian) menurut satu qiraat Ibraham (dari Tuhannya dengan beberapa kalimat) maksudnya dengan perintah dan larangan yang dibebankan kepadanya. Ada yang mengatakan manasik atau pekerjaan haji, ada pula berkumur-kumur, menghirup air ke hidung, menggosok gigi, memotong kumis, membelah rambut, memotong kuku, mencabut bulu ketiak, mencukur bulu kemaluan, berkhitan dan istinja (lalu disempurnakannya) maksudnya dikerjakannya secara sempurna. (Firman-Nya) yakni Allah Taala, ("Sesungguhnya Aku akan menjadikanmu sebagai imam bagi manusia.") Artinya contoh dan ikutan dalam keagamaan. (Kata Ibrahim, ``Aku mohon juga dari keturunanku!") maksudnya dari anak cucuku dijadikan imam-imam. (Firman-Nya, ``Janji-Ku ini tidak mencapai) untuk dijadikan imam (orang-orang yang aniaya") yakni orang-orang yang ingkar di antara mereka. Sebaliknya bagi orang yang tidak aniaya, tidak tertutup kemungkinan untuk diangkat sebagai imam.\qt@no{124}}%
\qt@newcmd\qurantrans@id@cxxxii{%
(Dan ketika Kami menjadikan Baitullah itu) yakni Kakbah (sebagai tempat kembali bagi manusia) maksudnya tempat berkumpul dari segenap pelosok (dan tempat yang aman) maksudnya aman dari penganiayaan dan serangan yang sering terjadi di tempat lain. Sebagai contohnya pernah seseorang menemukan pembunuh bapaknya, tetapi ia tidak mau membalas dendam di tempat ini, (dan jadikanlah) hai manusia (sebagian makam Ibrahim) yakni batu tempat berdirinya Nabi Ibrahim a.s. ketika membangun Baitullah (sebagai tempat salat) yaitu dengan mengerjakan salat sunah tawaf di belakangnya. Menurut satu qiraat dibaca 'wattakhadzuu' yang artinya, dan mereka menjadikan; hingga menjadi kalimat berita. (Dan telah Kami perintahkan kepada Ibrahim dan Ismail) (yang bunyinya) ("Bersihkanlah rumah-Ku) dari berhala (untuk orang-orang yang tawaf, yang iktikaf) artinya yang bermukim di sana (orang-orang yang rukuk dan orang-orang yang sujud!") artinya orang-orang yang salat.\qt@no{125}}%
\qt@newcmd\qurantrans@id@cxxxiii{%
(Dan ketika Ibrahim berdoa, ``Ya Tuhanku! Jadikanlah ini) maksudnya tempat ini (sebagai suatu negeri yang aman). Doanya dikabulkan Allah sehingga negeri Mekah dijadikan sebagai suatu negeri yang suci, darah manusia tidak boleh ditumpahkan, seorang pun tidak boleh dianiaya, tidak boleh pula diburu binatang buruannya dan dicabut rumputnya. (Dan berilah penduduknya rezeki berupa buah-buahan) dan ini juga sudah menjadi kenyataan dengan diangkutnya berbagai macam buah-buahan dari negeri Syam melalui orang-orang yang hendak tawaf sekalipun tanahnya merupakan suatu tempat yang tandus tanpa air dan tumbuh-tumbuhan (yakni yang beriman di antara mereka kepada Allah dan hari akhir") merupakan 'badal' atau kalimat pengganti bagi 'penduduknya' yang dikhususkan dengan doa, sesuai dengan firman-Nya, ``Dan janji-Ku ini tidaklah mencapai orang-orang yang aniaya." (Firman Allah, ``Dan) Aku beri mereka pula (orang-orang kafir lalu Aku beri kesenangan sedikit) atau sementara, yakni selama hidup di dunia dengan rezeki, dibaca 'fa-umatti`uhu', yakni dengan tasydid. (Kemudian Aku paksa ia) di akhirat kelak (menjalani siksa neraka) sehingga tidak mendapatkan jalan keluar (dan itulah seburuk-buruk tempat kembali").\qt@no{126}}%
\qt@newcmd\qurantrans@id@cxxxiv{%
(Dan) ingatlah (ketika Ibrahim meninggikan sendi-sendi) dasar-dasar atau dinding-dinding (Baitullah) maksudnya membinanya yang dapat dipahami dari kata 'meninggikan' tadi (beserta Ismail) `athaf atau dihubungkan kepada Ibrahim sambil keduanya berdoa, ("Ya Tuhan kami! Terimalah dari kami) amal kami membina ini, (sesungguhnya Engkau Maha Mendengar) akan permohonan kami (lagi Maha Mengetahui) akan perbuatan kami.\qt@no{127}}%
\qt@newcmd\qurantrans@id@cxxxv{%
(Ya Tuhan kami! Jadikanlah kami berdua ini orang yang patuh) dan tunduk (kepada-Mu dan) jadikanlah pula (di antara keturunan kami) maksudnya anak cucu kami (umat) atau golongan (yang patuh kepada-Mu). 'Min' menyatakan 'sebagian' dan diajukan mereka demikian karena firman Allah yang lalu, 'Dan janji-Ku ini tidak mencapai orang-orang yang aniaya.' (Dan tunjukkanlah kepada kami) ajarkanlah kepada kami (syariat ibadah haji kami) maksudnya cara-cara dan tempat-tempatnya (dan terimalah tobat kami, sesungguhnya Engkau Maha Penerima tobat lagi Maha Penyayang). Mereka bertobat kepada Allah padahal mereka maksum atau terpelihara dari dosa, disebabkan kerendahan hati mereka dan sebagai pelajaran bagi anak cucu mereka.\qt@no{128}}%
\qt@newcmd\qurantrans@id@cxxxvi{%
(Ya Tuhan kami! Utuslah untuk mereka) yakni Ahlulbait (seorang rasul dari kalangan mereka) ini telah dikabulkan Allah dengan dibangkitkannya kepada mereka Nabi Muhammad saw. (yang akan membacakan kepada mereka ayat-ayat-Mu) Alquran (dan mengajari mereka Alkitab) yakni Alquran (dan hikmah) maksudnya hukum-hukum yang terdapat di dalamnya (serta menyucikan mereka) dari kemusyrikan (sesungguhnya Engkau Maha Kuasa) sehingga mengungguli siapa pun (lagi Maha Bijaksana") dalam segala tindakan dan perbuatan.\qt@no{129}}%
\qt@newcmd\qurantrans@id@cxxxvii{%
(Dan siapakah) maksudnya tidak ada orang (yang benci pada agama Ibrahim) lalu meninggalkannya (kecuali orang yang memperbodoh dirinya sendiri) artinya tidak mengerti bahwa ia makhluk Allah dan harus mengabdikan diri kepada-Nya atau yang dimaksud, mencelakakan dan menghinakan dirinya sendiri (dan sungguh Kami telah memilihnya di dunia) sebagai seorang rasul dan seorang khalil, artinya 'sebagai seorang sahabat', (dan sesungguhnya di akhirat dia benar-benar termasuk orang-orang yang saleh) yang mempunyai kedudukan tinggi.\qt@no{130}}%
\qt@newcmd\qurantrans@id@cxxxviii{%
Ingatlah! (Ketika Tuhannya berfirman kepadanya, ``Tunduk dan berserah dirilah kamu!") maksudnya ``Tunduklah kepada Allah dan bulatkan pengabdianmu kepada-Nya!" (Jawab Ibrahim, ``Aku tunduk dan berserah diri kepada Tuhan semesta alam.")\qt@no{131}}%
\qt@newcmd\qurantrans@id@cxxxix{%
(Dan Ibrahim telah mewasiatkan) maksudnya agama itu. Menurut suatu qiraat 'aushaa', (kepada anak-anaknya, demikian pula Yakub) kepada anak-anaknya, katanya, ("Hai anak-anakku! Sesungguhnya Allah telah memilih agama ini untukmu) yakni agama Islam, (maka janganlah kamu mati kecuali dalam menganut agama Islam!") Artinya ia melarang mereka meninggalkan agama Islam dan menyuruh mereka agar memegang teguh agama itu sampai nyawa berpisah dari badan.\qt@no{132}}%
\qt@newcmd\qurantrans@id@cxl{%
Tatkala orang-orang Yahudi mengatakan kepada Nabi saw., ``Apakah kamu tidak tahu bahwa ketika akan mati itu Yakub memesankan kepada putra-putranya supaya memegang teguh agama Yahudi," maka turunlah ayat, ("Apakah kalian menyaksikan) atau turut hadir (ketika tanda-tanda kematian telah datang kepada Yakub, yakni ketika) menjadi 'bada' atau huruf pengganti bagi 'idz' yang sebelumnya, (ia menanyakan kepada anak-anaknya, 'Apa yang kamu sembah sepeninggalku?") yakni setelah aku meninggal? (Jawab mereka, ``Kami akan menyembah Tuhanmu dan Tuhan bapak-bapakmu Ibrahim, Ismail dan Ishak). Ismail dianggap sebagai 'bapak' berdasarkan taghlib atau pukul rata, karena kedudukan paman sama dengan bapak (yakni Tuhan Yang Maha Esa) merupakan 'badal' atau kata pengganti dari 'Tuhanmu', (dan kami tunduk serta berserah diri kepada-Nya.") Kata 'am' atau 'apakah' di atas berarti penolakan, artinya kalian tidak hadir ketika ia wafat, maka betapa kalian berani menyatakan dan mengucapkan kepadanya perkataan yang tidak-tidak!\qt@no{133}}%
\qt@newcmd\qurantrans@id@cxli{%
(Itu) isyarat kepada Ibrahim dan Yakub serta anak cucu mereka, menjadi 'mubtada' atau subyek dan dipakai kata muannats/jenis wanita disebabkan predikatnya yang muannats pula, (adalah umat yang telah lalu) (bagi mereka apa yang telah mereka usahakan) maksudnya balasan atau ganjaran amal perbuatan mereka (dan bagi kamu) ditujukan kepada orang-orang Yahudi (apa yang kamu usahakan dan kamu tidak akan diminta pertanggungjawaban tentang apa-apa yang mereka kerjakan) sebagaimana mereka tidak pula akan diminta pertanggungjawaban tentang amal perbuatanmu. Kalimat yang di belakang ini memperkuat maksud kalimat di muka.\qt@no{134}}%
\qt@newcmd\qurantrans@id@cxlii{%
(Dan kata mereka, ``Jadilah kamu sebagai penganut agama Yahudi atau Kristen, niscaya kamu mendapat petunjuk.") 'Au' yang berarti 'atau' berfungsi sebagai pemisah. Yang pertama diucapkan oleh orang-orang Yahudi Madinah, sedangkan yang kedua oleh kaum Kristen Najran. (Katakanlah) kepada mereka (tidak, bahkan) kami akan mengikuti (agama Ibrahim yang lurus) yang bertentangan dengan agama lain dan berpaling menjadi agama yang lurus dan benar. 'Hanifa' ini menjadi 'hal' dari Ibrahim. (Dan bukanlah dia dari golongan orang-orang musyrik).\qt@no{135}}%
\qt@newcmd\qurantrans@id@cxliii{%
(Katakanlah,) ucapan ini ditujukan kepada orang-orang beriman ("Kami beriman kepada Allah dan pada apa yang diturunkan kepada kami) yakni Alquran (dan pada apa yang diturunkan kepada Ibrahim) yakni shuhuf, yaitu lembaran-lembaran yang sepuluh (kepada Ismail, Ishak, Yakub dan anak cucunya) (dan apa yang diberikan kepada Musa) berupa Taurat (dan Isa) yakni Injil (begitu juga yang diberikan kepada nabi-nabi dari Tuhan mereka) baik berupa kitab maupun ayat. (Tidaklah kami beda-bedakan seorang pun di antara mereka) sehingga mengakibatkan kami beriman kepada sebagian dan kafir kepada sebagian yang lain sebagaimana halnya orang-orang Yahudi dan Kristen, (dan kami hanya tunduk kepada-Nya semata.")\qt@no{136}}%
\qt@newcmd\qurantrans@id@cxliv{%
(Maka jika mereka beriman) yakni orang-orang Yahudi dan Kristen tadi (dengan) 'mitsli' atau 'seperti' hanya sebagai tambahan (apa yang kamu imani, maka mereka telah memperoleh petunjuk dan jika mereka berpaling) dari keimanan itu, (berarti mereka dalam permusuhan) denganmu. (Maka Allah akan memeliharamu dari permusuhan mereka itu) hai Muhammad! (Dan Allah Maha Mendengar) ucapan-ucapan mereka (lagi Maha Mengetahui) semua keadaan mereka. Misalnya kamu telah ditolong-Nya dengan pembunuhan Bani Quraizhah, pengusiran Bani Nadhir dan pembebanan upeti atas mereka.\qt@no{137}}%
\qt@newcmd\qurantrans@id@cxlv{%
(Celupan Allah) 'mashdar' yang memperkuat 'kami beriman' tadi. Mendapat baris di atas sebagai maf`ul muthlak dari fi`il yang tersembunyi yang diperkirakan berbunyi 'Shabaghanallaahu shibghah', artinya ``Allah mencelup kami suatu celupan". Sedang maksudnya ialah agama-Nya yang telah difitrahkan-Nya atas manusia dengan pengaruh dan bekasnya yang menonjol, tak ubah bagai celupan terhadap kain. (Dan siapakah) maksudnya tidak seorang pun (yang lebih baik celupannya dari Allah) shibghah di sini menjadi 'tamyiz' (dan hanya kepada-Nya kami menyembah).\qt@no{138}}%
\qt@newcmd\qurantrans@id@cxlvi{%
(Katakanlah) kepada mereka! ("Apakah kamu hendak memperbantahkan) dengan kami (tentang Allah) karena Dia memilih seorang nabi dari kalangan Arab? (Padahal Dia adalah Tuhan kamu) dan berhak memilih siapa saja yang dikehendaki-Nya di antara hamba-hamba-Nya (dan bagi kamu amalan kamu) dan kamu akan memperoleh balasannya pula dan tidak mustahil jika di antara amal-amalan kami itu ada yang patut menerima ganjaran istimewa (dan hanya kepada-Nya kami mengikhlaskan) agama dan amalan kami; berbeda halnya dengan kamu, sehingga sepatutnyalah kami yang dipilih-Nya. 'Hamzah' atau 'apakah' di atas, maksudnya menolak, sedangkan ketiga kalimat di belakang berarti 'hal'.\qt@no{139}}%
\qt@newcmd\qurantrans@id@cxlvii{%
(Atau) apakah (kamu hendak mengatakan) ada pula yang membaca 'yaquuluuna', artinya mereka hendak mengatakan (bahwa Ibrahim, Ismail, Ishak, Yakub dan anak cucunya adalah penganut agama Yahudi dan Kristen?" Katakanlah) kepada mereka, ("Apakah kamu yang lebih tahu ataukah Allah") artinya Allahlah yang lebih mengetahui dan Allah sendiri telah membebaskan Ibrahim dari kedua agama itu, firman-Nya, ``Ibrahim itu bukanlah seorang Yahudi atau Kristen." Demikian pula nabi-nabi yang disebutkan bersamanya mereka itu adalah juga mengikuti agamanya. (Dan siapakah lagi yang aniaya daripada orang yang menyembunyikan) atau merahasiakan kepada umat manusia (kesaksian yang terdapat padanya) (dari Allah) maksudnya tidak ada lain yang lebih aniaya daripadanya. Yang dituju adalah orang-orang Yahudi yang menyembunyikan kesaksian Allah dalam Taurat bahwa Ibrahim itu menganut agama hanafiah, yaitu agama Islam yang lurus. (Dan Allah sekali-kali tidak lalai dari apa yang kamu kerjakan) merupakan ancaman dan peringatan terhadap mereka.\qt@no{140}}%
\qt@newcmd\qurantrans@id@cxlviii{%
(Mereka itu adalah umat yang telah lalu, bagi mereka apa yang telah mereka usahakan dan bagi kamu apa yang kamu usahakan; dan kamu tidak akan diminta pertanggungjawaban tentang apa yang telah mereka kerjakan). Ayat seperti ini telah kita temui di muka.\qt@no{141}}%
\qt@newcmd\qurantrans@id@cxlix{%
(Orang-orang yang bodoh, kurang akalnya, di antara manusia) yakni orang-orang Yahudi dan kaum musyrikin akan mengatakan, (Apakah yang memalingkan mereka) yakni Nabi saw. dan kaum mukminin (dari kiblat mereka yang mereka pakai selama ini) maksudnya yang mereka tuju di waktu salat, yaitu Baitulmakdis. Menggunakan 'sin' yang menunjukkan masa depan, merupakan pemberitaan tentang peristiwa gaib. (Katakanlah, ``Milik Allahlah timur dan barat) maksudnya semua arah atau mata angin adalah milik Allah belaka, sehingga jika Dia menyuruh kita menghadap ke arah mana saja, maka tak ada yang akan menentang-Nya. (Dia memberi petunjuk kepada orang yang dikehendaki-Nya) sesuai dengan petunjuk-Nya (ke jalan yang lurus") yakni agama Islam. Termasuk dalam golongan itu ialah kamu sendiri dan sebagai buktinya ialah:\qt@no{142}}%
\qt@newcmd\qurantrans@id@cl{%
(Demikian pula) sebagaimana Kami telah membimbing kamu padanya. (Kami jadikan kamu) hai Muhammad (sebagai umat yang pertengahan) artinya sebagai umat yang adil dan pilihan, (agar kamu sekalian menjadi saksi terhadap umat manusia) pada hari kiamat bahwa rasul-rasul mereka telah menyampaikan risalah kepada mereka (dan agar rasul menjadi saksi terhadap kamu sekalian) bahwa ia telah menyampaikan risalahnya kepadamu. (Dan tidaklah Kami jadikan kiblat) kamu sekarang ini (menurut arah kiblatmu dulu) yaitu Kakbah yang menjadi kiblatmu yang mula-mula. Di Mekah Nabi saw. ketika salat menghadap ke sana dan tatkala ia hijrah ke Madinah disuruhnya menghadap ke Baitulmakdis guna mengambil hati orang-orang Yahudi. Ada 16 atau 17 bulan lamanya Nabi menghadap ke Baitulmakdis, lalu kembali menghadap ke Kakbah (melainkan agar Kami ketahui) menurut ilmu lahir (siapa yang mengikuti rasul) lalu membenarkannya (di antara orang-orang yang membelot) artinya murtad dan kembali pada kekafiran disebabkan keragu-raguan terhadap agama dan dugaan bahwa Nabi saw. dalam kebimbangan menghadapi urusannya. Memang ada segolongan orang yang murtad disebabkan ini. (Dan sungguh) 'in' berasal dari 'inna', sedangkan isimnya dibuang dan pada mulanya berbunyi 'wa-innaha', artinya 'dan sesungguhnya ia' (adalah ia) yakni pemindahan kiblat itu (amat berat) amat sulit diterima manusia, (kecuali bagi orang-orang yang diberi petunjuk oleh Allah) di antara mereka (dan Allah tidak akan menyia-nyiakan keimanan mereka) maksudnya salat mereka yang dulu menghadap ke Baitulmakdis, tetapi akan tetap memberi pahala kepada mereka karenanya. Sebagaimana kita ketahui sebab turun ayat ini adalah datangnya pertanyaan mengenai orang yang meninggal sebelum pemindahan kiblat. (Sesungguhnya Allah terhadap manusia) yakni yang beriman (Maha Pengasih lagi Maha Penyayang) sehingga Dia tidak akan menyia-nyiakan amal perbuatan mereka. 'Ra`fah', artinya amat pengasih dan didahulukan agar lebih tepat menemui sasaran.\qt@no{143}}%
\qt@newcmd\qurantrans@id@cli{%
(Sungguh) menyatakan kepastian (telah Kami lihat perpalingan) atau tengadah (wajahmu ke) arah (langit) menunggu-nunggu kedatangan wahyu dan rindu menerima perintah untuk menghadap Kakbah. Sebabnya tidak lain karena ia merupakan kiblat Nabi Ibrahim dan lebih menggugah untuk masuk Islamnya orang-orang Arab (maka sungguh akan Kami palingkan kamu) pindahkan kiblatmu (ke kiblat yang kamu ridai) yang kamu sukai. (Maka palingkanlah mukamu) artinya menghadaplah di waktu salat (ke arah Masjidilharam) yakni Kakbah (dan di mana saja kamu berada) ditujukan kepada seluruh umat (palingkanlah mukamu) dalam salat (ke arahnya! Dan sesungguhnya orang-orang yang diberi Alkitab sama mengetahui bahwa itu) maksudnya pemindahan kiblat ke arah Kakbah (benar) tidak disangsikan lagi (dari Tuhan mereka) karena di dalam kitab-kitab suci mereka dinyatakan bahwa di antara ciri-ciri Nabi saw. ialah terjadinya pemindahan kiblat di masanya. (Dan Allah sekali-kali tidak lalai dari apa yang kamu kerjakan) jika dengan ta, maka ditujukan kepada 'kamu' hai orang-orang yang beriman, yang mematuhi segala perintah-Nya, sebaliknya bila dengan ya, maka ditujukan kepada orang-orang Yahudi yang menyangkal soal kiblat ini.\qt@no{144}}%
\qt@newcmd\qurantrans@id@clii{%
(Dan sesungguhnya jika) lam untuk sumpah (kamu datangkan kepada orang-orang yang diberi Alkitab semua bukti) atas kebenaranmu tentang soal kiblat (mereka tidak mengikuti) maksudnya tidak akan mengikuti (kiblatmu) disebabkan keingkaran (dan kamu pun tidak akan mengikuti kiblat mereka). Hal ini dipastikan Allah mengingat keinginan kuat dari Nabi agar mereka masuk Islam dan keinginan kuat mereka agar Nabi saw. kembali berkiblat ke Baitulmakdis. (Dan sebagian mereka pun tidak akan mengikuti kiblat sebagian yang lain) maksudnya orang-orang Yahudi terhadap kiblat orang-orang Kristen dan sebaliknya orang-orang Kristen terhadap kiblat orang-orang Yahudi. (Dan sekiranya kamu mengikuti keinginan mereka) yang mereka ajukan dan tawarkan kepadamu (setelah datang ilmu kepadamu) maksudnya wahyu, (maka kalau begitu kamu) apabila kamu mengikuti mereka (termasuk golongan orang-orang yang aniaya).\qt@no{145}}%
\qt@newcmd\qurantrans@id@cliii{%
(Orang-orang yang Kami beri Alkitab mengenalnya) Muhammad (sebagaimana mereka mengenal anak-anak mereka sendiri) karena disebutkan ciri-cirinya dalam kitab-kitab suci mereka. Kata Ibnu Salam, ``Sesungguhnya ketika aku melihatnya, maka aku pun segera mengenalnya, sebagaimana aku mengenal putraku sendiri, bahkan lebih kuat lagi mengenal Muhammad." (Dan sesungguhnya sebagian di antara mereka menyembunyikan kebenaran) maksudnya ciri-cirinya itu (padahal mereka mengetahui) keadaanmu dan siapa kamu yang sebenarnya.\qt@no{146}}%
\qt@newcmd\qurantrans@id@cliv{%
(Kebenaran itu) betapa pun (dari Tuhanmu, maka janganlah kamu berada dalam keragu-raguan) dalam kebimbangan, misalnya mengenai soal kiblat ini. Susunan kata seperti itu lebih kuat lagi daripada mengatakan, ``Jangan kamu ragu!"\qt@no{147}}%
\qt@newcmd\qurantrans@id@clv{%
(Dan bagi masing-masing) maksudnya masing-masing umat (ada arah dan tujuan) maksudnya kiblat (tempat ia menghadapkan wajahnya) di waktu salatnya. Menurut suatu qiraat bukan 'muwalliihaa' tetapi 'muwallaahaa' yang berarti majikan atau yang menguasainya, (maka berlomba-lombalah berbuat kebaikan) yakni segera menaati dan menerimanya. (Di mana saja kamu berada, pastilah Allah akan mengumpulkan kamu semua) yakni di hari kiamat, lalu dibalas-Nya amal perbuatanmu. (Sesungguhnya Allah Maha Kuasa atas segala sesuatu).\qt@no{148}}%
\qt@newcmd\qurantrans@id@clvi{%
(Dan dari mana saja kamu keluar) untuk sesuatu perjalanan, (maka palingkanlah wajahmu ke arah Masjidilharam. Dan sesungguhnya itu merupakan ketentuan yang hak dari Tuhanmu dan Allah tidak lalai terhadap apa yang kamu kerjakan) dibaca dengan ta dan ya. Ayat seperti ini telah kita temui dulu dan diulang-ulang untuk menyatakan persamaan hukum dalam perjalanan dan lain-lainnya.\qt@no{149}}%
\qt@newcmd\qurantrans@id@clvii{%
(Dan dari mana saja kamu berangkat, maka palingkanlah wajahmu ke arah Masjidilharam. Dan di mana saja kamu berada, maka hadapkanlah mukamu ke arahnya!) Diulang-ulang untuk memperkuat (agar tidak ada bagi manusia) baik Yahudi maupun orang musyrik (hujah atas kamu) maksudnya alasan agar kamu meninggalkan dan berpaling ke arah lainnya, yakni untuk menyangkal perdebatan mereka dengan kamu, misalnya kata orang-orang Yahudi, ``Ia mengingkari agama kita tetapi ia mengikuti arah kiblat kita," dan kata orang-orang musyrik, ``Ia mengaku mengikuti agama Ibrahim tetapi ia melanggar arah kiblatnya," (kecuali orang-orang yang aniaya di antara mereka) disebabkan keingkaran. Mereka mengatakan bahwa perpalingan Muhammad ke Kakbah itu sebabnya tidak lain hanyalah karena kecenderungannya pada agama nenek moyangnya. 'Itstitsna' atau pengecualian di sini adalah 'muttashil' atau berhubungan dan maksudnya adalah tak ada omelan seorang pun kepadamu selain dari omelan mereka itu. (Maka janganlah kamu takut kepada mereka) maksudnya teramat khawatir disebabkan peralihan kiblat itu (tetapi takutlah kepada-Ku) yaitu dengan mengikuti segala perintah-Ku, (dan agar Aku sempurnakan) `athaf atau dihubungkan pada 'li alla yakuuna', (nikmat-Ku kepadamu) dengan menuntunmu pada pokok agamamu (dan supaya kamu memperoleh petunjuk) pada kebenaran.\qt@no{150}}%
\qt@newcmd\qurantrans@id@clviii{%
(Sebagaimana Kami telah mengutus kepadamu seorang rasul dari golonganmu) berhubungan dengan lafal 'utimma', yakni untuk menyempurnakan sebagaimana sempurnanya utusan Kami, yaitu Nabi Muhammad saw. (yang membacakan kepadamu ayat-ayat Kami) Alquran, (menyucikan kamu) membersihkan kamu dari kesyirikan, (mengajari kamu Alkitab) Alquran (dan hikmah) yakni hukum-hukum yang terkandung di dalamnya, (serta mengajari kamu apa-apa yang belum kamu ketahui).\qt@no{151}}%
\qt@newcmd\qurantrans@id@clix{%
(Karena itu ingatlah kamu kepada-Ku) yakni dengan salat, tasbih dan lain-lain (niscaya Aku ingat pula kepadamu). Ada yang mengatakan maksudnya niscaya Aku balas amalmu itu. Dalam sebuah hadis qudsi diketengahkan firman Allah, ``Barang siapa yang mengingat-Ku dalam dirinya niscaya Aku akan ingat dia dalam diri-Ku dan barang siapa mengingat-Ku di hadapan khalayak ramai, maka Aku akan mengingatnya di hadapan khalayak yang lebih baik!" (Dan bersyukurlah kepada-Ku) atas nikmat-Ku dengan jalan taat kepada-Ku (dan janganlah kamu mengingkari-Ku) dengan jalan berbuat maksiat dan durhaka kepada-Ku.\qt@no{152}}%
\qt@newcmd\qurantrans@id@clx{%
(Hai orang-orang yang beriman! Mintalah pertolongan) untuk mencapai kebahagiaan akhirat (dengan jalan bersabar) taat melakukan ibadah dan sabar menghadapi cobaan (dan mengerjakan salat) dikhususkan menyebutkannya disebabkan berat dan berulang-ulang (sesungguhnya Allah bersama orang-orang yang sabar) artinya selalu melimpahkan pertolongan-Nya kepada mereka.\qt@no{153}}%
\qt@newcmd\qurantrans@id@clxi{%
(Dan janganlah kamu katakan terhadap orang yang terbunuh di jalan Allah) bahwa mereka itu (mati, tetapi) mereka itu (masih hidup) di mana roh-roh mereka bersemayam dalam jiwa burung-burung hijau terbang bebas di dalam surga ke mana saja mereka kehendaki. Demikian menurut suatu hadis, (hanya kamu tidak menyadarinya) artinya mengetahui mereka.\qt@no{154}}%
\qt@newcmd\qurantrans@id@clxii{%
(Dan sungguh Kami akan memberimu cobaan berupa sedikit ketakutan) terhadap musuh, (kelaparan) paceklik, (kekurangan harta) disebabkan datangnya malapetaka, (dan jiwa) disebabkan pembunuhan, kematian dan penyakit, (serta buah-buahan) karena bahaya kekeringan, artinya Kami akan menguji kamu, apakah kamu bersabar atau tidak. (Dan sampaikanlah berita gembira kepada orang-orang yang sabar) bahwa mereka akan menerima ganjaran kesabaran itu berupa surga.\qt@no{155}}%
\qt@newcmd\qurantrans@id@clxiii{%
(Yaitu orang-orang yang apabila mereka ditimpa musibah) bencana atau malapetaka (mereka mengucapkan, 'Innaa lillaahi') artinya sesungguhnya kita ini milik Allah; maksudnya menjadi milik dan hamba-Nya yang dapat diperlakukan-Nya sekehendak-Nya, ('wa innaa ilaihi raaji`uun') artinya dan sesungguhnya kepada-Nyalah kita akan kembali, yakni ke akhirat, di sana kita akan diberi-Nya balasan. Dalam sebuah hadis disebutkan, ``Barang siapa yang istirja`/mengucapkan 'innaa lillaahi wa innaa ilaihi raaji`uun' ketika mendapat musibah, maka ia diberi pahala oleh Allah dan diiringi-Nya dengan kebaikan." Juga diberitakan bahwa pada suatu ketika lampu Nabi saw. padam, maka beliau pun mengucapkan istirja`, lalu kata Aisyah, ``Bukankah ini hanya sebuah lampu!" Jawabnya, ``Setiap yang mengecewakan (hati) orang mukmin itu berarti musibah." Diriwayatkan oleh Abu Daud dalam kumpulan hadis-hadis mursalnya.\qt@no{156}}%
\qt@newcmd\qurantrans@id@clxiv{%
(Mereka itulah yang mendapat selawat) artinya ampunan (dari Tuhan mereka serta rahmat) atau nikmat (dan merekalah orang-orang yang mendapat petunjuk) ke arah yang benar.\qt@no{157}}%
\qt@newcmd\qurantrans@id@clxv{%
(Sesungguhnya Safa dan Marwah) nama dua bukit di Mekah (adalah sebagian dari syiar-syiar Allah) tanda-tanda kebesaran agama-Nya, jamak dari 'syaa`irah.' (Barang siapa yang melakukan ibadah haji atau umrah) artinya memakai pakaian haji atau umrah. Asal makna keduanya adalah menyengaja dan berkunjung, (maka tiada salah baginya) artinya ia tidak berdosa (mengerjakan sai) asalkan sebanyak tujuh kali. Ayat ini turun tatkala kaum muslimin tidak bersedia melakukannya, disebabkan orang-orang jahiliah dulu biasa tawaf di sana sambil menyapu dua berhala yang terdapat pada keduanya. Menurut Ibnu Abbas bahwa sai itu hukumnya tidak wajib, hanya takhyir, artinya dibolehkan memilih sebagai akibat tidak berdosa. Tetapi Syafii dan ulama lainnya berpendapat bahwa sai adalah rukun dan hukum fardunya dinyatakan oleh Nabi saw. dengan sabdanya, ``Sesungguhnya Allah mewajibkan sai atas kamu." (H.R. Baihaqi) Sabdanya pula, ``Mulailah dengan apa yang dimulai Allah, yakni Shafa." (H.R. Muslim) (Dan barang siapa yang dengan kemauan sendiri berbuat) ada yang membaca 'Taththawwa`a', yaitu dengan ditasydidkan ta pada tha, lalu diidgamkan (suatu kebaikan) maksudnya amalan yang tidak wajib seperti tawaf dan lain-lainnya (maka sesungguhnya Allah Maha Mensyukuri) perbuatannya itu dengan memberinya pahala (lagi Maha Mengetahui).\qt@no{158}}%
\qt@newcmd\qurantrans@id@clxvi{%
Ayat berikut ini turun tentang orang-orang Yahudi, (Sesungguhnya orang-orang yang menyembunyikan) kepada manusia (apa-apa yang telah Kami turunkan berupa keterangan dan petunjuk) seperti ayat rajam dan tentang ciri-ciri Nabi Muhammad saw. (setelah Kami jelaskan kepada manusia dalam Alkitab) yakni Taurat (mereka itu dikutuk oleh Allah) maksudnya disingkirkan-Nya dari rahmat-Nya (dan dikutuk pula oleh makhluk-makhluk lainnya dengan mendoakannya agar mendapat kutukan.\qt@no{159}}%
\qt@newcmd\qurantrans@id@clxvii{%
(Kecuali orang-orang yang tobat) artinya sadar dan kembali dari kesalahannya, (mengadakan perbaikan) mengenai amal perbuatan mereka, (dan memberikan penjelasan) tentang apa yang mereka sembunyikan itu, (maka terhadap mereka Kuterima tobatnya) (dan Aku Maha Penerima tobat lagi Maha Penyayang) terhadap orang-orang yang beriman.\qt@no{160}}%
\qt@newcmd\qurantrans@id@clxviii{%
(Sesungguhnya orang-orang yang kafir dan mereka mati dalam keadaan kafir) menjadi 'hal' (mereka itu mendapat kutukan Allah, malaikat dan manusia seluruhnya) maksudnya wajar mendapat kutukan itu baik di dunia maupun di akhirat. Mengenai 'manusia' ada yang mengatakannya umum dan ada pula yang mengatakannya khusus dari orang-orang beriman.\qt@no{161}}%
\qt@newcmd\qurantrans@id@clxix{%
(Mereka kekal di dalamnya) maksudnya dalam kutukan atau dalam neraka sebagaimana diisyaratkan dalam kutukan itu. (Tidak diringankan siksa dari mereka) walaupun sekejap mata (dan tidak pula mereka diberi tenggang waktu) untuk mengajukan tobat atau memohon ampun. Ayat berikut diturunkan ketika mereka berkata, ``Gambarkanlah kepadaku tentang Tuhanmu!"\qt@no{162}}%
\qt@newcmd\qurantrans@id@clxx{%
(Dan Tuhanmu) yang patut menjadi sembahanmu, (adalah Tuhan Yang Maha Esa) yang tiada bandingan-Nya, baik dalam zat maupun sifat, (tiada Tuhan melainkan Dia) (Dialah Yang Maha Pengasih lagi Maha Penyayang). Ketika mereka menuntut buktinya, turunlah ayat,\qt@no{163}}%
\qt@newcmd\qurantrans@id@clxxi{%
(Sesungguhnya pada penciptaan langit dan bumi) yakni keajaiban-keajaiban yang terdapat pada keduanya (serta pergantian malam dan siang) dengan datang dan pergi, bertambah serta berkurang, (serta perahu-perahu) atau kapal-kapal (yang berlayar di lautan) tidak tenggelam atau terpaku di dasar laut (dengan membawa apa yang berguna bagi manusia) berupa barang-barang perdagangan dan angkutan, (dan apa yang diturunkan Allah dari langit berupa air) hujan, (lalu dihidupkan-Nya bumi dengannya) yakni dengan tumbuhnya tanam-tanaman (setelah matinya) maksudnya setelah keringnya (dan disebarkan di bumi itu segala jenis hewan) karena mereka berkembang biak dengan rumput-rumputan yang terdapat di atasnya, (serta pengisaran angin) memindahkannya ke utara atau ke selatan dan mengubahnya menjadi panas atau dingin (dan awan yang dikendalikan) atas perintah Allah Taala, sehingga ia bertiup ke mana dikehendaki-Nya (antara langit dan bumi) tanpa ada hubungan dan yang mempertalikan (sungguh merupakan tanda-tanda) yang menunjukkan keesaan Allah Taala (bagi kaum yang memikirkan) serta merenungkan.\qt@no{164}}%
\qt@newcmd\qurantrans@id@clxxii{%
(Dan di antara manusia ada orang-orang yang mengambil selain dari Allah sebagai tandingan) misalnya berhala-berhala. (Mereka mencintainya) dengan penghormatan dan ketundukan (sebagaimana mencintai Allah) maksudnya sebagaimana mereka mencintai-Nya (sedangkan orang-orang beriman lebih kuat cintanya kepada Allah) melebihi kecintaan kepada siapa pun, karena mereka tak hendak berpaling daripada-Nya dalam keadaan bagaimana pun, sementara orang-orang kafir cintanya kepada Allah itu hanyalah dalam keadaan terdesak atau terpaksa. (Dan sekiranya kamu lihat) hai Muhammad (orang-orang yang aniaya) yang mengambil sekutu-sekutu bagi Allah (ketika mereka melihat) atau diperlihatkan kepada mereka, dalam bentuk aktif atau pun pasif (siksa) pastilah kamu akan menyaksikan peristiwa besar. Sedangkan 'idz' di sini berarti 'idzaa' atau 'apabila' (bahwa sesungguhnya) maksudnya karena sesungguhnya (kekuatan itu) kekuasaan dan keunggulan (bagi Allah semuanya) menjadi 'hal', (dan bahwa Allah itu amat berat siksaan-Nya). Menurut suatu qiraat dibaca 'yara' dengan titik dua di bawah, sedang yang menjadi fa`ilnya ialah dhamir atau kata ganti dari pendengar. Ada pula yang mengatakan 'orang-orang yang aniaya' sedangkan 'yaraa' berarti meyakini, sementara 'anna' dan kalimat yang di belakangnya berfungsi sebagai maf`ul awwal dan maf`ul tsani. Mengenai jawaban-jawaban 'lau' dibuang dan artinya diperkirakan sebagai berikut: Sekiranya mereka mengetahui secara pasti di atas dunia ini betapa kerasnya siksa Allah dan ketika bertemu dengan-Nya di akhirat nanti kekuasaan terpegang di tangan-Nya semata, tentulah mereka tidak akan mengambil yang lain sebagai sekutu!\qt@no{165}}%
\qt@newcmd\qurantrans@id@clxxiii{%
(Yakni ketika) menjadi badal bagi idz yang sebelumnya (orang-orang yang diikuti berlepas diri) maksudnya para pemimpin (dan orang-orang yang mengikuti) maksudnya mereka menyalahkan kekeliruannya (dan) sesungguhnya (mereka melihat siksa dan ketika terputus) `athaf atau dihubungkan pada tabarra-a (dengan mereka) maksudnya dari mereka (segala hubungan) yang terdapat di dunia selama ini berupa kekeluargaan dan kasih sayang.\qt@no{166}}%
\qt@newcmd\qurantrans@id@clxxiv{%
(Dan berkatalah orang-orang yang mengikuti, ``Sekiranya kami dapat kembali) ke dunia (tentulah kami akan berlepas diri pula dari mereka) maksudnya dari pemimpin-pemimpin yang menjadi ikutan itu, (sebagaimana mereka berlepas diri dari kami.") sekarang ini. 'Lau' untuk menyatakan angan-angan, sedangkan natabarra-u menjadi jawabannya. (Demikianlah) artinya sebagaimana Allah memperlihatkan kepada mereka sangat keras siksaan-Nya sehingga sebagian mereka saling berlepas diri (Allah memperlihatkan amal perbuatan mereka) yang jelek (menjadi sesalan) sebagai 'hal' (bagi mereka, dan mereka tidak akan dapat keluar dari neraka) yakni setelah memasukinya.\qt@no{167}}%
\qt@newcmd\qurantrans@id@clxxv{%
Ayat berikut ini turun tentang orang-orang yang mengharamkan sebagian jenis unta/sawaib yang dihalalkan, (Hai sekalian manusia, makanlah yang halal dari apa-apa yang terdapat di muka bumi) halal menjadi 'hal' (lagi baik) sifat yang memperkuat, yang berarti enak atau lezat, (dan janganlah kamu ikuti langkah-langkah) atau jalan-jalan (setan) dan rayuannya (sesungguhnya ia menjadi musuh yang nyata bagimu) artinya jelas dan terang permusuhannya itu.\qt@no{168}}%
\qt@newcmd\qurantrans@id@clxxvi{%
(Sesungguhnya setan itu hanya menyuruh kamu berbuat dosa) yakni dosa (dan yang keji) yakni yang buruk menurut syariat (dan agar kamu mengatakan terhadap Allah apa yang tidak kamu ketahui) misalnya mengharamkan apa yang tidak diharamkan Allah dan selainnya.\qt@no{169}}%
\qt@newcmd\qurantrans@id@clxxvii{%
(Dan apabila dikatakan kepada mereka) kepada orang-orang kafir, ("Ikutilah apa yang telah diturunkan Allah,") berupa tauhid dan menghalalkan yang baik-baik, (mereka menjawab,) ``Tidak!' (Tetapi kami hanya akan mengikuti apa yang kami jumpai) atau dapati (dari nenek moyang kami.") berupa pemujaan berhala, diharamkannya bahair/unta yang dipotong telinganya dan sawaib/unta yang tidak boleh dimanfaatkan, dibiarkan lepas bebas hingga mati dengan sendirinya. (Apakah) mereka akan mengikuti juga (walaupun mereka itu tidak mengetahui sesuatu) mengenai urusan keagamaan (dan tidak pula beroleh petunjuk) untuk mencapai kebenaran. Hamzah atau 'apakah' di atas untuk pengingkaran.\qt@no{170}}%
\qt@newcmd\qurantrans@id@clxxviii{%
(Dan perumpamaan) menjadi sifat (orang-orang kafir) serta orang yang mengajak mereka kepada petunjuk (adalah seperti orang yang memanggil binatang) berteriak memanggil (yang tidak dapat didengarnya selain berupa panggilan dan seruan saja) artinya suara yang tidak diketahui dan dimengerti maknanya. Maksudnya dalam menerima nasihat dan tidak memikirkannya, mereka itu adalah seperti hewan yang mendengar suara penggembalanya tetapi tidak paham akan maksudnya. (Mereka tuli, bisu, dan buta sehingga mereka tidak mengerti) akan nasihat.\qt@no{171}}%
\qt@newcmd\qurantrans@id@clxxix{%
(Hai orang-orang yang beriman! Makanlah di antara makanan yang baik-baik) maksudnya yang halal, (yang Kami berikan kepadamu, dan bersyukurlah kepada Allah) atas makanan yang dihalalkan itu (jika kamu benar-benar hanya kepada-Nya menyembah).\qt@no{172}}%
\qt@newcmd\qurantrans@id@clxxx{%
(Sesungguhnya Allah hanya mengharamkan bagimu bangkai) maksudnya memakannya karena konteks pembicaraan mengenai hal itu, maka demikian pula halnya yang sesudahnya. Bangkai ialah hewan yang tidak disembelih menurut syariat. Termasuk dalam hal ini hewan-hewan hidup yang disebutkan dalam hadis, kecuali ikan dan belalang (darah) maksudnya yang mengalir sebagaimana kita dapati pada binatang-binatang ternak, (daging babi) disebutkan daging, karena merupakan maksud utama, sedangkan yang lain mengikutinya (dan binatang yang ketika menyembelihnya disebut nama selain Allah) artinya binatang yang disembelih dengan menyebut nama selain asma Allah. 'Uhilla' dari 'ihlaal' ialah mengeraskan suara yang biasa mereka lakukan ketika menyembelih kurban buat tuhan-tuhan mereka. (Tetapi barang siapa berada dalam keadaan terpaksa) artinya keadaan memaksanya untuk memakan salah satu yang diharamkan ini lalu ia memakannya (sedangkan ia tidak menginginkannya) tidak keluar dari golongan kaum muslimin (dan ia tidak menjadi seorang yang melampaui batas) yaitu melakukan pelanggaran terhadap mereka dengan menyamun mereka dalam perjalanan (maka tidaklah berdosa) memakannya. (Sesungguhnya Allah Maha Pengampun) terhadap wali-wali-Nya (lagi Maha Penyayang) kepada hamba-hamba-Nya yang taat sehingga mereka diberi-Nya kemudahan dalam hal itu. Menurut Imam Syafii, mereka yang tidak dibolehkan memakan sedikit pun dari kemurahan yang telah Allah perkenankan itu ialah setiap orang yang melakukan maksiat dalam perjalanannya, seperti budak yang melarikan diri dari tuannya dan orang yang memungut cukai tidak legal selama mereka belum bertobat.\qt@no{173}}%
\qt@newcmd\qurantrans@id@clxxxi{%
(Sesungguhnya orang-orang yang menyembunyikan apa yang diturunkan Allah berupa Alkitab) yakni yang memuat ciri-ciri Nabi Muhammad saw. dan yang dituju oleh ayat ini ialah orang-orang Yahudi (dan menjualnya dengan harga sedikit) atau murah berupa harta dunia yang mereka dapatkan sebagai penggantinya dari kalangan rakyat bawahan sehingga mereka tidak mengungkapkannya sebab takut kehilangan hal tersebut. (Mereka itu tidak menelan ke dalam perutnya, kecuali api neraka) karena ke sanalah tempat kembali mereka, (Allah tidak akan berbicara dengan mereka pada hari kiamat) disebabkan murka kepada mereka (dan tidak pula akan menyucikan mereka) dari kotoran dosa-dosa (dan bagi mereka siksa yang pedih) atau menyakitkan yaitu api neraka.\qt@no{174}}%
\qt@newcmd\qurantrans@id@clxxxii{%
(Mereka itulah orang-orang yang membeli kesesatan dengan petunjuk) yang mereka ambil sebagai penggantinya di atas dunia (dan siksa dengan keampunan) yang disediakan bagi mereka di akhirat, yakni seandainya mereka tidak menyembunyikannya. (Maka alangkah sabarnya mereka menghadapi api neraka) artinya alangkah sabarnya mereka menanggung api neraka dan ini mengundang keheranan kaum muslimin terhadap perbuatan-perbuatan mereka yang menjerumuskan ke dalam neraka tanpa mempedulikannya. Kalau tidak demikian, kesabaran terhadap apakah yang mereka miliki itu?\qt@no{175}}%
\qt@newcmd\qurantrans@id@clxxxiii{%
(Demikian itu), yakni apa-apa yang telah disebutkan seperti menelan api dan seterusnya (disebabkan oleh karena) (Allah telah menurunkan Alkitab dengan sebenarnya) berkaitan dengan menurunkan, maka mereka berselisih padanya, mereka beriman pada sebagian dan kafir pada sebagian dengan jalan menyembunyikannya. (Dan sesungguhnya orang-orang yang berselisih tentang Alkitab) yakni orang-orang Yahudi dan ada pula yang mengatakan bahwa mereka itu adalah orang-orang musyrik, yaitu tentang Alquran, sebagian mengatakannya sebagai syair, yang lain sihir dan sebagiannya lagi sebagai tenung (berada dalam penyimpangan yang jauh) dari kebenaran.\qt@no{176}}%
\qt@newcmd\qurantrans@id@clxxxiv{%
(Kebaktian itu bukanlah dengan menghadapkan wajahmu) dalam salat (ke arah timur dan barat) ayat ini turun untuk menolak anggapan orang-orang Yahudi dan Kristen yang menyangka demikian, (tetapi orang yang berbakti itu) ada yang membaca 'al-barr' dengan ba baris di atas, artinya orang yang berbakti (ialah orang yang beriman kepada Allah, hari akhir, malaikat-malaikat, kitab) maksudnya kitab-kitab suci (dan nabi-nabi) serta memberikan harta atas) artinya harta yang (dicintainya) (kepada kaum kerabat) atau famili (anak-anak yatim, orang-orang miskin, orang yang dalam perjalanan) atau musafir, (orang-orang yang meminta-minta) atau pengemis, (dan pada) memerdekakan (budak) yakni yang telah dijanjikan akan dibebaskan dengan membayar sejumlah tebusan, begitu juga para tawanan, (serta mendirikan salat dan membayar zakat) yang wajib dan sebelum mencapai nisabnya secara tathawwu` atau sukarela, (orang-orang yang menepati janji bila mereka berjanji) baik kepada Allah atau kepada manusia, (orang-orang yang sabar) baris di atas sebagai pujian (dalam kesempitan) yakni kemiskinan yang sangat (penderitaan) misalnya karena sakit (dan sewaktu perang) yakni ketika berkecamuknya perang di jalan Allah. (Mereka itulah) yakni yang disebut di atas (orang-orang yang benar) dalam keimanan dan mengakui kebaktian (dan mereka itulah orang-orang yang bertakwa) kepada Allah.\qt@no{177}}%
\qt@newcmd\qurantrans@id@clxxxv{%
(Hai orang-orang beriman, diwajibkan atas kamu kisas) pembalasan yang setimpal (berkenaan dengan orang-orang yang dibunuh) baik tentang sifat maupun perbuatan (orang merdeka) dibunuh (oleh orang merdeka) maka tidak boleh oleh hamba (hamba oleh hamba dan wanita oleh wanita). Sunah menyatakan bahwa laki-laki boleh dibunuh oleh wanita dan dalam agama dipandang seimbang atau sebanding, tetapi tidak boleh seorang Islam walaupun ia seorang hamba dibunuh oleh seorang kafir walaupun ia seorang merdeka. (Barang siapa yang mendapat kemaafan) maksudnya di antara pembunuh-pembunuh itu (berkenaan dengan) darah (saudaranya) yang dibunuh (berupa sesuatu) misalnya dengan ditiadakannya kisas yang menyebabkan gugurnya sebagian hukuman oleh sebagian ahli waris. Dengan disebutkannya 'saudaranya', membangkitkan rasa santun yang mendorong seseorang untuk memaafkan dan menjadi pernyataan bahwa pembunuhan itu tidaklah mengakibatkan putusnya persaudaraan dalam agama dan keimanan. 'Man' yang merupakan syarthiyah atau isim maushul menjadi mubtada, sedangkan khabarnya ialah, (maka hendaklah mengikuti) artinya orang yang memaafkan itu terhadap pembunuh hendaklah mengikuti (dengan cara yang baik) misalnya memintanya supaya membayar diat atau denda dengan baik-baik dan tidak kasar. Pengaturan 'mengikuti' terhadap 'memaafkan' menunjukkan bahwa yang wajib ialah salah satu di antara keduanya dan ini merupakan salah satu di antara kedua pendapat Syafii, sedangkan menurut pendapatnya yang kedua yang wajib itu ialah kisas, sedangkan diat menjadi penggantinya. Sekiranya seseorang memaafkan dan tidak menyebutkan diat, maka bebaslah dari segala kewajiban (dan) hendaklah si pembunuh (membayar) diat (kepadanya) yaitu kepada yang memaafkan tadi, yakni ahli waris (dengan cara yang baik pula) artinya tanpa melalaikan dan mengurangi pembayarannya. (Demikian itu) maksudnya diperbolehkan mengganti hukum kisas dan kemaafan dengan diat, hal ini adalah (suatu keringanan) atau kemudahan (dari Tuhanmu) terhadapmu (suatu rahmat) kepadamu berupa kelapangan dan tidak dipastikan-Nya salah satu di antara keduanya, seperti diwajibkan-Nya kisas atas orang-orang Yahudi dan diat atas orang-orang Kristen. (Dan barang siapa yang melanggar batas) misalnya dianiayanya si pembunuh dengan membunuhnya pula (sesudah itu) maksudnya setelah memaafkan, (maka baginya siksa yang pedih) atau menyakitkan, yaitu di akhirat dengan api neraka, atau di dunia dengan dibunuh pula.\qt@no{178}}%
\qt@newcmd\qurantrans@id@clxxxvi{%
(Dan bagimu dalam kisas itu terdapat kehidupan) artinya terjaminnya kelangsungan hidup manusia (hai orang-orang yang berakal) karena jika seseorang yang akan membunuh itu mengetahui bahwa ia akan dibunuh pula, maka ia akan merasa takut lalu mengurungkan rencananya sehingga berarti ia telah memelihara nyawanya dan nyawa orang yang akan dibunuhnya tadi. Disyariatkan oleh Allah Taala (supaya kamu bertakwa) artinya menjaga dirimu dari membunuh, agar terhindar dari kisas.\qt@no{179}}%
\qt@newcmd\qurantrans@id@clxxxvii{%
(Diwajibkan atas kamu, apabila salah seorang di antara kamu didatangi maut) maksudnya tanda-tandanya (jika ia meninggalkan kebaikan) yakni harta yang banyak, (berwasiat) baris di depan sebagai naibul fa`il dari kutiba, dan tempat berkaitnya 'idzaa' jika merupakan zharfiyah dan menunjukkan hukumnya jika ia syartiyah dan sebagai jawaban pula dari 'in', artinya hendaklah ia berwasiat (untuk ibu bapak dan kaum kerabat secara baik-baik) artinya dengan adil dan tidak lebih dari sepertiga harta dan jangan mengutamakan orang kaya (merupakan kewajiban) mashdar yang memperkuat isi kalimat yang sebelumnya (bagi orang-orang yang bertakwa) kepada Allah. Ayat ini telah dihapus dan diganti dengan ayat tentang waris dan dengan hadis, ``Tidak ada wasiat untuk ahli waris." (H.R. Tirmizi)\qt@no{180}}%
\qt@newcmd\qurantrans@id@clxxxviii{%
(Barang siapa yang mengubahnya) mengubah wasiat, baik ia sebagai saksi atau yang menyampaikannya (setelah ia mendengarnya) atau mengetahuinya, (maka sesungguhnya dosanya) maksudnya dosa dari pemalsuan wasiat itu (atas orang-orang yang mengubahnya.) Di sini terdapat penempatan zahir pada tempat mudhmar. (Sesungguhnya Allah Maha Mengetahui) perbuatannya dan akan membalasnya.\qt@no{181}}%
\qt@newcmd\qurantrans@id@clxxxix{%
(Tetapi barang siapa merasa khawatir terhadap orang yang berwasiat) ada yang membaca muushin dan ada pula yang membaca muwashshin (berlaku berat sebelah) menyimpang dari keadilan (atau berbuat dosa) misalnya dengan sengaja melebihi sepertiga atau mengistimewakan orang kaya, (lalu didamaikannya di antara mereka) yakni antara yang menyampaikan dan yang diberi wasiat dengan menyuruh menepati keadilan, (sesungguhnya Allah Maha Pengampun lagi Maha Penyayang).\qt@no{182}}%
\qt@newcmd\qurantrans@id@cxc{%
(Hai orang-orang yang beriman, diwajibkan atas kamu berpuasa sebagaimana diwajibkan atas orang-orang sebelum kamu) di antara umat manusia (agar kamu bertakwa) maksudnya menjaga diri dari maksiat, karena puasa itu dapat membendung syahwat yang menjadi pangkal sumber kemaksiatan itu.\qt@no{183}}%
\qt@newcmd\qurantrans@id@cxci{%
(Beberapa hari) manshub atau baris di atas sebagai maf`ul dari fi`il amar yang bunyinya diperkirakan 'shiyam' atau 'shaum' (berbilang) artinya yang sedikit atau ditentukan waktunya dengan bilangan yang telah diketahui, yakni selama bulan Ramadan sebagaimana yang akan datang nanti. Dikatakannya 'yang sedikit' untuk memudahkan bagi mualaf. (Maka barang siapa di antara kamu) yakni sewaktu kehadiran hari-hari berpuasa itu (sakit atau dalam perjalanan) maksudnya perjalanan untuk mengerjakan puasa dalam kedua situasi tersebut, lalu ia berbuka, (maka hendaklah dihitungnya) berapa hari ia berbuka, lalu berpuasalah sebagai gantinya (pada hari-hari yang lain.) (Dan bagi orang-orang yang) (tidak sanggup melakukannya) disebabkan usia lanjut atau penyakit yang tak ada harapan untuk sembuh (maka hendaklah membayar fidyah) yaitu (memberi makan seorang miskin) artinya sebanyak makanan seorang miskin setiap hari, yaitu satu gantang/mud dari makanan pokok penduduk negeri. Menurut satu qiraat, dengan mengidhafatkan 'fidyah' dengan tujuan untuk penjelasan. Ada pula yang mengatakan tidak, bahkan tidak ditentukan takarannya. Di masa permulaan Islam, mereka diberi kesempatan memilih, apakah akan berpuasa atau membayar fidyah. Kemudian hukum ini dihapus (mansukh) dengan ditetapkannya berpuasa dengan firman-Nya. ``Maka barang siapa di antara kamu yang menyaksikan bulan, hendaklah ia berpuasa." Kata Ibnu Abbas, ``Kecuali wanita hamil dan yang sedang menyusui, jika berbukanya itu disebabkan kekhawatiran terhadap bayi, maka membayar fidyah itu tetap menjadi hak mereka tanpa nasakh." (Dan barang siapa yang secara sukarela melakukan kebaikan) dengan menambah batas minimal yang disebutkan dalam fidyah tadi (maka itu) maksudnya berbuat tathawwu` atau kebaikan (lebih baik baginya. Dan berpuasa) menjadi mubtada', sedangkan khabarnya ialah, (lebih baik bagi kamu) daripada berbuka dan membayar fidyah (jika kamu mengetahui) bahwa berpuasa lebih baik bagimu, maka lakukanlah.\qt@no{184}}%
\qt@newcmd\qurantrans@id@cxcii{%
Hari-hari tersebut adalah (bulan Ramadan yang padanya diturunkan Alquran) yakni dari Lohmahfuz ke langit dunia di malam lailatulkadar (sebagai petunjuk) menjadi 'hal', artinya yang menunjukkan dari kesesatan (bagi manusia dan penjelasan-penjelasan) artinya keterangan-keterangan yang nyata (mengenai petunjuk itu) yang menuntun pada hukum-hukum yang hak (dan) sebagai (pemisah) yang memisahkan antara yang hak dengan yang batil. (Maka barang siapa yang menyaksikan) artinya hadir (di antara kamu di bulan itu, hendaklah ia berpuasa dan barang siapa sakit atau dalam perjalanan, lalu ia berbuka, maka wajib baginya berpuasa sebanyak hari yang ditinggalkannya itu pada hari yang lain) sebagaimana telah diterangkan terdahulu. Diulang-ulang agar jangan timbul dugaan adanya nasakh dengan diumumkannya 'menyaksikan bulan' (Allah menghendaki kemudahan bagimu dan tidak menghendaki kesempitan) sehingga oleh karenanya kamu diperbolehkan-Nya berbuka di waktu sakit dan ketika dalam perjalanan. Karena yang demikian itu merupakan `illat atau motif pula bagi perintah berpuasa, maka diathafkan padanya. (Dan hendaklah kamu cukupkan) ada yang membaca 'tukmiluu' dan ada pula 'tukammiluu' (bilangan) maksudnya bilangan puasa Ramadan (hendaklah kamu besarkan Allah) sewaktu menunaikannya (atas petunjuk yang diberikan-Nya kepadamu) maksudnya petunjuk tentang pokok-pokok agamamu (dan supaya kamu bersyukur) kepada Allah Taala atas semua itu.\qt@no{185}}%
\qt@newcmd\qurantrans@id@cxciii{%
(Segolongan orang-orang bertanya kepada Nabi saw., ``Apakah Tuhan kami dekat, maka kami akan berbisik kepada-Nya, atau apakah Dia jauh, maka kami akan berseru kepada-Nya." Maka turunlah ayat ini. ("Dan apabila hamba-hamba-Ku menanyakan kepadamu tentang Aku, maka sesungguhnya Aku Maha Dekat) kepada mereka dengan ilmu-Ku, beritahukanlah hal ini kepada mereka (Aku kabulkan permohonan orang yang berdoa, jika ia berdoa kepada-Ku) sehingga ia dapat memperoleh apa yang dimohonkan. (Maka hendaklah mereka itu memenuhi pula perintah-Ku) dengan taat dan patuh (serta hendaklah mereka beriman) senantiasa iman (kepada-Ku supaya mereka berada dalam kebenaran.") atau petunjuk Allah.\qt@no{186}}%
\qt@newcmd\qurantrans@id@cxciv{%
(Dihalalkan bagi kamu pada malam hari puasa berkencan dengan istri-istrimu) maksudnya mencampuri mereka. Ayat ini turun menasakhkan hukum yang berlaku di masa permulaan Islam, berupa pengharaman mencampuri istri, begitu pula diharamkan makan minum setelah waktu Isyak. (Mereka itu pakaian bagi kamu dan kamu pakaian bagi mereka) kiasan bahwa mereka berdua saling bergantung dan saling membutuhkan. (Allah mengetahui bahwa kamu akan berkhianat pada) atau mengkhianati (dirimu) dengan melakukan jimak atau hubungan suami istri pada malam hari puasa. Hal itu pernah terjadi atas diri Umar dan sahabat lainnya, lalu ia segera memberitahukannya kepada Nabi saw., (maka Allah pun menerima tobatmu) yakni sebelum kamu bertobat (dan dimaafkan-Nya kamu. Maka sekarang) karena telah dihalalkan bagimu (campurilah mereka itu) (dan usahakanlah) atau carilah (apa-apa yang telah ditetapkan Allah bagimu) artinya apa yang telah diperbolehkan-Nya seperti bercampur atau mendapatkan anak (dan makan minumlah) sepanjang malam itu (hingga nyata) atau jelas (bagimu benang putih dari benang hitam berupa fajar sidik) sebagai penjelasan bagi benang putih, sedangkan penjelasan bagi benang hitam dibuang, yaitu berupa malam hari. Fajar itu tak ubahnya seperti warna putih bercampur warna hitam yang memanjang dengan dua buah garis berwarna putih dan hitam. (Kemudian sempurnakanlah puasa itu) dari waktu fajar (sampai malam) maksudnya masuknya malam dengan terbenamnya matahari (dan janganlah kamu campuri mereka) maksudnya istri-istri kamu itu (sedang kamu beriktikaf) atau bermukim dengan niat iktikaf (di dalam mesjid-mesjid) seorang yang beriktikaf dilarang keluar mesjid untuk mencampuri istrinya lalu kembali lagi. (Itulah) yakni hukum-hukum yang telah disebutkan tadi (larangan-larangan Allah) yang telah digariskan-Nya bagi hamba-hamba-Nya agar mereka tidak melanggarnya (maka janganlah kami mendekatinya). Kalimat itu lebih mengesankan dari kalimat ``janganlah kamu melanggarnya" yang diucapkan pada ayat lain. (Demikianlah sebagaimana telah dinyatakan-Nya bagi kamu apa yang telah disebutkan itu (Allah menjelaskan ayat-ayat-Nya bagi manusia supaya mereka bertakwa) maksudnya menjauhi larangan-Nya.\qt@no{187}}%
\qt@newcmd\qurantrans@id@cxcv{%
(Dan janganlah kamu memakan harta sesama kamu), artinya janganlah sebagian kamu memakan harta sebagian yang lain (dengan jalan yang batil), maksudnya jalan yang haram menurut syariat, misalnya dengan mencuri, mengintimidasi dan lain-lain (Dan) janganlah (kamu bawa) atau ajukan (ia) artinya urusan harta ini ke pengadilan dengan menyertakan uang suap (kepada hakim-hakim, agar kamu dapat memakan) dengan jalan tuntutan di pengadilan itu (sebagian) atau sejumlah (harta manusia) yang bercampur (dengan dosa, padahal kamu mengetahui) bahwa kamu berbuat kekeliruan.\qt@no{188}}%
\qt@newcmd\qurantrans@id@cxcvi{%
(Mereka menanyakan kepadamu) hai Muhammad, (tentang bulan sabit). 'Ahillah' jamak dari 'hilal'. Pada permulaannya tampak kecil tipis kemudian terus bertambah hingga penuh dengan cahaya. Lalu kembali sebagaimana semula, maka keadaannya tidak seperti matahari yang tetap (katakanlah) kepada mereka, ("Ia adalah tanda-tanda waktu); mawaaqiit jamak dari miiqaat (bagi manusia) untuk mengetahui waktu bercocok tanam, berdagang, idah wanita, berpuasa, dan berbuka mereka (dan bagi haji) diathafkan atau dihubungkan kepada manusia, artinya untuk diketahui waktunya. Karena seandainya bulan tetap dalam keadaan yang sama, tentulah hal itu tidak dapat diketahui (Dan bukanlah kebaktian, jika kamu memasuki rumah-rumah dari belakangnya) yakni di waktu ihram, dengan membuat lubang di belakang rumah untuk tempat keluar masuk kamu dengan meninggalkan pintu. Hal itu biasa mereka lakukan dulu dan mereka anggap sebagai kebaktian, (tetapi kebaktian itu), maksudnya orang yang berbakti (ialah orang yang bertakwa) kepada Allah dengan tidak melanggar perintah-perintah-Nya, (dan masuklah ke rumah-rumah itu dari pintu-pintunya) baik sewaktu ihram maupun pada waktu-waktu lainnya, (dan bertakwalah kepada Allah agar kamu beroleh keberuntungan").\qt@no{189}}%
\qt@newcmd\qurantrans@id@cxcvii{%
Tatkala Nabi saw. dihalangi kaum Quraisy untuk mengunjungi Baitullah pada perjanjian Hudaibiah dan berdamai dengan orang-orang kafir itu untuk kembali di tahun depan, di mana ia diberi kesempatan untuk memasuki Mekah selama tiga hari, kemudian tatkala ia telah bersiap-siap untuk umrah kada, sedangkan kaum muslimin merasa khawatir kalau-kalau Quraisy tidak menepati janjinya lalu memerangi mereka, padahal kaum muslimin tak mau melayani mereka jika di saat ihram, di tanah haram dan di bulan haram; maka turunlah ayat, (Dan perangilah di jalan Allah), maksudnya untuk menjunjung tinggi agama-Nya (orang-orang yang memerangi kamu) di antara orang-orang kafir (tetapi janganlah kamu melampaui batas) misalnya dengan memulai peperangan terhadap mereka (karena sesungguhnya Allah tidak menyukai orang-orang yang melampaui batas), artinya yang melanggar apa-apa yang telah digariskan bagi mereka. Dan ini dinasakh dengan ayat Bara-ah atau dengan firman-Nya:\qt@no{190}}%
\qt@newcmd\qurantrans@id@cxcviii{%
(Dan bunuhlah mereka di mana saja kamu menjumpai mereka, serta usirlah mereka di mana mereka mengusir kamu) artinya Mekah, dan ini telah dilakukan nabi terhadap mereka pada tahun pembebasan (sedangkan fitnah itu), artinya kesyirikan mereka (lebih berat), maksudnya lebih berbahaya (dari pembunuhan) terhadap mereka, yakni di tanah suci atau sewaktu ihram yang mereka hormati itu. (Dan janganlah kamu memerangi mereka di Masjidilharam), maksudnya di tanah suci, (sebelum mereka memerangi kamu di tempat itu. Jika mereka memerangi kamu) di sana, (maka bunuhlah mereka). Menurut satu qiraat tanpa alif pada kata kerja yang tiga, 'wala taqtuluuhum, hatta yaqtuluukum fiih, dan fa-in qataluukum'. (Demikianlah), maksudnya pembunuhan dan pengusiran (menjadi balasan bagi orang-orang kafir).\qt@no{191}}%
\qt@newcmd\qurantrans@id@cxcix{%
(Jika mereka berhenti) dari kekafiran lalu masuk Islam, (maka sesungguhnya Allah Maha Pengampun lagi Maha Penyayang) terhadap mereka.\qt@no{192}}%
\qt@newcmd\qurantrans@id@cc{%
(Dan perangilah mereka itu hingga tidak ada lagi) atau tidak dijumpai lagi (fitnah) yakni kesyirikan (dan (sehingga) agama itu) pengabdian atau perhambaan diri itu (hanya untuk Allah) semata dan tak ada yang disembah selain Dia. (Maka jika mereka berhenti) dari kesyirikan, janganlah kamu melakukan pelanggaran terhadap mereka; makna ini dapat disimpulkan dari (maka tak ada permusuhan lagi) seperti membunuh atau lainnya, (kecuali terhadap orang-orang yang aniaya). Orang yang telah menghentikan kekeliruannya, maka tidak termasuk orang yang aniaya, sehingga tidak perlu mendapat tindakan permusuhan lagi.\qt@no{193}}%
\qt@newcmd\qurantrans@id@cci{%
(Bulan haram), artinya bulan suci harus dibalas pula (dengan bulan haram), maksudnya sebagaimana mereka memerangi kamu pada bulan suci, perangilah pula mereka pada bulan itu sebagai sanggahan atas sikap kaum muslimin yang menghormati bulan suci (dan pada semua yang patut dihormati) jamak dari hurmatun (berlaku hukum kisas), maksudnya bila kehormatan itu dilanggar, maka hendaklah dibalas dengan perbuatan yang setimpal (Maka barang siapa yang menyerang kamu) dalam suatu pelanggaran di tanah suci, di waktu ihram atau di bulan-bulan haram, (maka seranglah pula dia dengan suatu serangan yang seimbang dengan serangan terhadap kamu). Tindakan pembalasan itu disebut 'serangan' karena sama dengan timpalannya dalam bentuk dan rupa (Dan bertakwalah kepada Allah) dalam membela diri, jangan melampaui batas (Dan ketahuilah olehmu bahwa Allah bersama orang-orang yang bertakwa), yakni memberi bantuan dan kemenangan.\qt@no{194}}%
\qt@newcmd\qurantrans@id@ccii{%
(Dan belanjakanlah di jalan Allah), artinya menaatinya, seperti dalam berjihad dan lain-lainnya (dan janganlah kamu jatuhkan tanganmu), maksudnya dirimu. Sedangkan ba sebagai tambahan (ke dalam kebinasaan) atau kecelakaan disebabkan meninggalkan atau mengeluarkan sana untuk berjihad yang akan menyebabkan menjadi lebih kuatnya pihak musuh daripada kamu. (Dan berbuat baiklah kamu), misalnya dengan mengeluarkan nafkah dan lain-lainnya (Sesungguhnya Allah mengasihi orang yang berbuat baik), artinya akan memberi pahala mereka.\qt@no{195}}%
\qt@newcmd\qurantrans@id@cciii{%
(Dan sempurnakanlah haji dan umrah karena Allah), artinya lakukanlah dengan memenuhi semua haknya (dan jika kamu terkepung), artinya terhalang untuk menyelesaikannya disebabkan ada musuh, (maka hendaklah menyembelih hewan yang mudah didapat), yaitu seekor kambing (dan janganlah kamu cukur kepalamu), maksudnya jangan tahalul (sebelum sampai sembelihan) tersebut (ke tempat penyembelihannya), artinya tempat penyembelihannya. Menurut Syafii adalah tempat terkepung itu. Maka hendaklah disembelih di sana dengan niat tahalul, lalu dibagi-bagikan kepada fakir miskin, kemudian bercukur rambut, sehingga dengan demikian tercapailah tahalul. (Dan barang siapa di antara kamu sakit atau ada gangguan pada kepalanya) berkutu dan pusing, lalu ia bercukur di waktu ihram (maka hendaklah ia membayar fidyah), (yaitu berpuasa) selama tiga hari (atau bersedekah) sebanyak tiga sukat makanan pokok penduduk itu kepada enam orang fakir miskin (atau berkurban), artinya menyembelih kambing. 'Au' yang berarti 'atau' memberi kesempatan untuk memilih. Termasuk pula dalam hal ini orang yang bercukur tanpa halangan apa-apa, karena ia lebih pantas lagi untuk membelinya, membayar denda atau tebusan. Demikian pula orang yang menikmati apa-apa yang dilarang tanpa bercukur, seperti memakai minyak wangi, pakaian yang berjahit atau minyak rambut yang disebabkan sesuatu halangan atau lainnya (Maka apabila kamu telah merasa aman) dari bahaya musuh-musuhmu, misalnya mereka telah pergi atau sudah tidak ada lagi (maka bagi siapa yang hendak bertamatu) yaitu (mendahulukan umrah) disebabkan telah kosongnya ia dari larangan-larangan ihram (daripada haji), maksudnya sampai saat ihram dengannya asal saja masih pada bulan-bulannya, (maka hendaklah wajib ia menyembelih kurban yang mudah didapat), yaitu seekor kambing yang harus disembelihnya sesudah ihram haji, dan lebih utama pada hari kurban. (Tetapi apabila ia tidak menemukan) kurban, misalnya karena hewan itu tidak ada, atau tidak punya uang untuk membelinya, (maka hendaklah ia berpuasa), artinya wajib atasnya berpuasa (tiga hari dalam masa haji) artinya sewaktu sedang ihram, dengan demikian ia wajib melakukan ihram sebelum tanggal tujuh Zulhijah, dan lebih utama sebelum tanggal enam, karena makruhnya berpuasa pada hari Arafah, sedangkan menurut salah satu di antara dua pendapat Syafii yang lebih sah, tidak boleh mempuasakannya pada hari-hari tasyrik (dan tujuh hari lagi bila kamu telah pulang) ke kampung halamanmu, baik Mekah atau lainnya. Ada pula yang mengatakan jika telah selesai dari pekerjaan-pekerjaan haji tanpa mempedulikan soal di rantau atau tidaknya. (Itulah sepuluh hari yang sempurna) suatu jumlah untuk menguatkan yang sebelumnya. (Demikian itu) maksudnya hukum yang telah disebutkan tadi berupa kewajiban menyembelih kurban atau berpuasa bagi orang yang mengerjakan haji secara tamatu (adalah bagi orang yang keluarganya tidak berada di sekitar Masjidilharam). Menurut Syafii, tidak berada kurang dari dua marhalah dari tanah suci. Jika sebaliknya, maka tak ada kurban dan tidak pula berpuasa sekalipun ia melakukan tamatu. Disebutkannya ahli atau penduduk, memperingatkan kita disyaratkannya status sebagai penduduk. Sekiranya ia bermukim sebelum bulan-bulan haji tetapi tidak menjadi penduduk tetap, lalu ia bertamatu, maka wajiblah baginya demikian itu. Ini merupakan salah satu dari dua pendapat Syafii, sedangkan pendapatnya yang kedua adalah tidak wajib. 'Ahli' itu merupakan sindiran terhadap diri orang yang bersangkutan. Sebagaimana disebutkan dalam hadis, termasuk pula dalam tamatuk ini ialah qiran artinya orang yang ihram dengan haji dan umrah sekaligus atau memasukkan haji ke dalam umrah sebelum memulai tawaf (Dan bertakwalah kamu kepada Allah), yakni mengenai perintah dan larangan-Nya (serta ketahuilah bahwa Allah amat berat siksaan-Nya), yakni bagi orang yang melanggar peraturan-Nya.\qt@no{196}}%
\qt@newcmd\qurantrans@id@cciv{%
(Haji), maksudnya adalah waktu dan musimnya (beberapa bulan yang dimaklumi), yaitu Syawal, Zulkaidah dan 10 hari pertama bulan Zulhijah. Tetapi ada pula yang mengatakan seluruh bulan Zulhijah. (Maka barang siapa yang telah menetapkan niatnya) dalam dirinya (akan melakukan ibadah haji pada bulan-bulan itu) dengan mengihramkannya, (maka tidak boleh ia mencampuri istrinya), yakni bersetubuh (dan jangan berbuat kefasikan) berbuat maksiat (dan jangan berbantah-bantahan) atau terlibat dalam percekcokan (sewaktu mengerjakan haji). Menurut satu qiraat, dengan baris di atas dua hal yang pertama dan makna yang dimaksud adalah larangan mengerjakan tiga hal itu. (Dan apa yang kamu kerjakan berupa kebaikan) sedekah (pastilah diketahui oleh Allah) yang akan membalas kebaikan itu. Ayat berikut ini diturunkan kepada penduduk Yaman yang pergi naik haji tanpa membawa bekal, sehingga mereka menjadi beban orang lain. (Dan berbekallah kamu) yang akan menyampaikan kamu ke tujuan perjalananmu (dan sesungguhnya sebaik-baik bekal adalah takwa), artinya yang dipergunakan manusia untuk menjaga dirinya agar tidak menjadi beban bagi orang lain dan sebagainya. (Dan bertakwalah kamu kepada-Ku, hai orang-orang yang berakal).\qt@no{197}}%
\qt@newcmd\qurantrans@id@ccv{%
(Tidak ada dosa bagi kamu) dalam (mencari) atau mengusahakan (karunia) atau rezeki (dari Tuhanmu) yakni dengan berniaga di musim haji. Ayat ini turun untuk menolak anggapan mereka yang keliru itu (Maka jika kamu telah bertolak), artinya berangkat (dari Arafah) yakni setelah wukuf di sana, (maka berzikirlah kepada Allah), yakni setelah bermalam di Muzdalifah sambil membaca talbiah, tahlil dan berdoa (di Masyarilharam) yaitu nama sebuah bukit di ujung Muzdalifah disebut Quzah. Dalam sebuah hadis disebutkan bahwa Nabi saw. wukuf di sana, berzikir dan berdoa kepada Allah hingga hari telah amat benderang." (H.R. Muslim). (Dan berzikirlah kepada-Nya disebabkan petunjuk yang diberikan-Nya kepadamu) untuk mengetahui pokok-pokok agama dan tata cara hajinya. 'Kaf' menunjukkan sebab atau motifnya. (Dan sesungguhnya) dibaca 'in' bukan 'inna' (kamu sebelum itu) maksudnya sebelum petunjuk itu (termasuk orang-orang yang sesat).\qt@no{198}}%
\qt@newcmd\qurantrans@id@ccvi{%
(Kemudian bertolaklah kamu) hai orang-orang Quraisy (dari tempat bertolaknya manusia) maksudnya dari Arafah dengan jalan wukuf bersama mereka. Sebelum itu biasanya mereka wukuf di Muzdalifah karena merasa enggan wukuf bersama-sama dengan orang lain. 'Tsumma' atau 'kemudian' menunjukkan urutan (dan mohonlah ampun kepada Allah) terhadap dosa-dosamu. (Sesungguhnya Allah Maha Pengampun lagi Maha Penyayang) terhadap orang-orang beriman.\qt@no{199}}%
\qt@newcmd\qurantrans@id@ccvii{%
(Apabila kamu telah menyelesaikan) atau menjalankan (ibadah hajimu) maksudnya, telah melempar jumrah Aqabah, telah tawaf, telah berada di Mina, (maka berzikirlah kepada Allah) dengan bertakbir dan menyanjung-Nya (sebagaimana kamu menyebut-nyebut nenek-moyangmu) yang kamu lakukan setelah haji untuk membangga-banggakan mereka (bahkan lebih banyak lagi dari itu) artinya lebih banyak dari ingatanmu kepada nenek-moyangmu itu. 'Asyadda' mendapat baris di atas disebabkan kedudukannya sebagai 'hal' dari 'dzikr' yang manshub oleh 'udzkuruu'. Seandainya ia terletak di belakangnya, maka ia akan menjadi sifat atau na`atnya. (Di antara manusia ada yang berdoa, ``Ya Tuhan kami! Berilah kami) bagian kami (di dunia"), sehingga ia pun diberikan bagian itu (dan tiadalah ia di akhirat mendapat bagian) yang menyenangkan.\qt@no{200}}%
\qt@newcmd\qurantrans@id@ccviii{%
(Dan di antara mereka ada pula yang berdoa, ``Ya Tuhan kami! Berilah kami di dunia kebaikan), artinya nikmat, (di akhirat kebaikan) yakni surga, (dan peliharalah kami dari siksa neraka.") yakni dengan tidak memasukinya. Ini merupakan lukisan tentang keadaan orang-orang musyrik dan keadaan orang-orang beriman, yang tujuannya ialah supaya kita mencari dua macam kebaikan dunia dan akhirat, sebagaimana telah dijanjikan akan beroleh pahala dengan firman-Nya:\qt@no{201}}%
\qt@newcmd\qurantrans@id@ccix{%
(Mereka itulah orang-orang yang mendapat bagian), maksudnya pahala (dari), artinya disebabkan (apa yang mereka usahakan), yakni amal mereka dari haji dan doa (dan Allah sangat cepat perhitungan-Nya). Menurut keterangan sebuah hadis, Allah melakukan hisab atau perhitungan bagi seluruh makhluk dalam tempo yang tidak lebih dari setengah hari waktu dunia.\qt@no{202}}%
\qt@newcmd\qurantrans@id@ccx{%
(Dan berzikirlah kepada Allah) dengan membaca takbir ketika melempar jumrah (pada beberapa hari yang berbilang), yakni pada hari-hari Tasyrik yang tiga. (Barang siapa yang ingin cepat-cepat), maksudnya ingin cepat berangkat dari Mina (dalam dua hari), artinya pada hari yang kedua hari tasyrik setelah melempar jumrah-jumrahnya, (maka tiadalah ia berdosa) dengan tindakan itu. (Dan barang siapa yang ingin mengundurkannya) hingga ia bermalam pada malam ketiga dan melempar jumrah-jumrahnya, (maka tiadalah ia berdosa) dengan perbuatannya itu. Jadi mereka diberi kesempatan untuk memilih tanpa memikul dosa apa pun (yakni bagi orang-orang yang bertakwa) kepada Allah dalam ibadah hajinya, karena pada hakikatnya itulah haji yang sebenarnya. (Dan bertakwalah kepada Allah dan ketahuilah bahwa kamu akan dikumpulkan kepada-Nya), yakni di akhirat yang nantinya amal perbuatanmu akan mendapat balasan dari-Nya.\qt@no{203}}%
\qt@newcmd\qurantrans@id@ccxi{%
(Di antara manusia ada seorang yang ucapannya tentang kehidupan dunia menarik hatimu) tetapi sebaliknya tidak demikian halnya tentang kehidupan akhirat karena berbeda dengan pandangan dan keyakinannya (dan dipersaksikannya kepada Allah atas isi hatinya) bahwa itu benar-benar cocok dengan apa yang diucapkannya (padahal ia adalah musuh yang paling keras) baik bagimu maupun bagi pengikut-pengikutmu disebabkan permusuhannya denganmu itu. Orang ini namanya Akhnas bin Syuraiq, seorang munafik yang manis mulut terhadap Nabi saw. Ia bersumpah bahwa ia seorang mukmin dan cinta kepada Nabi saw. lalu mendekati majelisnya. Maka kepalsuannya ini dibukakan Allah dan suatu waktu ia pernah lewat di pertanian dan peternakan seorang sahabat, maka dibakarnya tanaman dan disembelihnya hewan-hewan milik sahabat itu di waktu malam, sebagaimana yang dijelaskan dalam firman Allah swt.:\qt@no{204}}%
\qt@newcmd\qurantrans@id@ccxii{%
(Dan apabila ia berpaling) dari hadapanmu (ia berjalan di muka bumi untuk membuat kerusakan padanya dan membinasakan tanam-tanaman dan binatang ternak) untuk menyebut beberapa macam kerusakan itu (sedangkan Allah tidak menyukai kerusakan), artinya tidak rida padanya.\qt@no{205}}%
\qt@newcmd\qurantrans@id@ccxiii{%
(Dan jika dikatakan kepadanya, ``Bertakwalah kamu kepada Allah) dalam perbuatan-perbuatanmu, (bangkitlah kesombongannya) yang menyebabkan berbuat (dosa) yang disuruh menghindarinya. (Maka cukuplah baginya neraka Jahanam dan sungguh ia seburuk-buruk tempat tinggal).\qt@no{206}}%
\qt@newcmd\qurantrans@id@ccxiv{%
(Dan di antara manusia ada orang yang menjual dirinya), artinya mengorbankannya demi taatnya kepada Allah (guna menuntut) atau mencari (keridaan Allah). Namanya ialah Shuhaib. Tatkala ia dianiaya oleh orang-orang musyrik, ia pun berhijrah ke Madinah dan ditinggalkannya bagi mereka harta bendanya (dan Allah Maha Penyantun kepada hamba-hamba-Nya), sehingga ditunjuki-Nya mereka kepada hal-hal yang diridai-Nya.\qt@no{207}}%
\qt@newcmd\qurantrans@id@ccxv{%
Ayat berikut diturunkan mengenai Abdullah bin Salam dan kawan-kawannya tatkala mereka membesarkan hari Sabtu dan membenci unta sesudah masuk Islam. (Hai orang-orang beriman! Masuklah kamu ke dalam agama Islam), ada yang membaca 'salmi' dan ada pula 'silmi' (secara keseluruhan) 'hal' dari Islam artinya ke dalam seluruh syariatnya tanpa kecuali, (dan janganlah kamu ikuti langkah-langkah) atau jalan-jalan (setan), artinya godaan dan perdayaannya untuk membeda-bedakan, (sesungguhnya ia musuhmu yang nyata), artinya jelas permusuhannya terhadapmu.\qt@no{208}}%
\qt@newcmd\qurantrans@id@ccxvi{%
(Dan jika kamu tergelincir) atau menyimpang untuk masuk ke dalam keseluruhannya (setelah datang kepadamu bukti-bukti nyata) bahwa ia barang hak, (maka ketahuilah bahwa Allah Maha Tangguh) hingga tidak suatu pun yang dapat menghalangi-Nya untuk menjatuhkan hukuman kepadamu, (lagi Maha Bijaksana) di dalam segala perbuatan-Nya.\qt@no{209}}%
\qt@newcmd\qurantrans@id@ccxvii{%
(Tiadalah), maksudnya tidaklah (yang mereka tunggu-tunggu) buat memasukinya secara keseluruhan itu (melainkan datangnya Allah kepada mereka) maksudnya siksa Allah seperti pada firman-Nya ``atau datang amru rabbika artinya siksa Tuhanmu" (dalam naungan) 'zhulal' jamak dari 'zhillah', artinya naungan (awan dan malaikat dan diputuskanlah perkataan-Nya) hingga tamatlah riwayat mereka. (Dan kepada Allah dikembalikan segala urusan) ada yang menyatakan dalam bentuk pasif, ada pula aktif, yakni di akhirat untuk menerima pembalasan dari-Nya.\qt@no{210}}%
\qt@newcmd\qurantrans@id@ccxviii{%
(Tanyakanlah) hai Muhammad (kepada Bani Israel) sebagai pukulan bagi mereka (Berapa banyaknya yang telah kami berikan kepada mereka), 'kam' merupakan pertanyaan, tempat berkaitnya 'sal' mengenai maf`ul kedua (obyek kedua), yaitu maf`ul kedua dan mumayaz dari aatainaa (berupa tanda-tanda yang nyata) atau kuat, misalnya terbelahnya laut, turunnya manna dan salwa, lalu mereka sambut dengan kekafiran. (Dan barang siapa yang menukar nikmat Allah), maksudnya tanda-tanda yang telah diberikan-Nya, karena itu merupakan sebab beroleh petunjuk (setelah nikmat itu datang kepadanya) menjadi kekafiran, (maka sesungguhnya Allah amat berat siksa-Nya) terhadapnya.\qt@no{211}}%
\qt@newcmd\qurantrans@id@ccxix{%
(Dijadikan indah pada pandangan orang-orang yang kafir) di antara penduduk Mekah (kehidupan dunia ini) dengan jalan menghiasinya hingga mereka menyukainya (dan) mereka (memandang hina orang-orang yang beriman) karena kemiskinan mereka, seperti Bilal, Ammar, Shuhaib dan lain-lain, artinya mengejek mereka dan membanggakan kekayaan mereka kepada orang-orang miskin yang tidak punya itu. (Padahal orang-orang yang bertakwa) yang menjaga diri dari kesyirikan, mereka itu (berada di atas orang-orang kafir pada hari kiamat. Dan Allah memberi rezeki kepada siapa yang disukainya tanpa batas), artinya rezeki yang luas di akhirat atau di dunia, misalnya dimiliki-Nya harta benda dan budak dari pihak yang mengejek kepada pihak yang diejek.\qt@no{212}}%
\qt@newcmd\qurantrans@id@ccxx{%
(Adalah manusia itu umat yang satu) yang bersatu dalam keimanan lalu mereka bertikai paham sehingga sebagian mereka beriman dan sebagian lainnya kafir (Maka Allah pun mengutus para nabi) kepada mereka (membawa berita gembira) bahwa orang yang beriman akan masuk surga (dan peringatan) bahwa orang-orang kafir akan masuk neraka, (dan menurunkan bersama mereka Kitab), dengan arti kitab-kitab (dengan benar) berkaitan dengan 'menurunkan' (agar ia memberi keputusan dengan kitab itu (di antara manusia tentang perkara yang mereka perselisihkan) mengenai agama (Dan tidaklah berselisih tentangnya) mengenai agama itu (kecuali orang-orang yang diberi Kitab), maka berimanlah sebagian dan kafir sebagian (setelah datang kepada mereka keterangan-keterangan yang nyata) yang membuktikan ketauhidan. 'Min' berkaitan dengan 'ikhtalafa', dan bersama kalimat yang sesudahnya, ia didahulukan dari istitsna' dalam makna (karena kedengkian) dari orang-orang kafir (sesama mereka. Maka Allah menunjuki orang-orang yang beriman mengenai yang mereka perselisihkan itu kepada) sebagai penjelasan (kebenaran dengan izin-Nya) artinya kehendak-Nya. (Dan Allah menunjuki siapa yang disukai-Nya), artinya untuk ditunjuki (ke jalan yang lurus) atau jalan yang benar.\qt@no{213}}%
\qt@newcmd\qurantrans@id@ccxxi{%
Ayat berikut diturunkan mengenai susah payah yang menimpa kaum muslimin: (Ataukah), maksudnya apakah (kamu mengira bahwa kamu akan masuk surga. Padahal belum) maksudnya belum (datang kepadamu seperti) yang datang (kepada orang-orang yang terdahulu sebelum kamu) di antara orang-orang beriman berupa bermacam-macam cobaan, lalu kamu bersabar sebagaimana mereka bersabar? (Mereka ditimpa oleh); kalimat ini menjelaskan perkataan yang sebelumnya (malapetaka), maksudnya kemiskinan yang memuncak, (kesengsaraan) maksudnya penyakit, (dan mereka diguncang) atau dikejutkan oleh bermacam-macam bala, (hingga berkatalah) baris di atas atau di depan artinya telah bersabda (Rasul dan orang-orang yang beriman yang bersamanya) yang menganggap terlambatnya datang bantuan disebabkan memuncaknya kesengsaraan yang menimpa mereka, ("Bilakah) datangnya (pertolongan Allah) yang telah dijanjikan kepada kami?" Lalu mereka mendapat jawaban dari Allah, ("Ingatlah, sesungguhnya pertolongan Allah itu amat dekat") kedatangannya.\qt@no{214}}%
\qt@newcmd\qurantrans@id@ccxxii{%
(Mereka bertanya kepadamu) hai Muhammad (tentang apa yang mereka nafkahkan) Yang bertanya itu ialah Amar bin Jamuh, seorang tua yang hartawan. Ia menanyakan kepada Nabi saw. apa yang akan dinafkahkan dan kepada siapa dinafkahkannya? (Katakanlah) kepada mereka (Apa saja harta yang kamu nafkahkan) 'harta' merupakan penjelasan bagi 'apa saja' dan mencakup apa yang dinafkahkan yang merupakan salah satu dari dua sisi pertanyaan, tetapi juga jawaban terhadap siapa yang akan menerima nafkah itu, yang merupakan sisi lain dari pertanyaan dengan firman-Nya, (maka bagi ibu-bapak, kaum kerabat, anak-anak yatim, orang-orang miskin dan orang-orang yang sedang dalam perjalanan), artinya mereka lebih berhak untuk menerimanya. (Dan apa saja kebaikan yang kamu perbuat) baik mengeluarkan nafkah atau lainnya, (maka sesungguhnya Allah mengetahuinya) dan akan membalasnya.\qt@no{215}}%
\qt@newcmd\qurantrans@id@ccxxiii{%
(Diwajibkan atasmu berperang), yakni menghadapi orang-orang kafir (padahal hal itu suatu kebencian), maksudnya suatu hal yang tidak disukai (bagi kamu) menurut tabiat, disebabkan amat menyusahkannya. (Boleh jadi kamu membenci sesuatu padahal baik bagi kamu dan boleh jadi pula kamu menyukai sesuatu padahal amat buruk bagi kamu). Ini disebabkan kecenderungan nafsu pada syahwat atau keinginan-keinginan yang pasti akan mencelakakannya dan enggannya melakukan taklif atau tugas-tugas yang akan membahagiakannya. Siapa tahu bahwa dalam peperangan, walau kamu membencinya, tersembunyi kebaikan, misalnya kemenangan dan harta rampasan atau mati syahid dan memperoleh pahala. Sebaliknya dalam meninggalkan, walaupun menyenangkan hatimu, terdapat keburukan, misalnya kehinaan dan kemiskinan serta luput dari pahala. (Dan Allah Maha mengetahui) apa-apa yang baik bagimu (sedang kamu tidak mengetahui) demikian itu. Maka bersegeralah melakukan apa yang diperintahkan Allah kepadamu. Nabi saw. mengirim pasukannya yang pertama di antaranya terdapat Abdullah bin Jahsy. Mereka memerangi orang-orang musyrik dan membunuh Ibnul Hadhrami pada hari terakhir bulan Jumadilakhir hingga mereka memasuki awal bulan Rajab (salah satu bulan suci). Mereka lalu dicela oleh orang-orang kafir karena telah menghalalkan bulan suci itu, maka turunlah ayat:\qt@no{216}}%
\qt@newcmd\qurantrans@id@ccxxiv{%
(Mereka menanyakan kepadamu tentang bulan haram) atau bulan suci (yakni berperang padanya), menjadi badal isytimal (Katakanlah) kepada mereka, ("Berperang dalam bulan itu adalah besar"), maksudnya dosa besar. 'Berperang' menjadi mubtada', sedangkan 'besar' menjadi khabarnya, (tetapi menghalangi) manusia, menjadi mubtada' (dari jalan Allah) maksudnya dari agama-Nya (dan kafir kepada-Nya), (serta) menghalangi ia masuk (Masjidilharam), artinya kota Mekah (dan mengusir penduduknya daripadanya) sebagaimana yang dialami Nabi saw. bersama orang-orang mukmin, sedang yang menjadi khabarnya ialah (lebih besar lagi), artinya dosanya (di sisi Allah) daripada berperang itu. (Sedangkan berbuat fitnah) artinya kesyirikan (lebih besar lagi dari pembunuhan) bagimu padanya. (Dan tidak henti-hentinya mereka), maksudnya orang-orang kafir (memerangi kamu) hai orang-orang beriman (hingga), maksudnya agar (mengembalikan kamu dari agamamu) kepada kekafiran, (sekiranya mereka sanggup. Barang siapa yang murtad di antara kamu dari agamanya, lalu ia mati dalam kekafiran, maka mereka itu menjadi sia-sia) atau batal (amal-amal mereka) yang saleh (di dunia dan akhirat) hingga tidak dianggap dan tidak diberi pahala. Mengaitkannya dengan kematian menunjukkan bahwa seandainya ia kembali kepada Islam sebelum mati maka amalnya tidaklah batal dan tetap diberi pahala serta tidak perlu diulangi lagi, haji misalnya. Demikianlah menurut pendapat Syafii, (dan mereka itulah penghuni neraka, mereka kekal di dalamnya). Tatkala anak buah pasukannya tadi menyangka bahwa meskipun mereka tidak berdosa, tetap tidak beroleh pahala (karena melakukan peperangan pada bulan haram), maka turunlah ayat:\qt@no{217}}%
\qt@newcmd\qurantrans@id@ccxxv{%
(Sesungguhnya orang-orang yang beriman, orang-orang yang berhijrah) meninggalkan kampung halaman mereka, (dan berjihad di jalan Allah), yakni untuk meninggikan agama-Nya, (mereka itu mengharapkan rahmat Allah), artinya pahala-Nya, (dan Allah Maha Pengampun lagi Maha Penyayang) terhadap orang-orang beriman.\qt@no{218}}%
\qt@newcmd\qurantrans@id@ccxxvi{%
(Mereka menanyakan kepadamu tentang minuman keras dan berjudi) apakah hukumnya? (Katakanlah kepada mereka) (pada keduanya) maksudnya pada minuman keras dan berjudi itu terdapat (dosa besar). Menurut satu qiraat dibaca katsiir (banyak) disebabkan keduanya banyak menimbulkan persengketaan, caci-mencaci, dan kata-kata yang tidak senonoh, (dan beberapa manfaat bagi manusia) dengan meminum-minuman keras akan menimbulkan rasa kenikmatan dan kegembiraan, dan dengan berjudi akan mendapatkan uang dengan tanpa susah payah, (tetapi dosa keduanya), maksudnya bencana-bencana yang timbul dari keduanya (lebih besar) artinya lebih parah (daripada manfaat keduanya). Ketika ayat ini diturunkan, sebagian sahabat masih suka meminum minuman keras, sedangkan yang lainnya sudah meninggalkannya hingga akhirnya diharamkan oleh sebuah ayat dalam surat Al-Maidah. (Dan mereka menanyakan kepadamu beberapa yang akan mereka nafkahkan), artinya berapa banyaknya. (Katakanlah), Nafkahkanlah (kelebihan) maksudnya yang lebih dari keperluan dan janganlah kamu nafkahkan apa yang kamu butuhkan dan kamu sia-siakan dirimu. Menurut satu qiraat dibaca al-`afwu sebagai khabar dari mubtada' yang tidak disebutkan dan diperkirakan berbunyi, ``yaitu huwa....". (Demikianlah), artinya sebagaimana dijelaskan-Nya kepadamu apa yang telah disebutkan itu (dijelaskan-Nya pula bagimu ayat-ayat agar kamu memikirkan).\qt@no{219}}%
\qt@newcmd\qurantrans@id@ccxxvii{%
(Yaitu tentang) urusan (dunia dan akhirat) hingga kamu dapat memungut mana-mana yang lebih baik untukmu pada keduanya. (Dan mereka menanyakan kepadamu tentang anak-anak yatim) serta kesulitan-kesulitan yang mereka temui dalam urusan mereka. Jika mereka menyatukan harta mereka dengan harta anak-anak yatim, mereka merasa berdosa dan jika mereka pisahkan harta mereka dan dibuatkan makanan bagi mereka secara terpisah, maka mengalami kerepotan. (Katakanlah, ``Mengurus urusan mereka secara patut) misalnya mengenai campur-tangan dalam upaya mengembangkan harta mereka (adalah lebih baik) daripada membiarkannya. (Dan jika kamu mencampuri urusan mereka), maksudnya kamu campurkan pengeluaran kamu dengan pengeluaran mereka, (maka mereka adalah saudaramu) maksudnya mereka itu adalah saudara-saudara seagama dan telah menjadi kelaziman bagi seorang saudara untuk mencampurkan hartanya pada harta saudaranya. Tegasnya silakan melakukannya karena tak ada salahnya (Dan Allah mengetahui orang yang membuat kerusakan) terhadap harta anak-anak yatim itu ketika mencampurkan hartanya kepada harta mereka (dari orang yang berbuat kebaikan) dengannya, hingga masing-masing akan mendapat balasan yang setimpal (sekiranya Allah menghendaki, tentulah Dia akan mempersulitmu) dengan melarang mencampurkan harta, (sesungguhnya Allah Maha Kuasa) atas segala persoalan (lagi Maha Bijaksana) dalam segala tindakan dan perbuatan.\qt@no{220}}%
\qt@newcmd\qurantrans@id@ccxxviii{%
(Janganlah kamu nikahi) hai kaum muslimin, (wanita-wanita musyrik), maksudnya wanita-wanita kafir (sebelum mereka beriman. Sesungguhnya budak yang beriman itu lebih baik daripada wanita musyrik) walaupun ia merdeka. Sebab turunnya ayat ini adalah berkenaan dengan celaan yang ditujukan kepada laki-laki yang menikahi budak wanita dan menyanjung serta menyenangi laki-laki yang menikahi wanita merdeka yang musyrik (walaupun ia menarik hatimu) disebabkan harta dan kecantikannya. Ini dikhususkan bagi wanita yang bukan ahli kitab dengan ayat ``Dan wanita-wanita yang terpelihara di antara golongan ahli kitab". (Dan janganlah kamu kawinkan) atau nikahkan (laki-laki musyrik), artinya laki-laki kafir dengan wanita-wanita beriman (sebelum mereka beriman. Sesungguhnya budak yang beriman lebih baik daripada laki-laki musyrik walaupun ia menarik hatimu) disebabkan harta dan ketampanannya. (Mereka itu) atau ahli syirik (mengajak ke neraka) disebabkan anjuran mereka melakukan perbuatan membawa orang ke dalamnya, hingga tidaklah baik kawin dengan mereka. (Sedangkan Allah mengajak) melalui lisan para Rasul-Nya (ke surga serta ampunan), maksudnya amal perbuatan yang menjurus kepada keduanya (dengan izin-Nya), artinya dengan kehendak-Nya, maka wajiblah bagi kamu atau wali-walinya mengabulkan perkawinan (Dan dijelaskan-Nya ayat-ayat-Nya kepada manusia agar mereka beroleh peringatan) atau mendapat pelajaran.\qt@no{221}}%
\qt@newcmd\qurantrans@id@ccxxix{%
(Mereka bertanya kepadamu tentang haid), maksudnya haid atau tempatnya dan bagaimana memperlakukan wanita padanya. (Katakanlah, ``Haid adalah suatu kotoran) atau tempatnya kotoran, (maka jauhilah wanita-wanita), maksudnya janganlah bersetubuh dengan mereka (di waktu haid) atau pada tempatnya (dan janganlah kamu dekati mereka) dengan maksud untuk bersetubuh (sampai mereka suci). 'Yathhurna' dengan tha baris mati atau pakai tasydid lalu ha', kemudian pada ta' asalnya diidgamkan kepada tha' dengan arti mandi setelah terhentinya. (Apabila mereka telah suci maka datangilah mereka) maksudnya campurilah mereka (di tempat yang diperintahkan Allah kepadamu) jauhilah di waktu haid, dan datangilah di bagian kemaluannya dan jangan diselewengkan kepada bagian lainnya. (sesungguhnya Allah menyukai) serta memuliakan dan memberi (orang-orang yang bertobat) dari dosa (dan menyukai orang-orang yang menyucikan diri) dari kotoran.\qt@no{222}}%
\qt@newcmd\qurantrans@id@ccxxx{%
(Istri-istrimu adalah tanah persemaian bagimu), artinya tempat kamu membuat anak, (maka datangilah tanah persemaianmu), maksudnya tempatnya yaitu pada bagian kemaluan (bagaimana saja) dengan cara apa saja (kamu kehendaki) apakah sambil berdiri, duduk atau berbaring, baik dari depan atau dari belakang. Ayat ini turun untuk menolak anggapan orang-orang Yahudi yang mengatakan, ``Barang siapa yang mencampuri istrinya pada kemaluannya tetapi dari arah belakangnya (pinggulnya), maka anaknya akan lahir bermata juling. (Dan kerjakanlah untuk dirimu) amal-amal saleh, misalnya membaca basmalah ketika bercampur (dan bertakwalah kepada Allah) baik dalam perintah maupun dalam larangan-Nya (dan ketahuilah bahwa kamu akan menemui-Nya kelak) yakni di saat berbangkit, Dia akan membalas segala amal perbuatanmu. (Dan sampaikanlah kabar gembira kepada orang-orang yang beriman) yang bertakwa kepada-Nya, bahwa mereka akan memperoleh surga.\qt@no{223}}%
\qt@newcmd\qurantrans@id@ccxxxi{%
(Janganlah kamu jadikan Allah), artinya sewaktu bersumpah dengan-Nya (sebagai sasaran) atau penghalang (bagi sumpah-sumpahmu) yang mendorong kamu (untuk) tidak (berbuat baik dan bertakwa). Maka sumpah seperti itu tidak disukai, dan disunahkan untuk melanggarnya lalu membayar kafarat. Berbeda halnya dengan sumpah untuk berbuat kebaikan, maka itu termasuk taat (serta mendamaikan di antara manusia), maksud ayat, jangan kamu terhalang untuk membuat kebaikan yang disebutkan dan lain-lainnya itu jika terlanjur bersumpah, tetapi langgarlah dan bayarlah kafarat sumpah, karena yang menjadi asbabun nuzulnya ialah tidak mau melanggar sumpah yang telah diikrarkannya. (Dan Allah Maha Mendengar) ucapan-ucapanmu (lagi Maha Mengetahui) keadaan-keadaanmu.\qt@no{224}}%
\qt@newcmd\qurantrans@id@ccxxxii{%
(Allah tidaklah menghukum kamu disebabkan sumpah kosong), artinya yang tidak dimaksud (dalam sumpah-sumpahmu) yakni yang terucap dari mulut tanpa sengaja untuk bersumpah, misalnya, ``Tidak, demi Allah!" Atau ``Benar, demi Allah!" Maka ini tidak ada dosanya serta tidak wajib kafarat. (Tetapi Allah akan menghukum kamu disebabkan sumpah yang disengaja oleh hatimu), artinya kamu sadari bahwa itu sumpah yang tidak boleh dilanggar. (Dan Allah Maha Pengampun) terhadap hal-hal yang tidak disengaja (lagi Maha Penyantun) hingga sudi menangguhkan hukuman terhadap orang yang akan menjalaninya.\qt@no{225}}%
\qt@newcmd\qurantrans@id@ccxxxiii{%
(Bagi orang-orang yang melakukan ila` terhadap istri-istri mereka), artinya bersumpah tidak akan mencampuri istri-istri mereka, (diberi tangguh) atau menunggu (selama empat bulan. Jika mereka kembali), maksudnya rujuk dari sumpah untuk mencampuri, baik waktu itu atau sesudahnya, (maka sesungguhnya Allah Maha Pengampun) kepada mereka yang telah membuat istri-istrinya menderita disebabkan sumpahnya, (lagi Maha Penyayang) terhadap mereka.\qt@no{226}}%
\qt@newcmd\qurantrans@id@ccxxxiv{%
(Dan sekiranya mereka berketetapan hati untuk talak), artinya tak mau kembali, maka mereka harus menjatuhkannya, (karena sesungguhnya Allah Maha Mendengar) ucapan mereka (lagi Maha Mengetahui), maksud atau tekad mereka. Jadi maksudnya; setelah menunggu selama empat bulan tidak ada lagi kesempatan terbuka bagi mereka, kecuali kembali atau menjatuhkan talak.\qt@no{227}}%
\qt@newcmd\qurantrans@id@ccxxxv{%
(Dan wanita-wanita yang ditalak hendaklah menunggu) atau menahan (diri mereka) dari kawin (selama tiga kali quru') yang dihitung dari mulainya dijatuhkan talak. Dan quru' adalah jamak dari qar-un dengan mematahkan qaf, mengenai hal ini ada dua pendapat, ada yang mengatakannya suci dan ada pula yang mengatakannya haid. Ini mengenai wanita-wanita yang telah dicampuri. Adapun mengenai yang belum dicampuri, maka tidak ada idahnya berdasarkan firman Allah, ``Maka mereka itu tidak mempunyai idah bagimu. Juga bukan lagi wanita-wanita yang terhenti haidnya atau anak-anak yang masih di bawah umur, karena bagi mereka idahnya selama tiga bulan. Mengenai wanita-wanita hamil, maka idahnya adalah sampai mereka melahirkan kandungannya sebagaimana tercantum dalam surah At-Thalaq, sedangkan wanita-wanita budak, sebagaimana menurut hadis, idah mereka adalah dua kali quru' (Dan mereka tidak boleh menyembunyikan apa yang telah diciptakan Allah pada rahim-rahim mereka) berupa anak atau darah haid, (jika mereka beriman kepada Allah dan hari akhir. Dan suami-suami mereka) (lebih berhak untuk merujuk mereka) sekalipun mereka tidak mau dirujuk (di saat demikian), artinya di saat menunggu itu (jika mereka menghendaki perbaikan) sesama mereka dan bukan untuk menyusahkan istri. Ini merupakan dorongan bagi orang yang berniat mengadakan perbaikan dan bukan merupakan syarat diperbolehkannya rujuk. Ini mengenai talak raj`i dan memang tidak ada orang yang lebih utama daripada suami, karena sewaktu masih dalam idah, tidak ada hak bagi orang lain untuk mengawini istrinya. (Dan para wanita mempunyai) dari para suaminya (hak-hak yang seimbang) dengan hak-hak para suami (yang dibebankan kepada mereka) (secara makruf) menurut syariat, baik dalam pergaulan sehari-hari, meninggalkan hal-hal yang akan mencelakakan istri dan lain sebagainya. (Akan tetapi pihak suami mempunyai satu tingkat kelebihan) tentang hak, misalnya tentang keharusan ditaati disebabkan maskawin dan belanja yang mereka keluarkan dari kantong mereka. (Dan Allah Maha Tangguh) dalam kerajaan-Nya, (lagi Maha Bijaksana) dalam rencana-Nya terhadap hak-hak-Nya.\qt@no{228}}%
\qt@newcmd\qurantrans@id@ccxxxvi{%
(Talak) atau perceraian yang dapat kembali rujuk itu (dua kali) (setelah itu boleh memegang mereka) dengan jalan rujuk (secara baik-baik) tanpa menyusahkan mereka (atau melepas), artinya menceraikan mereka (dengan cara baik pula. Tidak halal bagi kamu) hai para suami (untuk mengambil kembali sesuatu yang telah kami berikan kepada mereka) berupa mahar atau maskawin, jika kamu menceraikan mereka itu, (kecuali kalau keduanya khawatir), maksudnya suami istri itu (tidak dapat menjalankan hukum-hukum Allah), artinya tidak dapat melaksanakan kewajiban-kewajiban yang telah digariskan-Nya. Menurut satu qiraat dibaca 'yukhaafaa' secara pasif, Sedangkan 'an laa yuqiimaa' menjadi badal isytimal bagi dhamir yang terdapat di sana. Terdapat juga bacaan dengan baris di atas pada kedua fi`il tersebut. (Jika kamu merasa khawatir bahwa mereka berdua tidak dapat menjalankan hukum-hukum Allah, maka tidaklah mereka itu berdosa mengenai uang tebusan) yang dibayarkan oleh pihak istri untuk menebus dirinya, artinya tak ada salahnya jika pihak suami mengambil uang tersebut begitu pula pihak istri jika membayarkannya. (Itulah), yakni hukum-hukum yang disebutkan di atas (peraturan-peraturan Allah, maka janganlah kamu melanggarnya. Barang siapa yang melanggar peraturan-peraturan Allah, maka merekalah orang-orang yang aniaya).\qt@no{229}}%
\qt@newcmd\qurantrans@id@ccxxxvii{%
(Kemudian jika ia menceraikannya lagi), maksudnya si suami setelah talak yang kedua, (maka wanita itu tidak halal lagi baginya setelah itu), maksudnya setelah talak tiga (hingga dia kawin dengan suami yang lain) serta mencampurinya sebagaimana tersebut dalam hadis yang diriwayatkan oleh Bukhari dan Muslim. (Kemudian jika ia menceraikannya pula) maksudnya suaminya yang kedua, (maka tidak ada dosa bagi keduanya), maksudnya istri dan bekas suami yang pertama (untuk kembali) pada perkawinan mereka setelah berakhirnya idah, (jika keduanya itu mengira akan dapat menjalankan hukum-hukum Allah. Itulah), maksudnya semua yang telah disebutkan itu (peraturan-peraturan Allah yang dijelaskan-Nya kepada kaum yang mau mengetahui) atau merenungkan.\qt@no{230}}%
\qt@newcmd\qurantrans@id@ccxxxviii{%
(Apabila kamu menceraikan istri-istri, lalu sampai idahnya), maksudnya dekat pada berakhir idahnya (maka peganglah mereka), artinya rujuklah kepada mereka (secara baik-baik) tanpa menimbulkan kesusahan bagi mereka (atau lepaskanlah secara baik-baik pula), artinya biarkanlah mereka itu sampai habis idah mereka. (Janganlah kamu tahan mereka itu) dengan rujuk (untuk menimbulkan kesusahan) berfungsi sebagai maf`ul liajlih (sehingga menganiaya mereka) sampai mereka terpaksa menebus diri, minta cerai dan menunggu lama. (Barang siapa melakukan demikian, berarti ia menganiaya dirinya) dengan menghadapkannya pada siksaan Allah (dan janganlah kamu jadikan ayat-ayat Allah sebagai permainan), artinya berolok-olok dengan melanggarnya (dan ingatlah nikmat Allah kepadamu), yakni agama Islam (dan apa-apa yang telah diturunkan-Nya padamu berupa Kitab) Alquran (dan hikmah) artinya hukum-hukum yang terdapat padanya (Allah memberimu pengajaran dengannya) agar kamu bersyukur dengan mengamalkannya (Dan bertakwalah kamu kepada Allah serta ketahuilah bahwa Allah mengetahui segala sesuatunya) hingga tidak satu pun yang tersembunyi bagi-Nya.\qt@no{231}}%
\qt@newcmd\qurantrans@id@ccxxxix{%
(Apabila kamu menceraikan istri-istrimu lalu sampai idahnya), maksudnya habis masa idahnya, (maka janganlah kamu halangi mereka itu) ditujukan kepada para wali agar mereka tidak melarang wanita-wanita untuk (untuk rujuk dengan suami-suami mereka yang telah menceraikan mereka itu). Asbabun nuzul ayat ini bahwa saudara perempuan dari Ma`qil bin Yasar diceraikan suaminya, lalu suaminya itu hendak rujuk kepadanya, tetapi dilarang oleh Ma`qil bin Yasar, sebagaimana diriwayatkan oleh Hakim (jika terdapat kerelaan), artinya kerelaan suami istri (di antara mereka secara baik-baik), artinya menurut syariat. (Demikian itu), yakni larangan menghalangi itu (dinasihatkan kepada orang-orang yang beriman di antara kamu kepada Allah dan hari yang akhir). Karena hanya mereka sajalah yang mengerti nasihat ini (Itu), artinya tidak menghalangi (lebih suci) lebih baik (bagi kamu dan lebih bersih) baik bagi kamu maupun bagi mereka karena dikhawatirkan kedua belah pihak bekas suami istri akan melakukan hubungan gelap, mengingat kedua belah pihak sudah saling cinta dan mengenal. (Dan Allah mengetahui) semua maslahat (sedangkan kamu tidak mengetahui yang demikian itu), maka mohonlah petunjuk dan ikutilah perintah-Nya.\qt@no{232}}%
\qt@newcmd\qurantrans@id@ccxl{%
(Para ibu menyusukan), maksudnya hendaklah menyusukan (anak-anak mereka selama dua tahun penuh) sifat yang memperkuat, (yaitu bagi orang yang ingin menyempurnakan penyusuan) dan tidak perlu ditambah lagi. (Dan kewajiban yang diberi anak), maksudnya bapak (memberi mereka (para ibu) sandang pangan) sebagai imbalan menyusukan itu, yakni jika mereka diceraikan (secara makruf), artinya menurut kesanggupannya. (Setiap diri itu tidak dibebani kecuali menurut kadar kemampuannya, maksudnya kesanggupannya. (Tidak boleh seorang ibu itu menderita kesengsaraan disebabkan anaknya) misalnya dipaksa menyusukan padahal ia keberatan (dan tidak pula seorang ayah karena anaknya), misalnya diberi beban di atas kemampuannya. Mengidhafatkan anak kepada masing-masing ibu dan bapak pada kedua tempat tersebut ialah untuk mengimbau keprihatinan dan kesantunan, (dan ahli waris pun) ahli waris dari bapaknya, yaitu anak yang masih bayi dan di sini ditujukan kepada wali yang mengatur hartanya (berkewajiban seperti demikian), artinya seperti kewajiban bapaknya memberi ibunya sandang pangan. (Apabila keduanya ingin), maksudnya ibu bapaknya (menyapih) sebelum masa dua tahun dan timbul (dari kerelaan) atau persetujuan (keduanya dan hasil musyawarah) untuk mendapatkan kemaslahatan si bayi, (maka keduanya tidaklah berdosa) atas demikian itu. (Dan jika kamu ingin) ditujukan kepada pihak bapak (anakmu disusukan oleh orang lain) dan bukan oleh ibunya, (maka tidaklah kamu berdosa) dalam hal itu (jika kamu menyerahkan) kepada orang yang menyusukan (pembayaran upahnya) atau upah yang hendak kamu bayarkan (menurut yang patut) secara baik-baik dan dengan kerelaan hati. (Dan bertakwalah kamu kepada Allah dan ketahuilah bahwa Allah Maha Melihat apa yang kamu kerjakan) hingga tiada satu pun yang tersembunyi bagi-Nya.\qt@no{233}}%
\qt@newcmd\qurantrans@id@ccxli{%
(Orang-orang yang wafat) atau meninggal dunia (di antara kamu dengan meninggalkan istri-istri, maka mereka menangguhkan), artinya hendaklah para istri itu menahan (diri mereka) untuk kawin setelah suami mereka yang meninggal itu (selama empat bulan dan sepuluh), maksudnya hari. Ini adalah mengenai wanita-wanita yang tidak hamil. Mengenai yang hamil, maka idah mereka sampai melahirkan kandungannya berdasarkan ayat At-Thalaq, sedangkan bagi wanita budak adalah setengah dari yang demikian itu, menurut hadis. (Apabila waktu mereka telah sampai), artinya habis masa idahnya, (mereka tiada dosa bagi kamu) hai para wali (membiarkan mereka berbuat pada diri mereka), misalnya bersolek dan menyiapkan diri untuk menerima pinangan (secara baik-baik), yakni menurut agama. (Dan Allah Maha Mengetahui apa-apa yang kamu lakukan), baik yang lahir maupun yang batin.\qt@no{234}}%
\qt@newcmd\qurantrans@id@ccxlii{%
(Dan tak ada dosa bagimu meminang wanita-wanita itu secara sindiran), yakni wanita-wanita yang kematian suami dan masih berada dalam idah mereka, misalnya kata seseorang kepadanya, ``Engkau cantik" atau ``Siapa yang melihatmu pasti jatuh cinta" atau ``tiada wanita secantik engkau" (atau kamu sembunyikan) kamu rahasiakan (dalam hatimu) rencana untuk mengawini mereka. (Allah mengetahui bahwa kamu akan menyebut-nyebut mereka) dan tidak sabar untuk meminang, maka diperbolehkannya secara sindiran, (tetapi janganlah kamu mengadakan perjanjian dengan mereka secara rahasia), maksudnya perjanjian kawin (melainkan) diperbolehkan (sekadar mengucapkan kata-kata yang baik) yang menurut syariat dianggap sindiran pinangan. (Dan janganlah kamu pastikan akan mengakadkan nikah), artinya melangsungkannya (sebelum yang tertulis) dari idah itu (habis waktunya) tegasnya sebelum idahnya habis. (Dan ketahuilah bahwa Allah mengetahui apa yang ada di dalam hatimu) apakah rencana pasti atau lainnya (maka takutlah kepada-Nya) dan janganlah sampai menerima hukuman-Nya disebabkan rencanamu yang pasti itu (Dan ketahuilah bahwa Allah Maha Pengampun) terhadap orang yang takut kepada-Nya (lagi Maha Penyantun) hingga menangguhkan hukuman-Nya terhadap orang yang berhak menerimanya.\qt@no{235}}%
\qt@newcmd\qurantrans@id@ccxliii{%
(Tidak ada dosa bagi kamu, jika kamu menceraikan istri-istrimu sebelum kamu menyentuh mereka) menurut satu qiraat, 'tumaassuuhunna' artinya mencampuri mereka (atau) sebelum (kamu menentukan maharnya), maksudnya maskawinnya. 'Ma' mashdariyah zharfiyah, maksudnya tak ada risiko atau tanggung jawabmu dalam perceraian sebelum campur dan sebelum ditentukannya berapa mahar, maka ceraikanlah mereka itu. (Dan hendaklah kamu beri mereka itu 'mutah') atau pemberian yang akan menyenangkan hati mereka; (bagi yang mampu) maksudnya yang kaya di antaramu (sesuai dengan kemampuannya, sedangkan bagi yang melarat) atau miskin (sesuai dengan kemampuannya pula). Ini menunjukkan bahwa tidak ada perbedaan tentang derajat atau kedudukan istri (yaitu pemberian) atau hiburan (menurut yang patut) menurut syariat dan menjadi sifat bagi mata`an. Demikian itu (merupakan kewajiban) 'haqqan' menjadi sifat yang kedua atau mashdar yang memperkuat (bagi orang-orang yang berbuat kebaikan) atau orang-orang yang taat.\qt@no{236}}%
\qt@newcmd\qurantrans@id@ccxliv{%
(Dan jika kamu menceraikan istri-istrimu sebelum mencampuri mereka, padahal kamu sudah menetapkan mahar, maka bayarlah separuh dari yang telah kamu tetapkan itu). Ini menjadi hak mereka, sedangkan yang separuhnya lagi kembali kepadamu, (kecuali) atau tidak demikian hukumnya (jika mereka itu), maksudnya para istri itu memaafkan mereka hingga mereka tidak mengambilnya (atau dimaafkan oleh yang pada tangannya tergenggam akad nikah), yaitu suami, maka mahar diserahkan kepada para istri-istri itu semuanya. Tetapi menurut keterangan yang diterima dari Ibnu Abbas, wali boleh bertindak sepenggantinya, bila wanita itu mahjurah (tidak dibolehkan bertasaruf) dan hal ini tidak ada dosa baginya, maka dalam hal itu tidak ada kesulitan (dan bahwa kamu memaafkan itu) 'an' dengan mashdarnya menjadi mubtada' sedangkan khabarnya ialah (lebih dekat kepada ketakwaan. Dan jangan kamu lupakan keutamaan di antara kamu), artinya saling menunjukkan kemurahan hati, (sesungguhnya Allah Maha Melihat apa yang kamu kerjakan) dan akan membalasmu sebaik-baiknya.\qt@no{237}}%
\qt@newcmd\qurantrans@id@ccxlv{%
(Peliharalah semua salatmu), yakni yang lima waktu dengan mengerjakannya pada waktunya (dan salat wustha atau pertengahan). Ditemui beberapa pendapat, ada yang mengatakan salat asar, subuh, zuhur atau selainnya dan disebutkan secara khusus karena keistimewaannya. (Berdirilah untuk Allah) dalam salatmu itu (dalam keadaan taat) atau patuh, berdasarkan sabda Nabi saw., ``Setiap qunut dalam Alquran itu maksudnya ialah taat" (H.R. Ahmad dan lain-lainnya). Ada pula yang mengatakan khusyuk atau diam, berdasarkan hadis Zaid bin Arqam, katanya, ``Mulanya kami berkata-kata dalam salat, hingga turunlah ayat tersebut, maka kami pun disuruh diam dan dilarang bercakap-cakap." (H.R. Bukhari dan Muslim)\qt@no{238}}%
\qt@newcmd\qurantrans@id@ccxlvi{%
(Jika kamu dalam keadaan takut) baik terhadap musuh, maupun banjir atau binatang buas (maka sambil berjalan kaki) jamak dari raajil, artinya salatlah sambil jalan kaki (atau berkendaraan), 'rukbaanan' jamak dari 'raakib', maksudnya bagaimana sedapatnya, baik menghadap kiblat atau tidak mau memberi isyarat saat rukuk dan sujud. (Kemudian apabila kamu telah aman), yakni dari ketakutan, (maka sebutlah Allah), artinya salatlah (sebagaimana Dia telah mengajarkan kepadamu apa-apa yang tidak kamu ketahui), yakni sebelum diajarkan-Nya itu berupa fardu dan syarat-syaratnya. 'Kaf' berarti 'umpama' dan 'maa' mashdariyah atau maushuulah.\qt@no{239}}%
\qt@newcmd\qurantrans@id@ccxlvii{%
(Dan orang-orang yang akan meninggal dunia di antara kamu dan meninggalkan istri) hendaklah (berwasiat) menurut satu qiraat dengan baris di depan dan berarti wajib berwasiat (untuk istri-istri mereka) agar mereka diberi (nafkah) yang dapat mereka nikmati (hingga) sempurna (satu tahun) lamanya menunggu bagi istri-istri yang ditinggal mati suami (tanpa mengeluarkan mereka), artinya tanpa menyuruh mereka pindah dari rumah yang mereka diami sewaktu suami mereka masih hidup. (Tetapi jika mereka pindah) atas kemauan sendiri, (maka tidak ada dosa bagimu) hai para wali orang yang mati (mengenai apa yang mereka perbuat terhadap diri mereka secara patut), yakni menurut syariat, misalnya bersolek, menghentikan masa berkabung dan tidak hendak menerima nafkah lagi. (Dan Allah Maha Tangguh) dalam kerajaan-Nya (lagi Maha Bijaksana) dalam perbuatan-Nya. Wasiat yang disebut di atas dinasakh oleh ayat waris dan menunggu selama setahun oleh ayat empat bulan sepuluh hari yang lalu, tetapi turunnya terkemudian. Mengenai tempat kediaman, menurut Syafii tetap dipertahankan bagi istri-istri itu, artinya tidak dinasakh.\qt@no{240}}%
\qt@newcmd\qurantrans@id@ccxlviii{%
(Wanita-wanita yang diceraikan hendaklah mendapat mutah), maksudnya diberi mutah (secara patut), artinya menurut kemampuan suami (sebagai suatu kewajiban), 'haqqan' dengan baris di atas sebagai maf`ul mutlak bagi fi`ilnya yang dapat diperkirakan (bagi orang-orang yang takwa). Hal ini diulang kembali oleh Allah agar mencapai pula wanita-wanita yang telah dicampuri, karena ayat yang lalu adalah ayat mengenai yang belum dicampuri.\qt@no{241}}%
\qt@newcmd\qurantrans@id@ccxlix{%
(Demikianlah), artinya seperti telah disebutkan di atas (Allah menjelaskan kepadamu ayat-ayat-Nya agar kamu mengerti) atau memahaminya.\qt@no{242}}%
\qt@newcmd\qurantrans@id@ccl{%
(Tidakkah kamu perhatikan) pertanyaan disertai keanehan dan dorongan untuk mendengar apa yang dibicarakan sesudah itu (orang-orang yang keluar dari kampung halaman mereka, sedangkan jumlah mereka beribu-ribu) ada yang mengatakan empat, delapan atau sepuluh ribu serta ada pula yang mengatakan berjumlah tiga puluh, empat puluh atau tujuh puluh ribu (disebabkan takut mati) sebagai maf`ul liajlih. Mereka ini ialah segolongan Bani Israel yang ditimpa oleh wabah sampar hingga lari meninggalkan negeri mereka. (Maka firman Allah kepada mereka, ``Matilah kamu!") hingga mereka pun mati, (kemudian mereka dihidupkan-Nya kembali), yakni setelah delapan hari atau lebih, atas doa Nabi mereka yang bernama Hizqil. Ada beberapa lamanya mereka hidup tetapi bekas kematian tanda-tandanya terdapat pada diri mereka, tidak memakai pakaian kecuali nanti berbalik menjadi kain kafan, dan peristiwa ini menjadi buah tutur sampai kepada anak-anak mereka. (Sesungguhnya Allah mempunyai karunia terhadap manusia) di antaranya menghidupkan mereka tadi, (tetapi kebanyakan manusia) yakni orang-orang kafir (tidak bersyukur). Adapun tujuan menyebutkan tentang orang-orang itu di sini ialah untuk merangsang semangat orang-orang beriman untuk berperang dan itulah sebabnya dihubungkan kepadanya.\qt@no{243}}%
\qt@newcmd\qurantrans@id@ccli{%
(Dan berperanglah kamu di jalan Allah) maksudnya untuk meninggikan agama-Nya (dan ketahuilah bahwa sesungguhnya Allah Maha Mendengar) akan ucapanmu (lagi Maha Mengetahui) akan keadaanmu, hingga memberi balasan kepadamu.\qt@no{244}}%
\qt@newcmd\qurantrans@id@cclii{%
(Siapakah yang bersedia memberi pinjaman kepada Allah) yaitu dengan menafkahkan hartanya di jalan Allah (yakni pinjaman yang baik) dengan ikhlas kepada-Nya semata, (maka Allah akan menggandakan) pembayarannya; menurut satu qiraat dengan tasydid hingga berbunyi 'fayudha'ifahu' (hingga berlipat-lipat) mulai dari sepuluh sampai pada tujuh ratus lebih sebagaimana yang akan kita temui nanti (Dan Allah menyempitkan) atau menahan rezeki orang yang kehendaki-Nya sebagai ujian (dan melapangkannya) terhadap orang yang dikehendaki-Nya, juga sebagai cobaan (dan kepada-Nya kamu dikembalikan) di akhirat dengan jalan akan dibangkitkan dari matimu dan akan dibalas segala amal perbuatanmu.\qt@no{245}}%
\qt@newcmd\qurantrans@id@ccliii{%
(Tidakkah kamu perhatikan segolongan Bani Israel setelah) wafat (Musa), maksudnya kisah dan berita mereka, (yaitu ketika mereka berkata kepada seorang nabi mereka) namanya Samuel, ("Angkatlah untuk kami seorang raja, supaya kami berperang) dengannya (di jalan Allah) hingga ia dapat memimpin dan menyusun barisan kami! (Jawab nabi mereka, ``Tidak mungkinkah) dengan memakai baris di atas dan baris di bawah (jika kamu diwajibkan berperang, kamu tidak mau berperang?") Khabar dari `asa, sedangkan pertanyaan menunjukkan lebih besar kemungkinan terjadinya. (Jawab mereka, ``Kenapa kami tidak mau berperang di jalan Allah, padahal kami sudah diusir dari kampung halaman kami dan dari anak-anak kami"), artinya sebagian dari mereka ada yang ditawan dan sebagian yang lain ada yang dibunuh. Hal ini telah dilakukan terhadap mereka oleh kaum Jalut. Jadi maksudnya adalah tidak ada halangan bagi kami untuk berperang, yakni selama alasannya masih ada. Firman Allah swt., (Maka tatkala berperang itu diwajibkan atas mereka, mereka pun berpaling) daripadanya dan merasa kecut, (kecuali sebagian kecil dari mereka), yakni yang menyeberangi sungai bersama Thalut sebagaimana yang akan diterangkan nanti. (Dan Allah Maha Mengetahui akan orang-orang yang aniaya), maksudnya akan membalas segala yang diperbuat oleh mereka. Dan nabi mereka pun memohon kepada Tuhannya agar mengirimkan seorang raja, tetapi yang dikabulkan-Nya ialah Thalut.\qt@no{246}}%
\qt@newcmd\qurantrans@id@ccliv{%
(Kata nabi mereka kepada mereka, ``Sesungguhnya Allah telah mengangkat Thalut bagi kamu sebagai raja." Jawab mereka, ``Bagaimana), artinya betapa (ia akan menjadi raja, padahal kami lebih berhak terhadap kerajaan ini daripadanya). Ia bukanlah dari keturunan raja-raja atau bangsawan dan tidak pula dari keturunan nabi-nabi. Bahkan ia hanyalah seorang tukang samak atau gembala, (sedangkan ia pun tidak diberi kekayaan yang mencukupi") yakni yang amat diperlukan untuk membina atau mendirikan sebuah kerajaan. (Kata nabi) kepada mereka, ("Sesungguhnya Allah telah memilihnya sebagai rajamu (dan menambahnya pula keluasan) dan keperkasaan (dalam ilmu dan tubuh"). Memang ketika itu dialah orang Israel yang paling berilmu, paling gagah dan paling berakhlak. (Dan Allah memberikan kerajaan-Nya kepada siapa yang dikehendaki-Nya) suatu pemberian yang tidak seorang pun mampu untuk menghalanginya. (Dan Allah Maha Luas) karunia-Nya, (lagi Maha Mengetahui) orang yang lebih patut menerima karunia-Nya itu.\qt@no{247}}%
\qt@newcmd\qurantrans@id@cclv{%
(Kata nabi mereka kepada mereka), yakni tatkala mereka meminta kepadanya tanda pengangkatannya sebagai raja. (Sesungguhnya tanda ia akan menjadi raja ialah datangnya tabut kepadamu), yakni sebuah peti tempat menyimpan serunai nabi-nabi yang diturunkan Allah kepada nabi Adam dan terus-menerus berada pada mereka sampai mereka dikalahkan oleh orang-orang Amaliqah yang berhasil merebut serunai itu. Selama ini mereka mengambilnya sebagai lambang kemenangan mereka terhadap musuh dan mereka tonjolkan dalam peperangan serta mendapatkan ketenangan hati, sebagaimana firman Allah swt., ("Di dalamnya terdapat ketenangan) ketenteraman bagi hatimu (dari Tuhanmu dan sisa-sisa peninggalan keluarga Musa dan keluarga Harun), yakni yang ditinggalkan kedua nabi itu, sepasang terompah Musa dan tongkatnya serta serban nabi Harun dan tulang-tulang burung manna yang pernah turun kepada mereka serta kepingan-kepingan luh (yang dibawa oleh malaikat) menjadi 'hal' dari pelaku 'ya'tiikum.' (Sesungguhnya pada demikian itu menjadi tanda bagi kamu) atas diangkatnya sebagai raja (jika kamu benar-benar beriman). Tabut itu lalu dibawa oleh malaikat, terapung-apung antara bumi dan langit serta disaksikan oleh mereka dan akhirnya ditaruh oleh malaikat dekat Thalut. Mereka pun mengakuinya sebagai raja dan berlomba-lomba untuk berjihad di sampingnya. Maka dipilihnyalah 70 ribu orang di antara pemuda-pemuda mereka.\qt@no{248}}%
\qt@newcmd\qurantrans@id@cclvi{%
(Maka tatkala keluar) artinya berangkat (Thalut bersama tentaranya) dari Baitulmakdis, sedang ketika itu hari amat panas hingga mereka meminta kepadanya agar diberi air, (maka jawabnya, ``Sesungguhnya Allah akan mencoba kamu) atau menguji kamu (dengan sebuah sungai) terletak antara Yordania dan Palestina, agar jelas siapa di antara kamu yang taat dan siapa pula yang durhaka. ``Maka barang siapa di antara kamu (meminumnya), maksudnya meminum airnya (maka tidaklah ia dari golonganku) bukan pengikut-pengikutku. (Barang siapa yang tidak merasainya) artinya tidak meminumnya, (kecuali orang yang hanya meneguk satu tegukan saja, maka ia adalah pengikutku) 'ghurfah' dengan baris di atas atau di depan (dengan tangannya) mencukupkan dengan sebanyak itu dan tidak menambahnya lagi, maka ia termasuk golonganku. (Maka mereka meminumnya) banyak-banyak ketika bertemu dengan anak sungai itu, (kecuali beberapa orang di antara mereka). Mereka ini mencukupkan satu tegukan tangan mereka, yakni untuk mereka minum dan untuk hewan-hewan mereka. Jumlah mereka tiga ratus dan beberapa belas orang (Tatkala ia telah melewati anak sungai itu, yakni Thalut dengan orang-orang yang beriman bersamanya) yakni mereka yang mencukupkan satu tegukan (mereka pun berkata) maksudnya yang minum secara banyak tadi, ("Tak ada kesanggupan) atau daya dan kekuatan (kami sekarang ini untuk menghadapi Jalut dan tentaranya") maksudnya untuk berperang dengan mereka. Mereka jadi pengecut dan tidak jadi menyeberangi sungai itu. (Berkatalah orang-orang yang menyangka), artinya meyakini (bahwa mereka akan menemui Allah), yakni di hari berbangkit, mereka itulah yang berhasil menyeberangi sungai: ("Berapa banyaknya), artinya amat banyak terjadi (golongan yang sedikit dapat mengalahkan golongan yang banyak dengan izin Allah) serta kehendak-Nya (Dan Allah beserta orang-orang yang sabar") dengan bantuan dan pertolongan-Nya.\qt@no{249}}%
\qt@newcmd\qurantrans@id@cclvii{%
(Dan tatkala mereka tampil untuk memerangi Jalut bersama tentaranya) artinya telah berbaris dan siap sedia untuk bertempur, (mereka berdoa, ``Ya Tuhan kami! Tuangkanlah) atau limpahkanlah (kepada kami kesabaran, teguhkanlah pendirian kami) dengan memperkokoh hati kami untuk berjuang, (dan bantulah kami terhadap orang-orang kafir").\qt@no{250}}%
\qt@newcmd\qurantrans@id@cclviii{%
(Mereka berhasil mengalahkan tentara Jalut) atau menghancurkan mereka (dengan izin Allah) atau kehendak-Nya, (dan Daud membunuh) yang berada dalam tentara Thalut (Jalut, kemudian ia diberi), yakni Daud (oleh Allah kerajaan) dalam lingkungan Bani Israel (dan hikmah), yaitu kenabian, setelah kematian Samuel dan Thalut. Kedua jabatan ini tidak pernah dirangkap oleh seorang pun sebelumnya (serta diajarkan-Nya kepadanya apa-apa yang dikehendaki-Nya), misalnya membuat baju besi dan menguasai bahasa burung. (Dan seandainya Allah tidak menolak kekejaman sebagian manusia) ba`dhuhum menjadi badal dari manusia (dengan sebagian yang lain, tentulah bumi ini akan rusak binasa), yakni dengan kemenangan orang-orang musyrik, terbunuhnya kaum muslimin dan dihancurkannya mesjid-mesjid. (Tetapi Allah mempunyai karunia terhadap seluruh alam) hingga Allah menolak atau menahan sebagian dari mereka (kaum musyrikin) melalui sebagian yang lain (kaum muslimin).\qt@no{251}}%
\qt@newcmd\qurantrans@id@cclix{%
(Itu), maksudnya ayat-ayat tadi (adalah ayat Allah yang Kami bacakan) atau ceritakan (kepadamu) hai Muhammad (dengan benar) (dan sesungguhnya kamu adalah salah seorang dari para rasul). Penegasan dengan 'inna' dan lain-lainnya, bertujuan untuk menolak ucapan orang-orang kafir terhadapnya yang mengatakan, ``Kamu bukanlah salah seorang rasul."\qt@no{252}}%
\qt@newcmd\qurantrans@id@cclx{%
(Para rasul itu) menjadi mubtada, sedangkan khabarnya adalah (Kami lebihkan sebagian atas lainnya), yaitu dengan memberi mereka keistimewaan yang tidak diberikan kepada lainnya. (Di antara mereka ada yang diajak berbicara oleh Allah), misalnya Musa (dan sebagian ditinggikan-Nya - kedudukannya -), yakni nabi Muhammad saw. (beberapa tingkat) dari yang lainnya, misalnya dengan dakwahnya yang umum, mukjizat yang berlimpah dan keistimewaan yang tidak terhitung banyaknya. (Dan Kami berikan kepada Isa bin Maryam beberapa mukjizat dan Kami kuatkan ia dengan Roh Kudus), yakni Jibril yang mengiringkannya ke mana pergi. (Sekiranya Allah menghendaki) tentulah akan ditunjuki-Nya semua manusia dan (tidaklah mereka akan berbunuh-bunuhan orang-orang yang datang sesudah mereka), yakni sesudah para rasul itu, maksudnya ialah umat-umat mereka (sesudah datang kepada mereka beberapa macam keterangan) disebabkan pertikaian dan saling menyesatkan di antara mereka. (Tetapi mereka bertikai) disebabkan kehendak Allah tadi, (maka di antara mereka ada yang beriman) artinya kuat dan tetap keimanannya (dan di antara mereka ada pula yang kafir) seperti orang-orang Kristen setelah Almasih. (Sekiranya Allah menghendaki tidaklah mereka akan berbunuh-bunuhan) sebagai pengukuhan (tetapi Allah berbuat apa yang dikehendaki-Nya) yaitu menunjuki siapa yang disukai-Nya dan menjatuhkan orang yang dikehendaki-Nya.\qt@no{253}}%
\qt@newcmd\qurantrans@id@cclxi{%
(Hai orang-orang yang beriman! Nafkahkanlah sebagian dan rezeki yang telah Kami berikan padamu), yakni zakatnya, (sebelum datang suatu hari tidak ada lagi jual beli) atau tebusan (padanya, dan tidak pula persahabatan) yang akrab dan memberi manfaat, (dan tidak pula syafaat) tanpa izin dari-Nya, yaitu di hari kiamat. Menurut satu qiraat dengan baris di depannya ketiga kata, bai`u, khullatu dan syafaa`atu. (Dan orang-orang yang kafir) kepada Allah atau terhadap apa yang diwajibkan-Nya, (merekalah orang-orang yang aniaya) karena menempatkan perintah Allah bukan pada tempatnya.\qt@no{254}}%
\qt@newcmd\qurantrans@id@cclxii{%
(Allah, tak ada Tuhan), artinya tak ada ma`bud atau sembahan yang sebenarnya di alam wujud ini, (melainkan Dia Yang Maha Hidup), artinya Kekal lagi Abadi (dan senantiasa mengatur), maksudnya terus-menerus mengatur makhluk-Nya (tidak mengantuk) atau terlena, (dan tidak pula tidur. Milik-Nyalah segala yang terdapat di langit dan di bumi) sebagai kepunyaan, ciptaan dan hamba-Nya. (Siapakah yang dapat), maksudnya tidak ada yang dapat (memberi syafaat di sisi-Nya, kecuali dengan izin-Nya) dalam hal itu terhadapnya. (Dia mengetahui apa yang di hadapan mereka), maksudnya di hadapan makhluk (dan apa yang di belakang mereka), artinya urusan dunia atau soal akhirat, (sedangkan mereka tidak mengetahui suatu pun dari ilmu-Nya), artinya manusia tidak tahu sedikit pun dari apa yang diketahui oleh Allah itu, (melainkan sekadar yang dikehendaki-Nya) untuk mereka ketahui melalui pemberitaan dari para Rasul. (Kursinya meliputi langit dan bumi) ada yang mengatakan bahwa maksudnya ialah ilmu-Nya, ada pula yang mengatakan kekuasaan-Nya, dan ada pula Kursi itu sendiri yang mencakup langit dan bumi, karena kebesaran-Nya, berdasarkan sebuah hadis, ``Tidaklah langit yang tujuh pada kursi itu, kecuali seperti tujuh buah uang dirham yang dicampakkan ke dalam sebuah pasukan besar (Dan tidaklah berat bagi-Nya memelihara keduanya), artinya memelihara langit dan bumi itu (dan Dia Maha Tinggi) sehingga menguasai semua makhluk-Nya, (lagi Maha Besar).\qt@no{255}}%
\qt@newcmd\qurantrans@id@cclxiii{%
(Tidak ada paksaan dalam agama), maksudnya untuk memasukinya. (Sesungguhnya telah nyata jalan yang benar dari jalan yang salah), artinya telah jelas dengan adanya bukti-bukti dan keterangan-keterangan yang kuat bahwa keimanan itu berarti kebenaran dan kekafiran itu adalah kesesatan. Ayat ini turun mengenai seorang Ansar yang mempunyai anak-anak yang hendak dipaksakan masuk Islam. (Maka barang siapa yang ingkar kepada tagut), maksudnya setan atau berhala, dipakai untuk tunggal dan jamak (dan dia beriman kepada Allah, maka sesungguhnya ia telah berpegang kepada simpul tali yang teguh kuat) ikatan tali yang kokoh (yang tidak akan putus-putus dan Allah Maha Mendengar) akan segala ucapan (Maha Mengetahui) segala perbuatan.\qt@no{256}}%
\qt@newcmd\qurantrans@id@cclxiv{%
(Allah pelindung) atau pembela (orang-orang yang beriman yang mengeluarkan mereka dari kegelapan), maksudnya kekafiran (pada cahaya) atau keimanan. (Sedangkan orang-orang kafir, pelindung-pelindung mereka ialah setan yang mengeluarkan mereka dari cahaya kepada kegelapan). Disebutkan di sini ikhraj atau mengeluarkan. Adakalanya sebagai imbangan firman-Nya, ``Mengeluarkan mereka dari kegelapan", atau mengenai orang-orang Yahudi yang beriman kepada nabi sebelum dibangkitkannya, kemudian kafir kepadanya. (Mereka itu adalah penghuni-penghuni neraka, mereka kekal di dalamnya).\qt@no{257}}%
\qt@newcmd\qurantrans@id@cclxv{%
(Tidakkah kamu perhatikan orang yang mendebat Ibrahim tentang Tuhannya) (mentang-mentang ia diberi Allah kerajaan) maksudnya raja Namruz yang karena telah berkuasa hendak menyangkal karunia Allah kepadanya, (ketika) menjadi badal dari 'haajja' (Ibrahim berkata) ketika Namruz menanyakan padanya, ``Siapakah Tuhanmu yang kamu seru kami kepada-Nya itu?" ("Tuhanku ialah yang menghidupkan dan mematikan"), maksudnya menciptakan kehidupan dan kematian di dalam tubuh. (Katanya) Kata Namruz, ("Sayalah yang menghidupkan dan yang mematikan), yakni dengan membunuh dan memaafkan, lalu dipanggillah dua orang laki-laki, yang seorang dibunuh dan yang seorang lagi dibiarkan hidup. Maka tatkala dilihatnya raja itu seorang yang tolol, (Ibrahim berkata) sambil meningkat kepada alasan yang lebih jelas lagi, ("Sesungguhnya Allah menerbitkan matahari dari timur, maka terbitkanlah) olehmu (dari barat. Karena itu, bingung dan terdiamlah orang kafir itu) tidak dapat memberikan jawaban atau dalih lagi (dan Allah tidak memberi petunjuk kepada orang-orang yang aniaya) karena kekafirannya, yakni petunjuk ke jalan hidayah.\qt@no{258}}%
\qt@newcmd\qurantrans@id@cclxvi{%
(Atau) tidakkah kamu perhatikan (orang) 'kaf' hanya tambahan belaka (yang lewat di suatu negeri). Orang itu bernama Uzair dan lewat di Baitulmakdis dengan mengendarai keledai sambil membawa sekeranjang buah tin dan satu mangkuk perasan anggur (yang temboknya telah roboh menutupi atap-atapnya), yakni setelah dihancurkan oleh raja Bukhtanashar. (Katanya, ``Bagaimana caranya Allah menghidupkan kembali negeri ini setelah robohnya?") disebabkan kagumnya akan kekuasaan-Nya (Maka Allah pun mematikan orang itu) dan membiarkannya dalam kematian (selama seratus tahun, kemudian menghidupkannya). Untuk memperlihatkan kepadanya bagaimana caranya demikian itu. (Allah berfirman) kepadanya, (Berapa lamanya kamu tinggal di sini?) (Jawabnya, ``Saya telah tinggal di sini sehari atau setengah hari) karena ia mulai tidur dari waktu pagi, lalu dimatikan dan dihidupkan lagi di waktu Magrib, hingga menurut sangkanya tentulah ia tidur sepanjang hari itu. (Firman Allah swt., ``Sebenarnya sudah seratus tahun lamanya kamu tinggal; lihatlah makanan dan minumanmu itu) buah tin dan perasan anggur (yang belum berubah) artinya belum lagi basi walaupun waktunya sudah sekian lama. 'Ha' pada 'yatasannah' ada yang mengatakan huruf asli pada 'sanaha', ada pula yang mengatakannya sebagai huruf saktah, sedangkan menurut satu qiraat, tidak pakai 'ha' sama sekali (dan lihatlah keledaimu) bagaimana keadaannya. Maka dilihatnya telah menjadi bangkai sementara tulang belulangnya telah putih dan berkeping-keping. Kami lakukan itu agar kamu tahu, (dan akan Kami jadikan kamu sebagai tanda) menghidupkan kembali (bagi manusia. Dan lihatlah tulang-belulang) keledaimu itu (bagaimana Kami menghidupkannya) dibaca dengan nun baris di depan. Ada pula yang membacanya dengan baris di atas kata 'nasyara', sedang menurut qiraat dengan baris di depan berikut zai 'nunsyizuha' yang berarti Kami gerakkan dan Kami susun, (kemudian Kami tutup dengan daging) dan ketika dilihatnya tulang-belulang itu sudah tertutup dengan daging, bahkan telah ditiupkan kepadanya roh hingga meringkik. (Maka setelah nyata kepadanya) demikian itu dengan kesaksian mata (ia pun berkata, ``Saya yakin") berdasar penglihatan saya (bahwa Allah Maha Kuasa atas segala sesuatu"). Menurut satu qiraat 'i`lam' atau 'ketahuilah' yang berarti perintah dari Allah kepadanya supaya menyadari.\qt@no{259}}%
\qt@newcmd\qurantrans@id@cclxvii{%
(Dan) ingatlah (ketika Ibrahim berkata, ``Ya Tuhanku! Perlihatkanlah kepadaku bagaimana Engkau menghidupkan orang mati." Firman Allah) kepadanya (Apakah kamu tidak percaya?") akan kekuasaan-Ku dalam menghidupkan itu? Ditanyakan Ibrahim padahal Dia mengetahui bahwa Ibrahim mempercayainya, agar Ibrahim memberikan jawaban terhadap pertanyaan-Nya, hingga para pendengar pun mengerti akan maksud-Nya. ("Saya percaya", katanya) (tetapi) saya tanyakan (agar tenang) dan tenteram (hatiku) disebabkan kesaksian yang digabungkan pada pengambilan dalil (Firman-Nya, ``Ambillah empat ekor burung, lalu jinakkanlah kepadamu) dengan 'shad' yang baris di bawah dan baris di depan yang berarti jinakkanlah olehmu, lalu potong-potonglah hingga daging dan bulunya bercampur baur. (Kemudian letakkanlah di setiap bukit) yang terletak di negerimu (sebagian darinya, setelah itu panggillah ia) kepadamu (niscaya mereka akan mendatangimu dengan cepat) atau segera. (Dan ketahuilah bahwa Allah Maha Tangguh.") dalam perbuatan-Nya. Maka diambilnya burung merak, burung elang, gagak dan ayam jantan, masing-masing satu ekor, lalu ia melakukan apa yang diperintahkan sambil memegang kepala masing-masing, kemudian dipanggilnya hingga beterbangan potongan-potongan burung itu menemui kelompoknya hingga lengkap, lalu menuju kepalanya yang berada di tangannya.\qt@no{260}}%
\qt@newcmd\qurantrans@id@cclxviii{%
(Perumpamaan) atau sifat nafkah dari (orang-orang yang membelanjakan harta mereka di jalan Allah) artinya dalam menaati-Nya (adalah seperti sebutir biji yang menumbuhkan tujuh buah tangkai, pada masing-masing tangkai seratus biji.) Demikianlah pula halnya nafkah yang mereka keluarkan itu menjadi 700 kali lipat. (Dan Allah melipatgandakan) lebih banyak dari itu lagi (bagi siapa yang dikehendaki-Nya dan Allah Maha Luas) karunia-Nya (lagi Maha Mengetahui) siapa-siapa yang seharusnya beroleh ganjaran yang berlipat ganda itu.\qt@no{261}}%
\qt@newcmd\qurantrans@id@cclxix{%
(Orang-orang yang membelanjakan harta mereka di jalan Allah, kemudian mereka tidak mengiringi apa yang mereka belanjakan itu dengan cercaan) terhadap orang yang diberi, misalnya dengan mengatakan, ``Saya telah berbuat baik kepadamu dan telah menutupi keperluanmu" (atau menyakiti perasaan) yang bersangkutan, misalnya dengan menyebutkan soal itu kepada pihak yang tidak perlu mengetahuinya dan sebagainya (mereka memperoleh pahala) sebagai ganjaran nafkah mereka (di sisi Tuhan mereka. Tak ada kekhawatiran terhadap mereka dan tidak pula mereka berduka cita) yakni di akhirat kelak.\qt@no{262}}%
\qt@newcmd\qurantrans@id@cclxx{%
(Perkataan yang baik) atau ucapan yang manis dan penolakan secara lemah lembut terhadap si peminta (serta pemberian maaf) kepadanya atas desakan atau tingkah lakunya (lebih baik daripada sedekah yang diiringi dengan menyakiti perasaan) dengan mencerca atau mengomelinya (Dan Allah Maha Kaya) hingga tidak menemukan sedekah hamba-hambanya (lagi Maha Penyantun) dengan menangguhkan hukuman terhadap orang yang mencerca dan menyakiti hati si peminta.\qt@no{263}}%
\qt@newcmd\qurantrans@id@cclxxi{%
(Hai orang-orang yang beriman, janganlah kamu batalkan sedekah-sedekahmu), maksudnya pahala-pahalanya (dengan menyebut-nyebutnya dan menyakiti perasaan) si penerima hingga menjadi hapus (seperti orang), maksudnya seperti batalnya nafkah orang yang (menafkahkan hartanya karena ria kepada manusia) maksudnya ingin mendapatkan pujian manusia (dan ia tidak beriman kepada Allah dan hari yang akhir) yakni orang munafik (Maka perumpamaannya adalah seperti sebuah batu licin yang bertanah di atasnya, lalu ditimpa oleh hujan lebat) (hingga menjadi licin tandas) tanpa tanah dan apa-apa lagi di atasnya. (Mereka tidak menguasai). Kalimat ini untuk menyatakan tamsil keadaan orang munafik yang menafkahkan hartanya dengan tujuan beroleh pujian manusia. Dhamir atau kata ganti manusia di sini menunjukkan jamak, mengingat makna 'alladzii' juga mencakupnya (suatu pun dari hasil usaha mereka) yang telah mereka kerjakan, maksudnya pahalanya di akhirat, tak ubahnya bagai batu licin yang ditimpa hujan hingga tanahnya habis dihanyutkan air. (Dan Allah tidak menunjukkan orang-orang yang kafir).\qt@no{264}}%
\qt@newcmd\qurantrans@id@cclxxii{%
(Dan perumpamaan) nafkah dari (orang-orang yang menafkahkan harta mereka guna mencari) atau mendapatkan (keridaan Allah dan untuk keteguhan jiwa mereka) maksudnya untuk memastikan pahalanya, berbeda halnya dengan orang-orang munafik yang tidak mengharapkannya sama sekali karena pada dasarnya sudah tidak mempercayainya (seperti sebuah kebun) atau taman (di sebuah rabwah) atau rubwah, artinya suatu dataran yang tinggi rata (ditimpa oleh hujan lebat, hingga memberikan) artinya menghasilkan (buahnya) atau hasil panennya (dua kali lipat) atau secara berganda. (Jika tidak disiram oleh hujan lebat, maka oleh hujan gerimis) yang memadai disebabkan letaknya yang tinggi. Tegasnya ia tetap berbuah dengan lebatnya, biar hujan yang menimpanya lebat atau rintik-rintik. Demikian pula halnya nafkah yang disebutkan tadi, di sisi Allah ia tetap berkembang, biar sedikit atau banyak. (Dan Allah Maha Melihat apa-apa yang kamu kerjakan) dan akan membalasnya dengan sebaik-baiknya.\qt@no{265}}%
\qt@newcmd\qurantrans@id@cclxxiii{%
(Apakah ingin salah seorang kamu mempunyai suatu kebun) atau taman dari kurma dan anggur, sedang di bawahnya mengalir anak-anak sungai dan di dalamnya terdapat) buah-buahan (dari berbagai corak dan) sungguh (datanglah masa tuanya) sehingga ia menjadi lemah dan tak sanggup berusaha lagi, (sedangkan ia mempunyai keturunan yang lemah-lemah) anak-anak yang masih kecil yang masih dalam asuhannya. (Maka tiba-tiba kebun itu ditiup angin keras) atau topan (yang mengandung api hingga terbakar). Maka orang tadi kehilangan kebunnya di saat ia amat memerlukannya, hingga tinggallah ia bersama anak-anaknya dalam keadaan bingung dan putus asa, tidak berdaya. Ini merupakan tamsil bagi orang yang mengeluarkan nafkah dengan ria dan membangga-banggakan dirinya, yakni tentang hampa dan tiada bergunanya di saat ia amat memerlukannya nanti di akhirat. Pertanyaan di sini berarti tidak. Dari Ibnu Abbas diterima keterangan bahwa tamsil ini adalah bagi orang yang pada mulanya gemar mengerjakan kebaikan, tetapi tergoda oleh setan hingga berbalik mengerjakan kedurhakaan yang membakar hangus amal-amalannya tadi. (Demikianlah) sebagaimana dijelaskan-Nya apa yang kita sebutkan itu (Allah menerangkan ayat-ayat-Nya kepada kamu supaya kamu memikirkannya) hingga mendapat pelajaran darinya.\qt@no{266}}%
\qt@newcmd\qurantrans@id@cclxxiv{%
(Hai orang-orang yang beriman, nafkahkanlah), maksudnya zakatkanlah (sebagian yang baik-baik) dari (hasil usahamu) berupa harta (dan sebagian) yang baik-baik dari (apa yang Kami keluarkan dari bumi untuk kamu) berupa biji-bijian dan buah-buahan (dan janganlah kamu sengaja) mengambil (yang jelek) atau yang buruk (darinya) maksudnya dari yang disebutkan itu, lalu (kamu keluarkan untuk zakat) menjadi 'hal' dari dhamir yang terdapat pada 'tayammamu' (padahal kamu sendiri tidak mau mengambilnya) maksudnya yang jelek tadi, seandainya ia menjadi hak yang harus diberikan kepadamu (kecuali dengan memejamkan mata terhadapnya), artinya pura-pura tidak tahu atau tidak melihat kejelekannya, maka bagaimana kamu berani memberikan itu guna memenuhi hak Allah! (Dan ketahuilah bahwa Allah Maha Kaya) sehingga tidak memerlukan nafkahmu itu (lagi Maha Terpuji) pada setiap kondisi dan situasi.\qt@no{267}}%
\qt@newcmd\qurantrans@id@cclxxv{%
(Setan menjanjikan kemiskinan bagimu), artinya menakut-nakuti kamu dengan kemiskinan sekiranya kamu mengeluarkan zakat, maka hendaklah waspada (dan menyuruh kamu berbuat kejahatan) bersifat kikir dan menahan zakat (sedangkan Allah menjanjikan kepadamu) dengan mengeluarkan nafkah itu (keampunan dari-Nya) terhadap dosa-dosamu (dan karunia), yakni rezeki sebagai penggantinya (dan Allah Maha Luas) karunia-Nya (lagi Maha Mengetahui) orang-orang yang suka mengeluarkan nafkah.\qt@no{268}}%
\qt@newcmd\qurantrans@id@cclxxvi{%
(Allah memberikan hikmah), artinya ilmu yang berguna yang dapat mendorong manusia untuk bekerja dan berkarya (kepada siapa yang dikehendaki-Nya dan barang siapa yang telah diberi hikmah itu, maka sungguh ia telah diberi kebaikan yang banyak) karena hikmah itu akan menuntunnya kepada kebahagiaan yang abadi. (Dan tiadalah yang dapat mengambil pelajaran). Asalnya ta diidghamkan pada dzal hingga menjadi yadzdzakkaruu, (kecuali orang-orang berakal).\qt@no{269}}%
\qt@newcmd\qurantrans@id@cclxxvii{%
(Apa saja nafkah yang kamu keluarkan), artinya zakat atau sedekah yang kamu bayarkan (dan apa saja nazar yang kamu janjikan) lalu kamu penuhi dengan tepat (maka sesungguhnya Allah mengetahuinya) lalu membalasnya dengan balasan sebaik-baiknya. (Dan tidaklah orang-orang yang aniaya itu), yakni yang menahan zakat dan tidak menepati nazar atau memberikan nafkah bukan pada tempatnya, hanya untuk berbuat maksiat kepada Allah (mempunyai pembela) yang akan melindungi mereka dari azab Allah swt.\qt@no{270}}%
\qt@newcmd\qurantrans@id@cclxxviii{%
(Jika kamu menampakkan) atau memperlihatkan kepada umum (sedekah-sedekah), yakni yang sunah, (maka itu baik sekali). (Sebaliknya, jika kamu sembunyikan) atau rahasiakan (dan kamu berikan kepada orang-orang miskin, maka itu lebih baik bagimu) daripada menampakkan dan memberikannya kepada orang-orang yang mampu. Adapun sedekah yang fardu, maka menampakkannya lebih utama agar ia menjadi ikutan orang lain dan untuk menghindarkan tuduhan yang bukan-bukan. Sedekah fardu atau zakat hanya diberikan kepada orang-orang miskin. (Dan Allah akan menghapus) dibaca dengan ya dan nun serta memakai baris mati karena diathafkan pada 'fahuwa' dan dapat pula dengan baris depan karena kedudukannya sebagai mubtada (daripadamu sebagian) 'min' untuk tab`idh atau menunjukkan sebagian (kesalahan-kesalahanmu. Dan Allah Maha Mengetahui apa-apa yang kamu kerjakan), artinya menyelami apa-apa yang tersembunyi, tak ubahnya dengan yang tampak atau yang lahir, tidak satu pun yang menjadi rahasia bagi-Nya.\qt@no{271}}%
\qt@newcmd\qurantrans@id@cclxxix{%
Tatkala Nabi saw. melarang memberikan sedekah kepada orang-orang musyrik agar mereka masuk Islam, turunlah ayat, (Bukan kewajibanmu menjadikan mereka mendapat petunjuk), maksudnya menjadikan manusia masuk Islam, karena kewajibanmu hanyalah menyampaikan belaka, (tetapi Allahlah yang menunjuki siapa yang dikehendaki-Nya) untuk memperoleh petunjuk agar masuk Islam. (Dan apa saja yang baik yang kamu nafkahkan), maksudnya berupa harta (maka buat dirimu sendiri) karena pahalanya untuk kamu (Dan tidaklah kamu menafkahkan sesuatu melainkan karena mengharapkan keridaan Allah), maksudnya pahala-Nya dan bukan karena yang lain seperti harta benda dunia. Kalimat ini kalimat berita, tetapi maksudnya adalah larangan, jadi berarti, ``Dan janganlah kamu nafkahkan sesuatu..." dan seterusnya. ("Dan apa saja harta yang kamu nafkahkan, niscaya akan diberikan kepadamu dengan secukupnya), artinya pahalanya (dan kamu tidaklah akan dirugikan"), artinya jumlahnya tidak akan dikurangi sedikit pun. Kedua kalimat belakangan memperkuat yang pertama.\qt@no{272}}%
\qt@newcmd\qurantrans@id@cclxxx{%
(Ialah bagi orang-orang fakir) menjadi predikat atau khabar dari subjek atau mubtada yang dibuang yang diperkirakan berbunyi, ``Sedekah itu untuk...." (yang terikat di jalan Allah), maksudnya yang menyediakan diri mereka untuk berjihad. Mereka itu ialah ahli sufi sebanyak 400 orang Muhajirin yang menekuni Alquran dan menunggu kesempatan untuk pergi keluar bersama rombongan pasukan. (Mereka tidak dapat berusaha) atau menjadi musafir (di muka bumi) untuk berdagang dan mencari penghidupan karena kesibukan mereka dalam perjuangan itu. (Orang-orang yang tidak tahu menyangka mereka) melihat keadaan lahiriah mereka (kaya raya karena mereka memelihara diri dari meminta-minta) karena segan dan tak hendak menadahkan tangan mereka. (Kamu mengenal mereka) hai para mukhathab (dengan tanda-tanda) atau ciri-ciri mereka misalnya tawaduk atau rendah hati dan bekas-bekas keletihan. (Mereka tak hendak meminta kepada orang-orang) sesuatu (dengan mendesak) artinya pada dasarnya mereka tak hendak meminta, hingga tidak mungkin pula akan mendesak. (Dan apa saja harta yang baik yang kamu infakkan, maka sesungguhnya Allah mengetahuinya) dan akan membalasnya.\qt@no{273}}%
\qt@newcmd\qurantrans@id@cclxxxi{%
(Orang-orang yang menafkahkan harta mereka, baik malam maupun siang secara sembunyi-sembunyi atau terang-terangan, maka mereka beroleh pahala di sisi Tuhan mereka, tak ada kekhawatiran terhadap mereka dan tidak pula mereka berduka cita).\qt@no{274}}%
\qt@newcmd\qurantrans@id@cclxxxii{%
(Orang-orang yang memakan riba), artinya mengambilnya. Riba itu ialah tambahan dalam muamalah dengan uang dan bahan makanan, baik mengenai banyaknya maupun mengenai waktunya, (tidaklah bangkit) dari kubur-kubur mereka (seperti bangkitnya orang yang kemasukan setan disebabkan penyakit gila) yang menyerang mereka; minal massi berkaitan dengan yaquumuuna. (Demikian itu), maksudnya yang menimpa mereka itu (adalah karena), maksudnya disebabkan mereka (mengatakan bahwa jual-beli itu seperti riba) dalam soal diperbolehkannya. Berikut ini kebalikan dari persamaan yang mereka katakan itu secara bertolak belakang, maka firman Allah menolaknya, (padahal Allah menghalalkan jual-beli dan mengharamkan riba. Maka barang siapa yang datang kepadanya), maksudnya sampai kepadanya (pelajaran) atau nasihat (dari Tuhannya, lalu ia menghentikannya), artinya tidak memakan riba lagi (maka baginya apa yang telah berlalu), artinya sebelum datangnya larangan dan doa tidak diminta untuk mengembalikannya (dan urusannya) dalam memaafkannya terserah (kepada Allah. Dan orang-orang yang mengulangi) memakannya dan tetap menyamakannya dengan jual beli tentang halalnya, (maka mereka adalah penghuni neraka, kekal mereka di dalamnya).\qt@no{275}}%
\qt@newcmd\qurantrans@id@cclxxxiii{%
(Allah menghancurkan riba) dengan menguranginya dan melenyapkan berkahnya (dan menyuburkan sedekah), maksudnya menambah dan mengembangkannya serta melipatgandakan pahalanya. (Dan Allah tidak menyukai setiap orang yang ingkar) yang menghalalkan riba (lagi banyak dosa), artinya yang durhaka dengan memakan riba itu hingga akan menerima hukuman-Nya.\qt@no{276}}%
\qt@newcmd\qurantrans@id@cclxxxiv{%
(Sesungguhnya orang-orang yang beriman dan beramal saleh serta mendirikan salat dan membayar zakat, bagi mereka pahala di sisi Tuhan mereka, tak ada kekhawatiran terhadap mereka dan tidak pula mereka berduka cita)\qt@no{277}}%
\qt@newcmd\qurantrans@id@cclxxxv{%
(Hai orang-orang yang beriman, bertakwalah kamu kepada Allah dan tinggalkanlah), maksudnya jauhilah (sisa yang tinggal dari riba, jika kamu beriman dengan sebenarnya, karena sifat atau ciri-ciri orang beriman adalah mengikuti perintah Allah. Ayat ini diturunkan tatkala sebagian sahabat masih juga menuntut riba di masa lalu, walaupun riba itu sudah dilarang.\qt@no{278}}%
\qt@newcmd\qurantrans@id@cclxxxvi{%
(Jika kamu tak mau melakukannya), yakni apa yang diperintahkan itu, (maka ketahuilah) datangnya (serbuan dari Allah dan rasul-Nya) terhadapmu. Ayat ini berisi ancaman keras kepada mereka, hingga ketika ia turun, mereka mengatakan, ``Tak ada daya kita untuk mengatasi serbuan itu!" (Dan jika kamu bertobat), artinya menghentikannya, (maka bagi kamu pokok) atau modal (hartamu, agar kamu tidak menganiaya) dengan mengambil tambahan (dan tidak pula teraniaya) dengan menerima jumlah yang kurang.\qt@no{279}}%
\qt@newcmd\qurantrans@id@cclxxxvii{%
(Dan jika dia), yakni orang yang berutang itu (dalam kesulitan, maka hendaklah diberi tangguh) maksudnya hendaklah kamu undurkan pembayarannya (sampai dia berkelapangan) dibaca 'maisarah' atau 'maisurah'. (Dan jika kamu menyedekahkannya), dibaca dengan tasydid, yakni setelah mengidgamkan ta pada asalnya pada shad menjadi 'tashshaddaqu', juga tanpa tasydid hingga dibaca 'tashaddaqu', yakni telah dibuang ta, sedangkan artinya ialah mengeluarkan sedekah kepada orang yang sedang dalam kesusahan itu dengan jalan membebaskannya dari utang, baik sebagian maupun keseluruhan (itu lebih baik bagimu, jika kamu mengetahui) bahwa demikian itu baik, maka kerjakanlah! Dalam sebuah hadis disebutkan, ``Barang siapa yang memberi tangguh orang yang dalam kesusahan atau membebaskannya dari utang, maka Allah akan melindunginya dalam naungan-Nya, di hari saat tak ada naungan selain naungan-Nya." (H.R. Muslim)\qt@no{280}}%
\qt@newcmd\qurantrans@id@cclxxxviii{%
(Dan takutlah akan suatu hari yang nanti kamu akan dikembalikan) dibina' bagi maf`ul, sedangkan jika bagi fa`il, maka bunyinya 'tasiiruun', artinya berjalan (kepada Allah pada hari itu), yakni hari kiamat (kemudian dipenuhkan) pada hari itu (kepada setiap jiwa) balasan terhadap (apa yang dilakukannya) baik berupa kebaikan maupun kejahatan (dan mereka tidak akan dianiaya) dengan mengurangi kebaikan atau menambah kejahatannya.\qt@no{281}}%
\qt@newcmd\qurantrans@id@cclxxxix{%
(Hai orang-orang yang beriman! Jika kamu mengadakan utang piutang), maksudnya muamalah seperti jua beli, sewa-menyewa, utang-piutang dan lain-lain (secara tidak tunai), misalnya pinjaman atau pesanan (untuk waktu yang ditentukan) atau diketahui, (maka hendaklah kamu catat) untuk pengukuhan dan menghilangkan pertikaian nantinya. (Dan hendaklah ditulis) surat utang itu (di antara kamu oleh seorang penulis dengan adil) maksudnya benar tanpa menambah atau mengurangi jumlah utang atau jumlah temponya. (Dan janganlah merasa enggan) atau berkeberatan (penulis itu) untuk (menuliskannya) jika ia diminta, (sebagaimana telah diajarkan Allah kepadanya), artinya telah diberi-Nya karunia pandai menulis, maka janganlah dia kikir menyumbangkannya. 'Kaf' di sini berkaitan dengan 'ya'ba' (Maka hendaklah dituliskannya) sebagai penguat (dan hendaklah diimlakkan) surat itu (oleh orang yang berutang) karena dialah yang dipersaksikan, maka hendaklah diakuinya agar diketahuinya kewajibannya, (dan hendaklah ia bertakwa kepada Allah, Tuhannya) dalam mengimlakkan itu (dan janganlah dikurangi darinya), maksudnya dari utangnya itu (sedikit pun juga. Dan sekiranya orang yang berutang itu bodoh) atau boros (atau lemah keadaannya) untuk mengimlakkan disebabkan terlalu muda atau terlalu tua (atau ia sendiri tidak mampu untuk mengimlakkannya) disebabkan bisu atau tidak menguasai bahasa dan sebagainya, (maka hendaklah diimlakkan oleh walinya), misalnya bapak, orang yang diberi amanat, yang mengasuh atau penerjemahnya (dengan jujur. Dan hendaklah persaksikan) utang itu kepada (dua orang saksi di antara laki-lakimu) artinya dua orang Islam yang telah balig lagi merdeka (Jika keduanya mereka itu bukan), yakni kedua saksi itu (dua orang laki-laki, maka seorang laki-laki dan dua orang perempuan) boleh menjadi saksi (di antara saksi-saksi yang kamu sukai) disebabkan agama dan kejujurannya. Saksi-saksi wanita jadi berganda ialah (supaya jika yang seorang lupa) akan kesaksian disebabkan kurangnya akal dan lemahnya ingatan mereka, (maka yang lain (yang ingat) akan mengingatkan kawannya), yakni yang lupa. Ada yang membaca 'tudzkir' dan ada yang dengan tasydid 'tudzakkir'. Jumlah dari idzkar menempati kedudukan sebagai illat, artinya untuk mengingatkannya jika ia lupa atau berada di ambang kelupaan, karena itulah yang menjadi sebabnya. Menurut satu qiraat 'in' syarthiyah dengan baris di bawah, sementara 'tudzakkiru' dengan baris di depan sebagai jawabannya. (Dan janganlah saksi-saksi itu enggan jika) 'ma' sebagai tambahan (mereka dipanggil) untuk memikul dan memberikan kesaksian (dan janganlah kamu jemu) atau bosan (untuk menuliskannya), artinya utang-utang yang kamu saksikan, karena memang banyak orang yang merasa jemu atau bosan (biar kecil atau besar) sedikit atau banyak (sampai waktunya), artinya sampai batas waktu membayarnya, menjadi 'hal' dari dhamir yang terdapat pada 'taktubuh' (Demikian itu) maksudnya surat-surat tersebut (lebih adil di sisi Allah dan lebih mengokohkan persaksian), artinya lebih menolong meluruskannya, karena adanya bukti yang mengingatkannya (dan lebih dekat), artinya lebih kecil kemungkinan (untuk tidak menimbulkan keraguanmu), yakni mengenai besarnya utang atau jatuh temponya. (Kecuali jika) terjadi muamalah itu (berupa perdagangan tunai) menurut satu qiraat dengan baris di atas hingga menjadi khabar dari 'takuuna' sedangkan isimnya adalah kata ganti at-tijaarah (yang kamu jalankan di antara kamu), artinya yang kamu pegang dan tidak mempunyai waktu berjangka, (maka tidak ada dosa lagi kamu jika kamu tidak menulisnya), artinya barang yang diperdagangkan itu (hanya persaksikanlah jika kamu berjual beli) karena demikian itu lebih dapat menghindarkan percekcokan. Maka soal ini dan yang sebelumnya merupakan soal sunah (dan janganlah penulis dan saksi -maksudnya yang punya utang dan yang berutang- menyulitkan atau mempersulit), misalnya dengan mengubah surat tadi atau tak hendak menjadi saksi atau menuliskannya, begitu pula orang yang punya utang, tidak boleh membebani si penulis dengan hal-hal yang tidak patut untuk ditulis atau dipersaksikan. (Dan jika kamu berbuat) apa yang dilarang itu, (maka sesungguhnya itu suatu kefasikan), artinya keluar dari taat yang sekali-kali tidak layak (bagi kamu dan bertakwalah kamu kepada Allah) dalam perintah dan larangan-Nya (Allah mengajarimu) tentang kepentingan urusanmu. Lafal ini menjadi hal dari fi`il yang diperkirakan keberadaannya atau sebagai kalimat baru. (Dan Allah mengetahui segala sesuatu).\qt@no{282}}%
\qt@newcmd\qurantrans@id@ccxc{%
(Jika kamu dalam perjalanan), yakni sementara itu mengadakan utang-piutang (sedangkan kamu tidak beroleh seorang penulis, maka hendaklah ada barang jaminan) ada yang membaca 'ruhunun' bentuk jamak dari rahnun (yang dipegang) yang diperkuat dengan kepercayaanmu. Sunah menyatakan diperbolehkannya jaminan itu di waktu mukim dan adanya penulis. Maka mengaitkannya dengan jaminan, karena kepercayaan terhadapnya menjadi lebih kuat, sedangkan firman-Nya, ``... dan jaminan yang dipegang", menunjukkan jaminan disyaratkan harus dipegang dan dianggap memadai walaupun si peminjam atau wakilnya tidak hadir. (Akan tetapi jika sebagian kamu mempercayai yang lainnya), maksudnya yang berpiutang kepada orang yang berutang dan ia tidak dapat menyediakan jaminan (maka hendaklah orang yang dipercayainya itu memenuhi), maksudnya orang yang berutang (amanatnya), artinya hendaklah ia membayar utangnya (dan hendaklah ia bertakwa kepada Allah, Tuhannya) dalam membayar utangnya itu. (Dan barang siapa yang menyembunyikan kesaksian, maka ia adalah orang yang berdosa hatinya). Dikhususkan menyebutkannya di sini, karena hati itulah yang menjadi tempat kesaksian dan juga karena apabila hati berdosa, maka akan diikuti oleh lainnya, hingga akan menerima hukuman sebagaimana dialami oleh semua anggota tubuhnya. (Dan Allah Maha Mengetahui apa yang kamu kerjakan) hingga tiada satu pun yang tersembunyi bagi-Nya.\qt@no{283}}%
\qt@newcmd\qurantrans@id@ccxci{%
(Milik Allahlah apa yang terdapat di langit dan apa yang terdapat di bumi dan jika kamu menyatakan) atau melahirkan (apa yang ada di dalam hatimu) berupa kejahatan dan rencana untuk melakukannya (atau kamu menyembunyikan) maksudnya merahasiakannya (pastilah akan dihisab), yakni dibukakan (oleh Allah) pada hari kiamat. Allah mengampuni siapa yang dikehendaki-Nya) untuk diampuni, (dan menyiksa siapa yang dikehendaki-Nya) untuk disiksa. Kedua kata kerja ini dapat dihubungkan pada jawab syarat dengan baris mati dan dapat pula dengan baris di depan dengan perkiraan, 'fahuwa...' (Dan Allah Maha Kuasa atas segala sesuatu), di antaranya melakukan hisab atas perhitungan terhadapmu dan memberikan balasannya.\qt@no{284}}%
\qt@newcmd\qurantrans@id@ccxcii{%
(Telah beriman), artinya membenarkan (Rasul), yakni Muhammad (terhadap apa yang diturunkan kepadanya dari Tuhannya), yakni Alquran, demikian pula (orang-orang yang beriman), ma`thuf atau dihubungkan kepada Rasul (semuanya), tanwinnya menjadi pengganti bagi mudhaf ilaih (beriman kepada Allah, malaikat-malaikat-Nya dan Kitab-Kitab-Nya) ada yang membaca secara jamak dan ada pula secara mufrad atau tunggal (serta para Rasul-Nya) kata mereka, ("Kami tidak membeda-bedakan antara seseorang pun di antara Rasul-Rasul-Nya") hingga kami beriman kepada sebagian dan kafir kepada lainnya, sebagaimana dilakukan oleh orang-orang Yahudi dan Kristen (Dan mereka mengatakan, ``Kami dengar"), maksudnya apa yang diperintahkan kepada kami itu, disertai dengan penerimaan (dan kami taati) serta kami bermohon, ("Ampunilah kami, wahai Tuhan kami, dan kepada Engkaulah kami kembali"), yakni dengan adanya saat berbangkit. Tatkala turun ayat yang sebelumnya, orang-orang mukmin mengadukan waswas dan kekhawatiran mereka serta terasa berat bagi mereka saat perhitungan, maka turun pula ayat:\qt@no{285}}%
\qt@newcmd\qurantrans@id@ccxciii{%
(Allah tidaklah membebani seseorang melainkan sesuai dengan kemampuannya), artinya sekadar kesanggupannya. (Ia mendapat dari apa yang diusahakannya) berupa kebaikan artinya pahalanya (dan ia beroleh pula dari hasil kejahatannya), yakni dosanya. Maka seseorang itu tidaklah menerima hukuman dari apa yang tidak dilakukannya, hanya baru menjadi angan-angan dan lamunan mereka. Mereka bermohon, ("Wahai Tuhan kami! Janganlah kami dihukum) dengan siksa (jika kami lupa atau tersalah), artinya meninggalkan kebenaran tanpa sengaja, sebagaimana dihukumnya orang-orang sebelum kami. Sebenarnya hal ini telah dicabut Allah terhadap umat ini, sebagaimana yang telah dijelaskan oleh hadis. Permintaan ini merupakan pengakuan terhadap nikmat Allah. (Wahai Tuhan kami! Janganlah Engkau bebankan kepada kami beban yang berat) yang tidak mungkin dapat kami pikul (sebagaimana Engkau bebankan kepada orang-orang yang sebelum kami), yaitu Bani Israel berupa bunuh diri dalam bertobat, mengeluarkan seperempat harta dalam zakat dan mengorek tempat yang kena najis. (Wahai Tuhan kami! Janganlah Kamu pikulkan kepada kami apa yang tidak sanggup) atau tidak kuat (kami memikulnya) berupa tugas-tugas dan cobaan-cobaan. (Beri maaflah kami) atau hapuslah sekalian dosa kami (ampunilah kami dan beri rahmatlah kami) dalam rahmat itu terdapat kelanjutan atau tambahan keampunan, (Engkaulah pembela kami), artinya pemimpin dan pengatur urusan kami (maka tolonglah kami terhadap orang-orang yang kafir."), yakni dengan menegakkan hujah dan memberikan kemenangan dalam peraturan dan pertempuran dengan mereka, karena ciri-ciri seorang maula atau pembela adalah menolong anak buahnya terhadap musuh-musuh mereka. Dalam sebuah hadis tercantum bahwa tatkala ayat ini turun dan dibaca oleh Nabi saw., maka setiap kalimat diberikan jawaban oleh Allah swt., ``Telah Engkau penuhi!"\qt@no{286}}%
\qt@newcmd\qurantrans@id@ccxciv{%
\basmalahid (Alif laam miim), Allah yang lebih tahu akan maksudnya.\qt@no{1}}%
\qt@newcmd\qurantrans@id@ccxcv{%
(Allah, tiada Tuhan melainkan Dia, Yang Maha Hidup lagi berdiri sendiri.)\qt@no{2}}%
\qt@newcmd\qurantrans@id@ccxcvi{%
(Diturunkan-Nya kepadamu) hai Muhammad (Al-kitab) Alquran, berisikan (kebenaran) dalam semua beritanya (membenarkan kitab-kitab yang berada di depannya) maksudnya kitab-kitab yang turun sebelumnya (dan diturunkan-Nya pula Taurat dan Injil).\qt@no{3}}%
\qt@newcmd\qurantrans@id@ccxcvii{%
(Sebelumnya) artinya sebelum diturunkannya Alquran (menjadi petunjuk) hal dengan makna menunjukkan dari kesesatan (bagi manusia) bagi orang-orang yang mengikuti kedua kitab itu. Pada Taurat dan Injil 'menurunkan' dipakai kata-kata 'anzala', sedangkan pada Alquran dengan 'nazzala' yang berarti secara berulang-ulang, berbeda dengan Taurat dan Injil yang diturunkan sekaligus (dan diturunkan-Nya pula Al-Furqan) artinya kitab yang memisahkan antara yang hak dan yang batil dan disebutkannya secara keseluruhan. (Sesungguhnya orang-orang yang kafir terhadap ayat-ayat Allah) misalnya pada Alquran dan lainnya (bagi mereka disediakan siksa yang berat dan Allah Maha Tangguh) menguasai segala urusan sehingga tak suatu pun yang dapat menghalangi-Nya untuk menunaikan janji dan ancaman-Nya (dan mempunyai balasan siksa) artinya hukuman berat terhadap orang yang durhaka, yang tak dapat dilakukan oleh siapa pun.\qt@no{4}}%
\qt@newcmd\qurantrans@id@ccxcviii{%
(Sesungguhnya bagi Allah tidak ada suatu pun yang tersembunyi) di antara barang wujud ini (baik di bumi maupun di langit) karena ilmu-Nya terhadap apa yang terdapat di seluruh alam, baik merupakan keseluruhan maupun yang sebagian-sebagian, dan ini diistimewakan menyebutkannya karena penginderaan dapat melampauinya.\qt@no{5}}%
\qt@newcmd\qurantrans@id@ccxcix{%
(Dialah yang membentuk kamu dalam rahim sebagaimana dikehendaki-Nya) apakah akan jadi laki-laki atau perempuan, berkulit putih atau berkulit hitam dan sebagainya. (Tiada Tuhan melainkan Dia Yang Maha Tangguh) dalam kerajaan-Nya (lagi Maha Bijaksana) dalam tindakan dan perbuatan-Nya.\qt@no{6}}%
\qt@newcmd\qurantrans@id@ccc{%
(Dialah yang menurunkan kepadamu Alquran, di antara isinya ada ayat-ayat yang muhkamat) jelas maksud dan tujuannya (itulah dia pokok-pokok Alquran) yakni yang menjadi pegangan dalam menetapkan (sedangkan yang lainnya mutasyabihat) tidak dimengerti secara jelas maksudnya, misalnya permulaan-permulaan surah. Semuanya disebut sebagai 'muhkam' seperti dalam firman-Nya 'uhkimat aayaatuh' dengan arti tak ada cacat atau celanya, dan 'mutasyaabiha' pada firman-Nya, 'Kitaaban mutasyaabiha,' dengan makna bahwa sebagian menyamai lainnya dalam keindahan dan kebenaran. (Adapun orang-orang yang dalam hatinya ada kecenderungan pada kesesatan) menyeleweng dari kebenaran, (maka mereka mengikuti ayat-ayat mutasyabihat untuk membangkitkan fitnah) di kalangan orang-orang bodoh dengan menjerumuskan mereka ke dalam hal-hal yang syubhat dan kabur pengertiannya (dan demi untuk mencari-cari takwilnya) tafsirnya (padahal tidak ada yang tahu takwil) tafsirnya (kecuali Allah) sendiri-Nya (dan orang-orang yang mendalam) luas lagi kokoh (ilmunya) menjadi mubtada, sedangkan khabarnya: (Berkata, ``Kami beriman kepada ayat-ayat mutasyaabihat) bahwa ia dari Allah, sedangkan kami tidak tahu akan maksudnya, (semuanya itu) baik yang muhkam maupun yang mutasyabih (dari sisi Tuhan kami," dan tidak ada yang mengambil pelajaran) 'Ta' yang pada asalnya terdapat pada 'dzal' diidgamkan pada dzal itu hingga berbunyi 'yadzdzakkaru' (kecuali orang-orang yang berakal) yang mau berpikir. Mereka juga mengucapkan hal berikut bila melihat orang-orang yang mengikuti mereka.\qt@no{7}}%
\qt@newcmd\qurantrans@id@ccci{%
("Tuhan kami! Janganlah engkau gelincirkan hati kami) janganlah diselewengkan dari kebenaran dengan mencari-cari tafsirnya yang tidak layak bagi kami sebagaimana dialami oleh mereka (setelah Engkau memberi petunjuk kepada kami) bimbingan ke arah perkara yang benar (dan berilah kami dari sisi-Mu rahmat) keteguhan hati (karena Engkaulah Yang Maha Memberi) karunia.\qt@no{8}}%
\qt@newcmd\qurantrans@id@cccii{%
(Tuhan kami! Sesungguhnya Engkau akan mengumpulkan manusia) menghimpun mereka (untuk suatu hari) maksudnya pada suatu hari (yang tak ada keraguan) atau kebimbangan (padanya) yakni hari kiamat, maka Engkau balas amal perbuatan mereka sebagaimana telah Engkau janjikan. (Sesungguhnya Allah tidak menyalahi janji.") yakni janji-Nya tentang saat berbangkit. Di sini terdapat peralihan pembicaraan dan kemungkinan ia merupakan firman Allah swt. Adapun maksud dari doa seperti itu ialah untuk menyatakan bahwa pusat perhatian mereka ialah soal akhirat. Oleh sebab itulah mereka memohon agar tetap berada dalam hidayah atau petunjuk Allah hingga beroleh pahala. Diriwayatkan oleh Bukhari dan Muslim melalui Aisyah r.a. katanya, ``Rasulullah saw. membaca ayat, 'Dialah yang telah menurunkan kepadamu kitab, di antara isinya ialah ayat-ayat yang muhkamat...' dan seterusnya lalu sabdanya, 'Apabila kamu lihat orang-orang yang mengikuti ayat-ayat mutasyabihat mereka itulah yang disebutkan oleh Allah, maka waspadalah terhadap mereka.'" Diriwayatkan pula oleh Thabrani dalam Al-Kabir melalui Abu Musa Al-Asyari, bahwa ia mendengar Nabi saw. bersabda, ``Tidak ada yang aku khawatirkan terhadap umatku, kecuali tiga perkara yang di antaranya ialah akan dimudahkan bagi mereka mempelajari Alquran, tetapi orang mukmin mencari-cari takwil yang mutasyabihat, padahal tidak ada yang tahu akan takwilnya itu kecuali Allah, sedangkan orang-orang yang mendalam ilmunya mengatakan, 'Kami beriman padanya, semuanya dari sisi Tuhan kami dan tidaklah yang beroleh peringatan kecuali orang-orang yang berakal.'" (Hadis)\qt@no{9}}%
\qt@newcmd\qurantrans@id@ccciii{%
(Sesungguhnya orang-orang kafir, harta benda dan anak-anak mereka tidak dapat menolak Allah) yakni siksa-Nya (sedikit pun dan merekalah bahan bakar api neraka) dibaca 'waquud', bahan untuk pembakaran.\qt@no{10}}%
\qt@newcmd\qurantrans@id@ccciv{%
(Seperti adat kebiasaan kaum Firaun dan orang-orang sebelum mereka) seperti kaum Ad dan Tsamud (mereka mendustakan ayat-ayat Kami hingga dicelakakan Allah) dibinasakan-Nya (disebabkan dosa-dosa mereka). Perkataan ini menafsirkan perkataan yang sebelumnya. (Dan Allah sangat keras siksa-Nya). Ayat berikut turun ketika Nabi saw. menyuruh orang-orang Yahudi masuk Islam sekembalinya dari perang Badar, maka jawab mereka, ``Janganlah kamu teperdaya mentang-mentang berhasil membunuh gerombolan Quraisy yang kacau balau dan tidak tahu memegang senjata."\qt@no{11}}%
\qt@newcmd\qurantrans@id@cccv{%
(Katakanlah) hai Muhammad (kepada orang-orang kafir) kepada golongan Yahudi itu, ("Kamu nanti akan menderita kekalahan) memakai ta dan ya, di alam dunia ini dengan dibunuh, ditawan dan membayar upeti dan itu telah terjadi (dan akan dihimpun) juga dengan memakai ta dan ya, di akhirat nanti (ke neraka Jahanam) lalu memasukinya (dan Jahanam itu adalah seburuk-buruk hamparan) tempat tinggal."\qt@no{12}}%
\qt@newcmd\qurantrans@id@cccvi{%
(Sesungguhnya bagi kamu ada tanda) atau pelajaran, lalu hal itu disebutkan untuk penjelasan (pada dua golongan) dua puak (yang bertemu) di hari Badar untuk berperang (segolongan bertempur di jalan Allah) untuk menaati perintah-Nya, yaitu Nabi saw. bersama para sahabat. Mereka berjumlah 313 orang laki-laki termasuk beberapa orang berkuda, enam buah ketopong besi dan delapan buah pedang, sedangkan kebanyakan mereka adalah berjalan kaki (dan yang lain kafir, yang melihat mereka) maksudnya kaum muslimin (dua kali lipat mereka) artinya jumlah mereka kaum muslimin kelihatan dua kali banyak dari jumlah mereka yang lebih kurang seribu orang, (yaitu penglihatan dengan mata kepala) artinya menurut pandangan lahir. Ini termasuk pertolongan Allah kepada kaum muslimin yang berjumlah sedikit. (Dan Allah menyokong) menguatkan (dengan pertolongan-Nya siapa yang disukai-Nya) untuk ditolong. (Sesungguhnya pada yang demikian itu) maksudnya yang disebutkan tadi (menjadi pelajaran bagi orang yang mempunyai mata hati). Kenapa kamu tidak mengambil pelajaran pula lalu kamu beriman?\qt@no{13}}%
\qt@newcmd\qurantrans@id@cccvii{%
(Dijadikan indah pada pandangan manusia kecintaan kepada syahwat) yakni segala yang disenangi serta diingini nafsu sebagai cobaan dari Allah atau tipu daya dari setan (yaitu wanita-wanita, anak-anak dan harta yang banyak) yang berlimpah dan telah berkumpul (berupa emas, perak, kuda-kuda yang tampan) atau baik (binatang ternak) yakni sapi dan kambing (dan sawah ladang) atau tanam-tanaman. (Demikian itu) yakni yang telah disebutkan tadi (merupakan kesenangan hidup dunia) di dunia manusia hidup bersenang-senang dengan hartanya, tetapi kemudian lenyap atau pergi (dan di sisi Allahlah tempat kembali yang baik) yakni surga, sehingga itulah yang seharusnya menjadi idaman dan bukan lainnya.\qt@no{14}}%
\qt@newcmd\qurantrans@id@cccviii{%
(Katakanlah) hai Muhammad kepada kaummu! ("Maukah saya sampaikan kepadamu) saya beritahukan (apa yang lebih baik dari yang demikian?") yakni yang disebutkan dari berbagai syahwat tadi; adapun pertanyaan di sini berarti pengukuhan. (Bagi orang-orang yang bertakwa) yang menjaga diri mereka dari kemusyrikan (di sisi Tuhan mereka) menjadi khabar sedangkan mubtadanya: (surga yang mengalir di bawahnya sungai-sungai, kekal mereka) artinya ditakdirkan kekal (di dalamnya) jika mereka memasukinya (dan istri-istri yang disucikan) dari haid dan lainnya yang dianggap kotor (serta keridaan) ada yang membaca ridhwaan dan ada pula rudhwaan; artinya keridaan yang banyak (dari Allah dan Allah Maha Melihat) maksudnya Maha Mengetahui (akan hamba-hamba-Nya) mereka akan dibalas menurut amalnya masing-masing.\qt@no{15}}%
\qt@newcmd\qurantrans@id@cccix{%
(Yakni orang-orang yang) menjadi na`at atau badal dari 'orang-orang' yang sebelumnya (berdoa,) ``Wahai (Tuhan kami! Sesungguhnya kami telah beriman) membenarkan-Mu dan rasul-Mu (maka ampunilah semua dosa kami dan lindungilah kami dari siksa neraka.")\qt@no{16}}%
\qt@newcmd\qurantrans@id@cccx{%
(Orang-orang yang tabah) mengikuti perintah dan menjauhi maksiat, menjadi na'at (yang benar) dalam keimanan (yang taat) kepada Allah (yang menafkahkan harta mereka) yang bersedekah (dan yang memohon ampun) kepada Allah dengan mengucapkan, ``Ya Allah! Ampunilah kami," (pada waktu sahur) artinya di akhir malam. Disebutkan di sini secara khusus, karena pada waktu itulah orang biasa lengah dan tidur nyenyak.\qt@no{17}}%
\qt@newcmd\qurantrans@id@cccxi{%
(Allah menyaksikan) artinya menjelaskan kepada hamba-hamba-Nya dengan dalil-dalil dan ayat-ayat (bahwasanya tidak ada Tuhan) yakni tidak ada yang disembah dalam wujud ini dengan benar (melainkan Dia, dan) menyaksikan pula atas yang demikian itu (para malaikat) dengan pengakuan mereka (dan orang-orang yang berilmu) dari kalangan para nabi dan orang-orang beriman, baik dengan keyakinan maupun dengan perkataan (menegakkan keadilan) dengan mengatur makhluk ciptaan-Nya. Manshub disebabkan kedudukannya sebagai hal, sedangkan yang menjadi amilnya ialah arti keseluruhan yakni hanya Allahlah yang mengatur makhluk-Nya dengan seadil-adilnya. (Tidak ada Tuhan melainkan Dia) diulangi kembali memperkokoh perkataan sebelumnya (Yang Maha Perkasa) dalam kerajaan-Nya (lagi Maha Bijaksana) dalam perbuatan dan ciptaan-Nya.\qt@no{18}}%
\qt@newcmd\qurantrans@id@cccxii{%
(Sesungguhnya agama) yang diridai (di sisi Allah) ialah agama (Islam) yakni syariat yang dibawa oleh para rasul dan dibina atas dasar ketauhidan. Menurut satu qiraat dibaca anna sebagai badal dari inna yakni badal isytimal. (Tidaklah berselisih orang-orang yang diberi kitab) yakni orang-orang Yahudi dan Nasrani dalam agama, sebagian mereka mengakui bahwa merekalah yang beragama tauhid sedangkan lainnya kafir (kecuali setelah datang kepada mereka ilmu) tentang ketauhidan disebabkan (kedengkian) dari orang-orang kafir (di antara sesama mereka, siapa yang kafir pada ayat-ayat Allah, maka sesungguhnya Allah cepat sekali perhitungan-Nya) maksudnya pembalasan-Nya.\qt@no{19}}%
\qt@newcmd\qurantrans@id@cccxiii{%
(Jika mereka menyanggah kamu) hai Muhammad dalam soal agama (maka katakanlah) kepada mereka ("Kuserahkan wajahku kepada Allah) artinya aku tunduk dan patuh kepada-Nya, aku (dan orang-orang yang mengikutiku.") wajah disebutkan secara khusus, karena kedudukannya yang mulia, maka yang lainnya lebih utama untuk berserah diri. (Dan katakanlah kepada orang-orang yang diberi Alkitab) yakni orang-orang Yahudi dan Nasrani (serta orang-orang yang tidak tahu baca tulis) yaitu orang-orang Arab musyrik ("Apakah kamu mau masuk Islam?") Maksudnya masuk Islamlah kamu! (Jika mereka masuk Islam, maka sesungguhnya mereka telah mendapat petunjuk) dari kesesatan (dan jika mereka berpaling) dari agama Islam (maka kewajiban kamu hanyalah menyampaikan) risalah yang diamanatkan kepadamu (dan Allah Maha Melihat akan hamba-hamba-Nya) lalu diberi-Nya balasan atas amal perbuatan mereka. Ayat berikut ini sebelum turunnya perintah untuk berperang:\qt@no{20}}%
\qt@newcmd\qurantrans@id@cccxiv{%
(Sesungguhnya orang-orang yang kafir akan ayat-ayat Allah dan membunuh) pada satu qiraat yuqatiluuna yang berarti memerangi (nabi-nabi tanpa alasan yang benar, dan membunuh orang-orang yang menyuruh berlaku adil di antara manusia) mereka ini ialah orang-orang Yahudi. Diriwayatkan bahwa mereka telah membunuh 43 orang nabi kemudian mereka dicegah oleh 170 orang pengikut-pengikut nabi tersebut namun akhirnya mereka pun dibunuh oleh mereka pada saat yang sama (maka gembirakanlah mereka) artinya beritahukanlah mereka (akan adanya siksa yang pedih) yang menyakitkan. Menyebutkan 'gembirakanlah' adalah sebagai penghinaan bagi mereka, dan khabar 'inna' dimasuki oleh fa, karena isimnya inna yang berupa isim maushul mirip dengan syarat.\qt@no{21}}%
\qt@newcmd\qurantrans@id@cccxv{%
(Mereka itulah orang-orang yang gugur) atau batal (amal-amalan mereka) kebaikan-kebaikan yang telah mereka lakukan, misalnya sedekah dan menghubungkan tali silaturahmi (di dunia dan di akhirat) sehingga tidak dianggap disebabkan tidak memenuhi syarat-syaratnya (dan tidaklah mereka mempunyai penolong-penolong) yang akan melindungi mereka dari azab tersebut.\qt@no{22}}%
\qt@newcmd\qurantrans@id@cccxvi{%
(Tidakkah kamu lihat) atau perhatikan (orang-orang yang diberi bagian dari Alkitab) yakni Taurat (mereka diseru) menjadi hal (kepada Kitab Allah untuk menetapkan hukum di antara mereka, kemudian sebagian di antara mereka berpaling dan mereka menolaknya) yakni tak mau menerima penetapan hukumnya. Ayat ini turun mengenai orang Yahudi: Dua orang di antara mereka berzina lalu bertahkim kepada Nabi saw., maka Nabi menjatuhkan hukuman rajam. Mereka menolak lalu diperlihatkan Taurat kepada mereka, ternyata memang tercantum di dalamnya, hingga hukuman rajam dilaksanakan. Akibatnya mereka menjadi marah.\qt@no{23}}%
\qt@newcmd\qurantrans@id@cccxvii{%
(Hal itu) yakni berpaling dan menolak (karena mereka mengatakan) disebabkan oleh ucapan mereka (Kami tidak akan disentuh oleh api neraka kecuali beberapa hari yang berbilang) hanya 40 hari, yakni selama mereka menyembah anak lembu lalu akan dihentikan terhadap mereka. (Mereka diperdayakan dalam agama mereka) berkaitan dengan firman-Nya (oleh apa yang mereka ada-adakan) berupa ucapan mereka tadi.\qt@no{24}}%
\qt@newcmd\qurantrans@id@cccxviii{%
(Maka betapakah) keadaan mereka (jika mereka Kami kumpulkan bagi suatu hari) maksudnya pada suatu hari (yang tak ada keraguan padanya) yakni hari kiamat (dan disempurnakan kepada setiap diri) baik dari golongan Ahli Kitab maupun dari lainnya, untuk menerima balasan dari (apa yang diusahakannya) dikerjakannya baik kebaikan maupun kejahatan (dan mereka) manusia itu (tidak dianiaya) dengan dikurangi kebaikan atau ditambah kejahatan. Ayat berikut ini turun tatkala Nabi saw. menjanjikan kepada umatnya akan diserahkannya kerajaan Persia dan Romawi, maka kata orang-orang munafik, ``Jauh..., mustahil...!"\qt@no{25}}%
\qt@newcmd\qurantrans@id@cccxix{%
(Katakanlah, ``Wahai Tuhan) atau ya Allah (yang mempunyai kerajaan! Engkau berikan kerajaan kepada orang yang Engkau kehendaki) di antara makhluk-makhluk-Mu (dan Engkau cabut kerajaan dari orang yang Engkau kehendaki. Engkau muliakan orang yang Engkau kehendaki) dengan memberinya kemuliaan itu (dan Engkau hinakan orang yang Engkau kehendaki) dengan mencabut darinya. (Di tangan-Mulah segala kebaikan) demikian pula segala kejahatan; artinya dalam kekuasaan-Mulah semua itu. (Sesungguhnya Engkau Maha Kuasa atas segala sesuatu.)\qt@no{26}}%
\qt@newcmd\qurantrans@id@cccxx{%
(Engkau masukkan malam ke dalam siang dan Engkau masukkan pula siang ke dalam malam) hingga bertambah panjanglah keduanya sebanyak berkurangnya dari yang lain (Engkau keluarkan yang hidup dari yang mati) misalnya manusia dari sperma dan burung dari telur (Engkau keluarkan yang mati dari yang hidup dan Engkau beri rezeki siapa yang Engkau kehendaki tanpa terhitung") artinya rezeki yang luas dan amat banyak.\qt@no{27}}%
\qt@newcmd\qurantrans@id@cccxxi{%
(Janganlah orang-orang beriman mengambil orang-orang kafir sebagai pemimpin) yang akan mengendalikan mereka (dengan meninggalkan orang-orang beriman. Barang siapa melakukan demikian) artinya mengambil mereka sebagai pemimpin (maka tidaklah termasuk dalam) agama (Allah sedikit pun kecuali jika menjaga sesuatu yang kamu takuti dari mereka) maksudnya jika ada yang kamu takuti, kamu boleh berhubungan erat dengan mereka, tetapi hanya di mulut dan bukan di hati. Ini hanyalah sebelum kuatnya agama Islam dan berlaku di suatu negeri di mana mereka merupakan golongan minoritas (dan Allah memperingatkanmu terhadap diri-Nya) maksudnya kemarahan-Nya jika kamu mengambil mereka itu sebagai pemimpin (dan hanya kepada Allah tempat kamu kembali) hingga kamu akan beroleh balasan dari-Nya.\qt@no{28}}%
\qt@newcmd\qurantrans@id@cccxxii{%
(Katakanlah) kepada mereka! ``Jika kamu menyembunyikan apa yang ada di dalam dadamu) di dalam hatimu berupa hubungan yang erat dengan mereka (atau kamu nyatakan) secara lahir (pastilah akan diketahui oleh Allah, dan) Dia (mengetahui apa-apa yang ada di langit dan apa-apa yang ada di bumi dan Allah Maha kuasa atas segala sesuatu.") di antaranya ialah menyiksa orang-orang yang mengambil orang-orang kafir sebagai pemimpin.\qt@no{29}}%
\qt@newcmd\qurantrans@id@cccxxiii{%
(Pada hari itu setiap diri akan mengetahui segala yang dilakukan)nya (berupa kebaikan akan dihadapkan ke hadapannya begitu juga segala yang dilakukan)nya (berupa kejahatan) menjadi mubtada sedangkan yang menjadi khabarnya: (ia ingin sekiranya antara ia dengan hari itu ada masa yang jauh) teramat jauh hingga ia takkan pernah sampai padanya. (Dan Allah memperingatkan kamu kepada diri-Nya) diulangi untuk memperkuat (Dan Allah Maha Penyayang terhadap hamba-hamba-Nya.) Ayat berikut turun tatkala mereka mengatakan, ``Kami tidaklah menyembah berhala itu hanyalah karena kecintaan kami kepada Allah, Kami bermaksud agar berhala-berhala itu mendekatkan kami kepada-Nya."\qt@no{30}}%
\qt@newcmd\qurantrans@id@cccxxiv{%
(Katakanlah) kepada mereka hai Muhammad! ("Jika kamu benar-benar mencintai Allah, ikutilah aku niscaya Allah mencintaimu) dengan arti bahwa Dia memberimu pahala (dan mengampuni dosa-dosamu, Allah Maha Pengampun) terhadap orang yang mengikutiku, mengenai dosa-dosanya yang telah terjadi sebelum itu (lagi Maha Penyayang") kepadanya.\qt@no{31}}%
\qt@newcmd\qurantrans@id@cccxxv{%
(Katakanlah) kepada mereka! ("Taatilah olehmu Allah dan Rasul-Nya) mengenai ketauhidan yang diperintahkan-Nya. (Jika mereka berpaling) atau menyimpang dari ketaatan (maka sesungguhnya Allah tidak menyukai orang-orang yang kafir.") Di sini terdapat penempatan zhahir di tempat mudhmar karena semestinya laa yuhibbuhum hingga kalimat itu berarti bahwa Dia akan menyiksa mereka.\qt@no{32}}%
\qt@newcmd\qurantrans@id@cccxxvi{%
(Sesungguhnya Allah telah memilih Adam dan Nuh, keluarga Ibrahim dan keluarga Imran) dengan makna diri dari yang bersangkutan (di antara penduduk alam) yakni dengan menjadikan nabi-nabi itu dari anak cucu dan keturunan mereka.\qt@no{33}}%
\qt@newcmd\qurantrans@id@cccxxvii{%
(Yakni suatu keturunan yang sebagiannya dari) turunan (yang lain.) (Dan Allah Maha Mendengar lagi Maha Mengetahui).\qt@no{34}}%
\qt@newcmd\qurantrans@id@cccxxviii{%
(Dan ingatlah ketika istri Imran) yang bernama Hanah telah lanjut usia dan rindu untuk beroleh anak, ia pun berdoa dan merasa dirinya hamil, ``Wahai (Tuhanku! Sesungguhnya aku menazarkan) untuk menjadikan (untuk-Mu kandungan yang berada di perutku ini sebagai anak yang saleh dan bebas) dari kepentingan-kepentingan dunia, semata-mata berkhidmat untuk rumah-Mu yang suci. (Karena itu terimalah dariku, sesungguhnya Engkau Maha Mendengar) akan doa (lagi Maha Mengetahui.") akan niat serta tujuan manusia. Pada waktu itu istrinya sedang mengandung dan Imran pun wafat.\qt@no{35}}%
\qt@newcmd\qurantrans@id@cccxxix{%
(Tatkala ia melahirkan anaknya) ternyata bayi itu perempuan sedangkan ia mengharapkan anak lelaki karena yang biasa dibaktikan itu hanyalah anak laki-laki (maka katanya) menyatakan penyesalan, ``Wahai (Tuhanku! Sesungguhnya aku melahirkan anak perempuan." dan Allah lebih tahu) mengetahui (apa yang dilahirkannya) firman Allah swt. yang merupakan interupsi bagi berita ini; menurut satu qiraat dengan ta baris di depan: wadha`tu ("dan anak laki-laki tidaklah) seperti yang dimintanya itu (serupa dengan anak wanita) yang diberikan Tuhannya, sedangkan maksudnya untuk membaktikannya guna berkhidmat kepada agama. Sebagaimana diketahui, anak wanita tidaklah tepat untuk keperluan itu disebabkan fisiknya lemah, auratnya, masa haid yang dialaminya dan lain-lain. (Sesungguhnya aku telah menamainya Maryam, kulindungkan dia serta anak-cucunya kepada-Mu dari setan yang terkutuk") atau terusir. Dalam sebuah hadis disebutkan, ``Tidak seorang bayi pun yang dilahirkan melainkan ia disentuh setan sewaktu ia dilahirkan itu sehingga ia menangis dengan suara keras kecuali Maryam dan putranya." (Riwayat Bukhari dan Muslim)\qt@no{36}}%
\qt@newcmd\qurantrans@id@cccxxx{%
(Maka Tuhannya menerimanya) menerima Maryam sebagai nazar dari ibunya (dengan penerimaan yang baik dan mendidiknya dengan pendidikan yang baik pula) Di samping pendidikan akhlaknya, Allah memperhatikan pula pertumbuhan jasmaninya, hingga dalam sehari besarnya bertambah seakan-akan dalam satu tahun. Ibunya membawanya kepada para pendeta penjaga Baitulmakdis, lalu katanya, ``Terimalah oleh tuan-tuan anak yang dinazarkan ini." Berlomba-lombalah mereka untuk menerimanya sebagai anak asuhan, karena ia adalah putri dari imam mereka. Kata Zakaria, ``Aku lebih berhak kepadanya, karena bibinya tinggal bersamaku." ``Tidak," kata mereka, ``sebelum kita mengadakan undian lebih dulu." Mereka yang banyaknya 29 orang itu pergi ke sungai Yordan dan melemparkan qalam atau anak panah mereka masing-masing ke dalamnya. Barang siapa yang qalamnya tidak hanyut dan timbul ke permukaan air, dialah yang lebih berhak menjadi pengasuhnya. Ternyata qalam Zakaria tidak hanyut dan timbul ke permukaan, hingga Maryam pun menjadi anak asuhannya, diambilnya dan dibuatkan untuknya sebuah bilik dalam mesjid dengan mempunyai tangga yang tak boleh dinaiki kecuali olehnya sendiri. Zakaria membawakannya makanan dan minuman serta alat-alat hiasannya, maka di musim dingin dijumpai padanya buah-buahan musim panas, dan di musim panas dijumpainya buah-buahan musim dingin, sebagaimana firman Allah swt. (dan dijadikan-Nya ia di bawah asuhan Zakaria). Menurut satu qiraat memakai tasydid sehingga berbunyi 'wakaffalahaa' sedangkan dinashabkannya 'Zakariya' itu ada yang panjang ada pula yang pendek. Yang mendatangkan buah-buahan tersebut adalah Allah swt. (Setiap Zakaria masuk untuk menemuinya di mihrab) yakni ruangan yang paling mulia di suatu mesjid (didapatinya makanan di sisinya, katanya, ``Hai Maryam! Dari mana kamu peroleh makanan ini?" Jawabnya) sedangkan ia masih kecil ("Makanan itu dari Allah) yang didatangkan-Nya bagiku dari surga." (Sesungguhnya Allah memberi rezeki kepada siapa yang disukai-Nya tanpa batas) yakni rezeki yang berlimpah yang diperoleh tanpa risiko dan jerih payah.\qt@no{37}}%
\qt@newcmd\qurantrans@id@cccxxxi{%
(Di sanalah) artinya tatkala Zakaria melihat hal itu dan mengetahui bahwa Tuhan yang berkuasa mendatangkan sesuatu bukan pada waktu yang semestinya pasti akan mampu pula mendatangkan anak keturunan dalam usia lanjut karena kaum keluarganya telah hampir musnah (maka Zakaria pun berdoa kepada Tuhannya) yakni ketika ia memasuki mihrab untuk salat di tengah malam (katanya, ``Tuhanku! Berilah aku dari sisi-Mu keturunan yang baik) maksudnya anak yang saleh (sesungguhnya Engkau Maha Mendengar) dan mengabulkan (doa.") permohonan.\qt@no{38}}%
\qt@newcmd\qurantrans@id@cccxxxii{%
(Lalu ia dipanggil oleh malaikat) yakni Jibril (ketika ia tengah berdiri mengerjakan salat di mihrab) maksudnya mesjid (bahwa) mestinya bi-anna dan menurut suatu qiraat bi-inna dengan memperkirakan iqaalat, yakni malaikat itu berkata (Allah memberimu kabar gembira) ada yang memakai tasydid dan ada pula yang tidak (dengan Yahya yang membenarkan kalimat) yang datang (dari Allah) maksudnya membenarkan Nabi Isa bahwa ia adalah roh ciptaan Allah. Dinamakan kalimat karena ia diciptakan melalui kalimat kun; artinya jadilah kamu. (Menjadi panutan) pemimpin (dan mampu menahan hawa nafsu) terutama nafsu seksual (dan seorang nabi dari keturunan orang-orang saleh.) Menurut riwayat ia tidak pernah berbuat satu kesalahan pun dan tak ada keinginan untuk melakukannya.\qt@no{39}}%
\qt@newcmd\qurantrans@id@cccxxxiii{%
(Kata Zakaria, ``Wahai Tuhanku! Betapa aku akan mendapatkan anak) atau putra (sedangkan aku sudah sangat tua) maksudnya aku telah hampir mencapai akhir usiaku, yakni 120 tahun (dan istriku pun seorang yang mandul.") usianya sudah 98 tahun. (Firman Allah,) soalnya ("Demikianlah) Allah menciptakan seorang anak laki-laki dari kamu berdua (Allah berbuat apa yang dikehendaki-Nya.") karena tidak ada suatu pun yang tidak disanggupi-Nya. Untuk membuktikan kekuasaan besar ini Zakaria diilhami-Nya pertanyaan untuk dijawab. Tatkala dirinya sudah amat rindu untuk bertemu dengan anak yang diberitakan itu.\qt@no{40}}%
\qt@newcmd\qurantrans@id@cccxxxiv{%
(Maka katanya, ``Wahai Tuhanku! Berilah aku suatu ciri.") atau tanda bahwa istriku telah hamil. (Firman-Nya, ``Tandanya ialah bahwa kamu tidak dapat berbicara dengan manusia) artinya terhalang untuk bercakap-cakap dengan mereka tetapi tidak terhalang untuk berzikir kepada Allah swt. (selama tiga hari) dan tiga malam (kecuali dengan isyarat) atau kode (dan sebutlah nama Tuhanmu sebanyak-banyaknya serta bertasbihlah) maksudnya salatlah (di waktu petang dan pagi.") di penghujung siang dan di akhir malam.\qt@no{41}}%
\qt@newcmd\qurantrans@id@cccxxxv{%
(Dan) ingatlah (ketika berkata malaikat) yakni Jibril ("Hai Maryam! Sesungguhnya Allah telah memilih dan menyucikanmu) dari sentuhan lelaki (dan mengutamakanmu atas wanita-wanita di seluruh dunia.")\qt@no{42}}%
\qt@newcmd\qurantrans@id@cccxxxvi{%
("Hai Maryam! Taatlah kepada Tuhanmu) artinya tunduklah (sujudlah dan rukuklah bersama orang-orang yang rukuk.") artinya salatlah bersama orang-orang yang salat.\qt@no{43}}%
\qt@newcmd\qurantrans@id@cccxxxvii{%
(Demikian itu) yakni apa yang telah disebutkan mengenai Zakaria dan Maryam (adalah sebagian dari berita-berita gaib) berita-berita yang kamu tidak ketahui (yang Kami wahyukan kepadamu) hai Muhammad (padahal kamu tidak hadir bersama mereka ketika mereka lemparkan anak-anak panah mereka) ke dalam air untuk mengundi (siapakah di antara mereka yang akan mengasuh) atau mendidik (Maryam. Dan kamu juga tidak hadir bersama mereka ketika mereka bersengketa) tentang pengasuhannya sehingga bagaimana kamu akan dapat mengetahui dan menceritakan kisahnya padahal kamu mengetahuinya hanyalah dengan perantaraan wahyu.\qt@no{44}}%
\qt@newcmd\qurantrans@id@cccxxxviii{%
Ingatlah! (Ketika berkata malaikat) yakni Jibril ("Hai Maryam! Sesungguhnya Allah menyampaikan berita gembira kepadamu dengan satu kalimat dari-Nya) maksudnya dengan kelahiran seorang putra yang diciptakan dengan satu kalimat (nama Almasih Isa putra Maryam) disebut namanya dengan menisbatkannya kepada dirinya untuk memperingatkan bahwa ia melahirkan tanpa bapak padahal kebiasaannya ialah menisbatkan anak-anak kepada bapak mereka (seorang yang terkemuka) atau berpengaruh (di dunia) dengan kenabian (di akhirat) dengan pemberian syafaat dan derajat yang tinggi (dan termasuk salah seorang yang dekat) kepada Allah swt.\qt@no{45}}%
\qt@newcmd\qurantrans@id@cccxxxix{%
(Dia berbicara dengan manusia sewaktu dalam buaian) sewaktu masih kecil dan belum lagi tiba saatnya untuk berkata-kata (dan ketika sudah dewasa dia termasuk salah seorang yang saleh.")\qt@no{46}}%
\qt@newcmd\qurantrans@id@cccxl{%
(Kata Maryam, ``Wahai Tuhanku! Betapa mungkin aku mempunyai anak padahal aku belum pernah disentuh oleh seorang laki-laki?") misalnya dengan perkawinan dan sebagainya. (Firman-Nya, ``Soalnya seperti itulah) yaitu menciptakan anakmu tanpa bapak (Allah menciptakan apa yang dikehendaki-Nya." Apabila Dia menghendaki menetapkan sesuatu) seperti hendak menciptakannya (maka cukuplah bagi-Nya mengatakan padanya, ``Jadilah," maka jadilah dia.) artinya terciptalah ia.\qt@no{47}}%
\qt@newcmd\qurantrans@id@cccxli{%
(Dia akan mengajarkan kepadanya) ada yang membaca dengan nun dan ada pula dengan ya (Alkitab) menulis (hikmah, Taurat dan Injil)\qt@no{48}}%
\qt@newcmd\qurantrans@id@cccxlii{%
(Dan) Kami jadikan pula sebagai (seorang rasul kepada Bani Israel) di waktu masih kecil atau sesudah balig. Jibril pun meniup saku baju Maryam sehingga ia pun hamil. Bagaimana keadaan selanjutnya akan diceritakan nanti dalam surah Maryam. Adapun Isa tatkala ia dibangkitkan Allah sebagai rasul kepada Bani Israel katanya kepada mereka, ``Sesungguhnya aku ini utusan Allah kepada kamu dan (sesungguhnya aku) (datang kepada kamu dengan membawa suatu tanda) bukti atas kebenaranku (dari Tuhan kamu) yaitu (bahwa aku) dapat (menciptakan) membuat bentuk (bagi kamu dari tanah seperti burung) kaf menjadi isim maf`ul (kemudian aku meniupnya) dhamir 'nya' kembali kepada kaf atau bentuk burung tadi (hingga ia pun menjadi seekor burung) menurut suatu qiraat thaa-iran (dengan izin Allah) dengan iradat-Nya. Maka diciptakan-Nya bagi mereka kelelawar, karena itulah yang paling sempurna kejadiannya di antara bangsa burung. Burung itu terbang, sementara mereka memperhatikannya. Setelah luput dari penglihatan mereka, kelelawar itu jatuh dan mati untuk membedakan antara perbuatan makhluk dengan hasil ciptaan Tuhan Yang Maha Pencipta dan agar diketahui bahwa kesempurnaan itu hanya ada pada ciptaan Allah. (dan Aku akan menyembuhkan orang yang buta) maksudnya yang buta semenjak ia dilahirkan (dan orang yang berpenyakit barash). Disebutkan kedua penyakit ini secara khusus karena lukanya tidak dapat disembuhkan, sedangkan Nabi Isa dibangkitkan di masa majunya ilmu kedokteran. Maka dalam satu hari beliau berhasil menyembuhkan 50 ribu penderita melalui doa, dengan syarat mereka beriman. (Bahkan aku hidupkan orang yang mati dengan izin Allah) 'Dengan kehendak Allah' diulang-ulangnya untuk melenyapkan dugaan bahwa ia mempunyai sifat ketuhanan. Maka dihidupkannyalah Azir seorang sahabatnya, anak seorang wanita tua kemudian seorang gadis kecil berumur sepuluh tahun. Mereka itu terus hidup bahkan sampai mempunyai keturunan. Kemudian dihidupkannya pula Sam bin Nuh lalu meninggal pada waktu itu juga (dan akan aku beritakan kepada kamu apa yang kamu makan dan apa yang kamu simpan di rumah-rumah kamu) padahal aku tak pernah melihatnya. Maka disampaikannyalah kepada masing-masing orang apa yang telah dimakan dan apa yang akan dimakannya nanti. (Sesungguhnya pada yang demikian itu) yakni pada peristiwa-peristiwa yang disebutkan tadi (menjadi tanda bagi kamu, jika kamu betul-betul beriman).\qt@no{49}}%
\qt@newcmd\qurantrans@id@cccxliii{%
(Dan) kedatangan aku kepada kamu (membenarkan apa yang berada di hadapan aku) yang datang sebelum aku (berupa Taurat dan untuk menghalalkan bagimu sebagian yang diharamkan atasmu) misalnya aku halalkan bangsa ikan dan burung yang tidak bertulang. Ada pula yang mengatakan dihalalkan semuanya, hingga 'sebagian' berarti 'semua' (dan aku datang kepada kamu dengan membawa tanda dari Tuhanmu) diulang-ulangnya untuk menguatkan dan membina kepercayaan di atasnya. (Maka bertobatlah kepada Allah dan taatlah kepadaku) yakni mengenai apa-apa yang aku perintahkan kepadamu, yaitu bertauhid kepada Allah serta taat akan semua perintah-Nya.\qt@no{50}}%
\qt@newcmd\qurantrans@id@cccxliv{%
(Sesungguhnya Allah Tuhanku dan Tuhan kamu, maka sembahlah Dia! Ini) yakni yang aku perintahkan kepadamu (adalah jalan yang lurus) tetapi mereka mendustakan dan tidak mau beriman kepadanya.\qt@no{51}}%
\qt@newcmd\qurantrans@id@cccxlv{%
(Maka tatkala diketahui oleh Isa kekafiran mereka) dan mereka bermaksud hendak membunuhnya (katanya, ``Siapakah yang bersedia menjadi pembela-pembela aku) penolong-penolong aku (kepada Allah.") untuk menegakkan agama-Nya? (Berkata orang-orang Hawari, ``Kamilah pembela-pembela Allah) artinya penolong-penolong agama-Nya dan mereka ini ialah teman-teman dekat Isa dan yang mula-mula beriman kepadanya. Jumlah mereka 12 orang, dan 'hawari' itu asalnya dari kata-kata 'hur' yang berarti putih bersih. Ada pula yang mengatakan bahwa mereka itu adalah orang yang pendek-pendek dan selalu memakai pakaian putih (Kami beriman kepada Allah dan saksikanlah) wahai Isa (bahwa kami orang-orang Islam).\qt@no{52}}%
\qt@newcmd\qurantrans@id@cccxlvi{%
(Wahai Tuhan kami, kami telah beriman kepada apa yang Engkau turunkan) yakni Injil (dan telah kami ikuti rasul) yaitu Isa (maka catatlah kami ke dalam golongan orang-orang yang menjadi saksi) tentang keesaan-Mu dan kebenaran rasul-Mu." Firman Allah swt.:\qt@no{53}}%
\qt@newcmd\qurantrans@id@cccxlvii{%
(Mereka mengatur tipu daya) maksudnya orang-orang kafir dari golongan Bani Israil terhadap Isa karena menunjuk orang yang akan membunuhnya secara diam-diam (dan Allah membalas tipu daya mereka) dengan jalan mengubah muka seorang seperti Isa sehingga mereka bunuh sedangkan Isa diangkat ke langit (dan Allah sebaik-baik yang membalas tipu daya.)\qt@no{54}}%
\qt@newcmd\qurantrans@id@cccxlviii{%
Ingatlah! (Ketika Allah berfirman, ``Sesungguhnya Aku akan memegangmu dan mengangkatmu kepada-Ku) yakni dari dunia tanpa mengalami kematian (dan menyucikanmu) atau menjauhkanmu (dari orang-orang yang kafir serta menjadikan orang-orang yang mengikutimu) artinya yang membenarkan kenabianmu di antara kaum muslimin dan orang-orang Nasrani (di atas orang-orang yang kafir) kepadamu, yakni orang-orang Yahudi; orang-orang yang percaya kepada kenabian Isa itu dapat mengalahkan mereka dengan berbagai hujah dan dengan mata pedang (sampai hari kiamat kemudian kepada Akulah kamu kembali lalu Kuputuskan di antara kamu apa-apa yang selalu kamu perbantahkan.) yakni tentang keagamaan.\qt@no{55}}%
\qt@newcmd\qurantrans@id@cccxlix{%
(Adapun orang-orang yang kafir maka akan Kusiksa mereka dengan siksaan berat di dunia) dengan pembunuhan, penawanan dan pembayaran upeti (dan di akhirat) dengan api neraka (dan tidaklah mereka mempunyai penolong) yang akan membela dan mempertahankan mereka dari siksa yang berat itu.\qt@no{56}}%
\qt@newcmd\qurantrans@id@cccl{%
(Adapun orang-orang yang beriman dan beramal saleh, maka Allah akan menyempurnakan) dengan memakai ya dan nun (pahala-pahala mereka dan Allah tidak menyukai orang-orang yang aniaya.") artinya Allah akan menyiksa mereka. Diriwayatkan bahwa Allah swt. mengirim kepadanya satu lapis awan yang membawanya naik. Ibunya bergantung kepadanya dan menangis, maka katanya, ``Hari kiamat akan mempertemukan kita kembali." Waktu itu ialah malam lailatulkadar dan terjadinya di Baitulmakdis dalam usianya yang ke 33 tahun. Sepeninggal ibunya masih hidup selama enam tahun. Bukhari dan Muslim meriwayatkan sebuah hadis bahwa ia akan turun nanti dekat hari kiamat dan akan melaksanakan hukum menurut syariat nabi kita. Ia akan membunuh dajal dan babi dan akan menghancurkan tiang salib dan menghapuskan upeti. Menurut hadis Muslim lamanya kembali itu ialah tujuh tahun sedangkan menurut hadis Abu Daud Ath-Thayalisi 40 tahun lalu ia wafat dan disalatkan. Ada kemungkinan bahwa yang dimaksud dengannya ialah keseluruhan lamanya tinggal di bumi baik sebelum maupun sesudah diangkat.\qt@no{57}}%
\qt@newcmd\qurantrans@id@cccli{%
(Demikianlah) perihal Isa yang Kami sebutkan itu (Kami bacakan) Kami kisahkan (kepadamu) hai Muhammad (sebagian dari tanda-tanda) menjadi hal dari dhamir yang terdapat pada natluuhu sedangkan amilnya apa yang terkandung di dalamnya berupa isyarat (dan peringatan yang penuh hikmah) yakni Alquran.\qt@no{58}}%
\qt@newcmd\qurantrans@id@ccclii{%
(Sesungguhnya perumpamaan Isa) keadaannya yang aneh atau ajaib (di sisi Allah adalah seperti Adam) seperti penciptaannya tanpa ibu dan tanpa bapak, dan ini termasuk perbandingan hal yang aneh dengan yang lebih aneh lagi dengan tujuan agar lebih dapat mematahkan hujah lawan dan lebih mantap di dalam hati (diciptakan-Nya ia) maksudnya Adam, yakni acuannya (dari tanah kemudian Allah berfirman kepadanya, ``Jadilah kamu!") seorang manusia (maka jadilah dia) artinya terciptalah ia sebagai seorang manusia. Demikian pula halnya dengan Isa, diciptakan-Nya supaya tercipta tanpa bapak, maka terciptalah dia.\qt@no{59}}%
\qt@newcmd\qurantrans@id@cccliii{%
(Itulah yang benar yang datang dari Tuhanmu) menjadi khabar bagi mubtada yang dibuang berbunyi, 'Peristiwa Isa.' (Maka janganlah kamu termasuk orang-orang yang ragu-ragu!) atau menyangsikannya.\qt@no{60}}%
\qt@newcmd\qurantrans@id@cccliv{%
(Siapa yang membantahmu) mendebatmu dari golongan Nasrani (tentang hal itu setelah datang kepadamu ilmu) dengan perintah-Nya (maka katakanlah) kepada mereka (Marilah kita panggil anak-anak kami dan anak-anak kamu, istri-istri kami dan istri-istri kamu, diri-diri kami dan diri-diri kamu) lalu kita kumpulkan mereka (kemudian mari kita bermubahalah) artinya berdoa dengan khusyuk dan dengan merendahkan diri (sambil memohon supaya kutukan Allah ditimpakan-Nya kepada orang-orang yang dusta) yaitu dengan mengatakan, ``Ya Allah, kutukilah orang yang dusta tentang peristiwa Isa." Nabi saw. telah mengajak utusan Najran untuk itu, yakni tatkala mereka membantahnya dalam hal tersebut. Jawab mereka, ``Kami akan memikirkannya dulu, kemudian akan datang kepada anda." Kata salah seorang yang berpikiran sehat di antara mereka, ``Tuan-tuan telah mengetahui kenabiannya, dan tidak suatu pun kaum yang mengadakan mubahalah dengan seorang nabi kecuali mereka akan celaka." Ditinggalkannyalah orang tadi, lalu mereka berpaling. Mereka datang lagi menemui Nabi saw. yang ketika itu sudah keluar siap bermubahalah bersama Hasan, Husein, Fatimah dan Ali. Nabi saw. berkata kepada orang-orang Nasrani Najran, ``Jika saya berdoa, aminkanlah." Tetapi ternyata pihak lawan tidak bersedia berkutuk-kutukan itu hanya minta berdamai dengan membayar upeti. Riwayat Abu Na`im dan diterima dari Ibnu Abbas, katanya, ``Seandainya orang-orang Nasrani Najran itu bersedia meneruskan mubahalah niscaya mereka akan kembali ke negerinya sedangkan harta dan keluarganya tiada lagi." Diriwayatkan pula bahwa sekiranya mereka bermubahalah niscaya akan terbakar.\qt@no{61}}%
\qt@newcmd\qurantrans@id@ccclv{%
(Sesungguhnya ini) yakni yang telah disebutkan tadi (merupakan kisah berita yang benar) yang tidak diragukan lagi. (Tiada) min merupakan tambahan (Tuhan melainkan Allah dan sesungguhnya Allah Maha Tangguh) dalam kerajaan-Nya (lagi Maha Bijaksana) dalam perbuatan-Nya.\qt@no{62}}%
\qt@newcmd\qurantrans@id@ccclvi{%
(Jika mereka berpaling) tidak mau beriman (maka sesungguhnya Allah Maha Mengetahui akan orang-orang yang berbuat kerusakan) mereka akan diberi-Nya balasan. Di sini kata-kata lahir ditempatkan pada kata-kata mudhmar.\qt@no{63}}%
\qt@newcmd\qurantrans@id@ccclvii{%
(Katakanlah, ``Hai Ahli Kitab!) yakni Yahudi dan Nasrani (Marilah kita menuju suatu kalimat yang sama) mashdar dengan makna sifat; artinya yang serupa (di antara kami dan kamu) yakni (bahwa kita tidak menyembah kecuali Allah dan tidak mempersekutukan-Nya dengan sesuatu pun juga dan bahwa sebagian kita tidak mengambil lainnya sebagai Tuhan selain daripada Allah) sebagaimana halnya kamu mengambil para rahib dan pendeta. (Jika mereka berpaling) jika menyeleweng dari ketauhidan (maka katakanlah olehmu) kepada mereka ('Saksikanlah bahwa kami ini beragama Islam.'") yang bertauhid. Ayat berikut diturunkan ketika orang-orang Yahudi mengatakan bahwa Ibrahim itu seorang Yahudi dan kita adalah penganut agamanya demikian pula orang-orang Nasrani mengklaim seperti itu.\qt@no{64}}%
\qt@newcmd\qurantrans@id@ccclviii{%
(Hai Ahli Kitab, kenapa kamu berbantah-bantahan tentang Ibrahim) dan kamu akui bahwa ia pemeluk agamamu? (Padahal Taurat dan Injil hanya diturunkan sesudahnya) bahkan dalam jarak waktu yang panjang dan setelah kedua Kitab itu diturunkan, Yahudi dan Nasrani membuat-buat hal tersebut, yakni mengenai Nabi Ibrahim. (Apakah kamu tidak berpikir?) akan kesalahan pengakuanmu itu.\qt@no{65}}%
\qt@newcmd\qurantrans@id@ccclix{%
(Begitulah) sebagai peringatan (kamu) menjadi mubtada (semuanya) sedangkan khabarnya ialah: (kalian masih berbantah-bantahan tentang hal yang kalian ketahui) tentang Nabi Musa dan Nabi Isa yang kalian akui diri kalian sebagai pemeluk agama keduanya (maka kenapa kalian berbantah-bantahan pula tentang apa yang tidak kalian ketahui) yakni perihal Nabi Ibrahim. (Allah mengetahui) keadaannya (sedangkan kalian tidak mengetahui)nya. Kemudian firman Allah membersihkan Ibrahim dari tuduhan tersebut:\qt@no{66}}%
\qt@newcmd\qurantrans@id@ccclx{%
(Ibrahim itu bukanlah seorang Yahudi dan bukan pula seorang Nasrani tetapi ia adalah seorang yang hanif) artinya menyimpang dari semua agama menuju agama yang lurus (lagi menyerahkan diri) dan bertauhid kepada Allah (dan sekali-kali bukanlah ia dari golongan musyrik).\qt@no{67}}%
\qt@newcmd\qurantrans@id@ccclxi{%
(Sesungguhnya orang-orang yang lebih dekat) artinya lebih berhak (kepada Ibrahim ialah orang-orang yang mengikutinya) di masanya (dan nabi ini) yakni Muhammad karena cocok agamanya dengan agama Ibrahim dalam kebanyakan syariatnya (serta orang-orang yang beriman) di antara umatnya. Merekalah sebenarnya yang sepatutnya mengatakan bahwa mereka mengikuti agamanya dan bukan kamu. (Dan Allah adalah wali orang-orang yang beriman) artinya pembela dan pelindung mereka. Ketika orang-orang Yahudi mengajak Muaz, Huzaifah dan Ammar masuk agama mereka turunlah ayat ini:\qt@no{68}}%
\qt@newcmd\qurantrans@id@ccclxii{%
(Segolongan Ahli Kitab hendak menyesatkan kamu padahal mereka hanya menyesatkan diri mereka sendiri) karena dosa kesesatan mereka tertimpa atas mereka, sedangkan orang-orang beriman tak mau menaati mereka (dan mereka tidak menyadari) demikian itu.\qt@no{69}}%
\qt@newcmd\qurantrans@id@ccclxiii{%
(Hai Ahli Kitab! Kenapakah kamu mengingkari ayat-ayat Allah) maksudnya kitab mereka yang memuat sifat-sifat dan ciri-ciri Muhammad (padahal kamu menyaksikan) artinya mengetahui bahwa hal itu benar.\qt@no{70}}%
\qt@newcmd\qurantrans@id@ccclxiv{%
(Hai Ahli Kitab! Kenapa kamu mencampur-adukkan yang hak dengan yang batil) yakni dengan mengubah-ubah dan memalsukan isi Kitab kalian (dan kamu sembunyikan kebenaran) ciri-ciri Muhammad itu (padahal kamu mengetahui) bahwa hal itu benar.\qt@no{71}}%
\qt@newcmd\qurantrans@id@ccclxv{%
(Segolongan dari Ahli Kitab berkata) segolongan Yahudi kepada golongan Yahudi lainnya (berimanlah kamu kepada apa yang diturunkan atas orang-orang beriman) kepada Alquran (di awal siang) atau permulaannya (dan kafirlah) kepadanya (di akhirnya, semoga mereka) yakni orang-orang yang beriman (kembali) kafir dari agama mereka, karena mereka niscaya akan mengatakan bahwa orang-orang itu mungkin keluar dari Islam setelah memasukinya sedangkan mereka ahli-ahli ilmu, mengetahui ketidakbenarannya, dan kata mereka pula:\qt@no{72}}%
\qt@newcmd\qurantrans@id@ccclxvi{%
(Dan janganlah kamu percaya) atau benarkan (kecuali orang) lam merupakan tambahan (yang mengikuti) atau menyetujui (agamamu). Firman Allah swt.: (Katakanlah) kepada mereka hai Muhammad ("Sesungguhnya petunjuk itu ialah petunjuk Allah") yang tidak lain dari agama Islam, sedangkan lainnya merupakan kesesatan dan jumlah ini mu'taridhah (bahwa) mestinya bi-an (seseorang akan diberi seperti yang diberikan kepadamu) berupa Kitab, hikmah dan keutamaan. An menjadi maf'ul bagi tu'minu sedangkan mustatsna minhu yaitu ahadun dikemudiankan dari mustatsna sehingga makna yang sebenarnya ialah: janganlah kamu sekalian percaya bahwa ada orang yang diberi demikian kecuali yang mengikuti agamamu (atau) bahwa (mereka mematahkan alasamu) orang-orang beriman akan mengalahkan kamu (di sisi Tuhanmu) pada hari kiamat karena agamamu lebih benar. Menurut suatu qiraat berbunyi a-an yakni dengan memakai hamzah yang disebut sebagai hamzah taubikh atau celaan, artinya: Apakah kamu mengakui diberinya seseorang seperti itu? Firman Allah swt.: (Sesungguhnya karunia itu di tangan Allah yang akan diberikan kepada siapa yang dikehendaki-Nya). Maka dari mana kamu peroleh berita bahwa apa yang telah diberikan kepadamu itu tidak akan diberikan kepada seorang pun juga? (Dan Allah Maha Luas) atau sangat berlimpah karunia-Nya (lagi Maha Mengetahui) siapa yang berhak untuk menerimanya.\qt@no{73}}%
\qt@newcmd\qurantrans@id@ccclxvii{%
(Allah menentukan rahmat-Nya kepada siapa yang dikehendaki-Nya dan Allah mempunyai karunia yang besar).\qt@no{74}}%
\qt@newcmd\qurantrans@id@ccclxviii{%
(Di antara Ahli Kitab ada orang yang apabila kamu percayakan kepadanya harta yang banyak) atau berharga (maka dikembalikan kepadamu) disebabkan sifat amanatnya. Misalnya Abdullah bin Salam yang mendapat amanat atau titipan dari seorang laki-laki sebanyak 1200 ukiah emas, maka dipenuhinya amanat itu dengan sebaik-baiknya. (Dan di antara mereka ada pula yang jika kamu percayai dengan satu dinar, maka tidak dikembalikannya) karena sifat ikhlasnya (kecuali jika kamu selalu menagihnya) tidak meninggalkannya. Apabila kamu meninggalkannya, maka titipan tadi tidak diakuinya, misalnya Kaab bin Asyraf yang diberi amanat oleh seorang Quraisy sebanyak satu dinar, maka tidak diakuinya. (Yang demikian itu) artinya sikap tak mau membayar itu (bahwa mereka berkata) artinya disebabkan perkataan mereka ("Tidak ada terhadap kami mengenai orang-orang buta huruf) maksudnya orang Arab (tuntutan) atau dosa." Sebabnya karena mereka menghalalkan menganiaya orang-orang yang berlainan agama dengan mereka dan pengakuan itu mereka nisbatkan pula kepada Allah swt. Firman Allah: ("Mereka berkata dusta terhadap Allah") maksudnya dalam menisbatkan penghalalan itu kepada-Nya (padahal mereka mengetahui) bahwa mereka berdusta.\qt@no{75}}%
\qt@newcmd\qurantrans@id@ccclxix{%
(Bukan demikian) tetapi terhadap mereka tetap ada tuntutan (barang siapa yang menepati janjinya) baik yang dibuatnya dengan Allah atau yang dititahkan Allah menepatinya, berupa memenuhi amanat dan lain-lain (serta ia bertakwa) kepada Allah dengan mengerjakan taat dan meninggalkan maksiat (maka sesungguhnya Allah menyukai orang-orang yang bertakwa.) Di sini ada penempatan zahir di tempat yang mudhmar, yang berarti ``Allah mengasihi mereka" maksudnya memberi mereka pahala.\qt@no{76}}%
\qt@newcmd\qurantrans@id@ccclxx{%
Ayat ini diturunkan kepada orang-orang Yahudi setelah mereka mengganti sifat-sifat Nabi dan janji-janji Allah atas mereka di dalam Taurat dan Kitab yang sebelumnya. Dan mereka mengganti pula hukum orang yang bersumpah dusta dalam hal tuntutan atas jual beli barang dagangan. (Sesungguhnya orang-orang yang membeli) menukar (janji Allah) untuk beriman kepada Nabi dan menepati amanat (dan sumpah-sumpah mereka) terhadap Allah dengan berhohong (dengan harga yang sedikit) berupa harta dunia (mereka itu tidak beroleh bagian) pahala (di akhirat dan Allah tidak akan berbicara dengan mereka) disebabkan murka kepada mereka (dan tidak akan melihat kepada mereka) artinya tidak akan mengasihi mereka (pada hari kiamat dan tidak akan membersihkan) menyucikan mereka (dan bagi mereka siksa yang pedih) yang menyakitkan.\qt@no{77}}%
\qt@newcmd\qurantrans@id@ccclxxi{%
(Sesungguhnya di antara mereka) maksudnya Ahli kitab (ada segolongan) misalnya Kaab bin Asyraf (yang memutar-mutar lidah mereka membaca Alkitab) artinya membelokkannya dari bacaan yang diturunkan kepada yang telah mereka ubah, seperti ciri-ciri Nabi saw. dsb. (supaya kamu menyangkanya) maksudnya yang telah diubah itu (sebagian dari Alkitab) yang diturunkan Allah swt. (padahal hal itu bukan dari Alkitab dan mereka mengatakan, ``Hal itu datang dari sisi Allah, padahal hal itu bukan dari sisi Allah, dan mereka berkata dusta terhadap Allah sedangkan mereka mengetahui") bahwa mereka memang berdusta. Tatkala orang-orang Nasrani Najran mengatakan bahwa Isa menyuruh mereka untuk menjadikannya sebagai Tuhan dan tatkala sebagian kaum muslimin meminta agar dibolehkan bersujud kepada Nabi Muhammad saw. turunlah ayat:\qt@no{78}}%
\qt@newcmd\qurantrans@id@ccclxxii{%
(Tidaklah pantas) atau layak (bagi seorang manusia yang diberi Allah Alkitab dan hikmah) artinya pengertian terhadap syariat (serta kenabian lalu katanya kepada manusia, ``Hendaklah kamu menjadi hamba-hambaku dan bukan hamba-hamba Allah!" Tetapi) seharusnya ia berkata ("Hendaklah kamu menjadi rabbani) artinya ulama-ulama yang beramal saleh, dinisbatkan kepada rab dengan tambahan alif dan nun sebagai penghormatan (disebabkan kamu mengajarkan) dibaca pakai tasydid dan tanpa tasydid (Alkitab dan disebabkan kamu selalu mempelajarinya.") Karena itu bila menghendaki faedahnya hendaklah kamu mengamalkannya.\qt@no{79}}%
\qt@newcmd\qurantrans@id@ccclxxiii{%
(Dan tidak pantas ia menyuruhmu) dengan baris di depan sebagai isti`naf sedangkan fa`ilnya ialah Allah. Tetapi ada pula yang membaca dengan baris di atas karena diathafkan kepada yaquula yang fa`ilnya ialah manusia (menjadikan malaikat dan nabi-nabi itu sebagai Tuhan) sebagaimana halnya orang-orang Shabiin mengambil malaikat, orang-orang Yahudi Uzeir dan orang-orang Nasrani Isa menjadi Tuhan mereka. (Patutkah ia menyuruhmu berbuat kekafiran setelah tadinya kamu menganut Islam?) hal ini tidaklah pantas baginya.\qt@no{80}}%
\qt@newcmd\qurantrans@id@ccclxxiv{%
(Dan) ingatlah (tatkala) ketika (Allah mengambil ikrar nabi-nabi) atau janji mereka ("Sungguh apa saja) lam baris di atas sebagai ibtida dan untuk taukid dengan makna sumpah yang terdapat dalam pengambilan ikrar. Dan baris di bawah yang berkaitan dengan mengambil ikrar sedangkan maa isim maushul yang berarti: bagi yang (yang Kuberikan kepadamu) menurut satu qiraat 'Kami berikan padamu' (berupa Kitab dan hikmah lalu datang kepadamu seorang rasul yang membenarkan apa yang ada padamu) berupa kitab dan hikmah itu dan dia adalah Nabi Muhammad saw. (bahwa kamu sungguh-sungguh akan beriman kepadanya serta akan membelanya) sebagai jawaban daripada sumpah tadi, yakni jika kamu menjumpai mereka dalam hal itu. (Firman-Nya) Allah swt. kepada mereka (Apakah kamu berikrar) atas hal itu (dan menerima perjanjian terhadap yang demikian itu?") (Kata mereka, ``Kami berikrar," dan Allah berfirman, ``Maka saksikanlah) atas dirimu dan pengikut-pengikutmu tentang hal itu (dan Aku turut menjadi saksi pula bersama kamu") baik terhadap dirimu maupun terhadap mereka.\qt@no{81}}%
\qt@newcmd\qurantrans@id@ccclxxv{%
(Barang siapa yang berpaling setelah demikian) setelah perjanjian tadi (maka merekalah orang-orang yang fasik).\qt@no{82}}%
\qt@newcmd\qurantrans@id@ccclxxvi{%
(Apakah mereka hendak mencari agama yang lain dari agama Allah) dengan memakai 'ya' artinya orang-orang yang berpaling tadi dan ada pula yang memakai 'ta' sehingga berarti kamu (padahal kepada-Nya tunduk segala apa yang di langit dan di bumi, baik suka) tanpa menaruh keberatan (maupun terpaksa) yakni dengan memakai sarana yang membuat mereka tunduk kepada-Nya (dan kepada-Nya mereka dikembalikan) dengan memakai ta dan ya, sedangkan hamzah atau kata tanya pada awal ayat sebagai sanggahan.\qt@no{83}}%
\qt@newcmd\qurantrans@id@ccclxxvii{%
(Katakanlah) kepada mereka hai Muhammad ("Kami beriman kepada Allah dan kepada apa yang diturunkan kepada kami dan yang diturunkan kepada Ibrahim, Ismail, Ishak, Yakub dan anak-anaknya, dan apa yang diberikan kepada Musa, Isa dan para nabi dari Tuhan mereka. Tidaklah kami beda-bedakan seorang pun di antara mereka) dalam membenarkan dan mendustakan (dan kami berserah diri kepada-Nya") tulus ikhlas dalam menunaikan ibadah kepada-Nya. Ayat berikut diturunkan mengenai orang-orang yang murtad dan menggabungkan diri dengan orang-orang kafir:\qt@no{84}}%
\qt@newcmd\qurantrans@id@ccclxxviii{%
(Barang siapa mencari agama selain agama Islam, maka tidaklah akan diterima dan di akhirat ia termasuk orang-orang yang merugi) karena tempat tinggalnya ialah neraka di mana ia akan menetap di sana untuk selama-lamanya.\qt@no{85}}%
\qt@newcmd\qurantrans@id@ccclxxix{%
(Bagaimana Allah akan menunjuki suatu kaum yang kafir setelah mereka beriman dan mereka menyaksikan) artinya Allah tidak akan menunjuki mereka padahal mereka telah bersaksi (bahwa Muhammad itu benar-benar rasul dan) sungguh (telah datang pula kepada mereka keterangan-keterangan) bukti-bukti yang nyata atas kebenaran Nabi saw. (dan Allah tidak menunjuki orang-orang yang aniaya) orang-orang yang kafir.\qt@no{86}}%
\qt@newcmd\qurantrans@id@ccclxxx{%
(Mereka itu balasannya ialah laknat Allah yang ditimpakan atas mereka begitu pula laknat malaikat dan seluruh umat manusia.)\qt@no{87}}%
\qt@newcmd\qurantrans@id@ccclxxxi{%
(Kekal mereka di dalamnya) di dalam laknat atau di dalam neraka itu (tidak diringankan siksa dari mereka dan tidak pula mereka diberi tangguh.)\qt@no{88}}%
\qt@newcmd\qurantrans@id@ccclxxxii{%
(Kecuali orang-orang yang bertobat sesudah itu dan mengadakan perbaikan) terhadap amal perbuatan mereka (karena sesungguhnya Allah Maha Pengampun) terhadap mereka (lagi Maha Penyayang). Ayat berikut turun mengenai orang-orang Yahudi.\qt@no{89}}%
\qt@newcmd\qurantrans@id@ccclxxxiii{%
(Sesungguhnya orang-orang yang kafir) terhadap Isa (setelah mereka beriman) kepada Musa (kemudian bertambah kekafiran mereka) terhadap Muhammad (tidaklah akan diterima tobat mereka) jika mereka dalam keadaan sekarat atau meninggal di dalam kekafiran (dan merekalah orang-orang yang sesat.)\qt@no{90}}%
\qt@newcmd\qurantrans@id@ccclxxxiv{%
(Sesungguhnya orang-orang kafir dan mati dalam kekafiran tidaklah akan diterima dari seorang pun di antara mereka sepenuh bumi) maksudnya suatu jumlah yang banyaknya seisi bumi ini (berupa emas yang digunakannya sebagai penebus diri mereka) fa dimasukkan kepada khabar inna karena serupanya lafal alladziina dengan syarat dan sebagai pemberitahuan tentang sebab tidak diterimanya tebusannya terhadap orang yang mati dalam kekafiran itu. (Bagi mereka disediakan siksa yang pedih) atau menyakitkan (dan sekali-kali mereka tidak punya pembela) yang akan membela dan melindungi mereka dari siksaan itu.\qt@no{91}}%
\qt@newcmd\qurantrans@id@ccclxxxv{%
(Kamu sekali-kali tidak sampai kepada kebaktian) artinya pahalanya yaitu surga (sebelum kamu menafkahkan) menyedekahkan (sebagian dari apa yang kamu cintai) berupa harta bendamu (dan apa yang kamu nafkahkan dari sesuatu maka sesungguhnya Allah mengetahuinya) dan akan membalasnya. Ketika orang-orang Yahudi mengatakan kepada Nabi saw., ``Anda mengakui diri Anda dalam agama Ibrahim padahal ia tidak memakan daging unta dan susunya," turunlah ayat:\qt@no{92}}%
\qt@newcmd\qurantrans@id@ccclxxxvi{%
(Semua makanan halal bagi Bani Israel kecuali makanan yang diharamkan oleh Israel) atau Yakub (atas dirinya) yaitu unta yang ditimpa penyakit pada urat nadinya. Ia bernazar jika hewan itu sembuh tidak akan dimakannya, maka haramlah hukumnya bagi mereka (sebelum Taurat diturunkan) hal ini terjadi sesudah Ibrahim sedangkan pada masanya sendiri tidaklah haram sebagaimana yang telah diakuinya. (Katakanlah) kepada mereka ("Ambillah Taurat lalu bacalah) agar nyata benar atau tidaknya ucapanmu itu (jika kamu orang-orang yang benar") dalam masalah tersebut. Mendengar itu mereka pun kebingungan dan tak pernah mengemukakan Taurat. Maka Allah swt. berfirman:\qt@no{93}}%
\qt@newcmd\qurantrans@id@ccclxxxvii{%
(Maka barang siapa yang mengada-adakan kedustaan terhadap Allah sesudah itu) setelah terbukti bahwa diharamkan unta itu ialah dari pihak Yakub bukan di masa Ibrahim (mereka orang-orang yang aniaya) artinya melampaui batas kebenaran hingga jatuh dalam kebatilan.\qt@no{94}}%
\qt@newcmd\qurantrans@id@ccclxxxviii{%
(Katakanlah, ``Benarlah Allah.") dalam soal ini sebagaimana juga dalam segala soal yang diberikan-Nya (maka ikutilah olehmu agama Ibrahim) yang saya anut (yang lurus) yang meninggalkan semua agama untuk memeluk agama Islam (dan tidaklah dia termasuk golongan musyrik). Ketika mereka mengatakan bahwa kiblat mereka lebih awal dari kiblat kaum Muslimin turun pula ayat:\qt@no{95}}%
\qt@newcmd\qurantrans@id@ccclxxxix{%
(Sesungguhnya rumah yang mula-mula dibangun) untuk tempat ibadah (bagi manusia) di muka bumi (ialah yang terdapat di Bakkah) dengan ba sebagai nama lain dari Mekah. Dinamakan demikian karena Kakbah mematahkan leher orang-orang durhaka lagi aniaya. Baitullah ini dibina oleh malaikat sebelum diciptakannya Adam dan setelah itu baru dibangun pula Masjidilaksa dan jarak di antara keduanya 40 tahun sebagai tersebut dalam kedua hadis sahih. Pada sebuah hadis lain disebutkan pula bahwa Kakbahlah yang mula-mula muncul di permukaan air ketika langit dan bumi ini diciptakan sebagai buih yang putih, maka dihamparkanlah tanah dari bawahnya (diberi berkah) hal dari alladzii tadi (dan menjadi petunjuk bagi seluruh alam) karena ia merupakan kiblat mereka.\qt@no{96}}%
\qt@newcmd\qurantrans@id@cccxc{%
(Padanya terdapat tanda-tanda yang nyata) di antaranya (makam Ibrahim) yakni batu tempat berpijaknya Ibrahim sewaktu mendirikan Baitullah itu. Kedua telapak kakinya meninggalkan bekas padanya sampai sekarang dan tetap sepanjang zaman walaupun pemerintahan yang berkuasa sudah silih berganti. Di antaranya pula dilipatgandakannya pahala kebaikan bagi yang salat di dalamnya dan burung tidak dapat terbang di atas Kakbah (dan barang siapa memasukinya menjadi amanlah dia) artinya bebas dari ancaman pembunuhan, keaniayaan dan lain-lain. (Mengerjakan haji di Baitullah itu menjadi kewajiban manusia terhadap Allah) Ada yang membaca hajja dengan makna menyengaja. Lalu sebagai badal dari 'manusia' ialah (yakni orang-orang yang sanggup mengadakan perjalanan kepadanya) yang oleh Nabi saw. ditafsirkan dengan adanya perbekalan dan kendaraan, menurut riwayat Hakim dan lain-lain. (Barang siapa yang kafir) terhadap Allah atau terhadap kewajiban haji (maka sesungguhnya Allah Maha Kaya terhadap seluruh alam) artinya tidak memerlukan manusia, jin dan malaikat serta amal ibadah mereka.\qt@no{97}}%
\qt@newcmd\qurantrans@id@cccxci{%
(Katakanlah, ``Hai Ahli Kitab! Kenapa kamu ingkar akan ayat-ayat Allah) yakni Alquran (padahal Allah menyaksikan apa yang kamu kerjakan.") hingga akan memberinya balasan?\qt@no{98}}%
\qt@newcmd\qurantrans@id@cccxcii{%
(Katakanlah, ``Hai Ahli Kitab! Kenapa kamu menghalang-halangi dari jalan Allah) dari agama-Nya (orang-orang yang beriman) melalui pendustaan kalian terhadap Nabi Muhammad saw. dan menyembunyikan sifat-sifatnya (kamu mengharap) menghendaki agama itu (menjadi bengkok) sebenarnya iwaja itu kata benda tetapi berarti sebagai kata sifat artinya bengkok atau menyimpang dari kebenaran (padahal kamu menyaksikan) mengetahui bahwa agama yang lurus lagi diridai seperti yang tercantum dalam kitab sucimu ialah agama Islam. (Dan Allah sekali-kali tidak lalai dari apa yang kamu kerjakan) berupa kekafiran dan mendustakan. Dia sengaja menangguhkan kamu sampai saatmu nanti buat menerima ganjaran dan balasan-Nya. Ayat berikut diturunkan tatkala beberapa orang Yahudi lewat pada sebagian orang-orang Aus dan Khazraj. Mereka berang melihat kerukunan mereka lalu mereka bangkit-bangkitkan fitnah yang terjadi di antara mereka di masa jahiliah sehingga mereka pun bersengketa bahkan hampir bunuh-bunuhan.\qt@no{99}}%
\qt@newcmd\qurantrans@id@cccxciii{%
(Hai orang-orang beriman! Jika kamu mengikuti sebagian dari orang-orang yang diberi Alkitab niscaya mereka akan mengembalikan kamu menjadi kafir setelah kamu beriman.")\qt@no{100}}%
\qt@newcmd\qurantrans@id@cccxciv{%
(Betapa kamu menjadi kafir) pertanyaan sebagai celaan dan membangkitkan keheranan (padahal ayat-ayat Allah dibacakan kepadamu dan rasul-Nya pun berada di tengah-tengah kamu. Barang siapa yang berpegang teguh) atau mengikuti (agama Allah, maka sesungguhnya ia telah dibimbing ke jalan yang lurus.)\qt@no{101}}%
\qt@newcmd\qurantrans@id@cccxcv{%
(Hai orang-orang yang beriman, bertakwalah kamu kepada Allah sebenar-benar takwa) yaitu dengan menaati dan bukan mendurhakai, mensyukuri dan bukan mengingkari karunia-Nya dan dengan mengingat serta tidak melupakan-Nya. Kata para sahabat, ``Wahai Rasulullah! Siapakah yang sanggup melaksanakan ini?" Maka ayat ini pun dinasakh dengan firman-Nya, ``Bertakwalah kamu kepada Allah menurut kemampuanmu." (dan janganlah sekali-kali kamu mati melainkan dalam keadaan beragama Islam.)\qt@no{102}}%
\qt@newcmd\qurantrans@id@cccxcvi{%
(Berpegang teguhlah kamu dengan tali Allah) maksudnya agama-Nya (kesemuanya dan janganlah kamu berpecah-belah) setelah menganut Islam (serta ingatlah nikmat Allah) yakni karunia-Nya (kepadamu) hai golongan Aus dan Khazraj (ketika kamu) yakni sebelum Islam (bermusuh-musuhan, maka dirukunkan-Nya) artinya dihimpun-Nya (di antara hatimu) melalui Islam (lalu jadilah kamu berkat nikmat-Nya bersaudara) dalam agama dan pemerintahan (padahal kamu telah berada dipinggir jurang neraka) sehingga tak ada lagi pilihan lain bagi kamu kecuali terjerumus ke dalamnya dan mati dalam kekafiran (lalu diselamatkan-Nya kamu daripadanya) melalui iman kalian. (Demikianlah) sebagaimana telah disebutkan-Nya tadi (Allah menjelaskan ayat-ayat-Nya supaya kamu beroleh petunjuk).\qt@no{103}}%
\qt@newcmd\qurantrans@id@cccxcvii{%
(Hendaklah ada di antara kamu satu golongan yang menyeru kepada kebaikan) ajaran Islam (dan menyuruh kepada yang makruf dan melarang dari yang mungkar. Merekalah) yakni orang-orang yang menyeru, yang menyuruh dan yang melarang tadi (orang-orang yang beruntung) atau berbahagia. 'Min' di sini untuk menunjukkan 'sebagian' karena apa yang diperintahkan itu merupakan fardu kifayah yang tidak mesti bagi seluruh umat dan tidak pula layak bagi setiap orang, misalnya orang yang bodoh.\qt@no{104}}%
\qt@newcmd\qurantrans@id@cccxcviii{%
(Dan janganlah kamu seperti orang-orang yang berpecah-belah) dalam agama mereka (dan berselisih) padanya (sesudah datang kepada mereka keterangan yang jelas) mereka itu ialah orang-orang Yahudi dan Nasrani. (Merekalah orang-orang yang mendapat siksa yang berat).\qt@no{105}}%
\qt@newcmd\qurantrans@id@cccxcix{%
(Ingatlah suatu hari di mana wajah-wajah ada yang menjadi putih berseri dan ada pula yang hitam legam) maksudnya pada hari kiamat. (Adapun orang-orang yang wajahnya menjadi hitam) yakni orang-orang kafir, maka mereka dilemparkan ke dalam neraka dan dikatakan kepada mereka sebagai celaan ("Kenapa kamu kafir setelah beriman?") yaitu sewaktu pengambilan ikrar dulu. ("Maka rasailah siksa disebabkan kekafiranmu itu.")\qt@no{106}}%
\qt@newcmd\qurantrans@id@cd{%
(Adapun orang-orang yang wajahnya menjadi putih berseri) yakni orang-orang yang beriman (mereka berada dalam rahmat Allah) dalam surga-Nya (mereka kekal di dalamnya).\qt@no{107}}%
\qt@newcmd\qurantrans@id@cdi{%
(Itulah) maksudnya ayat-ayat tadi (ayat-ayat Allah. Kami bacakan kepadamu) hai Muhammad (dengan benar, dan tiadalah Allah menghendaki keaniayaan bagi seluruh alam) misalnya dengan menjatuhkan hukuman pada mereka tanpa dosa.\qt@no{108}}%
\qt@newcmd\qurantrans@id@cdii{%
(Kepunyaan Allahlah segala yang di langit dan di bumi) baik sebagai milik maupun sebagai makhluk dan hamba (dan kepada Allah kembalinya segala urusan).\qt@no{109}}%
\qt@newcmd\qurantrans@id@cdiii{%
(Adalah kamu) hai umat Muhammad dalam ilmu Allah swt. (sebaik-baik umat yang dikeluarkan) yang ditampilkan (buat manusia, menyuruh kepada yang makruf dan melarang dari yang mungkar serta beriman kepada Allah. Sekiranya Ahli Kitab beriman, adalah ia) yakni keimanan itu (lebih baik bagi mereka. Di antara mereka ada yang beriman) misalnya Abdullah bin Salam r.a. dan sahabat-sahabatnya (tetapi kebanyakan mereka orang-orang yang fasik) kafir.\qt@no{110}}%
\qt@newcmd\qurantrans@id@cdiv{%
(Mereka sekali-kali tidak akan dapat memberi mudarat kepadamu) maksudnya sedikit pun juga orang-orang Yahudi tidak akan dapat memberi mudarat terhadap kaum Muslimin (kecuali gangguan saja) yakni gangguan lisan seperti makian dan ancaman (dan jika mereka berperang dengan kamu maka mereka akan berbalik melarikan diri) karena menderita kekalahan (kemudian mereka tidak mendapat pertolongan) untuk menghadapi kamu sebaliknya kamulah yang akan mendapat pertolongan untuk menghadapi mereka.\qt@no{111}}%
\qt@newcmd\qurantrans@id@cdv{%
(Ditimpakan atas mereka kehinaan di mana pun mereka berada) sehingga bagi mereka tak ada kemuliaan dan keamanan (kecuali) dengan dua hal: (dengan tali dari Allah dan tali dari manusia) yang beriman, yang merupakan janji dari mereka kepada Ahli Kitab bahwa mereka akan diberi keamanan dengan imbalan pembayaran upeti, maka tak ada jaminan bagi mereka selain dengan itu (dan mereka kembali mendapat kemurkaan dari Allah dan ditimpakan atas mereka kerendahan. Demikian itu bahwa mereka) artinya disebabkan karena mereka (kafir akan ayat-ayat Allah dan membunuh para nabi tanpa alasan yang benar. Demikian itu) sebagai pengukuhan (disebabkan mereka durhaka) akan perintah Allah (dan mereka melanggar batas) artinya melampaui yang halal hingga jatuh kepada yang haram.\qt@no{112}}%
\qt@newcmd\qurantrans@id@cdvi{%
(Mereka itu tidaklah) maksudnya Ahli-ahli Kitab (sama) atau serupa. (Di antara Ahli Kitab ada golongan yang bersikap lurus) jujur dan teguh berdiri di atas kebenaran seperti Abdullah bin Salam r.a. dan sahabat-sahabatnya (mereka membaca ayat-ayat Allah di saat-saat malam hari sedangkan mereka bersujud) maksudnya salat, menjadi hal.\qt@no{113}}%
\qt@newcmd\qurantrans@id@cdvii{%
(Mereka beriman kepada Allah dan hari yang akhir, menyuruh kepada yang makruf dan melarang dari yang mungkar dan berlomba-lomba mengerjakan kebaikan. Mereka itulah) yakni yang dilukiskan tadi (termasuk orang-orang yang saleh). Di antara mereka ada pula yang tidak seperti demikian dan tidak termasuk orang-orang yang saleh.\qt@no{114}}%
\qt@newcmd\qurantrans@id@cdviii{%
(Apa-apa yang mereka kerjakan) yang dikerjakan oleh umat yang lurus tadi, dengan ya atau yang kamu kerjakan, wahai umat dengan ta (berupa kebaikan, maka tidaklah akan tertutup) menurut dua versi tadi artinya tidaklah akan terhalang untuk mendapatkan pahalanya tetapi akan tetap diberi balasannya. (Dan Allah Maha Mengetahui akan orang-orang yang bertakwa.)\qt@no{115}}%
\qt@newcmd\qurantrans@id@cdix{%
(Sesungguhnya orang-orang yang kafir tidaklah akan dapat menolak) menghindarkan (diri mereka atau harta benda maupun anak-anak laki-laki mereka dari Allah) dari siksa-Nya (sedikit pun juga) dikhususkan-Nya menyebutkan keduanya karena biasanya manusia membela dirinya adakalanya dengan tebusan harta dan adakalanya dengan bantuan anak-anaknya. (Dan mereka adalah penghuni neraka, kekal mereka di dalamnya.)\qt@no{116}}%
\qt@newcmd\qurantrans@id@cdx{%
(Perumpamaan) atau sifat (harta yang mereka nafkahkan) maksudnya orang-orang kafir (dalam kehidupan dunia) yakni dalam memusuhi Nabi bahkan bersedekah dan sebagainya (seperti angin yang mengandung udara yang sangat dingin yang menimpa tanaman suatu kaum yang menganiaya diri mereka sendiri) dengan kekafiran dan berbuat maksiat (lalu dirusakkannya) tanaman itu hingga mereka tidak memperoleh manfaat darinya. Maka demikianlah pula nafkah-nafkah mereka tadi habis tidak membawa manfaat apa-apa. (Allah tidaklah menganiaya mereka) dengan lenyapnya harta benda itu tadi (tetapi merekalah yang menganiaya diri mereka sendiri) dengan kekafiran yang menyebabkan musnahnya harta mereka.\qt@no{117}}%
\qt@newcmd\qurantrans@id@cdxi{%
(Hai orang-orang yang beriman! Janganlah kamu ambil sebagai orang-orang kepercayaan) maksudnya sebagai teman-teman akrab tempat kamu membukakan rahasia kamu (orang-orang yang di luar kalanganmu) maksudnya orang lain, misalnya orang Yahudi, Nasrani dan munafik (tidak henti-hentinya mereka menimbulkan kesusahan bagimu) khabaala dijadikan manshub karena dihilangkannya huruf khafadh dan arti kalimat ialah mereka tidak putus-putusnya hendak membinasakan kamu (mereka ingin) atau mencita-citakan (supaya kamu menderita) artinya berada dalam puncak kesusahan. (Telah nyata) tampak (kebencian) permusuhan terhadapmu (dari mulut-mulut mereka) dengan menjelekkan kamu dan membukakan rahasia kamu kepada orang-orang musyrik (dan apa yang disembunyikan oleh hati mereka) berupa permusuhan (lebih besar lagi. Sungguh telah Kami jelaskan kepada kamu tanda-tanda) permusuhan mereka itu (jika kamu memikirkan)nya. Maka janganlah kamu ambil mereka itu sebagai orang-orang kepercayaan.\qt@no{118}}%
\qt@newcmd\qurantrans@id@cdxii{%
(Begitulah) sebagai peringatan (kamu) hai (orang-orang) yang beriman (kalian mencintai mereka) karena akrabnya persaudaraannya dengan kamu (tetapi mereka tidak mencintai kamu) karena perbedaan agamamu dengan agama mereka (dan kamu beriman kepada kitab-kitab kesemuanya) artinya kepada semua kitab, tetapi mereka tidak beriman kepada Kitabmu. (Jika mereka menjumpai kamu, mereka berkata, ``Kami beriman," dan apabila mereka telah berada dalam kalangan mereka sendiri, mereka menggigit ujung-ujung jari mereka disebabkan teramat marah kepadamu) melihat kerukunan kamu. Kemarahan diibaratkan dengan menggigit ujung-ujung jari, walaupun tidak sebenarnya terjadi. (Katakanlah, ``Matilah kamu dengan kemarahanmu itu!") artinya tetaplah dalam keadaan demikian sampai kamu mati, karena tidak akan pernah kamu melihat hal-hal yang akan menyenangkan hatimu! (Sesungguhnya Allah mengetahui apa yang terdapat di dalam dada) maksudnya segala isi hati termasuk apa yang mereka sembunyikan.\qt@no{119}}%
\qt@newcmd\qurantrans@id@cdxiii{%
(Jika kamu disentuh) ditimpa (oleh kebaikan) atau nikmat, seperti kemenangan atau harta rampasan (mereka merasa kecewa) atau berdukacita (sebaliknya jika kamu ditimpa bencana) seperti kekalahan dan kekeringan (mereka gembira karenanya) jumlah syarat yang kedua berhubungan dengan syarat yang sebelumnya, sedangkan di antara keduanya interupsi atau kalimat sela. Makna ayat, bahwa mereka mati-matian dalam memusuhi kamu, maka kenapa kamu mempercayai mereka, jauhilah mereka itu! (Jika kamu bersabar) terhadap gangguan mereka (dan bertakwa) kepada Allah hingga tidak mempercayai mereka dan sebagainya (maka tidaklah akan mendatangkan kemudaratan) bacaannya 'laa yadhirkum' atau 'laa yadhurrukum' (tipu daya mereka sedikit pun. Sesungguhnya Allah terhadap apa yang mereka lakukan) dengan 'ya' dan 'ta' (meliputi) mengetahui dan akan memberikan balasan\qt@no{120}}%
\qt@newcmd\qurantrans@id@cdxiv{%
(Dan) ingatlah hai Muhammad (ketika kamu berangkat di pagi hari dari keluargamu) yakni dari Madinah (untuk menempatkan orang-orang beriman pada beberapa tempat) atau markas di mana mereka bertahan (untuk berperang. Dan Allah Maha Mendengar) akan ucapanmu (lagi Maha Mengetahui) peri keadaanmu. Peristiwa ini terjadi pada waktu perang Uhud. Nabi saw. keluar dengan membawa 1000 atau 950 orang tentara sedangkan kaum musyrikin berjumlah sebanyak 3000 orang. Nabi saw. menduduki posisinya di lereng bukit Uhud pada hari Sabtu tanggal 7 Syawal tahun ketiga Hijriah. Punggung beliau dan punggung tentaranya menghadap ke arah bukit Uhud lalu mengatur barisan mereka dan menempatkan pasukan panah yang dipimpin oleh Abdullah bin Jubair di puncak bukit seraya bersabda, ``Hujani mereka dengan anak panah dari sini agar mereka tidak menyerang dari belakang dan jangan tinggalkan tempat ini biar sekali pun tidak kalah atau pun menang!"\qt@no{121}}%
\qt@newcmd\qurantrans@id@cdxv{%
(Ketika) badal dari idz yang sebelumnya (dua golongan daripadamu bermaksud) yakni Bani Salamah dan Bani Haritsah yang merupakan dua sayap tentara (hendak mundur) karena takut berperang dan mengikuti langkah Abdullah bin Ubai pemimpin golongan munafik yang menarik diri dari peperangan bersama sahabat-sahabatnya, katanya, ``Apa gunanya kita membunuh diri dan anak-anak kita?" Lalu katanya kepada Abu Jabir As-Salami yang memintanya agar membela Nabi dan diri mereka sendiri, ``Sekiranya kami pandai berperang, tentulah kami akan turut bersama kamu," maka Allah pun meneguhkan pendirian kedua golongan tadi hingga mereka tidak jadi menarik diri dari medan pertempuran (sedangkan Allah menjadi penolong bagi kedua golongan itu dan karena itu hendaklah kepada Allah orang-orang beriman bertawakal) hanya percaya kepada-Nya dan tidak kepada selain-Nya. Dan ketika mereka berhasil mengalahkan musuh, maka untuk mengingatkan mereka akan nikmat Allah turunlah ayat:\qt@no{122}}%
\qt@newcmd\qurantrans@id@cdxvi{%
(Sungguh, Allah telah menolong kamu di Badar) suatu tempat di antara Mekah dan Madinah (padahal kamu orang-orang yang lemah) disebabkan bilangan dan persenjataan yang sedikit (maka bertakwalah kepada Allah, supaya kamu menjadi orang-orang yang bersyukur) akan nikmat karunia-Nya\qt@no{123}}%
\qt@newcmd\qurantrans@id@cdxvii{%
(Ketika) zharfu zaman bagi datangnya pertolongan (kamu mengatakan kepada orang-orang beriman) menjanjikan demi ketenteraman hati mereka ("Tidakkah cukup bagi kamu jika kamu dibantu Tuhanmu dengan tiga ribu malaikat yang diturunkan.") ada yang membaca munzaliina dan ada pula munazzaliina.\qt@no{124}}%
\qt@newcmd\qurantrans@id@cdxviii{%
(Ya) itu cukup bagi kamu. Dalam surah Al-Anfal disebutkan seribu yakni sebagai bantuan pertama kemudian menjadi tiga ribu lalu lima ribu sebagaimana firman Allah swt.: (Jika kamu bersabar) dalam menghadapi musuh (dan bertakwa) kepada Allah dalam menghindari pertikaian (dan mereka datang) yakni orang-orang musyrikin (pada ketika itu juga) buat menyerang kamu (maka Tuhanmu akan membantu kamu dengan lima ribu malaikat yang memakai tanda) ada yang membaca musawwimiina dan ada pula musawwamiina keduanya berarti memakai tanda. Sungguh mereka itu telah menunjukkan kesabaran sehingga Allah pun menepati janji-Nya yaitu dengan ikut sertanya pasukan malaikat di atas kuda-kuda belang dengan memakai serban berwarna kuning atau putih yang mereka lepaskan teruntai di atas bahu.\qt@no{125}}%
\qt@newcmd\qurantrans@id@cdxix{%
(Allah tidaklah menjadikannya) maksudnya pengiriman bala bantuan itu (melainkan sebagai berita gembira bagi kamu) dengan kemenangan (dan agar tenteram hatimu karenanya) jadi janganlah kamu cemas melihat banyaknya musuh dan sedikitnya bilanganmu. (Dan tidaklah kemenangan itu kecuali dari sisi Allah Yang Maha Tangguh lagi Maha Bijaksana) yang memberikannya kepada siapa yang dikehendaki-Nya dan bukan kepada yang banyak jumlah tentaranya.\qt@no{126}}%
\qt@newcmd\qurantrans@id@cdxx{%
(Yaitu untuk memotong) berkaitan dengan kemenanganmu itu dan maksudnya ialah membinasakan (segolongan orang-orang yang kafir) dengan terbunuh dan tertawan (atau untuk menjadikan mereka hina dina) disebabkan kekalahan (sehingga mereka kembali dengan tangan hampa) tidak memperoleh apa yang mereka harapkan. Ayat berikut ini turun ketika gigi depan Nabi saw. patah dan wajahnya berlumuran darah di waktu perang Uhud, sampai beliau bersabda, ``Bagaimana suatu kaum akan beroleh keberuntungan, jika mereka berani melumuri wajah Nabi mereka dengan darah!"\qt@no{127}}%
\qt@newcmd\qurantrans@id@cdxxi{%
(Tak ada sedikit pun hakmu untuk campur tangan dalam urusan mereka itu) tetapi semua itu urusan Allah, maka hendaklah kamu bersabar (apakah) artinya hingga (Allah menerima tobat mereka) dengan masuknya mereka ke dalam agama Islam (atau menyiksa mereka, karena sesungguhnya mereka orang-orang yang aniaya) disebabkan kekafiran mereka.\qt@no{128}}%
\qt@newcmd\qurantrans@id@cdxxii{%
(Kepunyaan Allahlah apa yang ada di langit dan apa yang ada di bumi) baik sebagai milik maupun sebagai makhluk atau hamba-Nya (diampuni-Nya siapa yang dikehendaki-Nya) untuk diampuni (dan disiksa-Nya siapa yang dikehendaki) untuk disiksa (dan Allah Maha Pengampun) kekasih-kekasih-Nya (lagi Maha Penyayang) terhadap orang-orang yang taat kepada-Nya.\qt@no{129}}%
\qt@newcmd\qurantrans@id@cdxxiii{%
(Hai orang-orang yang beriman, janganlah kamu memakan riba dengan berlipat ganda) bacaannya ada yang memakai alif dan ada pula yang tidak, maksudnya ialah memberikan tambahan pada harta yang diutang yang ditangguhkan pembayarannya dari tempo yang telah ditetapkan (dan bertakwalah kamu kepada Allah) dengan menghindarinya (supaya kamu beroleh keberuntungan) atau hasil yang gemilang.\qt@no{130}}%
\qt@newcmd\qurantrans@id@cdxxiv{%
(Jagalah dirimu dari api neraka yang disediakan bagi orang-orang yang kafir) janganlah kamu sampai disiksa di dalamnya\qt@no{131}}%
\qt@newcmd\qurantrans@id@cdxxv{%
(Taatilah olehmu Allah dan Rasul, supaya kamu beroleh rahmat).\qt@no{132}}%
\qt@newcmd\qurantrans@id@cdxxvi{%
(Dan bersegeralah kamu) dengan atau tanpa wau (kepada keampunan dari Tuhanmu dan kepada surga yang luasnya seluas langit dan bumi) artinya seluas langit dan bumi bila keduanya disambung; sedangkan '`ardh' artinya ialah luas (yang disediakan bagi orang-orang yang bertakwa) kepada Allah dengan mengerjakan taat dan meninggalkan maksiat.\qt@no{133}}%
\qt@newcmd\qurantrans@id@cdxxvii{%
(Yaitu orang yang mengeluarkan nafkah) dalam menaati Allah (baik di waktu lapang maupun di waktu sempit dan yang dapat menahan amarahnya) hingga tidak melampiaskannya walaupun sebenarnya ia sanggup (dan yang memaafkan kesalahan manusia) yang melakukan keaniayaan kepadanya tanpa membalasnya (dan Allah menyukai orang-orang yang berbuat kebaikan) seperti pekerjaan-pekerjaan yang disebutkan itu dan akan memberi mereka balasan.\qt@no{134}}%
\qt@newcmd\qurantrans@id@cdxxviii{%
(Dan juga orang-orang yang apabila mereka berbuat kekejian) artinya dosa yang keji seperti perzinahan (atau menganiaya diri mereka sendiri) artinya melakukan dosa yang lebih ringan dari itu misalnya mencium (mereka ingat kepada Allah) maksudnya ingat akan ancaman-Nya (lalu memohon ampun terhadap dosa-dosa mereka dan siapakah) artinya tidak ada (yang dapat mengampuni dosa itu melainkan Allah. Dan mereka tidak meneruskan perbuatan mereka itu) menghentikannya sama sekali (sedangkan mereka mengetahui) bahwa apa yang mereka lakukan itu adalah perbuatan maksiat adanya.\qt@no{135}}%
\qt@newcmd\qurantrans@id@cdxxix{%
(Mereka itu balasannya ialah ampunan dari Tuhan mereka dan surga yang di bawahnya mengalir anak-anak sungai, kekal mereka di dalamnya) menjadi hal artinya ditakdirkan kekal jika mereka beruntung memasukinya (dan itulah sebaik-baiknya pahala bagi orang yang beramal) artinya pahala bagi orang-orang yang mengerjakan perbuatan terpuji ini.\qt@no{136}}%
\qt@newcmd\qurantrans@id@cdxxx{%
Ayat ini diturunkan berkenaan dengan kekalahan dalam perang Uhud (Sesungguhnya telah berlalu sebelum kamu sunah-sunah) artinya cara-cara Allah menghadapi orang-orang kafir yaitu menangguhkan kebinasaan mereka, lalu menghancurkan mereka secara tiba-tiba (maka berjalanlah kamu) hai orang-orang beriman (di muka bumi, dan lihatlah betapa akibat orang-orang yang mendustakan) para rasul, artinya kesudahan nasib mereka berupa kebinasaan. Maka janganlah kamu bersedih hati atas kemenangan mereka, karena Aku hanyalah menangguhkan kebinasaan mereka itu hingga pada saatnya nanti.\qt@no{137}}%
\qt@newcmd\qurantrans@id@cdxxxi{%
(Ini) maksudnya Alquran ini (menjadi penerang bagi manusia) artinya semuanya (dan petunjuk) dari kesesatan (serta pelajaran bagi orang-orang yang bertakwa) di antara mereka.\qt@no{138}}%
\qt@newcmd\qurantrans@id@cdxxxii{%
(Janganlah kamu merasa lemah) dalam memerangi orang-orang kafir (dan jangan pula bersedih hati) atas sesuatu musibah yang menimpa dirimu (padahal kamu orang-orang yang tertinggi) hingga mampu mengalahkan mereka (jika kamu orang-orang yang beriman) maksudnya benar-benar beriman sedangkan yang menjadi jawab syarat ialah apa yang ditunjukkan oleh makna kalimat-kalimat yang sebelumnya.\qt@no{139}}%
\qt@newcmd\qurantrans@id@cdxxxiii{%
(Jika kamu ditimpa) seperti pada perang Uhud (oleh luka-luka) qarh atau qurh, artinya ialah penderitaan disebabkan luka dan sebagainya (maka sesungguhnya kaum kafir itu pun telah ditimpa pula oleh luka yang serupa) di waktu perang Badar. (Dan hari-hari itu Kami pergilirkan) silih berganti (di antara manusia) misalnya sekarang masa kejayaan bagi satu golongan dan esok bagi golongan lainnya agar mereka sama-sama menarik pelajaran (dan supaya Allah mengetahui) secara lahiriah (orang-orang yang beriman) secara ikhlas dari yang tidak (dan supaya sebagian kamu dijadikan-Nya syuhada) artinya dimuliakan-Nya dengan mati syahid. (Dan Allah tidak menyukai orang-orang yang aniaya) yakni orang-orang kafir yang akan menerima hukuman daripada-Nya. Seumpama mereka diberi-Nya nikmat, itu hanyalah untuk mendekatkan mereka kepada siksa.\qt@no{140}}%
\qt@newcmd\qurantrans@id@cdxxxiv{%
(Agar Allah menyucikan orang-orang yang beriman) artinya membersihkan mereka dari dosa dengan musibah yang menimpa diri mereka itu (serta membinasakan orang-orang yang kafir).\qt@no{141}}%
\qt@newcmd\qurantrans@id@cdxxxv{%
(Atau) artinya apakah (kamu mengira bahwa kamu akan masuk surga padahal belumlah diketahui oleh Allah orang-orang yang berjihad di antara kamu) yakni secara lahirnya (dan belum diketahui-Nya orang-orang yang sabar) dalam menghadapi kesusahan.\qt@no{142}}%
\qt@newcmd\qurantrans@id@cdxxxvi{%
(Sesungguhnya dulu kamu mengharapkan) asalnya tatamannauna lalu salah satu dari ta-nya dibuang (kematian sebelum kamu menemuinya) artinya kamu pernah mengatakan dulu, ``Wahai kiranya kami dapat menemui suatu hari seperti hari perang Badar agar kami menemui mati syahid sebagaimana dialami oleh kawan-kawan kami dulu." (Sekarang kamu telah melihatnya) maksudnya yang menjadi sebab dan asal usulnya yaitu peperangan itu sendiri (sedangkan kamu menyaksikannya) dapat merenungkannya bagaimana seharusnya lalu kenapa kamu dapat dikalahkan? Dan mengenai kekalahan itu turun ayat bahwa sebabnya ialah tatkala disebarkan berita bahwa Nabi saw. telah terbunuh sementara orang-orang munafik meneriakkan, ``Karena ia telah terbunuh maka kembalilah kalian kepada agama kalian!"\qt@no{143}}%
\qt@newcmd\qurantrans@id@cdxxxvii{%
(Muhammad itu tidak lain hanyalah seorang rasul yang sebelumnya telah berlalu beberapa orang rasul. Apakah jika ia wafat atau terbunuh) seperti lainnya (kamu berbalik ke belakang) maksudnya kembali menjadi kafir. Kalimat akhir merupakan pertanyaan yang berarti sanggahan, artinya bukankah ia bukan sembahan kenapa kamu kembali? (Barang siapa yang berbalik ke belakang, murtad, maka tidaklah ia memberi mudarat kepada Allah sedikit pun) sebaliknya hanya memberi mudarat kepada dirinya sendiri (dan Allah akan memberi balasan kepada orang-orang yang bersyukur) terhadap nikmat-karunia-Nya.\qt@no{144}}%
\qt@newcmd\qurantrans@id@cdxxxviii{%
(Setiap diri tidaklah akan mati kecuali dengan izin Allah) artinya dengan kada daripada-Nya (sebagai ketentuan) mashdar artinya ketentuan yang telah ditetapkan oleh Allah (yang telah ditetapkan waktunya) hingga tidak dapat dimajukan atau diundurkan. Lalu kenapa kamu menderita kekalahan, padahal kekalahan itu tidak dapat menolak kematian dan ketabahan takkan dapat mengakhiri kehidupan. (Barang siapa yang menghendaki) dengan amalannya (pahala dunia) artinya balasannya (Kami berikan itu kepadanya) artinya bagiannya di dunia tetapi di akhirat ia tidak mendapat apa-apa. (Dan barang siapa menghendaki pahala akhirat Kami berikan pula kepadanya) artinya pahalanya (dan Kami akan memberi balasan kepada orang-orang yang bersyukur).\qt@no{145}}%
\qt@newcmd\qurantrans@id@cdxxxix{%
(Dan berapa banyaknya) 'ka-ayyin' sama artinya dengan 'kam' (nabi-nabi yang berperang) menurut satu qiraat 'qutila' yang berarti 'yang dibunuh'. Pelakunya ialah dhamir yang kembali kepada nabi (bersama mereka) menjadi khabar sedangkan mubtadanya ialah: (pengikut-pengikutnya yang amat banyak) yakni yang bertakwa (maka mereka tidak menjadi lemah) atau merasa takut (karena hal-hal yang menimpa mereka di jalan Allah) seperti mendapat luka dan terbunuhnya nabi-nabi dan para sahabat mereka (dan tidak menjadi lelah) menghadapi perjuangan (dan tidak pula menyerah) atau tunduk kepada musuh-musuh sebagaimana kamu lakukan ketika disiarkan orang berita bahwa Nabimu telah gugur. (Allah menyukai orang-orang yang sabar) dalam menerima bala hingga Allah berkenan memberikan imbalan kepadanya.\qt@no{146}}%
\qt@newcmd\qurantrans@id@cdxl{%
(Tak ada ucapan mereka) yakni ketika Nabi mereka dibunuh yang mereka terima dengan penuh kesabaran dan ketabahan itu (melainkan dengan berdoa, ``Wahai Tuhan kami! Ampunilah dosa kami dan keterlaluan kami) artinya tindakan kami yang melanggar batas (dalam urusan kami) sebagai pengakuan bahwa musibah yang menimpa mereka itu ialah karena jeleknya perbuatan mereka yang berarti menghancurkan diri mereka sendiri (dan tetapkanlah hati kami) dengan kekuatan menghadapi perjuangan (serta tolonglah kami terhadap kaum yang kafir.")\qt@no{147}}%
\qt@newcmd\qurantrans@id@cdxli{%
(Maka Allah pun memberi mereka pahala di dunia) berupa kemenangan dan harta rampasan (dan pahala yang baik di akhirat) maksudnya surga. Pahala yang baik ialah anugerah yang melebihi dari selayaknya (dan Allah menyukai orang-orang yang berbuat kebaikan).\qt@no{148}}%
\qt@newcmd\qurantrans@id@cdxlii{%
(Hai orang-orang yang beriman, jika kamu menaati orang-orang yang kafir) mengenai apa yang mereka perintahkan kepada kamu (tentulah mereka akan mengembalikan kamu ke belakang) maksudnya kepada kekafiran (hingga jadilah kamu orang-orang yang merugi).\qt@no{149}}%
\qt@newcmd\qurantrans@id@cdxliii{%
(Tetapi Allahlah yang menjadi pelindungmu) pembelamu (dan Dialah sebaik-baik pembela) maka patuhlah kamu kepada-Nya dan bukan kepada selain-Nya.\qt@no{150}}%
\qt@newcmd\qurantrans@id@cdxliv{%
(Akan Kami masukkan ke dalam hati orang-orang kafir itu rasa takut) dibaca ru`b atau ru`ub. Setelah berangkat dari Uhud itu sebenarnya mereka bermaksud hendak kembali untuk membasmi kaum Muslimin tetapi tiba-tiba merasa ciut dan tidak jadi kembali (disebabkan mereka mempersekutukan Allah dengan sesuatu yang tidak diberi-Nya wewenang) sebagai alasan dalam penyembahan terhadap berhala (tempat tinggal mereka ialah neraka dan itulah seburuk-buruk tempat tinggal orang-orang yang aniaya) lagi kafir itu.\qt@no{151}}%
\qt@newcmd\qurantrans@id@cdxlv{%
(Dan sesungguhnya Allah telah memenuhi janji-Nya) kepadamu dengan memberikan kemenangan (ketika kamu membunuh mereka dengan izin-Nya) atau dengan kehendak-Nya (hingga saat kamu gagal) atau takut menghadapi peperangan (dan berselisih dalam urusan itu) yakni mengenai perintah Nabi saw. agar tetap bertahan di lereng bukit untuk memanah musuh di mana sebagian kamu mengatakan, ``Mari kita turun bukankah teman-teman kita sudah beroleh kemenangan?" Sedangkan sebagian lagi berkata, ``Tidak, kita tidak boleh melanggar perintah Nabi saw." (dan kamu mendurhakai) perintahnya, lalu kamu tinggalkan markas demi mengharapkan harta rampasan (setelah diperlihatkan-Nya kepadamu) maksudnya oleh Allah (apa yang kamu sukai) yakni kemenangan. Mengenai jawab idzaa ditunjukkan oleh kalimat yang sebelumnya, artinya kamu terhalang beroleh kemenangan dari-Nya. (Di antaramu ada yang menghendaki dunia) lalu ditinggalkannya markas guna merebut harta rampasan (dan di antaramu ada yang menghendaki akhirat) maka ia tetap bertahan di tempat sampai ia gugur seperti Abdullah bin Jubair dan sahabat-sahabatnya. (Kemudian Allah memalingkan kamu) dihubungkan kepada jawaban idzaa yang diperkirakan berbunyi, ``Terpukul mundur karena menderita kekalahan" (dari mereka) maksudnya orang-orang kafir (untuk mencoba kamu) artinya menguji mana-mana yang ikhlas di antaramu dari yang bukan. (Sesungguhnya Allah telah memaafkan kamu) atas kesalahan yang telah kamu lakukan (dan Allah mempunyai karunia terhadap orang-orang yang beriman) dengan memaafkan dan mengampuni mereka.\qt@no{152}}%
\qt@newcmd\qurantrans@id@cdxlvi{%
(Ingatlah ketika kamu melarikan diri) dalam peperangan itu (dan tidak menoleh kepada seorang pun, sedang Rasul memanggil kamu dari belakangmu) seraya bersabda, ``Mari ke sini hai hamba-hamba Allah, marilah datang kepadaku!" (Karena itu Allah menimpakan padamu kesedihan di atas kesedihan) yang kamu timpakan kepada Rasulullah dengan melanggar perintahnya. Ada pula yang mengatakan 'ba' itu berarti '`alaa' hingga maknanya ialah 'berlipat ganda', yaitu kesedihan di balik kesedihan karena luputnya harta rampasan (supaya kamu tidak) berkaitan dengan Allah 'memaafkan' atau menimpakan pada kalian (berduka cita terhadap apa yang luput dari kamu) yakni harta rampasan (begitu pula terhadap apa yang telah menimpamu) berupa pembunuhannya dan kekalahan (Allah Maha Mengetahui apa yang kamu kerjakan.)\qt@no{153}}%
\qt@newcmd\qurantrans@id@cdxlvii{%
(Kemudian Allah menurunkan kepada kamu setelah kesedihan itu keamanan berupa kantuk) menjadi badal (yang meliputi) ada yang membaca dengan ya dan ada pula dengan ta (segolongan dari kamu) yakni orang-orang beriman; mereka tertidur lelap di balik tameng sehingga pedang-pedang pun tergelincir dan jatuh ke sisi mereka (sedangkan segolongan lagi telah dicemaskan oleh diri mereka sendiri) maksudnya mereka merasa cemas memikirkan nasib mereka hingga mereka tak ada kemauan selain menyelamatkan diri tanpa mempedulikan Nabi saw. dan para sahabatnya. Mereka tidak dapat tidur dan mereka adalah orang-orang munafik. (Mereka menyangka yang tidak benar terhadap Allah) maksudnya seperti sangkaan (jahiliah) yang berkeyakinan bahwa Nabi itu benar-benar telah terbunuh atau kalau tidak, maka ia takkan dapat dikalahkan. (Kata mereka, ``Apakah) maksudnya tak ada (bagi kita terhadap urusan ini) maksudnya mengenai kemenangan yang telah Kami janjikan itu (dari) merupakan tambahan (sesuatu."). (Katakanlah) kepada mereka ("Sesungguhnya urusan ini seluruhnya) manshub sebagai taukid dapat pula marfu` sebagai mubtada sedangkan khabarnya ialah: (bagi Allah.") maksudnya ketentuan berada di tangan-Nya. Ia berbuat apa yang dikehendaki-Nya (Mereka menyembunyikan dalam hati mereka apa yang tidak mereka terangkan kepadamu, maka mereka mengatakan) ini menjadi keterangan bagi 'apa' yang sebelumnya ("Sekiranya bagi kami terhadap urusan ini ada sesuatu tidaklah kami terbunuh di sini) maksudnya jika kita mempunyai campur tangan dalam urusan ini kita dapat saja tidak keluar sehingga tidak terbunuh tetapi apa daya kita karena kita ini dipaksa keluar." (Katakanlah) kepada mereka ("Sekiranya kamu berada di rumahmu) sedangkan di antaramu ada orang yang telah ditetapkan Allah akan menemui ajalnya (niscaya orang-orang yang telah ditakdirkan akan terbunuh itu akan keluar juga ke tempat pembunuhan mereka.") sehingga mereka akan mati terbunuh, dan tidak akan tertolong oleh ikhtiar atau usaha mereka itu karena kada Allah tetap berlaku tanpa sesuatu pun dapat menolaknya. (Dan) hal itu dilakukan-Nya (agar Allah menguji apa yang terdapat dalam dadamu) dalam hatimu berupa keikhlasan atau kemunafikan (dan untuk membersihkan isi hatimu. Dan Allah Maha Mengetahui akan sisi hati) semua itu tak ada yang tersembunyi bagi-Nya tetapi maksud-Nya agar dengan ujian itu tampaklah pula bagi manusia keikhlasan dan kemunafikan di antara kalian.\qt@no{154}}%
\qt@newcmd\qurantrans@id@cdxlviii{%
(Sesungguhnya orang-orang yang berpaling di antara kamu) dari peperangan (di saat bertemunya dua pasukan) yaitu pasukan kaum Muslimin dan pasukan orang-orang kafir di Uhud. Yang dituju ialah pasukan Muslimin itu kecuali dua belas orang (sesungguhnya mereka digelincirkan oleh setan) dengan waswas atau tipu dayanya (disebabkan sebagian apa yang mereka perbuat) berupa dosa yaitu melanggar perintah Nabi saw. (dan sesungguhnya Allah telah memberi maaf kepada mereka. Sesungguhnya Allah Maha Pengampun) terhadap orang-orang mukmin (lagi Maha Penyantun) sehingga menangguhkan siksa dari orang-orang durhaka.\qt@no{155}}%
\qt@newcmd\qurantrans@id@cdxlix{%
(Hai orang-orang yang beriman! Janganlah kamu seperti orang-orang kafir) maksudnya orang-orang munafik (yang mengatakan kepada kawan-kawan mereka) mengenai keadaan mereka (apabila mereka bepergian di muka bumi) lalu mati (atau mereka berperang) lalu terbunuh ("Sekiranya mereka berada bersama kita tidaklah mereka akan mati dan tidak pula terbunuh.") maksudnya janganlah kamu berkata seperti demikian. (Allah menjadikan demikian itu) sebagai akibat dari ucapan mereka tadi (suatu penyesalan dalam hati mereka. Allah menghidupkan dan mematikan) hingga tinggalnya seseorang di rumahnya sama sekali tidak menghalangi kematiannya (dan terhadap apa yang kamu kerjakan) dengan memakai ta atau ya (Maha Melihat) maka kelak Dia akan membalaskannya kepada kalian.\qt@no{156}}%
\qt@newcmd\qurantrans@id@cdl{%
(Sungguh sekiranya) lam menunjukkan sumpah (kamu dibunuh di jalan Allah) maksudnya dalam berjihad (atau meninggal) dibaca muttum atau mittum berasal dari maata-yamuutu; artinya didatangi oleh kematian di dalam berjihad (maka ampunan) yang kamu peroleh (dari Allah) terhadap dosa-dosamu (dan rahmat) daripada-Nya bagi kamu atas demikian itu. Lam serta kalimat yang dimasukinya menjadi jawab qasam di samping menjadi mubtada yang khabarnya ialah: (benar-benar lebih baik dari apa yang mereka kumpulkan) dari harta dunia; memakai ya atau ta.\qt@no{157}}%
\qt@newcmd\qurantrans@id@cdli{%
(Sungguh sekiranya) lam berarti sumpah (kamu meninggal) dibaca muttum atau mittum (atau terbunuh) dalam peperangan atau lainnya (maka hanya kepada Allahlah) dan bukan kepada selain-Nya (kamu akan dihimpun) di akhirat di mana amal perbuatanmu akan dibalas-Nya.\qt@no{158}}%
\qt@newcmd\qurantrans@id@cdlii{%
(Maka berkat) ma merupakan tambahan (rahmat dari Allah kamu menjadi lemah lembut) hai Muhammad (kepada mereka) sehingga kamu hadapi pelanggaran mereka terhadap perintahmu itu dengan sikap lunak (dan sekiranya kamu bersikap keras) artinya akhlakmu jelek tidak terpuji (dan berhati kasar) hingga kamu mengambil tindakan keras terhadap mereka (tentulah mereka akan menjauhkan diri dari sekelilingmu, maka maafkanlah mereka) atas kesalahan yang mereka perbuat (dan mintakanlah ampunan bagi mereka) atas kesalahan-kesalahan itu hingga Kuampuni (serta berundinglah dengan mereka) artinya mintalah pendapat atau buah pikiran mereka (mengenai urusan itu) yakni urusan peperangan dan lain-lain demi mengambil hati mereka, dan agar umat meniru sunah dan jejak langkahmu, maka Rasulullah saw. banyak bermusyawarah dengan mereka. (Kemudian apabila kamu telah berketetapan hati) untuk melaksanakan apa yang kamu kehendaki setelah bermusyawarah itu (maka bertawakallah kepada Allah) artinya percayalah kepada-Nya. (Sesungguhnya Allah menyukai orang-orang yang bertawakal) kepada-Nya.\qt@no{159}}%
\qt@newcmd\qurantrans@id@cdliii{%
(Jika Allah menolong kamu) terhadap musuhmu seperti di perang Badar (maka tak ada orang yang akan mengalahkan kamu, sebaliknya jika Dia membiarkan kamu) tanpa memberikan pertolongan seperti waktu perang Uhud (maka siapakah lagi yang dapat menolongmu setelah itu) artinya setelah kekalahan itu, maksudnya tak ada lagi. (Hanya kepada Allahlah) bukan kepada lain-Nya (orang-orang beriman itu harus bertawakal). Ayat berikut ini diturunkan ketika hilangnya sehelai permadani merah di waktu perang Uhud lalu sebagian orang mengatakan barangkali Nabilah yang mengambilnya:\qt@no{160}}%
\qt@newcmd\qurantrans@id@cdliv{%
(Tidaklah mungkin) atau patut (bagi seorang Nabi itu akan berkhianat dalam urusan harta rampasan perang) maka janganlah kamu menyangka hal yang demikian itu! Menurut satu qiraat dibaca 'yughalla' yang berarti dinisbatkan kepada pengkhianatan. (Barang siapa yang berkhianat dalam urusan harta rampasan perang itu, maka ia akan datang pada hari kiamat membawa barang yang dikhianatkannya itu) dengan memikulnya di atas pundaknya (kemudian setiap diri akan diberi balasan) baik yang berkhianat maupun yang tidak berkhianat (atas apa yang dikerjakannya sedangkan mereka tidaklah dianiaya) sedikit pun juga.\qt@no{161}}%
\qt@newcmd\qurantrans@id@cdlv{%
(Apakah orang yang mengikuti keridaan Allah) lalu ia taat dan tak berkhianat dalam soal rampasan perang (akan sama dengan orang yang kembali dengan kemurkaan dari Allah) karena perbuatan maksiat dan kecurangannya? (Tempatnya ialah neraka Jahanam dan itulah seburuk-buruk tempat kembali) jawabannya tentu saja tidak sama.\qt@no{162}}%
\qt@newcmd\qurantrans@id@cdlvi{%
(Mereka itu bertingkat-tingkat) maksudnya mempunyai tingkat masing-masing (di sisi Allah) artinya mempunyai kedudukan yang berbeda-beda. Maka orang yang mengikuti keridaan-Nya akan beroleh pahala atau surga sedangkan yang membawa amarah murka-Nya akan mendapat siksa atau neraka (dan Allah Maha Melihat apa yang mereka kerjakan) hingga akan mendapat balasan daripada-Nya.\qt@no{163}}%
\qt@newcmd\qurantrans@id@cdlvii{%
(Sesungguhnya Allah telah memberi karunia kepada orang-orang beriman ketika Dia mengirim kepada mereka seorang rasul dari kalangan mereka sendiri) maksudnya seorang Arab seperti mereka untuk mengawasi dan memberi pengertian, jadi bukan dari kalangan malaikat dan tidak pula dari bangsa asing (yang membacakan kepada mereka ayat-ayat-Nya) yakni Alquran (dan menyucikan mereka) membersihkan mereka dari dosa (serta mengajarkan kepada mereka Alkitab) yakni Alquran (dan hikmah) yakni sunah (dan sesungguhnya mereka) ditakhfifkan dari wainnahum (adalah sebelumnya) yakni sebelum kebangkitannya (benar-benar dalam kesesatan yang nyata) atau jelas.\qt@no{164}}%
\qt@newcmd\qurantrans@id@cdlviii{%
(Mengapa ketika kamu ditimpa musibah) yaitu di Uhud dengan gugurnya 70 orang di antara kamu (padahal kamu telah menimpakan kekalahan dua kali lipat kepada musuh-musuhmu) yakni di Badar dengan membunuh 70 orang dan menawan 70 di antara mereka (kamu berkata) dengan keheran-heranan ("Dari mana datangnya ini?") maksudnya kekalahan ini padahal kita adalah orang-orang muslim dan Rasulullah berada bersama kita. Kalimat terakhir merupakan pertanyaan yang berarti sanggahan. (Katakanlah) kepada mereka ("Itu dari dirimu sendiri) karena kamu meninggalkan markas sehingga mengalami kegagalan. (Sesungguhnya Allah Maha Kuasa atas segala sesuatu.") dan daripada-Nyalah datang kemenangan atau terhalangnya kemenangan itu; dan kamu mendapat balasan daripada-Nya disebabkan pelanggaran terhadap perintah Rasul-Nya.\qt@no{165}}%
\qt@newcmd\qurantrans@id@cdlix{%
(Apa yang menimpa kamu di hari bertemunya dua pasukan) yakni di Uhud (maka adalah dengan izin Allah) atau kehendak-Nya (dan supaya diketahui-Nya) secara nyata (orang-orang yang beriman) yang benar-benar beriman.\qt@no{166}}%
\qt@newcmd\qurantrans@id@cdlx{%
(Dan supaya diketahui-Nya orang-orang yang munafik dan) orang-orang yang (dikatakan kepada mereka) ketika mereka berpaling dari peperangan, yaitu Abdullah bin Ubai dan anak buahnya ("Marilah kita berperang di jalan Allah) dengan musuh-musuh-Nya (atau usirlah mereka") dari kami dengan memperbanyak anggotamu jika kamu tidak hendak berperang! (Jawab mereka, ``Sekiranya kami tahu) maksudnya pandai (berperang, tentulah kami akan mengikuti kamu") firman Allah mendustakan mereka, ("Pada hari itu mereka lebih dekat kepada kekafiran daripada keimanan) dengan sikap mereka yang terang-terangan mengkhianati kaum Muslimin sedangkan sebelumnya mereka pada lahirnya lebih dekat kepada keimanan. (Mereka mengatakan dengan mulut mereka apa yang tidak terdapat di dalam hati mereka) karena seandainya mereka pandai berperang, mereka juga tidak akan mengikutimu! (Dan Allah lebih mengetahui apa-apa yang mereka sembunyikan") berupa kemunafikan.\qt@no{167}}%
\qt@newcmd\qurantrans@id@cdlxi{%
(Yakni orang-orang) menjadi badal atau sifat bagi 'orang-orang' yang sebelumnya (yang mengatakan kepada saudara-saudara mereka) seagama (dan) sesungguhnya (mereka tidak ikut) berperang ("Sekiranya mereka mengikuti kita) maksudnya orang-orang yang gugur di perang Uhud itu (tentulah mereka tidak akan terbunuh!" Katakanlah) kepada mereka ("Hindarkanlah) tolaklah (kematian dari dirimu jika kamu orang-orang yang benar.") bahwa tidak ikut berperang itu dapat menghindarkan kematian. Ayat berikut turun mengenai syuhada atau orang-orang yang mati syahid\qt@no{168}}%
\qt@newcmd\qurantrans@id@cdlxii{%
(Janganlah kamu kira bahwa orang-orang yang gugur) dengan takhfif atau pakai tasydid (di jalan Allah) maksudnya demi agama-Nya (mati, tetapi) mereka itu (hidup di sisi Tuhan mereka). Roh-roh mereka berada dalam kantong burung-burung hijau yang beterbangan dalam surga ke mana saja mereka kehendaki sebagaimana tersebut dalam sebuah hadis (dengan mendapat rezeki) yaitu dengan memakan buah-buahan surga.\qt@no{169}}%
\qt@newcmd\qurantrans@id@cdlxiii{%
(Mereka riang gembira) menjadi hal dari kata ganti yang terdapat pada yurzaquuna (dengan karunia yang diberikan Allah kepada mereka, dan) mereka (bersenang hati terhadap orang-orang yang masih belum menyusul di belakang mereka) yakni dari saudara-saudara mereka orang-orang beriman dan yang menjadi badal bagi 'alladziina' (bahwa) artinya disebabkan karena (tak ada kekhawatiran terhadap mereka, dan tidak pula mereka akan berdukacita) di akhirat kelak. Maksudnya mereka bersenang hati pula karena teman-teman mereka yang akan menyusul di belakang tak perlu dikhawatirkan nasib dan keamanan mereka.\qt@no{170}}%
\qt@newcmd\qurantrans@id@cdlxiv{%
(Mereka bersenang hati dengan nikmat) atau pahala (dari Allah dan karunia) atau tambahan atasnya (dan bahwa) dibaca anna sebagai ma'thuf kepada 'ni'mah' atau 'inna' sebagai isti'naf atau permulaan kalimat (Allah tidak menyia-nyiakan pahala orang-orang yang beriman) tetapi sebaliknya akan memberi mereka ganjaran.\qt@no{171}}%
\qt@newcmd\qurantrans@id@cdlxv{%
(Orang-orang) menjadi subjek atau mubtada (yang memenuhi panggilan Allah dan rasul-Nya) agar keluar untuk berperang, yakni sewaktu Abu Sufyan dan kawan-kawannya hendak mengulangi peperangan dan berjanji dengan Nabi saw. serta para sahabat akan bertemu kembali di pasar Badar setahun setelah perang Uhud (setelah mereka mendapat luka) yakni di Uhud, sedangkan yang menjadi predikat atau khabar mubtadanya ialah: (bagi orang-orang yang berbuat kebaikan di antara mereka) dengan menaati-Nya (dan menjaga diri) dari menyalahi-Nya (tersedia pahala besar) yaitu surga.\qt@no{172}}%
\qt@newcmd\qurantrans@id@cdlxvi{%
(Yakni orang-orang) badal atau sifat dari 'alladziina' yang sebelumnya (kepada mereka ada yang mengatakan) yakni Na'im bin Masud Al-Asyjai ("Sesungguhnya manusia) yaitu Abu Sofyan dan kawan-kawannya (telah menghimpun pasukan untuk menyerang kamu) atau untuk membasmimu (maka takutlah kepada mereka") dan jangan hadapi mereka. (Maka ucapan itu menambah keimanan mereka) bertambah kepercayaan dan keyakinan mereka terhadap Allah swt. (dan jawaban mereka, ``Cukuplah bagi kami Allah) sebagai pembela terhadap mereka (dan Dialah sebaik-baik pelindung") tempat menyerahkan segala urusan. Nabi saw. bersama kaum Muslimin pergi ke pasar Badar tetapi tidak menemui Abu Sofyan dan kawan-kawannya, Allah telah meniupkan rasa cemas dan ketakutan ke dalam hati mereka sehingga mereka tidak muncul. Sebaliknya di kalangan kaum Muslimin dan penduduk berlangsung jual beli sehingga mereka beroleh laba dan keuntungan. Firman Allah swt. selanjutnya.\qt@no{173}}%
\qt@newcmd\qurantrans@id@cdlxvii{%
(Maka kembalilah mereka) dari Badar (dengan nikmat dan karunia dari Allah) yakni keselamatan dan keuntungan (tanpa mendapat bencana) baik luka atau kematian (dan mereka mengikuti keridaan Allah) yakni dengan menaati-Nya dan rasul-Nya supaya keluar berperang. (Dan Allah mempunyai karunia yang besar) terhadap ahli taat dan ibadah.\qt@no{174}}%
\qt@newcmd\qurantrans@id@cdlxviii{%
(Sesungguhnya mereka itu) yakni yang mengatakan bahwa manusia telah menghimpun pasukan dan seterusnya tadi (hanyalah setan yang menakut-nakuti) kamu dengan (kawan-kawannya) yakni orang-orang kafir (maka janganlah kamu takut kepada mereka hanya takutlah kepada-Ku) jika meninggalkan perintah-Ku (sekiranya kamu benar-benar beriman.)\qt@no{175}}%
\qt@newcmd\qurantrans@id@cdlxix{%
(Janganlah kamu menjadi sedih oleh) ada yang membaca 'yuhzinka' dan ada pula 'yahzunka', berasal dari kata 'ahzanahu' (orang-orang yang cepat jatuh dalam kekafiran) yakni orang-orang yang membela kekafiran itu seperti warga Mekah dan orang-orang munafik, maksudnya jangan kamu pedulikan hal itu. (Sesungguhnya mereka tak sekali-kali dapat memberi mudarat kepada Allah sedikit pun) dengan perbuatan mereka itu, dan mereka hanya membawa kerusakan bagi diri mereka sendiri (Allah menghendaki agar tidak memberi mereka sesuatu di akhirat) maksudnya surga, oleh sebab itu mereka dibiarkan-Nya (dan bagi mereka siksa yang besar) dalam neraka.\qt@no{176}}%
\qt@newcmd\qurantrans@id@cdlxx{%
(Sesungguhnya orang-orang yang menukar keimanan dengan kekafiran) artinya mengambil kekafiran sebagai ganti dari keimanan (tidaklah memberi mudarat kepada Allah) dengan kekafiran mereka itu (sedikit pun dan bagi mereka siksa yang pedih) atau menyakitkan.\qt@no{177}}%
\qt@newcmd\qurantrans@id@cdlxxi{%
(Janganlah sekali-kali menyangka) ada yang memakai 'ya' dan ada pula 'ta' (orang-orang kafir itu bahwa Kami menangguhkan) artinya penangguhan Kami (bagi mereka) yakni dengan memanjangkan umur dan menangguhkan hukuman (lebih baik bagi diri mereka). 'Anna' bersama kedua ma'mulnya menurut qiraat 'yahsabanna' menempati kedudukan dua maf'ulnya, 'tahsabanna' berkedudukan sebagai maf'ul kedua dari 'tahsabanna' ("Sesungguhnya Kami menangguhkan mereka itu hanyalah supaya dosa mereka bertambah-tambah) disebabkan banyaknya maksiat (dan bagi mereka siksa yang menghinakan") di akhirat.\qt@no{178}}%
\qt@newcmd\qurantrans@id@cdlxxii{%
(Allah sekali-kali tidak akan meninggalkan) membiarkan (orang-orang yang beriman dalam keadaan yang kamu) hai manusia (berada di atasnya) artinya yang kamu alami berupa campur aduknya yang ikhlas dengan yang lainnya (sampai Dia memisahkan) dibaca yamiiza atau yumayyiza artinya menyisihkan (orang-orang yang jelek) yaitu orang munafik (dari yang baik) yaitu orang beriman. Caranya ialah dengan tugas-tugas berat sehingga menyingkapkan yang demikian itu, misalnya seperti yang dilakukan-Nya di waktu perang Uhud. (Dan Allah sekali-kali tidak akan memperlihatkan padamu hal-hal gaib) sehingga kamu dapat mengenal mana yang munafik dan mana yang baik sebelum dipisahkan Allah itu (tetapi Allah memilih di antara rasul-rasul-Nya siapa yang dikehendaki-Nya) untuk diberitahukan-Nya hal-hal gaib itu seperti kepada Nabi saw. yang disingkapkan-Nya perihal orang-orang munafik. (Oleh sebab itu berimanlah kamu kepada Allah dan rasul-rasul-Nya dan jika kamu beriman dan bertakwa) artinya menjaga dirimu dari kemunafikan (maka akan beroleh pahala yang besar.)\qt@no{179}}%
\qt@newcmd\qurantrans@id@cdlxxiii{%
(Sekali-kali janganlah menyangka) dengan memakai 'ya' atau 'ta' (orang-orang yang bakhil dengan harta yang diberikan Allah dan karunia-Nya) artinya mengeluarkan zakatnya (bahwa itu) maksudnya kebakhilan itu (baik bagi mereka) menjadi maf'ul yang kedua sedangkan dhamir sebagai pemisah. Maf'ul yang pertama ialah 'kebakhilan mereka' yang diperkirakan sebelum isim maushul jika dibaca dengan 'ta' dan sebelum dhamir jika dengan 'ya' (tetapi itu buruk bagi mereka. Mereka akan dikalungi harta yang mereka bakhilkan) tidak dikeluarkan zakatnya (pada hari kiamat) yakni dengan melilitkan ular pada lehernya dan ular itu mematuknya sebagaimana tercantum dalam sebuah hadis. (Milik Allahlah segala warisan langit dan bumi) yang akan diwarisi-Nya setelah lenyap atau musnahnya penghuni langit dan bumi. (Dan Allah Maha Mengetahui apa yang kamu kerjakan) sehingga akan mendapat balasan daripada-Nya. Ada yang membaca 'ta'maluuna' dengan 'ta' ada pula 'ya'maluuna' dengan 'ya.'\qt@no{180}}%
\qt@newcmd\qurantrans@id@cdlxxiv{%
(Sungguh Allah telah mendengar ucapan orang-orang yang mengatakan, ``Sesungguhnya Allah itu miskin dan kami kaya.") Mereka itu ialah orang-orang Yahudi yang mengatakannya tatkala turun ayat ``Siapakah yang bersedia memberi pinjaman kepada Allah suatu pinjaman yang baik?" Kata mereka, ``Sekiranya Dia kaya tentulah Dia tidak akan meminjam kepada kita!" (Kami akan mencatat) maksudnya akan menyuruh mencatat (apa yang mereka katakan itu) yakni dalam buku catatan amal perbuatan mereka agar mereka menerima balasannya. Menurut suatu qiraat dibaca 'sayuktabu' bukan 'sanaktubu.' (Dan) Kami catat pula (pembunuhan mereka) memakai baris di atas atau baris di depan (atas nabi-nabi tanpa alasan yang benar dan Kami katakan) ada yang membaca 'naquulu' dan ada pula 'yaquulu' yang berarti bahwa yang mengatakan itu ialah Allah yakni di akhirat kelak, perantaraan lisan para malaikat ('Rasailah olehmu azab neraka) lalu dikatakan pula kepada mereka bila mereka dilemparkan ke dalam neraka.\qt@no{181}}%
\qt@newcmd\qurantrans@id@cdlxxv{%
(Demikian itu) maksudnya azab neraka tadi (disebabkan perbuatan tanganmu sendiri) diibaratkan dengan tangan karena kebanyakan perbuatan manusia dilaksanakan dengannya (dan bahwa Allah sekali-kali tidak menganiaya) artinya tidak berbuat aniaya atau melakukan keaniayaan (terhadap hamba-hamba-Nya) Allah tidak akan menyiksa orang-orang yang tidak bersalah atau berdosa.\qt@no{182}}%
\qt@newcmd\qurantrans@id@cdlxxvi{%
(Yakni orang-orang yang) 'na'at' atau sifat bagi alladziina yang sebelumnya (mengatakan) kepada Muhammad ("Sesungguhnya Allah telah menitahkan kepada kami) dalam Taurat (supaya kami tidak beriman kepada seorang rasul) artinya tidak membenarkannya (sebelum ia mendatangkan kepada kami suatu kurban yang dimakan api"). Maka kami tidak akan beriman kepadamu sebelum membawakan kurban, pemberian, yang mendekatkan diri kepada Allah berupa ternak atau lainnya. Jika kurban itu diterima, maka dari langit akan muncul api putih yang akan membakarnya. Dan jika tidak, maka ia akan tetap tinggal di tempatnya tanpa ada yang menyentuhnya. Hal ini diperintahkan kepada Bani Israel tetapi kepada Almasih dan Muhammad tidak demikian halnya, Allah swt. berfirman (Katakanlah) kepada mereka sebagai celaan ("Bukankah telah datang kepadamu beberapa orang rasul sebelumku dengan membawa keterangan-keterangan nyata) atau mukjizat (dan dengan apa yang kamu sebutkan itu) seperti Zakaria dan Yahya, tetapi mereka kamu bunuh juga. Perkataan ini ditujukan kepada orang-orang Yahudi yang hidup di masa Nabi kita saw. walaupun perbuatan itu dari nenek moyang mereka karena mereka menyetujuinya. (Maka kenapa kamu bunuh mereka jika kamu orang-orang yang benar?") maksudnya jika kamu benar-benar beriman ketika melakukan pelanggaran itu.\qt@no{183}}%
\qt@newcmd\qurantrans@id@cdlxxvii{%
(Jika mereka mendustakanmu, maka sesungguhnya rasul-rasul yang sebelum kamu pun telah didustakan pula, padahal mereka membawa keterangan-keterangan yang nyata) yakni mukjizat (dan zubur) maksudnya shuhuf-shuhuf seperti shuhuf Nabi Ibrahim (dan Alkitab) menurut satu qiraat dengan memakai 'ba' pada al-kitab dan az-zubur (yang terang) yakni Taurat dan Injil, maka bersabarlah kamu sebagaimana mereka telah bersabar.\qt@no{184}}%
\qt@newcmd\qurantrans@id@cdlxxviii{%
(Setiap diri akan merasai kematian dan hanya pada hari kiamatlah pahalamu disempurnakan) artinya pada hari kiamatlah ganjaran amal perbuatanmu dipenuhi dengan cukup. (Barang siapa yang dijauhkan) setelah itu (dari neraka dan dimasukkan ke dalam surga, maka sungguh ia beruntung) karena mencapai apa yang dicita-citakannya. (Kehidupan dunia ini tidak lain) maksudnya hidup di dunia ini (hanyalah kesenangan yang memperdayakan semata) artinya yang tidak sebenarnya karena dinikmati hanya sementara lalu ia segera sirna.\qt@no{185}}%
\qt@newcmd\qurantrans@id@cdlxxix{%
(Kamu sungguh-sungguh akan diuji) karena berturut-turutnya beberapa 'nun' maka nun tanda rafa'nya dihilangkan, begitu juga 'wau' dhamir jamak karena bertemunya dua wawu sakin, sedangkan artinya ialah kamu sungguh-sungguh akan diuji atau dicoba (mengenai hartamu) dengan beban-beban dan kewajiban yang harus kamu penuhi (dan dirimu) dengan ibadat dan ujian berupa malapetaka (dan sungguh akan kamu dengar dari orang-orang yang diberi Kitab sebelum kamu) yakni dari orang-orang Yahudi dan Nasrani (dan dari orang-orang musyrik) dari kalangan Arab (gangguan menyakitkan yang banyak sekali) berupa makian dan tuduhan serta godaan dan gangguan terhadap wanita-wanitamu. (Jika kamu bersabar) atas tantangan itu (dan bertakwa) kepada Allah (maka demikian itu termasuk di antara pekerjaan-pekerjaan utama) termasuk hal-hal yang harus dipentingkan dan wajib dihadapi dengan keteguhan hati dan kesabaran yang penuh.\qt@no{186}}%
\qt@newcmd\qurantrans@id@cdlxxx{%
(Dan) ingatlah (ketika Allah mengambil ikrar dari orang-orang yang diberi Alkitab) yakni tugas yang diberikan kepada mereka dalam Taurat ("Hendaklah kamu menerangkannya) maksudnya isi Alkitab itu (kepada manusia dan janganlah kamu menyembunyikannya") yakni Alkitab itu. Kedua kata kerja pada kalimat ini dengan memakai 'ta' dan 'ya.' (Lalu mereka melemparkannya) maksudnya ikrar tersebut (ke belakang punggung mereka) artinya tidak mereka penuhi dan amalkan (dan mereka menukarnya dengan) mereka ambil sebagai gantinya (harga yang sedikit) berupa harta benda dunia yang mereka pungut dari rakyat bawahan dengan keunggulan mereka dalam ilmu Alkitab. Maka ilmu itu mereka sembunyikan karena takut akan lepas dari tangan. (Maka amat jeleklah tukaran yang mereka terima) atau penukaran yang mereka lakukan itu.\qt@no{187}}%
\qt@newcmd\qurantrans@id@cdlxxxi{%
(Janganlah sekali-kali kamu kira) dengan memakai 'ta' dan 'ya' (bahwa orang-orang yang merasa gembira dengan apa yang telah mereka lakukan) yakni dengan apa yang telah mereka perbuat yaitu menyesatkan manusia (dan mereka ingin supaya dipuji terhadap perbuatan yang belum mereka kerjakan) yakni berpegang kepada kebenaran padahal mereka dalam kesesatan (janganlah kamu menyangka mereka) merupakan taukid atau pengukuhan dengan kedua versinya, memakai 'ta' dan 'ya' (terlepas) artinya berada di suatu tempat yang bebas (dari siksa) di akhirat tetapi mereka berada di suatu tempat di mana mereka akan menerima siksa yaitu di neraka Jahanam (dan bagi mereka siksa yang pedih) menyakitkan. Kedua maf'ul yahsabu yang pertama terkandung di dalam kedua maf'ul yahsabu yang kedua berdasarkan qiraat yahsabu sedangkan menurut qiraat tahsabu hanya maf'ul kedualah yang dibuang.\qt@no{188}}%
\qt@newcmd\qurantrans@id@cdlxxxii{%
(Milik Allahlah kerajaan langit dan bumi) maksudnya perbendaharaan hujan, rezeki, tumbuh-tumbuhan dan lain-lain (dan Allah Maha Kuasa atas segala sesuatu) di antaranya menyiksa orang-orang kafir dan membebaskan orang-orang beriman.\qt@no{189}}%
\qt@newcmd\qurantrans@id@cdlxxxiii{%
(Sesungguhnya pada penciptaan langit dan bumi) dan keajaiban-keajaiban yang terdapat pada keduanya (serta pergantian malam dan siang) dengan datang dan pergi serta bertambah dan berkurang (menjadi tanda-tanda) atau bukti-bukti atas kekuasaan Allah swt. (bagi orang-orang yang berakal) artinya yang mempergunakan pikiran mereka.\qt@no{190}}%
\qt@newcmd\qurantrans@id@cdlxxxiv{%
(Yakni orang-orang yang) menjadi 'na`at' atau badal bagi yang sebelumnya (mengingat Allah di waktu berdiri dan duduk dan ketika berbaring) artinya dalam keadaan bagaimana pun juga sedang menurut Ibnu Abbas mengerjakan salat dalam keadaan tersebut sesuai dengan kemampuan (dan mereka memikirkan tentang kejadian langit dan bumi) untuk menyimpulkan dalil melalui keduanya akan kekuasaan Allah, kata mereka: ("Wahai Tuhan kami! Tidaklah Engkau ciptakan ini) maksudnya makhluk yang kami saksikan ini (dengan sia-sia) menjadi hal sebaliknya semua ini menjadi bukti atas kesempurnaan kekuasaan-Mu (Maha Suci Engkau) artinya tidak mungkin Engkau akan berbuat sia-sia (maka lindungilah kami dari siksa neraka.)\qt@no{191}}%
\qt@newcmd\qurantrans@id@cdlxxxv{%
(Wahai Tuhan kami! Sesungguhnya barang siapa yang Engkau masukkan ke dalam neraka) untuk hidup kekal di sana (maka berarti Engkau telah menghinakannya dan tiadalah bagi orang-orang yang aniaya) maksudnya orang-orang yang kafir; di sini ditempatkan zhahir pada tempat mudhmar untuk mengingatkan dikhususkannya kehinaan itu bagi mereka (dari) merupakan tambahan (seorang penolong pun) yang akan melindungi mereka dari siksa Allah swt.\qt@no{192}}%
\qt@newcmd\qurantrans@id@cdlxxxvi{%
(Wahai Tuhan kami! Sesungguhnya kami telah mendengar seorang penyeru yang menyeru) manusia (untuk beriman) kepadanya, yaitu Muhammad atau Alquran (supaya) maksudnya yakni: ('Berimanlah kepada Tuhanmu!' Maka kami pun berimanlah) kepada-Nya (Wahai Tuhan kami! Ampunilah bagi kami dosa-dosa kami dan hapuskanlah) tutup (dari kami kesalahan-kesalahan kami) artinya janganlah dibukakan kepada umum dengan memberikan hukuman terhadapnya (dan wafatkanlah kami) cabutlah nyawa kami (bersama) golongan (orang-orang yang berbakti) yakni para nabi dan orang-orang saleh.\qt@no{193}}%
\qt@newcmd\qurantrans@id@cdlxxxvii{%
(Wahai Tuhan kami! Berilah kami apa yang telah Engkau janjikan kepada kami) (atas) artinya dengan perantaraan (para rasul-Mu) berupa nikmat dan karunia serta apa-apa yang mereka mohonkan walaupun janji Allah itu tidak bertentangan dengan permohonan orang yang meminta agar ia termasuk dalam golongan orang-orang yang diberi karunia disebabkan ia belum beroleh kepastian bahwa permohonannya itu akan dikabulkan. Mengenai disebutnya 'Wahai Tuhan kami' secara berulang-ulang maka itu menyatakan ketundukan dan kerendahan hati yang sedalam-dalamnya. (Dan janganlah Engkau hinakan kami pada hari kiamat, sesungguhnya Engkau tidak menyalahi janji.") yaitu janji dengan kebangkitan dan pembalasan.\qt@no{194}}%
\qt@newcmd\qurantrans@id@cdlxxxviii{%
(Maka Tuhan mereka memperkenankan bagi mereka) permohonan mereka (bahwa Aku tidak akan menyia-nyiakan amalan orang-orang yang beramal di antara kamu baik laki-laki maupun perempuan, sebagian kamu) adalah (dari sebagian yang lain) artinya laki-laki adalah turunan wanita sebaliknya wanita adalah keturunan laki-laki. Kalimat ini memperkuat kalimat yang sebelumnya yakni bahwa mereka akan sama-sama menerima balasan dari amal perbuatan masing-masing dan bahwa mereka sama-sama tidak akan disepelekan. Lanjutan ayat berikut turun ketika Ummu Salamah mengatakan kepada Rasulullah, ``Wahai Rasulullah! Tidak pernah saya dengar wanita disebut-sebut dalam soal hijrah." (Maka orang-orang yang berhijrah) dari Mekah ke Madinah (yang diusir dari kampung halamannya serta disakiti pada jalan-Ku) maksudnya karena agama-Ku (dan yang berperang) melawan orang-orang kafir (dan orang-orang yang gugur) di jalan-Ku baik memakai tasydid atau tidak dan menurut satu qiraat dengan mendahulukannya (niscaya Aku hapuskan kesalahan-kesalahan mereka) Aku tutupi dosa-dosa mereka dengan ampunan-Ku (dan Kumasukkan mereka ke dalam surga yang mengalir di bawahnya sungai-sungai sebagai pahala) mashdar dari pengertian 'Kuhapus' dan memperkokoh maknanya (dari sisi Allah) terdapat perpalingan kedudukan-Nya sebagai pembicara (dan Allah di sisi-Nya terdapat pahala yang baik.) sebagai balasan. Ayat berikut turun pula tatkala kaum Muslimin mengatakan bahwa musuh Allah kelihatan berbahagia sedangkan mereka dalam keadaan susah dan menderita:\qt@no{195}}%
\qt@newcmd\qurantrans@id@cdlxxxix{%
(Janganlah sekali-kali kamu terpedaya oleh keleluasaan orang-orang kafir bepergian) artinya bergerak ke mana mereka sukai (di dalam negeri) untuk berniaga dan berusaha.\qt@no{196}}%
\qt@newcmd\qurantrans@id@cdxc{%
(Itu hanyalah kesenangan sementara) yang mereka nikmati di dunia dalam waktu singkat kemudian akan lenyap (kemudian tempat tinggal mereka ialah neraka Jahanam dan itulah tempat yang seburuk-buruknya.)\qt@no{197}}%
\qt@newcmd\qurantrans@id@cdxci{%
(Akan tetapi orang-orang yang bertakwa kepada Tuhannya bagi mereka surga-surga yang di bawahnya mengalir sungai, mereka kekal) maksudnya ditakdirkan kekal (padanya sebagai tempat tinggal) yang biasanya disediakan buat tamu-tamu; dijadikan manshub karena kedudukannya sebagai hal dari jannaat sedangkan sebagai amilnya ialah pengertian zharf (dari sisi Allah dan apa yang dari sisi Allah) berupa pahala (lebih baik bagi orang-orang yang berbakti) daripada kesenangan dunia.\qt@no{198}}%
\qt@newcmd\qurantrans@id@cdxcii{%
(Sesungguhnya di antara Ahli Kitab ada orang yang beriman kepada Allah) seperti Abdullah bin Salam dan sahabat-sahabatnya serta Najasyi (dan kepada apa yang diturunkan kepadamu) yakni Alquran (dan kepada apa yang telah diturunkan kepada mereka) yakni Taurat dan Injil (dalam keadaan merendahkan diri) hal dari dhamir pada 'yu`minu' dengan menekankan makna 'man' dengan arti 'tawadhu`' (kepada Allah tanpa menukarkan ayat-ayat Allah) yang terdapat pada mereka dalam Taurat dan Injil berupa kebangkitan Nabi saw. (dengan harga yang sedikit) dari harta dunia, misalnya dengan menyembunyikannya karena takut kehilangan pengaruh seperti dilakukan oleh orang-orang Yahudi lainnya. (Mereka beroleh pahala) sebagai balasan atas amal perbuatan mereka (di sisi Tuhan mereka) yang diberikan kepada mereka dua kali sebagaimana terdapat dalam surah Al-Qashash (sesungguhnya Allah amat cepat perhitungan-Nya) dapat melakukan perhitungan terhadap seluruh makhluk dalam hanya setengah hari saja dari hari-hari dunia.\qt@no{199}}%
\qt@newcmd\qurantrans@id@cdxciii{%
(Hai orang-orang yang beriman, bersabarlah) melakukan taat dan menghadapi musibah serta menghindari maksiat (dan teguhkanlah kesabaranmu) menghadapi orang-orang kafir hingga mereka tidak lebih sabar daripada kamu (dan tetaplah waspada serta siap siaga) dalam perjuangan (serta bertakwalah kepada Allah) dalam setiap keadaan (supaya kamu beruntung) merebut surga dan bebas dari neraka.\qt@no{200}}%
\qt@newcmd\qurantrans@id@cdxciv{%
\basmalahid (Hai manusia) penduduk Mekah (bertakwalah kamu kepada Tuhanmu) artinya takutlah akan siksa-Nya dengan jalan menaati-Nya (yang telah menciptakan kamu dari satu diri) yakni Adam (dan menciptakan daripadanya istrinya) yaitu Hawa; dibaca panjang; dari salah satu tulang rusuknya yang kiri (lalu mengembangbiakkan) menyebarluaskan (dari kedua mereka itu) dari Adam dan Hawa (laki-laki yang banyak dan wanita) yang tidak sedikit jumlahnya. (Dan bertakwalah kepada Allah yang kamu saling meminta) terdapat idgam ta pada sin sedangkan menurut satu qiraat dengan takhfif yaitu membuangnya sehingga menjadi tas-aluuna (dengan nama-Nya) yang sebagian kamu mengatakan kepada sebagian lainnya, ``Saya meminta kepadamu dengan nama Allah," (dan) jagalah pula (hubungan silaturahmi) jangan sampai terputus. Menurut satu qiraat dibaca dengan kasrah diathafkan kepada dhamir yang terdapat pada bihi. Mereka juga biasa saling bersumpah dengan hubungan rahim. (Sesungguhnya Allah selalu mengawasi kamu) menjaga perbuatanmu dan memberi balasan terhadapnya. Maka sifat mengawasi selalu melekat dan terdapat pada Allah swt. Ayat berikut diturunkan mengenai seorang anak yatim yang meminta hartanya kepada walinya tetapi ia tidak mau memberikannya.\qt@no{1}}%
\qt@newcmd\qurantrans@id@cdxcv{%
(Dan berikanlah kepada anak-anak yatim) yaitu anak-anak yang tidak berbapak (harta mereka) jika sudah balig (dan janganlah kamu tukar yang baik dengan yang buruk) artinya yang halal dengan yang haram dan janganlah kamu ambil harta yang baik dari anak yatim itu lalu kamu ganti dengan hartamu yang jelek (dan jangan kamu makan harta mereka) yang telah dicampur aduk (dengan hartamu. Sesungguhnya itu) maksudnya memakan yang demikian itu (adalah dosa) atau kesalahan (besar). Tatkala ayat ini turun mereka berkeberatan untuk menjadi wali anak yatim. Kemudian di antara mereka ada orang yang memiliki sepuluh atau delapan orang istri sehingga ia tak sanggup untuk berlaku adil di antara mereka, maka turunlah ayat:\qt@no{2}}%
\qt@newcmd\qurantrans@id@cdxcvi{%
(Dan jika kamu takut tidak akan dapat berlaku adil terhadap anak-anak yatim) sehingga sulit bagi kamu untuk menghadapi mereka lalu kamu takut pula tidak akan dapat berlaku adil di antara wanita-wanita yang kamu kawini (maka kawinilah) (apa) dengan arti siapa (yang baik di antara wanita-wanita itu bagi kamu dua, tiga atau empat orang) boleh dua, tiga atau empat tetapi tidak boleh lebih dari itu. (kemudian jika kamu tidak akan dapat berlaku adil) di antara mereka dalam giliran dan pembagian nafkah (maka hendaklah seorang saja) yang kamu kawini (atau) hendaklah kamu batasi pada (hamba sahaya yang menjadi milikmu) karena mereka tidak mempunyai hak-hak sebagaimana istri-istri lainnya. (Yang demikian itu) maksudnya mengawini empat orang istri atau seorang istri saja, atau mengambil hamba sahaya (lebih dekat) kepada (tidak berbuat aniaya) atau berlaku lalim.\qt@no{3}}%
\qt@newcmd\qurantrans@id@cdxcvii{%
(Berikanlah kepada wanita-wanita itu maskawin mereka) jamak dari shadaqah (sebagai pemberian) karena ketulusan dan kesucian hati (Kemudian jika mereka menyerahkan kepadamu sebagian dari maskawin itu dengan senang hati) nafsan merupakan tamyiz yang asalnya menjadi fa'il; artinya hati mereka senang untuk menyerahkan sebagian dari maskawin itu kepadamu lalu mereka berikan (maka makanlah dengan enak) atau sedap (lagi baik) akibatnya sehingga tidak membawa bencana di akhirat kelak. Ayat ini diturunkan terhadap orang yang tidak menyukainya.\qt@no{4}}%
\qt@newcmd\qurantrans@id@cdxcviii{%
(Dan janganlah kamu serahkan) hai para wali (kepada orang-orang yang bebal) artinya orang-orang yang boros dari kalangan laki-laki, wanita dan anak-anak (harta kamu) maksudnya harta mereka yang berada dalam tanganmu (yang dijadikan Allah sebagai penunjang hidupmu) qiyaaman mashdar dari qaama; artinya penopang hidup dan pembela kepentinganmu karena akan mereka habiskan bukan pada tempatnya. Menurut suatu qiraat dibaca qayyima jamak dari qiimah; artinya alat untuk menilai harga benda-benda (hanya berilah mereka belanja daripadanya) maksudnya beri makanlah mereka daripadanya (dan pakaian dan ucapkanlah kepada mereka kata-kata yang baik) misalnya janjikan jika mereka telah dewasa, maka harta mereka itu akan diberikan semuanya kepada mereka.\qt@no{5}}%
\qt@newcmd\qurantrans@id@cdxcix{%
(Dan hendaklah kamu uji anak-anak yatim itu) sebelum mereka balig yakni mengenai keagamaan dan tingkah laku mereka (hingga setelah mereka sampai umur untuk kawin) artinya telah mampu untuk itu dengan melihat keadaan dan usia; menurut Imam Syafii 15 tahun penuh (maka jika menurut pendapatmu) atau penglihatanmu (mereka telah cerdas) artinya pandai menjaga agama dan harta mereka (maka serahkanlah kepada mereka itu harta-harta mereka dan janganlah kamu memakannya) hai para wali (secara berlebih-lebihan) tanpa hak; ini menjadi hal (dan dengan tergesa-gesa) untuk membelanjakannya karena khawatir (mereka dewasa) hingga harta itu harus diserahkan kepada yang berhak. (Dan barang siapa) di antara para wali (yang mampu, maka hendaklah ia menahan diri) dari mengambil dan memakan harta anak yatim itu (sedangkan siapa yang miskin, maka bolehlah ia memakan) harta itu (secara sepatutnya) artinya sekadar upah jerih payahnya. (Kemudian apabila kamu menyerahkan kepada mereka) maksudnya kepada anak-anak yatim (harta mereka, maka hendaklah kamu persaksikan terhadap mereka) yakni bahwa mereka telah menerimanya dan tanggung jawabmu telah selesai. Maksudnya ialah siapa tahu kalau-kalau terjadi persengketaan nanti, maka kamu dapat mempergunakan para saksi itu. Maka perintah ini tujuannya ialah untuk memberi petunjuk (Dan cukuplah Allah) ba merupakan tambahan (sebagai pengawas) yang mengawasi perbuatan-perbuatan hamba-Nya dan memberi mereka ganjaran. Ayat berikut ini diturunkan untuk menolak kebiasaan orang-orang jahiliah yang tidak mau memberi harta warisan kepada golongan wanita dan anak-anak.\qt@no{6}}%
\qt@newcmd\qurantrans@id@d{%
(Bagi laki-laki) baik anak-anak maupun karib kerabat (ada bagian) atau hak (dari harta peninggalan ibu bapak dan karib kerabat) yang meninggal dunia (dan bagi wanita ada bagian pula dari harta peninggalan ibu bapak dan karib kerabat, baik sedikit daripadanya) maksudnya dari harta itu (atau banyak) yang dijadikan Allah (sebagai hak yang telah ditetapkan) artinya hak yang pasti yang harus diserahkan kepada mereka.\qt@no{7}}%
\qt@newcmd\qurantrans@id@di{%
(Dan apabila pembagian harta warisan dihadiri oleh karib kerabat) yakni dari golongan yang tidak beroleh warisan (dan anak-anak yatim serta orang-orang miskin, maka berilah mereka daripadanya sekadarnya) sebelum dilakukan pembagian (dan ucapkanlah) hai para wali (kepada mereka) yakni jika mereka masih kecil-kecil (kata-kata yang baik) atau lemah-lembut, seraya meminta maaf kepada kaum kerabat yang tidak mewarisi itu, bahwa harta peninggalan ini bukan milik kalian tetapi milik ahli waris yang masih kecil-kecil. Ada yang mengatakan bahwa hukum ini yakni pemberian kepada kaum kerabat yang tidak mewarisi telah dinasakhkan/dihapus. Tetapi ada pula yang mengatakan tidak, hanya manusialah yang mempermudah dan tidak melakukannya. Berdasarkan itu maka hukumnya sunah, tetapi Ibnu Abbas mengatakannya wajib.\qt@no{8}}%
\qt@newcmd\qurantrans@id@dii{%
(Dan hendaklah bersikap waspada) maksudnya terhadap nasib anak-anak yatim (orang-orang yang seandainya meninggalkan) artinya hampir meninggalkan (di belakang mereka) sepeninggal mereka (keturunan yang lemah) maksudnya anak-anak yang masih kecil-kecil (mereka khawatir terhadap nasib mereka) akan terlantar (maka hendaklah mereka bertakwa kepada Allah) mengenai urusan anak-anak yatim itu dan hendaklah mereka lakukan terhadap anak-anak yatim itu apa yang mereka ingini dilakukan orang terhadap anak-anak mereka sepeninggal mereka nanti (dan hendaklah mereka ucapkan) kepada orang yang hendak meninggal (perkataan yang benar) misalnya menyuruhnya bersedekah kurang dari sepertiga dan memberikan selebihnya untuk para ahli waris hingga tidak membiarkan mereka dalam keadaan sengsara dan menderita.\qt@no{9}}%
\qt@newcmd\qurantrans@id@diii{%
(Sesungguhnya orang-orang yang memakan harta anak-anak yatim secara aniaya) maksudnya tanpa hak (bahwasanya mereka menelan api sepenuh perut mereka) karena harta itu akan berubah di akhirat nanti menjadi api (dan mereka akan masuk) dalam bentuk kalimat aktif atau pun pasif (api yang bernyala-nyala) yakni api neraka yang menyebabkan mereka terbakar hangus.\qt@no{10}}%
\qt@newcmd\qurantrans@id@div{%
(Allah mewasiatkan atau menitahkan padamu mengenai anak-anakmu) dengan apa yang akan disebutkan ini: (yaitu bagian seorang anak lelaki sama dengan bagian dua orang anak perempuan) di antara mereka. Jika ketiga mereka itu berkumpul, maka bagi yang lelaki seperdua harta dan bagi kedua anak perempuan seperdua pula. Sedangkan jika yang ditemui itu hanya seorang anak lelaki dan seorang perempuan, maka bagi yang perempuan itu hanya sepertiga sementara bagi yang laki-laki dua pertiga. Dan sekiranya yang laki-laki itu tunggal, maka ia menghabisi semua harta (jika mereka) maksudnya anak-anak itu (hanya perempuan) saja (lebih dari dua orang maka bagi mereka dua pertiga harta yang ditinggalkan) mayat; demikian pula jika jumlah mereka dua orang karena mereka itu dua bersaudara yang tercakup dalam firman Allah swt., ``... maka bagi mereka dua pertiga dari harta peninggalan," mereka lebih utama apalagi mengingat bahwa seorang anak perempuan berhak sepertiga harta jika bersama seorang anak laki-laki sehingga dengan demikian jika dia bersama seorang anak perempuan lebih utama lagi dan lebih didahulukan dari hubungan apa pun. Ada pula yang mengatakan bahwa demikian itu ialah untuk menghilangkan dugaan bertambahnya bagian dengan bertambahnya bilangan, yakni tatkala timbul pengertian bahwa dengan diberikannya sepertiga bagian untuk seorang anak perempuan jika ia bersama seorang anak laki-laki, maka dua orang anak perempuan beroleh dua pertiga bagian. (Jika dia) maksudnya anak perempuan itu (seorang saja) menurut qiraat dengan baris di depan sehingga kaana dianggap sebagai tam dan bukan naqish. (maka ia memperoleh seperdua harta sedangkan untuk kedua orang tuanya) maksudnya orang tua mayat yang di sini diberi badal dengan (bagi masing-masing mereka seperenam dari harta pusaka; yakni jika si mayat itu mempunyai anak) baik laki-laki maupun wanita. Ditekankannya badal ialah untuk menyatakan bahwa kedua orang tua itu tidaklah berserikat padanya. Dan terhadap adanya anak dianggap adanya cucu, begitu pula terhadap adanya bapak adanya kakek. (Jika si mayat tidak mempunyai anak dan dia diwarisi oleh kedua orang tuanya) saja atau bersama istrinya (maka bagi ibunya) dapat dibaca li-ummihi dengan hamzah baris di depan dan boleh pula limmihi dengan hamzah baris di bawah untuk meringankan bertemunya dhammah dan kasrah pada dua tempat yang berdekatan (sepertiga) maksudnya sepertiga dari harta yang telah dibagikan kepada pihak istri, sedangkan sisanya buat bapak. (Jika yang meninggal itu mempunyai beberapa orang saudara) maksudnya dua orang atau lebih, baik laki-laki atau perempuan (maka bagi ibunya seperenam) sedangkan sisanya untuk bapaknya, sementara saudara-saudaranya itu tidak beroleh bagian apa-apa. Dan pembagian warisan seperti tersebut di atas itu ialah (setelah) dilaksanakannya (wasiat yang dibuatnya) dibaca yuushii atau yuushaa dalam bentuk aktif atau pun pasif (atau) dibayarnya (utangnya). Dan disebutkannya lebih dulu pemenuhan wasiat daripada pembayaran utang, walaupun pelaksanaannya dibelakangkan ialah dengan maksud untuk tidak mengabaikannya. (Mengenai orang tuamu dan anak-anakmu) menjadi mubtada sedangkan khabarnya ialah: (tidaklah kamu ketahui manakah yang lebih dekat kepadamu manfaatnya) di dunia dan di akhirat. Ada orang yang mengira bahwa putranyalah yang lebih banyak kegunaannya kepadanya, lalu diberinya harta warisan sehingga dengan demikian ternyatalah bahwa bapaklah yang lebih bermanfaat bagi manusia, demikian sebaliknya. Maka yang mengetahui soal itu hanyalah Allah swt. dan itulah sebabnya diwajibkan-Nya pembagian pusaka. (Ini adalah ketetapan dari Allah; sesungguhnya Allah Maha Mengetahui) terhadap makhluk-Nya (lagi Maha Bijaksana) tentang peraturan-peraturan yang diberikan-Nya kepada mereka; artinya Dia tetap bersifat bijaksana dalam semuanya itu.\qt@no{11}}%
\qt@newcmd\qurantrans@id@dv{%
(Dan bagi kamu, suami-suami, seperdua dari harta peninggalan istri-istrimu jika mereka tidak mempunyai anak) baik dari kamu maupun dari bekas suaminya dulu. (Tetapi jika mereka mempunyai anak, maka kamu mendapat seperempat dari harta peninggalan, yakni setelah dipenuhinya wasiat yang mereka buat atau dibayarnya utang mereka.) Dalam hal ini cucu dianggap sama dengan anak menurut ijmak. (Dan bagi mereka) artinya para istri itu baik mereka berbilang atau tidak (seperempat dari harta yang kamu tinggalkan jika kamu tidak mempunyai anak; dan jika kamu mempunyai anak) baik dari istrimu itu maupun dari bekas istrimu (maka bagi mereka seperdelapan dari harta peninggalanmu, yakni setelah dipenuhinya wasiat yang kamu buat atau dibayarnya utangmu). Dalam hal ini cucu dianggap sama dengan anak menurut ijmak. (Jika seorang laki-laki yang diwarisi itu) menjadi sifat, sedangkan khabarnya: (kalalah) artinya tidak meninggalkan bapak dan tidak pula anak (atau perempuan) yang mewaris secara kalalah (tetapi ia mempunyai) maksudnya yang diwarisi itu (seorang saudara laki-laki atau seorang saudara perempuan) maksudnya yang seibu, dan jelas-jelas dibaca oleh Ibnu Masud dan lain-lain (maka masing-masing jenis saudara itu memperoleh seperenam) harta peninggalan. (Tetapi jika mereka itu) maksudnya saudara-saudara yang seibu itu, baik laki-laki maupun perempuan (lebih daripada itu) maksudnya lebih dari seorang (maka mereka berserikat dalam sepertiga harta) dengan bagian yang sama antara laki-laki dan perempuan (sesudah dipenuhinya wasiat yang dibuatnya atau dibayarnya utangnya tanpa memberi mudarat) menjadi hal dari dhamir yang terdapat pada yuushaa; artinya tidak menyebabkan adanya kesusahan bagi para ahli waris, misalnya dengan berwasiat lebih dari sepertiga harta (sebagai amanat) atau pesan, dan merupakan mashdar yang mengukuhkan dari yuushiikum (dari Allah, dan Allah Maha Mengetahui) faraid atau tata cara pembagian pusaka yang diatur-Nya buat makhluk-Nya (lagi Maha Penyantun) dengan menangguhkan hukuman terhadap orang-orang yang melanggarnya. Kemudian mengenai pembagian pusaka terhadap ahli-ahli waris tersebut yang mengandung keraguan dengan adanya halangan seperti pembunuhan atau perbedaan agama dan menjadi murtad, maka penjelasannya diserahkan pada sunah.\qt@no{12}}%
\qt@newcmd\qurantrans@id@dvi{%
(Itulah) maksudnya hukum-hukum tersebut semenjak urusan anak yatim hingga berikutnya (ketentuan-ketentuan Allah) syariat-syariat yang ditetapkan-Nya buat hamba-hamba-Nya agar mereka patuhi dan tidak dikhianati. (Barang siapa yang taat kepada Allah dan Rasul-Nya) mengenai hukum-hukum yang ditetapkan-Nya itu (maka akan dimasukkan-Nya) ada yang membaca nudkhiluhu; artinya Kami masukkan ia, dengan maksud merubah pembicaraan kepada orang pertama (ke dalam surga yang mengalir di bawahnya sungai-sungai, kekal mereka di dalamnya, dan itulah kemenangan yang besar).\qt@no{13}}%
\qt@newcmd\qurantrans@id@dvii{%
(Dan siapa yang mendurhakai Allah dan Rasul-Nya serta melanggar aturan-aturan-Nya, maka akan dimasukkan-Nya) ada dua versi dengan memakai ya dan ada pula dengan memakai nun (ke dalam api neraka, kekal ia di dalamnya dan baginya) di dalamnya (siksa yang menghinakan) di samping menciutkan hati. Pada kedua ayat terdapat lafal man sedangkan pada khaalidiina makna atau artinya.\qt@no{14}}%
\qt@newcmd\qurantrans@id@dviii{%
(Dan wanita-wanita yang melakukan perbuatan keji) maksudnya berzina di antara wanita-wanitamu (maka persaksikanlah mereka itu kepada empat orang saksi di antaramu) maksudnya di antara laki-lakimu yang beragama Islam. (Maka jika mereka memberikan kesaksian) terhadap perbuatan mereka itu (maka tahanlah mereka itu) atau kurunglah (dalam rumah) dan laranglah mereka bergaul dengan manusia (sampai mereka diwafatkan oleh maut) maksudnya oleh malaikat maut (atau) hingga (Allah memberi bagi mereka jalan lain) yakni jalan untuk membebaskan mereka dari hukuman semacam itu. Demikianlah hukuman mereka pada awal Islam lalu mereka diberi jalan lain yaitu digantinya dengan hukum dera sebanyak seratus kali serta membuangnya dari kampung halamannya selama setahun yakni bagi yang belum kawin dan dengan merajam wanita-wanita yang sudah kawin. Dalam hadis tersebut bahwa tatkala hukuman itu diumumkan, bersabdalah Nabi saw., ``Terimalah daripadaku, contohlah kepadaku karena Allah telah memberikan bagi mereka jalan lepas!" Riwayat Muslim.\qt@no{15}}%
\qt@newcmd\qurantrans@id@dix{%
(Dan mengenai dua orang) dengan nun yang memakai atau tanpa tasydid (yang melakukannya) maksudnya perbuatan keji, yaitu berzina atau homoseksual (di antara kamu) maksudnya kaum lelaki (maka berilah mereka hukuman) dengan mencela dan memukul mereka dengan terompah. (Kemudian jika mereka bertobat) daripadanya (dan memperbaiki perbuatan mereka) (maka tinggalkanlah mereka) dan jangan disakiti lagi. (Sesungguhnya Allah Maha Penerima tobat) terhadap orang yang sadar (lagi Maha Penyayang) kepadanya. Ayat ini telah dihapus/dimansukh hukumnya dengan ayat had, jika yang dimaksud karena berzina. Demikian pula menurut Syafii jika yang dimaksud karena homoseksual. Hanya menurutnya pula, orang yang ``dikerjai" tidaklah dirajam walaupun telah beristri, hanya dipukul dan diasingkan. Bahwa yang dimaksud itu homoseksual lebih kuat dengan alasan adanya dhamir tatsniah huma dan lain-lain. Menurut golongan yang pertama yang dimaksud dengan kedua mereka itu ialah pezina yang laki-laki dan yang perempuan. Tetapi pendapat ini ditolak oleh golongan Syafii dengan penjelasan yang diberikan kemudian dengan hubungannya yang berkaitan dengan dhamir laki-laki dan berserikatnya kedua mereka dalam menerima hukuman, bertobat dan diisolir. Dan ini khusus bagi pihak laki-laki, karena sebagaimana kita ketahui bagi pihak wanita ialah tahanan rumah.\qt@no{16}}%
\qt@newcmd\qurantrans@id@dx{%
(Sesungguhnya tobat di isi Allah) yakni yang pasti diterima di sisi-Nya berkat kemurahan-Nya (ialah bagi orang-orang yang mengerjakan kejahatan) atau maksiat (disebabkan kejahilan) menjadi hal artinya tidak tahu bahwa dengan itu berarti mendurhakai Allah (kemudian mereka bertobat dalam) waktu (dekat) yakni sebelum mengalami sekarat (maka mereka itulah yang diterima tobatnya oleh Allah) artinya diterima-Nya tobat mereka (dan Allah Maha Mengetahui) akan makhluk-Nya (lagi Maha Bijaksana) mengenai tindakan-Nya terhadap mereka.\qt@no{17}}%
\qt@newcmd\qurantrans@id@dxi{%
(Dan tidaklah dikatakan tobat bagi orang-orang yang mengerjakan kejahatan) atau dosa (hingga ketika ajal datang kepada salah seorang mereka) dan nyawanya hendak lepas (lalu dikatakannya) ketika menyaksikan apa yang sedang dialaminya ("Sesungguhnya saya bertobat sekarang.") karena itu tidaklah bermanfaat dan tidak akan diterima oleh Allah tobatnya. (Dan tidak pula orang-orang yang mati sedangkan mereka berada dalam kekafiran) yakni jika mereka bertobat di akhirat sewaktu menyaksikan azab, maka tidak pula akan diterima. (Mereka itu Kami siapkan) sediakan (bagi mereka siksa yang pedih) yang menyakitkan.\qt@no{18}}%
\qt@newcmd\qurantrans@id@dxii{%
(Hai orang-orang yang beriman, tidak halal bagi kamu mewarisi wanita) maksudnya diri mereka (dengan paksa) dibaca karhan atau kurhan; artinya tanpa kemauan dan kerelaan mereka. Di zaman jahiliah mereka biasa mewarisi wanita-wanita, istri karib kerabat mereka. Jika mereka kehendaki mereka dapat mengawininya tanpa maskawin, atau mereka kawinkan lalu diambil maskawinnya, atau mereka halangi kawin sampai wanita itu menebus dirinya dengan harta warisan yang diperolehnya atau mereka tunggu sampai meninggal lalu mereka warisi hartanya; maka mereka dilarang demikian itu. (Dan tidak pula) bahwa (kamu menyusahkan mereka) artinya kamu halangi istri-istrimu buat mengawini laki-laki lain dengan menahan mereka padahal tak ada keinginanmu lagi terhadap mereka selain dari menyusahkan belaka (karena hendak mengambil kembali sebagian dari apa yang telah kamu berikan kepada mereka) berupa mahar (kecuali jika mereka melakukan pekerjaan keji yang nyata) dengan ya baris di atas dan baris di bawah, yang nyata atau yang dinyatakan, artinya zina atau nusyuz; maka ketika itu bolehlah kamu menyusahkan mereka hingga mereka melakukan khuluk atau menebus diri mereka (dan pergaulilah mereka secara patut) artinya secara baik-baik, biar dalam perkataan maupun dalam memberi nafkah lahir atau batin. (Maka jika kamu tidak menyukai mereka) hendaklah bersabar (karena mungkin kamu tidak menyukai sesuatu tetapi Allah menjadikan padanya kebaikan yang banyak). Siapa tahu hal itu dilakukan-Nya misalnya dengan menganugerahimu anak yang saleh.\qt@no{19}}%
\qt@newcmd\qurantrans@id@dxiii{%
(Dan jika kamu bermaksud hendak mengganti istrimu dengan istri yang lain) artinya kamu ambil dia sebagai penggantinya setelah kamu ceraikan istrimu yang pertama itu (dan) sungguh (kamu telah memberikan kepada salah seorang di antara mereka) maksudnya istri-istri itu (harta yang banyak) sebagai maskawinnya (maka janganlah kamu mengambil kembali daripadanya barang sedikit pun. Apakah kamu akan mengambilnya kembali secara aniaya) dengan zalim (dan dengan -memikul- dosa yang nyata?) Dinashabkan keduanya karena kedudukan mereka sebagai hal sedangkan pertanyaan berikut maksudnya sebagai celaan dan penolakan:\qt@no{20}}%
\qt@newcmd\qurantrans@id@dxiv{%
(Bagaimana kamu akan mengambilnya kembali) artinya dengan alasan apa (padahal sebagian kamu telah bergaul dengan yang lain) atau telah berhubungan sebagai suami istri dengan bercampur yang telah mensahkan maskawin (dan mereka telah mengambil daripadamu perjanjian) atau pengakuan (yang erat) atau berat, yakni berupa perintah Ilahi agar memegang mereka secara baik-baik atau melepas mereka secara baik-baik pula.\qt@no{21}}%
\qt@newcmd\qurantrans@id@dxv{%
(Dan janganlah kamu kawini apa) maksudnya siapa (Di antara wanita-wanita yang telah dikawini oleh bapakmu kecuali) artinya selain dari (yang telah berlalu) dari perbuatanmu itu, maka dimaafkan. (Sesungguhnya hal itu) maksudnya mengawini mereka itu (adalah perbuatan keji) atau busuk (suatu kutukan) maksudnya sesuatu yang menyebabkan timbulnya kutukan dari Allah, yang berarti kemurkaan-Nya yang amat sangat (dan sejahat-jahat) seburuk-buruk (jalan) yang ditempuh.\qt@no{22}}%
\qt@newcmd\qurantrans@id@dxvi{%
(Diharamkan atas kamu ibu-ibumu) maksudnya mengawini mereka dan ini mencakup pula nenek, baik dari pihak bapak maupun dari pihak ibu (dan anak-anak perempuanmu) termasuk cucu-cucumu yang perempuan terus ke bawah (saudara-saudaramu yang perempuan) baik dari pihak bapak maupun dari pihak ibu (saudara-saudara bapakmu yang perempuan) termasuk pula saudara-saudara kakekmu (saudara-saudara ibumu yang perempuan) termasuk pula saudara-saudara nenekmu (anak-anak perempuan dari saudaramu yang laki-laki, anak-anak perempuan dari saudaramu yang perempuan) maksudnya keponakan-keponakanmu dan tercakup pula di dalamnya anak-anak mereka (ibu-ibumu yang menyusui kamu) maksudnya ibu-ibu susuan, yakni sebelum usiamu mencapai dua tahun dan sekurang-kurangnya lima kali susuan sebagaimana dijelaskan oleh hadis (saudara-saudara perempuanmu sesusuan). Kemudian dalam sunah ditambahkan anak-anak perempuan daripadanya, yaitu wanita-wanita yang disusukan oleh wanita-wanita yang telah dicampurinya, berikut saudara-saudara perempuan dari bapak dan dari ibu, serta anak-anak perempuan dari saudara laki-laki dan anak-anak perempuan dari saudara perempuannya, berdasarkan sebuah hadis yang berbunyi, ``Haram disebabkan penyusuan apa yang haram oleh sebab pertalian darah." Riwayat Bukhari dan Muslim. (ibu-ibu istrimu, mertua, dan anak-anak tirimu) jamak rabiibah yaitu anak perempuan istri dari suaminya yang lain (yang berada dalam asuhanmu) mereka berada dalam pemeliharaan kalian; kalimat ini berkedudukan sebagai kata sifat dari lafal rabaaib (dan istri-istrimu yang telah kamu campuri) telah kalian setubuhi (tetapi jika kamu belum lagi mencampuri mereka, maka tidaklah berdosa kamu) mengawini anak-anak perempuan mereka, jika kamu telah menceraikan mereka (dan diharamkan istri-istri anak kandungmu) yakni yang berasal dari sulbimu, berbeda halnya dengan anak angkatmu, maka kamu boleh kawin dengan janda-janda mereka (dan bahwa kamu himpun dua orang perempuan yang bersaudara) baik saudara dari pertalian darah maupun sepersusuan, dan menghimpun seorang perempuan dengan saudara perempuan bapaknya atau saudara perempuan ibunya tetapi diperbolehkan secara ``tukar lapik" atau ``turun ranjang" atau memiliki kedua mereka sekaligus asal yang dicampuri itu hanya salah seorang di antara mereka (kecuali) atau selain (yang telah terjadi di masa lalu) yakni di masa jahiliah sebagian dari apa yang disebutkan itu, maka kamu tidaklah berdosa karenanya. (Sesungguhnya Allah Maha Pengampun lagi Maha Penyayang).\qt@no{23}}%
\qt@newcmd\qurantrans@id@dxvii{%
(Dan) diharamkan bagimu (wanita-wanita yang bersuami) untuk dikawini sebelum bercerai dengan suami-suami mereka itu, baik mereka merdeka atau budak dan beragama Islam (kecuali wanita-wanita yang kamu miliki) yakni hamba-hamba sahaya yang tertawan, maka mereka boleh kamu campuri walaupun mereka punya suami di negeri perang, yakni setelah istibra' atau membersihkan rahimnya (sebagai ketetapan dari Allah) kitaaba manshub sebagai mashdar dari kata dzaalika; artinya telah ditetapkan sebagai suatu ketetapan dari Allah (atas kamu, dan dihalalkan) ada yang membaca uhilla bentuk pasif ada pula ahalla bentuk aktif (bagi kamu selain yang demikian itu) artinya selain dari wanita-wanita yang telah diharamkan tadi (bahwa kamu mencari) istri (dengan hartamu) baik dengan maskawin atau lainnya (untuk dikawini bukan untuk dizinahi) (maka istri-istri) dengan arti faman (yang telah kamu nikmati) artinya campuri (di antara mereka) dengan jalan menyetubuhi mereka (maka berikanlah kepada mereka upah mereka) maksudnya maskawin mereka yang telah kamu tetapkan itu (sebagai suatu kewajiban. Dan kamu tidaklah berdosa mengenai sesuatu yang telah saling kamu relakan) dengan mereka (setelah ditetapkan itu) baik dengan menurunkan, menambah atau merelakannya. (Sesungguhnya Allah Maha Mengetahui akan ciptaan-Nya (lagi Maha Bijaksana) dalam mengatur kepentingan mereka.\qt@no{24}}%
\qt@newcmd\qurantrans@id@dxviii{%
(Dan siapa yang tidak cukup biayanya untuk mengawini wanita-wanita merdeka) bukan budak (lagi beriman) ini yang berlaku menurut kebiasaan sehingga mafhumnya tidak berlaku (maka hamba sahaya yang kamu miliki) yang akan dikawininya (yakni dari golongan wanita-wanita kamu yang beriman. Dan Allah lebih mengetahui keimananmu) maka cukuplah kamu lihat lahirnya saja sedangkan batinnya serahkanlah kepada-Nya karena Dia mengetahui seluk-beluknya. Dan berapa banyaknya hamba sahaya yang lebih tinggi mutu keimanannya daripada wanita merdeka; ini merupakan bujukan agar bersedia kawin dengan hamba sahaya (sebagian kamu berasal dari sebagian yang lain) maksudnya kamu dan mereka itu sama-sama beragama Islam maka janganlah merasa keberatan untuk mengawini mereka (karena itu kawinilah mereka dengan seizin majikannya) artinya tuan dan pemiliknya (dan berikanlah kepada mereka upah) maksudnya mahar atau maskawin mereka (secara baik-baik) tanpa melalaikan atau menguranginya (sedangkan mereka pun hendaknya memelihara diri) menjadi hal (bukan melacurkan diri) atau berzina secara terang-terangan (serta tidak pula mengambil gundik) selir untuk berbuat zina secara sembunyi-sembunyi. (Maka jika mereka telah menjaga diri) artinya dikawinkan; dalam suatu qiraat dibaca ahshanna artinya telah kawin (lalu mereka melakukan perbuatan keji) maksudnya berzina (maka atas mereka separuh dari yang berlaku atas wanita-wanita merdeka) yakni yang masih perawan jika mereka berzina (berupa hukuman) atau hudud yaitu dengan didera 50 kali dan diasingkan setengah tahun. Dan kepada mereka ini dikiaskan hukuman bagi budak lelaki. Dan kawinnya hamba sahaya itu tidaklah dijadikan syarat untuk wajibnya hukuman, tetapi hanyalah untuk menunjukkan pada dasarnya mereka itu tidak menerima hukum rajam. (Demikian itu) maksudnya diperbolehkannya mengawini hamba sahaya sewaktu tak ada biaya itu (ialah bagi orang yang takut akan berzina) `anat artinya yang asli ialah masyaqqat atau kesulitan. Dinamakan zina demikian ialah karena dialah yang menyebabkan seseorang menerima hukuman berat di dunia dan siksa pedih di akhirat (di antara kamu). Ini berarti berbeda bagi orang yang tidak merasa khawatir dirinya akan jatuh dalam perzinaan, maka tidak halal baginya mengawini hamba sahaya itu. Demikian pula orang yang punya biaya untuk mengawini wanita-wanita merdeka. Pendapat ini juga dianut oleh Syafii. Hanya dalam firman Allah, ``... di antara wanita-wanitamu yang beriman," menurut Syafii tidak termasuk wanita-wanita kafir sehingga tidak boleh kawin walau ia dalam keadaan tidak mampu dan takut dirinya akan jatuh dalam perbuatan maksiat. (Dan jika kamu bersabar) artinya tidak mengawini hamba sahaya (itu lebih baik bagi kamu) agar kamu tidak mempunyai anak yang berstatus budak atau hamba sahaya. (Dan Allah Maha Pengampun lagi Maha Penyayang) dengan memberikan kelapangan dalam masalah itu.\qt@no{25}}%
\qt@newcmd\qurantrans@id@dxix{%
(Allah hendak menerangkan padamu) syariat-syariat agamamu dan kepentingan-kepentingan dirimu (dan memimpin kepada sunah-sunah) atau jalan-jalan (orang-orang yang sebelum kamu) dari para nabi dalam soal menghalalkan dan mengharamkan, sehingga kamu dapat mengikuti mereka (serta menerima tobatmu) dan membawa kamu kembali dari perbuatan maksiatmu selama ini kepada menaati-Nya. (Dan Allah Maha Mengetahui) keadaanmu (lagi Maha Bijaksana) mengenai rencana dan peraturan-peraturan-Nya terhadapmu.\qt@no{26}}%
\qt@newcmd\qurantrans@id@dxx{%
(Dan Allah hendak menerima tobatmu) diulang-Nya di sini untuk menjadi dasar pembinaan (sementara orang-orang yang mengikuti hawa nafsunya ingin) yakni orang-orang Yahudi, Nasrani atau Majusi atau yang gemar berzina (agar kamu berpaling sejauh-jauhnya) artinya menyimpang dari kebenaran dengan berbuat apa yang diharamkan sehingga kamu akan menjadi seperti mereka pula.\qt@no{27}}%
\qt@newcmd\qurantrans@id@dxxi{%
(Allah hendak memberi keringanan kepadamu) artinya memudahkan hukum-hukum syariat (karena manusia dijadikan bersifat lemah) tidak tahan menghadapi wanita dan godaan seksual.\qt@no{28}}%
\qt@newcmd\qurantrans@id@dxxii{%
(Hai orang-orang yang beriman! Janganlah kamu makan harta sesamamu dengan jalan yang batil) artinya jalan yang haram menurut agama seperti riba dan gasab/merampas (kecuali dengan jalan) atau terjadi (secara perniagaan) menurut suatu qiraat dengan baris di atas sedangkan maksudnya ialah hendaklah harta tersebut harta perniagaan yang berlaku (dengan suka sama suka di antara kamu) berdasar kerelaan hati masing-masing, maka bolehlah kamu memakannya. (Dan janganlah kamu membunuh dirimu) artinya dengan melakukan hal-hal yang menyebabkan kecelakaannya bagaimana pun juga cara dan gejalanya baik di dunia dan di akhirat. (Sesungguhnya Allah Maha Penyayang kepadamu) sehingga dilarang-Nya kamu berbuat demikian.\qt@no{29}}%
\qt@newcmd\qurantrans@id@dxxiii{%
(Dan siapa berbuat demikian) apa yang dilarang itu (dengan melanggar yang hak) menjadi hal (dan aniaya) menjadi taukid (maka akan Kami masukkan ia ke dalam neraka) ia akan dibakar hangus di dalamnya (dan demikian itu bagi Allah amat mudah) atau pekerjaan gampang.\qt@no{30}}%
\qt@newcmd\qurantrans@id@dxxiv{%
(Jika kamu menjauhi dosa-dosa besar di antara dosa-dosa yang dilarang kamu mengerjakannya) yakni dosa-dosa yang pernah pelakunya mendapat ancaman seperti membunuh, berzina, mencuri dan lain-lain yang menurut Ibnu Abbas banyaknya hampir tujuh ratus macam (niscaya Kami hapus kesalahan-kesalahanmu) yang kecil-kecil dengan jalan mengerjakan ketaatan (dan Kami masukkan kamu dengan pemasukan) dibaca mudkhalan atau madkhalan yang berarti pemasukan atau ke tempat (yang mulia) yaitu surga.\qt@no{31}}%
\qt@newcmd\qurantrans@id@dxxv{%
(Dan janganlah kamu mengangan-angankan karunia yang dilebihkan Allah kepada sebagian kamu dari sebagian lainnya) baik dari segi keduniaan maupun pada soal keagamaan agar hal itu tidak menimbulkan saling membenci dan mendengki. (Bagi laki-laki ada bagian) atau pahala (dari apa yang mereka usahakan) disebabkan perjuangan yang mereka lakukan dan lain-lain (dan bagi wanita ada bagian pula dari apa yang mereka usahakan) misalnya mematuhi suami dan memelihara kehormatan mereka. Ayat ini turun ketika Umu Salamah mengatakan, ``Wahai! Kenapa kita tidak menjadi laki-laki saja, hingga kita dapat berjihad dan beroleh pahala seperti pahala laki-laki," (dan mohonlah olehmu) ada yang memakai hamzah dan ada pula yang tidak (kepada Allah karunia-Nya) yang kamu butuhkan niscaya akan dikabulkan-Nya. (Sesungguhnya Allah Maha Mengetahui segala sesuatu) di antaranya siapa seharusnya yang beroleh karunia, begitu pula permohonan kamu kepada-Nya.\qt@no{32}}%
\qt@newcmd\qurantrans@id@dxxvi{%
(Dan bagi masing-masing) laki-laki dan wanita (Kami jadikan ahli waris) atau ashabah yang memperoleh (apa yang ditinggalkan oleh ibu bapak dan karib kerabat) bagi mereka berupa harta (dan mengenai orang-orang yang kamu telah berjanji dan bersumpah setia dengan mereka) `aqadat ada yang pakai alif sehingga menjadi `aaqadat; sedangkan aimaan jamak daripada yamiin berarti sumpah atau tangan sehingga kalimat itu berarti sumpah sekutu-sekutu kamu yang telah terikat dalam perjanjian denganmu di masa jahiliah buat tolong-menolong dan waris-mewarisi (maka berilah mereka) sekarang (bagian mereka) dari harta warisan yaitu seperenam (sesungguhnya Allah Maha Menyaksikan segala sesuatu) artinya mengetahui apa pun juga, termasuk hal-ihwalmu. Dan hukum ini telah dihapus dengan firman-Nya, ``Dan orang-orang yang mempunyai pertalian darah, sebagian mereka lebih utama dari sebagian lainnya."\qt@no{33}}%
\qt@newcmd\qurantrans@id@dxxvii{%
(Kaum lelaki menjadi pemimpin) artinya mempunyai kekuasaan (terhadap kaum wanita) dan berkewajiban mendidik dan membimbing mereka (oleh karena Allah telah melebihkan sebagian kamu atas lainnya) yaitu kekuasaan dan sebagainya (dan juga karena mereka telah menafkahkan) atas mereka (harta mereka. Maka wanita-wanita yang saleh ialah yang taat) kepada suami mereka (lagi memelihara diri di balik belakang)) artinya menjaga kehormatan mereka dan lain-lain sepeninggal suami (karena Allah telah memelihara mereka) sebagaimana dipesankan-Nya kepada pihak suami itu. (Dan wanita-wanita yang kamu khawatirkan nusyus) artinya pembangkangan mereka terhadap kamu misalnya dengan adanya ciri-ciri atau gejala-gejalanya (maka nasihatilah mereka itu) dan ingatkan supaya mereka takut kepada Allah (dan berpisahlah dengan mereka di atas tempat tidur) maksudnya memisahkan kamu tidur ke ranjang lain jika mereka memperlihatkan pembangkangan (dan pukullah mereka) yakni pukullah yang tidak melukai jika mereka masih belum sadar (kemudian jika mereka telah menaatimu) mengenai apa yang kamu kehendaki (maka janganlah kamu mencari gara-gara atas mereka) maksudnya mencari-cari jalan untuk memukul mereka secara aniaya. (Sesungguhnya Allah Maha Tinggi lagi Maha Besar) karena itu takutlah kamu akan hukuman-Nya jika kamu menganiaya mereka.\qt@no{34}}%
\qt@newcmd\qurantrans@id@dxxviii{%
(Dan jika kamu khawatir timbulnya persengketaan di antara keduanya) maksudnya di antara suami dengan istri terjadi pertengkaran (maka utuslah) kepada mereka atas kerelaan kedua belah pihak (seorang penengah) yakni seorang laki-laki yang adil (dari keluarga laki-laki) atau kaum kerabatnya (dan seorang penengah dari keluarga wanita) yang masing-masingnya mewakili pihak suami tentang putusannya untuk menjatuhkan talak atau menerima khuluk/tebusan dari pihak istri dalam putusannya untuk menyetujui khuluk. Kedua mereka akan berusaha sungguh-sungguh dan menyuruh pihak yang aniaya supaya sadar dan kembali, atau kalau dianggap perlu buat memisahkan antara suami istri itu. Firman-Nya: (jika mereka berdua bermaksud) maksudnya kedua penengah itu (mengadakan perbaikan, niscaya Allah memberikan taufik kepada mereka) artinya suami istri sehingga ditakdirkan-Nyalah mana-mana yang sesuai untuk keduanya, apakah perbaikan ataukah perceraian. (Sesungguhnya Allah Maha Mengetahui) segala sesuatu (lagi Maha Mengenali) yang batin seperti halnya yang lahir.\qt@no{35}}%
\qt@newcmd\qurantrans@id@dxxix{%
(Sembahlah olehmu Allah) dengan mengesakan-Nya (dan janganlah kamu mempersekutukan-Nya dengan suatu pun juga.) (Dan berbuat baiklah kepada kedua ibu bapak) dengan berbakti dan bersikap lemah lembut (kepada karib kerabat) atau kaum keluarga (anak-anak yatim, orang-orang miskin, tetangga yang karib) artinya yang dekat kepadamu dalam bertetangga atau dalam pertalian darah (dan kepada tetangga yang jauh) artinya yang jauh daripadamu dalam kehidupan bertetangga atau dalam pertalian darah (dan teman sejawat) teman seperjalanan atau satu profesi bahkan ada pula yang mengatakan istri (ibnu sabil) yaitu yang kehabisan biaya dalam perjalanannya (dan apa-apa yang kamu miliki) di antara hamba sahaya. (Sesungguhnya Allah tidak menyukai orang-orang yang sombong) atau takabur (membanggakan diri) terhadap manusia dengan kekayaannya.\qt@no{36}}%
\qt@newcmd\qurantrans@id@dxxx{%
(Orang-orang yang) menjadi mubtada (kikir) mengeluarkan apa yang wajib mereka keluarkan (dan menyuruh manusia supaya kikir pula) dengannya (serta menyembunyikan karunia yang telah diberikan Allah kepada mereka) berupa ilmu maupun harta, dan mereka ini ialah orang-orang Yahudi sedangkan yang menjadi khabar mubtadanya ialah: bagi mereka ancaman dahsyat (dan Kami sediakan bagi orang-orang yang kafir) terhadap hal itu dan hal-hal lainnya (siksa yang menghinakan).\qt@no{37}}%
\qt@newcmd\qurantrans@id@dxxxi{%
(Dan orang-orang yang) diathafkan kepada orang-orang yang sebelumnya (menafkahkan harta mereka karena riya kepada manusia) artinya karena mereka ingin dipuji (dan mereka tidak beriman kepada Allah dan tidak pula kepada hari akhir) misalnya orang-orang munafik dan kafir Mekah. (Barangsiapa yang menjadi sejawat setan) artinya temannya, maka ia akan mengikuti perintahnya dan akan melakukan seperti apa yang dilakukannya (maka setan itu adalah teman yang seburuk-buruknya).\qt@no{38}}%
\qt@newcmd\qurantrans@id@dxxxii{%
(Apa salahnya bagi mereka jika mereka beriman kepada Allah dan hari yang akhir serta menafkahkan sebagian rezeki yang diberikan Allah kepada mereka) artinya apa bencana dan kerugiannya bagi mereka? Pertanyaan ini berarti sanggahan, sedangkan 'lau' mashdariah, artinya tak ada mudaratnya di sana itu, hanya kondisi di mana mereka berada itulah yang membawa mudarat atau bencana. (Dan Allah Maha Mengetahui keadaan mereka) sehingga akan dibalas-Nya apa yang mereka lakukan.\qt@no{39}}%
\qt@newcmd\qurantrans@id@dxxxiii{%
(Sesungguhnya Allah tidak menganiaya) seorang pun (walau sebesar zarrah) artinya sebesar semut yang paling kecil, misalnya dengan mengurangi kebaikan-kebaikannya atau menambah kejahatan-kejahatannya (dan sekiranya ada kebaikan sebesar zarrah) dari seorang mukmin; menurut satu qiraat dengan baris di depan sehingga merupakan tammah (niscaya Allah akan melipatgandakannya) dari 10 sampai lebih dari 700 kali lipat. Menurut satu qiraat tanpa tasydid sehingga menjadi yudhaa`ifuha (dan mendatangkan dari sisi-Nya) di samping ganjaran yang berlipat ganda itu (pahala yang besar) tak dapat diperkirakan oleh seorang pun juga.\qt@no{40}}%
\qt@newcmd\qurantrans@id@dxxxiv{%
(Maka bagaimanakah) keadaan orang-orang kafir nanti (jika Kami datangkan dari setiap umat seorang saksi) yakni nabi mereka masing-masing yang menyaksikan amal perbuatan mereka (dan Kami datangkan kamu) hai Muhammad (sebagai saksi atas mereka itu) yakni umatmu.\qt@no{41}}%
\qt@newcmd\qurantrans@id@dxxxv{%
(Di hari itu) yakni hari kedatangannya (orang-orang kafir dan yang mendurhakai Rasul menginginkan agar) seandainya (mereka disamaratakan dengan tanah) tusawwaa dalam bentuk pasif dan ada pula yang membacanya dalam bentuk aktif dengan menghilangkan salah satu dari ta-nya pada asal lalu mengidgamkannya pada sin artinya dari tustawa sedangkan maksudnya ialah mereka ingin agar menjadi tanah karena mereka tercekam rasa takut yang hebat sebagaimana tersebut pada ayat lain, ``Dan orang kafir berkata, 'Wahai kiranya nasib, kenapa daku tidak menjadi tanah saja!' (dan mereka tidak dapat menyembunyikan kepada Allah suatu peristiwa pun) mengenai apa yang mereka kerjakan." Tetapi pada kali yang lain mereka masih mencoba-coba juga untuk menyembunyikan sebagaimana tersebut dalam Alquran, ``Dan mereka berkata, 'Demi Allah Tuhan kami, tidaklah kami mempersekutukan-Mu.'"\qt@no{42}}%
\qt@newcmd\qurantrans@id@dxxxvi{%
(Hai orang-orang yang beriman, janganlah kamu dekati salat) artinya janganlah salat (sedangkan kamu dalam keadaan mabuk) disebabkan minum-minuman keras. Asbabun nuzulnya ialah orang-orang salat berjemaah dalam keadaan mabuk (sehingga kamu mengerti apa yang kamu ucapkan) artinya sadar dan sehat kembali (dan tidak pula dalam keadaan junub) disebabkan bersetubuh atau keluar mani. Ia manshub disebabkan menjadi hal dan dipakai baik buat tunggal maupun buat jamak (kecuali sekadar melewati jalan) artinya selagi musafir atau dalam perjalanan (hingga kamu mandi lebih dulu) barulah kamu boleh melakukan salat itu. Dikecualikannya musafir boleh melakukan salat itu ialah karena baginya ada hukum lain yang akan dibicarakan nanti. Dan ada pula yang mengatakan bahwa yang dimaksud ialah larangan terhadap mendekati tempat-tempat salat atau mesjid, kecuali sekadar melewatinya saja tanpa mendiaminya. (Dan jika kamu sakit) yakni mengidap penyakit yang bertambah parah jika kena air (atau dalam perjalanan) artinya dalam bepergian sedangkan kamu dalam keadaan junub atau berhadas besar (atau seseorang di antaramu datang dari tempat buang air) yakni tempat yang disediakan untuk buang hajat artinya ia berhadas (atau kamu telah menyentuh perempuan) menurut satu qiraat lamastum itu tanpa alif, dan keduanya yaitu baik pakai alif atau tidak, artinya ialah menyentuh yakni meraba dengan tangan. Hal ini dinyatakan oleh Ibnu Umar, juga merupakan pendapat Syafii. Dan dikaitkan dengannya meraba dengan kulit lainnya, sedangkan dari Ibnu Abbas diberitakan bahwa maksudnya ialah jimak atau bersetubuh (kemudian kamu tidak mendapat air) untuk bersuci buat salat yakni setelah berusaha menyelidiki dan mencari. Dan ini tentu mengenai selain orang yang dalam keadaan sakit (maka bertayamumlah kamu) artinya ambillah setelah masuknya waktu salat (tanah yang baik) maksudnya yang suci, lalu pukullah dengan telapak tanganmu dua kali pukulan (maka sapulah muka dan tanganmu) berikut dua sikumu. Mengenai masaha atau menyapu, maka kata-kata itu transitif dengan sendirinya atau dengan memakai huruf. (Sesungguhnya Allah Maha Pemaaf lagi Maha Pengampun).\qt@no{43}}%
\qt@newcmd\qurantrans@id@dxxxvii{%
(Tidakkah kamu lihat orang-orang yang diberi bagian dari Alkitab) yakni orang-orang Yahudi (mereka membeli kesesatan) dengan petunjuk (dan menginginkan agar kamu sesat jalan) atau menempuh jalan yang tidak benar agar bernasib seperti mereka pula.\qt@no{44}}%
\qt@newcmd\qurantrans@id@dxxxviii{%
(Dan Allah lebih mengetahui tentang musuh-musuhmu) daripada kamu maka diberitakan-Nya kepada kamu keadaan mereka agar kamu tetap waspada (dan cukuplah Allah sebagai pelindung) atau pemeliharamu terhadap mereka (dan cukuplah Allah sebagai penolongmu) terhadap tipu daya mereka.\qt@no{45}}%
\qt@newcmd\qurantrans@id@dxxxix{%
(Di antara orang-orang Yahudi) ada suatu kaum (mereka mengubah perkataan-perkataan) yakni yang diturunkan Allah dalam Taurat berupa tanda-tanda dan sifat-sifat Nabi Muhammad saw. (dari tempat-tempatnya) semula (dan kata mereka) kepada Nabi saw. bila beliau menitahkan mereka mengerjakan sesuatu: ("Kami dengar) ucapanmu (dan kami langgar.") perintahmu (dan dengarlah padahal tidak ada yang akan didengar) menjadi hal yang berarti doa; artinya semoga saya tidak mendengarnya. (Dan) kata mereka pula kepadanya ("Ra`ina.") padahal mereka telah dilarang mengucapkannya karena dalam bahasa mereka kata-kata itu berarti makian (dengan memutar-mutar lidah mereka dan mencela) menjelekkan (agama) Islam. (Sekiranya mereka mengatakan, ``Kami dengar dan kami turut) sebagai ganti dari 'kami langgar' (dan dengarlah) saja (dan perhatikanlah kami") yaitu unzhurnaa sebagai ganti dari raa`inaa (tentulah itu lebih baik bagi mereka) daripada apa yang mereka ucapkan tadi (dan lebih tepat) lebih adil daripadanya. (Akan tetapi Allah mengutuk mereka) artinya menjauhkan mereka dari rahmat-Nya (disebabkan kekafiran mereka sehingga mereka tidaklah beriman selain hanya segelintir saja) misalnya Abdullah bin Salam dan para sahabatnya.\qt@no{46}}%
\qt@newcmd\qurantrans@id@dxl{%
(Hai orang-orang yang diberi Alkitab! Berimanlah kamu kepada apa-apa yang telah Kami turunkan) berupa Alquran (yang membenarkan apa yang berada padamu) yakni Taurat (sebelum Kami mengubah mukamu) dengan membuang mata, hidung dan alis yang terdapat padanya (lalu Kami putarkan ke belakang) sehingga menjadi rata dengan tengkuknya (atau Kami kutuk mereka) dengan menjadikan mereka sebagai kera (sebagaimana Kami telah mengutuk) menyerapah (pendurhaka-pendurhaka di hari Sabtu) di antara mereka (dan urusan Allah) maksudnya ketetapan-Nya (pasti berlaku). Tatkala ayat ini turun, maka masuk Islamlah Abdullah bin Salam. Maka ada yang mengatakan bahwa ini merupakan ancaman dengan suatu syarat karena setelah sebagian mereka masuk Islam, maka hukuman itu dibatalkan. Dan ada pula yang mengatakan bahwa baik perubahan wajah dan penjelmaan menjadi kera itu akan dilakukan sebelum terjadinya kiamat.\qt@no{47}}%
\qt@newcmd\qurantrans@id@dxli{%
(Sesungguhnya Allah tidak akan mengampuni bila Dia dipersekutukan) artinya tidak akan mengampuni dosa mempersekutukan-Nya (dan Dia akan mengampuni selain dari demikian) di antara dosa-dosa (bagi siapa yang dikehendaki-Nya) beroleh ampunan, sehingga dimasukkan-Nya ke dalam surga tanpa disentuh oleh siksa. Sebaliknya akan disiksa-Nya lebih dulu orang-orang mukmin yang dikehendaki-Nya karena dosa-dosa mereka, dan setelah itu barulah dimasukkan-Nya ke dalam surga. (Siapa mempersekutukan Allah, maka sesungguhnya ia telah berbuat dosa yang besar).\qt@no{48}}%
\qt@newcmd\qurantrans@id@dxlii{%
(Tidakkah kamu perhatikan orang-orang yang membersih-bersihkan diri mereka itu) yakni orang-orang Yahudi yang mengatakan bahwa mereka itu anak-anak Allah dan kekasih-kekasih-Nya. Jadi persoalannya kebaikan itu bukanlah dengan membersih-bersihkan diri (tetapi Allah membersihkan) artinya menyucikan (siapa yang dikehendaki-Nya) dengan keimanan (sedangkan mereka tidak dianiaya) atau dikurangi amalan mereka (sedikit pun) walau sebesar kulit buah kurma sekalipun.\qt@no{49}}%
\qt@newcmd\qurantrans@id@dxliii{%
(Perhatikanlah) menunjukkan keheranan (betapa mereka mengada-adakan kedustaan terhadap Allah) mengenai hal itu (dan cukuplah itu menjadi dosa yang nyata) bagi mereka. Ayat ini diturunkan berkenaan dengan Kaab bin Asyraf dan lain-lainnya dari kalangan ulama Yahudi, yaitu ketika mereka tiba di Mekah dan menyaksikan orang-orang musyrikin yang terbunuh dalam perang Badar, maka mereka membakar kaum musyrikin untuk membalas dendam atas kekalahan ini dan memerangi Nabi saw.:\qt@no{50}}%
\qt@newcmd\qurantrans@id@dxliv{%
(Tidakkah kamu perhatikan orang-orang yang diberi bagian dari Alkitab, mereka percaya kepada jibt dan tagut) nama dua berhala Quraisy (dan mengatakan kepada orang-orang kafir) yaitu Abu Sofyan dan sahabat-sahabatnya ketika mereka menanyakan kepada orang-orang Yahudi itu siapakah yang lebih benar jalannya, apakah mereka sebagai penguasa Kakbah, pelayan makan-minum jemaah haji dan pembantunya orang yang berada dalam kesukaran ataukah Muhammad, yakni orang yang telah menyalahi agama nenek moyangnya, memutuskan tali silaturahmi dan meninggalkan tanah suci? (bahwa mereka itu) maksudnya kamu hai orang-orang Quraisy (lebih benar jalannya dari orang-orang yang beriman) artinya lebih lurus jalan yang kamu tempuh daripada mereka.\qt@no{51}}%
\qt@newcmd\qurantrans@id@dxlv{%
(Mereka itulah orang-orang yang dikutuk oleh Allah dan siapa yang dikutuk) oleh (Allah, maka kamu sekali-kali tidak akan memperoleh penolongnya) yang akan melindunginya dari azab siksa-Nya.\qt@no{52}}%
\qt@newcmd\qurantrans@id@dxlvi{%
(Ataukah mereka ada mempunyai bagian kerajaan) maksudnya mereka tidak mempunyai sedikit pun daripadanya, dan walaupun ada (hingga bila demikian, maka tidak secuil pun yang akan mereka berikan kepada manusia) naqiira: sesuatu yang tak ada harganya, sebesar patukan burung kecil di atas biji, dan sikap mereka itu ialah karena amat bakhil atau kikirnya.\qt@no{53}}%
\qt@newcmd\qurantrans@id@dxlvii{%
(Atau) apakah (mereka dengki kepada manusia) maksudnya kepada Nabi saw. (atas karunia yang telah diberikan Allah kepada mereka itu) berupa kenabian dan banyaknya istri? Artinya mereka mengangankan lenyapnya nikmat itu daripadanya dan mengatakan, ``Sekiranya ia nabi, tentulah ia tidak akan menghiraukan banyak istri itu!" (Sungguh, Kami telah memberikan kepada keluarga Ibrahim) nenek moyang mereka seperti Musa, Daud dan Sulaiman (Kitab dan hikmah) serta nubuwah (dan telah Kami berikan kepada mereka kerajaan yang besar) Daud mempunyai 99 orang istri, sedangkan Sulaiman seribu orang wanita, campuran dari orang merdeka dan hamba sahaya.\qt@no{54}}%
\qt@newcmd\qurantrans@id@dxlviii{%
(Maka di antara mereka ada yang beriman kepadanya) yakni kepada Nabi Muhammad saw. (dan di antara mereka ada yang berpaling daripadanya) hingga ia tak mau beriman (dan cukuplah kiranya Jahanam itu sebagai api yang menyala-nyala) untuk membakar orang yang tidak beriman itu.\qt@no{55}}%
\qt@newcmd\qurantrans@id@dxlix{%
(Sesungguhnya orang-orang yang kafir akan ayat-ayat Kami akan Kami masukkan mereka ke dalam neraka) mereka akan terbakar hangus (setiap matang) atau menjadi hangus (kulit mereka itu Kami ganti dengan kulit lainnya) yakni dengan mengembalikannya kepada keadaannya sebelum matang atau hangus itu (supaya mereka merasakan azab) dan menderita kepedihannya. (Sesungguhnya Allah Maha Perkasa) dalam segala penciptaan-Nya.\qt@no{56}}%
\qt@newcmd\qurantrans@id@dl{%
(Dan orang-orang yang beriman dan beramal saleh kelak akan Kami masukkan mereka ke dalam surga yang di bawahnya mengalir anak-anak sungai; kekal mereka di sana untuk selama-lamanya. Mereka di dalamnya mempunyai istri-istri yang suci) dari haid dan dari segala kotoran (dan Kami masukkan mereka ke tempat yang senantiasa teduh berkepanjangan) artinya tidak diganggu oleh sinar matahari yang tiada lain dari naungan surga.\qt@no{57}}%
\qt@newcmd\qurantrans@id@dli{%
(Sesungguhnya Allah menyuruh kamu untuk menyampaikan amanat) artinya kewajiban-kewajiban yang dipercayakan dari seseorang (kepada yang berhak menerimanya) ayat ini turun ketika Ali r.a. hendak mengambil kunci Kakbah dari Usman bin Thalhah Al-Hajabi penjaganya secara paksa yakni ketika Nabi saw. datang ke Mekah pada tahun pembebasan. Usman ketika itu tidak mau memberikannya lalu katanya, ``Seandainya saya tahu bahwa ia Rasulullah tentulah saya tidak akan menghalanginya." Maka Rasulullah saw. pun menyuruh mengembalikan kunci itu padanya seraya bersabda, ``Terimalah ini untuk selama-lamanya tiada putus-putusnya!" Usman merasa heran atas hal itu lalu dibacakannya ayat tersebut sehingga Usman pun masuk Islamlah. Ketika akan meninggal kunci itu diserahkan kepada saudaranya Syaibah lalu tinggal pada anaknya. Ayat ini walaupun datang dengan sebab khusus tetapi umumnya berlaku disebabkan persamaan di antaranya (dan apabila kamu mengadili di antara manusia) maka Allah menitahkanmu (agar menetapkan hukum dengan adil. Sesungguhnya Allah amat baik sekali) pada ni`immaa diidgamkan mim kepada ma, yakni nakirah maushufah artinya ni`ma syaian atau sesuatu yang amat baik (nasihat yang diberikan-Nya kepadamu) yakni menyampaikan amanat dan menjatuhkan putusan secara adil. (Sesungguhnya Allah Maha Mendengar) akan semua perkataan (lagi Maha Melihat) segala perbuatan.\qt@no{58}}%
\qt@newcmd\qurantrans@id@dlii{%
(Hai orang-orang beriman! Taatlah kamu kepada Allah dan kepada rasul-Nya serta pemegang-pemegang urusan) artinya para penguasa (di antaramu) yakni jika mereka menyuruhmu agar menaati Allah dan Rasul-Nya. (Dan jika kamu berbeda pendapat) atau bertikai paham (tentang sesuatu, maka kembalikanlah kepada Allah) maksudnya kepada kitab-Nya (dan kepada Rasul) sunah-sunahnya; artinya selidikilah hal itu pada keduanya (yakni jika kamu benar-benar beriman kepada Allah dan hari akhir. Demikian itu) artinya mengembalikan pada keduanya (lebih baik) bagi kamu daripada bertikai paham dan mengandalkan pendapat manusia (dan merupakan rujukan yang sebaik-baiknya). Ayat berikut ini turun tatkala terjadi sengketa di antara seorang Yahudi dengan seorang munafik. Orang munafik ini meminta kepada Kaab bin Asyraf agar menjadi hakim di antara mereka sedangkan Yahudi meminta kepada Nabi saw. lalu kedua orang yang bersengketa itu pun datang kepada Nabi saw. yang memberikan kemenangan kepada orang Yahudi. Orang munafik itu tidak rela menerimanya lalu mereka mendatangi Umar dan si Yahudi pun menceritakan persoalannya. Kata Umar kepada si munafik, ``Benarkah demikian?" ``Benar," jawabnya. Maka orang itu pun dibunuh oleh Umar.\qt@no{59}}%
\qt@newcmd\qurantrans@id@dliii{%
(Tidakkah kamu perhatikan orang-orang yang mengakui diri mereka telah beriman kepada apa yang diturunkan kepadamu dan apa yang diturunkan sebelum kamu; mereka hendak bertahkim kepada tagut) artinya orang yang banyak berbuat kedurhakaan, yaitu Kaab bin Asyraf (padahal mereka sudah dititahkan untuk mengingkarinya) dan tak akan memuliakan serta tidak mengangkatnya sebagai pemimpin. (Dan setan bermaksud menyesatkan mereka dengan kesesatan yang sejauh-jauhnya) yakni dari kebenaran.\qt@no{60}}%
\qt@newcmd\qurantrans@id@dliv{%
(Dan apabila dikatakan kepada mereka, marilah kamu kembali kepada apa yang diturunkan Allah) dalam Alquran berupa hukum-hukum (dan kepada rasul) agar dapat mengadili kamu (maka kamu lihat orang-orang munafik berpaling daripadamu) kepada yang lain (sejadi-jadinya.)\qt@no{61}}%
\qt@newcmd\qurantrans@id@dlv{%
(Maka betapa jadinya) dan apa yang akan mereka perbuat (jika mereka ditimpa oleh musibah) atau hukuman (disebabkan perbuatan tangan mereka) berupa perbuatan-perbuatan maksiat dan kekafiran, apakah mereka mampu berpaling dan melarikan diri daripadanya? Tentu saja tidak! (Kemudian mereka datang kepadamu) diathafkan kepada yashudduuna (sambil bersumpah atas nama Allah, ``Tidaklah kami kehendaki) dengan bertahkim kepada orang lain (kecuali penyelesaian) atau perdamaian (dan kerukunan) di antara dua pihak yang bermusuhan dengan mengadakan pendekatan-pendekatan terhadap hukum dan bukan menyamarkan perkara yang benar."\qt@no{62}}%
\qt@newcmd\qurantrans@id@dlvi{%
(Mereka itu adalah orang-orang yang diketahui Allah isi hati mereka) berupa kemunafikan dan kedustaan mereka dalam mengajukan alasan (maka berpalinglah kamu dari mereka) dengan memberi mereka maaf (dan berilah mereka nasihat) agar takut kepada Allah (serta katakanlah kepada mereka tentang) keadaan (diri mereka perkataan yang dalam) artinya yang berbekas dan mempengaruhi jiwa, termasuk bantahan dan hardikan agar mereka kembali dari kekafiran.\qt@no{63}}%
\qt@newcmd\qurantrans@id@dlvii{%
(Dan Kami tidak mengutus seorang rasul kecuali untuk ditaati) segala yang diperintahkan dan diputuskannya (dengan izin Allah) dengan perintah-Nya; jadi bukan untuk ditentang atau didurhakai. (Dan sekiranya mereka ketika menganiaya kepada diri mereka itu) dengan bertahkim kepada tagut (segera datang kepadamu) dengan bertobat (lalu memohon ampun kepada Allah dan rasul pun memohonkan ampun untuk mereka) di sini terdapat peralihan arah pembicaraan demi meninggikan kedudukannya (tentulah akan mereka temui Allah Maha Penerima tobat) terhadap mereka (lagi Maha Penyayang) kepada mereka.\qt@no{64}}%
\qt@newcmd\qurantrans@id@dlviii{%
(Maka demi Tuhanmu) la menjadi tambahan (mereka tidaklah beriman sebelum menjadikanmu sebagai hakim tentang urusan yang menjadi pertikaian) atau sengketa (di antara mereka kemudian mereka tidak merasakan dalam hati mereka suatu keberatan) atau keragu-raguan (tentang apa yang kamu putuskan dan mereka menerima) atau tunduk kepada putusanmu itu (dengan sepenuhnya) tanpa bimbang atau ragu.\qt@no{65}}%
\qt@newcmd\qurantrans@id@dlix{%
(Dan seandainya Kami wajibkan kepada mereka) an sebagai penafsiran ("Bunuhlah dirimu," atau, ``Keluarlah kamu dari kampungmu,") sebagaimana telah Kami lakukan terhadap Bani Israel (tidaklah mereka akan melakukannya) apa yang diharuskan itu (kecuali sebagian kecil) dibaca marfu` sebagai badal dan manshub sebagai mustatsna (di antara mereka. Dan sekiranya mereka melakukan apa yang dinasihatkan kepada mereka itu) yakni menaati Rasul (tentulah hal itu lebih baik bagi mereka dan lebih menguatkan) lebih memantapkan keimanan mereka.\qt@no{66}}%
\qt@newcmd\qurantrans@id@dlx{%
(Dan jika demikian halnya) artinya jika mereka teguh dalam pendirian (tentulah akan Kami berikan kepada mereka dari sisi Kami pahala yang besar) yakni surga.\qt@no{67}}%
\qt@newcmd\qurantrans@id@dlxi{%
(Dan tentulah akan Kami bimbing mereka ke jalan yang lurus). Kata sebagian sahabat kepada Nabi saw., ``Betapa caranya kami dapat melihat baginda dalam surga padahal baginda berada pada tingkat yang tinggi sedangkan kami di tingkat bawah?" Maka turunlah ayat:\qt@no{68}}%
\qt@newcmd\qurantrans@id@dlxii{%
(Dan siapa yang menaati Allah dan Rasul) tentang apa yang dititahkan keduanya (maka mereka itu bersama orang-orang yang diberi karunia oleh Allah, yaitu golongan nabi-nabi dan shiddiqin) sahabat-sahabat utama dari para nabi-nabi dan rasul-rasul yang membenarkan dan amat teguh kepercayaan kepada mereka (para syuhada) orang-orang yang gugur syahid di jalan Allah (dan orang-orang saleh) yakni selain dari yang telah disebutkan itu. (Dan mereka itulah teman-teman yang sebaik-baiknya) maksudnya teman-teman dalam surga karena dapat melihat wajah mereka, berkunjung dan menghadiri majelis mereka walaupun tempat mereka jika dibandingkan dengan golongan-golongan lainnya lebih tinggi dan lebih mulia.\qt@no{69}}%
\qt@newcmd\qurantrans@id@dlxiii{%
(Demikian itu) artinya keadaannya bersama orang-orang yang disebutkan itu, menjadi mubtada sedangkan khabarnya ialah (karunia dari Allah) yang dianugerahkan-Nya kepada mereka, jadi bukan hasil dari ketaatan mereka sendiri. (Dan Allah cukup mengetahui) tentang pahala-pahala di akhirat, maka percayalah kamu kepada-Nya karena tak ada lagi yang lebih berwenang dalam penyampaian berita itu daripada-Nya.\qt@no{70}}%
\qt@newcmd\qurantrans@id@dlxiv{%
(Hai orang-orang yang beriman, waspadalah kamu) terhadap musuh-musuhmu; artinya bersiap-siaplah dan berhati-hatilah menghadapi mereka (dan majulah kamu secara berkelompok-kelompok) atau terpisah-pisah pasukan demi pasukan (atau majulah secara bersama-sama) dalam satu pasukan besar.\qt@no{71}}%
\qt@newcmd\qurantrans@id@dlxv{%
(Dan sungguh di antara kamu ada orang yang berlambat-lambat) atau bersikap lamban menghadapi peperangan, seperti Abdullah bin Ubai si munafik dan kawan-kawannya itu. Dia dianggap termasuk golongan munafik melihat sikap dan tindakan-tindakannya. Lam yang terdapat pada kata kerja berarti sumpah. (Jika kamu ditimpa musibah) seperti terbunuh atau kekalahan (maka katanya, ``Sesungguhnya Allah telah memberi nikmat kepadaku sehingga aku tak ikut hadir bersama mereka) yang akan menyebabkanku ditimpa musibah pula.\qt@no{72}}%
\qt@newcmd\qurantrans@id@dlxvi{%
(Dan sungguh jika) lam menunjukkan sumpah (kamu beroleh karunia dari Allah) seperti kemenangan atau harta rampasan (tentulah dia akan berkata) sambil menyesal (seolah-olah) ditakhfifkan sedangkan isimnya dibuang dan diperkirakan berbunyi kaannahu artinya seolah-olah (belum pernah ada) pakai ya atau ta (di antaramu dengannya kasih sayang) artinya perkenalan dan persahabatan. Dan ini kembali kepada ucapannya tadi, 'Aku telah memberi nikmat kepadaku,' yang diselangnya di antara ucapan itu dengan perkataannya sekarang ini, yaitu (Wahai) sebagai kata peringatan (sekiranya aku berada bersama mereka tentu aku akan mendapat keberuntungan yang besar pula.") maksudnya beroleh harta rampasan yang banyak. Firman Allah swt.:\qt@no{73}}%
\qt@newcmd\qurantrans@id@dlxvii{%
(Maka hendaklah berperang di jalan Allah) demi untuk meninggikan agama-Nya (orang-orang yang membeli) artinya menukar (kehidupan dunia dengan akhirat. Siapa yang berperang di jalan Allah lalu ia gugur) mati syahid (atau memperoleh kemenangan) terhadap musuhnya (maka nanti akan Kami beri ia pahala yang besar.)\qt@no{74}}%
\qt@newcmd\qurantrans@id@dlxviii{%
(Mengapa kamu tak hendak berperang) pertanyaan yang berarti celaan; maksudnya tak ada halangannya bagi kamu untuk berperang (di jalan Allah dan) untuk membebaskan (golongan yang lemah baik laki-laki, wanita maupun anak-anak) yakni yang ditahan oleh orang-orang kafir buat berhijrah dan yang dianiaya mereka. Berkata Ibnu Abbas r.a., ``Saya dan ibu saya termasuk golongan ini," (yang mengatakan) atau berdoa, ``Wahai (Tuhan kami! Keluarkanlah kami dari negeri ini) Mekah (yang penduduknya aniaya) disebabkan kekafiran (dan berilah kami dari sisi-Mu seorang pelindung) yang akan mengatur urusan kami (dan berilah kami dari sisi-Mu seorang pembela.") yang mempertahankan kami terhadap mereka. Allah telah mengabulkan permohonan mereka ini, maka dimudahkan-Nya sebagian mereka itu untuk keluar sedangkan sisanya tinggal di Mekah sampai kota itu berhasil dibebaskan lalu Nabi saw. mengangkat Itab bin Usaid sebagai penguasa di Mekah, maka dibelanya orang-orang teraniaya dari penganiaya-penganiayanya.\qt@no{75}}%
\qt@newcmd\qurantrans@id@dlxix{%
(Orang-orang yang beriman berperang di jalan Allah sedangkan orang-orang kafir berperang di jalan tagut) setan. (Maka perangilah anak buah setan itu) maksudnya penyokong-penyokong agamanya niscaya kamu akan beroleh kemenangan karena kekuatanmu dengan Allah. (Sesungguhnya tipu daya setan) terhadap orang-orang beriman (adalah lemah) tidak akan dapat mengatasi siasat Allah terhadap orang-orang kafir itu.\qt@no{76}}%
\qt@newcmd\qurantrans@id@dlxx{%
(Tidakkah kamu perhatikan orang-orang yang dikatakan kepada mereka, ``Tahanlah tanganmu) dari memerangi orang-orang kafir tatkala hal itu mereka tuntut di Mekah disebabkan penganiayaan orang-orang kafir terhadap mereka. Dan mereka ini ialah segolongan sahabat (dan dirikanlah salat serta bayarkanlah zakat." Maka setelah diwajibkan atas mereka berperang tiba-tiba sebagian dari mereka takut kepada manusia) maksudnya kepada orang-orang kafir disebabkan tindakan dan keberanian mereka dalam peperangan itu (seperti menakuti) siksa (Allah bahkan lebih takut lagi) daripada itu. Asyadda dibaca manshub karena menjadi hal juga sebagai jawaban terhadap apa yang ditunjukkan oleh idzaa dan yang sesudahnya artinya tiba-tiba mereka didatangi oleh ketakutan. (kata mereka) karena cemas menghadapi maut ("Wahai Tuhan kami! Kenapa Engkau wajibkan atas kami berperang? Kenapa tidak Engkau tangguhkan agak beberapa waktu lagi?" Katakanlah) kepada mereka ("Kesenangan dunia) maksudnya apa-apa yang disenangi dan dinikmati di dunia ini (hanya sebentar) dan akan kembali lenyap (sedangkan akhirat) maksudnya surga (lebih baik bagi orang yang takwa) yakni yang menjaga diri dari siksa Allah dengan menjauhi larangan-Nya (dan kamu tidak akan dianiaya) dibaca dengan ta dan ya artinya tidak akan dikurangi amalmu (sedikit pun.") artinya walau sebesar kulit padi sekali pun, maka berjihad atau berusahalah.\qt@no{77}}%
\qt@newcmd\qurantrans@id@dlxxi{%
(Di mana pun kamu berada, pastilah akan dicapai oleh maut sekalipun kamu di benteng yang tinggi lagi kokoh) karena itu janganlah takut berperang lantaran cemas akan mati. (Dan jika mereka ditimpa) yakni orang-orang Yahudi (oleh kebaikan) misalnya kesuburan dan keluasan (mereka berkata, ``Ini dari Allah." Dan jika mereka ditimpa oleh keburukan) misalnya kekeringan dan bencana seperti yang mereka alami sewaktu kedatangan Nabi saw. ke Madinah (mereka berkata, ``Ini dari sisimu,") hai Muhammad artinya ini karena kesialanmu! (Katakanlah) kepada mereka (Semuanya) baik kebaikan atau keburukan (dari sisi Allah) berasal daripada-Nya. (Maka mengapa orang-orang itu hampir-hampir tidak memahami pembicaraan) yang disampaikan kepada Nabi mereka. Mengapa pertanyaan disertai keheranan, melihat kebodohan mereka yang amat sangat. Dan ungkapan ``hampir-hampir tidak memahami" lebih berat lagi dari ``tidak memahaminya sama sekali."\qt@no{78}}%
\qt@newcmd\qurantrans@id@dlxxii{%
(Apa pun yang kamu peroleh) hai manusia (berupa kebaikan, maka dari Allah) artinya diberi-Nya kamu karena karunia dan kemurahan-Nya (dan apa pun yang menimpamu berupa keburukan) atau bencana (maka dari dirimu sendiri) artinya karena kamu melakukan hal-hal yang mengundang datangnya bencana itu. (Dan Kami utus kamu) hai Muhammad (kepada manusia sebagai rasul) menjadi hal yang diperkuat. (Dan cukuplah Allah sebagai saksi) atas kerasulanmu.\qt@no{79}}%
\qt@newcmd\qurantrans@id@dlxxiii{%
(Siapa menaati Rasul, maka sesungguhnya ia telah menaati Allah, dan siapa yang berpaling) artinya tak mau menaatinya, maka bukan menjadi urusanmu (maka Kami tidaklah mengutusmu sebagai pemelihara) atau penjaga amal-amal perbuatan mereka, tetapi hanyalah sebagai pemberi peringatan sedangkan urusan mereka terserah kepada Kami dan Kami beri ganjaran dan balasannya. Ini sebelum datangnya perintah berperang.\qt@no{80}}%
\qt@newcmd\qurantrans@id@dlxxiv{%
(Dan mereka berkata) maksudnya orang-orang munafik, jika mereka datang kepadamu, ``Kewajiban kami hanyalah (taat) kepadamu." (Tetapi apabila mereka telah keluar dari sisimu, segolongan di antara mereka menyembunyikan) ta diidgamkan kepada tha dan boleh pula tidak (lain dari apa yang mereka katakan) padamu di hadapanmu tadi berupa ketaatan, tegasnya mereka menyembunyikan kedurhakaan mereka (Allah menulis) maksudnya menyuruh malaikat menulis (apa yang mereka sembunyikan itu) yakni dalam buku-buku catatan mereka agar menerima pembalasan nanti (maka berpalinglah kamu dari mereka) dengan memaafkan mereka (dan bertawakallah kepada Allah) artinya percayalah kepada-Nya karena Dia pasti melindungimu (dan cukuplah Allah itu sebagai pelindung) atau tempat bertawakal.\qt@no{81}}%
\qt@newcmd\qurantrans@id@dlxxv{%
(Apakah mereka tidak memperhatikan) merenungkan (Alquran) dan makna-makna indah yang terdapat di dalamnya. (Sekiranya Alquran itu bukan dari sisi Allah, tentulah akan mereka jumpai di dalamnya pertentangan yang banyak) baik dalam makna maupun dalam susunannya.\qt@no{82}}%
\qt@newcmd\qurantrans@id@dlxxvi{%
(Dan apabila datang kepada mereka suatu berita) mengenai hasil-hasil yang dicapai oleh ekspedisi tentara Nabi saw. (berupa keamanan) maksudnya kemenangan (atau ketakutan) maksudnya kekalahan (mereka lalu menyiarkannya). Ayat ini turun mengenai segolongan kaum munafik atau segolongan orang-orang mukmin yang lemah iman mereka, dan dengan perbuatan mereka itu lemahlah semangat orang-orang mukmin dan kecewalah Nabi saw. (Padahal kalau mereka menyerahkannya) maksudnya berita itu (kepada Rasul dan kepada Ulil amri di antara mereka) maksudnya para pembesar sahabat, jika mereka diam mengenai berita itu menunggu keputusannya (tentulah akan dapat diketahui) apakah hal itu boleh disiarkan atau tidak (oleh orang-orang yang ingin mengetahui kebenarannya) artinya yang mengikuti perkembangannya dan dituntut untuk mengetahuinya, mereka adalah orang-orang yang berhak menyiarkan berita itu (dari mereka) yakni Rasul dan Ulil amri (Dan kalau bukanlah karena karunia Allah kepadamu) yakni dengan agama Islam (serta rahmat-Nya) kepadamu dengan Alquran (tentulah kamu sekalian akan mengikuti setan) untuk mengerjakan kekejian-kekejian yang diperintahkannya (kecuali sebagian kecil saja di antaramu) yang tidak.\qt@no{83}}%
\qt@newcmd\qurantrans@id@dlxxvii{%
(Maka berperanglah kamu) hai Muhammad (di jalan Allah kamu tidaklah dibebani kecuali dengan kewajibanmu sendiri) maka janganlah pedulikan keengganan mereka dalam berperang itu. Artinya, berperanglah kamu walau seorang diri, karena kamu telah dijamin akan beroleh kemenangan (dan kerahkanlah orang-orang mukmin) anjurkan mereka buat bertempur dan kobarkan semangat mereka (semoga Allah menahan kekerasan) artinya serangan (orang-orang kafir itu. Dan Allah lebih keras lagi) dari mereka (dan lebih hebat lagi siksa-Nya). Maka sabda Nabi saw., ``Demi Tuhan yang diri saya berada dalam kekuasaan-Nya, saya akan pergi walaupun hanya seorang diri!" Lalu pergilah ia bersama 70 orang berkuda ke Badar Shughra sehingga Allah pun menolak serangan orang-orang kafir itu dengan meniupkan ketakutan ke dalam hati mereka dan menahan Abu Sofyan supaya tidak keluar sebagaimana telah disebutkan dalam surah Ali Imran.\qt@no{84}}%
\qt@newcmd\qurantrans@id@dlxxviii{%
(Siapa memberikan syafaat) kepada sesama manusia (yakni syafaat yang baik) yang sesuai dengan syarat (niscaya akan memperoleh bagian) pahala (daripadanya) artinya disebabkannya. (Dan siapa memberikan syafaat yang jelek) yakni yang bertentangan dengan syariat (maka ia akan memikul beban) dosanya (daripadanya) disebabkan perbuatannya itu. (Dan Allah Maha Kuasa atas segala sesuatu) sehingga setiap orang akan mendapat balasan yang setimpal daripada-Nya.\qt@no{85}}%
\qt@newcmd\qurantrans@id@dlxxix{%
(Apabila kamu diberi salam dengan suatu salam penghormatan) misalnya bila dikatakan kepadamu, ``Assalamu'alaikum!" (maka balaslah) kepada orang yang memberi salam itu (dengan salam yang lebih baik daripadanya) yaitu dengan mengatakan, ``Alaikumus salaam warahmatullaahi wabarakaatuh." (atau balaslah dengan yang serupa) yakni dengan mengucapkan seperti apa yang diucapkannya. Artinya salah satu di antaranya menjadi wajib sedangkan yang pertama lebih utama. (Sesungguhnya Allah memperhitungkan segala sesuatu) artinya membuat perhitungan dan akan membalasnya di antaranya ialah terhadap membalas salam. Dalam pada itu menurut sunah, tidak wajib membalas salam kepada orang kafir, ahli bidah dan orang fasik. Begitu pula kepada orang Islam sendiri yakni orang yang sedang buang air, yang sedang berada dalam kamar mandi dan orang yang sedang makan. Hukumnya menjadi makruh kecuali pada yang terakhir. Dan kepada orang kafir jawablah, ``Wa`alaikum." Artinya: juga atasmu.\qt@no{86}}%
\qt@newcmd\qurantrans@id@dlxxx{%
(Allah, tiada Tuhan selain Dia) dan Allah (akan menghimpun kamu) dari kubur-kuburmu (sampai) maksudnya pada (dari kiamat yang tak ada keraguan) atau kebimbangan (mengenainya. Dan siapa lagi) artinya tidak ada seorang pun (yang lebih benar ucapannya daripada Allah). Tatkala orang-orang kembali dari perang Uhud, mereka berbeda pendapat mengenai orang-orang munafik. Suatu golongan mengatakan, ``Bunuhlah mereka!" Sedangkan satu golongan lagi mengatakan, ``Jangan!" Maka turunlah ayat berikut ini:\qt@no{87}}%
\qt@newcmd\qurantrans@id@dlxxxi{%
(Mengapa kamu menjadi dua golongan menghadapi golongan munafik padahal Allah telah membalikkan mereka menjadi kafir) (disebabkan usaha mereka) berupa perbuatan maksiat dan kekafiran. (Apakah kamu hendak menunjuki orang yang disesatkan oleh Allah) artinya kamu anggap mereka itu termasuk orang-orang yang beroleh petunjuk? Pertanyaan pada kedua tempat berarti sanggahan. (Siapa yang disesatkan oleh Allah maka kamu sekali-kali takkan mendapatkan jalan) untuk menunjukinya.\qt@no{88}}%
\qt@newcmd\qurantrans@id@dlxxxii{%
(Mereka ingin) atau mengangan-angankan (agar kamu kafir hingga kamu menjadi sama) dengan mereka dalam kekafiran (maka janganlah kamu ambil di antara mereka sebagai pembela) yang akan membelamu walaupun mereka menampakkan keimanan (hingga mereka berhijrah di jalan Allah) yakni benar-benar hijrah yang membuktikan keimanan mereka. (Jika mereka berpaling) dan tetap atas keadaan mereka (maka ambillah mereka itu) maksudnya tawanlah (dan bunuhlah mereka di mana saja kamu jumpai dan janganlah kamu jadikan seorang pun di antara mereka sebagai pelindung) yang akan melindungimu (dan tidak pula sebagai penolong) yang akan kamu mintai pertolongan untuk menghadapi musuh-musuhmu.\qt@no{89}}%
\qt@newcmd\qurantrans@id@dlxxxiii{%
(Kecuali orang-orang yang menghubungi) maksudnya minta perlindungan (kepada suatu kaum yang antara kamu dengan mereka ada perjanjian damai) termasuk dengan sekutu-sekutu mereka sebagaimana pernah terjadi antara Nabi saw. dengan Hilal bin Uwaimir Al-Aslami (atau) orang-orang yang (datang kepadamu) sedangkan (hati mereka merasa keberatan) untuk (memerangimu) bersama kaum mereka (atau memerangi kaum mereka) bersama kamu; artinya tak mau berperang dengan kamu maupun dengan kaum mereka, maka janganlah kamu tawan atau bunuh mereka. Ini berikut yang sesudahnya dinasakhkan oleh ayat perang. (Sekiranya Allah menghendaki) agar mereka menguasaimu (tentulah Dia akan menjadikan mereka berkuasa atasmu) yaitu dengan menguatkan hati mereka (sehingga pastilah mereka memerangimu) tetapi Allah tiada menghendaki demikian, maka ditiupkan-Nya ke dalam hati mereka rasa takut dan ciut. (Tetapi jika mereka membiarkanmu dan tidak memerangi kamu hanya menyatakan perdamaian kepadamu) artinya mereka tunduk (maka Allah tidaklah memberi jalan kepadamu) untuk menawan dan membunuh mereka.\qt@no{90}}%
\qt@newcmd\qurantrans@id@dlxxxiv{%
(Akan kamu dapati pula golongan lain yang bermaksud supaya mereka aman dari kamu) dengan berpura-pura beriman di hadapanmu (dan merasa aman pula dari kaum mereka) dengan menyatakan kekafiran jika mereka kembali kepada kaum mereka. Mereka ini ialah Bani Asad dan Ghathafan. (Setiap mereka diajak untuk fitnah) artinya kembali kepada kemusyrikan (mereka pun berbalik) atau terjun ke dalamnya. (Maka jika mereka tidak membiarkanmu) artinya masih hendak memerangimu (dan) tidak (mengemukakan perdamaian kepadamu serta) tidak (menahan tangan mereka) dari memerangimu (maka ambillah mereka) sebagai tawanan (dan bunuhlah mereka itu di mana juga kamu temui) atau jumpai (dan mereka itulah orang-orang yang Kami berikan kepadamu kekuasaan yang nyata) artinya wewenang dan bukti yang jelas untuk membunuh dan menawan mereka disebabkan kecurangan mereka.\qt@no{91}}%
\qt@newcmd\qurantrans@id@dlxxxv{%
(Dan tidak sepatutnya seorang mukmin membunuh seorang mukmin) yang lain; artinya tidak layak akan timbul perbuatan itu dari dirinya (kecuali karena tersalah) artinya tidak bermaksud untuk membunuhnya. (Dan siapa yang membunuh seorang mukmin karena tersalah itu) misalnya bermaksud melempar yang selainnya seperti binatang buruan atau pohon kayu tetapi mengenai seseorang dengan alat yang biasanya tidak menyebabkan kematian hingga membawa ajal (maka hendaklah memerdekakan) membebaskan (seorang hamba sahaya yang beriman beserta diat yang diserahkan) diberikan (kepada keluarganya) yaitu ahli waris yang terbunuh (kecuali jika mereka bersedekah) artinya memaafkannya. Dalam pada itu sunah menjelaskan bahwa besar diat itu 100 ekor unta, 20 ekor di antaranya terdiri dari yang dewasa, sedang lainnya yang di bawahnya, dalam usia yang bermacam-macam. Beban pembayaran ini terpikul di atas pundak `ashabah sedangkan keluarga-keluarga lainnya dibagi-bagi pembayarannya selama tiga tahun, bagi yang kaya setengah dinar, dan yang sedang seperempat dinar pada tiap tahunnya. Jika mereka tidak mampu maka diambilkan dari harta baitulmal, dan jika sulit maka dari pihak yang bersalah. (Jika ia) yakni yang terbunuh (dari kaum yang menjadi musuh) musuh perang (bagimu padahal ia mukmin, maka hendaklah memerdekakan seorang hamba sahaya yang beriman) jadi bagi si pembunuh wajib kafarat tetapi tidak wajib diat yang diserahkan kepada keluarganya disebabkan peperangan itu. (Dan jika ia) maksudnya yang terbunuh (dari kaum yang di antara kamu dengan mereka ada perjanjian) misalnya ahli dzimmah (maka hendaklah membayar diat yang diserahkan kepada keluarganya) yaitu sepertiga diat orang mukmin, jika dia seorang Yahudi atau Nasrani, dan seperlima belas jika ia seorang Majusi serta memerdekakan seorang hamba sahaya yang beriman) oleh si pembunuhnya. (Siapa yang tidak memperolehnya) misalnya karena tak ada budak atau biayanya (maka hendaklah berpuasa selama dua bulan berturut-turut) sebagai kafarat yang wajib atasnya. Mengenai pergantian dengan makanan seperti pada zihar, tidak disebutkan oleh Allah swt. Tetapi menurut Syafii, pada salah satu di antara dua pendapatnya yang terkuat, ini diberlakukan (untuk penerimaan tobat dari Allah) mashdar yang manshub oleh kata kerjanya yang diperkirakan. (Dan Allah Maha Mengetahui) terhadap makhluk-Nya (lagi Maha Bijaksana) mengenai pengaturan-Nya terhadap mereka.\qt@no{92}}%
\qt@newcmd\qurantrans@id@dlxxxvi{%
(Dan siapa yang membunuh seorang mukmin dengan sengaja) artinya sengaja hendak membunuhnya dengan alat yang biasa dipergunakan untuk membunuh di samping ia tahu pula bahwa orang yang akan dibunuhnya itu beriman (maka balasannya ialah neraka Jahanam, kekal ia di dalamnya dan Allah murka kepadanya dan mengutukinya) artinya menjauhkannya dari rahmat-Nya (serta menyediakan baginya siksa yang besar) yakni di neraka. Ini ditakwilkan jika seseorang menganggapnya halal dengan pernyataan bahwa inilah balasannya yang setimpal jika dihukum menurut sepatutnya. Tetapi dengan catatan bahwa hukuman itu dapat saja diubah berdasarkan firman Allah swt., ``Dan Dia mengampuni dosa selain itu, syirik, bagi siapa yang dikehendaki-Nya." Dan menurut Ibnu Abbas bahwa ayat ini menasakhkan ayat-ayat lain yang berisi pengampunan sementara ayat pada surah Al-Baqarah menyatakan bahwa orang yang membunuh secara sengaja hendaklah dibunuh pula dan bahwa ia wajib membayar diat jika memperoleh kemaafan dan telah diterangkan pula berapa banyaknya. Di samping itu sunah menerangkan pula bahwa di antara sengaja dengan tersalah itu ada semacam pembunuhan yang disebut semi sengaja, yakni jika seseorang membunuh orang lain dengan alat yang tidak biasa digunakan untuk membunuh, maka tidak wajib kisas, hanya diat, sebagaimana pula sengaja dalam bentuk atau sifatnya tetapi tersalah dalam mengundurkan dan melakukannya. Dan ini dalam keadaan sengaja lebih patut membayar kafarat daripada dalam keadaan tersalah. Ayat berikut ini turun tatkala serombongan sahabat lewat pada seorang laki-laki dari Bani Sulaim yang sedang menghalau kambingnya. Orang itu memberi salam kepada rombongan sahabat itu tetapi kata mereka, ``Ia mengucapkan salam itu hanyalah untuk menyelamatkan dirinya," lalu orang itu mereka bunuh dan mereka halau ternaknya.\qt@no{93}}%
\qt@newcmd\qurantrans@id@dlxxxvii{%
(Hai orang-orang yang beriman, jika kamu bepergian) maksudnya mengadakan perjalanan untuk berjihad (di jalan Allah maka selidikilah) menurut satu qiraat dengan tiga macam baris pada dua tempat (dan janganlah kamu katakan kepada orang yang mengucapkan salam kepadamu) ada yang memakai alif dan ada pula yang tidak sedangkan artinya ialah penghormatan atau ketundukan dengan membaca dua kalimat syahadat sebagai ciri-ciri bagi penganut agama Islam (kamu bukan seorang mukmin) kamu mengatakan itu hanyalah untuk menjaga diri dan hartamu, lalu kamu membunuhnya (dengan maksud, menuntut) artinya hendak mencari (harta benda kehidupan dunia) yakni barang rampasan (padahal di sisi Allah harta yang banyak) sehingga kamu tidak perlu membunuh untuk mendapatkan harta itu. (Begitu pulalah keadaan kamu dahulu) darah dan harta bendamu dipelihara berkat ucapan syahadat dari kamu (lalu Allah melimpahkan karunia-Nya kepadamu) hingga terkenal keimanan dan keteguhan pendirianmu (karena itu selidikilah) lebih dulu jangan sampai kamu membunuh orang yang telah beriman dan perlakukanlah terhadap orang yang baru masuk Islam sebagaimana kamu pernah diperlakukan. (Sesungguhnya Allah Maha Mengetahui apa yang kamu kerjakan) sehingga kamu akan mendapat balasan daripada-Nya.\qt@no{94}}%
\qt@newcmd\qurantrans@id@dlxxxviii{%
(Tidaklah sama di antara orang-orang mukmin yang duduk) maksudnya tidak ikut berjihad (tanpa mempunyai uzur) seperti tua, buta dan lain-lain; marfu` karena sifat dan manshub sebagai mustatsna (dengan orang-orang yang berjihad di jalan Allah berikut harta dan jiwa mereka. Allah melebihkan orang-orang yang berjihad dengan harta dan jiwa mereka atas orang-orang yang duduk) karena uzur (satu tingkat) atau satu kelebihan karena walaupun mereka sama dalam niat, tetapi ada tambahan pada orang-orang yang berjihad, yaitu pelaksanaan (dan kepada masing-masing) mereka dari kedua golongan itu (Allah menjanjikan pahala yang baik) yaitu surga. (Dan Allah memberi kelebihan terhadap orang yang berjihad atas orang-orang yang duduk) tanpa uzur (berupa pahala yang besar) dan sebagai badalnya ialah:\qt@no{95}}%
\qt@newcmd\qurantrans@id@dlxxxix{%
(Yaitu beberapa tingkat daripada-Nya) yang sebagiannya lebih mulia dari lainnya (dan keampunan serta rahmat) manshub disebabkan kedua fi'ilnya yang diperkirakan (dan Allah Maha Pengampun) bagi para wali-Nya (lagi Maha Penyayang) terhadap ahli taat-Nya.\qt@no{96}}%
\qt@newcmd\qurantrans@id@dxc{%
(Sesungguhnya orang-orang yang diwafatkan oleh malaikat dalam keadaan menganiaya diri sendiri) maksudnya orang-orang yang tinggal bersama orang kafir di Mekah dan tidak hendak hijrah (malaikat bertanya) kepada mereka sambil mencela ("Kenapa kamu ini?" artinya bagaimana sebenarnya pendirianmu terhadap agamamu ini? (Ujar mereka) mengajukan alasan ("Kami ini orang-orang yang ditindas) artinya lemah sehingga tidak mampu menegakkan agama (di muka bumi") artinya di negeri Mekah (Kata mereka) pula sambil mencela ("Bukankah bumi Allah luas hingga kamu dapat berhijrah padanya?") yakni dari bumi kaum kafir ke negeri lain sebagaimana dilakukan orang lain? Firman Allah swt. ("Mereka itu, tempat mereka ialah neraka Jahanam dan itulah seburuk-buruk tempat kembali.")\qt@no{97}}%
\qt@newcmd\qurantrans@id@dxci{%
(Kecuali orang-orang yang tertindas baik laki-laki maupun wanita dan anak-anak) yaitu mereka (yang tidak mampu berusaha) artinya tak ada tenaga maupun biaya bagi mereka untuk berhijrah (dan tidak mengetahui jalan) yang akan ditempuh menuju tempat berhijrah itu.\qt@no{98}}%
\qt@newcmd\qurantrans@id@dxcii{%
(Maka mereka ini, moga-moga Allah memaafkan mereka dan Allah Maha Pemaaf lagi Maha Pengampun.)\qt@no{99}}%
\qt@newcmd\qurantrans@id@dxciii{%
(Dan siapa yang berhijrah di jalan Allah, maka mereka akan menemukan di muka bumi ini tempat hijrah yang banyak dan kelapangan) dalam rezeki. (Dan siapa yang keluar dari rumahnya dengan tujuan berhijrah kepada Allah dan Rasul-Nya lalu ia ditimpa oleh kematian) di tengah jalan seperti terjadi atas Junda bin Dhamrah Al-Laitsi (maka sungguh, telah tetaplah pahalanya di sisi Allah, dan Allah Maha Pengampun lagi Maha Penyayang).\qt@no{100}}%
\qt@newcmd\qurantrans@id@dxciv{%
(Dan jika kamu mengadakan perjalanan) atau bepergian (di muka bumi, maka tak ada salahnya kamu) (apabila mengqasar salat) dengan membuat yang empat rakaat menjadi dua (jika kamu khawatir akan diperangi) atau mendapat cidera dari (orang-orang kafir) menyatakan peristiwa yang terjadi di kala itu, maka mafhumnya tidak berlaku. Menurut keterangan dari sunah, yang dimaksud dengan suatu perjalanan panjang ialah empat pos atau dua marhalah. Dan dari firman-Nya, ``Maka tak ada salahnya kamu," ditarik kesimpulan bahwa mengqasar salat itu merupakan keringanan dan bukan kewajiban. Dan ini merupakan pendapat Imam Syafii. (Sesungguhnya orang-orang kafir itu bagi kamu musuh yang nyata) maksudnya jelas dan terang permusuhannya terhadap kamu.\qt@no{101}}%
\qt@newcmd\qurantrans@id@dxcv{%
(Dan apabila kamu) hai Muhammad, hadir (di tengah-tengah mereka) sedangkan kamu khawatir terhadap musuh (lalu kamu hendak mendirikan salat bersama mereka) ini berlaku menurut kebiasaan Alquran dalam pola pembicaraan sehingga dengan demikian mafhumnya tidak berlaku (maka hendaklah segolongan dari mereka berdiri, salat, bersamamu) sedangkan golongan lainnya mengundurkan diri (dan hendaklah mereka mengambil) artinya golongan yang berdiri salat bersamamu tadi (senjata-senjata mereka) bersama mereka. (Dan apabila mereka sujud) artinya telah menyelesaikan salat satu rakaat (maka hendaklah mereka) yakni rombongan yang pertama tadi (pergi ke belakangmu) untuk menjaga musuh sampai salat selesai (dan hendaklah datang golongan yang kedua yang belum salat lalu salat bersamamu dan hendaklah mereka bersikap waspada dan membawa senjata mereka) bersama mereka sampai mereka menyelesaikan salat itu. Dan hal ini pernah dilakukan Nabi saw. di lembah Nakhl, diriwayatkan oleh Bukhari dan Muslim. (Orang-orang kafir ingin agar kamu lengah) di waktu kamu mengerjakan salat (terhadap senjata dan harta bendamu lalu mereka menyerbu kamu sekaligus) yakni dengan menyerang dan menawan kamu. Inilah yang menjadi sebab kenapa kamu disuruh membawa senjata. (Dan tak ada salahnya bagimu meletakkan senjata-senjatamu kalau kamu mendapat gangguan dari hujan atau kamu dalam keadaan sakit) sehingga kamu tidak membawanya. Ini menunjukkan wajibnya membawa senjata di kala tak ada halangan, dan merupakan salah satu di antara kedua pendapat Syafii. Sedangkan pendapatnya yang kedua bahwa ini hanyalah sunah dan merupakan pendapat yang lebih kuat. (Dan hendaklah kamu bersikap waspada) terhadap musuh; artinya selalulah dalam keadaan siap siaga menghadapi serangannya. (Sesungguhnya Allah telah menyediakan bagi orang-orang kafir itu siksa yang menghinakan.)\qt@no{102}}%
\qt@newcmd\qurantrans@id@dxcvi{%
(Dan apabila kamu telah menyelesaikan salat, maka ingatlah Allah) dengan membaca tahlil dan tasbih (baik di waktu berdiri maupun di waktu duduk dan berbaring) tegasnya pada setiap saat. (Kemudian apabila kamu telah merasa tenteram) artinya aman dari bahaya (maka dirikanlah salat itu) sebagaimana mestinya. (Sesungguhnya salat itu atas orang-orang yang beriman adalah suatu kewajiban) artinya suatu fardu (yang ditetapkan waktunya) maka janganlah diundur atau ditangguhkan mengerjakannya. Ayat berikut turun tatkala Rasulullah saw. mengirim satu pasukan tentara untuk menyusul Abu Sofyan dan anak buahnya ketika mereka kembali dari perang Uhud. Mereka mengeluh karena menderita luka-luka:\qt@no{103}}%
\qt@newcmd\qurantrans@id@dxcvii{%
(Dan janganlah kamu merasa lemah) atau tidak mampu (dalam mengejar musuh) yakni orang-orang kafir yang kamu perangi (karena jika kamu menderita sakit) disebabkan karena luka misalnya (maka sesungguhnya mereka menderita sakit pula sebagaimana kamu menderitakannya) maksudnya nasib mereka sama dengan kamu, sedangkan mereka tidak merasa takut atau pesimis dalam menghadapimu (dan kamu mengharapkan dari Allah) kemenangan dan pahala (sesuatu yang tidak mereka harapkan) hingga sebetulnya kamu lebih unggul dan ada kelebihan dari mereka, maka seharusnya lebih berani dan bergairah. (Dan Allah Maha Mengetahui) segala sesuatu (lagi Maha Bijaksana) dalam perbuatan dan pengaturan-Nya. Suatu kali Thu'mah bin Ubairiq mencuri sebuah baju besi dan menyembunyikannya di rumah seorang Yahudi. Ketika baju besi itu ditemukan, Thu'mah menuduh si Yahudi dan si Yahudi bersumpah bahwa ia tidak mencurinya. Lalu kaum si Yahudi itu pun meminta kepada Nabi saw. agar membelanya dan membersihkan dirinya dari tuduhan tersebut, maka turunlah ayat:\qt@no{104}}%
\qt@newcmd\qurantrans@id@dxcviii{%
(Sesungguhnya Kami telah menurunkan kitab kepadamu) yakni Alquran (dengan benar) kaitannya ialah kepada ``menurunkan" (agar kamu mengadili di antara manusia dengan apa yang telah diajarkan Allah kepadamu). (Dan janganlah kamu menjadi pembela bagi orang yang berkhianat) seperti Thu`mah dan menjadi penentang mereka atau pihak lawannya.\qt@no{105}}%
\qt@newcmd\qurantrans@id@dxcix{%
(Dan mohonlah ampunlah kepada Allah) mengenai apa yang telah kamu rencanakan dan sedianya hendak kamu lakukan. (Sesungguhnya Allah Maha Pengampun lagi Maha Penyayang.)\qt@no{106}}%
\qt@newcmd\qurantrans@id@dc{%
(Dan janganlah kamu berdebat dengan orang-orang yang mengkhianati diri mereka) artinya berkhianat dengan jalan berbuat maksiat karena bencana pengkhianatan itu akan kembali kepada diri sendiri. (Sesungguhnya Allah tidak menyukai orang yang gemar berkhianat) artinya suka berkhianat (dan bergelimang dosa) hingga pasti akan menyiksanya.\qt@no{107}}%
\qt@newcmd\qurantrans@id@dci{%
(Mereka bersembunyi) maksudnya Thu'mah dan kaumnya disebabkan malu (dari manusia dan tidak bersembunyi dari Allah padahal Dia bersama mereka) yakni dengan ilmu-Nya (ketika pada suatu malam mereka menetapkan) artinya memutuskan secara rahasia (suatu rencana yang tidak diridai-Nya) yaitu rencana mereka mengucapkan sumpah tidak mencuri dan menuding si Yahudi melakukannya. (Dan Allah Maha Meliputi apa yang kamu kerjakan) maksudnya ilmu-Nya.\qt@no{108}}%
\qt@newcmd\qurantrans@id@dcii{%
(Demikianlah, kamu ini) hai (kamu sekalian) diarahkan kepada kaum Thu'mah (berdebat untuk membela mereka) yakni membela Thu'mah dan keluarganya; ada pula yang membaca `anhu artinya Thu'mah saja (dalam kehidupan dunia. Maka siapakah yang akan berdebat dengan Allah untuk membela mereka di hari kiamat nanti) artinya ketika Dia menyiksa mereka (atau siapakah yang akan menjadi pelindung mereka kelak?) yakni yang akan mengurus persoalan mereka dan mempertahankan mereka? Tegasnya tidak seorang pun yang mampu berbuat demikian.\qt@no{109}}%
\qt@newcmd\qurantrans@id@dciii{%
(Dan siapa yang mengerjakan kejahatan) atau dosa yang mengenai orang lain seperti Thu'mah yang menuduh si Yahudi (atau menganiaya dirinya) artinya berbuat dosa yang hanya menimpa dan terbatas pada dirinya sendiri (kemudian ia memohon ampun kepada Allah) atas perbuatannya itu atau ia bertobat (maka akan didapatinya Allah Maha Pengampun lagi Maha Penyayang) kepadanya.\qt@no{110}}%
\qt@newcmd\qurantrans@id@dciv{%
(Siapa yang berbuat dosa, maka sesungguhnya ia mengerjakannya untuk kerugian dirinya sendiri) karena bencananya akan menimpa dirinya dan bukan diri orang lain. (Dan Allah Maha Mengetahui lagi Maha Bijaksana) dalam segala perbuatan-Nya.\qt@no{111}}%
\qt@newcmd\qurantrans@id@dcv{%
(Dan siapa yang mengerjakan suatu kesalahan) atau satu dosa kecil (atau suatu dosa) besar (kemudian dituduhkannya kepada orang yang tidak bersalah) membuatnya (maka sesungguhnya ia telah memikul suatu kebohongan) dan tuduhannya (dan dosa yang nyata) disebabkan kerja dan usahanya itu.\qt@no{112}}%
\qt@newcmd\qurantrans@id@dcvi{%
(Dan kalau bukanlah karena karunia dan rahmat Allah kepadamu) hai Muhammad (tentulah segolongan mereka bertekad) yakni kaum Thu`mah (akan menyesatkanmu) sehingga dengan penipuan mereka kamu menyimpang dari pengadilan yang benar. (Tetapi yang mereka sesatkan hanyalah diri mereka sendiri sedangkan mereka tidak dapat memberi mudarat kepadamu) min merupakan tambahan (sedikit pun juga) karena bencana perbuatan mereka yang menyesatkan itu kembali pada diri mereka sendiri (Allah telah menurunkan kepadamu kitab) Alquran (dan hikmah) maksudnya hikmah-hikmah yang terkandung di dalamnya (dan mengajarkan kepadamu apa yang belum kamu ketahui) berupa hukum-hukum dan berita-berita gaib. (Dan karunia Allah padamu) disebabkan demikian dan karena lain-lainnya (amat besar).\qt@no{113}}%
\qt@newcmd\qurantrans@id@dcvii{%
(Tidak ada kebaikan pada kebanyakan bisikan-bisikan mereka) artinya bisikan-bisikan manusia dan apa yang mereka percakapkan (kecuali) bisikan (orang yang menyuruh mengeluarkan sedekah atau melakukan perbuatan baik) atau kebaikan (atau mengadakan perdamaian di antara manusia. Siapa yang melakukan demikian) yakni yang telah disebutkan tadi (demi menuntut) mencari (keridaan Allah) dan bukan karena hal-hal lainnya berupa urusan dunia (maka akan Kami beri dia) memakai nun dan ya maksudnya Allah (pahala yang besar).\qt@no{114}}%
\qt@newcmd\qurantrans@id@dcviii{%
(Dan siapa yang menyalahi) atau menentang (Rasul) mengenai kebenaran yang dibawanya (setelah nyata baginya petunjuk) artinya setelah jelas baginya kebenaran dengan adanya mukjizat-mukjizat (dan ia mengikuti) jalan (yang bukan jalan orang-orang mukmin) artinya jalan keagamaan yang biasa mereka lalui dengan cara menyimpang dan mengingkarinya (maka Kami jadikan ia menguasai apa yang telah dikuasainya berupa kesesatan) artinya Kami jadikan ia membina hubungan di antaranya dengan kesesatan itu di atas dunia, lalu (Kami masukkan ia) di akhirat (ke dalam neraka Jahanam) hingga ia terbakar hangus di dalamnya (dan itulah seburuk-buruk tempat kembali).\qt@no{115}}%
\qt@newcmd\qurantrans@id@dcix{%
(Sesungguhnya Allah tidak akan mengampuni dosa mempersekutukan sesuatu dengan-Nya, dan Dia akan mengampuni dosa selain itu bagi siapa yang dikehendaki-Nya. Dan siapa yang mempersekutukan sesuatu dengan Allah, maka sungguh ia telah tersesat sejauh-jauhnya) dari kebenaran.\qt@no{116}}%
\qt@newcmd\qurantrans@id@dcx{%
(Tidaklah) apa (yang mereka seru) atau yang disembah oleh orang-orang musyrik (selain daripada-Nya) maksudnya selain dari Allah swt. (hanyalah berhala-berhala) yakni berhala-berhala betina seperti Lata, Uzza dan Manat (dan tidaklah) apa (yang mereka seru) yang mereka sembah dengan beribadah kepadanya itu (kecuali setan yang durhaka) disebabkan ketaatan mereka dalam hal beribadah kepada setan atau iblis itu.\qt@no{117}}%
\qt@newcmd\qurantrans@id@dcxi{%
(Dia dikutuk oleh Allah) artinya dijauhkan dari rahmat-Nya (dan katanya) setan itu ("Akan saya ambil) untuk saya (dari hamba-hamba-Mu bagian yang telah ditetapkan) yang saya ajak untuk menaati saya!\qt@no{118}}%
\qt@newcmd\qurantrans@id@dcxii{%
(Dan sungguh, akan saya sesatkan mereka) dari kebenaran dengan waswas dan godaan (dan akan saya berikan pada mereka angan-angan) artinya saya masukkan ke dalam hati mereka harapan akan berumur panjang dan bahwa tak ada saat berbangkit atau hari pengadilan (dan saya suruh mereka memotong telinga binatang-binatang ternak) dan hal itu telah mereka lakukan pada ternak bahirah. (Dan saya suruh mereka mengubah ciptaan Allah.") maksudnya agama-Nya yaitu dengan kekafiran, menghalalkan apa yang diharamkannya dan mengharamkan apa yang dihalalkannya. (Dan siapa yang mengambil setan sebagai pelindung) yang ditaati dan dipatuhinya (selain dari Allah, maka sesungguhnya ia menderita kerugian yang nyata) artinya yang jelas, karena tempat kediamannya sudah jelas tiada lain dari neraka yang akan didiaminya untuk selama-lamanya.\qt@no{119}}%
\qt@newcmd\qurantrans@id@dcxiii{%
(Setan itu menjanjikan pada mereka) panjang umur (dan meniupkan angan-angan kosong) tercapainya cita-cita di dunia dan bahwa tak ada hari kebangkitan dan pembalasan (dan tidaklah apa yang dijanjikan setan itu) seperti yang disebutkan tadi (kecuali tipu daya belaka) atau kosong semata.\qt@no{120}}%
\qt@newcmd\qurantrans@id@dcxiv{%
(Mereka itu tempatnya ialah neraka Jahanam dan mereka tak dapat menghindarkan diri daripadanya.)\qt@no{121}}%
\qt@newcmd\qurantrans@id@dcxv{%
(Orang-orang yang beriman dan beramal saleh akan Kami masukkan mereka ke dalam surga yang di bawahnya mengalir anak-anak sungai, kekal mereka di dalamnya buat selama-lamanya. Itu adalah janji yang benar dari Allah) artinya Allah telah menjanjikan demikian kepada mereka dan Allah pastilah akan menepati janji-Nya. (Dan siapakah lagi) maksudnya tak ada lagi (yang lebih benar dari Allah ucapannya) perkataan dan janjinya. Ayat berikut turun tatkala kaum Muslimin dan golongan Ahli kitab membangga-banggakan diri mereka:\qt@no{122}}%
\qt@newcmd\qurantrans@id@dcxvi{%
(Tidaklah) masalahnya tergantung kepada (angan-anganmu dan tidak pula angan-angan Ahli kitab) tetapi kepada amal saleh. (Siapa mengerjakan kejahatan niscaya akan diberi pembalasan) adakalanya di akhirat dan adakalanya di dunia dengan cobaan dan bala bencana sebagaimana tersebut dalam sebuah hadis (dan tidaklah akan dijumpainya selain dari Allah pelindung) yang akan melindunginya (dan tidak pula pembela) yang akan membelanya.\qt@no{123}}%
\qt@newcmd\qurantrans@id@dcxvii{%
(Dan siapa yang mengerjakan) sesuatu (dari amal saleh, baik laki-laki atau wanita dan dia beriman, maka mereka itu akan masuk) ada yang membaca dalam bentuk aktif dan ada yang dalam bentuk pasif (ke dalam surga dan tidak akan dianiaya walau sedikit pun) walau sebesar lubang kecil sekalipun.\qt@no{124}}%
\qt@newcmd\qurantrans@id@dcxviii{%
(Dan siapakah) maksudnya tidak seorang pun (yang lebih baik agamanya daripada orang yang menyerahkan dirinya) artinya ia tunduk dan ikhlas dalam beramal (karena Allah, sedangkan dia berbuat kebaikan) bertauhid (serta mengikuti agama Ibrahim) yang sesuai dengan agama Islam (yang lurus) menjadi hal, arti asalnya jalan condong, maksudnya condong kepada agama yang lurus dan meninggalkan agama lainnya. (Dan Allah mengambil Ibrahim sebagai kesayangan-Nya) yang disayangi-Nya secara tulus dan murni.\qt@no{125}}%
\qt@newcmd\qurantrans@id@dcxix{%
(Dan milik Allahlah apa yang terdapat di langit dan apa yang terdapat di bumi) baik sebagai kepunyaan, maupun sebagai makhluk dan sebagai hamba. (Dan Allah Maha Meliputi segala sesuatu) maksudnya ilmu dan kekuasaan-Nya yang tetap melekat dan tidak terpisah-pisah daripada-Nya.\qt@no{126}}%
\qt@newcmd\qurantrans@id@dcxx{%
(Dan mereka minta fatwa kepadamu) mohon agar mereka diberi fatwa (tentang) keadaan (wanita) dan pembagian warisan mereka. (Katakanlah) kepada mereka!, ("Allah akan memberi fatwa kepada kamu tentang mereka itu, dan apa yang dibacakan kepadamu dalam Kitab) yakni Alquran berupa ayat warisan, juga memfatwakan padamu (tentang wanita-wanita yatim yang tidak kamu beri apa yang telah diwajibkan) (sebagai hak mereka) berupa pusaka (sedangkan kamu tak ingin) hai para wali (untuk mengawini mereka) disebabkan derajat mereka yang rendah atau paras mereka yang buruk, dan kamu halangi kawin karena mengharapkan harta warisan mereka itu. Maksudnya Allah mengeluarkan fatwa yang berisi supaya kamu jangan melakukan itu (dan) tentang (golongan yang dianggap lemah) atau masih kecil (di antara anak-anak) agar kamu berikan kepada mereka hak-hak mereka (dan) disuruhnya kamu (agar mengurus anak-anak yatim secara adil) dalam soal harta warisan dan maskawin. (Dan apa juga yang kamu kerjakan berupa kebaikan, maka sesungguhnya Allah Maha Mengetahuinya.") hingga akan membalasnya.\qt@no{127}}%
\qt@newcmd\qurantrans@id@dcxxi{%
(Dan jika seorang wanita) imra-atun marfu' oleh fi'il yang menafsirkannya (takut) atau khawatir (dari suaminya nusyuz) artinya sikap tak acuh hingga berpisah ranjang daripadanya dan melalaikan pemberian nafkahnya, adakalanya karena marah atau karena matanya telah terpikat kepada wanita yang lebih cantik dari istrinya itu (atau memalingkan muka) daripadanya (maka tak ada salahnya bagi keduanya mengadakan perdamaian yang sebenarnya). Ta yang terdapat pada asal kata diidgamkan pada shad, sedang menurut qiraat lain dibaca yushliha dari ashlaha. Maksud perdamaian itu ialah dalam bergilir dan pemberian nafkah, misalnya dengan sedikit mengalah dari pihak istri demi mempertahankan kerukunan. Jika si istri bersedia, maka dapatlah dilangsungkan perdamaian itu, tetapi jika tidak, maka pihak suami harus memenuhi kewajibannya atau menceraikan istrinya itu. (Dan perdamaian itu lebih baik) daripada berpisah atau dari nusyuz atau sikap tak acuh. Hanya dalam menjelaskan tabiat-tabiat manusia, Allah berfirman: (tetapi manusia itu bertabiat kikir) artinya bakhil, seolah-olah sifat ini selalu dan tak pernah lenyap daripadanya. Maksud kalimat bahwa wanita itu jarang bersedia menyerahkan haknya terhadap suaminya kepada madunya, sebaliknya pihak laki-laki jarang pula yang memberikan haknya kepada istri bila ia mencintai istri lain. (Dan jika kamu berlaku baik) dalam pergaulan istri-istrimu (dan menjaga diri) dari berlaku lalim atau aniaya kepada mereka (maka sesungguhnya Allah Maha Mengetahui apa yang kamu lakukan) hingga akan memberikan balasannya.\qt@no{128}}%
\qt@newcmd\qurantrans@id@dcxxii{%
(Dan kamu sekali-kali takkan dapat berlaku adil) artinya bersikap sama tanpa berat sebelah (di antara istri-istrimu) dalam kasih sayang (walaupun kamu amat menginginkan) demikian. (Sebab itu janganlah kamu terlalu cenderung) kepada wanita yang kamu kasihi itu baik dalam soal giliran maupun dalam soal pembagian nafkah (hingga kamu tinggalkan) wanita yang tidak kamu cintai (seperti bergantung) janda tidak bersuami pun bukan. (Dan jika kamu mengadakan perjanjian) yakni dengan berlaku adil dalam mengatur giliran (dan menjaga diri) dari berbuat kecurangan (maka sesungguhnya Allah Maha Pengampun) terhadap kecenderungan yang terdapat dalam hatimu (lagi Maha Penyayang) kepadamu dalam masalah tersebut.\qt@no{129}}%
\qt@newcmd\qurantrans@id@dcxxiii{%
(Jika keduanya berpisah) maksudnya laki-istri itu dengan perceraian (maka Allah akan memberi kecukupan kepada masing-masing mereka dari limpahan karunia-Nya) misalnya dengan menjodohkan pihak laki-laki dengan istri yang lain, dan pihak istri dengan suami yang lain. (Dan Allah Maha Luas) karunia-Nya terhadap makhluk-Nya (lagi Maha Bijaksana) mengenai peraturan-peraturan yang ditetapkan-Nya bagi mereka.\qt@no{130}}%
\qt@newcmd\qurantrans@id@dcxxiv{%
(Dan milik Allahlah apa yang terdapat di langit dan apa yang terdapat di bumi. Dan sungguh telah Kami pesankan kepada orang-orang yang diberi Kitab) maksudnya kitab-kitab (sebelum kamu) yaitu orang-orang Yahudi dan Nasrani (dan juga kepada kamu) hai Ahli Alquran (supaya) artinya berbunyi: ("Bertakwalah kamu kepada Allah) takutilah siksa-Nya dengan jalan menaati-Nya," (dan) kepada mereka juga kepada kamu sendiri Kami katakan: ("Jika kamu ingkar,") terhadap apa yang Kami pesankan itu (maka, ketahuilah, bahwa apa yang terdapat di langit dan apa yang terdapat di bumi milik Allah belaka) baik sebagai makhluk maupun sebagai ciptaan dan hamba-Nya hingga keingkaran kamu itu tidaklah akan merugikan-Nya sedikit pun juga. (Dan Allah Maha Kaya) sehingga tiada membutuhkan makhluk dan ibadah mereka (lagi Maha Terpuji) mengenai perbuatan-Nya terhadap mereka.\qt@no{131}}%
\qt@newcmd\qurantrans@id@dcxxv{%
(Dan kepunyaan Allahlah apa yang terdapat di langit dan apa yang terdapat di bumi) diulangi-Nya di sini untuk memperkuat kewajiban manusia supaya bertakwa. (Dan cukuplah Allah sebagai saksi) yang menjadi saksi bahwa semua itu memang milik-Nya semata.\qt@no{132}}%
\qt@newcmd\qurantrans@id@dcxxvi{%
(Jika dikehendaki-Nya niscaya dimusnahkan-Nya kamu hai manusia dan didatangkan-Nya umat yang lain) sebagai penggantimu (dan Allah Maha Kuasa berbuat demikian).\qt@no{133}}%
\qt@newcmd\qurantrans@id@dcxxvii{%
(Siapa yang menginginkan) dengan amal perbuatannya (pahala dunia, maka di sisi Allah tersedia pahala dunia dan akhirat) yakni bagi orang yang menginginkannya, dan bukan untuk umumnya manusia. Mengapa seseorang di antara kalian mencari yang paling rendah di antara keduanya, dan kenapa ia tidak mencari yang lebih tinggi saja, yaitu yang akan diperolehnya dengan jalan mengikhlaskan tuntutan kepada-Nya serta yang tidak akan ditemuinya hanyalah pada Zat Yang Maha Kaya. (Dan Allah Maha Mendengar lagi Maha Melihat.)\qt@no{134}}%
\qt@newcmd\qurantrans@id@dcxxviii{%
(Hai orang-orang yang beriman! Hendaklah kamu menjadi penegak) atau benar-benar tegak dengan (keadilan) (menjadi saksi) terhadap kebenaran (karena Allah walaupun) kesaksian itu (terhadap dirimu sendiri) maka menjadi saksilah dengan mengakui kebenaran dan janganlah kamu menyembunyikannya (atau) terhadap (kedua ibu bapak dan kaum kerabatmu. Jika ia) maksudnya orang yang disaksikan itu (kaya atau miskin, maka Allah lebih utama bagi keduanya) daripada kamu dan lebih tahu kemaslahatan mereka. (Maka janganlah kamu mengikuti hawa nafsu) dalam kesaksianmu itu dengan jalan pilih kasih, misalnya dengan mengutamakan orang yang kaya untuk mengambil muka atau si miskin karena merasa kasihan kepadanya (agar) tidak (berlaku adil) atau menyeleweng dari kebenaran. (Dan jika kamu mengubah) atau memutarbalikkan kesaksian, menurut satu qiraat dengan membuang huruf wawu yang pertama sebagai takhfif (atau berpaling) artinya enggan untuk memenuhinya (maka sesungguhnya Allah Maha Mengetahui apa yang kamu kerjakan) hingga akan diberi-Nya balasannya.\qt@no{135}}%
\qt@newcmd\qurantrans@id@dcxxix{%
(Hai orang-orang yang beriman, berimanlah kamu) artinya tetaplah beriman (kepada Allah dan rasul-Nya dan kepada kitab yang diturunkan-Nya kepada rasul-Nya) Muhammad saw. yakni Alquran (serta kitab yang diturunkan-Nya sebelumnya) maksudnya kitab-kitab yang diturunkan-Nya kepada para rasul, dan menurut satu qiraat kedua kata kerjanya dalam bentuk pasif. (Dan siapa yang ingkar kepada Allah, malaikat-malaikat-Nya, kitab-kitab-Nya, rasul-rasul-Nya dan hari akhirat, maka sungguhnya ia telah sesat sejauh-jauhnya) dari kebenaran.\qt@no{136}}%
\qt@newcmd\qurantrans@id@dcxxx{%
(Sesungguhnya orang-orang yang beriman) kepada Musa, maksudnya orang-orang Yahudi (kemudian mereka kafir) dengan menyembah anak sapi (kemudian beriman) sesudah itu (lalu kafir lagi) kepada Isa (kemudian bertambah kekafiran mereka) kepada Muhammad saw. (maka Allah sekali-kali takkan mengampuni mereka) selama mereka dalam keadaan demikian (dan tidak pula akan menuntun mereka ke jalan yang lurus) atau benar.\qt@no{137}}%
\qt@newcmd\qurantrans@id@dcxxxi{%
(Beritakanlah hai Muhammad kepada orang-orang munafik bahwa mereka akan mendapat siksaan yang pedih) yang menyakitkan yaitu siksa neraka.\qt@no{138}}%
\qt@newcmd\qurantrans@id@dcxxxii{%
(Yaitu orang-orang) menjadi badal atau na'at bagi orang-orang munafik (yang mengambil orang-orang kafir sebagai temannya yang setia dan bukan orang-orang mukmin) karena dugaan mereka bahwa orang-orang kafir itu mempunyai kekuatan. (Apakah mereka hendak mencari kekuatan pada mereka itu?) Pertanyaan bermakna sanggahan, artinya mereka takkan menemukan hal itu padanya. (Karena sesungguhnya semua kekuatan itu milik Allah) baik di dunia maupun di akhirat, dan takkan tercapai kecuali oleh kekasih-kekasih-Nya.\qt@no{139}}%
\qt@newcmd\qurantrans@id@dcxxxiii{%
(Dan sungguh, Allah telah menurunkan) dapat dibaca nazzala dan nuzzila (kepadamu dalam Kitab) yakni Alquran surah Al-An'am (bahwa) ditakhfifkan sedangkan isimnya dibuang dan asalnya annahu (jika kamu dengar ayat-ayat Allah) maksudnya ayat-ayat Alquran (diingkari dan diperolok-olokkan, maka janganlah kamu ikut duduk bersama mereka) maksudnya bersama orang-orang kafir dan yang memperolok-olokkan itu (sampai mereka memasuki pembicaraan yang lain. Karena sesungguhnya kamu jika demikian) artinya duduk bersama mereka (serupa dengan mereka) dalam kedosaan. (Sesungguhnya Allah akan mengumpulkan semua orang munafik dan orang kafir di dalam neraka Jahanam) sebagaimana mereka pernah berkumpul di atas dunia dalam mengingkari dan memperolok-olokkan Alquran.\qt@no{140}}%
\qt@newcmd\qurantrans@id@dcxxxiv{%
(Yakni orang-orang) menjadi badal bagi ``orang-orang" yang sebelumnya (yang menunggu-nunggu datangnya padamu) giliran peristiwa (jika kamu beroleh kemenangan) berikut harta rampasan (dari Allah, mereka berkata) kepadamu ("Bukankah kami bersama kamu") baik dalam keagamaan maupun dalam berjihad? Lalu mereka diberi bagian harta rampasan itu. (Sebaliknya jika orang-orang kafir yang beroleh nasib baik) berupa kemenangan terhadapmu (mereka berkata) kepada orang-orang kafir itu: ("Bukankah kami turut berjasa memenangkanmu) padahal kalau kami mau, kami mampu pula menahan dan memusnahkanmu tetapi itu tidak kami lakukan?" ("Dan) tidakkah (kami membela kamu dari orang-orang mukmin) agar mereka tidak beroleh kemenangan, yaitu dengan mengirim berita kepadamu, membukakan rahasia dan siasat mereka, hingga jasa besar kami itu tidak dapat kamu ingkari dan lupakan?" Firman Allah swt.: ("Maka Allah akan memberi keputusan di antara kamu) dengan mereka (pada hari kiamat) yaitu dengan memasukkanmu ke dalam surga dan memasukkan mereka ke dalam neraka. (Dan Allah sekali-kali tidak akan memberi jalan kepada orang kafir terhadap orang-orang beriman.") maksudnya jalan untuk mencelakakan dan membasmi mereka\qt@no{141}}%
\qt@newcmd\qurantrans@id@dcxxxv{%
(Sesungguhnya orang-orang munafik itu menipu Allah) yaitu dengan menampakkan hal-hal yang berlawanan dengan kekafiran yang mereka sembunyikan dengan maksud untuk menghindari hukum-hukum keduniaan yang bertalian dengan itu (dan Allah menipu mereka pula) maksudnya membalas tipuan mereka itu dengan diberitahukannya apa yang mereka sembunyikan itu oleh Allah kepada nabi-Nya hingga di dunia ini rahasia mereka terbuka sedangkan di akhirat kelak mereka menerima siksa. (Dan jika mereka berdiri untuk mengerjakan salat) bersama orang-orang mukmin (mereka berdiri dengan malas) merasa berat. (Mereka bersifat riya di hadapan manusia) dengan salat itu (dan tidak berzikir kepada Allah) maksudnya tidak melakukan salat (kecuali sebentar) disebabkan riya tadi.\qt@no{142}}%
\qt@newcmd\qurantrans@id@dcxxxvi{%
(Mereka dalam keadaan bimbang) ragu-ragu (antara demikian) yakni antara kafir dan iman (tidak) masuk (kepada mereka ini) artinya golongan orang-orang kafir (dan tidak pula kepada mereka itu) artinya golongan orang-orang beriman. (Dan siapa yang disesatkan Allah, maka tidak akan kamu temui baginya jalan) untuk menerima petunjuk.\qt@no{143}}%
\qt@newcmd\qurantrans@id@dcxxxvii{%
(Hai orang-orang yang beriman, janganlah kamu ambil orang-orang kafir dan bukan orang-orang mukmin sebagai pelindung! Apakah kamu hendak memberikan kepada Allah buat menyiksamu) dengan mengambil mereka sebagai pelindung itu (suatu alasan yang nyata) atau bukti yang tegas atas kemunafikanmu?\qt@no{144}}%
\qt@newcmd\qurantrans@id@dcxxxviii{%
(Sesungguhnya orang-orang munafik itu pada tempat) atau tingkat (yang paling bawah dari neraka) yakni bagian kerak atau dasarnya. (Dan kamu sekali-kali tidak akan mendapatkan seorang penolong pun bagi mereka) yakni yang akan membebaskannya dari siksa.\qt@no{145}}%
\qt@newcmd\qurantrans@id@dcxxxix{%
(Kecuali orang-orang yang bertobat) dari kemunafikan (dan mengadakan perbaikan) terhadap amal perbuatan mereka (serta berpegang teguh kepada, agama, Allah dan mengikhlaskan agama mereka karena Allah) artinya daripada riya (maka mereka itu bersama orang-orang yang beriman) yakni mengenai apa-apa yang akan mereka peroleh (dan Allah akan memberikan kepada orang-orang beriman itu pahala yang besar) di akhirat kelak yaitu surga.\qt@no{146}}%
\qt@newcmd\qurantrans@id@dcxl{%
(Mengapa Allah akan menyiksamu, jika kamu bersyukur) atas nikmat-Nya (dan beriman) kepada-Nya? Pertanyaan ini berarti tidak, jadi maksudnya Allah tidaklah akan menyiksamu. (Dan Allah Maha Mensyukuri) perbuatan-perbuatan orang-orang beriman dengan memberi mereka pahala (lagi Maha Mengetahui) akan makhluk-Nya.\qt@no{147}}%
\qt@newcmd\qurantrans@id@dcxli{%
(Allah tidak menyukai perkataan buruk yang diucapkan secara terus terang) dari siapa pun juga, artinya Dia pastilah akan memberinya hukuman (kecuali dari orang yang dianiaya) sehingga apabila dia mengucapkannya secara terus terang misalnya tentang keaniayaan yang dideritanya sehingga ia mendoakan si pelakunya, maka tidaklah dia akan menerima hukuman dari Allah. (Dan Allah Maha Mendengar) apa-apa yang diucapkan (lagi Maha Mengetahui) apa-apa yang diperbuat.\qt@no{148}}%
\qt@newcmd\qurantrans@id@dcxlii{%
(Jika kamu melahirkan) atau memperlihatkan (suatu kebaikan) di antara perbuatan-perbuatan baik (atau menyembunyikannya) artinya melakukannya secara sembunyi-sembunyi (atau memaafkan sesuatu kesalahan) atau keaniayaan orang lain (maka sesungguhnya Allah Maha Pemaaf lagi Maha Kuasa).\qt@no{149}}%
\qt@newcmd\qurantrans@id@dcxliii{%
(Sesungguhnya orang-orang yang kafir kepada Allah dan rasul-rasul-Nya dan bermaksud akan membeda-bedakan di antara Allah dengan rasul-rasul-Nya) yakni dengan beriman kepada-Nya serta kafir terhadap mereka (serta mengatakan, ``Kami beriman kepada sebagian) di antara rasul-rasul itu (dan kami kafir terhadap yang lain") dari mereka (serta bermaksud hendak mengambil di antara demikian) maksudnya di antara kufur dan iman (jalan) yang akan mereka tempuh.\qt@no{150}}%
\qt@newcmd\qurantrans@id@dcxliv{%
(Merekalah orang-orang yang kafir sebenar-benarnya) haqqan adalah mashdar yang memperkuat isi kalimat sebelumnya (dan telah Kami sediakan bagi orang-orang yang kafir itu siksaan yang menghinakan) artinya azab neraka.\qt@no{151}}%
\qt@newcmd\qurantrans@id@dcxlv{%
(Orang-orang yang beriman kepada Allah dan para rasul-Nya) artinya semua mereka (dan tidak membeda-bedakan seorang pun di antara mereka kelak Allah akan memberikan kepada mereka) dengan memakai nun atau ya (pahala mereka) artinya pahala amal perbuatan mereka (dan Allah Maha Pengampun) bagi kekasih-kekasih-Nya (lagi Maha Penyayang) kepada ahli taat-Nya.\qt@no{152}}%
\qt@newcmd\qurantrans@id@dcxlvi{%
(Ahli Kitab meminta kepadamu) hai Muhammad; maksudnya orang-orang Yahudi (agar kamu menurunkan kepada mereka sebuah kitab dari langit) maksudnya sekaligus seperti pernah diturunkan-Nya kepada Musa guna mempersulit permintaan itu. Dan sekiranya menurut kamu itu berat (maka sesungguhnya mereka telah pernah meminta) maksudnya nenek moyang mereka (kepada Musa yang lebih besar dari itu, kata mereka, ``Perlihatkanlah Allah kepada kami dengan jelas.") atau nyata. (Maka mereka disambar oleh petir) artinya maut sebagai hukuman bagi mereka (disebabkan keaniayaan mereka) yakni meminta barang yang sulit. (Kemudian mereka mengambil anak sapi) sebagai tuhan (setelah datang kepada mereka bukti-bukti yang nyata) artinya mukjizat-mukjizat atas kekuasaan Allah (maka Kami maafkan mereka dari hal yang demikian) dan tidak Kami basmi mereka secara tuntas (dan telah Kami berikan kepada Musa kekuasaan yang nyata) artinya keunggulan yang menakjubkan bagi mereka hingga sewaktu mereka disuruh membunuh diri mereka guna bertobat mereka pun menurutinya dengan patuh.\qt@no{153}}%
\qt@newcmd\qurantrans@id@dcxlvii{%
(Dan Kami angkat ke atas kepada mereka Thur) nama sebuah bukit (disebabkan perjanjian dengan mereka) maksudnya hendak mengadakan perjanjian agar mereka takut dan bersedia menerimanya (dan kata Kami kepada mereka) sementara bukit itu dinaungkan kepada mereka ("Masukilah pintu gerbang itu) maksudnya pintu gerbang kampung atau negeri (sambil bersujud") yang menunjukkan ketundukkan (dan Kami wahyukan kepada mereka, ``Janganlah kamu melanggar perintah) menurut suatu qiraat dibaca ta`adduu dengan diidgamkan ta aslinya pada dal yang menjadi ta`taduu; artinya melanggar perintah (pada hari Sabtu") dengan menangkap ikan padanya (dan Kami telah menerima perjanjian erat dari mereka) mengenai hal itu tetapi mereka melanggarnya.\qt@no{154}}%
\qt@newcmd\qurantrans@id@dcxlviii{%
(Maka disebabkan mereka melanggar) ma merupakan tambahan; ba sababiyah berkaitan dengan yang dibuang, yang maksudnya: Kami kutuk mereka disebabkan mereka melanggar (perjanjian mereka dan karena kekafiran mereka terhadap ayat-ayat Allah dan pembunuhan yang mereka lakukan kepada nabi-nabi tanpa alasan yang benar dan kata mereka) kepada Nabi saw. ("Hati kami tertutup") tak dapat mendengar apa yang kamu katakan (bahkan Allah telah mengunci hati mereka itu disebabkan kekafiran mereka) hingga tak dapat mendengarkan nasihat dan pelajaran (oleh karena itu mereka tidak beriman kecuali sebagian kecil) dari mereka seperti Abdullah bin Salam dan kawan-kawannya.\qt@no{155}}%
\qt@newcmd\qurantrans@id@dcxlix{%
(Dan karena kekafiran mereka) buat kedua kalinya yakni terhadap Isa, dan ba diulang-ulang menyebutkannya untuk memisah di antaranya dengan tempat mengathafkannya (dan tuduhan mereka terhadap Maryam berupa kedustaan besar) di mana mereka menuduhnya berbuat zina.\qt@no{156}}%
\qt@newcmd\qurantrans@id@dcl{%
(Serta karena ucapan mereka) dengan membanggakan diri ("Sesungguhnya kami telah membunuh Almasih Isa putra Maryam utusan Allah") yakni menurut dugaan dan pengakuan mereka. Artinya disebabkan semua itu Kami siksa mereka. Dan Allah berfirman menolak pengakuan mereka telah membunuhnya itu (padahal mereka tidak membunuhnya dan tidak pula menyalibnya tetapi diserupakan bagi mereka dengan Isa) maksudnya yang mereka bunuh dan mereka salib itu ialah sahabat mereka sendiri yang diserupakan Allah dengan Isa hingga mereka kira Nabi Isa sendiri. (Sesungguhnya orang-orang yang berselisih paham padanya) maksudnya pada Isa (sesungguhnya dalam keragu-raguan terhadapnya) maksudnya terhadap pembunuhan itu. Agar terlihat orang yang dibunuh itu, sebagian mereka berkata, ``Mukanya seperti muka Isa, tetapi tubuhnya lain, jadi sebenarnya bukan dia!" Dan kata sebagian pula, ``Memang dia itu Isa!" (mereka tidak mempunyai terhadapnya) maksudnya pembunuhan itu (keyakinan kecuali mengikuti persangkaan belaka) disebut sebagai istitsna munqathi'; artinya mereka hanya mengikuti dugaan-dugaan hasil khayal atau lamunan belaka (mereka tidak yakin telah membunuh Isa) menjadi hal yang menyangkal pembunuhan Isa itu.\qt@no{157}}%
\qt@newcmd\qurantrans@id@dcli{%
(Tetapi Allah telah mengangkatnya kepada-Nya dan Allah Maha Tangguh) dalam kerajaan-Nya (lagi Maha Bijaksana) dalam perbuatan-Nya.\qt@no{158}}%
\qt@newcmd\qurantrans@id@dclii{%
(Dan tidak ada di antara Ahli Kitab) seorang pun juga (kecuali akan beriman kepadanya) yakin kepada Isa (sebelum meninggalnya) artinya sebelum ahli Kitab itu meninggal di waktu ia melihat malaikat maut, tetapi keimanannya itu sudah tidak berguna lagi. Atau sebelum wafatnya Isa, yakni ketika dia turun dekat datangnya hari kiamat sebagaimana tercantum dalam sebuah hadis (Dan pada hari kiamat itu, ia) yakni Isa (akan menjadi saksi terhadap mereka) mengenai apa yang mereka lakukan sewaktu ia diutus kepada mereka dahulu.\qt@no{159}}%
\qt@newcmd\qurantrans@id@dcliii{%
(Maka karena keaniayaan) artinya disebabkan keaniayaan (dari orang-orang Yahudi Kami haramkan atas mereka makanan yang baik-baik yang dihalalkan bagi mereka dulu) yakni yang tersebut dalam firman-Nya, ``Kami haramkan setiap yang berkuku..." sampai akhir ayat (juga karena mereka menghalangi) manusia (dari jalan Allah) maksudnya agama-Nya (banyak).\qt@no{160}}%
\qt@newcmd\qurantrans@id@dcliv{%
(Dan karena memakan riba padahal telah dilarang daripadanya) dalam Taurat (dan memakan harta orang dengan jalan batil) dengan memberi suap dalam pengadilan (dan telah Kami sediakan untuk orang-orang kafir itu siksa yang pedih) atau menyakitkan.\qt@no{161}}%
\qt@newcmd\qurantrans@id@dclv{%
(Tetapi orang-orang yang mendalam) artinya kukuh dan mantap (ilmunya di antara mereka) seperti Abdullah bin Salam (dan orang-orang mukmin) dari golongan Muhajirin dan Ansar (mereka beriman pada apa yang diturunkan kepadamu dan apa-apa yang diturunkan sebelummu) di antara kitab-kitab (sedangkan orang-orang yang mendirikan salat) manshub karena pujian, dan ada pula yang membacanya dengan marfu` (dan membayar zakat serta orang-orang yang beriman kepada Allah dan hari akhir, mereka itulah yang akan Kami beri) fi'ilnya dibaca dengan nun atau dengan ya (pahala yang besar) yakni surga.\qt@no{162}}%
\qt@newcmd\qurantrans@id@dclvi{%
(Sesungguhnya Kami telah menurunkan wahyu kepadamu sebagaimana Kami telah menurunkannya kepada Nuh dan nabi-nabi sesudahnya dan) seperti (telah Kami turunkan kepada Ibrahim, Ismail, Ishak) yakni kedua putranya (serta Yakub) bin Ishak (dan anak-anaknya) yakni anak-anak Yakub (serta Isa, Ayub, Yunus, Harun, Sulaiman dan Kami datangkan kepada) bapaknya, yakni bapak dari Sulaiman (Daud Zabur) dibaca dengan fathah hingga artinya ialah nama kitab yang diturunkan, dan ada pula yang membaca dengan marfu` yaitu mashdar yang berarti mazbuura artinya yang tertulis.\qt@no{163}}%
\qt@newcmd\qurantrans@id@dclvii{%
(Dan) telah Kami utus (rasul-rasul yang telah Kami kisahkan tentang mereka kepadamu dulu, dan rasul-rasul yang belum Kami kisahkan). Diriwayatkan bahwa Allah swt. mengirim delapan ribu orang nabi, empat ribu dari kalangan Bani Israel dan empat ribu lagi dari kalangan manusia lainnya ini dikatakan oleh Syekh dalam surah Ghafir. (Dan Allah telah berbicara dengan Musa sebenar berbicara) artinya secara langsung.\qt@no{164}}%
\qt@newcmd\qurantrans@id@dclviii{%
(Yaitu rasul-rasul) menjadi badal bagi rasul-rasul yang sebelumnya (selalu pembawa berita gembira) dengan diberinya pahala kepada orang yang beriman (dan penyampaian peringatan) dengan adanya siksa kepada orang yang ingkar. Mereka Kami utus itu ialah (agar tidak ada lagi bagi manusia terhadap Allah alasan) yang dapat dikemukakan (setelah) pengiriman (rasul-rasul itu) kepada mereka, misalnya dengan mengatakan, ``Wahai Tuhan kami! Kenapa tidak Tuhan kirim kepada kami seorang rasul agar kami dapat mengikuti ayat-ayat-Mu dan menjadi orang-orang beriman!" Maka Tuhan pun telah lebih dulu mengirimkan mereka untuk mematahkan alasan mereka tadi (Dan Allah Maha Tangguh) dalam kerajaan-Nya (lagi Maha Bijaksana) dalam perbuatan-Nya. Ayat berikut diturunkan tatkala orang-orang Yahudi ditanyai orang mengenai kenabian Muhammad saw. lalu mereka ingkari:\qt@no{165}}%
\qt@newcmd\qurantrans@id@dclix{%
(Tetapi Allah menyaksikan) artinya tentang kenabianmu (dengan apa yang diturunkan-Nya kepadamu) berupa Alquran yang menjadi mukjizat itu (diturunkan-Nya) sebagai hasil (dari ilmu-Nya) atau memuat ilmu-Nya (dan malaikat-malaikat pun menjadi saksi) pula atas kenabianmu itu. (Dan cukuplah Allah sebagai saksi)-nya.\qt@no{166}}%
\qt@newcmd\qurantrans@id@dclx{%
(Sesungguhnya orang-orang yang kafir) kepada Allah (dan menghalang-halangi) manusia (dari jalan Allah) artinya dari agama Islam dengan menyembunyikan ciri-ciri Nabi Muhammad saw.; maksudnya ialah orang-orang Yahudi (maka sesungguhnya mereka telah sesat sejauh-jauhnya) dari kebenaran.\qt@no{167}}%
\qt@newcmd\qurantrans@id@dclxi{%
(Sesungguhnya orang-orang yang kafir) kepada Allah (dan berlaku aniaya) kepada nabi-Nya dengan menyembunyikan ciri-cirinya itu (maka Allah sekali-kali tidak akan mengampuni mereka dan tidak pula akan menunjukkan kepada mereka suatu jalan) di antara jalan-jalan yang banyak ini.\qt@no{168}}%
\qt@newcmd\qurantrans@id@dclxii{%
(Kecuali jalan neraka Jahanam) maksudnya jalan menuju ke sana (kekal mereka) artinya ditakdirkan kekal (di dalamnya) jika mereka telah memasukinya (buat selama-lamanya. Dan yang demikian itu bagi Allah mudah) artinya gampang dan tidak sulit adanya.\qt@no{169}}%
\qt@newcmd\qurantrans@id@dclxiii{%
(Hai manusia) maksudnya warga Mekah (sesungguhnya telah datang kepadamu rasul) yakni Muhammad saw. (membawa kebenaran dari Tuhanmu, maka berimanlah kamu) kepadanya (dan usahakanlah yang terbaik bagi kamu) dari apa yang melingkungimu (Dan jika kamu kafir) kepadanya (maka bagi-Nya apa yang di langit dan yang di bumi) baik sebagai milik maupun sebagai makhluk dan hamba hingga tidaklah merugikan kepada-Nya kekafiranmu itu (Dan Allah Maha Mengetahui) terhadap makhluk-Nya (lagi Maha Bijaksana) mengenai perbuatan-Nya terhadap mereka.\qt@no{170}}%
\qt@newcmd\qurantrans@id@dclxiv{%
(Hai Ahli kitab) maksudnya kitab Injil (janganlah kamu melampaui batas dalam agamamu dan janganlah kamu katakan terhadap Allah kecuali) ucapan (yang benar) yaitu menyucikan-Nya dari kemusyrikan dan mempunyai anak. (Sesungguhnya Almasih Isa putra Maryam itu adalah utusan Allah dan kalimat-Nya yang diucapkan-Nya) atau disampaikan-Nya (kepada Maryam dan roh) artinya yang mempunyai roh (daripada-Nya) diidhafatkan kepada Allah swt. demi untuk memuliakan-Nya dan bukanlah sebagai dugaan kamu bahwa dia adalah anak Allah atau Tuhan bersama-Nya atau salah satu dari oknum yang tiga. Karena sesuatu yang mempunyai roh itu tersusun sedangkan Tuhan Maha Suci dari tersusun dan dari dinisbatkannya tersusun itu kepada-Nya (Maka berimanlah kamu kepada Allah dan kepada rasul-rasul-Nya dan janganlah kamu katakan) bahwa Tuhan itu (tiga) yakni Allah, Isa dan ibunya (hentikanlah) demikian itu (dan perbuatlah yang lebih baik bagi kamu) yakni bertauhid (Sesungguhnya Allah Tuhan Yang Maha Esa Maha Suci Dia) artinya bersih dan terhindar (dari mempunyai anak. Bagi-Nya apa yang terdapat di langit dan yang di bumi) baik sebagai makhluk maupun sebagai milik dan hamba sedangkan pemiliknya itu bertentangan dengan mempunyai anak (Dan cukuplah Allah sebagai wakil) atau saksi atas demikian itu.\qt@no{171}}%
\qt@newcmd\qurantrans@id@dclxv{%
(Almasih tidak merasa malu) maksudnya Almasih yang kamu katakan sebagai Tuhan itu tidak merasa enggan dan takabur (menjadi hamba bagi Allah dan tidak pula enggan malaikat-malaikat yang terdekat) kepada Allah mereka juga tidak malu untuk menjadi hamba-Nya. Ini suatu kalimat selang yang terbaik yang dikemukakan untuk menolak anggapan sementara orang bahwa mereka adalah Tuhan atau putri-putri Allah sebagaimana kalimat yang sebelumnya digunakan untuk menolak anggapan kaum Nasrani bahwa Isa adalah putra-Nya. (Siapa yang enggan untuk menyembah-Nya dan menyombongkan diri maka kelak Allah akan mengumpulkan mereka semua kepada-Nya) yakni di akhirat.\qt@no{172}}%
\qt@newcmd\qurantrans@id@dclxvi{%
(Adapun orang-orang yang beriman dan beramal saleh maka Allah akan menyempurnakan ganjaran mereka) artinya pahala dari amal perbuatan mereka itu (dan menambah untuk mereka dari karunia-Nya) yakni yang belum pernah dilihat oleh mata, tidak didengar telinga dan tidak pula terdetik dalam hati manusia. (Adapun orang-orang yang malu dan menyombongkan diri) dari mengabdikan diri kepada-Nya (maka akan disiksa-Nya mereka dengan siksaan yang pedih) atau menyakitkan yaitu siksa neraka (dan mereka tidak akan memperoleh bagian bagi diri mereka selain daripada Allah, pelindung) yang akan melindungi diri mereka (dan tidak pula pembela) yang akan menolong mereka.\qt@no{173}}%
\qt@newcmd\qurantrans@id@dclxvii{%
(Hai manusia, sesungguhnya telah datang kepadamu keterangan) bukti kebenaran (dari Tuhanmu) yaitu Nabi saw. (dan telah Kami turunkan kepadamu cahaya yang terang) benderang yakni Alquran.\qt@no{174}}%
\qt@newcmd\qurantrans@id@dclxviii{%
(Adapun orang-orang yang beriman kepada Allah dan berpegang teguh kepada-Nya, maka Allah akan memasukkan mereka ke dalam rahmat dan limpahan karunia-Nya dan membimbing mereka ke jalan yang lurus menuju kepada-Nya) yakni agama Islam.\qt@no{175}}%
\qt@newcmd\qurantrans@id@dclxix{%
(Mereka meminta fatwa kepadamu) mengenai kalalah, yaitu jika seseorang meninggal dunia tanpa meninggalkan bapak dan anak (Katakanlah, ``Allah memberi fatwa kepadamu tentang kalalah; jika seseorang) umru-un menjadi marfu' dengan fi'il yang menafsirkannya (celaka) maksudnya meninggal dunia (dan dia tidak mempunyai anak) dan tidak pula bapak yakni yang dimaksud dengan kalalah tadi (tetapi mempunyai seorang saudara perempuan) baik sekandung maupun sebapak (maka bagi saudaranya yang perempuan itu seperdua dari harta yang ditinggalkannya, dan dia) maksudnya saudaranya yang laki-laki (mewarisi saudaranya yang perempuan) pada seluruh harta peninggalannya (yakni jika ia tidak mempunyai anak). Sekiranya ia mempunyai seorang anak laki-laki, maka tidak satu pun diperolehnya, tetapi jika anaknya itu perempuan, maka saudaranya itu masih memperoleh kelebihan dari bagian anaknya. Dan sekiranya saudara laki-laki atau saudara perempuan itu seibu, maka bagiannya ialah seperenam sebagaimana telah diterangkan di awal surah. (Jika mereka itu) maksudnya saudara perempuan (dua orang) atau lebih, karena ayat ini turun mengenai Jabir; ia meninggal dunia dengan meninggalkan beberapa orang saudara perempuan (maka bagi keduanya dua pertiga dari harta peninggalan) saudara laki-laki mereka. (Dan jika mereka) yakni ahli waris itu terdiri dari (saudara laki-laki dan perempuan, maka bagian seorang laki-laki) di antara mereka (sebanyak bagian dua orang perempuan." Allah menerangkan kepadamu syariat-syariat agama-Nya (agar kamu) tidak (sesat. Dan Allah Maha Mengetahui segala sesuatu) di antaranya tentang pembagian harta warisan. Diriwayatkan oleh Bukhari dan Muslim dari Barra bahwa ia merupakan ayat yang terakhir diturunkan, maksudnya mengenai faraid.\qt@no{176}}%
\qt@newcmd\qurantrans@id@dclxx{%
\basmalahid (Hai orang-orang yang beriman, penuhilah olehmu perjanjian itu) baik perjanjian yang terpatri di antara kamu dengan Allah maupun dengan sesama manusia. (Dihalalkan bagi kamu binatang ternak) artinya halal memakan unta, sapi dan kambing setelah hewan itu disembelih (kecuali apa yang dibacakan padamu) tentang pengharamannya dalam ayat, ``Hurrimat `alaikumul maitatu..." Istitsna` atau pengecualian di sini munqathi` atau terputus tetapi dapat pula muttashil, misalnya yang diharamkan karena mati dan sebagainya (tanpa menghalalkan berburu ketika kamu mengerjakan haji) atau berihram; ghaira dijadikan manshub karena menjadi hal bagi dhamir yang terdapat pada lakum. (Sesungguhnya Allah menetapkan hukum menurut yang dikehendaki-Nya) baik menghalalkan maupun mengharamkannya tanpa seorang pun yang dapat menghalangi-Nya.\qt@no{1}}%
\qt@newcmd\qurantrans@id@dclxxi{%
(Hai orang-orang yang beriman, janganlah kamu melanggar syiar-syiar Allah) jamak sya`iiratun; artinya upacara-upacara agama-Nya. Melanggar yaitu dengan berburu di waktu ihram (dan jangan pula melanggar bulan haram) dengan melakukan peperangan padanya (dan jangan mengganggu binatang-binatang hadya) yakni hewan yang dihadiahkan buat tanah suci (serta binatang-binatang berkalung) jamak dari qilaadatun; artinya binatang yang diberi kalung dengan kayu-kayuan yang terdapat di tanah suci sebagai tanda agar ia aman, maka janganlah ada yang mengganggu baik hewan-hewan itu sendiri maupun para pemiliknya (jangan pula) kamu halalkan atau kamu ganggu (orang-orang yang berkunjung) atau menuju (Baitulharam) dengan memerangi mereka (sedangkan mereka mencari karunia) artinya rezeki (dari Tuhan mereka) dengan berniaga (dan keridaan) daripada-Nya di samping berkunjung ke Baitullah tidak seperti pengertian mereka yang salah itu. Ayat ini dimansukh oleh ayat Bara`ah. (Dan apabila kamu telah selesai) dari ihram (maka perintahlah berburu) perintah di sini berarti ibahah atau memperbolehkan (dan sekali-kali janganlah kamu terdorong oleh kebencian) dibaca syana-aanu atau syan-aanu berarti kebencian atau kemarahan (kepada suatu kaum disebabkan mereka telah menghalangi kamu dari Masjidilharam untuk berbuat aniaya) kepada mereka dengan pembunuhan dan sebagainya. (Bertolong-tolonglah kamu dalam kebaikan) dalam mengerjakan yang dititahkan (dan ketakwaan) dengan meninggalkan apa-apa yang dilarang (dan janganlah kamu bertolong-tolongan) pada ta`aawanu dibuang salah satu di antara dua ta pada asalnya (dalam berbuat dosa) atau maksiat (dan pelanggaran) artinya melampaui batas-batas ajaran Allah. (Dan bertakwalah kamu kepada Allah) takutlah kamu kepada azab siksa-Nya dengan menaati-Nya (sesungguhnya Allah amat berat siksa-Nya) bagi orang yang menentang-Nya.\qt@no{2}}%
\qt@newcmd\qurantrans@id@dclxxii{%
(Diharamkan bagimu bangkai) yakni memakannya (darah) yang mengalir seperti pada binatang ternak (daging babi, hewan yang disembelih karena selain Allah) misalnya disembelih atas nama lain-Nya (yang tercekik) yang mati karena tercekik (yang dipukul) yang dibunuh dengan jalan memukulnya (yang jatuh) dari atas ke bawah lalu mati (yang ditanduk) yang mati karena tandukan lainnya (yang diterkam oleh binatang buas kecuali yang sempat kamu sembelih) maksudnya yang kamu dapati masih bernyawa dari macam-macam yang disebutkan itu lalu kamu sembelih (dan yang disembelih atas) nama (berhala) jamak dari nishab; artinya patung (dan mengundi nasib) artinya menentukan bagian dan keputusan (dengan anak panah) azlaam jamak dari zalam atau zulam; artinya anak panah yang belum diberi bulu dan ujungnya tidak bermata. Anak panah itu ada tujuh buah disimpan oleh pengurus Kakbah dan padanya terdapat tanda-tanda. Maka tanda-tanda itulah yang mereka ambil sebagai pedoman, jika disuruh mereka lakukan dan jika dilarang mereka hentikan. (Demikian itu adalah kefasikan) artinya menyimpang dari ketaatan. Ayat ini turun pada hari Arafah masa haji wadak, yaitu haji terakhir yang dilakukan oleh Nabi Muhammad saw. (Pada hari ini orang-orang kafir telah putus-asa terhadap agamamu) untuk mengembalikan kamu menjadi murtad setelah mereka melihat kamu telah kuat (maka janganlah kamu takut kepada mereka dan takutlah pada-Ku. Pada hari ini telah Kusempurnakan untukmu agamamu) yakni hukum-hukum halal maupun haram yang tidak diturunkan lagi setelahnya hukum-hukum dan kewajiban-kewajibannya (dan telah Kucukupkan padamu nikmat karunia-Ku) yakni dengan menyempurnakannya dan ada pula yang mengatakan dengan memasuki kota Mekah dalam keadaan aman (dan telah Kuridai) artinya telah Kupilih (Islam itu sebagai agama kalian. Maka siapa terpaksa karena kelaparan) untuk memakan sesuatu yang haram lalu dimakannya (tanpa cenderung) atau sengaja (berbuat dosa) atau maksiat (maka sesungguhnya Allah Maha Pengampun) terhadapnya atas perbuatan memakannya itu (lagi Maha Pengasih) kepadanya dalam memperbolehkannya. Berbeda halnya dengan orang yang cenderung atau sengaja berbuat dosa, misalnya penyamun atau pemberontak, maka tidak halal baginya memakan itu.\qt@no{3}}%
\qt@newcmd\qurantrans@id@dclxxiii{%
(Mereka menanyakan kepadamu) hai Muhammad (Apakah yang dihalalkan bagi mereka) di antara makanan. (Katakanlah, ``Dihalalkan bagimu yang baik-baik) yang enak-enak atau yang halal (dan) hasil buruan (dari binatang-binatang buas yang telah kamu ajar) seperti anjing, serigala dan burung (dengan melatihnya berburu) hal dari kallabtal kalba pakai tasydid pada lam; artinya biasa kamu lepas berburu (kamu ajar mereka itu) hal dari dhamir mukallibiina; artinya kamu latih mereka itu (menurut apa yang diajarkan Allah kepadamu) tentang cara berburu (maka makanlah apa-apa yang ditangkapnya untukmu) mereka membunuh buruan tanpa memakannya. Berbeda halnya dengan yang tidak terlatih, maka tangkapannya itu tidak halal. Sebagai ciri-cirinya bila dilepas ia berangkat dan bila dicegah ia berhenti serta ditahannya buruan itu dan tidak dimakannya. Sekurang-kurangnya untuk mengetahui hal itu dibutuhkan pengamatan sebanyak tiga kali. Jika buruan itu dimakannya, berarti tidak ditangkapnya untuk tuannya, maka tidak halal dimakan sebagaimana tercantum dalam kedua hadis sahih Bukhari dan Muslim. Dalam hadis itu juga disebutkan bahwa hasil panahan jika dilepas dengan menyebut nama Allah, maka sama dengan hasil buruan dari binatang pemburu yang telah dilatih. (Dan sebutlah nama Allah atasnya) ketika melepasnya (serta bertakwalah kepada Allah; sesungguhnya Allah amat cepat perhitungan-Nya.")\qt@no{4}}%
\qt@newcmd\qurantrans@id@dclxxiv{%
(Pada hari ini dihalalkan bagimu yang baik-baik) artinya yang enak-enak (Dan makanan-makanan orang-orang yang diberi kitab) maksudnya sembelihan orang-orang Yahudi dan Nasrani (halal bagi kamu dan makananmu) yang kamu sajikan kepada mereka (halal pula bagi mereka. Dan wanita-wanita yang merdeka di antara wanita-wanita mukmin serta wanita-wanita merdeka dari kalangan orang-orang yang diberi kitab sebelum kamu) halal pula kamu kawini (apabila kamu telah membayar maskawin mereka) atau mahar (dengan maksud mengawini mereka) sehingga terpelihara kehormatan (bukan dengan maksud berzina) dengan mereka secara terang-terangan (dan bukan pula untuk mengambil mereka sebagai gundik) atau melakukan perzinaan dengan mereka secara sembunyi-sembunyi. (Dan siapa yang kafir terhadap iman) artinya murtad (maka sungguh telah hapuslah amalnya) amal saleh sebelum itu hingga tidak dianggap diberi pahala (dan ia di akhirat termasuk orang-orang yang merugi) yakni jika ia meninggal dalam keadaan demikian itu.\qt@no{5}}%
\qt@newcmd\qurantrans@id@dclxxv{%
(Hai orang-orang yang beriman, jika kamu berdiri) maksudnya hendak berdiri (mengerjakan salat) dan kamu sedang berhadas (maka basuhlah muka dan tanganmu sampai ke siku) artinya termasuk siku itu sebagaimana diterangkan dalam sunah (dan sapulah kepalamu) ba berarti melengketkan, jadi lengketkanlah sapuanmu itu kepadanya tanpa mengalirkan air. Dan ini merupakan isim jenis, sehingga dianggap cukup bila telah tercapai sapuan walaupun secara minimal, yaitu dengan disapunya sebagian rambut. Pendapat ini juga dianut oleh Imam Syafii (dan kakimu) dibaca manshub karena diathafkan kepada aidiyakum; jadi basuhlah tetapi ada pula yang membaca dengan baris di bawah/kasrah dengan diathafkan kepada yang terdekat (sampai dengan kedua mata kaki) artinya termasuk kedua mata kaki itu, sebagaimana diterangkan dalam hadis. Dua mata kaki ialah dua tulang yang tersembul pada setiap pergelangan kaki yang memisah betis dengan tumit. Dan pemisahan di antara tangan dan kaki yang dibasuh dengan rambut yang disapu menunjukkan diharuskannya/wajib berurutan dalam membersihkan anggota wudu itu. Ini juga merupakan pendapat Syafii. Dari sunah diperoleh keterangan tentang wajibnya berniat seperti halnya ibadah-ibadah lainnya. (Dan jika kamu dalam keadaan junub, maka bersucilah) maksudnya mandilah (dan apabila sakit) yang akan bertambah parah dengan menyentuh air (atau dalam perjalanan) musafir (atau kamu kembali dari tempat buang air) artinya berhadas (atau menyentuh wanita) hal ini telah dibicarakan dulu pada surah An-Nisa (lalu kamu tidak memperoleh air) yakni setelah mencarinya (maka bertayamumlah) dengan mencari (tanah yang baik) tanah yang bersih (sapulah muka dan tanganmu) beserta kedua siku (dengan tanah itu) dengan dua kali pukulan. Ba menunjukkan lengket sementara sunah menjelaskan bahwa yang dimaksud ialah hendaklah sapuan itu meliputi kedua anggota secara keseluruhan (Allah tidaklah hendak menyulitkan kamu) dengan kewajiban-kewajiban berwudu, mandi atau tayamum itu (tetapi Dia hendak menyucikan kamu) dari hadas dan dosa (dan hendak menyempurnakan nikmat-Nya kepadamu) yakni dengan Islam dengan menerangkan syariat-syariat agama (semoga kamu bersyukur) atas nikmat-Nya itu.\qt@no{6}}%
\qt@newcmd\qurantrans@id@dclxxvi{%
(Dan ingatlah olehmu karunia Allah kepadamu) maksudnya agama Islam (dan perjanjian-Nya yang telah diikat erat-Nya denganmu) artinya yang telah diperbuat-Nya denganmu (ketika kamu mengatakan) kepada Nabi saw. sewaktu baiat kepadanya (Kami dengar dan kami taati) mengenai apa juga yang engkau suruh atau pun larang, baik yang kami sukai maupun yang kami benci (dan bertakwalah kamu kepada Allah) jangan sampai melanggar perjanjian itu (Sesungguhnya Allah Maha Mengetahui isi hati) yakni apa yang terdapat di dalamnya apa lagi yang terdapat di luarnya.\qt@no{7}}%
\qt@newcmd\qurantrans@id@dclxxvii{%
(Hai orang-orang yang beriman, hendaklah kamu selalu berdiri karena Allah) menegakkan kebenaran-kebenaran-Nya (menjadi saksi dengan adil) (dan janganlah kamu terdorong oleh kebencian kepada sesuatu kaum) yakni kepada orang-orang kafir (untuk berlaku tidak adil) hingga kamu menganiaya mereka karena permusuhan mereka itu. (Berlaku adillah kamu) baik terhadap lawan maupun terhadap kawan (karena hal itu) artinya keadilan itu (lebih dekat kepada ketakwaan. Dan bertakwalah kepada Allah, sesungguhnya Allah Maha Mengetahui apa yang kamu kerjakan) sehingga kamu akan menerima pembalasan daripadanya.\qt@no{8}}%
\qt@newcmd\qurantrans@id@dclxxviii{%
(Allah telah menjanjikan kepada orang-orang yang beriman dan yang beramal saleh) suatu janji yang baik (bahwa untuk mereka keampunan dan pahala yang besar) yakni surga.\qt@no{9}}%
\qt@newcmd\qurantrans@id@dclxxix{%
(Sebaliknya orang-orang yang kafir dan mendustakan ayat-ayat Kami mereka itu adalah penduduk neraka.)\qt@no{10}}%
\qt@newcmd\qurantrans@id@dclxxx{%
(Hai orang-orang yang beriman, ingatlah nikmat Allah kepadamu ketika suatu kaum bermaksud) yakni orang-orang Quraisy (hendak memanjangkan tangan mereka kepadamu) buat mencelakakanmu (maka ditahan-Nya tangan mereka daripadamu) dan dilindungi-Nya kamu dari maksud jahat mereka itu (dan bertakwalah kamu kepada Allah dan hendaklah kepada Allah orang-orang mukmin itu bertawakal.)\qt@no{11}}%
\qt@newcmd\qurantrans@id@dclxxxi{%
(Dan sesungguhnya Allah telah mengambil perjanjian dari Bani Israel) mengenai apa yang akan disebutkan di belakang nanti (dan telah Kami angkat) terdapat peralihan dari dhamir gaib kepada orang pertama (di antara mereka 12 orang pemimpin) dari setiap suku seorang pemimpin yang akan menjamin dipenuhinya perjanjian itu oleh semua warga, dan kepada mereka (Allah berfirman, ``Sesungguhnya Aku beserta kamu) siap dengan pertolongan dan bantuan. (Demi jika) lam menunjukkan sumpah (kamu mendirikan salat, menunaikan zakat, beriman kepada rasul-rasul-Ku dan memberikan bantuan kepada mereka serta kamu berikan kepada Allah suatu pinjaman yang baik) dengan mengeluarkan nafkah di jalan-Nya (maka akan Kututupi kesalahan-kesalahan kamu dan akan Kumasukkan kamu ke dalam surga yang di bawahnya mengalir sungai-sungai. Maka siapa yang kafir sesudah itu) maksudnya sesudah perjanjian (di antara kamu, sesungguhnya ia telah sesat dari jalan yang lurus.") dari jalan yang benar. Sawaa` pada asalnya ialah yang pertengahan. Maka mereka langgar perjanjian itu hingga Allah pun berfirman:\qt@no{12}}%
\qt@newcmd\qurantrans@id@dclxxxii{%
(Maka disebabkan mereka melanggar) maa merupakan tambahan (janji itu, Kami kutuk mereka) artinya Kami jauhkan dari rahmat Kami (dan Kami jadikan hati mereka keras) tak hendak lunak untuk menerima keimanan. (Mereka ubah perkataan-perkataan)yang terdapat dalam Taurat berupa sifat-sifat dan ciri-ciri Muhammad (dari tempat-tempatnya) semula yang ditaruh oleh Allah (dan mereka lupakan) tinggalkan (sebagian dari peringatan-peringatan yang telah disampaikan kepada mereka) dalam Taurat mengenai ketaatan kepada Muhammad. (Dan selalulah kamu) perkataan ditujukan kepada Nabi saw. (melihat) secara jelas (pengkhianatan dari mereka) dengan mengingkari janji dan lain-lain (kecuali sedikit di antara mereka) yang masuk Islam. (Maka maafkanlah mereka itu dan biarkanlah, sesungguhnya Allah menyukai orang-orang yang berbuat baik) ini dimansukh oleh ayat perang.\qt@no{13}}%
\qt@newcmd\qurantrans@id@dclxxxiii{%
(Dan di antara orang-orang yang mengatakan, ``Sesungguhnya kami ini orang-orang Nasrani,") berkaitan dengan firman-Nya (ada yang telah Kami ambil pula janji mereka) sebagaimana halnya orang-orang Yahudi dari kalangan Bani Israel (maka mereka lupakan sebagian dari peringatan yang telah disampaikan kepada mereka) yakni dalam Injil berupa keimanan dan lain-lain hingga mereka ingkari perjanjian itu (maka Kami bangkitkan di antara mereka permusuhan dan kebencian sampai hari kiamat) dengan pertikaian dan perbedaan keinginan mereka, hingga setiap golongan mengafirkan yang lain (dan Allah akan memberitakan kepada mereka kelak) yakni di akhirat (apa-apa yang mereka perbuat) lalu mendapat pembalasan daripada-Nya.\qt@no{14}}%
\qt@newcmd\qurantrans@id@dclxxxiv{%
(Hai Ahli kitab! Sesungguhnya telah datang kepada kamu utusan kami) Muhammad (mengungkapkan kepadamu banyak hal dari apa yang kamu sembunyikan dari Alkitab) yakni kitab Taurat dan Injil seperti ayat tentang rajam dan sifat-sifat Nabi saw. (dan banyak pula yang dibiarkannya) di antara demikian sehingga tidak diungkapkannya jika tidak ada kepentingannya selain dari membukakan rahasia kamu belaka. (Sesungguhnya telah datang kepadamu cahaya dari Allah) itulah dia Nabi saw. (dan kitab) yakni Alquran (yang jelas) nyata.\qt@no{15}}%
\qt@newcmd\qurantrans@id@dclxxxv{%
(Dengan kitab itu Allah menunjuki orang-orang yang mengikuti keridaan-Nya) maksudnya dengan Alquran dan dengan jalan beriman (ke jalan-jalan keselamatan) jalan yang menyelamatkan mereka (dan mengeluarkan mereka dari kegelapan) yakni kekafiran (kepada cahaya) yakni keimanan (dengan izin-Nya) dengan iradat-Nya (serta membimbing mereka ke jalan yang lurus) yakni agama Islam.\qt@no{16}}%
\qt@newcmd\qurantrans@id@dclxxxvi{%
(Sungguh, telah kafirlah orang-orang yang mengatakan, ``Sesungguhnya Allah itu ialah Almasih putra Maryam.") yang mereka memandangnya sebagai Tuhan. Mereka ini ialah kaum Yakobin suatu sekte dari agama Nasrani (Katakanlah, ``Siapakah yang dapat menolak) menghalangi (akan) siksa (Allah walau sedikit pun, jika Dia hendak membinasakan Almasih putra Maryam itu beserta ibunya dan orang-orang yang ada di bumi keseluruhannya?) Maksudnya tak seorang pun yang mampu menolak kehendak-Nya. Dan sekiranya Almasih itu benar-benar Tuhan tentulah ia akan mampu melakukannya. (Dan milik Allahlah kerajaan langit dan bumi dan apa yang terdapat di antara keduanya. Diciptakan-Nya apa yang disukai-Nya, dan Allah atas segala sesuatu) yang dikehendaki-Nya (Maha Kuasa").\qt@no{17}}%
\qt@newcmd\qurantrans@id@dclxxxvii{%
(Kata orang-orang Yahudi dan Nasrani) artinya kata masing-masing golongan itu ("Kami ini anak-anak Allah) maksudnya seperti anak-anak-Nya dalam keakraban dan kedudukan, sebaliknya Dia tak ubahnya dengan bapak kami dalam kecintaan dan kasih sayang (dan kekasih-kekasih-Nya." Katakanlah) kepada mereka hai Muhammad ("Kalau begitu kenapa Allah menyiksamu karena dosa-dosamu?") Maksudnya ucapanmu itu bohong, karena biasanya bapak tak mau menyiksa anaknya begitu pula seorang kekasih terhadap orang yang disayanginya (bahkan kamu hanyalah manusia biasa termasuk) golongan makhluk (yang diciptakan-Nya) di antara manusia, sama-sama menerima pahala dan memikul dosa bersama mereka (diampuni-Nya siapa yang dikehendaki-Nya) bagi-Nyalah ampunan (dan disiksa-Nya siapa yang dikehendaki-Nya) untuk disiksa tanpa suatu pun yang akan menghalangi-Nya. (Dan milik Allahlah kerajaan langit dan bumi dan segala apa yang terdapat di antara keduanya dan kepada-Nya tempat kembali).\qt@no{18}}%
\qt@newcmd\qurantrans@id@dclxxxviii{%
(Hai Ahli Kitab! Sesungguhnya telah datang kepadamu rasul Kami) yakni Muhammad (menjelaskan kepada kamu) syariat-syariat agama (ketika terputusnya pengiriman rasul-rasul) karena antara dia dengan Isa tak seorang pun rasul yang diutus Allah sedangkan jarak masanya ialah 569 tahun (agar) tidak (kamu katakan) jika kamu disiksa nanti ("Tidak ada datang kepada kami) min sebagai tambahan (pembawa berita gembira dan tidak pula pembawa peringatan karena sesungguhnya telah datang kepadamu pembawa berita gembira maupun pembawa peringatan itu") sehingga tak ada kemaafan bagimu lagi! (Dan Allah Maha Kuasa atas segala sesuatu) di antaranya menyiksamu jika kamu tidak taat dan patuh kepada-Nya.\qt@no{19}}%
\qt@newcmd\qurantrans@id@dclxxxix{%
(Dan) ingatlah (ketika Musa berkata kepada kaumnya, ``Hai kaumku! Ingatlah nikmat Allah kepadamu ketika diangkat-Nya padamu) maksudnya dari golonganmu (para nabi dan dijadikan-Nya kamu sebagai raja-raja) yang mempunyai anak buah dan pelayan (serta diberi-Nya kamu apa yang belum pernah diberikan-Nya kepada seorang pun di antara umat manusia) seperti hidangan dari langit, manna dan salwa, terbelahnya lautan dan lain-lain.\qt@no{20}}%
\qt@newcmd\qurantrans@id@dcxc{%
(Hai kaumku! Masuklah kamu ke tanah suci) yang disucikan (yang telah ditetapkan Allah bagi kamu) telah dititahkan-Nya untuk memasukinya yaitu tanah Syam (dan janganlah kamu lari ke belakang) berbalik surut karena takut kepada musuh (nanti kamu menjadi orang-orang yang merugi.") dalam usahamu.\qt@no{21}}%
\qt@newcmd\qurantrans@id@dcxci{%
(Jawab mereka, ``Hai Musa! Sesungguhnya di dalamnya ada orang-orang yang aniaya) sisa-sisa bangsa Ad yang bertubuh tinggi dan bertenaga besar (Dan sesungguhnya kami tidak akan memasukinya hingga mereka keluar daripadanya. Jika mereka telah keluar daripadanya barulah kami memasuki.")nya.\qt@no{22}}%
\qt@newcmd\qurantrans@id@dcxcii{%
(Berkatalah) kepada mereka (dua orang laki-laki di antara orang-orang yang takut) menyalahi perintah-perintah Allah bernama Yusya dan Kalib, yakni dua orang di antara para pemimpin yang dikirim Musa untuk menyelidiki orang-orang aniaya itu (dan Allah telah memberi kedua mereka itu nikmat) berupa tindakan bijaksana hingga mereka tak hendak menyingkapkan keadaan sebenarnya dari orang-orang aniaya itu selain kepada Musa berbeda halnya dengan anggota-anggota lainnya yang menyiarkan berita itu hingga kaum Musa pun menjadi takut karenanya. ("Serbulah mereka dengan melalui pintu gerbang) maksudnya pintu gerbang kota dan janganlah takut kepada mereka karena mereka itu tinggal tubuh tanpa hati atau keberanian. (Apabila kamu memasukinya niscaya kamu akan beroleh kemenangan) hal itu mereka ucapkan karena yakin akan beroleh pertolongan Allah dan bahwa Allah pasti menepati janji-Nya. (Dan kepada Allahlah hendaknya kamu bertawakal jika kamu betul-betul orang-orang yang beriman.")\qt@no{23}}%
\qt@newcmd\qurantrans@id@dcxciii{%
(Kata mereka, ``Hai Musa! Kami sekali-kali tidak akan memasukinya untuk selama-lamanya selagi mereka masih berada di dalamnya. Maka pergilah kamu bersama Tuhanmu dan perangilah) mereka (biarlah kami di sini duduk menanti saja.") tak ikut berperang.\qt@no{24}}%
\qt@newcmd\qurantrans@id@dcxciv{%
(Kata Musa) ketika itu ("Wahai Tuhanku! Aku tidak menguasai kecuali diriku dan) kecuali (saudaraku) adapun yang lainnya tidak, oleh sebab itu paksalah mereka supaya tunduk (maka pisahkanlah) atau ceraikan (di antara kami dengan orang-orang yang fasik itu.")\qt@no{25}}%
\qt@newcmd\qurantrans@id@dcxcv{%
(Firman Allah) Taala kepadanya ("Maka kalau begitu negeri itu) yakni tanah suci tadi (diharamkan atas mereka) memasukinya (selama 40 tahun mereka akan bertualang tak tahu jalan) kebingungan (di negeri itu) menurut Ibnu Abbas luasnya sembilan farsakh persegi. (Maka janganlah kamu bersedih) berduka-cita (terhadap kaum yang fasik itu) menurut riwayat mereka memulai perjalanan di waktu malam dengan penuh kesungguhan ke arah yang dituju tetapi di waktu pagi mereka telah berada kembali di tempat semula. Demikian pula halnya perjalanan di waktu siang hingga akhirnya mereka binasa (mati") kecuali orang-orang yang di waktu itu usianya belum lagi mencapai 20 tahun. Ada yang mengatakan bahwa jumlah mereka enam ratus ribu orang dan di padang itulah, yakni yang disebut padang Tih, wafat Harun dan Musa. Hal itu menjadi rahmat bagi mereka berdua sebaliknya menjadi azab dan siksa bagi umat mereka. Setelah dekat kematiannya, Musa memohon kepada Allah agar didekatkan kepada tanah suci itu kira-kira dalam jarak sepelemparan batu, maka permohonan itu dikabulkannya sebagaimana tersebut dalam hadis. Setelah masa empat puluh tahun itu Allah mengangkat Yusya menjadi nabi dan memerintahkannya untuk memerangi orang-orang aniaya tadi. Maka berangkatlah ia dengan sisa-sisa Israel dan memerangi musuh yang ketika itu ialah hari Jumat. Menurut berita, matahari terhenti selama sesaat menunggu selesai mereka berperang. Diriwayatkan oleh Ahmad dalam musnadnya sebuah hadis bahwa matahari itu tidak pernah tertahan jalannya untuk kepentingan manusia kecuali bagi Yusya, yaitu di malam-malam perjalanannya menuju Baitulmakdis.\qt@no{26}}%
\qt@newcmd\qurantrans@id@dcxcvi{%
(Dan bacakanlah) hai Muhammad (kepada mereka) yakni kepada kaummu (kabar) berita (dua orang anak Adam) yaitu Habil dan Qabil (dengan sebenarnya) berhubungan dengan utlu (ketika keduanya mempersembahkan kurban) kepada Allah berupa domba dari Habil dan hasil tanaman dari Qabil. (Maka diterima dari salah seorang mereka) yakni dari Habil dengan alamat turunnya api dari langit yang melahap kurbannya (dan tidak diterima dari yang lain) yakni dari Qabil yang menjadi murka dan memendam kedengkian dalam dirinya menunggu naik hajinya Adam. (Katanya) yakni Qabil kepada Habil ("Sungguh, akan kubunuh kamu!") Kenapa kurbanmu diterima sedangkan kurban saya tidak! (Jawabnya, yakni Habil, ``Sesungguhnya Allah hanya menerima kurban dari orang-orang yang bertakwa").\qt@no{27}}%
\qt@newcmd\qurantrans@id@dcxcvii{%
("Sungguh, jika) lam menunjukkan sumpah (kamu mengulurkan) atau menggerakkan (tanganmu kepadaku untuk membunuhku, tidaklah aku akan mengulurkan tanganku kepadamu untuk membunuhmu. Sesungguhnya aku takut akan Allah, Tuhan seru sekalian alam.") jika membunuhmu.\qt@no{28}}%
\qt@newcmd\qurantrans@id@dcxcviii{%
(Sesungguhnya aku ingin agar kamu kembali membawa dosaku) maksudnya kembali menghadap kepada Allah dengan membawa dosa membunuhku (dan dosamu sendiri) yakni yang kamu perbuat sebelumnya (hingga kamu akan menjadi penghuni neraka) sedangkan aku tak ingin memikul dosamu jika membunuhnya sehingga aku menjadi penghuni neraka pula. Firman Allah swt.: ("Dan demikianlah balasan bagi orang-orang yang aniaya.")\qt@no{29}}%
\qt@newcmd\qurantrans@id@dcxcix{%
(Tetapi nafsunya menggodanya untuk membunuh saudaranya lalu dibunuhnyalah, maka jadilah dia termasuk di antara orang-orang yang merugi) disebabkan pembunuhan itu. Mulanya ia tidak tahu apa yang akan diperbuatnya terhadap mayat saudaranya itu karena ia adalah mayat yang pertama dari anak cucu Adam di muka bumi, maka dipikulnyalah di atas punggungnya.\qt@no{30}}%
\qt@newcmd\qurantrans@id@dcc{%
(Lalu Allah mengirimkan seekor burung gagak menggali bumi) maksudnya mengorek tanah dengan paruh dan kedua kakinya lalu menimbunkannya di atas bangkai saudaranya seakan-akan menguburkannya (untuk memperlihatkan kepadanya bagaimana seharusnya dia menutupi) atau menguburkan (mayat saudaranya. Katanya, ``Wahai celakanya daku! Mengapa aku tidak mampu) buat (bertindak seperti burung gagak ini hingga dapat menguburkan mayat saudaraku. Maka jadilah dia di antara orang-orang yang menyesal.") karena telah memikulnya tadi. Kemudian digalinya liang lalu dikuburkannya mayat saudaranya Habil itu.\qt@no{31}}%
\qt@newcmd\qurantrans@id@dcci{%
(Oleh sebab itu) artinya karena perbuatan Qabil itu tadi (Kami tetapkan bagi Bani Israel bahwa sesungguhnya) innahuu disebut dhamir sya`n (siapa yang membunuh seorang manusia bukan karena manusia lainnya) yang dibunuhnya (atau) bukan karena (kerusakan) yang diperbuatnya (di muka bumi) berupa kekafiran, perzinaan atau perampokan dan sebagainya (maka seolah-olah dia telah membunuh manusia kesemuanya. Sebaliknya siapa yang memelihara kehidupannya) artinya tidak hendak membunuhnya (maka seolah-olah ia telah memelihara kehidupan manusia seluruhnya.) Kata Ibnu Abbas, ``Ini dilihat dari segi melanggar kesuciannya dan dari segi memelihara serta menjaganya." (dan sesungguhnya telah datang kepada mereka itu) yakni kepada orang-orang Israel (rasul-rasul Kami membawa keterangan-keterangan yang jelas) maksudnya mukjizat-mukjizat (kemudian banyak di antara mereka sesudah itu melampaui batas dalam berbuat kerusakan di muka bumi) dengan kekafiran, melakukan pembunuhan dan lain-lain.\qt@no{32}}%
\qt@newcmd\qurantrans@id@dccii{%
(Bahwasanya pembalasan terhadap orang-orang yang memerangi Allah dan rasul-Nya) artinya dengan memerangi kaum muslimin (dan membuat kerusakan di muka bumi) dengan menyamun dan merampok (ialah dengan membunuh atau menyalib mereka atau tangan dan kaki mereka dipotong secara timbal balik) maksudnya tangan kanan dengan kaki kiri mereka (atau dibuang dari kampung halamannya). Atau secara bertingkat, maka hukum bunuh itu ialah bagi yang membunuh saja, hukum salib bagi yang membunuh dan merampas harta, hukum potong bagi yang merampas harta tetapi tanpa membunuh sedangkan hukum buang bagi yang mengacau saja. Hal ini dikemukakan oleh Ibnu Abbas dan dianut oleh Syafii. Menurut yang terkuat di antara dua buah pendapat dilaksanakannya hukum salib itu ialah tiga hari setelah dihukum bunuh. Tetapi ada pula yang mengatakan tidak lama sebelum dibunuh. Termasuk dalam hukum buang hukuman lain yang sama pengaruhnya dalam memberikan pelajaran seperti tahanan penjara dan lain-lain. (Demikian itu) maksudnya pembalasan atau hukuman tersebut (merupakan kehinaan bagi mereka) kenistaan (di dunia sedangkan di akhirat mereka beroleh siksa yang besar) yaitu siksa neraka.\qt@no{33}}%
\qt@newcmd\qurantrans@id@dcciii{%
(Kecuali orang-orang yang tobat) di antara orang-orang yang menyalakan api dan peperangan perampokan tadi (sebelum kamu dapat menguasai mereka, maka ketahuilah bahwa Allah Maha Pengampun) terhadap mereka atas perbuatan mereka itu (lagi Maha Penyayang) kepada mereka. Dalam ayat ini tidak disebutkan ``janganlah mereka kamu jatuhi hukuman" untuk menunjukkan bahwa dengan bertobat itu yang gugur hanyalah hak Allah dan tidak hak manusia. Demikian yang dapat ditangkap dengan jelas dan saya lihat tidak seorang pun yang menentangnya, wallahu a`lam. Maka jika seseorang membunuh dan merampas harta, maka ia dihukum bunuh dan dipotong tetapi tidak disalib. Ini merupakan yang terkuat di antara kedua pendapat Syafii. Mengenai bertobat setelah ia dapat ditangkap, maka tak ada pengaruh dan manfaat apa-apa. Ini juga merupakan yang terkuat di antara kedua pendapat Imam Syafii.\qt@no{34}}%
\qt@newcmd\qurantrans@id@dcciv{%
(Hai orang-orang yang beriman, bertakwalah kamu kepada Allah) artinya takutlah akan siksa-Nya dengan jalan menaati-Nya (dan carilah jalan kepada-Nya) yaitu jalan yang akan mendekatkan dirimu kepada-Nya dengan jalan taat dan ibadah (dan berjihadlah pada jalan-Nya) maksudnya untuk meninggikan agama-Nya (semoga kamu beruntung atau beroleh keberhasilan).\qt@no{35}}%
\qt@newcmd\qurantrans@id@dccv{%
(Sesungguhnya orang-orang kafir, sekiranya) terjadilah (bahwa mereka memiliki seluruh yang terdapat di bumi dan sebanyak itu lagi sebagai tambahannya untuk menebus diri mereka dari siksa hari kiamat tidaklah akan diterima dari mereka dan bagi mereka azab yang pedih).\qt@no{36}}%
\qt@newcmd\qurantrans@id@dccvi{%
(Mereka ingin) mengangankan (hendak keluar dari neraka, tetapi tidak mungkin keluar daripadanya dan bagi mereka siksa yang kekal) untuk selama-lamanya.\qt@no{37}}%
\qt@newcmd\qurantrans@id@dccvii{%
(Laki-laki yang mencuri dan wanita yang mencuri) al yang terdapat pada keduanya menunjukkannya sebagai isim maushul dan berfungsi sebagai mubtada, mengingat al mirip dengan syarat maka khabarnya diawali dengan fa, yaitu (maka potonglah tangan mereka) tangan kanan masing-masing mulai dari pergelangan. Dinyatakan oleh sunah bahwa hukum potong itu dilaksanakan jika yang dicuri itu bernilai seperempat dinar atau lebih; jika perbuatannya itu diulanginya lagi maka yang dipotong kakinya yang kiri dari pergelangan kaki, kemudian tangan kiri lalu kaki kanan dan setelah itu dilakukan hukum takzir (sebagai balasan) manshub sebagai mashdar (atas apa yang mereka kerjakan dan sebagai siksaan) artinya hukuman bagi mereka (dari Allah dan Allah Maha Perkasa) artinya menguasai segala urusan (lagi Maha Bijaksana) terhadap makhluk-Nya.\qt@no{38}}%
\qt@newcmd\qurantrans@id@dccviii{%
(Siapa yang tobat setelah keaniayaannya) artinya tidak mencuri lagi (dan memperbaiki diri) atau amalnya (maka sesungguhnya Allah menerima tobatnya. Sesungguhnya Allah itu Maha Pengampun lagi Maha Penyayang) untuk menguraikan ini telah kita kemukakan keterangan yang lalu. Maka dengan tobatnya itu tidaklah gugur hak manusia berupa hukum potong dan pengembalian harta. Kemudian sunah menyatakan bahwa jika yang punya hak memberi maaf sebelum diadukan kepada imam, gugurlah hukum potong itu terhadapnya. Dan inilah yang menjadi pendapat Syafii.\qt@no{39}}%
\qt@newcmd\qurantrans@id@dccix{%
(Tidaklah kamu ketahui) pertanyaan ini sebagai pengukuhan (bahwa sesungguhnya Allah memiliki kerajaan langit dan bumi, disiksa-Nya siapa yang dikehendaki-Nya) untuk disiksa (dan diampuni-Nya siapa yang dikehendaki-Nya) untuk diampuni. (Dan Allah Maha Kuasa atas segala sesuatu) di antaranya menurunkan siksa atau memberi ampun.\qt@no{40}}%
\qt@newcmd\qurantrans@id@dccx{%
(Hai Rasul, janganlah kamu menjadi bersedih hati oleh) disebabkan perbuatan (orang-orang yang berlomba-lomba dalam kekafiran) hingga tanpa menunggu lama mereka akan terjatuh di dalamnya; artinya bila ada kesempatan mereka akan menyatakan kekafiran itu (di antara) min merupakan penjelasan (orang-orang yang mengatakan dengan mulut mereka, ``Kami telah beriman.") maksudnya dengan lidah mereka nyatakan hal tersebut (padahal hati mereka tidak beriman) mereka ini ialah orang-orang munafik (dan juga di antara orang-orang Yahudi) yakni suatu kaum (yang amat gemar mendengar berita-berita bohong) yang dibuat-buat oleh pendeta-pendeta mereka lalu mereka terima dengan baik (dan amat suka pula mendengar berita-berita) daripadamu (untuk suatu kaum) artinya demi kepentingan kaum (yang lain) dari golongan Yahudi (yang belum pernah datang kepadamu) yakni warga Khaibar. Terdapat di sana sepasang laki-laki dan perempuan yang telah berumah tangga melakukan perzinaan, tetapi mereka berkeberatan untuk menjalankan hukuman rajam kepada kedua pesakitan. Lalu mereka mengirimkan orang-orang warga Quraizhah untuk menanyakan hukuman mereka itu kepada Nabi Muhammad saw. (Mereka mengubah-ubah perkataan) yang tercantum dalam Taurat seperti ayat tentang rajam (dari tempat-tempatnya) yang ditaruh Allah padanya; artinya mereka menggantikannya dengan yang lain. (Kata mereka) yakni kepada orang-orang yang mereka utus tadi ("Jika yang diberikan kepadamu itu ialah ini) maksudnya hukum yang telah dirubah dan difatwakan oleh Muhammad yaitu hukum pukulan (maka ambillah) terimalah (tetapi jika bukan itu yang diberikan kepadamu) dan fatwa yang diberikannya bertentangan dengannya (maka berhati-hatilah.") untuk menerimanya. (Siapa yang dikehendaki Allah kesesatannya, maka kamu sekali-kali tidak akan dapat menguasai sesuatu yang datang dari Allah) untuk menolaknya (mereka itu ialah orang-orang yang tidak dikehendaki Allah menyucikan hati mereka) dari kekafiran, dan sekiranya dikehendaki-Nya tentulah hal itu akan tercapai. (Bagi mereka di dunia ini kehinaan) kenistaan dengan terbukanya rahasia dan pembayaran upeti (sedangkan di akhirat siksa yang besar.)\qt@no{41}}%
\qt@newcmd\qurantrans@id@dccxi{%
(Mereka orang-orang yang gemar mendengar berita-berita bohong dan banyak memakan yang haram) dibaca suht atau suhut; artinya barang haram seperti uang suap (maka jika mereka datang kepadamu) untuk meminta sesuatu keputusan (maka putuskanlah di antara mereka atau berpalinglah dari mereka) pilihan di antara alternatif ini dihapus/dinasakh dengan firman-Nya, ``..... maka putuskanlah di antara mereka." Oleh sebab itu jika mereka mengadukan hal itu kepada kita wajiblah kita memberikan keputusannya di antara mereka. Dan ini merupakan yang terkuat di antara kedua pendapat Syafii. Dan sekiranya mereka mengadukan perkara itu bersama orang Islam, maka hukum memutuskan itu wajib secara ijmak. (Jika mereka berpaling daripadamu, maka sekali-kali tidak akan memberi mudarat kepadamu sedikit pun juga. Dan jika kamu memutuskan) perkara di antara mereka (maka putuskanlah di antara mereka dengan adil) tidak berat sebelah. (Sesungguhnya Allah menyukai orang-orang yang adil) dalam memberikan keputusan dan akan memberi mereka pahala.\qt@no{42}}%
\qt@newcmd\qurantrans@id@dccxii{%
(Dan betapa caranya mereka mengangkatmu menjadi hakim mereka padahal di sisi mereka ada Taurat yang memuat hukum Allah) yaitu dengan rajam. Pertanyaan ini menunjukkan keheranan; artinya maksud mereka yang sebenarnya bukanlah untuk mengetahui kebenaran tetapi untuk mencari mana yang lebih ringan (Kemudian mereka berpaling) dari hukum rajammu yang sebenarnya sesuai dengan kitab mereka (setelah demikian itu) setelah diberi keputusan itu (dan tidaklah mereka orang-orang yang sungguh-sungguh beriman.)\qt@no{43}}%
\qt@newcmd\qurantrans@id@dccxiii{%
(Sesungguhnya Kami telah menurunkan Taurat berisi petunjuk) dari kesesatan (dan cahaya) untuk menjelaskan hukum-hukum (yang diambil untuk memutuskan hukum oleh nabi-nabi) dari Bani Israel (yang tunduk) menyerahkan diri kepada Allah (bagi orang-orang Yahudi dan oleh orang-orang alim dan para pendeta) yakni ahli-ahli hukum dari kalangan mereka (dengan apa) disebabkan karena (mereka diminta untuk menyimpan) artinya diberi amanat untuk menjaga oleh Allah (Kitabullah) jangan sampai diubah-ubah (dan mereka menjadi saksi terhadapnya) bahwa ia benar adanya. (Maka janganlah kamu takut akan manusia) hai orang-orang Yahudi dalam menyingkapkan sifat-sifat dan ciri-ciri Muhammad saw. yang kamu ketahui, tentang ayat rajam dan sebagainya (hanya takutlah kepada-Ku) dalam menyembunyikannya (dan janganlah kamu beli, maksudnya, jangan kamu tukar ayat-ayat-Ku dengan harga yang sedikit) berupa harta benda dunia yang kamu dapatkan sebagai imbalan menyembunyikannya. (Siapa yang tidak memutuskan menurut apa yang diturunkan Allah, maka merekalah orang-orang yang kafir) terhadap-Nya.\qt@no{44}}%
\qt@newcmd\qurantrans@id@dccxiv{%
(Dan telah Kami tetapkan terhadap mereka d dalamnya) maksudnya di dalam Taurat (bahwa jiwa) dibunuh (karena jiwa) yang dibunuhnya (mata) dicongkel (karena mata, hidung) dipancung (karena hidung, telinga) dipotong (karena telinga, gigi) dicabut (karena gigi) menurut satu qiraat dengan marfu'nya keempat anggota tubuh tersebut (dan luka-luka pun) manshub atau marfu' (berlaku kisas) artinya dilaksanakan padanya hukum balas jika mungkin; seperti tangan, kaki, kemaluan dan sebagainya. Hukuman ini walaupun diwajibkan atas mereka tetapi ditaqrirkan atau diakui tetap berlaku dalam syariat kita. (Siapa menyedekahkannya) maksudnya menguasai dirinya dengan melepas hak kisas itu (maka itu menjadi penebus dosanya) atas kesalahannya (dan siapa yang tidak memutuskan dengan apa yang diturunkan Allah) seperti kisas dan lain-lain (merekalah orang-orang yang aniaya).\qt@no{45}}%
\qt@newcmd\qurantrans@id@dccxv{%
(Dan Kami iringi jejak-jejak mereka) maksudnya jejak para nabi itu (dengan Isa putra Maryam, membenarkan apa yang berada di depannya) maksudnya yang sebelumnya (berupa Taurat dan Kami berikan kepadanya Injil yang berisi petunjuk) dari kesesatan (dan cahaya) artinya penjelasan bagi hukum-hukum (serta membenarkan) menjadi hal (bagi kitab Taurat yang berada sebelumnya) membenarkan hukum-hukum Taurat (serta menjadi petunjuk dan pengajaran bagi orang-orang yang takwa).\qt@no{46}}%
\qt@newcmd\qurantrans@id@dccxvi{%
(Dan pengikut-pengikut Injil hendaklah memutuskan perkara dengan apa yang diturunkan Allah di dalamnya) berupa hukum-hukum dan menurut satu qiraat walyahkum itu dibaca waliyahkum karena diathafkan pada ma`mul aatainaahu (Dan siapa yang tidak memutuskan perkara dengan apa yang diturunkan Allah, maka mereka itu orang-orang yang fasik.)\qt@no{47}}%
\qt@newcmd\qurantrans@id@dccxvii{%
(Dan telah Kami turunkan kepadamu) hai Muhammad (kitab) yakni Alquran (dengan kebenaran) berkaitan dengan anzalnaa (membenarkan apa yang terdapat di hadapannya) maksudnya yang sebelumnya (di antara kitab dan menjadi saksi) atau batu ujian (terhadapnya) kitab di sini maksudnya ialah kitab-kitab terdahulu. (Sebab itu putuskanlah perkara mereka) maksudnya antara ahli kitab jika mereka mengadu kepadamu (dengan apa yang diturunkan Allah) kepadamu (dan janganlah kamu mengikuti hawa nafsu mereka) dengan menyimpang (dari kebenaran yang telah datang kepadamu. Bagi tiap-tiap umat di antara kamu Kami beri) hai manusia (aturan dan jalan) maksudnya jalan yang nyata dan agama dan yang akan mereka tempuh. (Sekiranya dikehendaki Allah tentulah kamu dijadikan-Nya satu umat) dengan hanya satu syariat (tetapi) dibagi-bagi-Nya kamu kepada beberapa golongan (untuk mengujimu) mencoba (mengenai apa yang telah diberikan-Nya kepadamu) berupa syariat yang bermacam-macam untuk melihat siapakah di antara kamu yang taat dan siapa pula yang durhaka (maka berlomba-lombalah berbuat kebaikan) berpaculah mengerjakannya. (Hanya kepada Allahlah kembali kamu semua) dengan kebangkitan (maka diberitahukan-Nya kepadamu apa yang kamu perbantahkan itu) yakni mengenai soal agama dan dibalas-Nya setiap kamu menurut amal masing-masing.\qt@no{48}}%
\qt@newcmd\qurantrans@id@dccxviii{%
(Dan hendaklah kamu putuskan perkara di antara mereka dengan apa yang diturunkan Allah dan janganlah kamu ikuti hawa nafsu mereka dan berhati-hatilah terhadap mereka) agar (supaya mereka) tidak (memfitnahmu) artinya menyesatkanmu (dari sebagian yang telah diturunkan Allah kepadamu. Jika mereka berpaling) dari hukum yang diturunkan dan bermaksud mengubahnya (maka ketahuilah bahwasanya Allah menghendaki akan menimpakan kepada mereka musibah) hukuman di dunia (disebabkan sebagian dosa-dosa mereka) yang mereka perbuat di antaranya berpaling itu. Dan akan membalas semua dosa itu di akhirat kelak. (Dan sesungguhnya banyak di antara manusia itu orang-orang yang fasik.)\qt@no{49}}%
\qt@newcmd\qurantrans@id@dccxix{%
(Apakah hukum jahiliah yang mereka kehendaki) dengan memakai ya dan ta; artinya dengan berpaling itu mereka hanyalah hendak bermanis mulut dan mengambil muka sedangkan pertanyaan di sini berarti sanggahan (dan siapakah) artinya tak seorang pun (yang lebih baik hukumannya daripada Allah bagi kaum) artinya di sisi orang-orang (yang yakin) kepada-Nya. Diistimewakan menyebutkan mereka karena hanya merekalah yang bersedia merenungkan hal ini.\qt@no{50}}%
\qt@newcmd\qurantrans@id@dccxx{%
(Hai orang-orang yang beriman, janganlah kamu ambil orang-orang Yahudi dan Nasrani menjadi pemimpin) menjadi ikutanmu dan kamu cintai. (Sebagian mereka menjadi pemimpin bagi sebagian lainnya) karena kesatuan mereka dalam kekafiran. (Siapa di antara kamu mengambil mereka sebagai pemimpin, maka dia termasuk di antara mereka) artinya termasuk golongan mereka. (Sesungguhnya Allah tidak menunjuki orang-orang yang aniaya) karena mengambil orang-orang kafir sebagai pemimpin mereka.\qt@no{51}}%
\qt@newcmd\qurantrans@id@dccxxi{%
(Maka kamu lihat orang-orang yang di dalam hati mereka ada penyakit) yakni lemah akidahnya seperti Abdullah bin Ubai gembong munafik itu (bersegera kepada mereka) untuk mengambil mereka sebagai pemimpin (seraya katanya) mengemukakan alasan dari sikap mereka itu ("Kami takut akan mendapat giliran bencana.") misalnya giliran musim kemarau, kekalahan sedangkan urusan Muhammad tidak berketentuan sehingga tidak dapat membela kami. Berfirman Allah swt.: (Semoga Allah mendatangkan kemenangan) kepada rasul-Nya dengan mengembangkan agama-Nya (atau sesuatu keputusan dari sisi-Nya) misalnya dengan membuka kedok orang-orang munafik dan menyingkapkan rahasia mereka (sehingga mereka atas apa yang mereka rahasiakan dalam diri mereka) berupa keragu-raguan dan mengambil orang-orang kafir itu sebagai pemimpin (menjadi menyesal.)\qt@no{52}}%
\qt@newcmd\qurantrans@id@dccxxii{%
(Dan berkatalah) dibaca yaquulu marfu` sebagai awal kata dengan memakai wawu atau tidak. Ada pula yang membaca yaquula manshub karena diathafkan kepada ya`tiya (orang-orang yang beriman) kepada kawan-kawan mereka keheranan; yakni jika topeng kedustaan mereka telah disingkapkan ("Inikah orang-orang yang telah bersumpah dengan nama Allah secara bersungguh-sungguh) artinya sebenar-benarnya bersumpah (bahwa sesungguhnya mereka beserta kamu.") dalam soal keagamaan. Firman Allah swt.: ("Gugurlah) rusaklah/binasalah (amal perbuatan mereka yang baik) (maka jadilah mereka orang-orang yang merugi.") baik di dunia dengan terbukanya rahasia mereka maupun di akhirat dengan datangnya azab dan siksa.\qt@no{53}}%
\qt@newcmd\qurantrans@id@dccxxiii{%
(Hai orang-orang yang beriman! Siapa yang murtad) yartadda pakai idgam atau tidak; artinya murtad atau berbalik (di antara kamu dari agamanya) artinya berbalik kafir; ini merupakan pemberitahuan dari Allah swt. tentang berita gaib yang akan terjadi yang telah terlebih dahulu diketahui-Nya. Buktinya setelah Nabi Muhammad saw. wafat segolongan umat keluar dari agama Islam (maka Allah akan mendatangkan) sebagai ganti mereka (suatu kaum yang dicintai oleh Allah dan mereka pun mencintai-Nya) sabda Nabi saw., ``Mereka itu ialah kaum orang ini," sambil menunjuk kepada Abu Musa Al-Asyari; riwayat Hakim dalam sahihnya (bersikap lemah lembut terhadap orang-orang mukmin dan bersikap keras) atau tegas (terhadap orang-orang kafir. Mereka berjihad di jalan Allah dan tidak takut akan celaan orang yang suka mencela) dalam hal itu sebagaimana takutnya orang-orang munafik akan celaan orang-orang kafir. (Demikian itu) yakni sifat-sifat yang disebutkan tadi (adalah karunia Allah yang diberikan-Nya kepada siapa yang dikehendaki-Nya dan Allah Maha Luas) karunia-Nya (lagi Maha Mengetahui) akan yang patut menerimanya. Ayat ini turun ketika Ibnu Salam mengadu kepada Rasulullah, ``Wahai Rasulullah! Kaum kami telah mengucilkan kami!"\qt@no{54}}%
\qt@newcmd\qurantrans@id@dccxxiv{%
(Sesungguhnya yang menjadi penolongmu ialah Allah dan rasul-Nya serta orang-orang yang beriman yang mendirikan salat dan menunaikan zakat serta mereka rukuk) maksudnya khusyuk atau melakukan salat sunah.\qt@no{55}}%
\qt@newcmd\qurantrans@id@dccxxv{%
(Siapa yang mengambil Allah dan rasul-Nya serta orang-orang yang beriman sebagai penolongnya) lalu mereka dibela dan ditolongnya pula (maka sesungguhnya golongan agama Allah itulah yang akan menang) yang terjamin dengan pertolongan Allah swt. sedangkan pembelaan seseorang kepada agama Allah itu menjadi bukti bahwa ia dari golongan dan pengikut agama itu.\qt@no{56}}%
\qt@newcmd\qurantrans@id@dccxxvi{%
(Hai orang-orang yang beriman! Janganlah kamu ambil orang-orang yang menjadikan agamamu sebagai olok-olok) ejekan (dan barang permainan di antara) min untuk penjelasan (orang-orang yang diberi Alkitab sebelumnya dan orang-orang kafir) atau orang-orang musyrik; dengan jar dan nashab (sebagai pemimpin dan bertakwalah kepada Allah) dengan tidak mengambil mereka sebagai pemimpin (jika kamu beriman) artinya sungguh-sungguh dalam keimanan kamu itu.\qt@no{57}}%
\qt@newcmd\qurantrans@id@dccxxvii{%
(Dan) orang-orang yang (apabila kamu menyeru) atau memanggil mereka (untuk salat) yaitu dengan azan (mereka menjadikannya) salat itu (sebagai bahan olok-olok dan permainan) yakni dengan mempermainkan dan menertawakannya. (Demikian itu) maksudnya sikap mereka itu (adalah karena mereka) disebabkan oleh karena mereka (kaum yang tak mau berpikir). Ayat berikut ini diturunkan ketika orang-orang Yahudi menanyakan kepada Nabi saw., ``Kepada rasul-rasul yang manakah kamu beriman?" Jawabnya, ``Kepada Allah dan kepada apa-apa yang diturunkan kepada kami... sampai akhir ayat." Ketika Nabi saw. menyebut nama Isa, mereka berkata, ``Sepengetahuan kami tak ada agama yang lebih buruk dari agamamu!"\qt@no{58}}%
\qt@newcmd\qurantrans@id@dccxxviii{%
(Katakanlah, ``Hai ahli kitab! Apakah kamu menyalahkan) menolak (kami hanya karena kami beriman kepada Allah, kepada apa yang diturunkan kepada kami dan apa yang diturunkan sebelumnya) yakni kepada nabi-nabi yang terdahulu (dan bahwa kebanyakan di antara kamu orang-orang yang fasik?") diathafkan kepada an aamannaa sedangkan maksudnya ialah: tak ada yang kamu salahkan kecuali hanyalah keimanan kami yang rupanya tidak kamu setujui. Sikap tersebut membuat kalian pantas disebut orang-orang yang fasik. Padahal hal ini merupakan hal yang sudah tidak boleh diingkari.\qt@no{59}}%
\qt@newcmd\qurantrans@id@dccxxix{%
(Katakanlah, ``Apakah akan kukabarkan kepadamu) kuberitakan (orang-orang yang lebih buruk) lagi daripada warga (demikian) yang kamu salahkan itu (mengenai pembalasannya) asal artinya ialah pahalanya (di sisi Allah) yaitu (orang yang dikutuk oleh Allah) artinya dijauhkan dari rahmat-Nya (dan dimurkai-Nya serta di antara mereka ada yang dijadikan-Nya kera dan babi) dengan merubah bentuknya (dan) orang (yang menyembah tagut) yakni setan dengan jalan menaatinya. Pada minhum ditekankan arti man pada lafal sebelumnya yang dimaksud ialah orang-orang Yahudi. Menurut satu qiraat dibaca `abuda dengan diidhafatkan kepada yang sesudahnya sebagai isim jamak dari `abd dan dinashabkan karena ma`thuf kepada qiradah. (Mereka itu lebih buruk tempatnya) karena mereka menempati neraka berfungsi sebagai tamyiz (dan lebih tersesat lagi dari jalan yang lurus) dari jalan yang benar. Sawaa` arti asalnya ialah pertengahan. Disebutkan buruk dan lebih tersesat untuk mengimbangi ucapan mereka, 'Sepengetahuan kami tak ada agama yang lebih buruk dari agamamu.'"\qt@no{60}}%
\qt@newcmd\qurantrans@id@dccxxx{%
(Dan jika mereka datang kepadamu) yaitu orang-orang Yahudi munafik (mereka berkata, ``Kami beriman," padahal mereka masuk) kepadamu dengan membawa (kekafiran dan mereka keluar) daripadamu (dengan membawa kekafiran pula) mereka tidak beriman (dan Allah lebih mengetahui apa yang mereka sembunyikan) itu berupa kemunafikan.\qt@no{61}}%
\qt@newcmd\qurantrans@id@dccxxxi{%
(Dan akan kamu lihat banyak di antara mereka) maksudnya orang-orang Yahudi (bersegera) artinya cepat terlibat dalam (berbuat dosa) kedustaan (dan permusuhan) keaniayaan (serta memakan barang yang haram) seperti uang suap dan lain-lain (sungguh, amat buruklah apa yang mereka kerjakan) itu; yakni perbuatan-perbuatan yang mereka lakukan tadi.\qt@no{62}}%
\qt@newcmd\qurantrans@id@dccxxxii{%
(Kenapa orang-orang alim dan para pendeta mereka tak melarang mereka mengucapkan dosa) artinya kata-kata dusta (dan memakan barang yang haram? Sungguh, amat buruklah apa yang mereka perbuat itu) yaitu tidak melarang mereka berbuat kejahatan.\qt@no{63}}%
\qt@newcmd\qurantrans@id@dccxxxiii{%
(Orang-orang Yahudi berkata) setelah mereka ditimpa kesusahan disebabkan mendustakan Nabi saw. padahal selama ini mereka adalah orang-orang yang paling mampu dan paling banyak harta. ("Tangan Allah terbelenggu.") artinya dikatup hingga terhalang untuk menyebarkan rezeki kepada kita. Ucapan itu merupakan sindiran terhadap kikirnya Allah swt. buat melimpahkan rezeki. Firman Allah swt.: ("Tangan merekalah yang dibelenggu.") dari berbuat kebaikan hingga tak mau melakukannya. Ini sebagai doa terhadap mereka (dan mereka dikutuk disebabkan apa yang telah mereka katakan itu. Bahkan kedua tangan-Nya terbuka lebar) merupakan simbol tentang kiasan tentang sifat Allah Yang Maha Pemurah. Pujian kepada tangan ini untuk menunjukkan banyak dan melimpah-ruah karena segala sesuatu yang diberikan oleh seorang dermawan berupa harta melalui tangannya. (Dia memberi nafkah sebagaimana dikehendaki-Nya) apakah akan diperlapang ataukah akan dipersempit-Nya, tidak satu pun dapat menghalangi-Nya. (Dan apa yang diturunkan kepadamu dari Tuhanmu, berarti akan menambah banyak kedurhakaan dan kekafiran mereka) karena kekafiran mereka kepadanya. (Dan Kami timbulkan di antara mereka permusuhan dan kebencian sampai hari kiamat) hingga setiap golongan menentang dan memusuhi lainnya. (Setiap mereka menyalakan api peperangan) maksudnya untuk memerangi Nabi Muhammad saw. (dipadamkannya oleh Allah) artinya setiap mereka bermaksud, maka ditolak oleh Allah (dan mereka berbuat kerusakan di muka bumi) maksudnya menghancurkannya dengan berbuat maksiat (dan Allah tidak menyukai orang-orang yang berbuat kerusakan).\qt@no{64}}%
\qt@newcmd\qurantrans@id@dccxxxiv{%
(Dan sekiranya Ahli Kitab itu beriman) kepada Nabi Muhammad saw. (dan bertakwa) artinya menjaga diri dari kekafiran (pastilah Kami hapus dari mereka kesalahan mereka dan Kami masukkan mereka ke dalam surga-surga kenikmatan).\qt@no{65}}%
\qt@newcmd\qurantrans@id@dccxxxv{%
(Dan sekiranya mereka menegakkan Taurat dan Injil) mengamalkan ajarannya, di antaranya beriman kepada Nabi saw. (dan apa yang diturunkan kepada mereka) maksudnya kitab-kitab (dari Tuhan mereka, tentulah mereka akan beroleh makanan dari atas mereka dan dari bawah kaki mereka) maksudnya dilapangkan-Nya rezeki dan dilimpahkan-Nya atas mereka dari segenap penjuru. (Di antara mereka ada umat) maksudnya golongan (yang adil) yakni mengamalkannya dan mereka itulah yang beriman kepada Nabi saw., seperti Abdullah bin Salam dan kawan-kawannya (tetapi banyak di antara mereka amat jelek atau amat buruk apa yang mereka kerjakan.)\qt@no{66}}%
\qt@newcmd\qurantrans@id@dccxxxvi{%
(Hai rasul, sampaikanlah) semua (yang diturunkan kepadamu dari Tuhanmu) dan janganlah kamu sembunyikan sesuatu pun daripadanya karena takut akan mendapatkan hal-hal yang tidak diinginkan (dan jika tidak kamu lakukan) tidak kamu sampaikan semua yang diturunkan padamu itu (berarti kamu tidak menyampaikan risalah-Nya) risalah dengan tunggal atau jamak karena menyembunyikan sebagian berarti menyembunyikan semuanya. (Dan Allah memelihara kamu dari manusia) agar tidak sampai membunuhmu. Pada mulanya Rasulullah saw. itu dikawal sampai turun ayat ini, lalu sabdanya, ``Pergilah karena sesungguhnya Allah memeliharaku!" Riwayat Hakim. (Sesungguhnya Allah tidak memberikan bimbingan kepada kaum yang kafir.)\qt@no{67}}%
\qt@newcmd\qurantrans@id@dccxxxvii{%
(Katakanlah ``Hai Ahli Kitab! Kamu tidaklah berada dalam sesuatu agama) tidak dianggap beragama (hingga kamu menjalankan Taurat dan Injil dan apa yang diturunkan kepadamu dari Tuhanmu) yakni dengan mengamalkan apa yang terdapat di dalamnya, di antaranya beriman kepadaku. (Sesungguhnya apa yang diturunkan kepadamu dari Tuhanmu hanyalah akan menambah kedurhakaan dan kekafiran kepada kebanyakan mereka) maksudnya bahwa disebabkan kekafiran mereka tadi, maka Alquran yang diturunkan padamu itu hanyalah menambah kekafiran dan kedurhakaan mereka, jadi bukan petunjuk dan keimanan. (Maka janganlah kamu berduka-cita) atau bersedih hati (terhadap orang-orang yang kafir.") jika mereka tak mau beriman, tidak usah mereka itu dihiraukan.\qt@no{68}}%
\qt@newcmd\qurantrans@id@dccxxxviii{%
(Sesungguhnya orang-orang mukmin orang-orang Yahudi) menjadi mubtada (kaum Shabiin) satu sekte dari Yahudi (dan orang-orang Nasrani) yang menjadi badal dari mubtada ialah (siapa saja yang benar-benar beriman) dari kalangan mereka (kepada Allah, hari kemudian dan beramal saleh, maka tidak ada kekhawatiran terhadap mereka dan tidak pula mereka bersedih hati) dalam menghadapi hari kemudian sebagai khabar dari mubtada dan yang menunjukkan kepada khabarnya inna.\qt@no{69}}%
\qt@newcmd\qurantrans@id@dccxxxix{%
(Sesungguhnya Kami telah mengambil perjanjian dari Bani Israel) untuk beriman kepada Allah dan Rasul-Nya (dan telah Kami utus kepada mereka rasul-rasul tetapi setiap datang kepada mereka seorang rasul) dari kalangan mereka sendiri (dengan membawa apa yang tidak diingini oleh hawa nafsu mereka) yaitu berupa perkara yang hak/benar maka mereka tidak mempercayainya (sebagian) dari rasul-rasul itu (mereka dustakan dan sebagian yang lain) dari rasul-rasul itu (mereka bunuh) seperti Nabi Zakaria dan Nabi Yahya. Pengungkapan dengan lafal yaqtuluuna/fi`il mudhari` bukannya dengan lafal qataluu/fi`il madhi menggambarkan tentang keadaan yang sedang berlangsung di masa lalu karena adanya fashilah/pemisah.\qt@no{70}}%
\qt@newcmd\qurantrans@id@dccxl{%
(Dan mereka mengira) mereka menduga (bahwa tidak akan terjadi) dengan dibaca rafa` maka an menjadi mukhaffafah/tidak beramal dan dibaca nashab maka an dapat menashabkan/beramal; artinya tidak bakalan terjadi (fitnah) siksaan yang menimpa diri mereka sebagai balasan dari perbuatan mendustakan para rasul dan berani membunuh mereka (sebagai akibatnya mereka menjadi buta) dari perkara yang hak hingga mereka tidak bisa melihatnya (dan mereka menjadi tuli) tidak bisa mendengar perkara yang hak (kemudian Allah menerima tobat mereka) tatkala mereka mau bertobat (kemudian mereka kembali menjadi buta dan tuli) untuk kedua kalinya (demikianlah kebanyakan dari kalangan mereka) lafal katsiirun sebagai dhamir/kata ganti (dan Allah Maha Melihat terhadap apa yang mereka kerjakan) untuk itu Ia membalas mereka sesuai dengan apa-apa yang telah mereka kerjakan.\qt@no{71}}%
\qt@newcmd\qurantrans@id@dccxli{%
(Sesungguhnya telah kafirlah orang-orang yang mengatakan, ``Sesungguhnya Allah ialah Almasih putra Maryam.") di masa sebelumnya telah terjadi hal yang serupa (padahal telah berkata) kepada mereka (Almasih, ``Hai Bani Israel, sembahlah Allah Tuhanku dan Tuhanmu) sesungguhnya aku ini hanyalah seorang hamba Allah dan bukan Tuhan (sesungguhnya orang-orang yang mempersekutukan sesuatu dengan Allah) menyembah kepada selain Allah (maka pasti Allah mengharamkan kepadanya surga) Allah melarangnya untuk memasuki surga (dan tempatnya ialah neraka dan tidak ada bagi orang-orang lalim itu seorang) lafal min adalah tambahan (penolong.") yang dapat mencegah siksaan Allah terhadap diri mereka.\qt@no{72}}%
\qt@newcmd\qurantrans@id@dccxlii{%
(Sesungguhnya telah kafirlah orang-orang yang mengatakan, ``Bahwasanya Allah salah seorang) dari tuhan (yang tiga) artinya salah seorang dari tuhan-tuhan yang jumlahnya tiga dan dua orang lainnya yang dianggap tuhan ialah Nabi Isa beserta ibunya. Mereka yang berpendapat demikian adalah golongan dari orang-orang Nasrani (padahal sekali-kali tidak ada Tuhan selain dari Tuhan Yang Esa. Dan jika mereka tidak berhenti dari apa yang mereka katakan itu) berhenti dari menigakan Allah, kemudian kembali mengesakan-Nya (pasti akan menimpa kepada orang-orang yang kafir) artinya mereka yang menetapi kekafirannya (di antara mereka siksaan yang pedih") siksaan yang sungguh amat memedihkan, yaitu siksaan neraka.\qt@no{73}}%
\qt@newcmd\qurantrans@id@dccxliii{%
(Maka mengapa mereka tidak bertobat kepada Allah dan memohon ampun kepada-Nya) atas apa yang telah mereka katakan; pertanyaan di sini menunjukkan kepada makna celaan. (Dan Allah Maha Pengampun) terhadap orang yang mau bertobat (lagi Maha Penyayang) kepadanya.\qt@no{74}}%
\qt@newcmd\qurantrans@id@dccxliv{%
(Almasih putra Maryam itu hanyalah seorang rasul yang sesungguhnya telah berlalu) telah lewat (sebelumnya beberapa rasul) maka dia pun akan berlalu/mati seperti mereka; dia bukanlah Tuhan seperti apa yang telah mereka sangkakan, jika memang demikian maka niscaya ia pun tidak akan berlalu/mati (dan ibunya seorang yang amat benar) seorang wanita yang teramat benar (keduanya biasa memakan makanan) sama seperti makhluk-makhluk hidup lainnya, maka siapa pun yang keadaannya demikian berarti dia bukanlah Tuhan karena ia masih membutuhkan makanan, lemah dan masih mengeluarkan kencing dan kotoran sebagai akibat dari makanan itu. (Perhatikanlah) dengan penuh rasa ketakjuban (bagaimana Kami menjelaskan kepada mereka, ahli kitab, tanda-tanda kekuasaan Kami) yang menunjukkan keesaan Kami (kemudian perhatikanlah bagaimana) lafal annaa adalah kata tanya (mendustakannya) mereka berpaling dari perkara hak yang disertai dengan bukti yang jelas.\qt@no{75}}%
\qt@newcmd\qurantrans@id@dccxlv{%
(Katakanlah, ``Mengapa kamu menyembah selain daripada Allah) selain-Nya (sesuatu yang tidak dapat memberi mara bahaya kepadamu dan tidak pula memberi manfaat?" Dan Allahlah Yang Maha Mendengar) terhadap perkataan-perkataanmu (lagi Maha Mengetahui) tentang tindak-tandukmu; kata istifham/kata tanya di sini menunjukkan keingkaran.\qt@no{76}}%
\qt@newcmd\qurantrans@id@dccxlvi{%
(Katakanlah, ``Hai Ahli Kitab!) para pemeluk agama Yahudi dan agama Nasrani (Janganlah kamu berlebih-lebihan) janganlah kamu melampaui batas (dalam agamamu) secara berlebih-lebihan (dengan cara tidak benar) yaitu dengan cara merendahkan Nabi Isa atau kamu mengangkatnya secara berlebihan dari apa yang seharusnya (dan janganlah kamu mengikuti hawa nafsu orang-orang yang telah sesat dahulunya sebelum kedatangan Nabi Muhammad) mengikuti cara berlebih-lebihan yang pernah dilakukan oleh para pendahulu mereka (dan mereka telah menyesatkan kebanyakan) manusia (dan mereka tersesat dari jalan yang lurus.") jalan yang hak; lafal as-sawaa` asalnya bermakna pertengahan.\qt@no{77}}%
\qt@newcmd\qurantrans@id@dccxlvii{%
(Telah dilaknat orang-orang kafir dari Bani Israel melalui lisan Daud) yaitu Nabi Daud mendoakan/menyerapah mereka hingga mereka berubah ujud menjadi kera-kera; mereka adalah orang-orang dari kalangan Bani Israel yang menduduki tanah Ailah (dan Isa putra Maryam) yaitu Nabi Isa mendoakan/menyerapah mereka sehingga mereka berubah ujud menjadi babi-babi; mereka adalah orang-orang Bani Israel yang memiliki Al-Maidah/hidangan yang didatangkan dari langit (yang demikian itu) adalah laknat (disebabkan mereka durhaka dan melampaui batas).\qt@no{78}}%
\qt@newcmd\qurantrans@id@dccxlviii{%
(Mereka satu sama lain tidak pernah melarang) artinya sebagian di antara mereka tidak pernah melarang sebagian lainnya (dari) kebiasaan (tindakan mungkar yang biasa mereka perbuat. Sesungguhnya amat buruklah apa yang selalu mereka perbuat) kebiasaan mereka dalam melakukan perbuatan mungkar itu.\qt@no{79}}%
\qt@newcmd\qurantrans@id@dccxlix{%
(Kamu melihat) wahai Muhammad (kebanyakan dari mereka tolong-menolong dengan orang-orang yang kafir/musyrik) dari kalangan penduduk Mekah karena membencimu. (Sesungguhnya amat buruklah apa yang mereka sediakan untuk diri mereka) yaitu berupa amal perbuatan untuk bekal mereka di akhirat yang akibatnya (Allah murka terhadap mereka dan mereka akan kekal dalam siksaan.)\qt@no{80}}%
\qt@newcmd\qurantrans@id@dccl{%
(Sekiranya mereka beriman kepada Allah, kepada Nabi) Muhammad (dan kepada apa yang diturunkan kepadanya niscaya mereka tidak akan mengambil orang-orang musyrik itu) orang-orang kafir (menjadi penolong-penolong tetapi kebanyakan dari mereka adalah orang-orang yang fasik/durhaka) mereka adalah orang-orang yang menyimpang dari keimanan.\qt@no{81}}%
\qt@newcmd\qurantrans@id@dccli{%
(Sesungguhnya kamu dapati) wahai Muhammad (orang-orang yang paling keras permusuhannya terhadap orang-orang yang beriman ialah orang-orang Yahudi dan orang-orang musyrik) dari kalangan penduduk Mekah oleh sebab menebalnya kekafiran mereka, kebodohan mereka dan tenggelamnya mereka dalam hawa nafsu (dan sesungguhnya kamu dapati yang paling dekat persahabatannya dengan orang-orang yang beriman ialah orang-orang yang berkata, ``Sesungguhnya kami ini orang Nasrani." Yang demikian itu) maksudnya kecintaan mereka begitu dekat terhadap orang-orang mukmin (disebabkan karena) oleh karena (di antara mereka/orang-orang Nasrani terdapat pendeta-pendeta) ulama-ulama agama Nasrani (dan rahib-rahib) orang-orang ahli ibadah Nasrani (juga karena sesungguhnya mereka tidak menyombongkan diri) untuk mengikuti barang yang hak tidak sebagaimana orang-orang Yahudi dan kaum musyrikin penduduk Mekah yang menyombongkan diri. Ayat ini diturunkan berkenaan dengan utusan raja Najasyi yang datang dari negeri Habasyah untuk menemui kaum Muslimin. Kemudian Nabi saw. membacakan surah Yasin kepada mereka setelah itu mereka menangis dan masuk Islam semuanya seraya mengatakan, ``Alangkah miripnya bacaan ini dengan apa yang telah diturunkan kepada Nabi Isa." Allah swt. berfirman:\qt@no{82}}%
\qt@newcmd\qurantrans@id@dcclii{%
(Dan apabila mereka mendengarkan apa yang diturunkan kepada Rasul) yaitu sebagian dari Alquran (kamu lihat mata mereka mencucurkan air mata disebabkan kebenaran Alquran yang telah mereka ketahui dari kitab-kitab mereka sendiri, seraya berkata, ``Ya Tuhan kami! Kami telah beriman) kami telah percaya kepada Nabi-Mu dan Kitab-Mu (maka catatlah kami bersama orang-orang yang menjadi saksi -atas kebenaran Alquran dan kenabian Nabi Muhammad-.") orang-orang yang mengakui dirinya beriman kepada keduanya.\qt@no{83}}%
\qt@newcmd\qurantrans@id@dccliii{%
(Dan) mereka mengatakan sehubungan dengan bantahan mereka terhadap orang-orang Yahudi yang mencap mereka masuk Islam (mengapa kami tidak beriman kepada Allah dan kepada kebenaran yang datang kepada kami) yaitu berupa Alquran; artinya tidak ada halangan bagi diri kami untuk beriman selagi memang ada bukti-bukti yang mengharuskan iman (padahal kami sangat ingin) diathafkan/dikaitkan dengan lafal nu'minu (agar Tuhan kami memasukkan kami ke dalam golongan orang-orang yang saleh?) orang-orang yang beriman ke dalam surga. Allah melanjutkan firman-Nya:\qt@no{84}}%
\qt@newcmd\qurantrans@id@dccliv{%
(Maka Allah memberi mereka pahala terhadap perkataan yang mereka ucapkan, yaitu surga yang mengalir sungai-sungai di bawahnya sedang mereka kekal di dalamnya. Dan itulah balasan bagi orang-orang yang berbuat kebaikan) yang ikhlas keimanannya.\qt@no{85}}%
\qt@newcmd\qurantrans@id@dcclv{%
(Dan orang-orang kafir serta mendustakan ayat-ayat Kami mereka itulah penghuni neraka.)\qt@no{86}}%
\qt@newcmd\qurantrans@id@dcclvi{%
Ayat ini diturunkan tatkala ada suatu kaum dari kalangan para sahabat yang bertekad menetapi puasa dan melakukan salat di malam harinya; mereka tidak mau mendekati wanita-wanita, memakai wewangian, memakan daging dan tidur di ranjang/kasur. (Hai orang-orang yang beriman janganlah kamu haramkan apa-apa yang baik yang telah Allah halalkan bagi kamu dan janganlah kamu melampaui batas.) janganlah kamu melanggar perintah Allah. (Sesungguhnya Allah tidak menyukai orang-orang yang melampaui batas.)\qt@no{87}}%
\qt@newcmd\qurantrans@id@dcclvii{%
(Dan makanlah makanan yang halal lagi baik dari apa yang Allah rezekikan kepadamu) sebagai maf`ul/obyek jar dan majrur yang sebelumnya menjadi hal yang berkaitan dengan maf`ul itu (dan bertakwalah kepada Allah yang kamu beriman kepada-Nya.)\qt@no{88}}%
\qt@newcmd\qurantrans@id@dcclviii{%
(Allah tidak menghukum kamu disebabkan senda-gurau) yang terjadi (di dalam sumpah-sumpahmu) yaitu sumpah yang dilakukan secara tidak sengaja hanya karena lisan terlanjur mengatakan, seperti ucapan seseorang, ``Tidak demi Allah," dan, ``Ya demi Allah." (tetapi Dia menghukum kamu disebabkan apa yang kamu sengaja) dengan dibaca ringan `aqadtum dan dibaca tasydid `aqqadtum, menurut suatu riwayat dibaca `aaqadtum (dalam sumpah-sumpahmu) mengenai hal itu, yaitu seumpamanya kamu bersumpah dengan sengaja (maka kafaratnya) artinya kafarat sumpah tersebut apabila kamu melanggarnya (memberi makan sepuluh orang miskin) yang untuk setiap orang sebanyak satu mud (yaitu dari makanan yang biasa kamu berikan) dari makanan tersebut (kepada keluargamu) artinya kualitas makanan yang paling pertengahan dan yang paling biasa dipakai bukannya kualitas makanan yang paling tinggi dan juga bukan yang paling rendah (atau memberi kepada mereka pakaian) yaitu sesuatu yang biasa dijadikan sebagai pakaian seperti baju gamis, serban dan kain. Imam Syafii berpendapat jika memberikannya secara sekaligus kepada seorang miskin saja dianggap kurang sempurna atau tidak memenuhi persyaratan (atau membebaskan) memerdekakan (seorang budak) yang beriman seperti dalam masalah kafarat membunuh dan kafarat zihar atas dasar memberlakukan yang mutlak dengan hukum yang muqayyad (dan siapa yang tidak menemukan) salah satu di antara yang telah disebutkan (maka berpuasa selama tiga hari) sebagai ganti kafaratnya; menurut pendapat yang terkuat dalam masalah ini tidak disyaratkan puasa secara berturut-turut, pendapat ini dikatakan oleh Imam Syafii. (Yang demikian itu) yang telah disebutkan (adalah kafarat sumpah-sumpahmu bila kamu bersumpah) kemudian kamu langgar. (Dan jagalah sumpahmu) jangan sampai kamu melanggarnya selagi sumpah itu bukanlah perbuatan kebaikan atau mendamaikan orang-orang sebagaimana yang telah disebutkan dalam surah Al-Baqarah. (Demikianlah) artinya seperti apa yang telah Allah jelaskan tentang beberapa hal yang telah lalu penuturannya (Allah menjelaskan kepada kamu tentang ayat-ayat-Nya agar kamu bersyukur) kepada-Nya atas hal itu.\qt@no{89}}%
\qt@newcmd\qurantrans@id@dcclix{%
(Hai orang-orang yang beriman, sesungguhnya meminum khamar) minuman yang memabukkan yang dapat menutupi akal sehat (berjudi) taruhan (berkorban untuk berhala) patung-patung sesembahan (mengundi nasib dengan anak panah) permainan undian dengan anak panah (adalah perbuatan keji) menjijikkan lagi kotor (termasuk perbuatan setan) yang dihiasi oleh setan. (Maka jauhilah perbuatan-perbuatan itu) yakni kekejian yang terkandung di dalam perbuatan-perbuatan itu jangan sampai kamu melakukannya (agar kamu mendapat keberuntungan).\qt@no{90}}%
\qt@newcmd\qurantrans@id@dcclx{%
(Sesungguhnya setan itu bermaksud hendak menimbulkan permusuhan dan kebencian di antara kamu lantaran meminum khamar dan berjudi itu) bila kamu melakukan keduanya mengingat dalam keduanya itu terkandung kejelekan dan fitnah (dan menghalangi kamu) karena sibuk melakukannya itu (dari mengingat Allah dan salat) Allah menyebutkan salat secara khusus sebagai pengagungan terhadap-Nya (maka berhentilah kamu) dari melakukan kedua pekerjaan ini.\qt@no{91}}%
\qt@newcmd\qurantrans@id@dcclxi{%
(Dan taatlah kamu kepada Allah dan taatlah kamu kepada Rasul-Nya dan berhati-hatilah) terhadap perbuatan-perbuatan maksiat. (Jika kamu berpaling) dari ketaatan (maka ketahuilah bahwa sesungguhnya kewajiban Rasul Kami hanyalah menyampaikan amanat Allah dengan terang) dengan gamblang, kemudian pembalasan kamu oleh Kami.\qt@no{92}}%
\qt@newcmd\qurantrans@id@dcclxii{%
(Tidak ada dosa bagi orang-orang yang beriman dan mengerjakan amalan yang saleh karena memakan makanan yang telah mereka makan dahulu) meminum dan melakukan perjudian sebelum adanya pengharaman (apabila mereka bertakwa) terhadap perbuatan-perbuatan yang haram (serta beriman dan mengerjakan amal-amalan yang saleh kemudian mereka tetap bertakwa dan beriman) mereka terus menetapi pada ketakwaan dan keimanannya (kemudian mereka tetap juga bertakwa dan berbuat kebaikan) dalam beramal. (Dan Allah menyukai orang-orang yang berbuat kebaikan) dengan pengertian bahwa Allah akan memberi pahala mereka.\qt@no{93}}%
\qt@newcmd\qurantrans@id@dcclxiii{%
(Hai orang-orang yang beriman, sesungguhnya kamu akan menerima ujian) percobaan dari (Allah dengan sesuatu) yang Ia kirimkan kepadamu (berupa binatang buruan yang mudah didapat) maksudnya binatang buruan yang kecil-kecil (oleh tangan-tanganmu dan tombak-tombakmu) berupa binatang buruan yang besar-besar. Peristiwa ini terjadi sewaktu di Hudaibiah sedangkan mereka dalam keadaan berihram; tersebutlah bahwa hewan-hewan liar berada di mana-mana sewaktu mereka dalam perjalanan (supaya Allah mengetahui) dengan pengetahuan yang jelas (orang yang takut kepada-Nya, biar pun ia tidak dapat melihat-Nya) menjadi hal yang artinya secara gaib tidak bisa melihat-Nya kemudian ia menghindari binatang buruan itu. (Siapa yang melanggar batas sesudah itu) sesudah dilarang menangkap binatang buruan itu kemudian ia bertekad menangkapnya (maka baginya siksaan yang pedih).\qt@no{94}}%
\qt@newcmd\qurantrans@id@dcclxiv{%
(Hai orang-orang yang beriman! Janganlah kamu membunuh binatang buruan ketika kamu sedang berihram) melakukan ihram haji dan ihram umrah. (Siapa di antara kamu membunuhnya dengan sengaja, maka dendanya) lafal yang sesudahnya dibaca secara tanwin dan rafa`; artinya ia harus membayar denda yang (sama dengan hewan yang telah dibunuhnya) artinya hewan yang sama bentuknya; dan di dalam suatu qiraat lafal jazaaun diidhafatkan kepada lafal yang sesudahnya sehingga dibaca wa jazaau mitsli (menurut keputusan) artinya mengenai perimbangan dua orang lelaki (dua orang yang adil di antara kamu) yang keduanya mempunyai kecerdasan dalam membedakan dan menyesuaikan hal-hal yang serupa. Ibnu Abbas, Umar dan Ali telah memutuskan denda seekor unta sebagai imbangan buruan seekor burung unta. Kemudian Ibnu Abbas dan Abu Ubaidah telah memutuskan mengganti sapi liar dan keledai liar dengan seekor sapi. Ibnu Umar dan Ibnu Auf mengganti seekor kijang dengan seekor kambing sebagai kafaratnya, kemudian Ibnu Abbas dan Umar serta selain keduanya telah memutuskan hal yang sama dalam kasus perburuan rusa sebab ia mirip dengan kambing dalam masalah besarnya (sebagai hadya) sebagai hal dari lafal jazaa (yang dibawa sampai ke Kakbah) artinya kurban itu dibawa sampai ke tanah suci lalu disembelih sesampainya di sana, lalu dagingnya disedekahkan kepada para penduduknya yang miskin; dan hewan hadya itu tidak boleh disembelih di tempat perburuan terjadi. Lafal balighal ka`bati dibaca nashab karena menjadi sifat dari lafal yang sebelumnya yaitu hadya, sekalipun ia diidhafatkan karena idhafatnya itu hanya bersifat lafzi. Jadi tidak memberikan pengertian makrifat. Apabila binatang buruan itu sangat sulit untuk ditemukan yang sepadan dengannya, seperti burung cicit dan belalang, maka pelakunya wajib membayar harganya saja (atau) ia harus membayar (kafarat) yang tidak sepadan sekalipun hewan yang sepadan memang ada, yaitu (memberi makan orang-orang miskin) berupa makanan pokok yang biasa dimakan oleh penduduk setempat dalam jumlah yang sesuai dengan harga denda untuk dibagikan kepada setiap orang miskin satu mud. Menurut suatu qiraat dengan mengidhafatkan lafal kaffarah kepada lafal yang sesudahnya dengan pengertian memperjelas (atau) ia harus membayarnya (dengan yang seimbang) seperti (jumlah itu) dalam bentuk makanan (berupa puasa) yang ia lakukan untuk setiap harinya sebagai ganti dari satu mud makanan, dan jika ia menemukan makanan, maka yang wajib baginya ialah membayarnya dengan makanan (supaya ia merasakan akibat) yang berat bagi pembalasan (perbuatannya) yang telah ia lakukan. (Allah telah memaafkan apa yang telah lalu) yaitu dari perbuatan membunuh binatang buruan sewaktu ihram sebelum diharamkan. (Dan siapa yang kembali mengerjakan)nya (niscaya Allah akan membalasnya. Allah Maha Perkasa) Maha Menang dalam segala perkara-Nya (lagi Yang Mempunyai pembalasan) terhadap orang yang berbuat durhaka kepada-Nya dan kemudian disamakan dengan membunuh secara sengaja, yaitu membunuh secara kesalahan.\qt@no{95}}%
\qt@newcmd\qurantrans@id@dcclxv{%
(Dihalalkan bagimu) hai umat manusia sewaktu kamu berada dalam keadaan halal/tidak ihram atau sedang ihram (binatang buruan laut) kamu boleh memakannya. Binatang buruan laut ialah binatang yang hidupnya hanya di laut/di air, seperti ikan. Berbeda dengan binatang yang terkadang hidup di laut dan terkadang hidup di darat seperti kepiting (dan makanan yang berasal dari laut) binatang laut yang terdampar dalam keadaan mati (sebagai makanan yang lezat) untuk dinikmati (bagimu) kamu boleh memakannya (dan bagi orang-orang yang bepergian) orang-orang yang musafir dari kalangan kamu dengan menjadikannya sebagai bekal mereka. (Dan diharamkan atasmu binatang buruan darat) yaitu binatang yang hidup di darat dari jenis binatang yang boleh dimakan, kamu dilarang memburunya (selagi kamu dalam keadaan ihram) dan jika yang memburunya itu adalah orang yang tidak sedang ihram, maka orang yang sedang ihram diperbolehkan memakannya sebagaimana yang telah dijelaskan oleh sunah. (Dan bertakwalah kepada Allah yang hanya kepada-Nya kamu kembali.)\qt@no{96}}%
\qt@newcmd\qurantrans@id@dcclxvi{%
(Allah telah menjadikan Kakbah rumah suci itu) rumah yang disucikan (sebagai pusat kegiatan umat manusia) yang mereka melaksanakan urusan agamanya dengan berhaji kepadanya, dan mengatur urusan keduniaan mereka dengan mengamankan orang-orang yang masuk ke dalamnya dan menjamin keselamatan mereka, kemudian mendatangkan semua jenis buah-buahan ke dalamnya. Menurut suatu qiraat dibaca qiyaman tanpa alif panjang yang berakar dari kata qaama tanpa dii'lalkan (dan bulan haram) yang dimaksud adalah bulan-bulan haram seperti Zulkaidah, Zulhijah, Muharam dan Rajab sebagai pusat kegiatan mereka dalam mengamankan lingkungan dan tidak boleh melakukan peperangan dalam bulan-bulan tersebut (dan hadya serta qalaid) sebagai pertanda bagi semua orang bahwa kedua jenis hewan kurban itu tidak boleh diganggu dan harus diamankan. (Demikian itu) peraturan yang telah disebutkan itu (agar kamu tahu, bahwa sesungguhnya Allah mengetahui apa yang ada di langit dan apa yang ada di bumi dan bahwa sesungguhnya Allah Maha Mengetahui segala sesuatu) karena sesungguhnya Ia telah menjadikan peraturan tersebut demi kemaslahatan kamu dan demi untuk menolak mara bahaya dari dirimu sebelum segala sesuatunya terjadi; hal ini jelas menunjukkan pengetahuan Allah yang mencakup semua yang ada dalam alam wujud ini dan semua yang sedang berlangsung.\qt@no{97}}%
\qt@newcmd\qurantrans@id@dcclxvii{%
(Ketahuilah bahwa sesungguhnya Allah amat berat siksaan-Nya) terhadap musuh-musuh-Nya (dan bahwa sesungguhnya Allah Maha Pengampun) terhadap kekasih-kekasih-Nya (lagi Maha Penyayang) terhadap mereka.\qt@no{98}}%
\qt@newcmd\qurantrans@id@dcclxviii{%
(Kewajiban rasul tidak lain hanyalah menyampaikan) kepadamu (dan Allah mengetahui apa yang kamu tampakkan) amal perbuatan yang kamu lahirkan (dan apa yang kamu sembunyikan) amal perbuatan yang kamu sembunyikan karena itu Allah membalas kamu.\qt@no{99}}%
\qt@newcmd\qurantrans@id@dcclxix{%
(Katakanlah, ``Tidak sama yang buruk) barang yang haram (dengan yang baik) barang yang halal (meskipun membuatmu kagum) membuatmu suka (banyaknya hal yang buruk itu, maka bertakwalah kepada Allah) tinggalkanlah hal yang buruk itu (hai orang-orang berakal agar kamu mendapat keberuntungan.") agar kamu mendapat kebahagiaan. Kemudian turunlah ayat berikut ini tatkala para sahabat banyak bertanya kepada Rasulullah saw.\qt@no{100}}%
\qt@newcmd\qurantrans@id@dcclxx{%
(Hai orang-orang yang beriman! Janganlah kamu menanyakan kepada Nabimu hal-hal yang jika diterangkan) dijelaskan (kepadamu, niscaya menyusahkan kamu) karena di dalamnya mengandung kemudaratan (dan jika kamu menanyakannya di waktu Alquran itu sedang diturunkan) artinya di masa Nabi saw. masih hidup (niscaya akan diterangkan kepadamu) makna ayat: apabila kamu bertanya tentang macam-macam masalah sewaktu Nabi saw. masih ada niscaya akan turun ayat-ayat Alquran yang menjelaskannya dan jika ayat-ayat Alquran telah turun niscaya isinya akan menjelek-jelekkan kamu sendiri oleh karena janganlah kamu banyak bertanya tentang hal-hal itu; sesungguhnya (Allah telah memaafkan kamu tentang hal-hal itu) sebelum kamu meminta maaf kepada-Nya, maka dari itu janganlah kamu mengulanginya. (Allah Maha Pengampun lagi Maha Penyantun.)\qt@no{101}}%
\qt@newcmd\qurantrans@id@dcclxxi{%
(Sesungguhnya telah menanyakan hal itu) artinya hal-hal serupa itu (suatu kaum sebelum kamu) kepada nabi-nabi mereka, maka mereka diberi penjelasan tentang hukum-hukumnya (kemudian jadilah mereka) mereka menjadi (tidak percaya kepadanya) karena mereka tidak mengamalkannya.\qt@no{102}}%
\qt@newcmd\qurantrans@id@dcclxxii{%
(Tidak sekali-kali menjadikan) mensyariatkan (Allah akan adanya bahirah, saibah, wasilah dan ham) sebagaimana yang telah dilakukan oleh orang-orang jahiliah. Telah diriwayatkan oleh Imam Bukhari dari Said bin Musayyab yang telah mengatakan bahwa bahirah ialah unta betina yang air susunya dihadiahkan untuk berhala-berhala, maka tidak ada seorang pun yang berani memerah air susunya. Saibah ialah unta betina yang mereka lepaskan begitu saja dibiarkan demi untuk berhala-berhala mereka, maka unta tersebut tidak boleh dibebani sesuatu pun. Wasilah ialah unta betina yang sewaktu melahirkan anak unta pertama kalinya betina setelah ia beranak lagi secara kembar yang kedua-duanya betina; induk unta itu dibiarkan terlepas bebas jika anak-anaknya itu tidak ada yang jantan yang memisahkan antara kedua anaknya itu. Hal ini mereka lakukan demi berhala-berhala mereka. Dan ham ialah unta pejantan yang dipekerjakan dalam masa yang telah ditentukan dan jika masanya telah habis lalu mereka membiarkannya bebas demi untuk mendekatkan diri kepada berhala-berhala sesembahan mereka. Selain dari itu mereka membebaskannya dari segala muatan dan beban hingga ia tidak lagi disuruh membawa apa pun dan nama lain dari jenis unta itu ialah hami. (Akan tetapi orang-orang kafir selalu membuat kedustaan terhadap Allah) dalam hal tersebut kemudian mereka mengaitkannya kepada Allah (dan kebanyakan mereka tidak mengerti) bahwa perkara tersebut merupakan kedustaan karena mereka dalam hal ini hanyalah mengikuti apa yang biasa dilakukan oleh nenek moyang mereka.\qt@no{103}}%
\qt@newcmd\qurantrans@id@dcclxxiii{%
(Apabila dikatakan kepada mereka, ``Marilah mengikuti apa yang telah diturunkan Allah dan mengikuti rasul!") artinya kepada hikmah yang menjelaskan tentang penghalalan apa yang kamu haramkan (Mereka menjawab, ``Cukuplah untuk kami) kami cukup puas dengan (apa yang kami dapati bapak-bapak kami mengerjakannya.") yaitu berupa agama dan syariat. Allah selanjutnya berfirman: (Apakah) mereka cukup puas dengan hal itu (sekalipun nenek moyang mereka itu tidak mengetahui apa-apa dan tidak pula mendapat petunjuk) ke jalan yang benar? Kata tanya/istifham di sini menunjukkan makna ingkar.\qt@no{104}}%
\qt@newcmd\qurantrans@id@dcclxxiv{%
(Hai orang-orang yang beriman! Jagalah dirimu) peliharalah dirimu dan berbuatlah kamu untuk memperbaikinya (tiadalah orang yang sesat itu akan memberi mudarat kepadamu apabila kamu telah mendapat petunjuk.) Dikatakan bahwa yang dimaksud dengan makna tidak akan membahayakan kamu orang-orang yang sesat ialah golongan Ahlul Kitab. Menurut pendapat lainnya, yang dimaksud dengan mereka adalah orang-orang selain Ahlul Kitab, pendapat ini berlandaskan pada hadisnya Abu Tsa'labah Al-Khusyani. Dalam hadisnya Al-Khusyani mengatakan, ``Aku bertanya kepada Rasulullah saw. tentang makna ayat ini; kemudian beliau menjawab, 'Saling perintah-memerintahkanlah kamu sekalian kepada kebaikan, dan saling cegah-mencegahlah kamu sekalian tentang kemungkaran, hingga jika kamu melihat orang yang bakhil (pelit) ditaati; hawa nafsu mulai diikuti; keduniawian paling dipentingkan; dan orang-orang yang berakal mulai merasa kagum dengan akalnya sendiri, maka peliharalah dirimu.'" Hadis ini diriwayatkan oleh Imam Hakim dan lain-lainnya (hanya kepada Allahlah kamu semuanya kembali, kemudian Dia akan menerangkan kepadamu apa yang telah kamu kerjakan) kemudian Dia akan membalas kamu.\qt@no{105}}%
\qt@newcmd\qurantrans@id@dcclxxv{%
(Hai orang-orang yang beriman! Diperlukan kesaksian di antara kamu apabila salah seorang di antara kamu menghadapi kematian) menghadapi hal-hal yang menyebabkan kepada kematian (tatkala ia hendak berwasiat; yaitu oleh dua orang lelaki yang adil di antara kamu) Kalimat syahaadatu bainikum adalah kalimat berita yang bermakna perintah; yang artinya hendaklah disaksikan/liyasyhad. Mengidhafatkan Lafal syahaadah kepada Lafal baina menunjukkan makna keluasan memilih; kata hiina merupakan badal (kata ganti) dari kata idzaa atau menjadi zharaf bagi kalimat hadhara (atau oleh dua orang yang berbeda dengan kamu) artinya yang bukan seagama denganmu (jika kamu dalam perjalanan) sedang bepergian (di muka bumi lalu kamu tertimpa bahaya kematian. Kamu tahan kedua saksi itu) kamu pegang kedua orang itu; kalimat ini menjadi kata sifat dari lafal aakharaani (sesudah kamu salat) yaitu salat asar (lalu mereka keduanya bersumpah) mengikrarkan perjanjian (dengan atas nama Allah jika kamu ragu-ragu) kamu merasa syakwasangka mengenainya, kemudian keduanya mengatakan: ("Kami tidak akan membeli dengan sumpah itu) atas nama Allah (harga yang sedikit) sebagai imbalan berupa materi/duniawi yang kami ambil sebagai penggantinya dengan cara bersumpah atau mengadakan kesaksian dusta demi untuk meraih imbalan itu (walaupun dia) orang yang disumpahi atau orang yang disaksikan itu adalah (kerabat karib) familinya sendiri (dan tidak pula kami menyembunyikan persaksian Allah) yang kami diperintahkan-Nya untuk melaksanakannya (sesungguhnya kami kalau demikian) kalau kami menyembunyikannya (termasuk orang-orang yang berdosa.")\qt@no{106}}%
\qt@newcmd\qurantrans@id@dcclxxvi{%
(Jika diketahui) terbukti sesudah keduanya bersumpah (bahwa kedua saksi itu melakukan dosa) artinya melakukan perbuatan yang mengakibatkan dosa, seperti berkhianat atau berdusta dalam kesaksiannya; hal ini diperkuat dengan adanya bukti bahwa keduanya hanya mengaku telah membeli barang yang diwasiatkan itu dari si mayat atau mereka mengaku bahwa si mayat telah mewasiatkan untuk mereka (maka dua orang yang lain mengganti kedudukan mereka berdua) untuk mengajukan tuntutan kepada mereka berdua (dari orang-orang yang berhak) menerima wasiat; mereka ialah para ahli waris dari si mayat kemudian keduanya diganti (yang keduanya lebih dekat) kepada orang yang mati; artinya dua orang yang kekerabatannya dekat dengan si mayat. Di dalam suatu qiraat dibaca al-awwaliin, jamak dari kata awwal sebagai sifat atau badal dari kata alladziina (kemudian keduanya melakukan sumpah dengan nama Allah) mengenai khianat yang dilakukan oleh kedua saksi pertama, lalu mengucapkan: ("Sesungguhnya persaksian kami) sumpah kami ini (lebih berhak) lebih diakui (daripada persaksian kedua saksi itu) sumpah keduanya (dan kami tidak melanggar batas) melewati garis-garis kebenaran dalam sumpah (sesungguhnya kami kalau demikian tentulah termasuk orang-orang yang berdosa.") Makna ayat secara ringkasnya ialah: Hendaklah orang yang sedang menghadapi kematian mempersaksikan wasiatnya itu di hadapan dua orang saksi. Atau ia berwasiat kepada dua orang yang seagama atau berlainan agama jika kamu jauh dari ahli warismu oleh karena kamu sedang mengadakan perjalanan atau karena ada keperluan lainnya. Apabila para ahli waris merasa ragu terhadap kejujuran kedua saksi itu, maka mereka diperbolehkan mengajukan tuntutan terhadap kedua saksi itu, bahwa mereka berdua telah berkhianat dengan mengambil sesuatu dari wasiat itu. Atau kedua saksi itu memberikan wasiat si mayat kepada orang lain yang mereka duga bahwa si mayat berwasiat kepada mereka untuk orang itu, kemudian hendaknya kedua saksi itu bersumpah untuk membela dirinya. Jika sang hakim melihat tanda-tanda kedustaan kedua orang saksi itu, maka hendaknya kesaksian mereka berdua ditolak dengan sumpah para ahli waris si mayat yang terdekat yang membuktikan kedustaan mereka dan membenarkan apa yang didakwakan oleh para ahli waris itu. Hukum yang menetapkan hak orang-orang yang diberi wasiat telah dinasakh oleh kesaksian para saksi dari ahli waris demikian pula kesaksian orang-orang yang bukan seagama dinasakh olehnya. Penuturan salat asar di sini hanyalah untuk memperberat sanksi; dan pengkhususan penyebutan dua orang saksi dari kalangan ahli waris terdekat si mayat adalah karena melihat kekhususan peristiwa yang menyangkut turunnya ayat ini. Mengenai peristiwa yang menyebabkan turunnya ayat ini ialah sebuah hadis yang diriwayatkan oleh Imam Bukhari, bahwa seorang lelaki dari kalangan Bani Sahm keluar bersama Tamim Ad-Dariy dan Addiy bin Badda yang keduanya adalah pemeluk agama Nasrani. Kemudian dalam perjalanan Sahmiy -lelaki dari Bani Sahm itu- meninggal di tanah suatu kaum yang penduduknya tidak ada seorang muslim pun. Tatkala keduanya tiba di Madinah seraya membawa harta harta peninggalan Sahmiy, para ahli warisnya merasa kehilangan sebuah piala yang terbuat dari perak dilapisi dengan emas milik pribadi Sahmiy. Maka permasalahan kedua saksi itu dilaporkan kepada Nabi saw., kemudian turunlah ayat pertama. Nabi saw. menyumpah kedua saksi itu, kemudian ternyata piala itu ditemukan, lalu mereka berkata, ``Kami telah membelinya dari Tamim dan Addiy." Setelah itu turun pula ayat yang kedua lalu dua orang lelaki dari kalangan keluarga Sahmiy berdiri mengucapkan sumpahnya. Di dalam riwayat Tirmizi disebutkan, bahwa Amr bin Ash dan seorang lelaki dari kalangan mereka bangkit kemudian mengucapkan sumpah mengingat Amr bin Ash lebih dekat kepadanya. Di dalam riwayat lain disebutkan, bahwa Sahmiy dalam perjalanannya itu mengalami sakit keras, lalu ia berwasiat kepada kedua temannya itu agar keduanya menyampaikan harta peninggalannya kepada keluarga yang akan mewarisinya. Tatkala Sahmiy meninggal dunia kedua orang temannya itu mengambil piala tersebut kemudian mereka menyerahkan sisanya kepada ahli warisnya.\qt@no{107}}%
\qt@newcmd\qurantrans@id@dcclxxvii{%
(Hal itu) hukum yang telah disebutkan itu, yaitu yang menyangkut perpindahan sumpah kepada para ahli waris (lebih dekat) lebih mendekati untuk (menjadikan mereka mau mengemukakan) artinya para saksi itu atau orang-orang yang diwasiatkan (persaksiannya menurut apa yang sebenarnya) yang mendorong mereka untuk mengemukakan persaksian tanpa diubah-ubah dan juga tanpa khianat (atau) lebih dekat untuk menjadikan mereka (merasa takut akan dikembalikan sumpahnya sesudah mereka bersumpah) kepada para ahli waris yang mengajukan tuntutan, maka ahli waris si mayat melakukan sumpah yang menyatakan khianat mereka dan kedustaan yang mereka lakukan yang akibatnya mereka akan ditelanjangi kejelekannya hingga mereka harus mengganti kerugian kepada ahli waris mayat, oleh karena itu janganlah kamu berdusta. (Dan bertakwalah kamu kepada Allah) dengan cara meninggalkan perbuatan khianat dan dusta (dan dengarkanlah olehmu) dengan pendengaran yang insaf akan hal-hal yang kamu diperintahkan melakukannya (dan Allah tidak memberi petunjuk kepada orang-orang yang fasik) orang-orang yang keluar dari garis ketaatan terhadap-Nya atau orang-orang yang menyimpang dari jalan yang baik.\qt@no{108}}%
\qt@newcmd\qurantrans@id@dcclxxviii{%
Ingatlah! (hari di waktu Allah mengumpulkan para rasul) yaitu pada hari kiamat (lalu Allah bertanya) kepada mereka dengan nada mencela yang ditujukan kepada kaum mereka (Apa) yang (jawaban kaummu terhadap seruanmu?) tatkala kamu mengajak mereka kepada ketauhidan (Para rasul menjawab, ``Tidak ada pengetahuan kami) tentang hal itu (sesungguhnya Engkaulah yang mengetahui perkara yang gaib.") apa-apa yang tidak bisa dijangkau oleh pengetahuan hamba-hamba-Nya dan gaib di mata mereka oleh sebab kengerian yang mereka hadapi pada saat hari kiamat yang membuat mereka kaget. Kemudian para rasul itu menjadi saksi terhadap umat mereka masing-masing tatkala umat mereka diam seribu bahasa.\qt@no{109}}%
\qt@newcmd\qurantrans@id@dcclxxix{%
Ingatlah! (ketika Allah mengatakan, ``Hai Isa putra Maryam! Ingatlah nikmat-Ku kepadamu dan kepada ibumu) syukurilah nikmat-Ku itu (di waktu Aku mendukung kamu) menguatkan kamu (dengan ruhul kudus) malaikat Jibril (kamu dapat berbicara dengan manusia) menjadi hal bagi kaaf atau dhamir mukhathab yang terdapat dalam kalimat ayyadtuka (sewaktu dalam buaian) masih dalam keadaan bayi (dan sesudah dewasa) kalimat ini memberikan pengertian bahwa ia (Nabi Isa) akan turun ke bumi sebelum hari kiamat sebab sebelum ia mencapai usia tua telah diangkat terlebih dahulu ke langit sebagaimana penjelasan yang telah dikemukakan dalam surah Ali Imran. (Dan ingatlah di waktu Aku mengajar kamu menulis, hikmah, Taurat dan Injil dan ingat pula di waktu kamu membuat suatu bentuk dari tanah yang berupa) seperti gambaran (burung) huruf kaaf dalam kalimat kahaiah adalah bermakna isim yang artinya seperti dan kedudukan i`rabnya menjadi maf`ul atau objek (dengan seizin-Ku kemudian kamu meniup padanya lalu bentuk itu menjadi burung yang sebenarnya seizin-Ku) dengan kehendak-Ku. (Dan ingatlah waktu kamu menyembuhkan orang yang buta dan orang yang berpenyakit sopak dengan seizin-Ku, dan ingatlah di waktu kamu mengeluarkan orang-orang mati) dari kuburan-kuburan mereka dalam keadaan hidup (dengan seizin-Ku, dan ingatlah di waktu Aku menghalangi Bani Israel dari kamu) sewaktu mereka bersengaja hendak membunuhmu (di kala kamu mengemukakan kepada mereka keterangan-keterangan yang nyata) yakni mukjizat-mukjizat (lalu orang-orang kafir di antara mereka berkata, 'Tidak) tidak lain (hal ini) yang engkau datangkan melainkan sihir yang nyata') dan menurut qiraat dibaca saahirun/tukang sihir, yang dimaksud ialah Nabi Isa.\qt@no{110}}%
\qt@newcmd\qurantrans@id@dcclxxx{%
(Dan ingatlah ketika Aku ilhamkan kepada para pengikut Nabi Isa yang setia) Aku perintahkan mereka melalui lisannya (hendaknya) (kamu beriman kepada-Ku dan kepada rasul-Ku.") yaitu Nabi Isa (Mereka menjawab, ``Kami telah beriman) kepada Allah dan rasul-Nya (dan saksikanlah, wahai rasul, bahwa sesungguhnya kami adalah orang-orang yang berserah diri kepada seruanmu.")\qt@no{111}}%
\qt@newcmd\qurantrans@id@dcclxxxi{%
Ingatlah (Ketika pengikut-pengikut Isa berkata, ``Hai Isa putra Maryam! Sanggupkah) artinya bisakah (Tuhanmu) menurut satu qiraat dibaca tastathii'u kemudian lafal yang sesudahnya dibaca nashab/rabbaka, yang artinya apakah engkau bisa meminta kepada-Nya (menurunkan hidangan dari langit kepada kami?" Menjawab) kepada mereka Isa ("Bertakwalah kepada Allah) di dalam meminta bukti-bukti itu/mukjizat-mukjizat (jika betul-betul kamu orang yang beriman.")\qt@no{112}}%
\qt@newcmd\qurantrans@id@dcclxxxii{%
(Mereka berkata, ``Kami menginginkan) dengan permintaan ini agar (agar bisa memakan hidangan itu dan supaya menjadi tenteram) menjadi tenang/mantap (hati kami) semakin bertambah yakin (dan supaya kami mengetahui) kami makin bertambah pengetahuan (bahwa) an mukhaffafah; artinya bahwa sesungguhnya (kamu telah berkata benar kepada kami) dalam pengakuanmu menjadi nabi (dan kami menjadi orang-orang yang menyaksikan hidangan itu.")\qt@no{113}}%
\qt@newcmd\qurantrans@id@dcclxxxiii{%
(Isa Putra Maryam berdoa, ``Ya Tuhan kami! Turunkanlah kiranya kepada kami suatu hidangan dari langit yang hal itu bagi kami) artinya pada hari turunnya hidangan itu (menjadi hari raya) yang kami hormati dan kami muliakan (bagi orang-orang sezaman dengan kami) kalimat ini menjadi badal/kalimat pengganti bagi lafal lanaa, yang juga disertai pula dengan huruf jarnya (dan bagi orang-orang yang datang sesudah kami) orang-orang yang akan datang sesudah kami (dan menjadi tanda kekuasaan Engkau) yang menunjukkan akan kekuasaan-Mu dan kenabianku (berilah kami rezeki) dengan hidangan tersebut (dan Engkaulah Pemberi rezeki Yang Paling Utama.")\qt@no{114}}%
\qt@newcmd\qurantrans@id@dcclxxxiv{%
(Allah berfirman) mengabulkan doanya ("Sesungguhnya Aku akan menurunkan hidangan itu) boleh dibaca takhfif/munziluhaa dan boleh pula dibaca tasydid/munazziluhaa (kepadamu; siapa yang kafir sesudah) artinya sesudah diturunkannya hidangan itu (di antara kamu, maka sesungguhnya Aku akan menyiksanya dengan siksaan yang tidak pernah Aku timpakan kepada seseorang pun di antara umat manusia.") kemudian turunlah malaikat-malaikat seraya membawa hidangan dari langit berupa tujuh buah roti dan tujuh macam lauk-pauk. Kemudian mereka memakan sebagian darinya hingga semuanya merasa kenyang. Demikianlah menurut riwayat Ibnu Abbas dalam hadisnya sehubungan dengan kisah mengenai turunnya hidangan dari langit ini. Hadisnya itu mengatakan, bahwa hidangan itu berupa roti dan daging, kemudian mereka diperintahkan agar jangan berkhianat dan juga jangan menyimpannya hingga keesokan harinya. Akan tetapi mereka berkhianat dan menyimpan sebagian hidangan itu, akhirnya mereka dikutuk menjadi kera-kera dan babi-babi.\qt@no{115}}%
\qt@newcmd\qurantrans@id@dcclxxxv{%
(Dan) ingatlah (ketika berfirman) artinya akan berfirman (Allah) kepada Isa di hari kiamat sebagai penghinaan terhadap kaumnya ("Hai Isa putra Maryam! Adakah kamu mengatakan kepada manusia, 'Jadikanlah aku dan ibuku dua orang tuhan selain Allah?' Ia menjawab) Isa menjawab seraya gemetar ('Maha Suci Engkau) aku menyucikan-Mu dari apa-apa yang tidak layak bagi-Mu seperti sekutu dan lain-lainnya (tidaklah patut) tidak pantas (bagiku mengatakan apa yang bukan hakku mengatakannya) bihaqqin menjadi khabar dari laisa sedangkan kata lii adalah untuk penjelas/tabyin (jika aku pernah mengatakannya maka tentulah Engkau mengetahuinya. Engkau mengetahui apa) yang aku sembunyikan (pada diriku dan aku tidak mengetahui apa yang ada pada diri Engkau) artinya apa-apa yang Engkau sembunyikan di antara pengetahuan-pengetahuan Engkau (Sesungguhnya Engkau Maha Mengetahui perkara yang gaib-gaib.)\qt@no{116}}%
\qt@newcmd\qurantrans@id@dcclxxxvi{%
(Aku tidak pernah mengatakan kepada mereka kecuali apa yang telah Engkau perintahkan kepadaku untuk mengatakannya) yaitu: ('Sembahlah Allah Tuhanku dan Tuhanmu dan adalah aku menjadi saksi terhadap mereka) sebagai pengawas yang mencegah mereka dari apa yang mereka katakan itu (selama aku berada di antara mereka. Maka setelah Engkau wafatkan aku) Engkau telah mengambilku dengan cara mengangkatku ke langit (Engkaulah yang menguasai mereka) yang memelihara amal perbuatan mereka. (Sesungguhnya Engkau atas segala sesuatu) termasuk perkataanku kepada mereka dan perkataan mereka sesudahku dan lain-lainnya (Maha Menyaksikan) Maha Waspada dan Maha Mengetahui tentang hal itu.\qt@no{117}}%
\qt@newcmd\qurantrans@id@dcclxxxvii{%
(Jika Engkau menyiksa mereka) artinya orang-orang yang melakukan kekafiran di antara mereka (maka sesungguhnya mereka adalah hamba-hamba Engkau) Engkau adalah Yang Menguasai mereka; Engkaulah yang berhak memperlakukan mereka menurut apa yang Engkau kehendaki, tak ada yang bisa menghalang-halangi Engkau (dan jika Engkau mengampuni mereka) artinya mengampuni orang-orang yang beriman di antara mereka (maka sesungguhnya Engkaulah Yang Maha Perkasa) Yang Maha Menang perkara-Nya (lagi Maha Bijaksana'") dalam perbuatan-Nya.\qt@no{118}}%
\qt@newcmd\qurantrans@id@dcclxxxviii{%
(Allah berfirman, ``Ini adalah) artinya hari kiamat (suatu hari yang bermanfaat orang-orang yang benar) sewaktu di dunia seperti Nabi Isa (kebenaran mereka) sebab hari itu adalah hari pembalasan (bagi mereka surga yang mengalir di bawahnya sungai-sungai; mereka kekal di dalamnya untuk selama-lamanya; Allah rida terhadap mereka) oleh sebab ketaatan terhadap-Nya (dan mereka pun rida terhadap-Nya) dengan pahala-Nya (Itulah keberuntungan yang besar.") dan orang-orang pendusta sewaktu hidup di dunia, tidak akan bisa bermanfaat kejujuran mereka pada hari itu seperti orang-orang kafir, yaitu tatkala mereka mulai percaya dan iman sewaktu mereka melihat azab Allah.\qt@no{119}}%
\qt@newcmd\qurantrans@id@dcclxxxix{%
(Kepunyaan Allahlah kerajaan langit dan bumi) tempat-tempat penyimpanan hujan, semua tumbuhan, semua rezeki dan lain-lainnya (dan apa yang ada di dalamnya) dipergunakan kata maa, karena kebanyakan makhluk Allah itu terdiri dari yang tidak berakal (dan Dia Maha Kuasa atas segala sesuatu) di antara kekuasaan-Nya itu ialah memberi pahala kepada orang yang berbuat benar, dan menyiksa orang yang berbuat dusta.\qt@no{120}}%
\qt@newcmd\qurantrans@id@dccxc{%
\basmalahid (Segala puji) yaitu ungkapan tentang sifat yang baik lagi tetap (bagi Allah) apakah yang dimaksud dengan pemberitaan dalam bentuk ini sebagai ungkapan rasa iman terhadap-Nya ataukah hanya sebagai panjatan puji kepada-Nya atau memang untuk maksud keduanya? Memang mengandung beberapa hipotesis akan tetapi hipotesis yang paling banyak faedahnya ialah yang ketiga, demikianlah menurut pendapat Syekh di dalam surah Al-Kahfi (Yang telah menciptakan langit dan bumi) Allah menyebutkan keduanya secara khusus mengingat keduanya adalah makhluk ciptaan Allah yang paling besar di mata orang-orang yang menyaksikannya (dan mengadakan) menjadikan (gelap dan terang) artinya setiap yang gelap dan terang; pengungkapan kata gelap dengan bentuk jamak sedangkan untuk terang tidak karena gelap itu mempunyai banyak penyebabnya. Hal ini merupakan sebagian dari bukti-bukti keesaan-Nya (namun orang-orang yang kafir) sekalipun dengan adanya bukti ini (terhadap Tuhan mereka adalah orang-orang yang mempersekutukan-Nya) mereka menyamakan selain Allah dalam hal ibadah.\qt@no{1}}%
\qt@newcmd\qurantrans@id@dccxci{%
(Dialah Yang menciptakanmu dari tanah) dengan diciptakan-Nya ayah kamu Adam dari tanah (sesudah itu ditentukan-Nya ajal) bagi kamu, setelah sampai pada ajal itu kamu akan mati (dan ajal lain yang ditentukan) ditetapkan (di sisi-Nya) untuk membangkitkan kamu dari kematian (kemudian kamu) hai orang-orang kafir (masih tidak percaya tentang berbangkit itu) kamu masih meragukan tentang adanya hari berbangkit padahal sebelumnya kamu telah mengetahui, bahwa Dialah yang mulai menciptakanmu. Dan siapa yang mampu menciptakan berarti Dia lebih mampu untuk mengembalikan ke asalnya.\qt@no{2}}%
\qt@newcmd\qurantrans@id@dccxcii{%
(Dan Dialah Allah) yang berhak untuk disembah dan dipuja (baik di langit maupun di bumi, Dia mengetahui apa yang kamu rahasiakan dan apa yang kamu lahirkan) hal-hal yang kamu sembunyikan dan hal-hal yang kamu tampakkan di antara kamu sekalian (dan mengetahui pula apa yang kamu usahakan) perkara baik dan perkara buruk yang kamu ketahui.\qt@no{3}}%
\qt@newcmd\qurantrans@id@dccxciii{%
(Dan tidak ada yang sampai kepada mereka) artinya penduduk Mekah (berupa) huruf min adalah tambahan/zaidah (suatu ayat dari ayat-ayat Tuhan mereka) dari Alquran (melainkan mereka selalu berpaling daripadanya.)\qt@no{4}}%
\qt@newcmd\qurantrans@id@dccxciv{%
(Sesungguhnya mereka telah mendustakan yang hak) yakni Alquran (tatkala sampai kepada mereka maka akan sampai kepada mereka berita-berita) akibat-akibat (yang selalu mereka perolok-olokkan.)\qt@no{5}}%
\qt@newcmd\qurantrans@id@dccxcv{%
(Apakah mereka tidak memperhatikan) dalam perjalanan-perjalanan mereka menuju ke negeri Syam dan negeri-negeri lainnya (berapa banyak) kalimat khabariah atau bukan kata tanya yang artinya betapa banyaknya (generasi-generasi yang telah Kami binasakan sebelum mereka) umat-umat yang terdahulu (padahal mereka telah Kami teguhkan) Kami berikan kedudukan (di muka bumi) melalui kekuatan dan kekuasaannya (yaitu keteguhan yang belum pernah Kami menganugerahkan) Kami berikan (kepadamu) dalam Lafal ini terkandung pengertian iltifat/peralihan dari orang ketiga ke orang kedua yang maksudnya ditujukan kepada orang ketiga (dan Kami curahkan) hujan (atas mereka dengan derasnya) tahap demi tahap (dan Kami jadikan sungai-sungai mengalir di bawah mereka) di bawah rumah-rumah tempat tinggal mereka (kemudian Kami binasakan mereka karena dosa-dosa mereka sendiri) oleh sebab kedustaan mereka terhadap para nabi (dan Kami ciptakan sesudah mereka generasi yang lain.)\qt@no{6}}%
\qt@newcmd\qurantrans@id@dccxcvi{%
(Dan kalau Kami turunkan kepadamu sebuah kitab) yang tertulis (di atas kertas) yang tipis seperti apa yang mereka minta (lalu mereka dapat memegangnya dengan tangan mereka) lebih akurat daripada seandainya mereka hanya menyaksikan saja sebab cara ini jelas lebih menghapuskan rasa ragu (tentulah orang-orang kafir itu mengatakan, ``Tiada) tidak lain (hal ini adalah sihir yang nyata.") sebagai ungkapan rasa ketidakpercayaan dan keingkaran mereka.\qt@no{7}}%
\qt@newcmd\qurantrans@id@dccxcvii{%
(Dan mereka berkata, ``Mengapa tidak) kenapa tidak (diturunkan kepadanya) kepada Nabi Muhammad saw. (seorang malaikat?") yang membenarkannya (dan kalau Kami turunkan kepadanya seorang malaikat) sebagaimana yang telah mereka minta, niscaya mereka tidak akan beriman (tentu selesailah urusan itu) dengan binasanya mereka (kemudian mereka tidak ditangguhkan) tidak diberi kesempatan untuk bertobat atau minta ampunan, seperti yang telah dilakukan oleh Allah terhadap orang-orang sebelum mereka, yaitu di kala permintaan mereka dikabulkan, kemudian mereka tidak juga mau beriman.\qt@no{8}}%
\qt@newcmd\qurantrans@id@dccxcviii{%
(Dan kalau Kami jadikan rasul itu) yang diutus untuk mereka (seorang malaikat, tentulah Kami jadikan dia) artinya malaikat itu berupa (seorang laki-laki) artinya berbentuk seorang laki-laki supaya mereka bisa melihatnya, sebab manusia itu tidak akan kuat untuk melihat malaikat (dan) seandainya Kami menurunkannya lalu menjadikannya sebagai seorang laki-laki (niscaya akan Kami serupakan) Kami miripkan (atas mereka apa yang membuat mereka ragu) terhadap diri mereka, sebab mereka pasti mengatakan bahwa malaikat ini tidak lain kecuali seorang manusia seperti kamu.\qt@no{9}}%
\qt@newcmd\qurantrans@id@dccxcix{%
(Dan sungguh telah diperolok-olokkan beberapa rasul sebelum kamu) ungkapan ini mengandung makna yang menghibur hati Nabi saw. (maka datanglah) turunlah (kepada orang-orang yang mencemoohkan di antara mereka sebagai akibat dari apa yang mereka perolok-olokkan) yang berupa azab; demikian pula siksaan itu akan menimpa orang-orang yang memperolok-olokkan kamu.\qt@no{10}}%
\qt@newcmd\qurantrans@id@dccc{%
(Katakanlah) kepada mereka ("Berjalanlah di muka bumi kemudian perhatikanlah bagaimana kesudahan orang-orang yang mendustakan.") rasul-rasul itu; yaitu kebinasaan mereka karena tertimpa azab supaya orang-orang yang memperolok-olokkanmu itu mengambil pelajaran darinya.\qt@no{11}}%
\qt@newcmd\qurantrans@id@dccci{%
(Katakanlah, ``Kepunyaan siapakah apa yang ada di langit dan di bumi?" Katakanlah, ``Kepunyaan Allah.") jika mereka tidak mengatakannya dan tidak ada jawaban lain kecuali itu. (Dia telah memastikan) telah menetapkan (atas diri-Nya kasih sayang) sebagai kemurahan dari-Nya. Ungkapan ini mengandung seruan yang lembut untuk mengajak mereka agar beriman (Dia sungguh-sungguh akan menghimpun kamu pada hari kiamat) untuk membalas kamu atas perbuatan-perbuatan kamu (tidak ada keraguan) kebimbangan (terhadapnya. Orang-orang yang merugikan dirinya) karena mereka menjerumuskan dirinya ke dalam siksaan. Alladziina adalah mubtada sedangkan khabarnya ialah (mereka itu tidak beriman).\qt@no{12}}%
\qt@newcmd\qurantrans@id@dcccii{%
(Dan kepunyaan Allahlah) Maha Luhur Allah (segala yang ada) yang berada (di malam hari dan di siang hari) artinya Dialah Tuhan segala sesuatu, Penciptanya dan Pemiliknya (Dan Dia Maha Mendengar) terhadap apa yang dikatakan (lagi Maha Mengetahui) atas apa yang diperbuat.\qt@no{13}}%
\qt@newcmd\qurantrans@id@dccciii{%
(Katakanlah) kepada mereka ("Apakah akan aku jadikan pelindung selain dari Allah) yang aku sembah (yang menjadikan langit dan bumi) Allah yang menciptakan keduanya (padahal Dia memberi makan) memberi rezeki (dan tidak diberi makan?") tidak memerlukan rezeki (Katakanlah, ``Sesungguhnya aku diperintah supaya aku menjadi orang yang pertama sekali menyerahkan diri) kepada Allah dari kalangan umat ini (dan) dikatakan kepadaku (jangan sekali-kali kamu termasuk golongan orang-orang yang musyrik") kepada-Nya.\qt@no{14}}%
\qt@newcmd\qurantrans@id@dccciv{%
(Katakanlah, ``Sesungguhnya aku takut jika aku mendurhakai Tuhanku) dengan menyembah selain-Nya (azab hari yang besar.") yaitu hari kiamat.\qt@no{15}}%
\qt@newcmd\qurantrans@id@dcccv{%
(Siapa yang dijauhkan siksaan) dalam bentuk pasif, maf'ulnya azab/siksaan; dan dalam bentuk aktif, fa'ilnya Allah, sedangkan dhamirnya dibuang (daripadanya pada hari itu, maka sungguh Allah telah memberikan rahmat kepadanya) Maha Tinggi Allah, artinya Ia menghendaki kebaikan untuknya. (Dan itu keberuntungan yang nyata) keselamatan yang nyata.\qt@no{16}}%
\qt@newcmd\qurantrans@id@dcccvi{%
(Jika Allah menimpakan suatu kemudaratan kepadamu) musibah, seperti sakit dan kemiskinan (maka tidak ada yang menghilangkannya) tidak ada yang bisa mengangkatnya (daripadanya selain Dia sendiri. Dan jika Dia mendatangkan kebaikan kepadamu) seperti kesehatan dan kecukupan (maka Dia Maha Kuasa atas tiap-tiap segala sesuatu) berada pada kekuasaan-Nyalah segala sesuatu itu; tidak ada seorang pun yang dapat menolaknya dari dirimu selain daripada-Nya sendiri.\qt@no{17}}%
\qt@newcmd\qurantrans@id@dcccvii{%
(Dan Dialah yang berkuasa) Maha Kuasa tidak ada sesuatu pun yang dapat melemahkan-Nya, Dia Maha Tinggi (atas sekalian hamba-hamba-Nya. Dan Dialah Yang Maha Bijaksana) atas makhluk-Nya (lagi Maha Mengetahui) Semua yang tersimpan dalam batin mereka sebagaimana halnya yang tampak pada mereka. Ayat berikut diturunkan berkenaan dengan pertanyaan yang mereka ajukan kepada Nabi saw., ``Datangkanlah kepada kami orang yang menyaksikan dirimu sebagai Nabi karena sesungguhnya orang-orang Ahli Kitab pun ingkar terhadap dirimu."\qt@no{18}}%
\qt@newcmd\qurantrans@id@dcccviii{%
(Katakanlah) kepada mereka ("Siapakah yang lebih kuat persaksiannya?") menjadi tamyiz yang dialihkan dari mubtada (Katakanlah, ``Allah.") jika kamu tidak mengatakannya, maka tidak ada jawaban lain bagimu selain itu. (Dia menjadi saksi antara aku dan kamu) yang menyaksikan kebenaranku. (Dan Alquran ini diwahyukan kepadaku supaya aku memberi peringatan kepadamu) aku membuat kamu takut hai penduduk Mekah (dengannya dan kepada orang-orang yang sampai kepadanya Alquran) diathafkan kepada dhamir yang terdapat dalam Lafal undzirakum; artinya manusia dan jin yang sampai kepadanya Alquran. ("Apakah sesungguhnya kamu mengakui bahwa ada tuhan-tuhan yang lain di samping Allah?") kata tanya mengandung arti ingkar. (Katakanlah) kepada mereka ("Aku tidak mengakui") hal tersebut. (Katakanlah, ``Sesungguhnya Dia adalah Tuhan Maha Esa dan sesungguhnya aku berlepas diri dari apa yang kamu persekutukan.") terhadap Allah.\qt@no{19}}%
\qt@newcmd\qurantrans@id@dcccix{%
(Orang-orang yang telah Kami berikan kitab kepadanya mereka mengenalnya) artinya mengenal Muhammad dengan sifat-sifat atau ciri-cirinya yang terdapat di dalam Kitab mereka (seperti mereka mengenal anak-anak sendiri. Orang-orang yang merugikan dirinya) di antara mereka (mereka itu tidak beriman) kepada Muhammad.\qt@no{20}}%
\qt@newcmd\qurantrans@id@dcccx{%
(Dan siapakah) artinya tidak ada seorang pun (yang lebih aniaya daripada orang yang membuat-buat suatu kedustaan kepada Allah) yaitu menyekutukan-Nya dengan selain-Nya (atau mendustakan ayat-ayat-Nya?) Alquran. (Sesungguhnya) artinya keadaan yang sebenarnya (orang-orang yang aniaya itu tidak mendapat keberuntungan) oleh sebab kedustaannya itu.\qt@no{21}}%
\qt@newcmd\qurantrans@id@dcccxi{%
(Dan) ingatlah (hari yang di waktu itu Kami menghimpun mereka semuanya, kemudian Kami berkata kepada orang-orang musyrik) sebagai celaan ("Di manakah sesembahan-sesembahan yang kamu katakan dahulu?") yang kalian jadikan sebagai sekutu-sekutu Allah.\qt@no{22}}%
\qt@newcmd\qurantrans@id@dcccxii{%
(Kemudian tiadalah) Takun dapat dibaca yakun (fitnah mereka) dapat dibaca fitnatuhum dan fitnatahum; artinya alasan mereka (kecuali mengatakan) selain ucapan mereka ("Demi Allah, Tuhan kami) dibaca dengan jar sebagai sifat, dan dibaca nashab sebagai seruan (kami bukanlah orang-orang yang musyrik terhadap Allah").\qt@no{23}}%
\qt@newcmd\qurantrans@id@dcccxiii{%
Allah berfirman (Lihatlah) olehmu Muhammad (bagaimana mereka telah berdusta terhadap diri mereka sendiri) mereka menganggap bukan sebagai orang-orang musyrik (dan hilanglah) lenyaplah (dari mereka apa-apa yang selama ini mereka buat-buat) sebagai sesembahan mereka selain Allah.\qt@no{24}}%
\qt@newcmd\qurantrans@id@dcccxiv{%
(Dan di antara mereka ada orang-orang yang mau mendengarkanmu) apabila kamu membaca Alquran (padahal Kami telah menjadikan tutupan di atas hati mereka) penutup-penutup (agar mereka tidak memahaminya) supaya mereka tidak dapat memahami Alquran (dan di telinga mereka Kami letakkan sumbatan) sehingga mereka tuli tidak dapat mendengarnya, dengan pengertian pendengaran yang masuk di hati (Dan sekali pun mereka melihat segala tanda kebenaran, mereka tetap tidak mau beriman kepadanya. Sehingga apabila mereka datang kepadamu untuk membantahmu, orang-orang kafir itu berkata, ``Tiadalah) tidak lain (ini) Alquran ini (kecuali dongengan) cerita-cerita bohong (orang orang dahulu.") sama seperti lelucon-lelucon dan legenda-legenda; asaathiir adalah bentuk jamak dari usthuurah.\qt@no{25}}%
\qt@newcmd\qurantrans@id@dcccxv{%
(Mereka melarang) orang-orang lain (darinya) dari mengikut kepada Nabi Muhammad saw. (dan mereka sendiri menjauh) makin menjauh (darinya) mereka semakin tidak beriman kepadanya. Menurut suatu riwayat ayat ini diturunkan berkenaan dengan Abu Thalib; ia melarang orang-orang mengganggu Nabi saw. akan tetapi ia sendiri tidak mau beriman kepadanya (dan tidaklah) tiada lain (mereka itu membinasakan) oleh sebab menjauh dari Nabi saw. (kecuali diri mereka sendiri) karena bahaya mereka sendirilah yang menanggungnya (sedangkan mereka tidak menyadari) akibat perbuatannya itu.\qt@no{26}}%
\qt@newcmd\qurantrans@id@dcccxvi{%
(Dan jika kamu melihat) hai Muhammad (ketika mereka dihadapkan) dikemukakan (ke neraka lalu mereka berkata, ``Hai kiranya) ungkapan penyesalan (kami dikembalikan) ke dunia (dan tidak mendustakan ayat-ayat Tuhan kami serta menjadi orang-orang yang beriman.") kalau dibaca rafa' kedua fi'ilnya menjadi jumlah istinaf atau kalimat permulaan, jika dibaca nashab keduanya menjadi jawab dari tamanniy, demikian pula bila dibaca rafa' fi'ilnya yang pertama serta dibaca nashab fi'ilnya yang kedua. Sedang jawab dari lau/seandainya ialah: tentu kamu melihat suatu peristiwa yang besar.\qt@no{27}}%
\qt@newcmd\qurantrans@id@dcccxvii{%
Allah berfirman (Tetapi) sebagai sanggahan terhadap kemauan mereka untuk beriman; pengertian ini dipahami dari makna tamanniy tadi (telah nyata) telah jelas (bagi mereka apa yang dahulu mereka menyembunyikannya) apa yang tersimpan dalam hati mereka yang dahulu mereka mengatakan, bahwa demi Allah, Tuhan kami, kami bukanlah orang-orang musyrik terhadap Allah. Hal itu terungkapkan berkat kesaksian anggota-anggota tubuh mereka, sehingga mereka mengharapkan (Sekiranya mereka dikembalikan) ke dunia secara perkiraan (tentulah mereka kembali kepada apa yang mereka telah dilarang mengerjakannya) yaitu perbuatan syirik (dan sesungguhnya mereka itu adalah pendusta-pendusta belaka) dalam janji mereka yang menyatakan sedia untuk beriman.\qt@no{28}}%
\qt@newcmd\qurantrans@id@dcccxviii{%
(Dan tentu mereka akan mengatakan) orang-orang yang ingkar terhadap hari berbangkit ("Tiada lain) tidak lain (ia) dimaksud kehidupan (kecuali hanya kehidupan dunia saja, dan kita sekali-kali tidak akan dibangkitkan.")\qt@no{29}}%
\qt@newcmd\qurantrans@id@dcccxix{%
(Dan seandainya kamu melihat ketika mereka dihadapkan) mereka diajukan (kepada Tuhan mereka) tentulah kamu akan melihat peristiwa yang besar. (Allah berfirman) kepada mereka melalui lisan malaikat-malaikat-Nya sebagai cemoohan. ("Bukankah hal ini) yakni kebangkitan dan hari pembalasan ini (benar?" Mereka menjawab, ``Sungguh benar, demi Tuhan kami") sungguh hal itu adalah benar belaka (Berfirman Allah, ``Karena itu rasakanlah azab ini, disebabkan kamu mengingkari")nya sewaktu hidup di dunia.\qt@no{30}}%
\qt@newcmd\qurantrans@id@dcccxx{%
(Sungguh telah rugilah orang-orang yang mendustakan pertemuan mereka dengan Allah) mendustakan adanya hari kebangkitan (sehingga) sebagai tanda keterlaluan mereka dalam mendustakan (apabila kiamat datang kepada mereka) yaitu hari kiamat (dengan tiba-tiba) secara mendadak (mereka berkata, ``Alangkah besarnya penyesalan kami) sebagai ungkapan rasa derita yang sangat keras; dan pemakaian huruf nida atau panggilan di sini hanyalah majaz atau kiasan yang artinya sekarang saatnya telah tiba maka datanglah (terhadap kelalaian kami) kealpaan kami (tentang kiamat itu.") sewaktu di dunia (sambil mereka memikul dosa-dosa di atas punggungnya) dosa-dosa itu mendatangi mereka dalam bentuk yang paling buruk dan paling berbau kemudian dosa-dosa itu menaiki mereka. (Ingatlah, amatlah buruk) sangat jeleklah (apa yang mereka pikul itu) beban yang mereka pikul itu.\qt@no{31}}%
\qt@newcmd\qurantrans@id@dcccxxi{%
(Dan tiadalah kehidupan dunia ini) artinya kesibukannya (selain dari main-main dan senda-gurau) adapun mengenai amal taat dan hal-hal yang menjadi sarananya maka hal itu termasuk perkara-perkara akhirat. (Dan sungguh kampung akhirat itu) di dalam suatu qiraat yang dimaksud dengan kampung akhirat itu ialah surga (lebih baik bagi orang-orang yang takwa) yang takut berbuat kemusyrikan. (Maka tidakkah kamu memahaminya?) dengan memakai ya dan ta; hal itu kemudian mendorong kamu untuk beriman.\qt@no{32}}%
\qt@newcmd\qurantrans@id@dcccxxii{%
(Sesungguhnya) untuk penegasan (Kami mengetahui bahwasanya) perihal itu (apa yang mereka katakan itu membuat kamu bersedih hati) berupa kedustaan yang ditujukan kepadamu (karena mereka sebenarnya tidak mendustakan kamu) secara sembunyi-sembunyi oleh sebab pengetahuan mereka tentang dirimu yang dapat dipercaya itu. Dan di dalam suatu qiraat dibaca dengan takhfif atau ringan; artinya mereka tidak menuduhmu berbuat dusta (akan tetapi orang-orang yang zalim itu) azh-zhaalimiina diletakkan pada tempatnya dhamir (terhadap ayat-ayat Allah) Alquran (mereka ingkar) mereka mendustakannya.\qt@no{33}}%
\qt@newcmd\qurantrans@id@dcccxxiii{%
(Dan sungguh telah didustakan pula rasul-rasul sebelumnya) dalam ayat ini terkandung makna yang menghibur diri Nabi saw. (akan tetapi mereka sabar dalam menghadapi pendustaan dan penganiayaan yang dilakukan terhadap mereka sampai datang pertolongan Kami kepada mereka) untuk membinasakan kaumnya; maka bersabarlah kamu sehingga datang pertolongan-Ku yang akan membinasakan kaummu. (Tak ada seorang pun yang dapat merubah kalimat-kalimat Allah) janji-janji-Nya (Dan sesungguhnya telah datang kepadamu sebagian dari berita rasul-rasul itu) yang dapat menenangkan hatimu.\qt@no{34}}%
\qt@newcmd\qurantrans@id@dcccxxiv{%
(Dan jika makin bertambah besar) makin menjadi (berpalingnya mereka darimu) dari agama Islam padahal kamu masih berharap agar mereka beriman (maka jika kamu dapat membuat lubang) membuat terowongan (di bumi atau tangga) alat untuk naik (ke langit lalu kamu dapat mendatangkan mukjizat kepada mereka) sesuai dengan apa yang mereka minta, maka lakukanlah. Artinya sesungguhnya kamu tidak akan kuat untuk melakukan hal itu oleh karena itu bersabarlah hingga datang kepada mereka keputusan Allah. (Dan kalau Allah menghendaki) memberikan hidayah kepada mereka (tentu saja Allah menjadikan mereka semua dalam petunjuk) akan tetapi Ia tidak menghendaki demikian oleh karenanya mereka tidak mau beriman (janganlah kamu sekali-kali termasuk orang-orang jahil) mengenai hal itu.\qt@no{35}}%
\qt@newcmd\qurantrans@id@dcccxxv{%
(Sesungguhnya yang mendengar) ajakanmu kepada keimanan (hanyalah orang-orang yang mematuhi ajakanmu) dengan pendengaran yang penuh pengertian dan penuh pertimbangan (dan orang-orang yang mati hatinya) yakni orang-orang kafir; Allah menyerupakan mereka dengan orang-orang yang mati oleh karena mereka semua sama-sama tidak bisa mendengar (akan dibangkitkan oleh Allah) di akhirat (kemudian kepada-Nyalah mereka dikembalikan) mereka akan dikembalikan kepada-Nya kemudian Allah membalas amal perbuatan mereka.\qt@no{36}}%
\qt@newcmd\qurantrans@id@dcccxxvi{%
(Dan mereka berkata) yaitu orang-orang musyrik Mekah ("Mengapa tidak) kenapa tidak (diturunkan kepadanya, Muhammad, suatu mukjizat dari Tuhannya?") seperti mukjizat onta, tongkat dan hidangan. (Katakanlah) kepada mereka ("Sesungguhnya Allah kuasa menurunkan) dengan dibaca tasydid dan takhfif (suatu mukjizat) seperti apa yang mereka minta (tetapi kebanyakan mereka tidak mengetahui") karena sesungguhnya dengan turunnya mukjizat itu berarti suatu musibah besar yang pasti menimpa mereka jika mereka masih tetap mengingkarinya.\qt@no{37}}%
\qt@newcmd\qurantrans@id@dcccxxvii{%
(Dan tiadalah) min sebagai tambahan (binatang-binatang) yang berjalan (di muka bumi dan burung-burung yang terbang) di udara (dengan kedua sayapnya melainkan umat-umat juga seperti kamu) dalam pengaturan penciptaannya, rezeki dan sepak terjangnya. (Tiadalah Kami alpakan) Kami tinggalkan (di dalam Alkitab) yakni Lohmahfuz (tentang) sebagai tambahan (sesuatu pun) artinya Kami tidak menulisnya (kemudian kepada Tuhanlah mereka dihimpunkan) kemudian Tuhan memutuskan hukum-Nya di antara mereka. Ia mengkisas si kuat yang menganiaya di lemah setelah Ia berfirman kepada mereka semua, ``Jadilah kamu semua sebagai tanah!"\qt@no{38}}%
\qt@newcmd\qurantrans@id@dcccxxviii{%
(Dan orang-orang yang mendustakan ayat-ayat Kami) Alquran (adalah pekak) tidak dapat mendengarkannya dengan pendengaran yang meresap ke dalam hati lalu menerimanya (bisu) tidak dapat mengucapkan perkara yang hak (lagi berada dalam gelap-gulita) yakni kekafiran. (Siapa yang dikehendaki Allah) ia tersesat (niscaya disesatkan-Nya. Dan siapa yang dikehendaki-Nya) mendapat petunjuk (niscaya Dia menjadikannya berada di atas jalan) titian (yang lurus) yakni agama Islam.\qt@no{39}}%
\qt@newcmd\qurantrans@id@dcccxxix{%
(Katakanlah) hai Muhammad kepada penduduk Mekah ("Terangkanlah kepadaku) beritakanlah kepadaku (jika datang siksaan Allah kepadamu) di dunia ini (atau datang kepadamu hari kiamat) yaitu kiamat yang mencakup semuanya secara tiba-tiba (apakah kamu menyeru tuhan selain Allah) tidak (jika kamu orang-orang yang benar.") bahwa berhala-berhala itu dapat memberi manfaat kepadamu, maka serulah mereka.\qt@no{40}}%
\qt@newcmd\qurantrans@id@dcccxxx{%
(Bahkan hanya kepada-Nyalah) tidak ada lain (kamu berseru) memohon pertolongan-Nya di masa kalian tertimpa kesulitan (maka Dia menghilangkan bahaya yang karenanya kamu berdoa kepada-Nya) Ia akan menyingkirkan mara bahaya dari dirimu dan juga lain-lainnya (jika Dia menghendaki) niscaya Ia melenyapkannya (dan kamu melupakan) kamu meninggalkan (apa-apa yang kamu sekutukan) dengan Allah yaitu berupa sesembahan-sesembahan lain-Nya, maka dari itu janganlah kamu berseru kepadanya.\qt@no{41}}%
\qt@newcmd\qurantrans@id@dcccxxxi{%
(Dan sesungguhnya Kami telah mengutus kepada umat-umat) min sebagai tambahan yang tidak mempunyai arti (sebelum kamu) rasul-rasul, akan tetapi mereka mendustakannya (kemudian Kami siksa mereka dengan kesengsaraan) kemelaratan yang sangat (dan penderitaan) penyakit (supaya mereka tunduk merendahkan diri) merasa rendah diri lalu mereka mau beriman.\qt@no{42}}%
\qt@newcmd\qurantrans@id@dcccxxxii{%
(Maka mengapa tidak) kenapa tidak (tatkala datang siksaan Kami kepada mereka) azab Kami (memohon kepada Allah dengan menundukkan diri) artinya mereka tidak mau melakukan hal itu, padahal yang mengharuskan mereka berbuat demikian sudah ada (bahkan hati mereka telah menjadi keras) oleh karenanya tidak mau tunduk kepada keimanan (dan setan pun menampakkan kepada mereka kebagusan apa yang selalu mereka kerjakan) yaitu perbuatan-perbuatan maksiat sehingga mereka terus menetapinya.\qt@no{43}}%
\qt@newcmd\qurantrans@id@dcccxxxiii{%
(Maka tatkala mereka melupakan) mereka mengabaikan (peringatan yang telah diberikan kepada mereka) nasihat dan ancaman yang telah diberikan kepada mereka (melaluinya) yaitu dalam bentuk kesengsaraan dan penderitaan, mereka tetap tidak mau mengambil pelajaran dan nasihat darinya (Kami bukakan) dengan dibaca takhfif dan tasydid (kepada mereka semua pintu-pintu) yakni kesenangan-kesenangan sebagai istidraj untuk mereka (sehingga apabila mereka bergembira dengan apa yang telah diberikan kepada mereka) gembira yang diwarnai rasa sombong (Kami siksa mereka) dengan azab (dengan tiba-tiba) secara sekonyong-konyong (maka ketika itu mereka terdiam berputus-asa) mereka merasa berputus asa dari segala kebaikan.\qt@no{44}}%
\qt@newcmd\qurantrans@id@dcccxxxiv{%
(Maka orang-orang yang lalim itu dimusnahkan) sampai ke akar-akarnya sehingga habis tanpa bekas (Segala puji bagi Allah Tuhan semesta alam) yang menolong rasul-rasul dan membinasakan orang-orang kafir.\qt@no{45}}%
\qt@newcmd\qurantrans@id@dcccxxxv{%
(Katakanlah) kepada penduduk Mekah ("Terangkanlah kepadaku) beritakanlah kepadaku (jika Allah mencabut pendengaranmu) membuatmu menjadi tuli (dan penglihatanmu) membutakanmu (serta mengunci) menutup (hatimu) sehingga kamu tidak dapat mengenal sesuatu (Siapakah tuhan selain Allah yang kuasa mengembalikannya kepadamu?") apa-apa yang telah Dia cabut darimu sesuai dengan dugaanmu (Perhatikanlah bagaimana Kami memperlihatkan) menjelaskan (tanda-tanda kebesaran Kami) bukti-bukti yang menunjukkan kepada keesaan Kami (kemudian mereka masih tetap berpaling) tetap berpaling dari-Nya dan tidak mau beriman.\qt@no{46}}%
\qt@newcmd\qurantrans@id@dcccxxxvi{%
(Katakanlah,) kepada mereka ("Terangkanlah kepadaku, jika datang siksaan Allah kepadamu dengan sekonyong-konyong atau terang-terangan) siang hari maupun malam hari (maka adakah yang dibinasakan Allah selain dari orang-orang yang lalim?") yakni orang-orang kafir. Atau dengan kata lain: tidak ada yang dibinasakan-Nya kecuali hanya mereka.\qt@no{47}}%
\qt@newcmd\qurantrans@id@dcccxxxvii{%
(Dan tidaklah Kami mengutus para rasul itu melainkan untuk memberi kabar gembira) tentang surga terhadap orang yang beriman (dan memberi peringatan) kepada orang yang kafir dengan adanya siksaan neraka. (Siapa yang beriman) kepada rasul-rasul itu (dan mengadakan perbaikan) terhadap amal perbuatannya (maka tak ada kekhawatiran terhadap mereka dan tidak pula mereka bersedih hati) di akhirat kelak.\qt@no{48}}%
\qt@newcmd\qurantrans@id@dcccxxxviii{%
(Dan orang-orang yang mendustakan ayat-ayat Kami mereka ditimpa siksaan disebabkan mereka selalu berbuat fasik) yaitu keluar dari garis-garis ketaatan.\qt@no{49}}%
\qt@newcmd\qurantrans@id@dcccxxxix{%
(Katakanlah) kepada mereka ("Aku tidak mengatakan kepadamu, bahwa perbendaharaan Allah ada padaku) yang di antaranya ialah rezeki yang diberikan kepadanya (dan tidak) pula bahwa aku (mengetahui yang gaib) hal-hal yang gaib dariku dan tidak diwahyukan kepadaku (dan tidak pula aku mengatakan kepadamu bahwa aku seorang malaikat) di antara malaikat-malaikat lainnya. (Tidaklah) tiada lain (aku hanya mengikut apa yang diwahyukan kepadaku." Katakanlah, ``Apakah sama orang yang buta) orang kafir (dengan orang yang melihat?") orang yang beriman; tentu saja tidak. (Maka apakah kamu tidak memikirkan) tentang hal itu, kemudian kamu beriman.\qt@no{50}}%
\qt@newcmd\qurantrans@id@dcccxl{%
(Dan berilah peringatan) takut-takutilah (dengannya) dengan Alquran (orang-orang yang takut akan dihimpunkan kepada Tuhannya pada hari kiamat sedang tidak ada bagi mereka selain-Nya) yakni selain Allah (seorang pelindung) yang dapat menolong mereka (dan pemberi syafaat pun) yang dapat memberikan syafaat kepada mereka. Jumlah kalimat yang diawali dengan huruf nafi menjadi hal dari dhamir yang terdapat di dalam lafal yuhsyaruu; maksudnya tempat yang ditakuti. Dan yang dimaksud dengan mereka adalah orang-orang yang maksiat (agar mereka bertakwa) kepada Allah dengan memberhentikan diri mereka dari kebiasaan yang biasa mereka lakukan kemudian mau berbuat ketaatan.\qt@no{51}}%
\qt@newcmd\qurantrans@id@dcccxli{%
(Dan janganlah kamu mengusir orang-orang yang menyeru Tuhannya di pagi hari dan di petang hari sedangkan mereka menghendaki) dengan ibadahnya itu (keridaan-Nya) Yang Maha Tinggi bukannya untuk tujuan meraih sesuatu dari keduniaan. Mereka adalah kaum muslimin yang miskin sedangkan kaum musyrikin sangat tidak menyukai mereka lalu orang-orang musyrik meminta kepada Nabi saw. agar beliau mengusir mereka dari sisinya supaya orang-orang musyrik itu dapat duduk bersama-sama dengan beliau. Kemudian Nabi saw. bermaksud untuk memenuhi permintaan orang-orang musyrik itu agar mereka mau masuk Islam. (Kamu tidak memikul tanggung jawab terhadap perbuatan mereka) huruf min adalah tambahan (sedikit pun) jika hati mereka tidak rela (dan mereka pun tidak memikul tanggung jawab sedikit pun terhadap perbuatanmu yang menyebabkan kamu berhak mengusir mereka) sebagai jawab dari nafi (sehingga kamu termasuk orang-orang yang lalim) jika kamu melakukan hal itu.\qt@no{52}}%
\qt@newcmd\qurantrans@id@dcccxlii{%
(Dan demikianlah telah Kami uji) Kami telah coba (sebagian mereka dengan sebagian lainnya) yakni orang yang mulia dengan orang yang rendah, orang kaya dengan orang miskin, untuk Kami lombakan siapakah yang berhak paling dahulu kepada keimanan (supaya mereka berkata) orang-orang yang mulia dan orang-orang yang kaya yaitu mereka yang ingkar ("Orang-orang semacam inikah) yakni orang-orang miskin (di antara kita yang diberi anugerah oleh Allah kepada mereka?") hidayah. Artinya jika apa yang sedang dilakukan oleh orang-orang miskin dan orang-orang rendahan itu dinamakan hidayah, niscaya orang-orang mulia dan orang-orang kaya itu tidak akan mampu mendahuluinya. Allah berfirman, ("Tidakkah Allah lebih mengetahui tentang orang-orang yang bersyukur?") kepada-Nya lalu Dia memberikan hidayah kepada mereka. Memang betul.\qt@no{53}}%
\qt@newcmd\qurantrans@id@dcccxliii{%
(Apabila orang-orang yang beriman kepada ayat-ayat Kami itu datang kepadamu, maka katakanlah) kepada mereka ("Mudah-mudahan Allah melimpahkan kesejahteraan atas kamu telah menetapkan) telah memastikan (Tuhanmu atas diri-Nya kasih sayang, yaitu bahwasanya) yakni perihalnya; di dalam suatu qiraat dibaca dengan fathah yaitu annahu sebagai badal atau kata ganti dari Lafal ar-rahmah (siapa yang berbuat kejahatan di antara kamu lantaran kejahilan) terhadap perbuatan itu sewaktu ia melakukannya (kemudian ia bertobat) kembali ke jalan yang benar (setelah itu) setelah mengerjakannya (dan mengadakan perbaikan) terhadap amal perbuatannya (maka sesungguhnya Ia) yakni Allah swt. (Maha Pengampun) kepadanya (lagi Maha Penyayang.") kepada dirinya. Menurut qiraat lainnya dibaca dengan fatah; artinya maka Dialah yang memberi ampunan dan kasih sayang.\qt@no{54}}%
\qt@newcmd\qurantrans@id@dcccxliv{%
(Dan demikianlah) sebagaimana yang telah Kami jelaskan sebelumnya (Kami terangkan) Kami jelaskan (ayat-ayat) Alquran untuk menampakkan yang hak kemudian diamalkan (supaya jelas) supaya menjadi terang (jalan) kelakuan (orang-orang yang berdosa) kemudian engkau menjauhinya. Dalam suatu qiraat dibaca litubayyina; menurut qiraat lainnya dibaca litastabiina. Bila lafal sabiil dibaca nashab maka pembicaraannya ditujukan kepada Nabi saw.\qt@no{55}}%
\qt@newcmd\qurantrans@id@dcccxlv{%
(Katakanlah, ``Sesungguhnya aku dilarang menyembah tuhan-tuhan yang kamu seru) kamu sembah (selain Allah." Katakanlah, ``Aku tidak akan mengikuti hawa nafsumu) dalam menyembah tuhan-tuhanmu itu (sungguh tersesatlah aku jika berbuat demikian) jika aku ikut menyembah tuhan-tuhan itu (dan tidak pula aku termasuk orang-orang yang mendapat petunjuk.")\qt@no{56}}%
\qt@newcmd\qurantrans@id@dcccxlvi{%
(Katakanlah, ``Sesungguhnya aku berada di atas hujah) penjelasan yang nyata (dari Tuhanku dan) ternyata (kamu mendustakannya) mendustakan Tuhanku karena kamu telah menyekutukan-Nya. (Tidak ada padaku apa yang kamu minta supaya disegerakan kedatangannya) yaitu berupa azab. (Tidak lain) tiada lain (menetapkan hukum itu) dalam masalah tersebut dan masalah-masalah lainnya (hanyalah hak Allah. Dia memutuskan) menentukan (yang sebenarnya dan Dia pemberi keputusan yang paling baik.") pemberi ketentuan hukum yang paling baik. Menurut suatu qiraat dibaca yaqushshu/menerangkan bukannya yaqdhii/memutuskan.\qt@no{57}}%
\qt@newcmd\qurantrans@id@dcccxlvii{%
(Katakanlah) kepada mereka ("Kalau sekiranya ada padaku apa/azab yang kamu minta supaya disegerakan kedatangannya, tentu telah diselesaikan Allah urusan yang ada antara aku dan kamu) yaitu dengan cara aku menyegerakan azab itu kepadamu, kemudian aku istirahat. Akan tetapi azab itu hanya ada di tangan kekuasaan Allah (Dan Allah lebih mengetahui tentang orang-orang yang lalim.") di kala Ia mau menghukum mereka.\qt@no{58}}%
\qt@newcmd\qurantrans@id@dcccxlviii{%
(Dan pada sisi Allahlah) Yang Maha Luhur (kunci-kunci semua yang gaib) simpanan-simpanan ilmu gaib atau jalan-jalan yang mengantarkan kepada pengetahuan tentangnya (tak ada yang mengetahuinya kecuali Dia sendiri) ilmu tentang kegaiban itu ada lima macam; mengenai penjelasannya telah dikemukakan dalam surah Luqman ayat 34, yaitu firman-Nya, ``Sesungguhnya Allah hanya pada sisi-Nya sajalah pengetahuan tentang hari kiamat... sampai akhir ayat." Demikianlah menurut riwayat Imam Bukhari (dan Dia mengetahui apa) yang terjadi (di daratan) permukaan bumi (dan di lautan) perkampungan-perkampungan yang ada di atas sungai-sungai (dan tiada sehelai daun pun yang gugur) huruf min adalah zaidah/ tambahan (melainkan Dia mengetahuinya pula, dan tidak jatuh sebutir biji pun dalam kegelapan bumi dan tidak sesuatu yang basah atau yang kering) diathafkan kepada Lafal waraqatin (melainkan tertulis dalam kitab yang nyata) yakni Lohmahfuz. Al-Istitsna/pengecualian berkedudukan sebagai badal isytimal dari istitsna yang sebelumnya.\qt@no{59}}%
\qt@newcmd\qurantrans@id@dcccxlix{%
(Dan Dialah yang menidurkan kamu di malam hari) Ia mencabut arwah kamu di kala tidur (dan Dia mengetahui apa yang kamu kerjakan) yang kamu lakukan (pada siang hari kemudian Dia membangunkan kamu pada siang hari) maksudnya dibangunkan kembali pada siang harinya dengan cara mengembalikan arwahmu (untuk disempurnakan ajalmu yang telah ditentukan) yakni batas kehidupan (kemudian kepada Allahlah kamu kembali) melalui kebangkitan (lalu Dia memberitakan kepadamu apa yang dahulu kamu kerjakan) kemudian Ia membalas kamu berdasarkan hal itu.\qt@no{60}}%
\qt@newcmd\qurantrans@id@dcccl{%
(Dan Dialah yang mempunyai kekuasaan tertinggi) kekuasaan yang maha tinggi (di atas semua hamba-Nya dan diutus-Nya kepadamu malaikat-malaikat penjaga) yaitu para malaikat yang mencatat semua amal perbuatanmu (sehingga apabila datang kepada salah seorang di antara kamu kematian, ia diwafatkan) di dalam qiraat lainnya dibaca tawaffahu (oleh utusan-utusan Kami) yakni para malaikat yang ditugaskan untuk mencabut arwah-arwah (dan mereka itu tidak melalaikan kewajibannya) tidak pernah berlaku sembrono terhadap apa yang telah diperintahkan kepada mereka untuk dilakukannya.\qt@no{61}}%
\qt@newcmd\qurantrans@id@dcccli{%
(Kemudian mereka dikembalikan) semua makhluk itu (kepada Allah Penguasa mereka) Yang Memiliki mereka (yang sebenarnya) yang bersifat Maha Adil untuk membalas amal perbuatan mereka. (Ketahuilah bahwa segala hukum pada hari itu kepunyaan-Nya) keputusan yang dilaksanakan atas diri mereka (dan Dialah Pembuat perhitungan yang paling cepat.") Dia menghisab semua makhluk dalam jangka waktu setengah hari menurut ukuran hari dunia sebagaimana yang telah dijelaskan oleh sebuah hadis mengenai hal ini.\qt@no{62}}%
\qt@newcmd\qurantrans@id@dccclii{%
(Katakanlah,) hai Muhammad kepada penduduk Mekah ("Siapakah yang dapat menyelamatkanmu dari kegelapan-kegelapan di darat dan di laut) dari bencana-bencananya dalam perjalananmu, yaitu tatkala (kamu berdoa kepada-Nya dengan berendah diri) dengan secara terang-terangan (dengan suara yang lembut) dengan secara sembunyi-sembunyi kamu mengatakan (Sesungguhnya jika) lam menunjukkan qasam/sumpah (Dia menyelamatkan kami) dalam qiraat lainnya dibaca anjaytanaa, yakni Allah (dari ini) maksudnya dari kegelapan dan bencana-bencana ini (tentulah kami menjadi orang-orang yang bersyukur.") menjadi orang-orang yang beriman.\qt@no{63}}%
\qt@newcmd\qurantrans@id@dcccliii{%
(Katakanlah,) kepada mereka ("Allah menyelamatkan kamu) dibaca dengan takhfif yaitu yunjiikum dan dibaca dengan tasydid yaitu yunajjiikum (daripada bencana itu dan dari segala macam kesusahan) kesulitan yang selain bencana itu (kemudian kamu kembali menyekutukan")-Nya.\qt@no{64}}%
\qt@newcmd\qurantrans@id@dcccliv{%
(Katakanlah, ``Dialah yang berkuasa untuk mengirimkan azab kepadamu dari atas kamu) dari langit yakni berupa batu-batu dan suara keras yang mengguntur (atau dari bawah kakimu) dengan diamblaskan/ditelan bumi (atau Dia mencampurkan kamu) mencampur-adukkan kamu (menjadi golongan-golongan) kelompok-kelompok yang berbeda keinginannya (dan merasakan kepada sebagian kamu keganasan sebagian yang lain.") dengan cara saling membunuh. Rasulullah saw. telah bersabda tatkala ayat ini turun, ``Ini lebih ringan dan lebih mudah." Akan tetapi tatkala ayat sebelumnya turun Nabi saw. bersabda, ``Aku berlindung kepada Zat-Mu," hadis ini diriwayatkan oleh Imam Bukhari. Dan Imam Muslim meriwayatkan tentang sabda Nabi saw., ``Aku memohon kepada Tuhanku agar Ia tidak menjadikan keganasan umatku disebabkan ulah sebagian di antara mereka tetapi Ia melarangku mendoakan hal ini." Dan sehubungan dengan hadis pertama, Imam Muslim mengatakan bahwa kejadiannya pasti akan ada hanya saja kenyataannya masih belum terungkapkan. (Perhatikanlah bagaimana Kami menjelaskan) menerangkan kepada mereka (tentang ayat-ayat) yang menunjukkan kepada kekuasaan Kami (barangkali saja mereka mau memahaminya) mereka mau mengetahuinya bahwa apa yang mereka lakukan itu adalah perkara batil.\qt@no{65}}%
\qt@newcmd\qurantrans@id@dccclv{%
(Dan telah berdusta kepadanya) terhadap Alquran (kaummu padahal Alquran itu adalah hak) yakni benar (Katakanlah,) kepada mereka ("Aku ini bukanlah orang yang diserahi mengurus urusan kamu.") kemudian aku membalas kamu; sesungguhnya aku ini hanyalah seorang pemberi peringatan sedangkan mengenai urusanmu hal itu terserah kepada Allah. Ayat ini diturunkan sebelum ada ayat perintah untuk berperang.\qt@no{66}}%
\qt@newcmd\qurantrans@id@dccclvi{%
(Untuk tiap-tiap berita) kabar (ada ketetapannya) yakni waktu kejadiannya dan waktu ketetapannya yang antara lain ialah pengazaban kamu (dan kelak kamu akan mengetahui) sebagai ancaman yang ditujukan kepada mereka.\qt@no{67}}%
\qt@newcmd\qurantrans@id@dccclvii{%
(Dan apabila melihat orang-orang memperolok-olokkan ayat-ayat Kami) yakni Alquran dengan cemoohan (maka tinggalkanlah mereka) janganlah kamu bergaul dengan mereka (sehingga mereka membicarakan pembicaraan yang lain. Dan jika) Lafal immaa berasal dari in syarthiah yang diidghamkan ke dalam maa zaidah (menjadikan kamu lupa) dengan dibaca yunsiyannaka atau yunassiyannaka (godaan setan) kemudian engkau duduk bersama mereka (maka janganlah kamu duduk sesudah teringat) artinya sesudah engkau teringat akan larangan itu (bersama orang-orang yang lalim itu) ungkapan ini mengandung peletakan isim zahir pada posisi isim mudhmar. Dan orang-orang muslim mengatakan, ``Jika kami berdiri sewaktu mereka mulai memperolok-olokkan ayat-ayat Allah, maka kami tidak bisa lagi duduk di mesjid dan melakukan tawaf di dalamnya," lalu turunlah ayat berikut ini:\qt@no{68}}%
\qt@newcmd\qurantrans@id@dccclviii{%
(Dan tidak ada atas orang-orang yang bertakwa) kepada Allah (pertanggungjawaban terhadap dosa mereka) orang-orang yang memperolok-olokkan ayat-ayat Allah (barang) sebagai huruf zaidah (sedikit pun) jika orang-orang yang bertakwa itu duduk-duduk dengan mereka (akan tetapi) kewajiban orang-orang yang bertakwa adalah (mengingatkan) memberikan peringatan kepada mereka dan juga nasihat (agar mereka bertakwa) tidak lagi memperolok-olokkan ayat-ayat Allah.\qt@no{69}}%
\qt@newcmd\qurantrans@id@dccclix{%
(Dan tinggalkanlah) biarkanlah (orang-orang yang menjadikan agama mereka) yang sudah menjadi kewajiban bagi mereka untuk mengamalkannya (sebagai main-main dan senda gurau) oleh sebab mereka mengejek agama (dan mereka telah ditipu oleh kehidupan dunia) maka janganlah engkau menghalang-halangi mereka; ayat ini diturunkan sebelum adanya perintah untuk berperang (Peringatkanlah) berilah nasihat umat manusia itu (dengannya) Alquran (agar) janganlah (setiap diri terjerumus ke dalam neraka) atau ke dalam kebinasaan (karena perbuatannya sendiri) karena amal perbuatannya sendiri (Baginya tidak akan ada selain dari Allah) (sebagai penolong) yang dapat menyelamatkannya (dan tidak pula pemberi syafaat) yang dapat mencegah dirinya dari siksaan neraka. (Dan jika ia menebus dengan segala tebusan) dengan segala macam tebusan (niscaya tidak akan diterima) maksudnya diri mereka tidak dapat ditebus. (Mereka itulah orang-orang yang terjerumus ke dalam neraka disebabkan perbuatan mereka sendiri. Bagi mereka disediakan minuman dari air yang sedang mendidih) yakni air yang sangat panas sekali (dan azab yang pedih) yang sangat menyakitkan (disebabkan kekafiran mereka dahulu) oleh sebab kekafiran mereka.\qt@no{70}}%
\qt@newcmd\qurantrans@id@dccclx{%
(Katakanlah, ``Apakah kita akan menyeru) apakah kita akan menyembah (selain daripada Allah sesuatu yang tidak dapat mendatangkan kemanfaatan kepada kita) karena menyembahnya (dan tidak pula mendatangkan kemudaratan kepada kita) oleh sebab tidak menyembahnya; yang dimaksud adalah berhala-berhala (dan apakah kita akan dikembalikan ke belakang) dikembalikan kepada kemusyrikan (sesudah Allah memberi petunjuk kepada kita) kepada agama Islam (seperti orang yang digoda) yang disesatkan (oleh setan dipesawangan yang menakutkan dalam keadaan bingung) bingung tidak tahu jalan yang akan ditempuhnya; Lafal ini menjadi hal bagi dhamir ha (dia mempunyai kawan-kawan) teman-teman (yang memanggilnya ke jalan yang lurus) artinya mereka bermaksud memberikan petunjuk jalan yang benar kepadanya kemudian berkata kepadanya: (Marilah ikuti kami.") akan tetapi ia tidak mengikuti ajakan mereka sehingga binasalah ia dalam kesesatan. Istifham/kata tanya di sini bermakna ingkar dan kalimat yang ada tasybihnya adalah menjadi hal bagi dhamir yang terdapat di dalam Lafal nuraddu (Katakanlah, ``Sesungguhnya petunjuk Allah) yakni agama Islam (ialah sebenar-benar petunjuk) dan yang selain petunjuk-Nya adalah kesesatan belaka (dan kita disuruh agar menyerahkan diri) diperintahkan agar kita berserah diri (kepada Tuhan semesta alam).\qt@no{71}}%
\qt@newcmd\qurantrans@id@dccclxi{%
(dan agar) hendaknya (mendirikan salat dan bertakwa kepada-Nya) Yang Maha Tinggi (dan Dialah Tuhan yang kepada-Nyalah kamu akan dihimpunkan) dikumpulkan kelak di hari kiamat guna menjalani perhitungan amalnya.\qt@no{72}}%
\qt@newcmd\qurantrans@id@dccclxii{%
(Dan Dialah yang menciptakan langit dan bumi dengan benar.) dengan secara hak (Dan) ingatlah (di waktu Dia mengatakan) kepada sesuatu ("Jadilah," lalu terjadilah) pada hari kiamat Allah mengatakan kepada makhluk semua, ``Bangkitlah kamu," lalu bangkitlah mereka (yakni perkataan-Nya yang benar) benar terjadi dan sudah pasti (dan di tangan-Nyalah segala kekuasaan di waktu sangkakala ditiup) pada masa malaikat Israfil meniup sangkakalanya yang kedua pada waktu itu tidak ada kekuasaan selain dari kekuasaan-Nya. Pada waktu itu kekuasaan hanya milik-Nya. (Dia mengetahui yang gaib dan yang tampak) apa-apa yang gaib dan apa-apa yang nyata. (Dan Dialah Yang Maha Bijaksana) dalam mengatur makhluk-Nya (lagi Maha Waspada) terhadap rahasia segala sesuatu sama halnya dengan lahiriahnya.\qt@no{73}}%
\qt@newcmd\qurantrans@id@dccclxiii{%
(Dan) ingatlah (di waktu Ibrahim berkata kepada bapaknya Azar) julukan dan nama aslinya adalah Tarikh ("Pantaskah kamu menjadikan patung-patung sebagai tuhan-tuhan?) yang kamu sembah. Kata tanya di sini bermakna celaan. (Sesungguhnya aku melihat kamu dan kaummu) karena menjadikan berhala-berhala sebagai tuhan-tuhan (dalam kesesatan) yakni tersesat dari jalan yang benar (yang nyata.") yang jelas.\qt@no{74}}%
\qt@newcmd\qurantrans@id@dccclxiv{%
(Dan demikianlah) sebagaimana apa yang telah Kami perhatikan kepada Ibrahim, yaitu ia menganggap sesat ayahnya dan kaum ayahnya (Kami perlihatkan kepada Ibrahim kerajaan) kekuasaan (langit dan bumi) agar ia dapat mengambil kesimpulan tentang keesaan-Ku (dan agar dia termasuk orang-orang yang yakin) terhadap tanda-tanda keagungan Kami itu. Jumlah wakadzaalika serta jumlah yang sesudahnya adalah jumlah I`tiradhiah yang diathafkan kepada Lafal qaala.\qt@no{75}}%
\qt@newcmd\qurantrans@id@dccclxv{%
(Ketika menjadi gelap) menjadi kelam pekat (malam hari atasnya, dia melihat sebuah bintang) menurut suatu pendapat bahwa yang dimaksud adalah bintang Zahrah/Venus (lalu dia berkata) kepada kaumnya yang pada waktu itu menjadi para penyembah bintang-bintang ("Inilah Tuhanku") menurut persangkaan kamu (Tetapi tatkala bintang itu tenggelam) surut (dia berkata, ``Saya tidak suka kepada yang tenggelam.") maksudnya aku tidak suka menjadikannya sebagai tuhan-tuhan sebab tuhan tidak patut mempunyai sifat yang berubah-ubah dan pindah-pindah tempat karena kedua sifat ini hanyalah pantas disandang oleh makhluk-makhluk akan tetapi ternyata cara yang disampaikan oleh Nabi Ibrahim ini tidak mempan pada diri mereka.\qt@no{76}}%
\qt@newcmd\qurantrans@id@dccclxvi{%
(Kemudian tatkala dia melihat bulan terbit) bulan mulai menampakkan sinarnya (dia berkata) kepada mereka ("Inilah tuhanku." Tetapi setelah bulan itu terbenam dia berkata, ``Sesungguhnya jika Tuhanku tidak memberi petunjuk kepadaku) memantapkan hidayah dalam diriku (pastilah aku termasuk orang-orang yang sesat.") perkataan ini merupakan sindiran Nabi Ibrahim terhadap kaumnya bahwa mereka itu berada dalam kesesatan akan tetapi ternyata apa yang telah dilakukannya itu sedikit pun tidak bermanfaat bagi kaumnya.\qt@no{77}}%
\qt@newcmd\qurantrans@id@dccclxvii{%
(Kemudian tatkala dia melihat matahari terbit dia berkata, ``Inilah) dhamir dalam Lafal ra-aa dimudzakarkan mengingat khabarnya mudzakkar (Tuhanku ini yang lebih besar.") daripada bintang dan bulan (maka tatkala matahari itu tenggelam) hujah yang ia sampaikan kepada kaumnya itu cukup kuat dan tidak dapat dibantah lagi oleh mereka (dia berkata, ``Hai kaumku! Sesungguhnya aku berlepas diri dari apa yang kamu persekutukan.") dari mempersekutukan Allah dengan berhala-berhala dan benda-benda hawadits/baru yang masih membutuhkan kepada yang menciptakannya. Akhirnya kaumnya itu berkata kepadanya, ``Lalu apakah yang engkau sembah?" Nabi Ibrahim menjawab:\qt@no{78}}%
\qt@newcmd\qurantrans@id@dccclxviii{%
("Sesungguhnya aku menghadapkan diriku) aku menghadapkan diri dengan beribadah (kepada Tuhan yang telah menciptakan) yang telah mewujudkan (langit dan bumi) yaitu Allah swt. (dengan cenderung) meninggalkan semua agama untuk memeluk agama yang benar (dan aku bukanlah termasuk orang-orang yang mempersekutukan.") Allah.\qt@no{79}}%
\qt@newcmd\qurantrans@id@dccclxix{%
(Dan dia dibantah oleh kaumnya) ia mendapat sanggahan dari kaumnya mengenai agama yang dipeluknya itu, lalu mereka mengancam dan menakut-nakutinya dengan berhala-berhala mereka, bahwa jika ia tidak menyembah berhala-berhala mereka, ia pasti tertimpa musibah dan kejelekan. (Dia berkata, ``Apakah kamu hendak membantahku) dengan dibaca tasydid huruf nunnya dan dapat juga ditakhfifkan dengan cara membuang salah satu nunnya, yakni nun alamat rafa'nya, demikianlah menurut ulama nahwu. Akan tetapi menurut Imam Farra' yang dibuang adalah nun yang untuk wiqayah. Maknanya ialah: Apakah kamu menyanggah aku? (tentang) keesaan (Allah padahal sesungguhnya Allah telah memberi petunjuk kepadaku.") Maha Tinggi Allah yang telah memberiku petunjuk kepada keesaan-Nya. (Dan aku tidak takut kepada apa yang kamu persekutukan) dia (dengan Allah) yakni berhala-berhala tersebut; mereka tidak akan dapat menimpakan malapetaka terhadap diriku, sebab mereka tidak mempunyai kekuatan apa-apa (kecuali) melainkan (di kala Tuhanku menghendaki sesuatu dari malapetaka itu) jika Dia hendak menimpakan malapetaka kepadaku, maka hal itu pasti terjadi (Pengetahuan Tuhanku meliputi segala sesuatu). (Maka apakah kamu tidak dapat mengambil pelajaran?) daripadanya kemudian kamu mau beriman.\qt@no{80}}%
\qt@newcmd\qurantrans@id@dccclxx{%
(Bagaimana aku takut dengan sesembahan-sesembahan yang kamu persekutukan) dengan Allah sedangkan mereka sama sekali tidak dapat mendatangkan malapetaka dan tidak pula kemanfaatan (padahal kamu tidak takut) kepada Allah (bahwasanya kamu sendiri mempersekutukan Allah) dalam ibadah kamu (dengan sesembahan-sesembahan yang Allah sendiri tidak menurunkan tentangnya) dalam hal menyembahnya (atas kamu suatu hujah pun) untuk mempersekutukan-Nya; yakni suatu alasan dan bukti padahal Allah itu Maha Kuasa atas segala sesuatu. (Maka manakah di antara dua golongan itu yang lebih berhak mendapat keamanan) apakah kami ataukah kamu? (jika kamu mengetahui?) siapakah yang paling berhak untuk mendapatkan keamanan dari malapetaka itu? Yang dimaksud dengan kami adalah Nabi Ibrahim, maka dari itu mengikutlah kamu kepada Ibrahim. Allah berfirman:\qt@no{81}}%
\qt@newcmd\qurantrans@id@dccclxxi{%
(Orang-orang yang beriman dan tidak mencampur-adukkan) tidak mencampurkan (keimanan mereka dengan kelaliman) yakni kemusyrikan demikianlah menurut penafsiran yang tersebutkan di dalam hadis sahih Bukhari dan Muslim (mereka itulah orang-orang yang mendapat keamanan) dari siksaan (dan mereka itu adalah orang-orang yang mendapat petunjuk.)\qt@no{82}}%
\qt@newcmd\qurantrans@id@dccclxxii{%
(Dan itulah) menjadi mubtada lalu dijelaskan (hujah Kami) yang dijadikan sebagai hujah oleh Nabi Ibrahim untuk membuktikan keesaan Allah; yakni tenggelamnya bintang-bintang itu. Dan jumlah yang sesudahnya menjadi khabar dari tilka (yang Kami berikan kepada Ibrahim) yang Kami tunjukkan kepada Ibrahim sebagai hujah (untuk menghadapi kaumnya. Kami tinggikan siapa yang Kami kehendaki beberapa derajat) dengan dibaca idhafah dan juga dibaca tanwin, yakni dalam masalah ilmu dan hikmah. (Sesungguhnya Tuhanmu Maha Bijaksana) dalam mengatur ciptaan-Nya (lagi Maha Mengetahui) seluk-beluk makhluk-Nya.\qt@no{83}}%
\qt@newcmd\qurantrans@id@dccclxxiii{%
(Dan Kami telah menganugerahkan Ishak dan Yakub kepadanya) sebagai anaknya (kepada keduanya) kepada masing-masingnya (telah Kami beri petunjuk dan kepada Nuh sebelum itu telah Kami beri petunjuk) sebelum Ibrahim (dan kepada sebagian dari keturunannya) yakni keturunan Nabi Nuh (yaitu Daud dan Sulaiman) Sulaiman anak Daud (Ayub dan Yusuf) anak lelaki Yakub (Musa dan Harun. Demikianlah) seperti mereka yang telah Kami beri pahala (Kami memberi balasan kepada orang-orang yang berbuat baik.)\qt@no{84}}%
\qt@newcmd\qurantrans@id@dccclxxiv{%
(Dan Zakaria, Yahya) yakni anak lelakinya (Isa) anak lelaki Maryam; hal ini menunjukkan bahwa pengertian keturunan itu mencakup juga anak-anak lelaki dari anak perempuan (dan Ilyas) anak lelaki Nabi Harun saudara lelaki Nabi Musa. (Semuanya) mereka itu (termasuk orang-orang yang saleh).\qt@no{85}}%
\qt@newcmd\qurantrans@id@dccclxxv{%
(Dan Ismail) anak lelaki Nabi Ibrahim (Alyasa) huruf lam adalah tambahan, yakni Yasa' (Yunus dan Luth) anak laki-laki Nabi Harun saudara lelaki Nabi Ibrahim (masing-masing) dari mereka itu (Kami lebihkan derajatnya di atas umat manusia) dengan pangkat kenabian.\qt@no{86}}%
\qt@newcmd\qurantrans@id@dccclxxvi{%
(Dan Kami lebihkan pula derajat sebagian dari bapak-bapak mereka, keturunan mereka dan saudara-saudara mereka) diathafkan pada Lafal kullan atau nuuhan; dan makna min di sini menunjukkan littab'idh, sebab sebagian dari mereka ada yang tidak mempunyai anak, dan sebagian lainnya ada yang mempunyai anak hanya saja kafir. (Dan Kami memilih mereka) Kami menyeleksi mereka (dan Kami menunjuki mereka ke jalan yang lurus).\qt@no{87}}%
\qt@newcmd\qurantrans@id@dccclxxvii{%
(Itulah) agama yang mereka diberi petunjuk kepadanya (petunjuk Allah yang dengannya Dia memberi petunjuk kepada siapa yang dikehendaki-Nya di antara hamba-hamba-Nya. Seandainya mereka menyekutukan Allah) sebagai perumpamaan saja (niscaya lenyaplah dari mereka amalan yang telah mereka lakukan.)\qt@no{88}}%
\qt@newcmd\qurantrans@id@dccclxxviii{%
(Merekah itulah orang-orang yang telah Kami berikan kepada mereka kitab) yakni kitab-kitab (hukum) hikmah (dan kenabian. Jika berlaku ingkar terhadapnya) terhadap tiga hal itu (mereka itu) yaitu penduduk Mekah (maka sesungguhnya Kami akan menyerahkannya) Kami akan memasrahkannya (kepada kaum yang sekali-kali tidak akan mengingkarinya) mereka adalah kaum Muhajirin dan kaum Ansar.\qt@no{89}}%
\qt@newcmd\qurantrans@id@dccclxxix{%
(Mereka itulah orang-orang yang mendapat petunjuk) yaitu mereka yang mendapat hidayah (Allah, maka petunjuk mereka) jalan mereka seperti mentauhidkan Allah dan bersabar (ikutilah) dengan ha saktah baik dibaca wakaf maupun washal akan tetapi menurut suatu qiraat dibaca tanpa ha saktah jika dibaca washal/dibaca langsung (katakanlah) kepada penduduk Mekah ("Aku tidak meminta kepadamu dalam menyampaikannya) dimaksud menyampaikan Alquran (suatu upah pun.") yang kamu berikan upah itu kepadaku (tidak lain ia itu) Alquran itu (hanyalah peringatan) nasihat (untuk segala umat) mencakup umat manusia dan umat jin.\qt@no{90}}%
\qt@newcmd\qurantrans@id@dccclxxx{%
(Dan mereka tidak menghormati) orang-orang Yahudi itu (Allah dengan penghormatan yang semestinya) artinya mereka sama sekali tidak mengagungkan-Nya dengan pengagungan yang seharusnya, atau mereka tidak mengetahui-Nya dengan pengetahuan yang semestinya (di kala mereka mengatakan) kepada Nabi saw., yaitu sewaktu mereka mendebat Nabi saw. dalam masalah Alquran ("Allah tidak menurunkan sesuatu pun kepada manusia." Katakanlah,) kepada mereka ("Siapakah yang menurunkan kitab Taurat yang dibawa oleh Musa sebagai cahaya dan petunjuk bagi manusia, kamu jadikan kitab itu) dengan memakai ya dan ta pada tiga tempat (lembaran-lembaran kertas) kamu menuliskannya pada lembaran-lembaran kertas yang bercerai-berai (kamu perlihatkan sebagiannya) kamu tidak suka menampakkan kesemua isinya (dan kamu sembunyikan sebagian besarnya) sebagian besar dari apa yang terdapat di dalam kandungannya, seperti mengenai ciri-ciri Nabi Muhammad saw. (padahal telah diajarkan kepadamu) hai orang-orang Yahudi di dalam Alquran (apa yang kamu dan bapak-bapak kamu tidak mengetahuinya?") karena tidak terdapat di dalam kitab Taurat, maka hal itu membuat kamu ragu dan berselisih paham tentang Taurat antara sesamamu. (Katakanlah, ``Allahlah") yang menurunkannya; jika mereka tidak mengatakannya, maka tidak ada jawaban lain kecuali jawaban itu (kemudian biarkanlah mereka di dalam kesibukan mereka) dalam kebatilan mereka (bermain-main).\qt@no{91}}%
\qt@newcmd\qurantrans@id@dccclxxxi{%
(Dan ini) Alquran ini (adalah kitab yang Kami turunkan yang diberkahi; membenarkan kitab-kitab yang sebelumnya) yaitu kitab-kitab yang diturunkan sebelumnya (dan agar kamu memberi peringatan) dengan memakai ta dan ya diathafkan kepada makna kalimat sebelumnya, yang artinya, Kami menurunkan Alquran untuk diambil keberkahannya, dipercayai dan agar kamu memberi peringatan dengannya (kepada penduduk Umul Qura/Mekah dan orang-orang yang ada disekitarnya) yaitu penduduk kota Mekah dan umat lainnya (dan orang-orang yang beriman kepada adanya kehidupan akhirat tentu beriman kepadanya, dan mereka selalu memelihara salatnya) karena takut akan siksaan akhirat.\qt@no{92}}%
\qt@newcmd\qurantrans@id@dccclxxxii{%
(Dan siapakah) maksudnya tidak ada seorang pun (yang lebih lalim daripada orang yang membuat kedustaan terhadap Allah) dengan mengaku menjadi seorang nabi padahal tidak ada yang mengangkatnya menjadi nabi (atau yang berkata, ``Telah diwahyukan kepada saya," padahal tidak ada diwahyukan sesuatu pun kepadanya) ayat ini diturunkan berkenaan dengan sikap Musailamah si pendusta itu (dan) lebih aniaya daripada (orang yang berkata, ``Saya akan menurunkan seperti apa yang diturunkan Allah") mereka adalah orang-orang yang memperolok-olokkan Alquran; mereka mengatakan, bahwa andaikata kami suka niscaya kami pun dapat membuat kata-kata seperti Alquran (dan sekiranya engkau melihat) wahai Muhammad (tatkala orang-orang lalim) yang telah disebutkan tadi (berada dalam sekarat) yaitu sedang menghadapi kematiannya (yakni maut sedangkan para malaikat memukul dengan tangannya) kepada mereka seraya menyiksa lalu para malaikat itu berkata dengan kasar kepada mereka ("Keluarkanlah nyawamu,") kepada kami untuk kami cabut. (Di hari ini kamu dibalas dengan siksaan yang sangat menghinakan) sangat merendahkan (karena kamu selalu mengatakan terhadap Allah perkataan yang tidak benar) dengan mengaku menjadi nabi dan berpura-pura diberi wahyu padahal dusta (dan karena kamu selalu menyombongkan diri terhadap ayat-ayat-Nya) kamu merasa tinggi diri tidak mau beriman kepada ayat-ayat-Nya. Jawab dari huruf lau ialah: niscaya engkau akan melihat peristiwa yang mengerikan.\qt@no{93}}%
\qt@newcmd\qurantrans@id@dccclxxxiii{%
(Dan) dikatakan kepada mereka ketika dibangkitkan (sesungguhnya kamu datang kepada Kami sendiri-sendiri) dalam keadaan sendiri-sendiri, terpisah dari keluarga, harta benda dan anak (sebagaimana kamu Kami ciptakan pada mulanya) dalam keadaan telanjang bulat dan masih belum disunatkan (dan kamu tinggalkan apa yang telah Kami berikan kepadamu) apa-apa yang telah Kami anugerahkan kepadamu berupa harta benda (berada di belakangmu) di dunia tanpa ada pilihan lain bagimu. (Dan) dikatakan kepada mereka sebagai cemoohan (Kami tidak melihat besertamu pemberi syafaat kamu) berhala-berhala kamu (yang kamu anggap bahwa mereka di antara kamu) artinya yang berhak kamu sembah (sebagai sekutu-sekutu) Allah. (Sungguh telah terputuslah di antara kamu) pertalian kamu, artinya telah tercerai-berailah persatuanmu. Dan di dalam suatu qiraat dibaca nashab sebagai zharaf; yang artinya telah terputuslah pertalian antara kamu (dan telah lenyap) maksudnya telah hilang (daripada kamu apa yang dahulu kamu anggap) sewaktu hidup di dunia bahwa kamu mendapatkan syafaatnya.\qt@no{94}}%
\qt@newcmd\qurantrans@id@dccclxxxiv{%
(Sesungguhnya Allah menumbuhkan) menjadikan (butir) tunas tetumbuhan (dan biji) dari pohon kurma. (Dia mengeluarkan yang hidup dan yang mati) seperti manusia dan unggas yaitu berasal dari air mani dan telur (dan mengeluarkan yang mati) yakni air mani dan telur (dari yang hidup, yang demikian itu) artinya yang menumbuhkan dan yang mengeluarkan (ialah Allah, maka mengapa kamu masih berpaling) mengapa kamu masih berpaling juga dari keimanan padahal bukti-buktinya telah ada.\qt@no{95}}%
\qt@newcmd\qurantrans@id@dccclxxxv{%
(Dia menyingsingkan pagi) mashdar yang bermakna isim yakni subuh atau pagi hari; artinya Allahlah yang menyingsingkan sinar pagi, yaitu cahaya yang tampak di permulaan pagi hari mengusir kegelapan malam hari (dan menjadikan malam untuk beristirahat) waktu semua makhluk beristirahat dari kepenatannya (dan menjadikan matahari dan bulan) dibaca nashab diathafkan kepada Lafal lail secara makna (untuk perhitungan) untuk ukuran perhitungan waktu; atau dengan tanpa huruf ba atau hisaaban, maka menjadi hal bagi Lafal yang tersimpan. Artinya matahari dan bulan itu beredar menurut perhitungannya sebagaimana yang dijelaskan dalam ayat surah Ar-Rahman. (Itulah) yang telah tersebut itu (ketentuan Allah Yang Maha Perkasa) di dalam kerajaan-Nya (lagi Maha Mengetahui) seluk-beluk makhluk-Nya.\qt@no{96}}%
\qt@newcmd\qurantrans@id@dccclxxxvi{%
(Dan Dialah yang menjadikan bintang-bintang bagimu agar kamu menjadikannya sebagai petunjuk dalam kegelapan di darat dan di laut) sewaktu dalam perjalanan (sesungguhnya Kami telah menjelaskan) Kami telah terangkan (tanda-tanda) yang menunjukkan akan kekuasaan Kami (kepada orang-orang yang mengetahui) yakni orang-orang yang mau menggunakan akalnya.\qt@no{97}}%
\qt@newcmd\qurantrans@id@dccclxxxvii{%
(Dan Dialah yang menciptakan kamu) maksudnya yang mengadakan kamu (dari seorang diri) yaitu Nabi Adam (maka ada tempat tetap) bagimu di dalam rahim (dan tempat simpanan) bagimu di dalam tulang rusuk. Dalam suatu qiraat huruf qaf dibaca fatah; yang artinya tempat menetap kamu. (Sesungguhnya telah kami jelaskan tanda-tanda kebesaran Kami kepada orang-orang yang mengerti) tentang apa yang dikatakan kepada mereka.\qt@no{98}}%
\qt@newcmd\qurantrans@id@dccclxxxviii{%
(Dan Dialah yang menurunkan air hujan dari langit, lalu Kami tumbuhkan) dalam ayat ini terkandung iltifat dari orang yang ketiga menjadi pembicara (dengan air itu) yakni dengan air hujan itu (segala macam tumbuh-tumbuhan) yang dapat tumbuh (maka Kami keluarkan darinya) dari tumbuh-tumbuhan itu sesuatu (tanaman yang hijau) yang menghijau (Kami keluarkan darinya) dari tanaman yang menghijau itu (butir yang banyak) yang satu sama lainnya bersusun seperti bulir-bulir gandum dan sejenisnya (dan dari pohon kurma) menjadi khabar dan dijadikan sebagai mubdal minhu (yaitu dari mayangnya) yaitu dari pucuk pohonnya; dan mubtadanya ialah (keluar tangkai-tangkainya) tunas-tunas buahnya (yang mengurai) saling berdekatan antara yang satu dengan yang lainnya (dan) Kami tumbuhkan berkat air hujan itu (kebun-kebun) tanaman-tanaman (anggur, zaitun dan delima yang serupa) dedaunannya; menjadi hal (dan yang tidak serupa) buahnya (perhatikanlah) hai orang-orang yang diajak bicara dengan perhatian yang disertai pemikiran dan pertimbangan (buahnya) dengan dibaca fathah huruf tsa dan huruf mimnya, atau dibaca dhammah keduanya sebagai kata jamak dari tsamrah; perihalnya sama dengan kata syajaratun jamaknya syajarun, dan khasyabatun jamaknya khasyabun (di waktu pohonnya berbuah) pada awal munculnya buah; bagaimana keadaannya? (dan) kepada (kematangannya) artinya kemasakannya, yaitu apabila telah masak; bagaimana keadaannya. (Sesungguhnya yang demikian itu ada tanda-tanda) yang menunjukkan kepada kekuasaan Allah swt. dalam menghidupkan kembali yang telah mati dan lain sebagainya (bagi orang-orang yang beriman) mereka disebut secara khusus sebab hanya merekalah yang dapat memanfaatkan hal ini untuk keimanan mereka, berbeda dengan orang-orang kafir.\qt@no{99}}%
\qt@newcmd\qurantrans@id@dccclxxxix{%
(Dan mereka menjadikan di samping Allah) menjadi maf'ul tsani (sekutu-sekutu) menjadi maf'ul awal dan menjadi mubdal minhu (terdiri dari jin) yang mereka menaatinya dalam menyembah berhala-berhala (dan) padahal (Allahlah yang telah menciptakan mereka) lalu mengapa mereka menjadikannya sebagai sekutu-sekutu-Nya (dan mereka membohong) dengan dibaca takhfif dan tasydid; artinya mereka membuat-buat perkataan (bahwanya Allah mempunyai anak laki-laki dan perempuan, tanpa landasan ilmu pengetahuan) mereka telah mengatakan, bahwa Uzair adalah anak lelaki Allah, dan malaikat-malaikat itu adalah anak-anak perempuan Allah. (Maha Suci Allah) yakni sebagai ungkapan menyucikan-Nya (dan Maha Tinggi dari sifat-sifat yang mereka berikan) mengenai diri-Nya, yaitu mempunyai anak.\qt@no{100}}%
\qt@newcmd\qurantrans@id@dcccxc{%
(Dia Pencipta langit dan bumi) yang menciptakan keduanya tanpa ada contoh yang mendahuluinya. (Bagaimana) mengapa (Dia dikatakan mempunyai anak padahal Dia tidak mempunyai istri?) yakni teman hidup. (Dia menciptakan segala sesuatu) maksudnya Dialah yang menciptakan kesemuanya (dan Dia mengetahui segala sesuatu).\qt@no{101}}%
\qt@newcmd\qurantrans@id@dcccxci{%
(Demikian itu ialah Allah Tuhan kamu; tidak ada Tuhan selain Dia; pencipta segala sesuatu, maka sembahlah Dia) esakanlah Dia (dan Dia adalah pemelihara segala sesuatu) yang memelihara semuanya.\qt@no{102}}%
\qt@newcmd\qurantrans@id@dcccxcii{%
(Dia tidak dapat dicapai oleh penglihatan mata) artinya engkau tidak akan dapat melihat-Nya sebab hal ini hanya khusus untuk kaum mukminin kelak di akhirat sebagaimana yang diungkapkan dalam firman-Nya surah Al-Qiyamah ayat 22-23 yaitu, ``Wajah-wajah orang-orang mukmin pada hari itu berseri-seri. Kepada Tuhannya mereka melihat." Dijelaskan pula dalam hadis yang diriwayatkan oleh Bukhari dan Muslim yaitu, ``Sesungguhnya kamu itu akan melihat Tuhanmu kelak di akhirat sebagaimana kamu melihat bulan pada malam purnama." Ada penafsiran lain yang mengatakan, bahwa yang dimaksud ialah bahwa pandangan mata itu tidak akan dapat meliputi-Nya (sedangkan Dia dapat melihat segala yang kelihatan) yakni Dia dapat melihatnya sedangkan apa-apa yang terlihat itu tidak dapat melihat-Nya; dan tiada selain-Nya mempunyai sifat ini (dan Dialah Yang Maha Lembut) terhadap kekasih-kekasih-Nya (lagi Maha Waspada) terhadap mereka.\qt@no{103}}%
\qt@newcmd\qurantrans@id@dcccxciii{%
Katakanlah olehmu hai Muhammad kepada mereka (Sesungguhnya telah datang kepadamu bukti-bukti) hujah-hujah (dari Tuhanmu; maka siapa melihat) bukti-bukti kebenaran itu, lalu ia mau beriman kepadanya (maka manfaatnya bagi dirinya sendiri) sebab pahalanya dia sendirilah yang merasakannya sebagai imbalan dari maunya dia melihat bukti-bukti itu (dan siapa buta) tidak mau melihat kebenaran itu sehingga ia menjadi sesat (maka kemudaratannya kembali kepada dirinya) yakni malapetaka dari kesesatannya itu. (Dan aku, Muhammad, sekali-kali bukanlah pemeliharamu) yang selalu mengawasi amal perbuatanmu karena sesungguhnya aku ini hanyalah seorang pemberi peringatan.\qt@no{104}}%
\qt@newcmd\qurantrans@id@dcccxciv{%
(Demikianlah) sebagaimana yang telah Kami jelaskan di atas (Kami menjelaskan) Kami terangkan (ayat-ayat itu) agar mereka mau berpikir tentangnya (dan supaya mereka mengatakan) yaitu orang-orang musyrik mengenai akibat dari perkara ini ("Kamu telah mempelajari.") engkau telah mempelajari tentang ahli kitab; dan menurut qiraat lainnya ditafsirkan bahwa engkau telah mempelajari kitab-kitab orang-orang terdahulu kemudian engkau mendatangkan ayat-ayat ini berdasarkan sumber darinya (dan supaya Kami menjelaskan Alquran itu kepada orang-orang yang mengetahui).\qt@no{105}}%
\qt@newcmd\qurantrans@id@dcccxcv{%
(Ikutilah apa yang telah diwahyukan kepadamu dari Tuhanmu) yakni Alquran (tidak ada tuhan selain Dia dan berpalinglah dari orang-orang musyrik.)\qt@no{106}}%
\qt@newcmd\qurantrans@id@dcccxcvi{%
(Dan jika Allah menghendaki niscaya mereka tidak mempersekutukan-Nya. Dan Kami tidak menjadikan kamu pemelihara bagi mereka) sebagai pengawas yang oleh sebabnya engkau membalas mereka atas amal-amal yang mereka lakukan (dan kamu sekali-kali bukanlah pemelihara bagi mereka) yang oleh sebabnya engkau memaksa mereka untuk beriman. Ayat ini diturunkan sebelum adanya perintah untuk berperang.\qt@no{107}}%
\qt@newcmd\qurantrans@id@dcccxcvii{%
(Dan janganlah kamu memaki sesembahan-sesembahan yang mereka puja) yaitu berhala-berhala (selain Allah) yaitu berhala-berhala yang mereka sembah (karena mereka akan memaki Allah dengan melampaui batas) penuh dengan perasaan permusuhan dan kelaliman (tanpa pengetahuan) karena mereka tidak mengerti tentang Allah (Demikianlah) sebagaimana yang telah Kami jadikan sebagai perhiasan pada diri mereka yaitu amal perbuatan mereka (Kami jadikan setiap umat menganggap baik pekerjaan mereka) berupa pekerjaan yang baik dan pekerjaan yang buruk yang biasa mereka lakukan. (Kemudian kepada Tuhanlah mereka kembali) di akhirat kelak (lalu Dia memberikan kepada mereka apa yang dahulu mereka lakukan) kemudian Dia memberikan balasannya kepada mereka.\qt@no{108}}%
\qt@newcmd\qurantrans@id@dcccxcviii{%
(Mereka bersumpah) orang-orang kafir penduduk Mekah (dengan nama Allah dengan segala kesungguhan) dengan segala kesungguhan yang ada pada mereka dalam hal bersumpah (bahwa sungguh jika datang kepada mereka sesuatu mukjizat) sesuai dengan apa yang mereka minta (pastilah mereka beriman kepada mukjizat tersebut. Katakanlah) kepada mereka ("Sesungguhnya mukjizat-mukjizat itu hanya berada di sisi Allah.") Dialah yang akan menurunkan sesuai dengan apa yang dikehendaki-Nya karena sesungguhnya aku hanya seorang pemberi peringatan (dan apakah yang memberitahukan kepadamu) yang membuat kamu tentang keimanan mereka apabila mukjizat-mukjizat itu didatangkan; artinya kamu tidak akan mengetahui hal itu (bahwa apabila mukjizat itu datang mereka tidak akan beriman) berkat pengetahuan-Ku yang telah waspada sebelumnya. Dan menurut suatu qiraat memakai ta yakni tu`minuuna yang berarti khithab ayat ditujukan kepada orang-orang kafir. Menurut qiraat lainnya dibaca annahaa yang maknanya sinonim dengan Lafal la`alla atau menjadi ma'mul dari `amil sebelumnya.\qt@no{109}}%
\qt@newcmd\qurantrans@id@dcccxcix{%
(Dan Kami memalingkan hati mereka) Kami menyimpangkan hati mereka dari perkara yang hak sehingga mereka sama sekali tidak mengerti mengenai kebenaran (dan penglihatan mereka) dari perkara yang hak tersebut sehingga mereka tidak dapat melihatnya dan pula tidak mau beriman kepadanya (seperti mereka belum pernah beriman kepadanya) artinya kepada ayat-ayat yang telah diturunkan (pada permulaannya dan Kami biarkan mereka) Kami tinggalkan mereka (di dalam lewat batas mereka) yaitu kesesatan mereka (menggelimangkan dirinya) sehingga bolak-balik dalam keadaan bingung.\qt@no{110}}%
\qt@newcmd\qurantrans@id@cm{%
(Kalau sekiranya Kami turunkan malaikat kepada mereka, dan orang-orang yang telah mati berbicara dengan mereka) seperti apa yang telah mereka minta (dan Kami kumpulkan pula) Kami himpunkan pula (segala sesuatu ke hadapan mereka) dibaca dengan damah kedua huruf permulaannya, jamak dari Lafal qabiil yakni gelombang demi gelombang. Dibaca kasrah huruf qaf-nya serta dibaca fatah huruf ba-nya; artinya: secara terang-terangan sehingga mereka dapat menyaksikan kebenaranmu (niscaya mereka tidak juga akan beriman) karena hal itu telah diketahui oleh Allah sebelumnya (kecuali) melainkan (jika Allah menghendaki) mereka beriman, maka baru mereka dapat beriman (akan tetapi kebanyakan mereka tidak mengetahui) tentang hal itu.\qt@no{111}}%
\qt@newcmd\qurantrans@id@cmi{%
(Dan demikianlah Kami jadikan bagi tiap-tiap nabi itu musuh) sebagaimana Kami telah jadikan mereka sebagai musuh-musuhmu; kemudian pengertian musuh itu dijelaskan (yakni setan-setan) siluman-siluman (dari jenis manusia dan jin yang memberikan bisikan) yang menghembuskan godaan (antara yang sebagian kepada sebagian lainnya tentang perkataan-perkataan yang indah-indah) yang memulas warna kebatilan (untuk membujuk) umat manusia. (Jika Tuhanmu menghendaki, niscaya mereka tidak mengerjakannya) maksudnya bisikan-bisikan yang menyesatkan tadi (maka tinggalkanlah mereka) biarkanlah orang-orang kafir itu (dan apa yang mereka ada-adakan) berupa kekafiran dan lain-lainnya yang sudah menjadi watak mereka; ayat ini diturunkan sebelum turunnya ayat perintah untuk berperang.\qt@no{112}}%
\qt@newcmd\qurantrans@id@cmii{%
(Dan juga agar mau mendengar) diathafkan kepada Lafal ghuruuran; artinya agar mau cenderung (kepada bisikan itu) yakni godaan tersebut (hati kecil) hati sanubari (orang-orang yang tidak beriman kepada kehidupan akhirat dan agar mereka merasa senang kepadanya dan supaya mereka mau mengerjakan) (apa yang setan-setan itu kerjakan) yaitu berupa perbuatan-perbuatan dosa sehingga mereka mendapat siksaan karenanya.\qt@no{113}}%
\qt@newcmd\qurantrans@id@cmiii{%
Ayat ini diturunkan tatkala mereka meminta kepada Nabi saw. agar menjadikan seorang hakim yang melerai antara dia dan mereka; katakanlah: (Maka patutkah aku meminta kepada selain Allah) aku mencari (sebagai hakim) yang melerai antara aku dan kamu (padahal Dialah yang telah menurunkan Alkitab kepadamu) yakni Alquran (dengan terinci) di dalamnya terkandung penjelasan yang memisahkan antara perkara yang hak dengan perkara yang batil. (Orang-orang yang telah Kami datangkan kitab kepada mereka) yaitu kitab Taurat seperti Abdullah bin Salam dan teman-temannya (mereka mengetahui bahwa Alquran itu diturunkan) dengan dibaca takhfif dan dibaca tasydid (dari Tuhanmu dengan sebenarnya. Maka janganlah kamu sekali-kali termasuk orang-orang yang ragu-ragu) sehingga menjadi orang-orang yang bimbang terhadap Alquran. Yang dimaksud dengan pernyataan ini adalah sebagai bukti kepada orang-orang kafir bahwa sesungguhnya Alquran itu adalah benar.\qt@no{114}}%
\qt@newcmd\qurantrans@id@cmiv{%
(Dan telah sempurnalah kalimat Tuhanmu) yakni Alquran yang memuat hukum-hukum dan ancaman-ancaman (sebagai kalimat yang benar dan adil) menjadi tamyiz. (Tidak ada yang dapat mengubah-ubah kalimat-kalimat-Nya) baik dengan menguranginya atau menggantinya (dan Dialah Maha Mendengar) terhadap apa yang dikatakan olehnya (lagi Maha Mengetahui) tentang apa yang diperbuatnya.\qt@no{115}}%
\qt@newcmd\qurantrans@id@cmv{%
(Dan jika kamu menuruti kebanyakan orang-orang yang di muka bumi) yakni orang-orang kafir (niscaya mereka akan menyesatkanmu dari jalan Allah) yaitu agama-Nya (sama sekali) (mereka tidak akan mau mengikuti kecuali hanya pada prasangka belaka) dalam perdebatan mereka denganmu tentang masalah bangkai, yaitu di kala mereka berkata, ``Apa yang telah dibunuh oleh Allah lebih berhak untuk kamu makan daripada apa yang kamu bunuh sendiri." (dan sama sekali) tidak lain (mereka hanyalah berdusta) di dalam hal tersebut.\qt@no{116}}%
\qt@newcmd\qurantrans@id@cmvi{%
(Sesungguhnya Tuhanmu Dialah yang lebih mengetahui) Maha Mengetahui (tentang orang yang tersesat dari jalan-Nya dan Dia lebih mengetahui tentang orang-orang yang mendapat petunjuk) dengan demikian maka Dia memberikan balasan pahala kepada mereka masing-masing.\qt@no{117}}%
\qt@newcmd\qurantrans@id@cmvii{%
(Maka makanlah binatang-binatang yang halal yang disebutkan nama Allah atasnya) yang disembelih dengan menyebut nama-Nya (jika kamu beriman kepada ayat-ayat-Nya.)\qt@no{118}}%
\qt@newcmd\qurantrans@id@cmviii{%
(Mengapa kamu tidak mau memakan binatang-binatang yang halal yang disebut nama Allah atasnya) yaitu hewan-hewan sembelihan (padahal sesungguhnya Allah telah menjelaskan) boleh juga dibaca dengan bina maf`ul atau bina fa`il untuk kedua fi`ilnya (kepada kamu apa yang diharamkan-Nya atasmu) yang telah disebutkan di dalam ayat, ``Telah diharamkan atas kamu bangkai..." (Q.S. Al-Maidah 3) (kecuali apa yang terpaksa kamu harus memakannya) di antara apa yang diharamkan itu maka hal itu juga dihalalkan bagi kamu. Adapun maknanya ialah: tidak ada larangan bagi kamu untuk memakan apa-apa yang telah disebutkan itu; Allah telah menjelaskan kepadamu apa-apa yang diharamkan kamu memakannya, maka ini bukanlah termasuk yang itu. (Dan sesungguhnya kebanyakan dari manusia benar-benar hendak menyesatkan orang lain) dengan dibaca fatah atau damah huruf ya-nya (dengan hawa nafsu mereka) dengan apa yang disukai hawa nafsu mereka; di antaranya ialah menghalalkan bangkai dan lain-lainnya (tanpa pengetahuan) yang secara sengaja mereka melakukannya. (Sesungguhnya Tuhanmu Dialah yang lebih mengetahui orang-orang yang melampaui batas) artinya orang-orang yang melampaui batas perkara yang dihalalkan untuk melakukan hal-hal yang diharamkan.\qt@no{119}}%
\qt@newcmd\qurantrans@id@cmix{%
(Dan tinggalkanlah) berhentilah kamu dari melakukan (dosa yang tampak dan yang tersembunyi) maksudnya dosa yang terang-terangan dan dosa yang tersembunyi; dikatakan bahwa yang dimaksud adalah perbuatan zina; dan dikatakan lagi adalah semua perbuatan maksiat. (Sesungguhnya orang-orang yang mengerjakan dosa, kelak akan diberi pembalasan) pada hari kiamat (disebabkan apa yang telah mereka kerjakan) usahakan.\qt@no{120}}%
\qt@newcmd\qurantrans@id@cmx{%
(Dan janganlah kamu memakan binatang-binatang yang tidak disebut nama Allah) seumpamanya karena mati dengan sendirinya atau disembelih dengan menyebut asma selain-Nya terkecuali apa yang disembelih oleh orang muslim, sekali pun tidak menyebut nama-Nya sewaktu menyembelihnya baik secara sengaja atau pun karena lupa, maka sembelihannya tetap halal, demikianlah menurut pendapat Ibnu Abbas, yang kemudian dianut oleh Imam Syafii. (Sesungguhnya) memakan hewan-hewan yang diharamkan itu (adalah suatu kefasikan) keluar dari garis apa yang telah dihalalkan. (Sesungguhnya setan itu membisikkan) menghembuskan godaannya (kepada kawan-kawannya) yaitu kepada orang-orang kafir (agar mereka membantah kamu) di dalam masalah menghalalkan bangkai (dan jika kamu menuruti mereka) di dalam hal ini (sesungguhnya kamu tentulah menjadi orang-orang musyrik). Ayat berikut ini diturunkan berkenaan dengan Abu Jahal dan lain-lainnya.\qt@no{121}}%
\qt@newcmd\qurantrans@id@cmxi{%
(Dan apakah yang sudah mati) oleh sebab kekafirannya (kemudian dia Kami hidupkan) dengan hidayah (dan Kami berikan kepadanya cahaya yang terang yang dengan cahaya itu dia dapat berjalan di tengah-tengah masyarakat manusia) dia dapat pula melihat perkara yang benar berkat cahaya itu dan dapat membedakannya daripada yang lainnya; yang dimaksud adalah keimanan (serupa dengan orang yang keadaannya) Lafal mitsl adalah tambahan, yakni sebagaimana seseorang (yang keadaannya dalam gelap-gulita yang sekali-kali tidak dapat keluar darinya) dimaksud orang kafir; sebagai jawabannya ialah tentu saja tidak. (Demikianlah) sebagaimana orang-orang mukmin dihiasi dengan keimanan (orang-orang kafir pun dihiasi pula dengan apa yang telah mereka kerjakan) berupa kekafiran dan maksiat-maksiat.\qt@no{122}}%
\qt@newcmd\qurantrans@id@cmxii{%
(Dan demikianlah) sebagaimana yang telah Kami jadikan orang-orang fasik penduduk Mekah terdiri dari para pembesarnya (Kami adakan pada tiap-tiap negeri penjahat-penjahat yang terbesar agar mereka melakukan tipu daya dalam negeri itu) dengan cara menghalang-halangi jalan keimanan (Dan mereka tidak memperdayakan melainkan dirinya sendiri) sebab akibat perbuatannya menimpa diri mereka sendiri (sedangkan mereka tidak menyadarinya) tentang hal tersebut.\qt@no{123}}%
\qt@newcmd\qurantrans@id@cmxiii{%
(Dan apabila datang kepada mereka) kepada penduduk Mekah (satu ayat) yang membenarkan Nabi saw. (mereka berkata, ``Kami tidak akan beriman) kepadanya (sehingga diberikan kepada kami yang serupa dengan apa yang telah diberikan kepada utusan-utusan Allah.") berupa risalah dan wahyu kepada kami sebab kami adalah yang terbanyak hartanya dan yang paling tua umurnya lalu Allah swt. berfirman: (Allah lebih mengetahui di mana Dia menempatkan tugas kerasulan-Nya) dengan dibaca jamak dan tunggal dan Lafal haitsu menjadi maf`ul bihi dari fi`il yang ditunjuk oleh Lafal a`lamu. Artinya Allah mengetahui tempat yang layak untuk meletakkan risalah-Nya lalu Ia meletakkannya. Sedangkan mereka itu bukanlah orang-orang yang pantas untuk mengemban tugas risalah ini (orang-orang yang berdosa nanti akan ditimpa) sebab perkataan mereka itu (suatu kehinaan) yakni menjadi rendah (di sisi Allah dan siksa yang keras disebabkan mereka lalu membuat tipu daya) oleh tipu daya mereka sendiri.\qt@no{124}}%
\qt@newcmd\qurantrans@id@cmxiv{%
(Siapa yang Allah menghendaki akan memberikan kepadanya petunjuk niscaya Dia melapangkan dadanya untuk memeluk agama Islam) dengan cara menyinarkan nur hidayah ke dalam dadanya sehingga dengan sadar ia mau menerima Islam dan mau membuka dadanya lebar-lebar untuk menerimanya. Demikianlah sebagaimana yang telah disebutkan dalam suatu hadis. (Dan siapa yang dikehendaki) Allah (kesesatannya niscaya Allah menjadikan dadanya sesak) dengan dibaca takhfif dan tasydid yakni merasa sempit untuk menerimanya (lagi sempit) terasa amat sempit; dengan dibaca kasrah huruf ra-nya menjadi sifat dan dibaca fathah sebagai mashdar yang diberi sifat dengan makna mubalaghah (seolah-olah ia sedang mendaki) menurut suatu qiraat dibaca yashsha`adu di dalam kedua bacaan tersebut berarti mengidgamkan ta asal ke dalam huruf shad. Menurut qiraat lainnya dengan dibaca sukun huruf shad-nya (ke langit) apabila iman dipaksakan kepadanya karena hal itu terasa berat sekali baginya. (Begitulah) sebagaimana kejadian itu (Allah menimpakan siksa) yakni azab atau setan, dengan pengertian azab atau setan itu menguasainya (kepada orang-orang yang tidak beriman).\qt@no{125}}%
\qt@newcmd\qurantrans@id@cmxv{%
(Dan inilah) apa yang engkau berada di dalamnya hai Muhammad! (jalan) titian (Tuhanmu yang lurus) tidak ada liku-likunya; Lafal mustaqiiman dibaca nashab menjadi hal yang mengukuhkan jumlah, sedangkan yang menjadi `amilnya adalah makna isyarah. (Sesungguhnya Kami telah menjelaskan) Kami telah menerangkan (ayat-ayat Kami kepada orang-orang yang mengambil pelajaran) Lafal yadzdzakkaruun dengan mengidgamkan huruf ta tambahan ke dalam huruf dzal asal; maknanya orang-orang yang mau mengambil sebagai pelajaran. Mereka disebutkan secara khusus sebab merekalah orang-orang yang mengambil manfaat darinya.\qt@no{126}}%
\qt@newcmd\qurantrans@id@cmxvi{%
(Bagi mereka disediakan Darussalam) yakni rumah keselamatan atau surga (pada sisi Tuhannya dan Dialah Pelindung mereka disebabkan amal-amal saleh yang selalu mereka kerjakan).\qt@no{127}}%
\qt@newcmd\qurantrans@id@cmxvii{%
(Dan) ingatlah (hari di waktu Kami menghimpun mereka semuanya) dengan memakai nun dan ya; artinya Allahlah yang menghimpun semua makhluk kemudian diserukan kepada mereka ("Hai golongan jin/setan! Sesungguhnya kamu telah banyak menyesatkan manusia,") dengan cara kamu menyesatkan mereka (lalu berkatalah kawan-kawan mereka) yaitu mereka yang mau menaatinya (dari kalangan manusia, ``Ya Tuhan kami, sesungguhnya sebagian daripada kami telah dapat kesenangan dari sebagian yang lainnya) manusia telah mengambil manfaat melalui jin yang menghiasi keinginan-keinginan nafsu syahwat mereka, dan demikian pula jin pun mengambil manfaat dari manusia melalui ketaatan manusia kepada mereka (dan kami telah sampai kepada waktu yang telah Engkau tentukan bagi kami") yakni hari kiamat; hal ini adalah merupakan ungkapan kekecewaan mereka (Allah berfirman) Maha Tinggi Allah, kepada mereka melalui lisan para malaikat-Nya ("Neraka itulah tempat kamu) tempat diam kamu (sedangkan kamu kekal di dalamnya, kecuali kalau Allah menghendaki yang lain.") batas-batas waktu tertentu di mana mereka dapat dikeluarkan dari neraka, untuk meminum hamim/keringat ahli neraka yang berada di luar neraka, demikianlah seperti apa yang dikatakan dalam firman-Nya, ``Kemudian sesungguhnya tempat kembali mereka benar-benar ke neraka Jahim," surah Ash-Shaffaat. Dan telah diriwayatkan dari Ibnu Abbas bahwasanya ayat ini diturunkan berkenaan dengan orang-orang yang telah diketahui Allah bahwa mereka orang-orang yang beriman. Dengan demikian berarti Lafal maa bermakna man. (Sesungguhnya Tuhanmu Maha Bijaksana) di dalam mengatur ciptaan-Nya (lagi Maha Mengetahui) tentang makhluk-makhluk-Nya.\qt@no{128}}%
\qt@newcmd\qurantrans@id@cmxviii{%
(Dan demikianlah) sebagaimana yang telah Kami berikan nikmat kepada orang-orang yang maksiat dari golongan manusia dan jin sebagian mereka melalui sebagian lainnya (Kami jadikan berteman) saling bantu-membantu (sebagian orang-orang yang lalim itu dengan sebagian lainnya) atas sebagian lainnya (disebabkan apa yang mereka usahakan) berupa perbuatan-perbuatan maksiat.\qt@no{129}}%
\qt@newcmd\qurantrans@id@cmxix{%
(Hai golongan jin dan manusia, apakah belum datang kepadamu rasul-rasul dari golongan kamu sendiri) kalangan kamu sendiri; artinya sebagian kamu yang percaya kepada manusia atau utusan-utusan jin yang sengaja Kami biarkan mereka mendengar ucapan-ucapan para rasul Kami kemudian mereka menyampaikannya kepada kaumnya (yang menceritakan kepada kamu tentang ayat-ayat-Ku dan memperingatkan kamu tentang pertemuanmu dengan hari ini? Mereka berkata, ``Kami menjadi saksi atas diri kami sendiri.") bahwa sesungguhnya kami telah menerimanya. Allah swt. berfirman: (Kehidupan dunia telah menipu mereka) sehingga mereka tidak mau beriman (dan mereka menjadi saksi atas diri mereka sendiri bahwa mereka adalah orang-orang yang kafir.)\qt@no{130}}%
\qt@newcmd\qurantrans@id@cmxx{%
(Yang demikian itu) dengan mengutus para utusan (supaya) huruf lam dimuqaddarahkan sedangkan an berasal dari anna yang ditakhfifkan; yaitu berasal dari liannahu (Tuhanmu tidak membinasakan kota-kota secara aniaya) sebagian dari kota-kota itu (sedangkan penduduknya dalam keadaan lengah) dan belum pernah diutus kepada mereka seorang rasul pun yang memberikan penjelasan kepada mereka.\qt@no{131}}%
\qt@newcmd\qurantrans@id@cmxxi{%
(Dan masing-masing) dari kalangan orang-orang itu (memperoleh derajat-derajat) pembalasan (sesuai dengan apa yang telah dikerjakannya) berupa pembalasan yang baik dan pembalasan yang buruk (Dan Tuhanmu tidak lengah dari apa yang mereka kerjakan) dengan memakai ya dan ta.\qt@no{132}}%
\qt@newcmd\qurantrans@id@cmxxii{%
(Dan Tuhanmu Maha Kaya) tidak membutuhkan makhluk-Nya dan juga tidak membutuhkan ibadah mereka (lagi mempunyai rahmat. Jika Dia menghendaki niscaya Dia memusnahkan kamu) hai penduduk Mekah yakni membinasakan kalian (dan menggantimu dengan siapa yang dikehendaki-Nya setelah kamu musnah) di antara makhluk-Nya (sebagaimana Dia telah menjadikan kamu dari keturunan orang-orang lain) yang telah Dia memusnahkan akan tetapi Dia tetap membiarkan kamu sebagai rahmat atas kamu sekalian.\qt@no{133}}%
\qt@newcmd\qurantrans@id@cmxxiii{%
(Sesungguhnya apa yang dijanjikan kepadamu) pada hari kiamat dan azab (pasti datang) tidak dapat ditawar-tawar lagi (dan kamu sekali-kali tidak sanggup menolaknya) tidak bisa selamat dari azab Kami.\qt@no{134}}%
\qt@newcmd\qurantrans@id@cmxxiv{%
(Katakanlah) kepada mereka ("Hai kaumku! Berbuatlah sepenuh kemampuanmu) sesuai dengan keadaanmu (sesungguhnya aku pun berbuat pula) sesuai dengan keadaanku. (Kelak kamu akan mengetahui siapakah di antara kita) man menjadi maushul dan menjadi maf`ul dari Lafal al-`ilm (yang akan memperoleh hasil yang baik dari dunia ini.") akibat yang dipuji di akhirat nanti, apakah kami atau kamu? (Sesungguhnya tidak akan mendapat keberuntungan) kebahagiaan (orang-orang yang lalim itu) yaitu orang-orang kafir.\qt@no{135}}%
\qt@newcmd\qurantrans@id@cmxxv{%
(Dan mereka memperuntukkan) orang-orang kafir Mekah (bagi Allah satu bagian dari apa yang telah diciptakan)-Nya (yaitu berupa tanaman) hasil lahan (dan ternak sebagai bagian) yang mereka infakkan untuk tamu-tamu dan orang-orang miskin dan juga satu bagian lainnya untuk sesembahan-sesembahan mereka yang mereka berikan kepada para juru kuncinya (lalu mereka berkata sesuai dengan prasangka mereka, ``Ini untuk Allah) dengan dibaca fatah dan damah huruf zai-nya (dan ini untuk berhala-berhala kami.") maksudnya apabila ada sesuatu yang terjatuh dari bagian untuk sesembahan mereka, mereka berani mengambilnya kembali. Tetapi apabila ada sesuatu yang terjatuh, dari bagian untuk Allah mereka membiarkannya kemudian mereka berkata, ``Sesungguhnya Allah tidak membutuhkan ini." Demikianlah sebagaimana yang diungkapkan dalam firman-Nya berikut ini: (Maka sajian-sajian yang diperuntukkan bagi berhala-berhala mereka tidak sampai kepada Allah) (dan sajian-sajian yang diperuntukkan bagi Allah, maka sajian itu sampai kepada berhala-berhala mereka. Amat buruklah) amat jeleklah (apa yang mereka tetapkan) yakni keputusan hukum mereka itu.\qt@no{136}}%
\qt@newcmd\qurantrans@id@cmxxvi{%
(Dan demikianlah) sebagaimana telah menjadi kebiasaan mereka apa-apa yang telah disebutkan itu (telah menghiasi kebanyakan orang-orang musyrik memandang baik membunuh anak-anak mereka) dengan cara mengubur mereka hidup-hidup (karena hasutan sesembahan-sesembahan mereka) yang terdiri dari makhluk jin. Dengan dibaca rafa' sebagai fa'il dari fi'il zayyana; dan menurut suatu qiraat dengan dibaca bina maf'ul serta Lafal qatla dibaca rafa', dan dibaca nashab Lafal al-awlaad, berdasarkan bacaan ini Lafal syurakaaihim dibaca jar dengan mengidhafatkannya kepada Lafal al-qatlu; dengan demikian berarti ada fashal/pemisah antara mudhaf dan mudhaf ilaih yang dipisahkan oleh maf'ul, hal ini tidak mengapa, sebab mengidhafatkan Lafal al-qatlu kepada Lafal syurakaa karena merekalah pada hakikatnya yang melakukannya melalui bujukan mereka (untuk membinasakan mereka) untuk memusnahkan mereka (dan untuk mengaburkan) dengan mencampur-adukkan (bagi mereka agamanya. Dan kalau Allah menghendaki niscaya mereka tidak mengerjakannya, maka tinggalkanlah mereka dan apa yang mereka ada-adakan).\qt@no{137}}%
\qt@newcmd\qurantrans@id@cmxxvii{%
(Dan mereka mengatakan, ``Inilah binatang ternak dan tanaman yang dilarang) yang diharamkan (tidak boleh memakannya kecuali orang yang kami kehendaki") yaitu para pelayan berhala-berhala dan lain-lainnya (menurut anggapan mereka) artinya mereka tidak punya alasan lagi dalam masalah ini (dan ada binatang ternak yang diharamkan menungganginya) maka ternak-ternak itu tidak boleh dinaiki, seperti hewan sawaib dan hewan hawami (dan binatang ternak yang mereka tidak menyebut nama Allah atasnya) di kala menyembelihnya melainkan menyebut nama berhala-berhala mereka kemudian mengaitkan hal itu kepada Allah (semata-mata membuat-buat kedustaan terhadap Allah. Kelak Allah akan membalas mereka terhadap apa yang selalu mereka ada-adakan) sebagai balasannya.\qt@no{138}}%
\qt@newcmd\qurantrans@id@cmxxviii{%
(Dan mereka mengatakan, ``Apa yang dalam perut binatang ini) yaitu ternak yang diharamkan untuk dimakan seperti ternak sawaib dan ternak bahair (adalah khusus) dihalalkan (untuk pria kami dan diharamkan atas wanita kami") yakni haram untuk perempuan-perempuan kami (dan jika yang dalam perut itu dilahirkan mati) dengan dibaca rafa` dan nashab serta fi`il dita`nitskan atau ditadzkirkan (maka pria dan wanita sama-sama boleh memakannya. Kelak akan membalas mereka) yakni Allah (terhadap ketetapan mereka) berupa pembelaan azab atas penghalalan dan pengharaman ini (Sesungguhnya Allah Maha Bijaksana) dalam ciptaan-Nya (lagi Maha Mengetahui) tentang makhluk-Nya.\qt@no{139}}%
\qt@newcmd\qurantrans@id@cmxxix{%
(Sesungguhnya rugilah orang-orang yang membunuh) dengan dibaca takhfif dan tasydid (anak-anak mereka) dengan mengubur mereka hidup-hidup (karena kebodohan) karena ketidakmengertian mereka (lagi tidak mengetahui dan mereka mengharamkan apa yang Allah telah memberi rezeki kepada mereka) yaitu apa-apa yang telah disebutkan (dengan semata-mata mengada-adakan terhadap Allah. Sesungguhnya mereka telah sesat dan tidaklah mereka mendapat petunjuk.)\qt@no{140}}%
\qt@newcmd\qurantrans@id@cmxxx{%
(Dan Dialah yang menjadikan) yang telah menciptakan (kebun-kebun) yang mendatar di permukaan tanah, seperti tanaman semangka (dan yang tidak terhampar) yang berdiri tegak di atas pohon seperti pohon kurma (dan) Dia menjadikan (pohon kurma dan tanaman-tanaman yang bermacam-macam buahnya) yakni yang berbeda-beda buah dan bijinya baik bentuk maupun rasanya (dan zaitun dan delima yang serupa) dedaunannya; menjadi hal (dan tidak sama) rasa keduanya (Makanlah dari buahnya yang bermacam-macam itu bila dia berbuah) sebelum masak betul (dan tunaikanlah haknya di hari memetik hasilnya) dengan dibaca fatah atau kasrah; yaitu sepersepuluhnya atau setengahnya (dan janganlah kamu berlebih-lebihan) dengan memberikannya semua tanpa sisa sedikit pun buat orang-orang tanggunganmu. (Sesungguhnya Allah tidak menyukai orang-orang yang berlebih-lebihan) yaitu orang-orang yang melampaui batas hal-hal yang telah ditentukan bagi mereka.\qt@no{141}}%
\qt@newcmd\qurantrans@id@cmxxxi{%
(Dan) Dia menjadikan (di antara binatang ternak itu sebagai kendaraan angkutan) yaitu layak untuk mengangkut barang-barang, seperti unta yang sudah dewasa (dan sebagai binatang sembelihan) yang tak layak untuk dijadikan angkutan, seperti unta yang masih muda dan kambing. Ia dinamakan farsy/hamparan karena ia mirip dengan hamparan tanah mengingat ia sangat dekat dengannya. (Makanlah dari rezeki yang telah diberikan Allah kepadamu dan janganlah kamu mengikuti langkah-langkah setan) jalan setan di dalam masalah pengharaman dan penghalalan. (Sesungguhnya setan itu musuh yang nyata bagimu) yang jelas permusuhannya.\qt@no{142}}%
\qt@newcmd\qurantrans@id@cmxxxii{%
(Yaitu delapan binatang yang berpasangan) yang bermacam-macam, menjadi badal dari Lafal humuulah dan farasy (dari domba) yang sejodoh (sepasang) jantan dan betina (dan dari kambing) dibaca fathah atau sukun (sepasang. Katakanlah) hai Muhammad, terhadap orang yang terkadang mengharamkan binatang jantan dan terkadang mengharamkan binatang betina kemudian ia mengaitkan hal itu kepada Allah ("Apakah dua yang jantan) baik dari kambing maupun dari domba (diharamkan) Allah atas kamu (ataukah dua yang betina) dari kedua jenis ternak itu (ataukah yang ada dalam kandungan dua betinanya?") baik jantan atau pun betina. (Terangkanlah kepadaku dengan berdasar pengetahuan) tentang cara pengharaman hal itu (jika kamu memang orang-orang yang benar) di dalam ayat ini terkandung makna sebagai berikut: dari manakah datangnya pengharaman itu? Apabila dari pihak jantan, maka semua binatang yang jantan berarti haram; atau bila dari pihak betina, maka berarti semua binatang betina haram hukumnya dan demikian pula binatang-binatang yang masih berada di dalam rahimnya maka berarti kedua jenis itu diharamkan. Lalu dari manakah adanya pengecualian ini sedangkan kata tanya menunjukkan makna ingkar.\qt@no{143}}%
\qt@newcmd\qurantrans@id@cmxxxiii{%
(Dan dari sepasang unta dan dari sepasang lembu, katakanlah, ``Apakah dua yang jantan yang diharamkan ataukah dua yang betina, ataukah yang ada di dalam kandungan dua betinanya. Apakah) bahkan (kamu menyaksikan) hadir (di waktu Allah menetapkan ini bagimu?) tentang pengharaman ini kemudian sengaja kamu menyatakan hal ini, tidak, bahkan kamu adalah orang-orang yang dusta dalam hal ini. (Maka siapakah) tak ada seorang pun (yang lebih lalim daripada orang-orang yang membuat-buat dusta terhadap Allah) dalam hal itu (untuk menyesatkan manusia tanpa pengetahuan?" Sesungguhnya Allah tidak memberi petunjuk kepada orang-orang yang lalim.)\qt@no{144}}%
\qt@newcmd\qurantrans@id@cmxxxiv{%
(Katakanlah, ``Tiadalah aku peroleh dalam wahyu yang diwahyukan kepadaku) tentang sesuatu (yang diharamkan bagi orang yang hendak memakannya kecuali kalau yang dimakan itu) dengan memakai ya dan ta (bangkai) dengan dibaca nashab dan menurut suatu qiraat dibaca rafa` serta tahtaniyyah (atau darah yang mengalir) yang beredar berbeda dengan darah yang tidak mengalir seperti hati dan limpa (atau daging babi karena sesungguhnya semua itu kotor) haram (atau) kecuali jika hewan itu (binatang yang disembelih atas nama selain Allah) yakni hewan yang dipotong dengan menyebut nama selain nama Allah. (Siapa yang dalam keadaan terpaksa) menghadapi semua yang telah disebutkan sehingga ia memakannya (sedangkan ia tidak menginginkannya dan tidak pula melampaui batas, maka sesungguhnya Tuhanmu Maha Pengampun) kepadanya atas apa yang telah dimakannya (lagi Maha Penyayang.") terhadapnya. Kemudian apa yang telah disebutkan itu dilengkapi dengan sebuah hadis yang menambahkan yaitu setiap hewan yang bertaring dan setiap burung yang berkuku tajam.\qt@no{145}}%
\qt@newcmd\qurantrans@id@cmxxxv{%
(Dan kepada orang-orang Yahudi) yaitu pemeluk agama Yahudi (Kami haramkan segala binatang yang berkuku) maksudnya hewan yang jari-jari kakinya tidak terpisah-pisah seperti unta dan burung unta (dan dari sapi dan domba, Kami haramkan atas mereka lemak dari kedua binatang) yaitu lemak perut dan lemak pantat (kecuali lemak yang melekat di punggung keduanya) lemak yang menggantung pada punggungnya (atau) yang menempel (di perut besar) yang ada di lambung, kata jamak dari haawiyaa atau haawiyah (atau yang bercampur dengan tulang) lemak yang menempel di tulang, maka jenis lemak ini dihalalkan untuk mereka. (Demikianlah) masalah pengharaman ini (Kami hukum mereka) sebagai balasan (atas kedurhakaan mereka) oleh sebab kelaliman mereka sendiri sebagaimana yang telah disebutkan dalam surah An-Nisa (dan sesungguhnya Kami adalah Maha Benar) di dalam berita-berita Kami dan janji-janji Kami.\qt@no{146}}%
\qt@newcmd\qurantrans@id@cmxxxvi{%
(Maka jika mereka mendustakan kamu) mengenai apa yang engkau sampaikan (katakanlah,) kepada mereka ("Tuhanmu mempunyai rahmat yang luas) sehingga Dia tidak menyegerakan untuk menghukum kamu; di dalam ayat ini terkandung ajakan yang lembut untuk mereka kepada keimanan (dan siksa-Nya tidak dapat ditolak) yakni azab-Nya apabila datang (dari kaum yang berdosa.")\qt@no{147}}%
\qt@newcmd\qurantrans@id@cmxxxvii{%
(0rang-orang yang mempersekutukan Tuhan akan mengatakan, ``Jika Allah menghendaki niscaya kami tidak mempersekutukan-Nya) (dan juga bapak-bapak kami dan tidak pula kami mengharamkan sesuatu apa pun.") kemusyrikan kami dan pengharaman kami adalah berdasarkan kehendak-Nya, Dia rela dengan ketentuan itu. Allah berfirman: (Demikian pulalah) sebagaimana mereka telah mendustakan (orang-orang yang sebelum mereka telah mendustakan) para utusan mereka (sampai mereka merasakan siksaan Kami) azab Kami (Katakanlah, ``Adakah kamu mempunyai sesuatu pengetahuan) bahwa Allah telah rela dengan hal itu (sehingga dapat kamu mengemukakannya kepada Kami?") pasti kamu tidak mempunyai pengetahuan tentang hal ini. (Tidak) tiadakan (kamu mengikuti) dalam hal ini (kecuali hanya dugaan belaka dan tidak lain) tiada lain (kamu hanya berdusta) hanya membual.\qt@no{148}}%
\qt@newcmd\qurantrans@id@cmxxxviii{%
(Katakanlah) apabila kamu tidak mempunyai hujah ("Allah mempunyai hujah yang jelas lagi kuat) yang sempurna (maka jika Dia menghendaki) memberikan hidayah kepadamu (pasti Dia memberi hidayah kepada kamu semuanya.")\qt@no{149}}%
\qt@newcmd\qurantrans@id@cmxxxix{%
(Katakanlah, ``Bawalah ke mari) datangkanlah (saksi-saksi kamu yang dapat mempersaksikan bahwasanya Allah telah mengharamkan ini") yaitu makanan yang kamu haramkan. (Jika mereka mempersaksikan, maka janganlah kamu ikut pula menjadi saksi bersama mereka dan janganlah kamu mengikuti hawa nafsu orang-orang yang mendustakan ayat-ayat Kami dan orang-orang yang tidak beriman kepada kehidupan akhirat sedangkan mereka mempersekutukan Tuhan mereka) berlaku musyrik terhadap-Nya.\qt@no{150}}%
\qt@newcmd\qurantrans@id@cmxl{%
(Katakanlah, ``Marilah kubacakan yang diharamkan atas kamu oleh Tuhanmu, yaitu) an bermakna menafsirkan (janganlah kamu mempersekutukan sesuatu dengan Dia dan) berbuat baiklah (terhadap kedua orang tua sebaik-baiknya dan janganlah kamu membunuh anak-anak kamu) dengan menguburkan hidup-hidup (karena) sebab (takut kemiskinan) kemelaratan yang kamu khawatirkan (Kami akan memberi rezeki kepadamu dan kepada mereka dan janganlah kamu mendekati perbuatan-perbuatan yang keji) dosa-dosa besar seperti perbuatan zina (baik yang tampak di antaranya maupun yang tersembunyi) yang kelihatan dan yang tidak kelihatan. (Dan janganlah kamu membunuh jiwa yang diharamkan Allah membunuhnya kecuali dengan sesuatu sebab yang benar.") yaitu seperti hukum kisas dan hudud murtad serta rajam bagi yang pezina muhshan. (Demikian itu) apa yang telah disebutkan itu (adalah yang diperintahkan oleh Tuhanmu kepadamu supaya kamu memahaminya) supaya kamu memikirkannya.\qt@no{151}}%
\qt@newcmd\qurantrans@id@cmxli{%
(Dan janganlah kamu dekati harta anak yatim kecuali dengan cara) dengan sikap yang (lebih baik) yaitu cara yang di dalamnya mengandung kemaslahatan/manfaat bagi anak yatim hingga ia dewasa) seumpamanya dia sudah balig. (Dan sempurnakanlah takaran dan timbangan dengan adil) secara adil dan tidak curang. (Kami tidak memikulkan beban kepada seseorang melainkan sekadar kesanggupannya) sesuai dengan kemampuannya dalam hal ini; apabila ia berbuat kekeliruan di dalam menakar atau menimbang sesuatu, maka Allah mengetahui kebenaran niat yang sesungguhnya, oleh karena itu maka ia tidak berdosa, sebagaimana yang telah disebutkan dalam hadis Nabi saw. (Dan apabila kamu berkata) dalam masalah hukum atau lainnya (maka hendaklah kamu berlaku adil) jujur (kendatipun dia) orang yang bersangkutan (adalah kerabatmu) famili (dan penuhilah janji Allah. Yang demikian itu diperintahkan Allah kepadamu agar kamu ingat) dengan memakai tasydid agar menjadikannya sebagai pelajaran; dan juga dibaca dengan sukun.\qt@no{152}}%
\qt@newcmd\qurantrans@id@cmxlii{%
(Dan bahwa) dengan memakai harakat fatah mentakdirkan lam, dan dengan memakai harakat kasrah sebagai jumlah isti'naf/permulaan (hal ini) apa yang Kami pesankan kepada kamu (adalah jalan-Ku yang lurus) menjadi hal (maka ikutilah dia; dan janganlah kamu mengikuti jalan-jalan) cara-cara yang bertentangan dengannya (karena jalan itu mencerai-beraikan) dengan membuang salah satu di antara dua huruf ta, yakni akan menyelewengkan (kamu dari jalan-Nya) agama-Nya (yang demikian itu diperintahkan Allah kepadamu agar kamu bertakwa.)\qt@no{153}}%
\qt@newcmd\qurantrans@id@cmxliii{%
(Kemudian Kami telah memberikan Alkitab kepada Musa) kitab Taurat; tsumma bermakna untuk tertibnya rentetan kisah (untuk menyempurnakan) nikmat (kepada orang-orang yang berbuat kebaikan) agar mengamalkan kandungan isinya (dan untuk menjelaskan) menerangkan (segala sesuatu) yang diperlukan dalam masalah agama (dan sebagai petunjuk dan rahmat agar mereka) kaum Bani Israel (terhadap hari pertemuan dengan Tuhan mereka) dengan dibangkitkannya mereka (mereka mau beriman.)\qt@no{154}}%
\qt@newcmd\qurantrans@id@cmxliv{%
(Dan ini) maksudnya Alquran ini (adalah kitab yang Kami turunkan yang diberkati, maka ikutilah dia) hai penduduk Mekah dengan mengamalkan apa yang dikandungnya (dan bertakwalah kamu) jangan melakukan kekafiran (agar kamu diberi rahmat) Kami turunkan dia yaitu Alquran.\qt@no{155}}%
\qt@newcmd\qurantrans@id@cmxlv{%
(Agar jangan) tidak (kamu mengatakan bahwa kitab itu hanya diturunkan kepada dua golongan saja) yaitu golongan Yahudi dan golongan Nasrani (sebelum kami dan sesungguhnya) ditakhfifkan dari innaa yang bertasydid sedangkan isimnya dibuang (kami terhadap pelajaran mereka) apa yang mereka baca (tidak memperhatikan) oleh sebab kami tidak mengerti tentangnya karena bukan bahasa kami.\qt@no{156}}%
\qt@newcmd\qurantrans@id@cmxlvi{%
(Atau agar kamu tidak mengatakan, ``Sesungguhnya jika kitab itu diturunkan kepada kami tentulah kami lebih mendapat petunjuk dari mereka.") oleh karena kebersihan hati kami. (Sesungguhnya telah datang kepada kamu keterangan yang nyata) yaitu penjelasan (dari Tuhanmu, petunjuk dan rahmat) bagi orang yang mengikutinya (maka siapakah) artinya tidak ada seorang pun (yang lebih lalim daripada orang yang mendustakan ayat-ayat Allah dan berpaling) memalingkan diri (daripadanya. Kelak Kami akan memberi balasan kepada orang-orang yang berpaling dari ayat-ayat Kami dengan siksaan yang buruk) siksaan yang paling keras (disebabkan mereka selalu berpaling.)\qt@no{157}}%
\qt@newcmd\qurantrans@id@cmxlvii{%
(Tiadalah yang mereka nantikan) apa yang mereka nanti-nanti (kecuali hanyalah datang kepada mereka) dapat dibaca ta`tiyahum atau ya`tiyahum (malaikat-malaikat) untuk mencabut arwah-arwah mereka (atau kedatangan Tuhanmu) yaitu perintah-Nya yang dimaksud adalah azab-Nya (atau kedatangan beberapa ayat Tuhanmu) tanda-tanda dari Tuhanmu yang menunjukkan dekatnya hari kiamat. (Pada hari datangnya beberapa ayat dari Tuhanmu) terbitnya matahari dari ufuk barat sebagaimana yang telah disebutkan di dalam hadis riwayat Bukhari dan Muslim (tidaklah bermanfaat lagi iman seseorang kepada dirinya sendiri yang belum beriman sebelum itu) jumlah lam takun menjadi sifat dari Lafal nafsan (atau) jiwa yang belum pernah (mengusahakan kebaikan dalam masa imannya) yakni ketaatan; artinya tobatnya tidak lagi bermanfaat bagi dirinya seperti apa yang telah dijelaskan oleh hadis. (Katakanlah, ``Tunggulah olehmu) salah satu dari alamat-alamat tersebut (sesungguhnya kami pun menunggu pula.") hal tersebut.\qt@no{158}}%
\qt@newcmd\qurantrans@id@cmxlviii{%
(Sesungguhnya orang-orang yang memecah belah agamanya) oleh sebab mereka bercerai-berai di dalamnya, yaitu mereka mengambil sebagian peraturannya dan meninggalkan sebagian lainnya (dan mereka menjadi berpuak-puak) menjadi bersekte-sekte dan masalah agama. Menurut suatu qiraat artinya mereka berpecah-belah dan meninggalkan agamanya yang harus mereka peluk, mereka adalah orang-orang Yahudi dan Nasrani (tidak ada sedikit pun tanggung jawabmu terhadap mereka) janganlah engkau menghalang-halangi mereka. (Sesungguhnya urusan mereka hanyalah terserah kepada Allah) Dialah yang mengurusnya (kemudian Allah memberitahukan kepada mereka) di akhirat kelak (apa yang telah mereka perbuat) Allah memberikan balasan kepada mereka. Ayat ini telah dinasakh dengan turunnya ayat saif/ayat yang memerintahkan berperang.\qt@no{159}}%
\qt@newcmd\qurantrans@id@cmxlix{%
(Siapa membawa amal yang baik) yakni zikir laa ilaaha illallaah/tidak ada tuhan selain Allah (maka baginya pahala sepuluh kali lipat amalnya) balasan pahalanya adalah sepuluh kali kebaikan (dan siapa membawa perbuatan yang jahat, maka dia tidak diberi pembalasan melainkan seimbang dengan kejahatannya) balasannya yang setimpal (sedang mereka sedikit pun tidak dianiaya atau dirugikan) dikurangi sesuatu dari pembalasan yang sebenarnya.\qt@no{160}}%
\qt@newcmd\qurantrans@id@cml{%
(Katakanlah, ``Sesungguhnya Aku telah ditunjuki oleh Tuhanku kepada jalan yang lurus) kemudian dijadikan badal (yaitu agama yang benar) agama yang lurus (agama Ibrahim yang lurus dan Ibrahim itu bukanlah termasuk orang-orang yang musyrik").\qt@no{161}}%
\qt@newcmd\qurantrans@id@cmli{%
(Katakanlah, ``Sesungguhnya salatku, ibadahku) amal ibadahku, yaitu ibadah haji dan lain-lainnya (hidupku) kehidupanku (dan matiku) meninggalku (hanyalah untuk Allah, Tuhan semesta alam).\qt@no{162}}%
\qt@newcmd\qurantrans@id@cmlii{%
(Tiada sekutu bagi-Nya) di dalam hal tersebut (dan demikian itulah) ketauhidan (yang diperintahkan kepadaku, dan aku adalah orang yang pertama-tama menyerahkan diri kepada Allah") dari kalangan umat ini.\qt@no{163}}%
\qt@newcmd\qurantrans@id@cmliii{%
(Katakanlah, ``Apakah aku akan mencari Tuhan selain Allah) sebagai sesembahan; artinya aku tidak mencari Tuhan selain-Nya (Dia adalah Tuhan) yang memiliki (segala sesuatu. Dan tidaklah seorang membuat dosa) berbuat dosa (melainkan kemudaratannya kembali kepada dirinya sendiri; dan seorang yang berdosa tidak akan memikul) maksudnya seseorang tidak akan memikul (dosa) perbuatan dosa (orang lain. Kemudian kepada Tuhanmulah kamu kembali dan akan diberitakannya kepadamu apa yang kamu perselisihkan.)\qt@no{164}}%
\qt@newcmd\qurantrans@id@cmliv{%
(Dan Dialah yang menjadikan kamu penguasa-penguasa di bumi) jamak dari kata khalifah; yakni sebagian di antara kamu mengganti sebagian lainnya di dalam masalah kekhalifahan ini (dan Dia meninggikan sebagian kamu atas sebagian yang lain beberapa derajat) dengan harta benda, kedudukan dan lain sebagainya (untuk mengujimu) untuk mencobamu (tentang apa yang diberikan kepadamu) artinya Dia memberi kamu agar jelas siapakah di antara kamu yang taat dan siapakah yang maksiat. (Sesungguhnya Tuhanmu itu adalah amat cepat siksaan-Nya) terhadap orang-orang yang berbuat maksiat kepada-Nya (dan sesungguhnya Dia Maha Pengampun) terhadap orang-orang mukmin (lagi Maha Penyayang.") terhadap mereka.\qt@no{165}}%
\qt@newcmd\qurantrans@id@cmlv{%
\basmalahid (Alif laam miim shaad) hanya Allah-lah yang mengetahui apa yang dimaksud dengannya.\qt@no{1}}%
\qt@newcmd\qurantrans@id@cmlvi{%
Ini adalah (kitab yang diturunkan kepadamu) khithab atau pembicaraan ayat ini ditujukan kepada Nabi saw. (maka janganlah ada kesempitan di dalam dadamu) kerumitan (karenanya) sewaktu engkau akan menyampaikannya karena merasa khawatir akan didustakan (supaya kamu memberi peringatan) berkaitan dengan lafal unzila, artinya supaya engkau memperingatkan (dengan kitab itu dan menjadi pelajaran) yaitu bahan pengingat (bagi orang-orang yang beriman) kepada kitab itu.\qt@no{2}}%
\qt@newcmd\qurantrans@id@cmlvii{%
Katakanlah kepada mereka, (Ikutilah apa yang diturunkan kepadamu dari Tuhanmu) yakni Alquran (dan janganlah kamu mengikuti) maksudnya jangan kamu menjadikan (selain-Nya) selain Allah, (sebagai pemimpin-pemimpin) yang kamu taati untuk berbuat maksiat kepada Allah swt. (Amat sedikitlah kamu mengambil pelajaran) dengan memakai ta atau ya; yakni mengambil pelajaran darinya. Lafal tadzakkaruun dibaca dengan mengidgamkan ta asal ke dalam dzal. Menurut suatu qiraat dibaca tadzkuruun. Sedangkan huruf maa adalah tambahan, yang diadakan untuk mengukuhkan makna sedikit, sehingga artinya menjadi amat sedikit.\qt@no{3}}%
\qt@newcmd\qurantrans@id@cmlviii{%
(Betapa banyaknya) kalimat berita dan menjadi maf`ul (negeri) yang dimaksud adalah penduduknya (yang telah Kami binasakan) Kami bermaksud untuk membinasakannya (maka datanglah kekuatan Kami) yakni siksaan Kami (tengah malam) yaitu pada malam hari (atau di waktu mereka beristirahat di tengah hari) artinya sedang tidur-tiduran di siang hari. Yang dimaksud dengan al-qailulah, artinya beristirahat di tengah hari sekalipun tidak tidur. Yakni siksaan itu terkadang datang di waktu tengah malam dan terkadang di siang hari.\qt@no{4}}%
\qt@newcmd\qurantrans@id@cmlix{%
(Maka tidak adalah keluhan mereka) yaitu perkataan mereka (di waktu datang kepada mereka siksaan Kami kecuali mengatakan, ``Sesungguhnya kami adalah orang-orang yang lalim.")\qt@no{5}}%
\qt@newcmd\qurantrans@id@cmlx{%
(Maka sesungguhnya Kami akan menanyai umat-umat yang telah diutus rasul-rasul kepada mereka) yaitu kepada umat-umat tentang tanggapan mereka terhadap rasul-rasul dan pengamalan mereka terhadap apa-apa yang telah disampaikan kepada mereka (dan sesungguhnya Kami akan menanyai pula rasul-rasul Kami) tentang penyampaian mereka.\qt@no{6}}%
\qt@newcmd\qurantrans@id@cmlxi{%
(Maka sesungguhnya akan Kami kabarkan kepada mereka dengan penuh pengetahuan). Kami akan menceritakan kepada mereka tentang apa-apa yang telah mereka perbuat dengan penuh pengetahuan (dan Kami sekali-kali tidak gaib) untuk menyampaikan kepada rasul-rasul dan umat-umat terdahulu tentang apa-apa yang pernah mereka perbuat.\qt@no{7}}%
\qt@newcmd\qurantrans@id@cmlxii{%
(Dan timbangan) untuk amal-amal perbuatan atau untuk lembaran-lembaran catatan amal perbuatan yang ditaruh di dalamnya. Timbangan itu memiliki jarum penunjuk berat dan dua gantungan, demikian sebagaimana yang telah dijelaskan oleh hadis. Timbangan itu ada (pada hari itu) yakni hari penghisaban yang telah disebutkan, yaitu hari kiamat (adalah benar) adalah adil, menjadi sifat dari lafal al-wazn (maka barang siapa berat timbangannya) oleh kebaikan (maka mereka itulah orang-orang yang berbahagia) orang-orang yang beruntung.\qt@no{8}}%
\qt@newcmd\qurantrans@id@cmlxiii{%
(Dan siapa yang ringan timbangannya) oleh sebab amal-amal keburukannya (maka itulah orang-orang yang merugikan dirinya sendiri) yang membawa dirinya ke neraka (disebabkan mereka selalu mengingkari ayat-ayat Kami) mereka tidak mau mempercayainya.\qt@no{9}}%
\qt@newcmd\qurantrans@id@cmlxiv{%
(Sesungguhnya Kami telah menempatkan kamu sekalian) hai anak-anak Adam (di muka bumi dan Kami adakan bagimu di muka bumi itu sumber-sumber penghidupan) dengan memakai huruf ya, yakni sarana-sarana untuk kamu bisa hidup. Ma`ayisy jamak dari kata ma'isyah (amat sedikitlah) untuk mengukuhkan keminiman (kamu bersyukur) terhadap kesemuanya itu.\qt@no{10}}%
\qt@newcmd\qurantrans@id@cmlxv{%
(Sesungguhnya Kami telah menciptakanmu) maksudnya ayah kamu yaitu Adam (lalu Kami bentuk tubuhmu) Kami membentuk tubuhnya sedangkan kamu masih berada di dalam sulbinya (kemudian Kami katakan kepada para malaikat, ``Bersujudlah kamu kepada Adam,") sebagai penghormatan, yaitu dengan menundukkan punggung (maka mereka pun bersujud kecuali iblis) yaitu kakek moyang bangsa jin yang ada di antara malaikat (dia tidak termasuk mereka yang bersujud).\qt@no{11}}%
\qt@newcmd\qurantrans@id@cmlxvi{%
(Allah berfirman,) Maha Tinggi Allah, ("Apakah yang menghalangimu untuk) huruf laa adalah tambahan (bersujud di waktu) tatkala (Aku menyuruhmu." Menjawab iblis, ``Aku lebih baik daripadanya, Engkau ciptakan aku dari api sedangkan dia Engkau ciptakan dari tanah.")\qt@no{12}}%
\qt@newcmd\qurantrans@id@cmlxvii{%
(Allah berfirman, ``Turunlah kamu dari surga itu) ada yang mengatakan dari langit (karena tidak patut) tidak layak (bagi kamu menyombongkan diri di dalamnya, maka keluarlah) dari surga (sesungguhnya kamu termasuk orang-orang yang hina.") maksudnya orang-orang yang terhina.\qt@no{13}}%
\qt@newcmd\qurantrans@id@cmlxviii{%
(Iblis menjawab, ``Beri tangguhlah saya) artinya berilah saya kesempatan (sampai waktu mereka dibangkitkan.") yakni sampai manusia dibangkitkan.\qt@no{14}}%
\qt@newcmd\qurantrans@id@cmlxix{%
(Allah berfirman, ``Sesungguhnya kamu termasuk mereka yang diberi tangguh.") pada ayat lain disebutkan, ``Hingga hari yang telah ditentukan," yaitu waktu ditiupnya sangkakala pertama.\qt@no{15}}%
\qt@newcmd\qurantrans@id@cmlxx{%
(Iblis menjawab, ``Karena Engkau telah menyesatkan saya) Engkau telah menghukum saya; huruf ba mengandung makna qasam/sumpah dan sebagai jawabnya ialah (saya benar-benar akan menghalang-halangi mereka) yaitu anak-anak Adam (dari jalan Engkau yang lurus) maksudnya dari jalan yang dapat mempertemukan mereka kepada Engkau.\qt@no{16}}%
\qt@newcmd\qurantrans@id@cmlxxi{%
(Kemudian saya akan mendatangi mereka dari muka dan dari belakang, dari kanan dan dari kiri mereka) maksudnya dari segala penjuru, kemudian aku halang-halangi mereka untuk bisa menempuh jalan-Mu itu. Akan tetapi Ibnu Abbas memberikan penafsirannya, bahwa iblis tidak akan dapat mendatangi mereka dari arah atasnya hal itu supaya ia jangan menghalang-halangi jalan antara hamba dengan rahmat Allah swt. (dan engkau tidak akan mendapati kebanyakan mereka bersyukur") yakni beriman.\qt@no{17}}%
\qt@newcmd\qurantrans@id@cmlxxii{%
(Allah berfirman, ``Keluarlah kamu dari surga itu sebagai orang yang terhina) dengan memakai hamzah, artinya tercela atau kena murka Allah (lagi terusir) dijauhkan dari rahmat Allah. (Sesungguhnya barang siapa di antara mereka mengikuti kamu) dari kalangan umat manusia; huruf lam menunjukkan makna ibtida/permulaan kalimat atau sebagai pendahuluan dari qasam/sumpah, yang mana sumpahnya adalah (sungguh Aku akan memenuhi neraka Jahanam dengan kamu semuanya") yakni kamu dan anak-cucumu serta manusia. Di dalam ayat ini terkandung makna taghliibul haadhir `alal ghaaib atau mengutamakan yang hadir daripada yang tidak hadir; jumlah ini mengandung makna syarat, yakni: Barang siapa yang mengikutimu Aku akan menyiksanya.\qt@no{18}}%
\qt@newcmd\qurantrans@id@cmlxxiii{%
(Dan) Allah berfirman ("Hai Adam bertempat tinggallah kamu) lafal anta merupakan pengukuhan terhadap dhamir yang terdapat di dalam lafal uskun, tujuannya ialah untuk dijadikan sebagai ma'thuf alaih (dan istrimu) yakni Hawa, dengan dibaca panjang (di surga serta makanlah olehmu berdua buah-buahan mana saja yang kamu sukai, dan janganlah kamu berdua mendekati pohon ini) dengan cara memakannya, yang dimaksud adalah pohon gandum (maka menjadilah kamu berdua termasuk orang-orang yang lalim").\qt@no{19}}%
\qt@newcmd\qurantrans@id@cmlxxiv{%
(Maka setan mulai menggoda keduanya) yakni iblis (untuk menampakkan) memperlihatkan (kepada keduanya apa yang tertutup) dengan wazan fu`ila dari lafal al-muwaaraah (dari mereka, yaitu auratnya dan setan berkata, ``Tuhan kamu tidak melarangmu dari mendekati pohon ini melainkan) karena khawatir (supaya kamu berdua tidak menjadi malaikat) dan menurut suatu qiraat dibaca dengan malikaini/lam dikasrahkan (atau tidak menjadi orang-orang yang kekal dalam surga") berdasarkan hal itu maka memakan pohon itu adalah suatu keharusan sebagaimana yang disebutkan pula di dalam ayat lain, yaitu, ``Maukah saya tunjukkan kepada kamu pohon kekekalan dan kerajaan yang tidak akan binasa." (Q.S. Thaha 120)\qt@no{20}}%
\qt@newcmd\qurantrans@id@cmlxxv{%
(Dan dia, setan, bersumpah kepada keduanya) setan bersumpah dengan nama Allah kepada keduanya ("Sesungguhnya saya adalah termasuk orang yang memberi nasihat kepada kamu berdua.") di dalam hal ini.\qt@no{21}}%
\qt@newcmd\qurantrans@id@cmlxxvi{%
(Maka setan membujuk keduanya) untuk menurunkan kedudukan keduanya (dengan tipu daya) darinya. (Tatkala keduanya telah merasai buah pohon itu) mereka berdua telah memakannya (nampaklah bagi keduanya aurat-auratnya) yakni kedua kemaluan masing-masing tampak oleh lainnya; kedua anggota tubuh itu dinamakan sau`ah, sebab jika terbuka akan membuat malu orang yang bersangkutan (dan mulailah keduanya menutupi) maksud keduanya mengambil penutup untuk menutupi (kedua auratnya dengan daun-daun surga) untuk menutupinya. (Kemudian Tuhan mereka menyeru mereka, ``Bukankah Aku telah melarang kamu berdua dari pohon itu dan Aku katakan kepadamu, 'Sesungguhnya setan itu adalah musuh yang nyata bagi kamu berdua.')" yang jelas permusuhannya; kata tanya menunjukkan makna penegasan.\qt@no{22}}%
\qt@newcmd\qurantrans@id@cmlxxvii{%
(Keduanya berkata, ``Ya Tuhan kami, kami telah menganiaya diri kami sendiri) oleh sebab perbuatan maksiat kami berdua (dan jika Engkau tidak mengampuni kami dan memberi rahmat kepada kami, niscaya pastilah kami termasuk orang-orang yang merugi.")\qt@no{23}}%
\qt@newcmd\qurantrans@id@cmlxxviii{%
(Allah berfirman, ``Turunlah kamu sekalian) yakni Adam dan Hawa serta anak-cucu kamu yang masih berada di dalam diri kamu (sebagian kamu) maksudnya sebagian keturunan (menjadi musuh bagi sebagian yang lain) sebagian mereka berlaku aniaya terhadap sebagian yang lainnya. (Dan kamu di muka bumi mempunyai tempat kediaman) yaitu tempat tinggal (dan kesenangan) tempat bersenang-senang (sampai waktu yang ditentukan.") apabila ajal kamu telah sampai pada saatnya.\qt@no{24}}%
\qt@newcmd\qurantrans@id@cmlxxix{%
(Allah berfirman, ``Di muka bumi itu kamu hidup dan di muka bumi itu kamu mati, dan dari bumi itu pula kamu akan dikeluarkan") dibangkitkan, dengan memakai bina fa`il dan bina maf`ul atau bentuk aktif dan bentuk pasif.\qt@no{25}}%
\qt@newcmd\qurantrans@id@cmlxxx{%
(Hai anak Adam! Sesungguhnya Kami telah menurunkan kepadamu pakaian) Kami telah menciptakannya untuk kamu (untuk menutupi) guna menutupi (auratmu dan pakaian perhiasan) pakaian yang digunakan sebagai perhiasan. (Dan pakaian takwa) yakni amal saleh dan akhlak yang baik; dengan dibaca nashab karena diathafkan kepada lafal libaasan, dan dibaca rafa' sebagai mubtada sedangkan khabarnya ialah jumlah berikut ini (itulah yang lebih baik. Yang demikian itu adalah sebagian tanda-tanda kekuasaan Allah) bukti-bukti yang menunjukkan kekuasaan-Nya (mudah-mudahan mereka selalu ingat) kemudian mau beriman; di dalam jumlah ini terkandung iltifat atau kata sindiran terhadap mukhathab atau orang yang diajak bicara.\qt@no{26}}%
\qt@newcmd\qurantrans@id@cmlxxxi{%
(Hai anak Adam janganlah sekali-kali kamu dapat ditipu) disesatkan (oleh setan) janganlah kamu mengikuti setan sehingga akibatnya kamu akan tertipu (sebagaimana ia telah mengeluarkan ibu-bapakmu) dengan senjata tipu-dayanya (dari surga, di mana ia menanggalkan) menjadi hal (daripada keduanya yaitu pakaian mereka berdua untuk memperlihatkan kepada keduanya aurat masing-masing. Sesungguhnya ia) yakni setan itu (dan pengikut-pengikutnya melihat kamu) yaitu bala tentaranya (dari suatu tempat yang kamu tidak bisa melihat mereka) karena kehalusan jasad mereka atau karena mereka tidak berwarna. (Sesungguhnya Kami telah menjadikan setan-setan itu pemimpin-pemimpin) artinya pendukung-pendukung dan teman-teman (bagi orang-orang yang tidak beriman).\qt@no{27}}%
\qt@newcmd\qurantrans@id@cmlxxxii{%
(Dan apabila mereka melakukan perbuatan keji) seperti perbuatan syirik dan tawaf mereka di sekeliling Kakbah dalam keadaan telanjang seraya mengemukakan alasan mereka, ``Kami tidak akan melakukan tawaf dengan pakaian yang biasa kami gunakan untuk maksiat." Kemudian mereka dilarang dari perbuatan tersebut (mereka berkata, ``Kami mendapati nenek-moyang kami mengerjakan yang demikian itu) kami hanya mengikut kepada mereka (dan Allah menyuruh kami mengerjakannya.") juga. (Katakanlah) kepada mereka ("Sesungguhnya Allah tidak menyuruh mengadakan perbuatan yang keji." Mengapa kamu mengada-adakan terhadap Allah apa yang tidak kamu ketahui?) bahwa Allah mengatakannya; istifham atau kata tanya di sini menunjukkan makna ingkar atau sanggahan.\qt@no{28}}%
\qt@newcmd\qurantrans@id@cmlxxxiii{%
(Katakanlah, ``Tuhanku menyuruh menjalankan keadilan") yaitu perbuatan yang adil. (Dan luruskanlah) diathafkan secara makna kepada lafal bil qisthi, yang artinya, Ia berkata, ``Berlaku adillah kamu dan luruskanlah dirimu." Atau diathafkan kepada lafal sebelumnya dengan menyimpan taqdir yakni: Hadapkanlah dirimu (mukamu) kepada Allah (di setiap salatmu) ikhlaslah kamu kepada-Nya di dalam sujudmu (dan sembahlah Allah) beribadahlah kepada-Nya (dengan mengikhlaskan ketaatan kepada-Nya) bersih dari kemusyrikan. (Sebagaimana Dia menciptakanmu pada permulaan) yang sebelumnya kamu bukanlah merupakan sesuatu (demikian pulalah akan kembali kepada-Nya) artinya Dia akan mengembalikan kamu pada hari kiamat dalam keadaan hidup kembali.\qt@no{29}}%
\qt@newcmd\qurantrans@id@cmlxxxiv{%
(Sebagian) dari kamu (diberi-Nya petunjuk dan sebagian lagi telah pasti kesesatan bagi mereka. Sesungguhnya mereka menjadikan setan-setan pelindung mereka selain Allah) (dan mereka mengira bahwa mereka mendapat petunjuk).\qt@no{30}}%
\qt@newcmd\qurantrans@id@cmlxxxv{%
(Hai anak Adam, pakailah pakaianmu yang indah) yaitu buat menutupi auratmu (di setiap memasuki mesjid) yaitu di kala hendak melakukan salat dan tawaf (makan dan minumlah) sesukamu (dan janganlah berlebih-lebihan. Sesungguhnya Allah tidak menyukai orang yang berlebih-lebihan).\qt@no{31}}%
\qt@newcmd\qurantrans@id@cmlxxxvi{%
(Katakanlah,) sebagai rasa ingkar kepada mereka ("Siapakah yang mengharamkan perhiasan dari Allah yang telah dikeluarkan-Nya untuk hamba-hamba-Nya) yang terdiri dari pakaian (dan yang baik-baik) yakni kelezatan-kelezatan (dari rezeki?" Katakanlah, ``Semuanya itu disediakan bagi orang-orang yang beriman dalam kehidupan dunia) yang berhak memilikinya sekalipun selain mereka turut pula memilikinya (khusus) khusus untuk mereka saja; dengan dibaca rafa` sedangkan dibaca nashab menjadi hal (di hari kiamat." Demikianlah Kami menjelaskan ayat-ayat itu) maksudnya Kami menerangkan hal itu sedemikian terincinya (bagi orang-orang yang mengetahui) yaitu mereka yang mau menggunakan pikirannya sebab hanya merekalah yang dapat memanfaatkannya secara baik.\qt@no{32}}%
\qt@newcmd\qurantrans@id@cmlxxxvii{%
(Katakanlah, ``Tuhanku hanya mengharamkan perbuatan yang keji) yaitu dosa-dosa besar seperti perbuatan zina (baik yang tampak atau pun yang tersembunyi) yang terang-terangan atau pun yang sifatnya rahasia (dan perbuatan dosa) perbuatan maksiat (melanggar hak) orang lain (tanpa alasan yang benar) perbuatan lalim (mempersekutukan Allah dengan sesuatu yang Allah tidak menurunkan tentangnya) memusyrikkan-Nya (suatu kekuasaan pun) suatu hujah pun (dan mengharamkan mengada-adakan terhadap Allah apa yang tidak kamu ketahui.") yaitu mengharamkan apa yang tidak diharamkan dan lain sebagainya.\qt@no{33}}%
\qt@newcmd\qurantrans@id@cmlxxxviii{%
(Tiap-tiap umat mempunyai ajal) yakni masa tertentu (maka apabila telah datang ajalnya, mereka tidak dapat mengundurkannya) ajal itu (barang sesaat pun dan tidak dapat pula memajukannya) memajukan temponya.\qt@no{34}}%
\qt@newcmd\qurantrans@id@cmlxxxix{%
(Hai anak-anak Adam, jika) lafal immaa merupakan gabungan antara in syarthiah dan maa zaaidah atau tambahan (datang kepadamu rasul-rasul daripada kamu yang menceritakan kepadamu ayat-ayat-Ku, maka siapa yang bertakwa) menjauhkan diri dari kemusyrikan (dan mengadakan perbaikan) amal perbuatannya (tidaklah ada kekhawatiran terhadap mereka dan tidak pula mereka bersedih hati) di akhirat kelak.\qt@no{35}}%
\qt@newcmd\qurantrans@id@cmxc{%
(Dan orang-orang yang mendustakan ayat-ayat Kami dan menyombongkan diri) berlaku takabur (terhadapnya) sehingga mereka tidak mau percaya kepadanya (mereka itu penghuni-penghuni neraka; mereka kekal di dalamnya).\qt@no{36}}%
\qt@newcmd\qurantrans@id@cmxci{%
(Maka siapakah) maksudnya tidak ada seorang pun (yang lebih lalim daripada orang yang membuat-buat dusta terhadap Allah) dengan mengatakan bahwa Allah itu mempunyai sekutu atau Ia beranak (atau mendustakan ayat-ayat-Nya?) yakni Alquran. (Orang-orang itu akan memperoleh) mereka tetap akan mendapat (bagian mereka) yakni bagian yang telah ditentukan untuknya (dalam Alkitab) yaitu apa-apa yang telah dipastikan dan tertulis untuk mereka di Lohmahfuz berupa rezeki, ajal dan lain-lainnya (sehingga bila datang kepada mereka utusan-utusan Kami) para malaikat (untuk mengambil nyawa mereka seraya mengatakan,) kepada mereka dengan nada mengejek ("Di mana berhala-berhala yang biasa kamu sembah) sesembahan-sesembahan yang selalu kamu puja-puja (selain Allah." Mereka menjawab, ``Berhala-berhala itu telah lenyap) telah hilang (dari kami) sehingga kami tidak dapat melihatnya (dan mereka mengakui terhadap diri mereka) di kala menjelang ajalnya (bahwa mereka adalah orang-orang yang kafir").\qt@no{37}}%
\qt@newcmd\qurantrans@id@cmxcii{%
(Allah berfirman,) Maha Tinggi Allah; Dia berfirman kepada mereka kelak di hari kiamat ("Masuklah kamu sekalian ke dalam) golongan (umat-umat yang telah terdahulu sebelum kamu dari kalangan jin dan manusia ke dalam neraka") Jar dan majrurnya berta'alluq pada lafal udkhuluu. (Setiap umat yang masuk) ke dalam neraka (dia mengutuk kawannya) yang sebelumnya telah menyesatkannya (sehingga apabila mereka masuk) menyusul kawan-kawannya (ke dalam neraka semuanya, berkatalah orang-orang yang masuk kemudian) mereka adalah orang-orang yang hanya mengikuti (kepada orang-orang yang masuk terdahulu) maksudnya para penghulu mereka yang menjadi panutan ("Ya Tuhan kami, mereka telah menyesatkan kami, sebab itu datangkanlah kepada mereka siksaan yang berlipat ganda) yang berkali-kali lipat (dari neraka." Allah berfirman,) Maha Tinggi Allah ("Masing-masing) dari kamu dan dari mereka (mendapat siksaan yang berlipat ganda) maksudnya azab yang berlipat ganda (akan tetapi mereka tidak mengetahui.") dengan memakai ya dan ta; mereka tidak mengetahui siksaan apa yang diterima oleh masing-masing golongan.\qt@no{38}}%
\qt@newcmd\qurantrans@id@cmxciii{%
(Dan berkata orang-orang yang masuk terdahulu di antara mereka kepada orang-orang yang masuk kemudian, ``Kamu tidak mempunyai kelebihan sedikit pun atas kami") sebab kamu ikut kafir seperti kami, maka kami dan kamu adalah sama, kemudian Allah berfirman kepada mereka semua, (maka rasakanlah siksaan dari perbuatan yang telah kamu lakukan).\qt@no{39}}%
\qt@newcmd\qurantrans@id@cmxciv{%
(Sesungguhnya orang-orang yang mendustakan ayat-ayat Kami dan menyombongkan diri) mereka berlaku sombong (terhadapnya) kemudian mereka tidak mau percaya terhadapnya (sekali-kali tidak akan dibukakan bagi mereka pintu-pintu langit) yaitu apabila arwah-arwah mereka dinaikkan sesudah mati, sehingga arwah mereka turun kembali ke Sijjin atau neraka yang ada di dalam perut bumi. Berbeda dengan arwahnya orang yang beriman, pintu-pintu langit dibukakan untuknya, sehingga arwahnya dapat naik ke langit yang ke tujuh, demikianlah menurut penjelasan hadis (dan tidak pula mereka masuk surga hingga unta masuk) yakni jika ada unta yang dapat masuk (ke dalam lubang jarum) maksudnya lubang yang ada pada jarum; ini kata kiasan bahwa hal itu tidak mungkin terjadi, demikian pula masuknya mereka ke dalam surga. (Demikianlah) pembalasan itu (Kami memberi balasan kepada orang-orang yang berbuat kejahatan) oleh sebab kekafirannya.\qt@no{40}}%
\qt@newcmd\qurantrans@id@cmxcv{%
(Mereka mempunyai tikar tidur dari api neraka) alas untuk tidur (dan di atas mereka ada selimut) penutup dari api neraka; ghawaasyin bentuk jamak dari kata ghaasyiyah, sedangkan tanwinnya adalah merupakan pergantian dari ya yang telah dibuang. (Demikianlah Kami memberi balasan kepada orang-orang yang zalim).\qt@no{41}}%
\qt@newcmd\qurantrans@id@cmxcvi{%
(Orang-orang yang beriman dan mengerjakan amal-amal saleh) menjadi mubtada, sedangkan firman Allah swt. (Kami tidak memikulkan kewajiban kepada diri seseorang melainkan sekedar kesanggupannya) sesuai kemampuannya dalam beramal; ini adalah jumlah mu'taridhah antara mubtada dan khabarnya, sedangkan khabarnya ialah (mereka itulah penghuni-penghuni surga, mereka kekal di dalamnya).\qt@no{42}}%
\qt@newcmd\qurantrans@id@cmxcvii{%
(Dan Kami cabut segala macam dendam yang berada di dalam dada mereka) perasaan dengki yang pernah ada sewaktu mereka hidup di alam dunia (mengalir di bawah mereka) di bawah gedung-gedung tempat tinggal mereka (sungai-sungai dan mereka berkata,) tatkala mereka mulai menetap di tempat tinggal masing-masing ("Segala puji bagi Allah yang telah menunjuki kami kepada surga ini) yakni amal perbuatan yang balasannya adalah hal ini (Dan kami sekali-kali tidak akan mendapat petunjuk kalau Allah tidak memberi kami petunjuk) di sini membuang jawabnya laula, hal itu bisa diketahui karena ada tanda sebelumnya yang menunjukkan kepadanya. (Sesungguhnya telah datang rasul-rasul Tuhan kami, membawa kebenaran." Dan diserukan kepada mereka bahwasanya) dengan anna yang ditakhfifkan, yakni annahuu. Atau dapat juga berasal dari an mufassirah (itulah surga yang diwariskan kepadamu, disebabkan apa yang dahulu kamu kerjakan).\qt@no{43}}%
\qt@newcmd\qurantrans@id@cmxcviii{%
(Dan penghuni-penghuni surga berseru kepada penghuni-penghuni neraka,) sebagai pernyataan dan ejekan ("Sesungguhnya kami telah memperoleh apa yang telah Tuhan kami menjanjikannya kepada kami) berupa pahala (dengan sebenarnya. Maka apakah kamu telah memperoleh apa yang telah dijanjikan) kepadamu (oleh Tuhanmu) berupa azab (dengan sebenarnya?" Mereka, penduduk neraka, menjawab, ``Betul." Kemudian seorang penyeru, malaikat, mengumumkan) menyerukan pengumuman (di antara mereka) yaitu di antara kedua golongan itu. Malaikat itu mengumandangkan kepada mereka ("Kutukan Allah ditimpakan kepada orang-orang yang lalim).\qt@no{44}}%
\qt@newcmd\qurantrans@id@cmxcix{%
(Yaitu orang-orang yang menghalangi) manusia (dari jalan Allah) dari tuntunan agama-Nya (dan menginginkan agar jalan itu) maksudnya mereka menghendaki agar jalan Allah itu (bengkok) tidak lurus (dan mereka ingkar terhadap kehidupan akhirat).\qt@no{45}}%
\qt@newcmd\qurantrans@id@m{%
(Dan di antara keduanya) yaitu antara para penghuni surga dan para penghuni neraka (ada batas) penghalang; menurut suatu pendapat batas itu berupa tembok vang diberi nama Al-A'raaf (di atas Al-A`raaf itu) yakni nama tembok surga (ada orang-orang) yang amat tampan dan amat buruk rupanya, rupa mereka sama, artinya yang cantik sama cantiknya dan yang buruk sama pula buruknya, sebagaimana yang dijelaskan oleh hadis (yang mengenal masing-masing dari kedua golongan itu) penduduk surga dan neraka (dengan tanda-tanda mereka) ciri-ciri khas mereka, yakni berbadan putih bagi orang-orang yang beriman dan berbadan hitam bagi orang-orang kafir, oleh sebab orang-orang yang di atas Al-A`raaf itu dapat langsung melihat kedua golongan itu mengingat mereka berada di tempat yang tinggi. (Dan mereka menyeru penduduk surga, 'Mudah-mudahan Allah melimpahkan kesejahteraan atas kamu.') Allah swt. berfirman, ('Mereka belum lagi memasukinya) yakni para penghuni Al-A'raaf itu ke surga (sedangkan mereka ingin segera')" memasukinya. Hasan mengatakan, ``Mereka tidak terdorong oleh rasa keinginan yang sangat melainkan karena memang Allah telah menghendakinya untuk mereka." Dan Imam Hakim telah meriwayatkan dari Hudzaifah yang telah mengatakan, ``Tatkala calon penghuni surga itu dalam keadaan demikian berada di Al-A'raaf, kemudian Tuhanmu muncul di hadapan mereka seraya berfirman, 'Masuklah kamu sekalian ke dalam surga, sesungguhnya Aku telah mengampuni kamu.'"\qt@no{46}}%
\qt@newcmd\qurantrans@id@mi{%
(Dan apabila pandangan mereka dialihkan) yakni Ashhaabul A`raaf itu (ke arah) ke sebelah (penghuni neraka, mereka berkata, ``Ya Tuhan kami! Janganlah Engkau tempatkan kami) di dalam neraka (bersama-sama orang-orang yang lalim itu").\qt@no{47}}%
\qt@newcmd\qurantrans@id@mii{%
(Dan orang-orang yang di atas Al-A`raaf memanggil beberapa orang pemuka-pemuka) penduduk neraka (yang mereka mengenalnya dengan tanda-tandanya dengan mengatakan, ``Tidaklah memberi manfaat kepadamu) dapat menyelamatkanmu dari neraka (apa yang kamu kumpulkan) yakni harta benda atau banyaknya bilangan kamu (dan apa yang selalu kamu sombongkan itu.") yaitu kepongahanmu tidak mau beriman, kemudian orang-orang yang di atas Al-A`raaf bertanya kepada penghuni neraka seraya memberi isyarat kepada orang-orang Islam yang lemah.\qt@no{48}}%
\qt@newcmd\qurantrans@id@miii{%
("Itukah orang-orang yang telah kamu bersumpah bahwa mereka tidak akan mendapat rahmat Allah?") akan tetapi telah dikatakan kepada orang-orang Islam yang lemah itu ("Masuklah ke dalam surga, tidak ada kekhawatiran terhadapmu dan tidak pula kamu bersedih hati") menurut suatu qiraat dibaca dengan bina maf'ul yakni udkhiluu dan dukhiluu, jumlah nafi menjadi hal yakni perkataan tersebut ditujukan kepada mereka.\qt@no{49}}%
\qt@newcmd\qurantrans@id@miv{%
(Dan penghuni neraka menyeru kepada penghuni surga, ``Limpahkanlah kepada kami sedikit air atau apa yang telah direzekikan Allah kepadamu.") yaitu makanan (Mereka, para penghuni surga, menjawab, ``Sesungguhnya Allah telah mengharamkan keduanya) telah melarang makanan dan minuman itu (atas orang-orang kafir).\qt@no{50}}%
\qt@newcmd\qurantrans@id@mv{%
(Yaitu orang-orang yang menjadikan agama mereka sebagai main-mainan dan senda-gurau, dan kehidupan dunia telah menipu mereka." Maka pada hari ini, hari kiamat, Kami melupakan mereka) Kami membiarkan mereka di dalam neraka (sebagaimana mereka melupakan pertemuan mereka dengan hari ini) di mana mereka mengabaikan beramal baik untuk menghadapinya (dan sebagaimana mereka selalu mengingkari ayat-ayat Kami) sebagaimana mereka telah berlaku ingkar terhadapnya.\qt@no{51}}%
\qt@newcmd\qurantrans@id@mvi{%
(Dan sesungguhnya Kami telah mendatangkan kepada mereka) para penduduk Mekah (sebuah Kitab) yakni Alquran (yang Kami telah menjelaskannya) telah Kami terangkan melalui berita-beritanya, janji-janjinya dan ancaman-ancamannya (atas dasar pengetahuan Kami) menjadi hal, yakni Kami mengetahui tentang apa yang terincikan di dalamnya (menjadi petunjuk) menjadi hal bagi dhamir ha (dan rahmat bagi orang-orang yang beriman) kepadanya.\qt@no{52}}%
\qt@newcmd\qurantrans@id@mvii{%
(Tiadalah mereka menunggu-nunggu) mereka tidak menunggu (kecuali terlaksananya kebenaran Alquran itu) akibat dari apa yang ada di dalamnya. (Pada hari datangnya kebenaran pemberitaan Alquran itu) yaitu hari kiamat (berkatalah orang-orang yang melupakannya sebelum itu,) mereka tidak mau beriman kepada Alquran ("Sesungguhnya telah datang rasul-rasul Tuhan kami membawa yang hak, maka adakah bagi kami pemberi syafaat yang akan memberi syafaat kepada kami atau) dapatkah (kami dikembalikan) ke dunia (sehingga dapat beramal yang lain dari yang pernah kami amalkan?") kami akan mentauhidkan Allah dan meninggalkan kemusyrikan. Kemudian dikatakan kepada mereka, ``Tidak dapat." Allah swt. berfirman, (Sungguh mereka telah merugikan diri mereka sendiri) sebab mereka menjadi binasa (dan lenyaplah) maksudnya hilanglah (dari mereka tuhan-tuhan yang mereka ada-adakan) sebagai sekutu Allah yang mereka buat-buat sendiri.\qt@no{53}}%
\qt@newcmd\qurantrans@id@mviii{%
(Sesungguhnya Tuhan kamu ialah Allah yang telah menciptakan langit dan bumi dalam enam masa) menurut ukuran hari dunia atau yang sepadan dengannya, sebab pada zaman itu masih belum ada matahari. Akan tetapi jika Allah menghendakinya niscaya Ia dapat menciptakannya dalam sekejap mata, adapun penyebutan hal ini dimaksud guna mengajari makhluk-Nya agar tekun dan sabar dalam mengerjakan sesuatu (lalu Dia bersemayam di atas Arsy) Arsy menurut istilah bahasa artinya singgasana raja, yang dimaksud dengan bersemayam ialah yang sesuai dengan kebesaran Allah dan kesucian-Nya (Dia menutupkan malam kepada siang) bisa dibaca takhfif yakni yughsyii dan dibaca tasydid, yakni yughasysyii, artinya: keduanya itu saling menutupi yang lain silih-berganti (yang mengikutinya) masing-masing di antara keduanya itu mengikuti yang lainnya (dengan cepat) secara cepat (dan diciptakan-Nya pula matahari, bulan dan bintang-bintang) dengan dibaca nashab diathafkan kepada as-samaawaat, dan dibaca rafa` sebagai mubtada sedangkan khabarnya ialah (masing-masing tunduk) patuh (kepada perintah-Nya) kepada kekuasaan-Nya (ingatlah, menciptakan itu hanya hak Allah) semuanya (dan memerintah) kesemuanya adalah hak-Nya pula (Maha Suci) Maha Besar (Allah, Tuhan) Pemelihara (semesta alam).\qt@no{54}}%
\qt@newcmd\qurantrans@id@mix{%
(Berdoalah kepada Tuhanmu dengan berendah diri) menjadi hal, yakni merendahkan diri (dan dengan suara yang lembut) secara berbisik-bisik (Sesungguhnya Allah tidak menyukai orang-orang yang melampaui batas) di dalam berdoa. Seperti banyak berbicara dengan suara yang keras.\qt@no{55}}%
\qt@newcmd\qurantrans@id@mx{%
(Dan janganlah kamu membuat kerusakan di muka bumi) dengan melakukan kemusyrikan dan perbuatan-perbuatan maksiat (sesudah Allah memperbaikinya) dengan cara mengutus rasul-rasul (dan berdoalah kepada-Nya dengan rasa takut) terhadap siksaan-Nya (dan dengan penuh harap) terhadap rahmat-Nya. (Sesungguhnya rahmat Allah amat dekat kepada orang-orang yang berbuat baik) yakni orang-orang yang taat. Lafal qariib berbentuk mudzakkar padahal menjadi khabar lafal rahmah yang muannats, hal ini karena lafal rahmah dimudhafkan kepada lafal Allah.\qt@no{56}}%
\qt@newcmd\qurantrans@id@mxi{%
(Dan Dialah yang meniupkan angin sebagai pembawa berita gembira sebelum kedatangan rahmat-Nya) yakni terpencar-pencar sebelum datangnya hujan. Menurut suatu qiraat dibaca dengan takhfif, yaitu syin disukunkan; dan menurut qiraat lainnya dengan disukunkan syinnya kemudian memakai nun yang difatahkan sebagai mashdar. Menurut qiraat lainnya lagi dengan disukunkan syinnya kemudian didamahkan huruf sebelumnya sebagai pengganti dari nun, yakni mubsyiran. Bentuk tunggal (dari yang pertama ialah nusyuurun seperti lafal rasuulun, sedangkan bentuk tunggal yang kedua ialah basyiirun (sehingga apabila angin itu membawa) maksudnya meniupkan (mendung yang tebal) yaitu hujan (Kami halau mendung itu) mega yang mengandung air hujan itu. Di dalam lafal ini terkandung makna iltifat `anil ghaibiyyah (ke suatu daerah yang tandus) daerah yang tidak ada tetumbuhannya guna menyuburkannya (lalu Kami turunkan di daerah itu) di kawasan tersebut (hujan, maka Kami keluarkan dengan sebab hujan itu berbagai macam buah-buahan. Seperti itulah) cara pengeluaran itulah (Kami membangkitkan orang-orang yang telah mati) dari kuburan mereka dengan menghidupkan mereka kembali (mudah-mudahan kamu mengambil pelajaran) kemudian kamu mau beriman.\qt@no{57}}%
\qt@newcmd\qurantrans@id@mxii{%
(Dan tanah yang baik) yang subur tanahnya (tanaman-tanamannya tumbuh subur) tumbuh dengan baik (dengan seizin Tuhannya) hal ini merupakan perumpamaan bagi orang mukmin yang mau mendengar petuah/nasihat kemudian ia mengambil manfaat dari nasihat itu (dan tanah yang tidak subur) jelek tanahnya (tidaklah mengeluarkan) tanamannya (kecuali tumbuh merana) sulit dan susah tumbuhnya. Hal ini merupakan perumpamaan bagi orang yang kafir. (Demikianlah) seperti apa yang telah Kami jelaskan (Kami menjelaskan) menerangkan (ayat-ayat Kami kepada orang-orang yang bersyukur) terhadap Allah, kemudian mereka mau beriman kepada-Nya.\qt@no{58}}%
\qt@newcmd\qurantrans@id@mxiii{%
(Sesungguhnya) merupakan jawab dari qasam/sumpah yang mahdzuf/tidak disebutkan. (Kami telah mengutus Nuh kepada kaumnya lalu ia berkata, ``Wahai kaumku, sembahlah Allah, sekali-kali tak ada Tuhan bagimu selain-Nya.") dengan dibaca jar sebagai sifat dari lafal ilaahun, dan dibaca rafa' sebagai badal dari lafal ilaahun (Sesungguhnya aku takut kamu) jika kamu menyembah selain Allah (akan ditimpa azab yang besar) yakni azab pada hari kiamat.\qt@no{59}}%
\qt@newcmd\qurantrans@id@mxiv{%
(Pemuka-pemuka) orang-orang terhormat (dari kaumnya berkata, ``Sesungguhnya kami memandang kamu berada dalam kesesatan yang nyata.") yang jelas.\qt@no{60}}%
\qt@newcmd\qurantrans@id@mxv{%
(Nuh menjawab, ``Hai kaumku, tak ada padaku kesesatan sedikit pun) lafal dhalaalah lebih umum pengertiannya daripada lafal adh-dhalaal dengan demikian maka penolakannya pun lebih kuat (tetapi aku adalah utusan dari Tuhan semesta alam.")\qt@no{61}}%
\qt@newcmd\qurantrans@id@mxvi{%
("Aku sampaikan kepadamu) dengan dibaca takhfif dan tasydid (amanat-amanat Tuhanku dan aku memberi nasihat) maksudnya, aku menghendaki kebaikan (kepadamu, dan aku mengetahui dari Allah apa yang tidak kamu ketahui.")\qt@no{62}}%
\qt@newcmd\qurantrans@id@mxvii{%
(Apakah) kamu tidak percaya (dan heran bahwa datang kepada kamu peringatan) yakni pelajaran (dari Tuhanmu dengan perantaraan) lisan (seorang laki-laki dari golonganmu agar dia memberi peringatan kepadamu) tentang siksaan jika kamu tidak mau beriman (dan mudah-mudahan kamu bertakwa) kepada Allah (dan supaya kamu mendapat rahmat?) oleh sebab pelajaran itu.\qt@no{63}}%
\qt@newcmd\qurantrans@id@mxviii{%
(Maka mereka mendustakan Nuh, kemudian Kami selamatkan dia dan orang-orang yang bersamanya) dari tenggelam (di dalam bahtera) perahu (dan Kami tenggelamkan orang-orang yang mendustakan ayat-ayat Kami) dengan banjir besar. (Sesungguhnya mereka adalah kaum yang buta) mata hatinya dari kebenaran.\qt@no{64}}%
\qt@newcmd\qurantrans@id@mxix{%
(Dan) Kami telah mengutus (kepada kaum Ad) yang pertama (saudara mereka yaitu Hud. Ia berkata, ``Hai kaumku, sembahlah Allah) tauhidkanlah Allah (sekali-kali tidak ada Tuhan bagimu selain dari-Nya. Maka mengapa kamu tidak bertakwa?") kamu tidak takut kepada-Nya sehingga kamu mau mengimani-Nya.\qt@no{65}}%
\qt@newcmd\qurantrans@id@mxx{%
(Pemuka-pemuka yang kafir dari kaumnya berkata, ``Sesungguhnya kami benar-benar memandang kamu dalam keadaan kurang akal) yaitu bodoh (dan sesungguhnya kami menganggap kamu termasuk orang-orang yang berdusta.") di dalam kerasulanmu.\qt@no{66}}%
\qt@newcmd\qurantrans@id@mxxi{%
(Hud berkata, ``Hai kaumku! Tidak ada padaku kekurangan akal sedikit pun tetapi aku ini adalah utusan dari Tuhan semesta alam)\qt@no{67}}%
\qt@newcmd\qurantrans@id@mxxii{%
(Aku menyampaikan amanat-amanah Tuhanku kepadamu dan aku hanyalah pemberi nasihat yang terpercaya bagimu") yakni orang yang dipercaya untuk mengemban risalah.\qt@no{68}}%
\qt@newcmd\qurantrans@id@mxxiii{%
(Apakah kamu tidak percaya dan heran bahwa datang kepadamu peringatan dari Tuhanmu yang dibawa oleh) lisan (seorang laki-laki di antara kamu untuk memberi peringatan kepadamu? Dan ingatlah oleh kamu sekalian di waktu Allah menjadikan kamu sebagai pengganti-pengganti yang berkuasa) di muka bumi (sesudah lenyapnya kaum Nuh dan Tuhan telah melebihkan kekuatan tubuh dan perawakanmu) memberi kekuatan dan tinggi tubuh; tersebutlah bahwa orang yang paling tinggi di antara mereka adalah seratus hasta, sedangkan yang paling pendek enam puluh hasta (Maka ingatlah nikmat-nikmat Allah) yaitu karunia-karunia-Nya (supaya kamu mendapat keberuntungan) supaya kamu memperoleh keberhasilan.\qt@no{69}}%
\qt@newcmd\qurantrans@id@mxxiv{%
(Mereka berkata, ``Apakah kamu datang kepada kami agar kami hanya menyembah Allah saja dan meninggalkan) artinya membiarkan (apa yang biasa disembah oleh bapak-bapak kami? Maka datangkanlah apa yang kamu ancamkan kepada kami) berupa azab (jika kamu termasuk orang-orang yang benar") di dalam pengakuanmu.\qt@no{70}}%
\qt@newcmd\qurantrans@id@mxxv{%
(Ia berkata, ``Sungguh sudah pasti) telah wajib (kamu akan ditimpa azab Tuhanmu) yakni siksaan-Nya (dan kemarahan-Nya. Apakah kamu sekalian hendak berbantah dengan aku tentang nama-nama yang telah kamu menamakannya) artinya yang telah diberi nama oleh kamu (kamu beserta nenek-moyangmu) yang dimaksud ialah berhala-berhala yang biasa mereka sembah (padahal Allah sekali-kali tidak menurunkan untuk itu) untuk menyembahnya (suatu hujah pun?) bukti argumentasi. (Maka tunggulah olehmu) azab itu (sesungguhnya aku juga termasuk orang-orang yang menunggu bersama kamu.") menanti azab itu disebabkan kedustaanmu kepadaku. Kemudian dikirimkan kepada mereka angin yang panas sekali. Maksudnya, Allah menimpakan azab-Nya atas mereka dengan angin yang amat panas.\qt@no{71}}%
\qt@newcmd\qurantrans@id@mxxvi{%
(Maka Kami selamatkan dia) Hud (beserta orang-orang yang bersamanya) dari kalangan orang-orang yang beriman (dengan rahmat yang besar dari Kami dan Kami tumpas) kaumnya itu (orang-orang yang mendustakan ayat-ayat Kami) Kami habiskan mereka dengan akar-akarnya (dan tiadalah mereka orang-orang yang beriman) diathafkan kepada lafal kadzdzabuu.\qt@no{72}}%
\qt@newcmd\qurantrans@id@mxxvii{%
(Dan) Kami telah mengutus (kepada kaum Tsamud) tanpa tanwin, yang dimaksud adalah kabilahnya (saudara mereka Saleh. Ia berkata, ``Hai kaumku, sembahlah Allah sekali-kali tidak ada Tuhan bagimu selain-Nya. Sesungguhnya telah datang bukti yang nyata) yakni mukjizat (dari Tuhanmu) yang membenarkan kerasulanku. (Unta betina ini menjadi tanda bagimu) menjadi hal sedangkan amilnya adalah makna yang terkandung dalam isyarah. Sebelumnya kaum Nabi Saleh itu meminta kepadanya agar ia mengeluarkan unta betina tersebut dari sebuah batu besar yang telah mereka tentukan sendiri (maka biarkanlah dia makan di bumi Allah dan janganlah kamu mengganggunya dengan gangguan apa pun) menyembelihnya atau memukulnya (maka kamu ditimpa siksaan yang pedih.").\qt@no{73}}%
\qt@newcmd\qurantrans@id@mxxviii{%
(Dan ingatlah olehmu di waktu Tuhan menjadikan kamu pengganti-pengganti) di bumi ini (sesudah kaum Ad dan memberikan tempat bagimu) yakni menempatkan kamu (di bumi. Kamu dirikan istana-istana di atas tanah-tanah yang datar) sebagai tempat tinggalmu di musim panas (dan kamu pahat gunung-gunungnya untuk dijadikan rumah) yang kamu tempati di musim dingin, dinashabkannya lafal buyuutan menjadi hal dari lafal yang tersimpan (maka ingatlah nikmat-nikmat Allah dan janganlah kamu merajalela di muka bumi membuat kerusakan).\qt@no{74}}%
\qt@newcmd\qurantrans@id@mxxix{%
(Pemuka-pemuka yang menyombongkan diri di antara kaumnya berkata) maksudnya mereka yang sombong tidak mau beriman kepada Saleh (kepada orang-orang yang dianggap lemah yang telah beriman di antara mereka,) di antara kaumnya, menjadi badal dari lafal yang sebelumnya dengan mengulangi huruf jar ("Tahukah kamu bahwa Saleh diutus menjadi rasul oleh Tuhannya?) kepadamu (Mereka menjawab,) 'Ya, betul.' (Sesungguhnya kami beriman kepada wahyu yang Saleh diutus untuk menyampaikannya.")\qt@no{75}}%
\qt@newcmd\qurantrans@id@mxxx{%
(Orang-orang yang menyombongkan diri berkata, ``Sesungguhnya kami adalah orang yang tidak percaya kepada apa yang kamu imani itu.")\qt@no{76}}%
\qt@newcmd\qurantrans@id@mxxxi{%
Tersebutlah bahwa bagi unta betina itu satu hari minum, dan untuk mereka satu hari lainnya, akhirnya mereka bosan dengan ketentuan itu. (Kemudian mereka sembelih unta betina itu) yang melakukannya adalah orang yang terkuat berdasarkan perintah dari mereka, yaitu ia diperintahkan agar menyembelihnya dengan pedangnya (dan mereka berlaku angkuh terhadap perintah Tuhan. Dan mereka berkata, ``Hai Saleh! Datangkanlah apa yang kamu ancamkan itu kepada kami) yakni azab sebagai balasan atas pembunuhan unta itu (jika betul kamu termasuk orang yang diutus Allah.").\qt@no{77}}%
\qt@newcmd\qurantrans@id@mxxxii{%
(Karena itu mereka ditimpa gempa) gempa bumi yang keras beserta suara gemuruh dari langit (maka jadilah mereka mayat-mayat yang bergelimpangan di tempat tinggal mereka) mereka mati dalam keadaan bertekuk-lutut.\qt@no{78}}%
\qt@newcmd\qurantrans@id@mxxxiii{%
(Maka Saleh berpaling) ia meninggalkan (mereka seraya berkata, ``Hai kaumku! Sesungguhnya aku telah menyampaikan kepadamu amanat Tuhanku dan aku telah memberi nasihat kepadamu tetapi kamu tidak menyukai orang-orang yang memberi nasihat.")\qt@no{79}}%
\qt@newcmd\qurantrans@id@mxxxiv{%
(Dan) ingatlah (Luth) kemudian disebutkan badalnya yaitu, (tatkala dia berkata kepada kaumnya, ``Mengapa kamu mengerjakan perbuatan fahisyah itu) yakni mendatangi dubur/anus laki-laki (yang belum pernah dikerjakan oleh seorang pun di dunia ini sebelummu?") dari kalangan manusia dan jin.\qt@no{80}}%
\qt@newcmd\qurantrans@id@mxxxv{%
(Tiada lain kamu itu) dengan menetapkan dua hamzah yang ditashilkan nomor duanya serta memasukkan alif di antara keduanya, menurut dua bacaan (mendatangi lelaki untuk melepaskan nafsumu kepada mereka bukan kepada wanita, melainkan kamu itu adalah orang-orang yang melampaui batas) melewati batas kehalalan menuju kepada keharaman.\qt@no{81}}%
\qt@newcmd\qurantrans@id@mxxxvi{%
(Jawab kaumnya tidak lain hanya mengatakan, ``Usirlah mereka) Luth dan pengikut-pengikutnya (dari kotamu ini; sesungguhnya mereka adalah orang-orang yang berpura-pura menyucikan diri.") dari mendatangi dubur laki-laki/homosek.\qt@no{82}}%
\qt@newcmd\qurantrans@id@mxxxvii{%
(Kemudian Kami selamatkan dia dan pengikut-pengikutnya kecuali istrinya; dia termasuk orang-orang yang tertinggal) yang ikut binasa oleh azab Allah.\qt@no{83}}%
\qt@newcmd\qurantrans@id@mxxxviii{%
(Dan Kami turunkan kepada mereka hujan) yakni hujan batu dari neraka Sijjiil kemudian membinasakan mereka (maka perhatikanlah bagaimana kesudahan orang-orang yang berdosa.)\qt@no{84}}%
\qt@newcmd\qurantrans@id@mxxxix{%
(Dan) Kami telah mengutus (kepada penduduk Madyan saudara mereka Syuaib. Ia berkata, ``Hai kaumku, sembahlah Allah, sekali-kali tidak ada Tuhan bagimu selain-Nya. Sesungguhnya telah datang kepadamu bukti yang nyata) yakni mukjizat (dari Tuhanmu) yang membenarkan kerasulanku (Maka sempurnakanlah) genapkanlah (takaran dan timbangan dan janganlah kamu kurangkan) maksudnya menekorkan (bagi manusia barang-barang takaran dan timbangan mereka dan janganlah kamu membuat kerusakan di muka bumi) dengan kekafiran dan maksiat-maksiat (sesudah Tuhan memperbaikinya) dengan mengutus rasul-rasul-Nya (Yang demikian itu) yang telah disebutkan itu (lebih baik bagimu jika betul-betul kamu orang-orang yang beriman) yang menghendaki keimanan, maka bersegeralah kamu kepada keimanan.\qt@no{85}}%
\qt@newcmd\qurantrans@id@mxl{%
(Dan janganlah kamu duduk di tiap-tiap jalan) yakni tempat orang berlalu lintas (dengan menakut-nakuti) membuat orang-orang takut untuk melewatinya karena takut pakaian mereka diambil atau dikenakan pajak (dan menghalang-halangi) menghambat (dari jalan Allah) agama-Nya (terhadap orang yang beriman kepada-Nya) dengan cara kamu mengancam akan membunuhnya (dan kamu menginginkan agar jalan Allah itu) kamu menghendaki agar jalan itu (menjadi bengkok) tidak lurus (Dan ingatlah di waktu dahulunya kamu berjumlah sedikit, kemudian Allah membuat kamu menjadi banyak, lalu perhatikanlah bagaimana kesudahan orang-orang yang berbuat kerusakan") sebelum kamu, oleh karena mereka mendustakan rasul-rasul mereka; yakni akhir dari perkara mereka ialah kebinasaan.\qt@no{86}}%
\qt@newcmd\qurantrans@id@mxli{%
(Jika ada segolongan daripada kamu beriman kepada apa yang aku diutus untuk menyampaikannya, dan ada pula segolongan yang tidak beriman) terhadapnya (maka bersabarlah kamu) artinya kamu harap menunggu (hingga Allah menetapkan hukum-Nya di antara kita) antara kami dan kamu, dengan menyelamatkan yang hak dan menghancurkan yang batil (dan Dia adalah hakim yang sebaik-baiknya) yang paling adil.\qt@no{87}}%
\qt@newcmd\qurantrans@id@mxlii{%
(Pemuka-pemuka dari kaum Syuaib yang menyombongkan diri berkata,) mereka yang sombong tidak mau beriman ("Sesungguhnya kami akan mengusir kamu hai Syuaib dan orang-orang yang beriman bersamamu dari kota kami atau kamu kembali) sungguh mau kembali (kepada agama kami.") yaitu din/agama kami. Di dalam pembicaraan ini yang dipakai dhamir jamak padahal pembicaranya hanya seorang yaitu Syuaib sendiri. Sebab Syuaib itu sama sekali bukan berada dalam agama mereka, lalu ia menjawab sebaliknya (Syuaib menjawab, ``Apakah) kami harus kembali kepada agamamu itu (kendatipun kami tidak menyukainya?") Istifham/kata tanya di sini mengandung pengertian pengingkaran.\qt@no{88}}%
\qt@newcmd\qurantrans@id@mxliii{%
(Sungguh kami mengada-adakan kebohongan yang besar terhadap Allah jika kami kembali kepada agamamu sesudah Allah melepaskan kami daripadanya. Dan tidaklah patut) tidak pantas (bagi kami kembali kepadanya kecuali jika Allah Tuhan kami menghendaki) hal itu, yaitu menghinakan kami (Pengetahuan Tuhan kami meliputi segala sesuatu) yang di antaranya ialah Dia mengetahui keadaanku dan keadaanmu (Kepada Allah sajalah kami bertawakal. Ya Tuhan kami, berilah keputusan) ketentuan hukum (antara kami dan kaum kami dengan hak dan Engkaulah pemberi keputusan yang sebaik-baiknya) yakni hakim yang paling baik.\qt@no{89}}%
\qt@newcmd\qurantrans@id@mxliv{%
(Pemuka-pemuka kaum Syuaib yang kafir berkata,) sebagian mereka berkata kepada sebagian yang lain ("Sesungguhnya jika) lam adalah untuk qasam atau sumpah (kamu mengikut Syuaib, tentu jika kamu berbuat demikian menjadi orang-orang yang merugi.")\qt@no{90}}%
\qt@newcmd\qurantrans@id@mxlv{%
(Kemudian mereka ditimpa gempa) gempa bumi yang dahsyat (maka jadilah mereka mayat-mayat yang bergelimpangan di tempat tinggal mereka) mereka mati dalam keadaan bertekuk-lutut.\qt@no{91}}%
\qt@newcmd\qurantrans@id@mxlvi{%
(Yaitu orang-orang yang mendustakan Syuaib) menjadi mubtada dan khabarnya ialah (seolah-olah) dengan ditakhfifkan sedangkan isimnya dibuang, lengkapnya ialah: Seolah-olah mereka (mereka belum pernah berdiam) artinya mereka belum pernah tinggal (di kota itu) di rumah-rumah mereka sendiri (orang-orang yang mendustakan Syuaib mereka itulah orang-orang yang merugi) pengukuhan dengan mengulangi maushul dan lainnya merupakan jawaban terhadap perkataan mereka yang terdahulu.\qt@no{92}}%
\qt@newcmd\qurantrans@id@mxlvii{%
(Maka Syuaib berpaling) yakni meninggalkan (mereka seraya berkata, ``Hai kaumku! Sesungguhnya aku telah menyampaikan amanat-amanah Tuhanku dan aku telah memberi nasihat kepadamu) akan tetapi kamu tidak juga mau beriman (Maka bagaimana aku akan bersedih hati) bersusah hati (terhadap orang-orang yang kafir?") Istifham di sini bermakna nafi.\qt@no{93}}%
\qt@newcmd\qurantrans@id@mxlviii{%
(Kami tidaklah mengutus seseorang nabi pun kepada sesuatu negeri) kemudian penduduknya mendustakannya (melainkan Kami timpakan) Kami siksa (kepada penduduknya kesempitan) yakni kemiskinan yang sangat (dan penderitaan) berupa penyakit (supaya mereka tunduk dengan merendahkan diri) mereka mau merendahkan dirinya sehingga mereka mau beriman.\qt@no{94}}%
\qt@newcmd\qurantrans@id@mxlix{%
(Kemudian Kami ganti) Kami berikan kepada mereka (kesusahan itu) yakni azab itu (dengan kesenangan) kecukupan dan kesehatan (hingga mereka bertambah banyak) makin banyak keturunan dan hartanya (dan mereka berkata,) sebagai ungkapan ingkar terhadap karunia Allah ("Sesungguhnya nenek moyang kami pun telah merasai penderitaan dan kesenangan") seperti apa yang sedang kami alami, memang demikianlah hukum alam itu, jadi bukanlah merupakan siksaan dari Allah, maka dari itu tetaplah kamu dengan apa yang sekarang kamu pegang. Allah berfirman, (maka Kami timpakan kepada mereka) siksaan (dengan sekonyong-konyong) secara tiba-tiba (sedangkan mereka tidak menyadarinya) sebelum saat azab itu datang.\qt@no{95}}%
\qt@newcmd\qurantrans@id@ml{%
(Dan jika sekiranya penduduk negeri-negeri) yang mendustakan (beriman) terhadap Allah dan rasul-rasul mereka (dan bertakwa) tidak kafir dan maksiat (pastilah Kami akan melimpahkan) dengan dibaca takhfif dan tasydid (kepada mereka berkah dari langit) dengan melalui hujan (dan bumi) dengan melalui tetumbuhan (tetapi mereka mendustakan) rasul-rasul (maka Kami siksa mereka) Kami hukum mereka (disebabkan perbuatan mereka sendiri).\qt@no{96}}%
\qt@newcmd\qurantrans@id@mli{%
(Maka apakah merasa aman penduduk negeri-negeri itu) yang mendustakan (dari kedatangan siksaan Kami kepada mereka) yaitu azab Kami (di malam hari) tengah malam (di waktu mereka sedang tidur) dalam keadaan lalai dari kedatangan azab itu.\qt@no{97}}%
\qt@newcmd\qurantrans@id@mlii{%
(Atau apakah penduduk negeri-negeri itu merasa aman dari kedatangan siksaan Kami kepada mereka di waktu matahari sepenggalah naik) pada waktu siang hari (ketika mereka sedang bermain).\qt@no{98}}%
\qt@newcmd\qurantrans@id@mliii{%
(Maka apakah mereka merasa aman dari tipu daya Allah.) yakni istidraj Allah terhadap mereka dengan memberi mereka banyak kenikmatan kemudian Ia menghukum mereka dengan sekonyong-konyong (Tiada yang merasa aman dari tipu daya Allah kecuali hanya orang-orang yang merugi).\qt@no{99}}%
\qt@newcmd\qurantrans@id@mliv{%
(Dan apakah belum jelas) artinya belum terang (bagi orang-orang yang mempusakai bumi ini) sebagai tempat tinggalnya (sesudah) binasanya (penduduknya bahwa) menjadi fa'il berasal dari anna yang ditakhfifkan sedangkan isimnya dibuang, artinya bahwasanya (kalau Kami menghendaki tentu Kami timpakan kepada mereka siksaan) yakni azab (karena dosa-dosanya) sebagaimana telah Kami timpakan siksaan kepada orang-orang sebelum mereka. Kesemua hamzah di empat tempat tersebut semuanya bermakna lit-taubikh/mencela; dan huruf fa dan wawu yang memasuki pada kedua di antaranya untuk tujuan athaf. Menurut suatu qiraat dibaca dengan wawu yang disukunkan pada tempat yang pertama karena diathafkan kepada huruf aw. (Dan) Kami (kunci) Kami lak (hati mereka sehingga mereka tidak dapat mendengar) nasihat dengan pendengaran yang sehat.\qt@no{100}}%
\qt@newcmd\qurantrans@id@mlv{%
(Negeri-negeri itu) yang telah disebutkan tadi (Kami ceritakan kepadamu) hai Muhammad (tentang sebagian dari berita-beritanya) cerita-cerita penduduknya (Dan sungguh telah datang kepada mereka rasul-rasul mereka dengan membawa bukti-bukti) yaitu mukjizat-mukjizat yang selalu unggul lagi jelas (maka mereka juga tidak beriman) tatkala rasul-rasul itu datang (kepada apa yang dahulu mereka telah mendustakannya) yang telah mereka ingkari (sebelum itu) sebelum para rasul itu datang, bahkan mereka tetap terus melakukan kekafirannya. (Demikianlah) seperti penguncian itu (Allah mengunci mati hati orang-orang kafir).\qt@no{101}}%
\qt@newcmd\qurantrans@id@mlvi{%
(Dan Kami tidak mendapati kebanyakan mereka) maksudnya kebanyakan umat manusia itu (memenuhi janji) menunaikan janji mereka tatkala tiba saat pemenuhannya (Sesungguhnya) ditakhfifkan dari anna (Kami mendapati kebanyakan mereka orang-orang yang fasik).\qt@no{102}}%
\qt@newcmd\qurantrans@id@mlvii{%
(Kemudian Kami utus sesudah rasul-rasul itu) sesudah diutusnya rasul-rasul tersebut (Musa dengan membawa ayat-ayat Kami) yang banyaknya sembilan (kepada Firaun dan pemuka-pemuka kaumnya) golongannya (lalu mereka mengingkari) mengkafiri (ayat-ayat itu. Maka perhatikanlah bagaimana akibat orang-orang yang membuat kerusakan) artinya mereka binasa akibat kekafirannya itu.\qt@no{103}}%
\qt@newcmd\qurantrans@id@mlviii{%
(Dan Musa berkata, ``Hai Firaun, sesungguhnya aku ini adalah seorang utusan Tuhan semesta alam") kepadamu, akan tetapi Firaun mendustakannya dan Musa berkata,\qt@no{104}}%
\qt@newcmd\qurantrans@id@mlix{%
("Aku lebih berhak) lebih pantas (untuk) agar (tidak mengatakan sesuatu terhadap Allah kecuali yang hak) menurut suatu qiraat dibaca tasydid ya-nya; haqiiqun adalah mubtada sedangkan khabarnya adalah an dan kalimat sesudahnya (Sesungguhnya aku datang kepadamu dengan membawa bukti yang nyata dari Tuhanmu, maka lepaskanlah pergi bersamaku) menuju ke negeri Syam (Bani Israel.") kaum Bani Israel itu selalu ditindas oleh Firaun.\qt@no{105}}%
\qt@newcmd\qurantrans@id@mlx{%
(Berkatalah) Firaun kepadanya, ("Jika kamu benar membawa sesuatu ayat) bukti yang memperkuat pengakuanmu (maka datangkanlah bukti itu jika betul kamu termasuk orang-orang yang benar.") membawa bukti itu.\qt@no{106}}%
\qt@newcmd\qurantrans@id@mlxi{%
(Maka Musa menjatuhkan tongkatnya, lalu seketika itu juga tongkat itu menjadi ular yang sebenarnya) yakni ular yang sangat besar bentuknya.\qt@no{107}}%
\qt@newcmd\qurantrans@id@mlxii{%
(Dan ia mengeluarkan tangannya) mengeluarkannya dari dalam sakunya (maka ketika itu juga tangan itu menjadi putih bercahaya menyilaukan (bagi orang-orang yang melihatnya) berbeda warnanya dengan keadaan kulit tangan yang sebenarnya.\qt@no{108}}%
\qt@newcmd\qurantrans@id@mlxiii{%
(Pemuka-pemuka kaum Firaun berkata, ``Sesungguhnya Musa ini adalah ahli sihir yang pandai) yang ulung di dalam ilmu sihir, dan di dalam surah Asy-Syu`ara disebutkan bahwa perkataan ini adalah perkataan Firaun sendiri. Seolah-olah para pemuka kaum Firaun itu mengatakan perkataan tersebut bersama Firaun sendiri, setelah mereka dan dia bermusyawarah tentang hal itu.\qt@no{109}}%
\qt@newcmd\qurantrans@id@mlxiv{%
(Yang bermaksud hendak mengeluarkan kamu dari negerimu." Firaun berkata, ``Maka apakah yang kamu anjurkan?")\qt@no{110}}%
\qt@newcmd\qurantrans@id@mlxv{%
(Pemuka-pemuka itu menjawab, ``Beri tangguhlah dia dan saudaranya) tangguhkanlah perkara keduanya (serta kirimlah ke kota-kota beberapa orang yang akan mengumpulkan ahli-ahli sihir) yang menghimpun para ahli sihir.\qt@no{111}}%
\qt@newcmd\qurantrans@id@mlxvi{%
(Supaya mereka membawa kepadamu semua ahli sihir) menurut suatu qiraat dibaca sahhaar (yang pandai.") maksudnya yang dapat melebihi kepandaian ilmu sihir Musa, akhirnya mereka dapat menghimpunnya.\qt@no{112}}%
\qt@newcmd\qurantrans@id@mlxvii{%
(Dan beberapa ahli sihir itu datang kepada Firaun mengatakan, ``Apakah sesungguhnya) menurut qiraat yang lain lafal inna dibaca ainna (kami akan mendapat upah jika kamilah yang menang?").\qt@no{113}}%
\qt@newcmd\qurantrans@id@mlxviii{%
(Firaun menjawab, ``Ya, dan sesungguhnya kamu benar-benar akan termasuk orang-orang yang dekat kepadaku.")\qt@no{114}}%
\qt@newcmd\qurantrans@id@mlxix{%
(Ahli-ahli sihir berkata, ``Hai Musa! Kamukah yang akan melemparkan lebih dahulu) tongkatmu (ataukah kami yang akan melemparkan?") apa-apa yang ada pada kami.\qt@no{115}}%
\qt@newcmd\qurantrans@id@mlxx{%
(Musa menjawab, ``Lemparkanlah olehmu lebih dahulu) ini adalah suatu perintah yang mempersilakan mereka untuk melemparkan apa yang ada pada mereka, sebagai suatu taktik dari Musa untuk menampakkan yang hak (Maka tatkala mereka melemparkan) tambang-tambang mereka dan tongkat-tongkat mereka (mereka menyulap mata orang) mereka membalik mata para hadirin supaya tidak bisa melihat hal yang sebenarnya (dan menjadikan orang banyak itu takut) artinya mereka membuatnya takut karena mereka menjadikan seolah-olah hal itu adalah ular-ular yang menjalar (serta mereka mendatangkan sihir yang besar, menakjubkan").\qt@no{116}}%
\qt@newcmd\qurantrans@id@mlxxi{%
(Dan Kami wahyukan kepada Musa, ``Lemparkanlah tongkatmu!" Maka sekonyong-konyong tongkat itu menelan) dengan membuang salah satu di antara kedua ta yang asal, yakni: tongkat itu mencaplok (apa yang mereka sulapkan) apa yang mereka balikkan pada pandangan mata orang dengan tipu sulap mereka.\qt@no{117}}%
\qt@newcmd\qurantrans@id@mlxxii{%
(Karena itu nyatalah yang benar) yakni telah tetap dan menang yang benar itu (dan batallah yang selalu mereka kerjakan) yaitu perbuatan-perbuatan sihir mereka.\qt@no{118}}%
\qt@newcmd\qurantrans@id@mlxxiii{%
(Maka mereka kalah) yakni Firaun dan kaumnya (di tempat itu dan jadilah mereka orang-orang yang hina) artinya kini mereka menjadi orang-orang yang kecil lagi hina.\qt@no{119}}%
\qt@newcmd\qurantrans@id@mlxxiv{%
(Dan ahli-ahli sihir itu dengan serta-merta meniarapkan diri dengan bersujud).\qt@no{120}}%
\qt@newcmd\qurantrans@id@mlxxv{%
(Mereka berkata, ``Kami beriman kepada Tuhan semesta alam).\qt@no{121}}%
\qt@newcmd\qurantrans@id@mlxxvi{%
(Yaitu Tuhan Musa dan Harun") berkat pengetahuan mereka yang menyimpulkan bahwa apa yang telah mereka saksikan itu, yaitu tentang tongkat Musa semata-mata bukanlah perbuatan sihir.\qt@no{122}}%
\qt@newcmd\qurantrans@id@mlxxvii{%
(Firaun berkata, ``Apakah kamu beriman) lafal aamantum dapat dibaca a amantum (kepadanya) kepada Musa (sebelum aku memberi izin) (kepadamu? Sesungguhnya hal ini) apa yang kamu perbuat ini (adalah suatu muslihat yang telah kamu rencanakan di dalam kota ini untuk mengeluarkan penduduknya daripadanya, maka kelak kamu akan mengetahui) apa yang bakal kamu terima balasannya dariku.\qt@no{123}}%
\qt@newcmd\qurantrans@id@mlxxviii{%
(Demi sesungguhnya aku akan memotong tangan dan kakimu dengan bersilang secara timbal balik) yakni tangan kanan setiap orang akan dipotong berikut kaki sebelah kirinya (kemudian sungguh-sungguh aku akan menyalibmu semuanya.")\qt@no{124}}%
\qt@newcmd\qurantrans@id@mlxxix{%
(Ahli-ahli sihir itu menjawab, ``Sesungguhnya kepada Tuhan kamilah) sesudah kami mati dengan cara apa pun (kami kembali) dikembalikan kelak di akhirat.\qt@no{125}}%
\qt@newcmd\qurantrans@id@mlxxx{%
(Dan kamu tidak membalas dendam) maksudnya kamu tidak mengingkari (dengan menyiksa kami melainkan karena kami telah beriman kepada ayat-ayat Tuhan kami ketika ayat-ayat itu datang kepada kami." Mereka berdoa, ``Ya Tuhan kami, limpahkanlah kesabaran kepada kami) tatkala dilaksanakannya apa yang diancamkan oleh Firaun agar kami tidak kembali menjadi orang-orang kafir (dan wafatkanlah kami dalam keadaan berserah diri kepada-Mu.")\qt@no{126}}%
\qt@newcmd\qurantrans@id@mlxxxi{%
(Berkatalah pembesar-pembesar dari kaum Firaun,) kepada Firaun sendiri ("Apakah kamu membiarkan) meninggalkan (Musa dan kaumnya untuk membuat kerusakan di negeri ini) yaitu dengan menyeru ajakan agar menentangmu (dan meninggalkan kamu serta tuhan-tuhanmu?") tersebutlah bahwa Firaun itu telah membuat berhala-berhala kecil untuk disembah oleh kaumnya, kemudian Firaun berkata, ``Aku adalah tuhanmu dan tuhan mereka," oleh karena itu ia pernah mengatakan, ``Aku adalah tuhanmu yang paling tinggi." (Firaun menjawab, ``Akan kita bunuh) dengan mentasydidkan huruf ta-nya (anak-anak lelaki mereka) yang baru dilahirkan (dan kita biarkan hidup) kita biarkan (perempuan-perempuan mereka) sebagaimana yang pernah kita lakukan terhadap mereka sebelumnya (dan sesungguhnya kita berkuasa penuh di atas mereka.") yakni orang-orang yang berkuasa; akhirnya mereka melakukan hal itu terhadap kaum Musa, sehingga membuat kaum Bani Israel mengadu kepada Musa.\qt@no{127}}%
\qt@newcmd\qurantrans@id@mlxxxii{%
(Musa berkata kepada kaumnya, ``Mohonlah pertolongan kepada Allah dan bersabarlah) dalam menghadapi penganiayaan mereka (sesungguhnya bumi ini kepunyaan Allah yang dipusakakan-Nya) yang diberi-Nya (kepada siapa yang dikehendaki-Nya dari hamba-hamba-Nya. Dan kesudahan yang baik) yang terpuji (adalah bagi orang-orang yang bertakwa.") terhadap Allah.\qt@no{128}}%
\qt@newcmd\qurantrans@id@mlxxxiii{%
(Kaum Musa berkata, ``Kami telah ditindas, oleh Firaun, sebelum kamu datang kepada kami dan sesudah kamu datang." Musa menjawab, ``Mudah-mudahan Allah membinasakan musuhmu dan menjadikan kamu khalifah di bumi-Nya, maka Allah akan melihat bagaimana perbuatanmu.") di dalamnya.\qt@no{129}}%
\qt@newcmd\qurantrans@id@mlxxxiv{%
(Dan sesungguhnya Kami telah menghukum Firaun dan kaumnya dengan mendatangkan musim kemarau yang panjang) musim paceklik (dan kekurangan buah-buahan supaya mereka mengambil pelajaran) menjadikannya sebagai pelajaran bagi mereka kemudian mereka mau beriman karenanya.\qt@no{130}}%
\qt@newcmd\qurantrans@id@mlxxxv{%
(Kemudian apabila datang kepada mereka kemakmuran) kesuburan tanah dan kecukupan hidup (mereka berkata, ``Ini adalah karena usaha kami") kami berhak memperolehnya, akan tetapi mereka tidak mau mensyukurinya. (Dan jika mereka ditimpa kesusahan) kekeringan dan musibah/bencana (mereka lemparkan sebab kesialan itu) mereka menganggap kesialan itu (kepada Musa dan orang-orang yang besertanya) dari kalangan orang-orang yang beriman. (Ketahuilah sesungguhnya kesialan mereka itu) rasa sial mereka itu (adalah ketetapan dari Allah) yang sengaja diturunkan kepada mereka (akan tetapi kebanyakan mereka tidak mengetahui) bahwa apa yang menimpa mereka adalah datang dari sisi Allah.\qt@no{131}}%
\qt@newcmd\qurantrans@id@mlxxxvi{%
(Dan mereka berkata,) kepada Musa ("Bagaimana kamu mendatangkan keterangan kepada kami untuk menyihir kami dengan keterangan itu, maka kami sekali-kali tidak akan beriman kepadamu.") kemudian Musa berdoa agar mereka diberi pelajaran.\qt@no{132}}%
\qt@newcmd\qurantrans@id@mlxxxvii{%
(Maka Kami kirimkan kepada mereka taufan) yaitu air bah yang memasuki rumah-rumah mereka sehingga mencapai setinggi tempat pesanggrahan duduk mereka selama tujuh hari (belalang) kemudian belalang itu memakan persawahan dan buah-buahan milik mereka, demikian pula (kutu) ulat atau sejenis serangga yang memakan apa yang ditinggalkan oleh belalang (katak) kemudian katak itu memenuhi rumah-rumah mereka dan juga makanan-makanan mereka (dan darah) di dalam air milik mereka (sebagai bukti-bukti yang jelas) yang terang (tetapi mereka tetap menyombongkan diri) tidak mau beriman kepada bukti-bukti tersebut (dan mereka adalah kaum yang berdosa).\qt@no{133}}%
\qt@newcmd\qurantrans@id@mlxxxviii{%
(Dan ketika mereka ditimpa azab) yaitu siksaan (mereka pun berkata, ``Hai Musa! Mohonkanlah untuk kami kepada Tuhanmu dengan perantaraan kenabian yang diketahui Allah ada pada sisimu) yang dapat menghilangkan azab dari kami jika kami beriman (Sesungguhnya jika) lam adalah bermakna qasam/sumpah (kamu dapat menghilangkan azab itu dari kami, pasti kami akan beriman kepadamu dan akan kami biarkan Bani Israel pergi bersamamu.").\qt@no{134}}%
\qt@newcmd\qurantrans@id@mlxxxix{%
(Maka setelah Kami hilangkan) berkat doa Musa (dari mereka azab itu hingga batas waktu yang mereka sampai kepadanya, tiba-tiba mereka mengingkarinya) janjinya dan bersikeras melakukan kekafiran.\qt@no{135}}%
\qt@newcmd\qurantrans@id@mxc{%
(Kemudian Kami menghukum mereka, maka Kami tenggelamkan mereka di laut) laut yang airnya asin (disebabkan mereka) dikarenakan mereka (mendustakan ayat-ayat Kami dan mereka adalah orang-orang yang melalaikan ayat-ayat Kami) tetapi mereka tidak mau memikirkannya.\qt@no{136}}%
\qt@newcmd\qurantrans@id@mxci{%
(Dan Kami pusakakan kepada kaum yang telah ditindas itu) melalui perbudakan, yaitu mereka adalah kaum Bani Israel (negeri-negeri bagian timur dan bagian baratnya yang telah Kami beri berkah padanya) dengan air dan pohon, ini adalah kata sifat bagi tanah, yang dimaksud adalah tanah Syam (Dan telah sempurnalah perkataan Tuhanmu yang baik) yang dimaksud ialah firman-Nya, ``Dan Kami hendak memberi karunia kepada orang-orang yang tertindas di bumi, Mesir, itu." (Q.S. Al-Qashash 5) (untuk Bani Israel disebabkan kesabaran mereka) di dalam menanggung penganiayaan musuh mereka (dan Kami hancurkan) Kami binasakan (apa-apa yang telah dibuat Firaun dan kaumnya) bangunan-bangunannya (dan apa yang telah dibangun mereka) dengan mengkasrahkan ra-nya dan boleh juga didamahkan, yakni bangunan-bangunan yang telah mereka tinggikan.\qt@no{137}}%
\qt@newcmd\qurantrans@id@mxcii{%
(Dan Kami seberangkan) Kami lewatkan (Bani Israel ke seberang lautan itu, maka setelah mereka sampai) mereka lewat (pada suatu kaum yang tetap menyembah) dengan dibaca damah atau kasrah huruf kaf-nya (berhala mereka) mereka masih tetap menyembah berhala-berhala itu (Bani Israel berkata, ``Hai Musa! Buatlah untuk kami sebuah tuhan) berhala yang akan kami sembah (sebagaimana mereka mempunyai beberapa tuhan, berhala." Musa menjawab, ``Sesungguhnya kamu ini adalah kaum yang bodoh.") karena kamu membalas karunia Allah atas kamu dengan apa yang tadi kamu katakan.\qt@no{138}}%
\qt@newcmd\qurantrans@id@mxciii{%
(Sesungguhnya mereka itu akan dihancurkan) dibinasakan (kepercayaan yang dianutnya dan akan batal apa yang selalu mereka kerjakan).\qt@no{139}}%
\qt@newcmd\qurantrans@id@mxciv{%
(Musa menjawab, ``Patutkah aku mencari Tuhan untuk kamu yang selain daripada Allah?") yakni sesembahan; pada asalnya lafal abghiikum itu ialah abghii lakum (padahal Dialah yang telah melebihkan kamu atas segala umat) di zaman kamu sesuai dengan apa yang dituturkan dalam firman-Nya berikut ini.\qt@no{140}}%
\qt@newcmd\qurantrans@id@mxcv{%
(Dan) ingatlah kamu (ketika Kami menyelamatkan kamu) dan menurut suatu qiraat dibaca anjaakum (dari Firaun dan kaumnya yang mengazab kamu) mereka menyiksa dan menganiaya kamu (dengan azab yang sangat jahat) yakni siksaan/azab yang paling keras, yaitu dalam bentuk (yaitu mereka membunuh anak-anak lelakimu dan membiarkan hidup) tidak membunuh (wanita-wanitamu. Dan pada yang demikian itu) penyelamatan dan siksaan (cobaan) pemberian nikmat dan ujian (dari Tuhanmu, yaitu cobaan yang besar) maka apakah kamu tidak mau mengambil pelajaran darinya sehingga kamu berhenti dari apa yang kamu katakan itu.\qt@no{141}}%
\qt@newcmd\qurantrans@id@mxcvi{%
(Dan telah Kami janjikan) dengan memakai alif dan tidak memakainya (kepada Musa sesudah berlalu waktu tiga puluh malam) di mana Kami akan berbicara kepadanya seusai masa tersebut agar ia berpuasa terlebih dahulu; masa itu adalah bulan Zulkaidah kemudian Musa berpuasa dan tatkala ia selesai, bau mulutnya masih kurang enak. Akhirnya Musa bersiwak dan Allah swt. memerintahkannya agar melakukan puasa sepuluh hari lagi agar ia dapat berbicara dengan-Nya melalui mulutnya; hal ini telah dijelaskan dalam firman Allah swt. (dan Kami sempurnakan jumlah malam itu dengan sepuluh malam lagi) yakni dari bulan Zulhijah (maka sempurnalah waktu yang telah ditentukan Tuhannya) yaitu waktu yang telah dijanjikan oleh-Nya untuk berbicara dengan-Nya (empat puluh) menjadi hal (malam) menjadi tamyiz. (Dan berkata Musa kepada saudaranya, yaitu Harun) di kala hendak pergi ke bukit untuk bermunajat ("Gantikanlah aku) maksudnya jadilah engkau sebagai penggantiku (dalam memimpin kaumku dan perbaikilah") perkara mereka (dan janganlah kamu mengikuti jalan orang-orang yang membuat kerusakan) dengan menyetujui mereka berbuat kemaksiatan.\qt@no{142}}%
\qt@newcmd\qurantrans@id@mxcvii{%
(Dan tatkala Musa datang untuk munajat dengan Kami pada waktu yang telah Kami tentukan) waktu yang telah Kami janjikan kepadanya akan berbicara dengannya pada waktu itu (dan Tuhan telah berfirman kepadanya) tanpa perantara dengan pembicaraan yang dapat Musa dengar dari segala penjuru (berkatalah Musa, ``Ya Tuhanku! Tampakkanlah kepadaku) diri Engkau (agar aku dapat melihat-Mu." Tuhan berfirman, ``Kamu sekali-kali tidak sanggup melihat-Ku) artinya kamu tidak akan mampu melihat-Ku; bila hal itu diungkapkan bukan dengan memakai huruf lan, maka pengertiannya berarti melihat Tuhan itu mungkin dapat dilakukan (tetapi lihatlah kepada bukit itu) yang bangunannya lebih kuat daripada dirimu (maka jika ia tetap) tegak seperti sediakala (pada tempatnya, niscaya kamu dapat melihat-Ku") engkau dapat melihat-Ku dan jika tidak, maka niscaya kamu tidak akan kuat (Tatkala Tuhannya tampak) yakni sebagian dari nur-Nya yang hanya sebesar setengah jari manis, demikianlah menurut penjelasan dari hadis yang telah diriwayatkan oleh Al-Hakim (bagi gunung itu, kejadian itu menjadikan gunung itu hancur luluh) dengan dibaca qashr atau pendek dan panjang, yakni gunung itu menjadi lebur rata dengan tanah (dan Musa jatuh pingsan) tak sadarkan diri karena sangat terkejut melihat apa yang ia saksikan (Maka setelah Musa sadar kembali, dia berkata, ``Maha Suci Engkau) dengan memahasucikan Engkau (aku bertobat kepada Engkau) dari permintaan yang aku tidak diperintahkan mengemukakannya (dan aku orang yang pertama-tama beriman") pada zamanku ini.\qt@no{143}}%
\qt@newcmd\qurantrans@id@mxcviii{%
(Allah berfirman,) Maha Tinggi Allah ("Hai Musa, sesungguhnya Aku memilih melebihkan kamu) yakni Aku memilihmu (dari manusia) yang hidup di masamu (untuk membawa risalah-Ku) dengan memakai jamak dan mufrad/tunggal (dan untuk berbicara langsung dengan-Ku) Aku berbicara kepadamu secara langsung (sebab itu berpegang teguhlah kepada apa yang Aku berikan kepadamu) berupa keutamaan (dan hendaklah kamu termasuk orang-orang yang bersyukur") atas nikmat-nikmat-Ku.\qt@no{144}}%
\qt@newcmd\qurantrans@id@mxcix{%
(Dan telah Kami tuliskan untuk Musa pada lempengan-lempengan) lempengan-lempengan kitab Taurat yang terdiri dari dedaunan surga, atau dari zabarjad atau dari tujuh jenis atau sepuluh jenis zamrud (segala sesuatu) yang diperlukan di dalam menyampaikan agama (sebagai pelajaran dan penjelasan) keterangan (bagi segala sesuatu) menjadi badal dari jar dan majrur sebelumnya. (Maka berpeganglah kepadanya) sebelumnya terdapat kalimat Kami berfirman yang ditakdirkan/yang diperkirakan keberadaannya (dengan teguh) dengan sungguh-sungguh dan dengan segala kemampuan (dan suruhlah kaummu berpegang kepadanya dengan sebaik-baiknya, nanti Aku akan memperlihatkan kepadamu negeri orang-orang yang fasik) yakni Firaun beserta para pengikutnya, yaitu negeri Mesir, supaya kamu mengambil pelajaran darinya.\qt@no{145}}%
\qt@newcmd\qurantrans@id@mc{%
(Aku akan memalingkan dari ayat-ayat-Ku) dari bukti-bukti yang menunjukkan kekuasaan-Ku, yaitu berupa hasil-hasil ciptaan-Ku dan lain-lainnya (orang-orang yang menyombongkan dirinya di muka bumi tanpa alasan yang benar) yaitu Aku akan menjadikan mereka terhina sehingga tidak lagi mereka berlaku sombong di muka bumi (jika mereka melihat tiap-tiap ayat-Ku, mereka tidak beriman kepadanya. Dan jika mereka melihat jalan) yakni titian (yang membawa kepada petunjuk) hidayah yang datang dari sisi Tuhan (mereka tidak mau menjalankannya sebagai jalan hidup) yang mereka tempuh (tetapi jika mereka melihat jalan kesesatan) jalan yang salah (mereka terus menempuhnya. Yang demikian itu) berpalingnya mereka itu (adalah karena mereka mendustakan ayat-ayat Kami dan mereka selalu lalai daripadanya) contoh mengenai mereka telah disebutkan.\qt@no{146}}%
\qt@newcmd\qurantrans@id@mci{%
(Dan orang-orang yang mendustakan ayat-ayat Kami dan mendustakan akan menemui akhirat) dimaksud mengenai hari berbangkit dan lain-lainnya (sia-sialah) artinya batillah (perbuatan mereka) yaitu perbuatan-perbuatan yang telah mereka lakukan sewaktu hidup di alam dunia, berupa amal-amal kebaikan seperti silaturahmi dan sedekah, maka mereka tidak lagi mendapat pahalanya karena persyaratannya sudah tidak memenuhi lagi (Tidak) (mereka itu mendapat balasan kecuali) hanya balasan (apa yang telah mereka kerjakan) yakni perbuatan mendustakan ayat-ayat Kami dan perbuatan-perbuatan maksiat.\qt@no{147}}%
\qt@newcmd\qurantrans@id@mcii{%
(Dan kaum Musa, setelah kepergian Musa, mereka membuat) setelah pergi meninggalkan mereka untuk bermunajat (dari perhiasan mereka) yang telah mereka pinjam dari kaumnya Firaun dengan alasan untuk perkawinan (berhala) yang kemudian dipuja-puja oleh mereka (anak lembu) Samirilah yang mencetaknya berdasarkan permintaan mereka (yang bertubuh) sebagai ganti dari daging dan darah (dan bersuara) artinya suara yang dapat didengar; dan dapat bergerak sebab Samiri menaruh debu di mulutnya dari bekas teracak kuda malaikat Jibril, sebagai pengaruhnya berhala itu dapat hidup. Maf'ul dari lafal ittakhadza dibuang yang asalnya ialah lafal ilaahan, yakni sebagai tuhan. (Apakah mereka tidak mengetahui bahwa anak lembu itu tidak dapat berbicara dengan mereka dan tidak dapat pula menunjukkan jalan kepada mereka?) lalu mengapa mereka menganggapnya sebagai tuhan mereka (Mereka menjadikannya) sebagai sesembahan (dan mereka adalah orang-orang yang lalim) disebabkan mengambilnya sebagai sesembahan.\qt@no{148}}%
\qt@newcmd\qurantrans@id@mciii{%
(Dan setelah mereka menyesali perbuatannya) mereka menyesal mengambil sebagai sesembahan mereka (dan mereka melihat) mereka mengetahui (bahwa mereka telah sesat) oleh sebab perbuatan itu; penyesalan itu datang setelah Musa kembali kepada mereka (mereka pun berkata, ``Sungguh jika Tuhan kami tidak memberi rahmat kepada kami dan tidak mengampuni kami) dengan memakai ya dan ta pada kedua fi'ilnya (pastilah kami menjadi orang-orang yang merugi.").\qt@no{149}}%
\qt@newcmd\qurantrans@id@mciv{%
(Dan tatkala Musa kembali kepada kaumnya dalam keadaan marah) oleh sebab perbuatan mereka (dan sedih hati) yakni amat bersedih hati (berkatalah dia,) kepada mereka ("Alangkah buruknya perbuatan) teramat jelek perbuatan (yang kamu kerjakan) dalam hal ini (sesudah kepergianku!) dimaksud pekerjaanmu ini di mana kamu berlaku musyrik. (Apakah kamu hendak mendahului janji Tuhanmu?" Dan Musa pun melemparkan lempengan-lempengan) yaitu lempengan-lempengan Kitab Taurat karena marah kepada kaumnya, sehingga lempengan-lempengan itu pecah (dan ia memegang rambut kepala saudaranya) dengan tangan kanannya dan jenggotnya dengan tangan kirinya (sambil menariknya ke arahnya) saking marahnya (Harun berkata,) ``Hai (anak ibuku!) dengan mim dikasrahkan dan difathahkan, yang dimaksud adalah ummi, penyebutan dengan kata-kata ini untuk lebih menimbulkan rasa sayang ke dalam hati Musa (Sesungguhnya kaum ini telah menganggapku lemah dan hampir-hampir mereka) hampir saja (membunuhku, sebab itu janganlah kamu menjadikan gembira) membuat girang (musuh-musuh melihatku) karena kamu menghinakan diriku (dan janganlah kamu masukkan aku ke dalam golongan orang-orang yang lalim.") sebagaimana engkau memperlakukan orang yang benar-benar menyembah anak sapi.\qt@no{150}}%
\qt@newcmd\qurantrans@id@mcv{%
(Musa berdoa, ``Ya Tuhanku! Ampunilah aku) atas apa yang telah kuperbuat terhadap saudaraku (dan saudaraku) Musa menyertakan saudaranya dalam doa demi untuk membuatnya rela atas apa yang telah ia lakukan kepadanya dan sekaligus untuk menolak agar musuh jangan girang melihat sikapnya terhadap saudaranya itu (dan masukkanlah kami ke dalam rahmat Engkau, dan Engkau adalah Maha Penyayang di antara para penyayang.") Allah berfirman,\qt@no{151}}%
\qt@newcmd\qurantrans@id@mcvi{%
("Sesungguhnya orang-orang yang menjadikan anak lembu) sebagai sesembahan (kelak akan menimpa mereka kemurkaan) yakni azab (dari Tuhan mereka dan kehinaan dalam kehidupan di dunia) maka mereka dihukum dengan perintah agar mereka membunuh diri mereka sendiri dan kehinaan akan selalu menimpa mereka sampai hari kiamat nanti. (Demikianlah) seperti apa yang telah Kami balaskan kepada mereka (Kami memberi balasan kepada orang-orang yang membuat-buat kebohongan) terhadap Allah dengan melakukan perbuatan syirik dan lain-lainnya.\qt@no{152}}%
\qt@newcmd\qurantrans@id@mcvii{%
(Dan orang-orang yang mengerjakan kejahatan; kemudian bertobat) kembali tidak melakukannya (sesudah itu dan beriman) terhadap Allah (sesungguhnya Tuhan kamu sesudahnya) sesudah tobat (adalah Maha Pengampun) kepada mereka (lagi Maha Penyayang").\qt@no{153}}%
\qt@newcmd\qurantrans@id@mcviii{%
(Sesudah mereda) telah tenang (amarah Musa, lalu diambilnya kembali lempengan-lempengan itu) yang telah ia banting itu (dan dalam tulisannya) apa yang tertulis di dalam lempengan kitab Taurat itu (terdapat petunjuk) dari kesesatan (dan rahmat untuk orang-orang yang takut kepada Tuhannya) mereka takut kepada-Nya; huruf lam dimasukkan ke dalam maf'ul mengingat tempatnya yang didahulukan.\qt@no{154}}%
\qt@newcmd\qurantrans@id@mcix{%
(Dan Musa memilih dari kaumnya) dimaksud sebagian dari kaumnya (sebanyak tujuh puluh orang lelaki) dari kalangan orang-orang yang tidak ikut menyembah anak sapi, ia lakukan hal itu berdasarkan perintah dari Allah swt. (untuk memenuhi waktu yang telah Kami tentukan) waktu yang telah Kami janjikan, agar mereka datang tepat pada waktunya, untuk memohon ampunan dari penyembahan terhadap anak sapi yang telah dilakukan oleh teman-teman mereka. Kemudian Musa keluar bersama mereka. (Maka ketika mereka diguncang gempa bumi) yaitu gempa yang dahsyat. Ibnu Abbas mengatakan, ``Sebab mereka tidak melarang kaumnya tatkala menyembah anak sapi itu," selanjutnya Ibnu Abbas mengatakan lagi, ``Mereka adalah selain dari orang-orang yang meminta agar dapat melihat Tuhan yang kemudian ditimpa azab berupa sha`iqah" (Ia berkata,) yakni Musa ("Ya Tuhanku! Kalau Engkau kehendaki tentulah Engkau membinasakan sebelum ini) sebelum aku keluar bersama mereka; maksud Musa untuk menentukan nasib kaum Bani Israel sehubungan dengan peristiwa penyembahan anak sapi itu, agar jika mereka terkena azab tidak menuduhku sebagai penyebabnya (dan aku. Apakah Engkau membinasakan kami karena perbuatan orang-orang yang kurang akal di antara kami?) Istifham bermakna isti`thaf, memohon belas kasihan, yakni janganlah Engkau menyiksa kami oleh sebab dosa yang dilakukan oleh selain kami. (Tidak lain) (itu) fitnah yang dilakukan oleh orang-orang yang akalnya kurang (kecuali hanyalah fitnah dari Engkau) dimaksud cobaan dari Engkau (Engkau sesatkan dengan cobaan itu siapa yang Engkau kehendaki) kesesatannya (dan Engkau beri petunjuk kepada siapa yang Engkau kehendaki) kehidayahannya. (Engkaulah yang memimpin kami) yang menguasai perkara-perkara kami (maka ampunilah kami, dan berilah kami rahmat dan Engkaulah Pemberi ampun yang sebaik-baiknya.")\qt@no{155}}%
\qt@newcmd\qurantrans@id@mcx{%
(Dan tetapkanlah) pastikanlah (untuk kami kebaikan di dunia ini dan di akhirat) kebaikan (sesungguhnya kami kembali pada jalan hidayah) maksudnya kami telah bertobat (kepada-Mu. Allah berfirman,) Maha Tinggi Allah ("Siksa-Ku akan Kutimpakan kepada siapa yang Aku kehendaki) Aku ingin menyiksanya (dan rahmat-Ku meliputi) menyeluruh (segala sesuatu) yang ada di dunia (Maka akan Aku tetapkan rahmat-Ku) di akhirat kelak (untuk orang-orang yang bertakwa yang menunaikan zakat dan orang-orang yang beriman kepada ayat-ayat Kami.")\qt@no{156}}%
\qt@newcmd\qurantrans@id@mcxi{%
(Yaitu orang-orang yang mengikut rasul, nabi yang ummi) yaitu Nabi Muhammad saw. (yang namanya mereka dapati tertulis di dalam Taurat dan Injil yang ada di sisi mereka) lengkap dengan nama dan ciri-cirinya (yang menyuruh mereka mengerjakan yang makruf dan melarang mereka dari mengerjakan yang mungkar dan menghalalkan bagi mereka segala yang baik) dari apa yang sebelumnya diharamkan oleh syariat mereka (dan mengharamkan bagi mereka segala yang buruk) yaitu bangkai dan lain-lainnya (dan membuang dari mereka beban-beban) maksud tanggungan mereka (dan belenggu-belenggu) hal-hal yang berat (yang ada pada mereka) seperti bertobat dengan jalan membunuh diri dan memotong apa yang terkena oleh najis. (Maka orang-orang yang beriman kepadanya) dari kalangan mereka (memuliakannya) yaitu menghormatinya (menolongnya dan mengikuti cahaya yang terang yang diturunkan kepadanya) yakni Alquran (mereka itulah orang-orang yang beruntung).\qt@no{157}}%
\qt@newcmd\qurantrans@id@mcxii{%
(Katakanlah,) pembicaraan ini ditujukan kepada Nabi saw. ("Hai manusia! Sesungguhnya aku adalah utusan Allah kepadamu semua, yaitu Allah yang mempunyai kerajaan langit dan bumi; tidak ada Tuhan selain Dia; yang menghidupkan dan mematikan, maka berimanlah kamu kepada Allah dan rasul-Nya, nabi yang ummi yang beriman kepada Allah dan kepada kalimat-kalimat-Nya) yakni Alquran (dan ikutilah dia, supaya kamu mendapat petunjuk.") artinya kamu akan mendapat bimbingan hidayah.\qt@no{158}}%
\qt@newcmd\qurantrans@id@mcxiii{%
(Dan di antara kaum Musa itu terdapat suatu umat) suatu jemaah (yang memberi petunjuk) kepada manusia (dengan hak dan dengan yang hak itulah mereka menjalankan keadilan) di dalam memberikan keputusan hukum.\qt@no{159}}%
\qt@newcmd\qurantrans@id@mcxiv{%
(Dan Kami bagi mereka) Kami pecahkan kaum Bani Israel (menjadi dua belas) sebagai hal (suku-suku) menjadi badal dari yang sebelumnya, yaitu kabilah-kabilah (yang masing-masingnya berjumlah besar) menjadi badal dari yang sebelumnya (dan Kami wahyukan kepada Musa ketika kaumnya meminta air kepadanya,) di tengah padang sahara ("Pukullah batu itu dengan tongkatmu!") kemudian Musa memukulkannya (maka memancarlah) maksudnya tersemburlah (daripadanya dua belas mata air) sesuai dengan bilangan kabilah (Sesungguhnya tiap-tiap suku telah mengetahui) setiap suku dari kalangan mereka (tempat minum masing-masing. Dan Kami naungkan awan di atas mereka) di padang pasir tempat mereka berada guna melindungi mereka dari panasnya matahari (dan Kami turunkan kepada mereka manna dan salwa) keduanya adalah taranjabin, makanan manis seperti madu, dan sebangsa burung puyuh dengan ditakhfifkan mimnya dan dibaca pendek. Dan Kami berfirman kepada mereka, ("Makanlah yang baik-baik dari apa yang telah Kami rezekikan kepadamu." Mereka tidak menganiaya Kami, tetapi merekalah yang selalu menganiaya dirinya sendiri).\qt@no{160}}%
\qt@newcmd\qurantrans@id@mcxv{%
(Dan) Ingatlah (ketika dikatakan kepada mereka, Bani Israel, ``Diamlah di negeri ini saja) yaitu Baitulmakdis (dan makanlah dari hasil buminya di mana saja kamu kehendaki. Dan katakanlah,) perintah Kami ('Bebaskanlah kami dari dosa kami' dan masukilah pintunya) pintu gerbang negeri itu (sambil membungkuk) dengan membungkukkan punggung (niscaya Kami ampuni) dengan memakai nun dan ta, dan bina maf'ul (kesalahan-kesalahanmu." Kelak Kami akan tambah pahala kepada orang-orang yang berbuat baik) orang-orang yang taat pahala.\qt@no{161}}%
\qt@newcmd\qurantrans@id@mcxvi{%
(Maka orang-orang yang lalim di antara mereka itu mengganti perkataan itu dengan perkataan yang tidak dikatakan kepada mereka) mereka mengatakan, ``Habbatun fii sya`ratin sebagai ganti dari hiththatun" dan kemudian mereka memasuki pintu gerbangnya sambil merangkak bukannya membungkukkan badan (maka Kami timpakan kepada mereka azab) yakni siksaan (dari langit disebabkan kelaliman mereka.)\qt@no{162}}%
\qt@newcmd\qurantrans@id@mcxvii{%
(Dan tanyakanlah kepada Bani Israel) hai Muhammad, sebagai celaan (tentang negeri yang terletak di dekat laut) di pinggir laut Qalzum yaitu kota Aylah; yang dipertanyakan ialah tentang apa yang terjadi atas penduduknya (ketika mereka melanggar aturan) saat mereka melakukan pelanggaran (pada hari Sabtu) di mana mereka berburu ikan yang pada hari itu mereka dilarang melakukannya (di waktu) merupakan zharaf dari lafal ya'duuna (datang kepada mereka ikan-ikan pada hari Sabtunya dengan terapung-apung pada pinggirannya) yang tampak di permukaan air (dan di hari-hari yang bukan Sabtu) maksudnya di mana mereka sudah tidak lagi terikat dengan pengagungan hari Sabtu, atau dengan kata lain ialah hari-hari selain hari Sabtu (ikan-ikan itu tidak datang kepada mereka) sebagai ujian dari Allah. (Demikianlah Kami mencoba mereka disebabkan mereka berlaku fasik) dan tatkala mereka hendak berburu ikan para penduduk kota terbagi suaranya menjadi tiga bagian; sebagian berpendapat ikut berburu bersama orang-orang yang berburu, sebagian lainnya mencegah mereka melakukannya dan sebagian lainnya bersikap abstain, tidak ikut dan juga tidak melarang.\qt@no{163}}%
\qt@newcmd\qurantrans@id@mcxviii{%
(Dan ketika) diathafkan kepada lafal idz yang sebelumnya (suatu umat di antara mereka berkata,) yaitu kaum yang tidak ikut berburu dan juga tidak melarang orang-orang yang berburu ("Mengapa kamu menasihati kaum yang Allah akan membinasakan mereka atau mengazab mereka dengan azab yang keras?" Mereka menjawab,) nasihat kami ("Agar kami mempunyai alasan) yang bisa dijadikan sebagai pelepas tanggung jawab (kepada Tuhanmu) supaya kami tidak dituduh lalai dalam masalah tidak memberikan larangan kepada mereka (dan supaya mereka bertakwa.") tidak berani melakukan perburuan lagi.\qt@no{164}}%
\qt@newcmd\qurantrans@id@mcxix{%
(Maka tatkala mereka melupakan) yaitu mereka meninggalkan (apa yang diperingatkan kepada mereka) apa yang dinasihatkan kepada mereka (tentang hal itu) kemudian mereka tidak mau juga menuruti nasihat (Kami selamatkan orang-orang yang melarang dari perbuatan jahat dan Kami timpakan kepada orang-orang yang lalim) yang melakukan pelanggaran (siksaan yang berat) yang keras (disebabkan mereka selalu berbuat fasik.)\qt@no{165}}%
\qt@newcmd\qurantrans@id@mcxx{%
(Maka tatkala mereka bersikap sombong) yakni bersikap takabur (terhadap) tidak mau meninggalkan (apa yang dilarang mereka mengerjakannya, Kami katakan kepada mereka, ``Jadilah kamu kera yang hina.") yang terhina, maka jadilah mereka itu kera yang hina; keterangan ini adalah penjelasan dari apa yang telah lalu. Ibnu Abbas mengatakan, ``Saya tidak mengetahui tentang apa yang terjadi dengan golongan yang bersikap abstain." Ikrimah mengatakan, ``Mereka tidak dibinasakan, sebab mereka membenci apa yang telah dilakukan rekan-rekannya dan mereka mengatakan, 'Mengapa kamu menasihati....'." Hakim telah meriwayatkan dari Ibnu Abbas bahwa golongan tersebut ikut pula melakukannya dan bahkan takjub dengan sikap mereka yang melakukannya.\qt@no{166}}%
\qt@newcmd\qurantrans@id@mcxxi{%
(Dan ketika memberitahukan) mempermaklumkan (Tuhanmu, bahwa sesungguhnya Dia akan mengirim kepada mereka) dimaksud orang-orang Yahudi (sampai hari kiamat orang-orang yang akan menimpakan kepada mereka azab yang seburuk-buruknya) dengan dihinakan dan dibebani pajak/jizyah; kemudian Allah mengutus Nabi Sulaiman kepada mereka, dan sesudah itu Raja Bukhtunasher (Nebukat Nezar) yang membunuh dan menawan mereka serta mewajibkan mereka membayar jizyah. Mereka selalu membayar jizyah kepada orang-orang Majusi sehingga Allah swt. mengutus nabi kita Muhammad saw. yang kemudian mengambil pula jizyah dari mereka. (Sesungguhnya Tuhanmu amat cepat siksa-Nya) (dan sesungguhnya Dia Maha Pengampun) terhadap orang-orang yang taat kepada-Nya (lagi Maha Penyayang) terhadap mereka yang taat.\qt@no{167}}%
\qt@newcmd\qurantrans@id@mcxxii{%
(Dan Kami bagi-bagi mereka) Kami pecah-pecah mereka (di dunia menjadi beberapa golongan) terdiri dari beberapa golongan (di antaranya ada orang-orang yang saleh dan di antaranya) ada orang-orang (yang tidak demikian) yaitu menjadi orang-orang kafir dan orang-orang fasik (Dan Kami coba mereka dengan yang baik-baik) yang nikmat-nikmat (dan yang buruk-buruk) dengan bencana-bencana (agar mereka kembali) kepada kebenaran dan tidak mau berbuat fasik lagi.\qt@no{168}}%
\qt@newcmd\qurantrans@id@mcxxiii{%
(Maka datanglah sesudah mereka generasi yang jahat yang mewarisi Alkitab) yakni kitab Taurat dari para pendahulu mereka (yang mengambil harta benda dunia yang rendah ini) sesuatu yang tidak ada harganya, yaitu duniawi baik yang halal maupun yang haram (dan berkata, ``Kami akan diberi ampun.") atas apa yang telah kami lakukan. (Dan kelak jika datang kepada mereka harta benda dunia sebanyak itu pula niscaya mereka akan mengambilnya juga) jumlah kalimat ini menjadi hal; artinya mereka masih juga mengharapkan ampunan sedangkan mereka masih tetap kembali melakukannya padahal di dalam kitab Taurat tidak ada janji ampunan jika disertai dengan menetapi perbuatan dosa (bukankah sudah diambil) Istifham atau kata tanya bermakna menetapkan (perjanjian kitab Taurat dari mereka) Idhafah di sini bermakna fii (yaitu bahwa mereka tidak akan mengatakan terhadap Allah kecuali yang benar, padahal mereka telah mempelajari) diathafkan kepada lafal yu`khadzu, yakni mereka telah membaca (apa yang tersebut di dalamnya?) maka mengapa mereka mendustakan tentang masalah ampunan itu, sedangkan mereka masih terus menepati perbuatan dosanya. (Dan kampung akhirat itu lebih baik bagi mereka yang bertakwa) yang takut terhadap perbuatan haram. (Maka apakah mereka tidak mengerti) dengan memakai ya dan ta, sesungguhnya pahala akhirat itu lebih baik yang seharusnya mereka lebih memilihnya daripada perkara duniawi.\qt@no{169}}%
\qt@newcmd\qurantrans@id@mcxxiv{%
(Dan orang-orang yang berpegang teguh) dengan memakai tasydid dan tidak/takhfif (dengan Alkitab Taurat) yaitu sebagian di antara mereka (serta mendirikan salat) seperti Abdullah bin Salam dan teman-temannya. (Sesungguhnya Kami tidak menyia-nyiakan pahala orang-orang yang mengadakan perbaikan) Jumlah kalimat ini menjadi khabar dari lafal lilladziina; dan di dalamnya terkandung meletakkan isim zhahir pada tempat isim dhamir; yakni ajrahum/pahala mereka.\qt@no{170}}%
\qt@newcmd\qurantrans@id@mcxxv{%
(Dan) ingatlah (ketika Kami mengangkat bukit) yaitu Kami mencabutnya dari dasarnya (ke atas mereka seakan-akan bukit itu naungan awan dan mereka menduga) dan merasa yakin (bahwa bukit itu akan jatuh menimpa mereka) akan jatuh kepada mereka sesuai dengan janji Allah kepada mereka, bahwa hal itu akan menimpa mereka jika mereka tidak mau menerima hukum-hukum syariat kitab Taurat. Mereka menolaknya mengingat hal itu teramat berat pada permulaannya tetapi kemudian mereka mau menerimanya. Kami berfirman kepada mereka, ("Peganglah dengan teguh apa yang telah Kami berikan kepadamu) dengan sungguh-sungguh dan dengan segala kemampuan (serta ingatlah selalu apa yang tersebut di dalamnya) dengan mengamalkannya (supaya kamu menjadi orang-orang yang bertakwa.").\qt@no{171}}%
\qt@newcmd\qurantrans@id@mcxxvi{%
(Dan) ingatlah (ketika) sewaktu (Tuhanmu mengeluarkan keturunan anak-anak Adam dari sulbi mereka) menjadi badal isytimal dari lafal sebelumnya dengan mengulangi huruf jar (yaitu anak cucu mereka) maksudnya Dia mengeluarkan sebagian mereka dari tulang sulbi sebagian lainnya yang berasal dari sulbi Nabi Adam secara turun-temurun, sebagaimana sekarang mereka beranak-pinak mirip dengan jagung di daerah Nu`man sewaktu hari Arafah/musim jagung. Allah menetapkan kepada mereka bukti-bukti yang menunjukkan ketuhanan-Nya serta Dia memberinya akal (dan Allah mengambil kesaksian terhadap jiwa mereka) seraya berfirman, ("Bukankah Aku ini Tuhanmu?" Mereka menjawab, ``Betul.) Engkau adalah Tuhan kami (kami menjadi saksi.") yang demikian itu. Kesaksian itu supaya (tidak) jangan (kamu mengatakan) dengan memakai ya dan ta pada dua tempat, yakni orang-orang kafir (di hari kiamat kelak, ``Sesungguhnya kami terhadap hal-hal ini) yakni keesaan Tuhan (adalah orang-orang yang lalai.") kami tidak mengetahuinya.\qt@no{172}}%
\qt@newcmd\qurantrans@id@mcxxvii{%
(Atau agar kamu tidak mengatakan, ``Sesungguhnya orang-orang tua kami telah mempersekutukan Tuhan sejak dahulu) dimaksud sebelum kami (sedangkan kami ini adalah anak-anak keturunan yang datang sesudah mereka) maka kami hanya mengikut mereka (Maka apakah Engkau akan membinasakan kami) Engkau akan mengazab kami (karena perbuatan orang-orang yang sesat dahulu?") dari kalangan orang-orang tua kami yang pertama kali melakukan kemusyrikan. Kesimpulan pengertian dari ayat ini bahwa mereka tidak mungkin berhujah dengan alasan itu sedangkan mereka telah melakukan kesaksian terhadap diri mereka sendiri tentang keesaan Tuhan itu. Penuturan tentang hal ini melalui lisan pemilik mukjizat/Nabi Muhammad saw. kedudukannya sama dengan penuturan terhadap jiwa manusia semuanya.\qt@no{173}}%
\qt@newcmd\qurantrans@id@mcxxviii{%
(Dan demikianlah Kami menjelaskan ayat-ayat itu) Kami menerangkan seperti apa yang telah Kami jelaskan di dalam perjanjian kesaksian supaya mereka memikirkannya (agar mereka kembali) dari kekafiran mereka kepada kebenaran.\qt@no{174}}%
\qt@newcmd\qurantrans@id@mcxxix{%
(Dan bacakanlah) hai Muhammad (kepada mereka) yakni orang-orang Yahudi (berita) kabar (orang yang telah Kami berikan kepadanya ayat-ayat Kami, pengetahuan tentang isi Alkitab, kemudian dia melepaskan diri dari ayat-ayat itu) maksudnya ia keluar darinya dengan membawa kekafirannya, sebagaimana seekor ular keluar dari kulitnya, orang yang dimaksud ialah Bal`am bin Ba`ura salah seorang ulama terkemuka Bani Israel. Ia diminta agar mendoakan Musa celaka dan untuk itu diberi hadiah, dia mendoakan hal itu tetapi doanya itu menyebabkan senjata makan tuan akhirnya lidahnya menjulur sampai ke dadanya (lalu dia diikuti oleh setan) setan dapat menggodanya sehingga jadilah ia temannya (maka jadilah ia termasuk orang-orang yang sesat).\qt@no{175}}%
\qt@newcmd\qurantrans@id@mcxxx{%
(Dan kalau Kami menghendaki, sesungguhnya Kami tinggikan dia) kepada derajat para ulama (dengan ayat-ayat itu) seumpamanya Kami memberikan taufik/kekuatan kepadanya untuk mengamalkan ayat-ayat itu (tetapi dia cenderung) yaitu lebih menyukai (kepada tanah) yakni harta benda dan duniawi (dan menurutkan hawa nafsunya yang rendah) dalam doa yang dilakukannya, akhirnya Kami balik merendahkan derajatnya. (Maka perumpamaannya) ciri khasnya (seperti anjing jika kamu menghalaunya) mengusir dan menghardiknya (diulurkannya lidahnya) lidahnya menjulur (atau) jika (kamu membiarkannya dia mengulurkan lidahnya juga) sedangkan sifat seperti itu tidak terdapat pada hewan-hewan selain anjing. Kedua jumlah syarat menjadi hal, ia menjulurkan lidahnya dalam keadaan terhina dalam segala kondisi. Maksudnya penyerupaan/tasybih ini ialah mengumpamakan dalam hal kerendahan dan kehinaan dengan qarinah adanya fa yang memberikan pengertian tertib dengan kalimat sebelumnya, yakni kecenderungan terhadap duniawi dan mengikuti hawa nafsu rendahnya, juga karena adanya qarinah/bukti firman-Nya, (Demikian itulah) perumpamaan itulah (perumpamaan orang-orang yang mendustakan ayat-ayat Kami. Maka ceritakanlah kisah-kisah itu) kepada orang-orang Yahudi (agar mereka berpikir) agar mereka mau memikirkannya hingga mereka mau beriman.\qt@no{176}}%
\qt@newcmd\qurantrans@id@mcxxxi{%
(Amat buruklah) amat jeleklah (perumpamaan suatu kaum) yaitu perumpamaan kaum itu (yaitu orang-orang yang mendustakan ayat-ayat Kami dan kepada diri mereka sendirilah mereka berbuat lalim) dengan mendustakan ayat-ayat itu.\qt@no{177}}%
\qt@newcmd\qurantrans@id@mcxxxii{%
(Barang siapa yang diberi petunjuk oleh Allah, maka dialah yang mendapat petunjuk dan barang siapa yang disesatkan Allah, maka merekalah orang-orang yang merugi).\qt@no{178}}%
\qt@newcmd\qurantrans@id@mcxxxiii{%
(Dan sesungguhnya Kami jadikan) Kami ciptakan (untuk isi neraka Jahanam kebanyakan dari jin dan manusia, mereka mempunyai hati tetapi tidak dipergunakan untuk memahami ayat-ayat Allah) yakni perkara hak (dan mereka mempunyai mata tetapi tidak dipergunakannya untuk melihat tanda-tanda kekuasaan Allah) yaitu bukti-bukti yang menunjukkan kekuasaan Allah dengan penglihatan yang disertai pemikiran (dan mereka mempunyai telinga tetapi tidak dipergunakannya untuk mendengar ayat-ayat Allah) ayat-ayat Allah dan nasihat-nasihat-Nya dengan pendengaran yang disertai pemikiran dan ketaatan (mereka itu sebagai binatang ternak) dalam hal tidak mau mengetahui, melihat dan mendengar (bahkan mereka lebih sesat) dari hewan ternak itu sebab hewan ternak akan mencari hal-hal yang bermanfaat bagi dirinya dan ia akan lari dari hal-hal yang membahayakan dirinya tetapi mereka itu berani menyuguhkan dirinya ke dalam neraka dengan menentang (mereka itulah orang-orang yang lalai)\qt@no{179}}%
\qt@newcmd\qurantrans@id@mcxxxiv{%
(Allah mempunyai asma-asma yang baik) yang sembilan puluh sembilan, demikianlah telah disebutkan oleh hadis. Al-husna adalah bentuk muannats dari al-ahsan (maka bermohonlah kepada-Nya) sebutkanlah Dia olehmu (dengan menyebut nama-nama-Nya itu dan tinggalkanlah) maksudnya biarkanlah (orang-orang yang menyimpang dari kebenaran) berasal dan kata alhada dan lahada, yang artinya mereka menyimpang dari perkara yang hak (dalam menyebut nama-nama-Nya) artinya mereka mengambil nama-nama tersebut untuk disebutkan kepada sesembahan-sesembahan mereka, seperti nama Latta yang berakar dari lafal Allah, dan Uzzaa yang berakar dari kata Al-Aziiz, dan Manaat yang berakar dari kata Al-Mannaan (nanti mereka akan mendapat balasan) kelak di akhirat sebagai pembalasannya (terhadap apa yang telah mereka kerjakan) ketentuan ini sebelum turunnya ayat perintah berperang.\qt@no{180}}%
\qt@newcmd\qurantrans@id@mcxxxv{%
(Dan di antara orang-orang yang Kami ciptakan ada umat yang memberi petunjuk dengan hak, dan dengan yang hak itu pula mereka menjalankan keadilan) mereka adalah umat Muhammad saw. sebagaimana yang telah dijelaskan oleh hadis.\qt@no{181}}%
\qt@newcmd\qurantrans@id@mcxxxvi{%
(Dan orang-orang yang mendustakan ayat-ayat Kami) yakni Alquran, dari kalangan penduduk Mekah (nanti Kami akan menarik mereka secara berangsur-angsur) Kami akan mengazab mereka sedikit demi sedikit (dengan cara yang tidak mereka ketahui).\qt@no{182}}%
\qt@newcmd\qurantrans@id@mcxxxvii{%
(Dan Aku memberi tangguh kepada mereka) Kami menangguhkan mereka (Sesungguhnya rencana-Ku amat tangguh) amat keras dan tidak bisa ditahan.\qt@no{183}}%
\qt@newcmd\qurantrans@id@mcxxxviii{%
(Apakah mereka tidak memikirkan) kemudian mereka dapat mengetahui (bahwa teman mereka) yaitu Muhammad saw. (tidak berpenyakit gila) bukanlah kurang akal (tidak lain) (dia hanyalah seorang pemberi peringatan lagi pemberi penjelasan) yang jelas peringatannya.\qt@no{184}}%
\qt@newcmd\qurantrans@id@mcxxxix{%
(Dan apakah mereka tidak memperhatikan kerajaan) kekuasaan (langit dan bumi dan) di dalam (segala sesuatu yang diciptakan Allah) merupakan penjelasan dari apa yang sebelumnya, dengan hal itu mereka menyimpulkan tentang kekuasaan dan keesaan penciptanya (dan bahwasanya) sehubungan dengan (kemungkinan telah dekatnya) (kebinasaan mereka?) kemudian mereka mati dalam keadaan kafir, lalu mereka dimasukkan ke dalam neraka. Mengapa mereka tidak bersegera untuk beriman. (Maka kepada berita manakah lagi sesudahnya) yakni sesudah berita Alquran (mereka akan beriman?)\qt@no{185}}%
\qt@newcmd\qurantrans@id@mcxl{%
(Barang siapa yang Allah sesatkan, maka baginya tak ada orang yang akan memberi petunjuk. Dan Allah membiarkan mereka) dengan memakai ya dan nun serta dirafa`kan sebagai jumlah isti'naf/permulaan; sedangkan apabila dijazamkan maka diathafkan secara mahall kepada lafal sesudah fa (terombang-ambing dalam kesesatan) mereka terombang-ambing dalam keadaan bingung.\qt@no{186}}%
\qt@newcmd\qurantrans@id@mcxli{%
(Mereka menanyakan kepadamu) yaitu mereka penduduk kota Mekah (tentang kiamat,) tentang hari akhir ("Bilakah) kapan (terjadinya?" Katakanlah,) kepada mereka ("Sesungguhnya pengetahuan tentang kiamat itu) bila terjadinya (adalah pada sisi Tuhanku; tidak seorang pun yang dapat menjelaskan) menerangkan (waktu kedatangannya) huruf lam bermakna fii (selain Dia. Kiamat itu amat berat) amat besar peristiwanya (yang di langit dan di bumi) amat berat dirasakan oleh penduduk keduanya mengingat kengerian huru-haranya. (Kiamat itu tidak akan datang kepadamu melainkan dengan tiba-tiba.") secara sekonyong-konyong (Mereka bertanya kepadamu seolah-olah kamu benar-benar mengetahui) terlalu berlebihan di dalam bertanya (tentang kiamat itu) sehingga engkau memberitahukan tentangnya. (Katakanlah, ``Sesungguhnya pengetahuan tentang kiamat itu adalah di sisi Allah) merupakan pengukuhan sebelumnya (tetapi kebanyakan manusia tidak mengetahui.") pengetahuan mengenai kiamat itu hanya ada di sisi Allah swt.\qt@no{187}}%
\qt@newcmd\qurantrans@id@mcxlii{%
(Katakanlah, ``Aku tidak berkuasa menarik kemanfaatan bagi diriku sendiri) untuk mendapatkannya (dan tidak pula menolak kemudaratan) mampu menolaknya (kecuali yang dikehendaki Allah. Dan sekiranya aku mengetahui yang gaib) apa-apa yang gaib dariku (tentulah aku membuat kebaikan sebanyak-banyaknya dan aku tidak akan ditimpa kemudaratan) berupa kemiskinan dan lain sebagainya karena sebelumnya aku telah bersiap-siap menghadapinya dengan cara menghindari kemudaratan-kemudaratan itu (tidak lain) (aku ini hanyalah pemberi peringatan) dengan neraka bagi orang-orang kafir (dan pembawa berita gembira) dengan surga (bagi orang-orang yang beriman").\qt@no{188}}%
\qt@newcmd\qurantrans@id@mcxliii{%
(Dialah) Allahlah (yang menciptakan kamu dari diri yang satu) yaitu Adam (dan Dia menjadikan) Dia menciptakan (daripadanya istrinya) yakni Hawa (agar dia merasa tenang) Adam menjimaknya (istrinya itu mengandung kandungan yang ringan) berupa air mani (dan teruslah dia merasa ringan) masih bisa berjalan ke sana dan kemari mengingat ringannya kandungan (kemudian tatkala dia merasa berat) anak yang ada dalam perutnya makin membesar, kemudian ia merasa khawatir bahwa kandungannya itu nanti berupa hewan (keduanya bermohon kepada Allah Tuhannya seraya berkata, ``Sesungguhnya jika Engkau memberi kami) anak (yang saleh) yang sempurna (tentulah kami termasuk orang-orang yang bersyukur.") kepada-Mu atas karunia itu.\qt@no{189}}%
\qt@newcmd\qurantrans@id@mcxliv{%
(Tatkala Allah memberi kepada keduanya) seorang anak (yang saleh, maka keduanya menjadikan sekutu bagi Allah) dalam suatu qiraat dibaca dengan dikasrahkan syinnya dan tanwin pada huruf akhirnya; yakni sekutu (tentang anak yang dianugerahkan-Nya kepada mereka berdua) dengan menamakannya Abdul Harits, sedangkan tidak boleh seorang hamba menjadi hamba selain kepada Allah. Yang dimaksud dalam penyekutuan di sini bukanlah dalam masalah ubudiah/ibadah, karena Nabi Adam telah dimaksum dari hal semacam itu. Samurah telah meriwayatkan dari Nabi saw. yang pernah bersabda bahwa ketika Hawa melahirkan seorang anak, iblis bertawaf mengelilingi Siti Hawa; sebelumnya anak Siti Hawa belum pernah ada yang hidup, kemudian iblis berkata kepadanya, ``Namakanlah dia anakmu yang baru lahir itu Abdul Harits, maka ia kelak akan hidup." Anak itu ternyata dapat hidup, hal itu terjadi karena ada saran dari setan dan perintah darinya, demikianlah menurut apa yang diriwayatkan oleh Al-Hakim. Al-Hakim mengatakan bahwa hadis ini sahih; Tirmizi mengatakan bahwa predikat hadis ini hasan gharib (Maka Maha Tinggi Allah dari apa yang mereka persekutukan) yakni penduduk Mekah dengan menjadikan berhala-berhala sebagai sesembahan mereka. Jumlah ayat ini merupakan musabbab atau penyebab, dan diathafkan kepada lafal khalaqakum, dan di antara sabab dengan musababnya terhadap jumlah mu`taridhah.\qt@no{190}}%
\qt@newcmd\qurantrans@id@mcxlv{%
(Apakah mereka mempersekutukan) Allah dalam ibadah (dengan berhala-berhala yang tak dapat menciptakan sesuatu pun? Sedangkan berhala-berhala itu sendiri buatan orang).\qt@no{191}}%
\qt@newcmd\qurantrans@id@mcxlvi{%
(Dan berhala-berhala itu terhadap mereka tidak dapat) terhadap para pengabdinya (memberikan pertolongan, dan kepada dirinya sendiri pun berhala-berhala itu tidak dapat memberi pertolongan) tidak dapat mencegah orang yang bermaksud merusak mereka, apakah orang itu mau memecahkannya atau mau berbuat yang lain. Istifham/kata tanya di sini mempunyai pengertian untuk mencemoohkan.\qt@no{192}}%
\qt@newcmd\qurantrans@id@mcxlvii{%
(Dan jika kamu menyerunya) menyeru berhala-berhala itu (untuk memberi petunjuk kepadamu, tidaklah berhala-berhala itu dapat memperkenankan seruanmu) dengan memakai takhfif dan tasydid (sama saja hasilnya buat kamu menyeru mereka) untuk meminta petunjuk (atau pun kamu berdiam diri) tidak menyeru mereka, maka mereka pasti tidak dapat memenuhi permintaanmu karena mereka tidak dapat mendengar.\qt@no{193}}%
\qt@newcmd\qurantrans@id@mcxlviii{%
(Sesungguhnya berhala-berhala yang kamu seru) yang kamu sembah (selain Allah itu adalah makhluk yang lemah) hamba-hamba (yang serupa juga dengan kamu. Maka serulah berhala-berhala itu lalu biarkanlah mereka memperkenankan permintaanmu) doa kamu (jika kami memang orang-orang yang benar) dalam anggapanmu bahwa mereka adalah tuhan. Kemudian Allah menjelaskan tentang kelemahan berhala-berhala tersebut dan Dia menjelaskan pula bahwa justru para pengabdinyalah yang lebih utama dari berhala-berhala itu sendiri. Untuk itu Allah berfirman:\qt@no{194}}%
\qt@newcmd\qurantrans@id@mcxlix{%
(Apakah berhala-berhala itu mempunyai kaki yang dengan itu mereka dapat berjalan atau) bahkan apakah (mereka mempunyai tangan-tangan) bentuk jamak dari lafal yadun/tangan (yang dengan tangan-tangan itu mereka dapat memukul atau) bahkan apakah (mereka mempunyai mata yang dengan mata itu mereka dapat melihat atau) bahkan apakah (mereka mempunyai telinga yang dengan telinga itu mereka dapat mendengar?) kata tanya yang terdapat di dalam ayat ini menunjukkan makna ingkar. Yakni bahwa berhala-berhala itu tidak mempunyai sesuatu pun dari hal-hal tersebut seperti apa yang kamu sekalian miliki. Lalu mengapa kamu menyembahnya sedang diri kamu sendiri keadaannya jauh lebih baik daripada mereka. (Katakanlah) kepada mereka, hai Muhammad ("Panggillah berhala-berhalamu yang kamu jadikan sekutu bagi Allah itu) untuk mencelakakanku (kemudian lakukanlah tipu-daya kepadaku tanpa memberi tangguh kepadaku") memberi tenggang waktu karena aku tidak lagi memperdulikanmu.\qt@no{195}}%
\qt@newcmd\qurantrans@id@mcl{%
(Sesungguhnya pelindungku ialah Allah) yang mengurusi perkaraku (yang telah menurunkan Alkitab) Alquran (dan Dia melindungi orang-orang yang saleh) memeliharanya.\qt@no{196}}%
\qt@newcmd\qurantrans@id@mcli{%
(Dan berhala-berhala yang kamu seru selain Allah tidaklah sanggup menolongmu, bahkan tidak dapat menolong dirinya sendiri) lalu mengapa aku mempedulikan keadaan mereka.\qt@no{197}}%
\qt@newcmd\qurantrans@id@mclii{%
(Dan jika kamu sekalian menyeru mereka) berhala-berhala itu (untuk memberi petunjuk, niscaya berhala-berhala tidak dapat mendengarnya. Dan kamu melihat mereka) berhala-berhala itu, hai Muhammad (memandang kepadamu) yakni, mereka berhadapan denganmu bagaikan orang yang sedang memandang (padahal mereka tidak dapat melihat).\qt@no{198}}%
\qt@newcmd\qurantrans@id@mcliii{%
(Jadilah engkau pemaaf) mudah memaafkan di dalam menghadapi perlakuan orang-orang, dan jangan membalas (dan suruhlah orang mengerjakan makruf) perkara kebaikan (serta berpalinglah daripada orang-orang yang bodoh) janganlah engkau melayani kebodohan mereka.\qt@no{199}}%
\qt@newcmd\qurantrans@id@mcliv{%
(Dan jika) lafal immaa merupakan gabungan antara in syarthiah dan maa zaidah atau tambahan (kamu ditimpa suatu godaan setan) dimaksud jika setan memalingkan kamu dari apa yang kamu diperintahkan untuk melakukannya dengan suatu godaan (maka berlindunglah kepada Allah) sebagai jawab syarath sedangkan jawab amarnya dibuang, yaitu guna menolak setan daripada dirimu (sesungguhnya Allah Maha Mendengar) semua perkataan (lagi Maha Mengetahui) semua pekerjaan.\qt@no{200}}%
\qt@newcmd\qurantrans@id@mclv{%
(Sesungguhnya orang-orang yang bertakwa bila mereka ditimpa) terkena (was-was) menurut suatu qiraat dibaca thaifun bukan thaaifun, artinya sesuatu yang menimpa mereka (dari setan mereka ingat) akan siksa Allah dan pahala-Nya (maka ketika itu mereka melihat) perbedaan antara perkara yang hak dan yang batil lalu mereka kembali kepada jalan yang hak.\qt@no{201}}%
\qt@newcmd\qurantrans@id@mclvi{%
(Dan teman-teman mereka) yaitu teman-teman setan terdiri dari orang-orang kafir (membantu mereka) setan-setan itu (dalam menyesatkan kemudian) mereka (tidak henti-hentinya) di dalam menyesatkan dengan sikap penuh hati-hati sebagaimana orang-orang yang takwa pun berhati-hati terhadap godaan mereka.\qt@no{202}}%
\qt@newcmd\qurantrans@id@mclvii{%
(Dan apabila kamu tidak membawa kepada mereka) kepada penduduk Mekah (suatu ayat) seperti apa yang mereka minta (mereka berkata, ``Mengapa tidak) (kamu buat-buat ayat itu?") artinya kamu buat sendiri ayat itu? (Katakanlah,) kepada mereka ("Sesungguhnya aku hanya mengikut apa yang diwahyukan kepadaku dari Tuhanku) aku tidak berhak untuk mendatangkannya dari diriku sendiri. (Ini) Alquran ini (adalah bukti-bukti yang jelas) hujah-hujah (dari Tuhanmu, petunjuk dan rahmat bagi orang-orang yang beriman.")\qt@no{203}}%
\qt@newcmd\qurantrans@id@mclviii{%
(Dan apabila dibacakan Alquran, maka dengarkanlah baik-baik dan perhatikanlah) jangan berbicara (agar kamu mendapat rahmat) ayat ini diturunkan sehubungan dengan perintah tidak boleh berbicara sewaktu khutbah Jumat yang diungkapkan oleh ayat ini dengan istilah Alquran, mengingat khutbah itu mengandung ayat-ayat Alquran. Menurut pendapat lain berkaitan dengan pembacaan Alquran secara mutlak.\qt@no{204}}%
\qt@newcmd\qurantrans@id@mclix{%
(Dan sebutlah nama Tuhanmu di dalam hatimu) secara diam-diam (dengan merendahkan diri) menghinakan diri (dan rasa takut) yakni takut terhadap-Nya (dan) lebih jelas lagi daripada diam-diam dengan (tidak mengeraskan suara) maksudnya pertengahan di antara diam-diam dan keras suara (di waktu pagi dan petang) pada permulaan siang hari dan pada akhir siang hari (dan janganlah kamu termasuk orang-orang yang lalai) daripada mengingat atau menyebut Allah.\qt@no{205}}%
\qt@newcmd\qurantrans@id@mclx{%
(Sesungguhnya mereka yang berada di sisi Tuhanmu) yakni malaikat-malaikat-Nya (tidaklah merasa enggan) tidak takabur (untuk menyembah Allah dan mereka bertasbih kepada-Nya) menyucikan-Nya dari hal-hal yang tidak layak menjadi sifat-Nya (dan hanya kepada-Nyalah mereka bersujud) mereka secara khusus tunduk dan bersujud hanya kepada-Nya, maka jadilah kamu sekalian seperti mereka.\qt@no{206}}%
\qt@newcmd\qurantrans@id@mclxi{%
\basmalahid (Mereka menanyakan kepadamu) hai Muhammad (tentang harta rampasan) perang, siapakah yang berhak menerimanya (Katakanlah,) kepada mereka ("Harta rampasan perang itu kepunyaan Allah dan rasul-Nya) harta rampasan perang itu terserah menurut kesukaan Allah dan rasul-Nya; kemudian Rasulullah saw. membagi-bagikan harta rampasan itu secara merata kepada mereka semuanya. Demikianlah menurut hadis yang diriwayatkan oleh Imam Al-Hakim di dalam kitab Al-Mustadrak (sebab itu bertakwalah kalian kepada Allah dan perbaikilah hubungan di antara sesamamu) yakni jalinlah kembali hubungan antara kalian dengan penuh kecintaan dan tinggalkanlah persengketaan (dan taatlah kalian kepada Allah dan rasul-Nya, jika kamu adalah orang-orang yang beriman.") yang benar-benar beriman.\qt@no{1}}%
\qt@newcmd\qurantrans@id@mclxii{%
(Sesungguhnya orang-orang yang beriman itu) yang sempurna keimanannya (adalah mereka yang apabila disebut Allah) yakni ancaman-Nya (gemetarlah) karena takut (hati mereka dan apabila dibacakan kepada mereka ayat-ayat-Nya bertambahlah keimanan mereka) kepercayaan mereka (dan kepada Tuhanlah mereka bertawakal) hanya kepada Rabblah mereka percaya bukan kepada selain-Nya.\qt@no{2}}%
\qt@newcmd\qurantrans@id@mclxiii{%
(Yaitu orang-orang yang mendirikan salat) mereka menunaikannya sesuai dengan ketentuan-ketentuannya (dan sebagian dari apa yang telah Kami berikan kepada mereka) Kami anugerahkan kepada mereka (mereka menafkahkannya) demi taat kepada Allah.\qt@no{3}}%
\qt@newcmd\qurantrans@id@mclxiv{%
(Itulah) orang-orang yang berciri khas seperti tadi (mereka orang-orang yang beriman dengan sebenar-benarnya) yang tidak diragukan lagi keimanannya. (Mereka akan memperoleh beberapa derajat ketinggian) kedudukan-kedudukan di surga (di sisi Tuhannya dan ampunan serta rezeki yang mulia) di surga.\qt@no{4}}%
\qt@newcmd\qurantrans@id@mclxv{%
(Sebagaimana Tuhanmu menyuruhmu pergi dari rumahmu dengan kebenaran) jar dan majrur berta`alluq pada lafal akhraja (padahal sesungguhnya sebagian dari orang-orang yang beriman itu tidak menyukainya) yakni mereka tidak menyukai keluar bersama Nabi. Jumlah kalimat maa akhrajaka dan seterusnya merupakan keterangan keadaan dari huruf kaf yang terdapat pada lafal kamaa. Kemudian lafal kamaa akhrajaka berkedudukan menjadi khabar atau kalimat berita dari mubtada yang dibuang, yakni keadaan yang tidak mereka sukai adalah sewaktu engkau diminta keluar sedangkan mereka tidak menyukai hal itu, padahal itu baik untuk mereka, demikianlah keadaan mereka. Demikian itu karena Abu Sofyan yang datang membawa kafilah perdagangan dari negeri Syam, beritanya sampai kepada Nabi saw. Maka Nabi saw. segera keluar bersama para sahabat guna mencegah kafilah tersebut. Akan tetapi berita keberangkatannya diketahui oleh orang-orang Quraisy. Maka keluarlah Abu Jahal beserta pasukan perang kota Mekah untuk melindungi kafilahnya itu, mereka bersenjata lengkap dan banyak pasukannya. Abu Sofyan membawa kafilahnya mengikuti jalan tepi pantai sehingga selamatlah mereka dari cegatan kaum Muslimin. Lalu ada yang berkata kepada Abu Jahal, ``Mari kita kembali." Akan tetapi Abu Jahal menolak dan bahkan terus bermusyawarah dengan para sahabatnya; Nabi saw. bersabda kepada mereka, ``Sesungguhnya Allah swt. telah menjanjikan kepadaku kemenangan atas salah satu dari dua rombongan," yaitu rombongan Abu Sofyan atau rombongan Abu Jahal. Akhirnya mereka sepakat untuk memerangi pasukan yang bersenjata; tetapi sebagian dari kaum Mukminin tidak menyukai hal itu, mereka mengatakan, ``Kami masih belum siap untuk menghadapi hal itu," sebagaimana yang diungkapkan oleh firman-Nya berikut ini:\qt@no{5}}%
\qt@newcmd\qurantrans@id@mclxvi{%
(Mereka membantahmu tentang kebenaran) yaitu tentang alternatif berperang (sesudah nyata) sesudah jelas bagi mereka bahwa mereka pasti menang (seolah-olah mereka dihalau kepada kematian sedang mereka melihat) kematian itu secara terang-terangan yang membuat mereka tidak senang kepadanya.\qt@no{6}}%
\qt@newcmd\qurantrans@id@mclxvii{%
(Dan) ingatlah (ketika Allah menjanjikan kepadamu salah satu dari dua golongan) yakni rombongan kafilah atau pasukan bersenjata (bahwa salah satu dari dua golongan yang kamu hadapi adalah untukmu, sedangkan kamu menginginkan) kalian hanya menghendaki (bahwa golongan yang tidak mempunyai kekuatan senjatalah) golongan yang tidak mempunyai kekuatan dan persenjataan, yaitu golongan kafilah dagang (yang untukmu) mengingat pengawalnya sedikit dan persenjataannya pun tidak lengkap, berbeda dengan golongan pasukan bersenjata (dan Allah menghendaki untuk membenarkan yang benar) menampakkan yang benar (dengan ayat-ayat-Nya) yang dahulu melalui kemenangan Islam (dan memusnahkan orang-orang kafir) kekuatan mereka dengan mengalahkan mereka, maka Dia memerintahkan kalian untuk memerangi pasukan bersenjata mereka.\qt@no{7}}%
\qt@newcmd\qurantrans@id@mclxviii{%
(Agar Allah menetapkan yang hak dan membatalkan) menghapus (kebatilan) yakni kekafiran (walaupun orang-orang yang berdosa itu tidak menyukainya) orang-orang musyrik tidak menyenangi hal itu.\qt@no{8}}%
\qt@newcmd\qurantrans@id@mclxix{%
(Ingatlah, ketika kamu memohon pertolongan Tuhanmu) ketika kamu meminta pertolongan dari-Nya untuk dapat mengalahkan orang-orang musyrik (lalu diperkenankan-Nya bagimu, ``Sesungguhnya Aku) sungguh Aku pasti (memberikan bantuan kepadamu) akan menolongmu (dengan mendatangkan seribu malaikat yang datang berturut-turut") yakni mereka datang secara berturut-turut, sebagian dari mereka menyusul sebagian lainnya. Pada permulaannya Allah menjanjikan untuk mereka bantuan seribu malaikat, kemudian menjadi tiga ribu malaikat, hingga sampai lima ribu malaikat, seperti yang dijelaskan di dalam surah Ali Imran. Menurut suatu qiraat lafal alfun dibaca aalaf seperti aflas dalam bentuk jamak.\qt@no{9}}%
\qt@newcmd\qurantrans@id@mclxx{%
(Dan Allah tidak menjadikannya) bala bantuan tersebut (melainkan sebagian berita gembira dan agar hatimu menjadi tenteram karenanya. Dan kemenangan itu hanyalah dari sisi Allah. Sesungguhnya Allah Maha Perkasa lagi Maha Bijaksana).\qt@no{10}}%
\qt@newcmd\qurantrans@id@mclxxi{%
(Ingatlah, ketika Allah menjadikan kamu mengantuk sebagai suatu penenteram) untuk menenteramkan hatimu dari rasa takut yang menimpa dirimu (daripada-Nya) Allah Yang Maha Tinggi (dan Allah menurunkan kepadamu hujan dari langit untuk menyucikan kamu dengan hujan itu) dari hadas dan jinabah itu (dan menghilangkan dari kamu gangguan-gangguan setan) godaan setan dari dirimu yang mengatakan bahwasanya jika kamu berada dalam jalan kebenaran, niscaya kamu tidak akan kehausan lagi berhadas sedang kaum musyrikin berada dekat air (dan untuk menguatkan) mengokohkan (hatimu) dalam keyakinan dan kesabaran (dan memperteguh dengannya telapak kakimu) agar telapak kakimu berdiri tegar di padang pasir.\qt@no{11}}%
\qt@newcmd\qurantrans@id@mclxxii{%
(Ingatlah ketika Tuhanmu mewahyukan kepada para malaikat) yang diperbantukan kepada kaum Muslimin ("Sesungguhnya Aku) bahwasanya Aku (bersama kamu) memberikan pertolongan dan bantuan (maka teguhkanlah pendirian orang-orang yang telah beriman) dengan memberikan pertolongan kepada mereka dan mengabarkan berita gembira. (Kelak Aku akan timpakan rasa ketakutan ke dalam hati orang-orang kafir) ketakutan yang sangat (maka penggallah leher mereka) kepala mereka (dan pancunglah tiap-tiap ujung jari mereka) ujung-ujung jari tangan dan kaki. Dikatakan bahwa dalam perang itu jika seseorang muslim hendak memukul kepala si kafir tiba-tiba kepala itu sudah jatuh menggelinding sendiri sebelum pedangnya sampai kepadanya. Dan Rasulullah saw. melempar mereka dengan segenggam batu kerikil, maka tidak ada seorang musyrik pun yang luput matanya dari lemparan batu kerikil itu, akhirnya mereka kalah.\qt@no{12}}%
\qt@newcmd\qurantrans@id@mclxxiii{%
(Yang demikian itu) azab yang menimpa mereka itu (adalah karena sesungguhnya mereka menentang) melawan (Allah dan rasul-Nya; dan barang siapa menentang Allah dan rasul-Nya, maka sesungguhnya Allah amat keras siksaan-Nya) terhadapnya.\qt@no{13}}%
\qt@newcmd\qurantrans@id@mclxxiv{%
(Itulah) hukuman yang ditimpakan atasmu (maka rasakanlah hukuman itu) hai orang-orang kafir, sebagai hukuman di dunia (sesungguhnya bagi orang-orang yang kafir itu) kelak di hari kemudian (azab neraka").\qt@no{14}}%
\qt@newcmd\qurantrans@id@mclxxv{%
(Hai orang-orang yang beriman, jika kamu bertemu dengan orang-orang yang kafir yang sedang menyerangmu) mereka menghimpun kekuatan dalam jumlah yang banyak sehingga mereka kelihatan seakan-akan merayap maju (maka janganlah kamu membelakangi mereka) dalam keadaan lari karena kalah.\qt@no{15}}%
\qt@newcmd\qurantrans@id@mclxxvi{%
(Barang siapa yang membelakangi mereka di waktu itu) ketika berhadapan dengan mereka di medan peperangan (dalam keadaan mundur kecuali berbelok) mengelak (untuk siasat perang) dengan cara berpura-pura lari tetapi untuk tujuan menyerang (atau menggabungkan diri) menyatu (dengan pasukan yang lain) dengan pasukan kaum Muslimin lainnya meminta tolong kepada mereka (maka sesungguhnya orang itu kembali) pulang (dengan membawa kemurkaan dari Allah, dan tempatnya ialah neraka Jahanam. Dan amat buruklah tempat kembalinya) sejelek-jelek tempat kembali ialah neraka Jahanam. Keadaan ini khusus jika orang-orang kafir tidak makin bertambah lemah.\qt@no{16}}%
\qt@newcmd\qurantrans@id@mclxxvii{%
(Maka yang sebenarnya bukan kamu yang membunuh mereka) di Badar dengan kekuatanmu (akan tetapi Allahlah yang membunuh mereka) dengan melalui pertolongan-Nya yang Dia limpahkan kepada kalian (dan bukan kamu yang melempar) mata kaum musyrikin, hai Muhammad (ketika kamu melempar) dengan batu kerikil, sebab sekali lempar dengan segenggam batu kerikil yang dilakukan oleh manusia tidak akan dapat memenuhi mata bala tentara yang begitu banyaknya (tetapi Allahlah yang melempar) dengan cara mengenakan lemparan itu kepada mereka; hal ini sengaja Dia lakukan guna mengalahkan orang-orang kafir (dan untuk memberi kemenangan kepada orang-orang mukmin dengan kemenangan) yakni anugerah (yang baik) yang dimaksud adalah ganimah/harta rampasan perang. (Sesungguhnya Allah Maha Mendengar) perkataan mereka (lagi Maha Mengetahui) tentang keadaan mereka.\qt@no{17}}%
\qt@newcmd\qurantrans@id@mclxxviii{%
(Itulah) kemenangan itu suatu hal yang nyata (dan sesungguhnya Allah melemahkan) membuat tidak berdaya (tipu daya orang-orang yang kafir).\qt@no{18}}%
\qt@newcmd\qurantrans@id@mclxxix{%
(Jika kalian mencari keputusan) hai orang-orang kafir, yakni kamu sekalian meminta keputusan, di mana salah seorang dari kamu yaitu Abu Jahal mengatakan, ``Ya Allah! Siapakah dari kami yang paling memutuskan silaturahmi dan yang paling banyak melakukan hal-hal yang tidak dikenal pada kalangan kami, maka semoga Engkau membinasakannya (maka telah datang kepadamu keputusan) ketentuan binasanya orang-orang yang melakukan hal itu, mereka adalah Abu Jahal dan orang-orang yang terbunuh bersamanya, bukannya Nabi saw. dan kaum mukminin (dan jika kalian berhenti) dari perbuatan kafir dan memerangi Nabi saw. (maka itulah yang lebih baik bagi kalian; dan jika kalian kembali) untuk memerangi Nabi saw. (niscaya Kami kembali) untuk memberikan pertolongan kepada Nabi saw. atas kalian (dan tidak akan dapat mencukupi) menolak (angkatan perang kalian dari kalian) yakni golongan kalian (sesuatu bahaya pun biar pun angkatan perang itu banyak dan sesungguhnya Allah beserta orang-orang yang beriman) huruf inna dibaca kasrah sebagai jumlah isti`naf, dan dibaca anna dengan memperkirakan adanya huruf lam, bentuk lengkapnya ialah lama`al mu`miina.\qt@no{19}}%
\qt@newcmd\qurantrans@id@mclxxx{%
(Hai orang-orang yang beriman, taatlah kamu sekalian kepada Allah dan Rasul-Nya, dan janganlah kalian berpaling) memalingkan diri (daripada-Nya) dengan cara menentang perintah-Nya (sedang kalian mendengar) Alquran dan nasihat-nasihat-Nya.\qt@no{20}}%
\qt@newcmd\qurantrans@id@mclxxxi{%
(Dan janganlah kalian menjadi sebagai orang-orang yang berkata, ``Kami mendengar; padahal mereka tidak mendengarkan) secara sadar dan penuh dengan pengertian, mereka adalah orang-orang munafik dan kaum musyrikin\qt@no{21}}%
\qt@newcmd\qurantrans@id@mclxxxii{%
(Sesungguhnya binatang, makhluk-makhluk yang seburuk-buruknya di sisi Allah ialah orang-orang yang tuli) tidak mau mendengarkan perkara yang hak (dan bisu) tidak mengucapkan perkara yang hak (yang tidak mengerti apa pun) tentang perkara yang hak.\qt@no{22}}%
\qt@newcmd\qurantrans@id@mclxxxiii{%
(Kalau sekiranya Allah mengetahui kebaikan pada mereka) bakat yang baik di dalam mendengarkan perkara yang hak (tentulah Allah menjadikan mereka dapat mendengar) dengan pendengaran yang disertai pemahaman. (Dan jika Allah menjadikan mereka dapat mendengar) sebagai perumpamaan, karena Allah telah mengetahui bahwa tidak ada kebaikan dalam diri mereka (niscaya mereka pasti berpaling juga) dari perkara yang hak itu (sedangkan mereka memalingkan diri") dari menerima perkara hak yang mereka dengar itu karena keras hati dan ingkar.\qt@no{23}}%
\qt@newcmd\qurantrans@id@mclxxxiv{%
(Hai orang-orang yang beriman, penuhilah seruan Allah dan seruan Rasul) dengan taat (apabila Rasul menyeru kamu pada suatu yang memberi kehidupan kepada kalian) berupa perkara agama sebab perkara agama merupakan penyebab bagi kehidupan yang kekal (dan ketahuilah oleh kalian bahwa sesungguhnya Allah menghalangi antara manusia dan hatinya) maka ia tidak dapat beriman atau kafir melainkan berdasarkan kehendak Allah (dan sesungguhnya kepada-Nyalah kamu akan dikumpulkan) Allah akan membalas semua amal perbuatan kalian.\qt@no{24}}%
\qt@newcmd\qurantrans@id@mclxxxv{%
(Dan peliharalah diri kalian daripada siksaan) jika siksaan menimpa kalian (ia tidak khusus menimpa orang-orang yang lalim saja di antara kalian) bahkan siksaan itu merata kepada mereka dan selain mereka. Dan cara untuk memelihara diri supaya jangan tertimpa siksaan ialah membenci penyebabnya, yaitu perkara mungkar. (Dan ketahuilah bahwa Allah sangat keras siksaan-Nya) terhadap orang-orang yang melanggar perintah dan larangan-Nya.\qt@no{25}}%
\qt@newcmd\qurantrans@id@mclxxxvi{%
(Dan ingatlah hai para Muhajirin ketika kalian masih berjumlah sedikit lagi tertindas di muka bumi) yakni Mekah (kalian takut orang-orang Mekah akan menculik kalian) mengambil kalian dengan cepat (maka Allah memberi kalian tempat menetap) yaitu kota Madinah (dan didukung-Nya kalian) Dia membuat kalian menjadi kuat (dengan pertolongan-Nya) ketika perang Badar, yaitu melalui bantuan para malaikat (dan diberi-Nya kalian rezeki dari yang baik-baik) berupa ganimah (agar kalian bersyukur) terhadap nikmat-nikmat-Nya. Ayat ini diturunkan berkenaan dengan Abu Lubabah alias Marwan bin Abdul Munzir. Nabi saw. telah mengutusnya kepada orang-orang Bani Quraizhah dengan membawa pesan darinya, supaya mereka mau tunduk di bawah kekuasaan Nabi saw. Maka Abu Lubabah bermusyawarah dengan mereka; akan tetapi ia mengisyaratkan dengan tangannya kepada mereka, bahwa jika mereka tunduk maka hukumannya adalah sembelih (maut). Abu Lubabah sengaja berbuat demikian demi untuk melindungi anak-anak dan harta bendanya yang berada di antara mereka.\qt@no{26}}%
\qt@newcmd\qurantrans@id@mclxxxvii{%
(Hai orang-orang yang beriman janganlah kalian mengkhianati Allah dan rasul-Nya dan) jangan pula (kalian mengkhianati amanat-amanat kalian) yakni apa-apa yang dipercayakan kepada kalian berupa agama dan hal-hal yang lain (sedangkan kalian mengetahui).\qt@no{27}}%
\qt@newcmd\qurantrans@id@mclxxxviii{%
(Dan ketahuilah bahwa harta kalian dan anak-anak kalian itu hanyalah sebagai cobaan) buat kalian yang menghambat kalian daripada perkara-perkara akhirat (dan sesungguhnya di sisi Allahlah pahala yang besar) maka janganlah sekali-kali kalian melewatkan pahala yang besar sehingga kalian mau berbuat khianat demi untuk mereka. Ayat berikut diturunkan berkenaan dengan tobatnya Abu Lubabah.\qt@no{28}}%
\qt@newcmd\qurantrans@id@mclxxxix{%
(Hai orang-orang yang beriman, jika kalian bertakwa kepada Allah) melalui berserah diri kepada-Nya dan cara-cara yang lain (niscaya Dia akan memberikan kepada kalian petunjuk) buat kalian sehingga kalian dapat membedakan hal-hal yang dapat membawa keselamatan dan hal-hal yang membahayakan diri kalian, sehingga kalian selamat dari hal-hal yang kalian takutkan (dan menghapuskan segala kesalahan-kesalahan dan mengampuni kalian) dosa-dosa kalian. (Dan Allah mempunyai karunia yang besar).\qt@no{29}}%
\qt@newcmd\qurantrans@id@mcxc{%
(Dan) ingatlah hai Muhammad (ketika orang-orang kafir Quraisy merencanakan tipu muslihat terhadap dirimu) mereka mengadakan pertemuan di Darun Nadwah tempat mereka bermusyawarah guna mengadakan makar terhadap dirimu (untuk menangkapmu) untuk mengikatmu dan memenjarakanmu (atau membunuhmu) di mana mereka secara beramai-ramai membunuhmu (atau mengusirmu) dari Kota Mekah. (Mereka merencanakan tipu muslihat) terhadap dirimu (akan tetapi Allah menggagalkan rencana mereka dengan cara memberikan pemberitahuan kepadamu melalui wahyu-Nya akan rencana mereka dan Dia memerintahkan kamu untuk keluar terlebih dahulu. (Dan Allah sebaik-baik pembalas tipu muslihat). Dia Maha Mengetahui tentang tipu muslihat.\qt@no{30}}%
\qt@newcmd\qurantrans@id@mcxci{%
(Dan apabila dibacakan kepada mereka ayat-ayat Kami) yakni Alquran (mereka berkata, ``Sesungguhnya kami telah mendengar ayat-ayat seperti ini, kalau kami menghendaki niscaya kami dapat membacakan yang seperti ini) ucapan ini telah dikatakan oleh Nadhr bin Harits, karena ia sering berkunjung ke negeri Hairah untuk tujuan berniaga. Di sana ia membeli buku-buku tentang sejarah orang-orang Ajam, kemudian ia menceritakannya kepada penduduk kota Mekah. (Tiada lain) tak lain (hal ini) yakni Alquran (hanyalah dongeng-dongengan) cerita-cerita bohong (orang-orang dahulu.")\qt@no{31}}%
\qt@newcmd\qurantrans@id@mcxcii{%
(Dan ingatlah ketika mereka/orang-orang musyrik berkata, ``Ya Allah! Jika betul hal ini) yaitu Alquran yang dibacakan oleh Muhammad (dialah yang benar) diturunkan (dari sisi Engkau, maka hujanilah kami dengan batu dari langit, atau datangkanlah kepada kami azab yang pedih.") siksaan yang menyakitkan sekali sebagai pembalasan atas ingkar kami terhadapnya. Perkataan ini diucapkan oleh Nadhr dan lain-lainnya sebagai penghinaan dengan maksud untuk memberikan gambaran kepada orang lain seakan-akan ia benar-benar mengetahui akan kebatilan Alquran. Allah swt. telah berfirman:\qt@no{32}}%
\qt@newcmd\qurantrans@id@mcxciii{%
(Dan Allah sekali-kali tidak akan mengazab mereka) oleh sebab apa yang telah mereka minta (sedangkan kamu berada di antara mereka) karena jika azab itu turun akan menimpa semua orang tanpa kecuali. Dan tiada suatu umat pun yang diazab melainkan setelah nabi dan kaum mukminin keluar daripadanya. (Dan tidak pula Allah akan mengazab mereka, sedangkan mereka meminta ampun) karena ternyata di dalam tawaf yang mereka lakukan mereka selalu mengatakan, ``Ampunan-Mu, ampunan-Mu." Dan menurut suatu pendapat dikatakan bahwa orang-orang yang meminta ampunan itu adalah orang-orang lemah dari kalangan kaum mukminin yang tinggal bersama dengan orang-orang kafir sebagaimana yang telah dijelaskan oleh firman-Nya, ``Sekiranya mereka tidak bercampur-baur, tentulah Kami akan mengazab orang-orang kafir di antara mereka dengan azab yang pedih." (Q.S. Al-Fath 25).\qt@no{33}}%
\qt@newcmd\qurantrans@id@mcxciv{%
(Mengapa Allah tidak mengazab mereka) dengan pedang sesudah engkau dan kaum mukminin yang lemah keluar dari Mekah. Berdasarkan pendapat yang pertama, ayat ini menasakh ayat sebelumnya; dan ternyata Allah swt. mengazab mereka dalam perang Badar dan perang-perang yang lain (padahal mereka menghalangi) mencegah Nabi saw. dan kaum muslimin (untuk mendatangi Masjidilharam) yakni untuk melakukan tawaf di dalamnya (dan mereka bukanlah orang-orang yang berhak menguasainya?) seperti menurut dugaan mereka. (Tiada lain) tidak lain (orang-orang yang berhak menguasainya hanyalah orang-orang yang bertakwa tetapi kebanyakan mereka tidak mengetahui) bahwasanya tidak ada hak bagi orang-orang kafir untuk menguasai Masjidilharam.\qt@no{34}}%
\qt@newcmd\qurantrans@id@mcxcv{%
(Salat mereka di sekitar Baitullah itu tiada lain hanyalah siulan) bersiul-siul (dan tepuk tangan) artinya mereka menjadikan hal-hal tersebut sebagai upacara sembahyang mereka yang dianjurkan oleh sesama mereka. (Maka rasakanlah azab) dalam perang Badar (disebabkan kekafiran kalian).\qt@no{35}}%
\qt@newcmd\qurantrans@id@mcxcvi{%
Sesungguhnya orang-orang yang kafir itu menafkahkan harta mereka) di dalam memerangi Nabi saw. (untuk menghalangi orang dari jalan Allah. Mereka akan menafkahkan harta itu kemudian hal itu) pada akhirnya (menjadi sesalan bagi mereka sendiri) mereka akan merasa menyesal karena harta mereka terbuang secara percuma dan tujuan mereka tidak berhasil (kemudian mereka dikalahkan) di dunia. (Dan orang-orang yang kafir itu) dari kalangan orang-orang Quraisy (ke neraka Jahanam) kelak di akhirat (akan dikumpulkan) mereka digiring ke dalamnya.\qt@no{36}}%
\qt@newcmd\qurantrans@id@mcxcvii{%
(Supaya Allah membedakan) lafal ini berkaitan dengan lafal takuunu pada ayat yang sebelumnya. Boleh dibaca tidak memakai tasydid atau memakainya; artinya memisahkan (antara golongan yang buruk) orang kafir (dan yang baik) orang mukmin (dan menjadikan golongan yang buruk itu sebagiannya di atas sebagian yang lain, kesemuanya ditumpukkan-Nya) artinya Allah mengumpulkan mereka secara bertumpuk-tumpuk, sebagian di antara mereka berada di atas sebagian yang lain (dan dimasukkan-Nya ke dalam neraka Jahanam. Mereka itulah orang-orang yang merugi).\qt@no{37}}%
\qt@newcmd\qurantrans@id@mcxcviii{%
(Katakanlah kepada orang-orang yang kafir itu,) seperti Abu Sofyan dan teman-temannya ("Jika mereka berhenti) dari kekafirannya dan dari memerangi Nabi saw. (niscaya Allah akan mengampuni mereka tentang dosa-dosa mereka yang telah lalu) dari amal perbuatan mereka (dan jika mereka kembali lagi) untuk memerangi Nabi saw. (sesungguhnya akan berlaku terhadap mereka sunah Allah terhadap orang-orang dahulu.") Allah akan memberlakukan sunah-Nya terhadap diri mereka, dengan cara membinasakannya, seperti yang telah Kami lakukan terhadap umat-umat terdahulu.\qt@no{38}}%
\qt@newcmd\qurantrans@id@mcxcix{%
(Dan perangilah mereka supaya tidak ada) supaya jangan ada (fitnah) kemusyrikan (dan supaya agama itu semata-mata bagi Allah) hanya bagi Allah semata dan tidak disembah selain dari-Nya. (Jika mereka berhenti) dari kekafiran (Maka sesungguhnya Allah Maha Melihat apa yang mereka kerjakan) Dia akan membalas mereka karenanya.\qt@no{39}}%
\qt@newcmd\qurantrans@id@mcc{%
(Dan jika mereka berpaling) dari keimanan (maka ketahuilah bahwasanya Allah pelindung kalian) yang akan menolong dan mengatur urusan-urusan kalian (sebaik-baik pelindung) adalah Dia (dan Dia adalah sebaik-baik penolong) yang akan menolong kalian.\qt@no{40}}%
\qt@newcmd\qurantrans@id@mcci{%
(Ketahuilah sesungguhnya apa saja yang telah kalian peroleh) kalian ambil dari orang-orang kafir secara paksa (dalam bentuk apa pun, maka sesungguhnya seperlima untuk Allah) Dialah yang akan mengaturnya sesuai dengan kehendak-Nya (Rasul, kerabat Rasul) kaum kerabat Nabi saw. yang terdiri dari kalangan Bani Hasyim dan Bani Mutalib (anak-anak yatim) anak-anak kaum muslimin yang ayah-ayah mereka telah meninggal dunia sedangkan mereka dalam keadaan miskin (orang-orang miskin) kaum muslimin yang hidupnya masih kekurangan (dan ibnu sabil) orang muslim yang kehabisan bekal dalam perjalanannya. Atau dengan kata lain Nabi saw. dan keempat golongan orang-orang tadi berhak untuk mendapatkan seperlima dari seperlimanya. Sedangkan sisa seluruh ganimah yang tinggal empat perlima, seluruhnya untuk pasukan yang telah memperolehnya (jika kalian beriman kepada Allah) maka ketahuilah oleh kalian hal tersebut (dan kepada apa) diathafkan pada lafal billaah (yang Kami turunkan kepada hamba Kami) Muhammad saw., yaitu malaikat dan ayat-ayat (di hari Furqan) artinya pada perang Badar karena di dalam perang tersebut dipisahkan antara perkara yang hak dan yang batil (yaitu di hari bertemunya dua pasukan) pasukan kaum muslimin dan pasukan kaum kafir. (Dan Allah Maha Kuasa atas segala sesuatu) antara lain Dia telah memenangkan kalian sekali pun jumlah kalian sedikit dan jumlah musuh-musuh kalian banyak.\qt@no{41}}%
\qt@newcmd\qurantrans@id@mccii{%
(Yaitu di hari ketika) lafal ini merupakan badal dari lafal yaum (kalian) berada (di pinggir lembah) yang dekat dari kota Madinah; huruf `ain boleh dibaca damah dan boleh dibaca kasrah, artinya di pinggir lembah (dan mereka berada di pinggir lembah yang jauh) dari kota Madinah (sedang kafilah) iring-iringan perdagangan orang-orang kafir berada di tempat (yang lebih rendah daripada kalian) yaitu dekat dengan pantai (Sekiranya kalian mengadakan persetujuan) antara kalian dan pasukan kaum musyrikin untuk menentukan hari pertempuran (pastilah kalian tidak akan sependapat untuk menentukan hari pertempuran itu akan tetapi) Allah mempertemukan antara kalian dan mereka tanpa persetujuan terlebih dahulu (agar Dia melakukan suatu urusan yang mesti dilaksanakan) yang urusan tersebut telah berada dalam pengetahuan-Nya, yaitu memenangkan Islam dan menghapus kekafiran, maka Allah melaksanakan hal tersebut (yaitu agar orang yang binasa itu) yakni orang kafir (binasanya berdasarkan keterangan yang nyata) artinya sesudah adanya hujah yang jelas tegak di hadapannya; yaitu melalui dimenangkannya pasukan kaum muslimin sekali pun jumlah mereka sedikit atas pasukan musuh yang jumlahnya sangat banyak itu (dan agar orang yang hidup itu) orang yang mukmin (hidupnya dengan keterangan yang nyata pula. Sesungguhnya Allah Maha Mendengar lagi Maha Mengetahui).\qt@no{42}}%
\qt@newcmd\qurantrans@id@mcciii{%
(Yaitu ketika Allah menampakkan mereka kepadamu di dalam mimpimu) ketika kamu sedang tidur (berjumlah sedikit) lalu kamu memberitahukan hal tersebut kepada sahabat-sahabatmu sehingga mereka merasa gembira dan optimis (Dan sekiranya Allah memperlihatkan mereka kepadamu berjumlah banyak tentu kalian akan merasa gentar) kalian akan berselisih pendapat mengenainya (dan tentu saja kalian akan berbantah-bantahan dalam urusan itu) yakni mengenai masalah peperangan (akan tetapi Allah menyelamatkan kalian) dari rasa gentar dan bantah-bantahan. (Sesungguhnya Allah Maha Mengetahui segala isi hati) apa-apa yang tersimpan di dalam hati.\qt@no{43}}%
\qt@newcmd\qurantrans@id@mcciv{%
(Yaitu ketika Allah menampakkan mereka kepada kamu sekalian) wahai orang-orang mukmin (ketika kalian berjumpa dengan mereka berjumlah sedikit pada penglihatan mata kalian) sekitar tujuh puluh atau seratus orang padahal kenyataannya jumlah mereka ada seribu orang, dimaksud supaya kalian mau maju menghadapi mereka (dan kalian ditampakkan-Nya berjumlah sedikit pada penglihatan mereka) supaya mereka mau maju menghadapi kalian dan mereka tidak mundur untuk memerangi kalian, hal ini berlangsung sebelum perang berkecamuk. Maka tatkala perang telah berkecamuk lalu Allah memperlihatkan kepada mereka jumlah kalian yang lebih besar dua kali lipat daripada jumlah mereka sebagaimana yang telah dijelaskan di dalam surah Ali Imran (karena Allah hendak melakukan suatu urusan yang mesti dilaksanakan. Dan hanya kepada Allahlah dikembalikan segala urusan).\qt@no{44}}%
\qt@newcmd\qurantrans@id@mccv{%
(Hai orang-orang yang beriman, apabila kalian berperang dengan golongan) orang-orang kafir (maka berteguh hatilah) di kala memerangi mereka dan jangan sekali-kali kalian mundur (dan sebutlah nama Allah sebanyak-banyaknya) berdoalah kalian kepada-Nya untuk kemenangan (agar kalian beruntung) memperoleh kemenangan.\qt@no{45}}%
\qt@newcmd\qurantrans@id@mccvi{%
(Dan taatlah kepada Allah dan Rasul-Nya dan janganlah kalian berbantah-bantahan) saling bersengketa di antara sesama kalian (yang menyebabkan kalian menjadi gentar) membuat kalian menjadi pengecut (dan hilang kekuatan kalian) kekuatan dan kedaulatan kalian lenyap (dan bersabarlah. Sesungguhnya Allah beserta orang-orang yang sabar) Dia akan memberikan bantuan dan pertolongan-Nya.\qt@no{46}}%
\qt@newcmd\qurantrans@id@mccvii{%
(Dan janganlah kalian menjadi seperti orang-orang yang keluar dari kampungnya) untuk tujuan melindungi kafilah perdagangan milik mereka, dan mereka tidak mau kembali ke kampung halamannya sesudah kafilah perdagangan mereka selamat dari sergapan pasukan kaum Mukminin (dengan rasa angkuh dan dengan maksud ria kepada manusia) yang mereka telah mengatakan, ``Kami tidak akan kembali sebelum meminum khamar, menyembelih unta dan para penyanyi wanita menghibur kami dengan musik dan nyanyiannya di Badar nanti." Kemudian hal tersebut tersiar beritanya di kalangan orang-orang banyak (serta menghalangi) orang-orang (dari jalan Allah. Dan ilmu Allah terhadap apa yang mereka kerjakan) boleh dibaca ya'maluuna dan boleh pula ta'maluuna (Maha Meliputi) melalui ilmu-Nya, Dia akan membalas semua amal perbuatan mereka.\qt@no{47}}%
\qt@newcmd\qurantrans@id@mccviii{%
(Dan) ingatlah (ketika setan menjadikan mereka memandang baik) yakni iblis (pekerjaan mereka) iblis memberikan semangat kepada mereka untuk menghadapi kaum Muslimin, hal itu dilakukannya ketika mereka merasa takut untuk keluar berperang melawan musuh-musuh mereka Bani Bakar (dan mengatakan,) kepada mereka ("Tidak ada seorang manusia pun yang dapat menang terhadap kalian pada hari ini, dan sesungguhnya aku ini adalah pelindung kalian.") iblis mendatangi mereka dalam bentuk seseorang dari kalangan kabilah Kinanah, yaitu berupa Suraqah bin Malik pemimpin dari orang-orang Kinanah. (Maka tatkala saling lihat-melihat) saling berhadap-hadapan (kedua pasukan itu) pasukan kaum Muslimin dan pasukan kaum kafir dan iblis melihat malaikat berada pada pihak pasukan kaum Muslimin sedangkan pada saat itu tangannya diapit oleh tangan Harits bin Hisyam (setan itu berbalik) kembali (ke belakang) lari (seraya berkata,) tatkala mereka, yaitu pasukan kaum kafir berkata kepadanya, ``Apakah engkau mau membuat kami terhina (kalah) dalam keadaan begini." ("Sesungguhnya saya berlepas diri dari kalian) dari melindungi kalian (sesungguhnya saya dapat melihat apa yang kamu sekalian tidak dapat melihat) yaitu para malaikat (sesungguhnya saya takut kepada Allah.") Dia akan membinasakan saya (Dan Allah sangat keras siksa-Nya).\qt@no{48}}%
\qt@newcmd\qurantrans@id@mccix{%
(Ingatlah ketika orang-orang munafik dan orang-orang yang ada penyakit di dalam hatinya berkata,) lemah keyakinan ("Mereka itu ditipu) yakni kaum Muslimin (oleh agamanya) sebab mereka mau keluar untuk berperang sekalipun jumlah mereka sedikit sedangkan jumlah musuh yang dihadapinya sangat besar bilangannya. Mereka menduga bahwa diri mereka pasti menang oleh sebab jumlah mereka. Maka Allah menjawab mereka melalui firman selanjutnya, (Barang siapa yang bertawakal kepada Allah) percaya bahwa bersama dengan Allah pasti ia menang (maka sesungguhnya Allah Maha Perkasa) menguasai semua perkara-Nya (lagi Maha Bijaksana") di dalam ciptaan-Nya.\qt@no{49}}%
\qt@newcmd\qurantrans@id@mccx{%
(Kalau kamu melihat) hai Muhammad (ketika dicabut jiwa) boleh dibaca yatawaffaa dan boleh pula dibaca tatawaffaa (orang-orang yang kafir oleh para malaikat seraya memukul) lafal yadhribuuna kedudukan i'rabnya menjadi hal/kata keterangan (muka dan belakang mereka) dengan gada-gada besi. (Dan) para malaikat berkata kepada mereka (rasakanlah oleh kalian siksa yang membakar ini) artinya siksa neraka. Jawabnya lau ialah la raaita amran azhiiman (maka niscaya kamu akan menyaksikan peristiwa yang sangat mengerikan).\qt@no{50}}%
\qt@newcmd\qurantrans@id@mccxi{%
(Demikian itu) artinya siksaan atas kalian itu (disebabkan oleh perbuatan tangan kalian sendiri) Allah swt. sengaja memakai kata tangan bukannya anggota-anggota tubuh manusia yang lainnya, karena kebanyakan pekerjaan manusia itu dilakukan oleh tangan mereka (Sesungguhnya Allah sekali-kali tidak menganiaya) artinya tukang menganiaya (hamba-Nya) dengan mengazabnya tanpa dosa.\qt@no{51}}%
\qt@newcmd\qurantrans@id@mccxii{%
Kebiasaan orang-orang kafir itu (sama dengan kebiasaan) tradisi (Firaun dan pengikut-pengikutnya serta orang-orang yang sebelumnya. Mereka mengingkari ayat-ayat Allah, maka Allah menyiksa mereka) mengazab mereka (disebabkan dosa-dosanya) lafal kafaruu dan lafal-lafal sesudahnya merupakan jumlah yang menafsirkan makna lafal-lafal yang sebelumnya. (Sesungguhnya Allah Maha Kuat) atas semua apa yang dikehendaki-Nya (lagi amat keras siksaan-Nya).\qt@no{52}}%
\qt@newcmd\qurantrans@id@mccxiii{%
(Yang demikian itu) disiksa-Nya orang-orang kafir (disebabkan) karena (Allah sekali-kali tidak akan mengubah sesuatu nikmat yang telah dianugerahkan-Nya kepada suatu kaum) dengan cara menggantinya dengan siksaan (sehingga kaum itu mengubah apa yang ada pada diri mereka) sehingga mereka sendiri mengubah nikmat yang mereka terima dengan kekafiran, seperti apa yang telah dilakukan oleh orang-orang kafir Mekah; berbagai macam makanan dilimpahkan kepada mereka, sehingga mereka terhindar dari kelaparan, diamankan-Nya mereka dari rasa takut, dan diutus-Nya Nabi saw. kepada mereka. Kesemuanya itu mereka balas dengan kekafiran, menghambat jalan Allah dan memerangi kaum Mukminin. (Dan sesungguhnya Allah Maha Mendengar lagi Maha Mengetahui).\qt@no{53}}%
\qt@newcmd\qurantrans@id@mccxiv{%
(Keadaan mereka serupa dengan keadaan Firaun dan pengikut-pengikutnya serta orang-orang yang sebelumnya. Mereka mendustakan ayat-ayat Tuhannya maka Kami membinasakan mereka disebabkan dosa-dosanya dan Kami tenggelamkan Firaun dan pengikut-pengikutnya) yakni kaumnya yang menjadi pengikut-pengikutnya (dan kesemuanya) yaitu umat-umat yang mendustakan Tuhan (adalah orang-orang yang zalim). Ayat berikut ini diturunkan berkenaan dengan orang-orang Bani Quraizhah.\qt@no{54}}%
\qt@newcmd\qurantrans@id@mccxv{%
(Sesungguhnya binatang/makhluk yang paling buruk di sisi Allah ialah orang-orang yang kafir, karena mereka itu tidak beriman).\qt@no{55}}%
\qt@newcmd\qurantrans@id@mccxvi{%
(Yaitu orang-orang yang kamu telah mengambil perjanjian dari mereka) hendaknya mereka jangan membantu orang-orang musyrik (sesudah itu mereka mengkhianati janjinya pada setiap kalinya) di mana mereka melakukan perjanjian (dan mereka tidak takut) kepada Allah sewaktu mereka berbuat khianat.\qt@no{56}}%
\qt@newcmd\qurantrans@id@mccxvii{%
(Jika) lafal immaa merupakan gabungan dari in syarthiyyah dan maa zaidah, kemudian keduanya diidgamkan sehingga jadilah immaa (kamu menemui mereka) menjumpai mereka (dalam peperangan, maka cerai-beraikanlah) hancurkanlah (orang-orang yang di belakang mereka dengan menumpas mereka) yang berada dalam barisan depan dengan membasmi dan menghukum mereka (supaya) orang-orang yang berada di belakang mereka (mengambil pelajaran) menjadikannya sebagai pelajaran buat mereka.\qt@no{57}}%
\qt@newcmd\qurantrans@id@mccxviii{%
(Dan jika kamu merasa khawatir dari suatu kaum) yang telah mengadakan perjanjian denganmu (akan perbuatan khianat) terhadap janjinya melalui tanda-tanda yang terlihat jelas olehmu (maka kembalikanlah perjanjian itu) lemparkanlah perjanjian mereka itu (kepada mereka dengan cara yang jujur) lafal sawaaun menjadi kata keterangan, artinya: secara adil antara kamu dan mereka, supaya kedua belah pihak mengetahui bersama siapakah yang merusak perjanjian terlebih dahulu. Yaitu dengan cara kamu memberitahukan kepada mereka tentang pelanggaran tersebut, supaya mereka tidak menuduhmu berbuat khianat bila kamu mengadakan tindakan. (Sesungguhnya Allah tidak menyukai orang-orang yang berkhianat).\qt@no{58}}%
\qt@newcmd\qurantrans@id@mccxix{%
Ayat ini diturunkan berkenaan dengan orang-orang yang merasa dirinya dapat lolos dari kekuasaan Allah (Dan janganlah mengira) engkau hai Muhammad (orang-orang yang kafir itu bahwa mereka dapat lolos) dari kekuasaan Allah. (Sesungguhnya mereka tidak dapat melemahkan Allah) artinya mereka justru tidak dapat meloloskan diri dari Allah. Menurut suatu qiraat dibaca tahsabanna, maf'ul pertamanya tidak disebutkan, yakni lafal anfusahum artinya: janganlah engkau mengira diri mereka hai Muhammad. Menurut qiraat yang lain, innahum dibaca annahum, dengan mentakdirkan lam lengkapnya liannahum.\qt@no{59}}%
\qt@newcmd\qurantrans@id@mccxx{%
(Dan siapkanlah untuk menghadapi mereka) untuk memerangi mereka (kekuatan apa saja yang kalian sanggupi) Rasulullah saw. menjelaskan, bahwa yang dimaksud dengan kekuatan adalah ar-ramyu atau pasukan pemanah. Demikianlah menurut hadis yang diriwayatkan oleh Imam Muslim (dan dari kuda-kuda yang ditambat) lafal ribath berbentuk mashdar, artinya kuda-kuda yang sengaja disediakan untuk berperang di jalan Allah (untuk membuat takut) kalian membuat gentar (dengan adanya persiapan itu musuh Allah dan musuh kalian) artinya orang-orang kafir Mekah (dan orang-orang yang selain mereka) terdiri dari orang-orang munafik atau orang-orang Yahudi (yang kalian tidak mengetahuinya sedangkan Allah mengetahuinya. Apa saja yang kalian nafkahkan pada jalan Allah niscaya akan dibalaskan kepada kalian dengan balasan yang cukup) yakni pahalanya (dan kalian tidak akan dianiaya) tidak akan dikurangi sedikit pun dari pahala kalian.\qt@no{60}}%
\qt@newcmd\qurantrans@id@mccxxi{%
(Dan jika mereka condong) cenderung (kepada perdamaian) boleh dibaca lissilmi dan boleh pula dibaca lissalmi, artinya perdamaian (maka condonglah kepadanya) adakanlah perjanjian dengan mereka untuk itu. Akan tetapi menurut Ibnu Abbas r.a. bahwa ayat ini dimansukh hukumnya oleh ayat perintah untuk berperang. Mujahid mengatakan, bahwa hukum yang terkandung di dalam ayat ini khusus hanya menyangkut ahli kitab sebab ayat ini diturunkan berkenaan dengan orang-orang Yahudi Bani Quraizhah (dan bertawakallah kepada Allah) percayalah kepada-Nya. (Sesungguhnya Dialah Yang Maha Mendengar) perkataan (lagi Maha Mengetahui) perbuatan.\qt@no{61}}%
\qt@newcmd\qurantrans@id@mccxxii{%
(Dan jika mereka bermaksud hendak menipumu) dengan cara berdamai, kemudian mereka bersiap-siap untuk menyerangmu (maka sesungguhnya cukuplah bagimu) cukup bagimu (Allah menjadi pelindung. Dialah yang memperkuatmu dengan pertolongan-Nya dan dengan para mukmin).\qt@no{62}}%
\qt@newcmd\qurantrans@id@mccxxiii{%
(Dan yang mempersatukan) menghimpun (hati mereka) sesudah mengalami ujian-ujian. (Walaupun kamu membelanjakan semua kekayaan yang berada di bumi niscaya kamu tidak dapat mempersatukan hati mereka akan tetapi Allah telah mempersatukan hati mereka) dengan kekuasaan-Nya. (Sesungguhnya Dia Maha Perkasa) Maha Menang atas semua perkara-Nya (lagi Maha Bijaksana) tiada sesuatu pun yang terlepas daripada kebijaksanaan-Nya.\qt@no{63}}%
\qt@newcmd\qurantrans@id@mccxxiv{%
(Hai Nabi, cukuplah Allah dan) cukup untuk menjadi penolongmu (orang-orang mukmin yang mengikutimu).\qt@no{64}}%
\qt@newcmd\qurantrans@id@mccxxv{%
(Hai Nabi, kobarkanlah semangat) berilah semangat (para mukmin itu untuk berperang) melawan orang-orang kafir. (Jika ada dua puluh orang yang sabar di antara kalian niscaya mereka dapat mengalahkan dua ratus orang musuh) di antara orang-orang kafir. (Dan jika ada) boleh dibaca yakun dan boleh pula takun (seratus orang yang sabar di antara kalian, niscaya mereka dapat mengalahkan seribu daripada orang-orang kafir disebabkan orang-orang kafir itu) mereka yang kafir itu (kaum yang tidak mengerti). Ayat ini merupakan ungkapan kalimat berita akan tetapi maknanya adalah sama seperti kalimat perintah; yakni hendaknya dua puluh orang di antara kalian mampu memerangi dua ratus orang kafir dan seratus orang mukmin mampu memerangi seribu orang kafir dan hendaknya mereka (kaum mukmin) bersabar di dalam menghadapi orang-orang kafir. Kemudian ayat ini dinasakh manakala bilangan pasukan kaum mukminin telah banyak jumlahnya, yaitu oleh firman-Nya berikut ini:\qt@no{65}}%
\qt@newcmd\qurantrans@id@mccxxvi{%
(Sekarang Allah telah meringankan kepada kalian dan Dia telah mengetahui bahwa pada diri kalian ada kelemahan) lafal dha`fan boleh dibaca dhu`fan. Artinya kalian tidak mampu lagi untuk memerangi orang-orang yang jumlahnya sepuluh kali lipat jumlah kalian. (Maka jika ada) boleh dibaca yakun boleh dibaca takun (di antara kalian seratus orang yang sabar niscaya mereka dapat mengalahkan dua ratus orang) daripada orang-orang kafir (dan jika di antara kalian ada seribu orang yang sabar niscaya mereka dapat mengalahkan dua ribu orang dengan seizin Allah) dengan kehendak-Nya. Maka kalimat ini sekalipun bentuknya kalimat berita akan tetapi maknanya adalah perintah, yakni hendaknya kalian memerangi orang-orang kafir yang jumlahnya dua kali lipat kalian dan hendaknya kalian bersabar di dalam menghadapi mereka itu (Dan Allah beserta orang-orang yang sabar) pertolongan-Nya selalu menyertai mereka.\qt@no{66}}%
\qt@newcmd\qurantrans@id@mccxxvii{%
Ayat ini diturunkan ketika kaum muslimin memilih untuk mengambil tebusan terhadap para tawanan perang Badar. (Tidak patut bagi seorang nabi) boleh dibaca yakuuna boleh pula takuuna (mempunyai tawanan sebelum ia dapat melumpuhkan musuhnya di muka bumi) lafal yutskhina fil ardhi menunjukkan makna sangat di dalam memerangi orang-orang kafir. (Kalian menghendaki) hai orang-orang mukmin (harta benda duniawi) yakni kebendaannya dengan mengambil tebusan (sedangkan Allah menghendaki) untuk kalian (pahala akhirat) sebagai pahala oleh sebab memerangi orang-orang kafir (Allah Maha Perkasa lagi Maha Bijaksana) ayat ini telah dinasakh oleh firman-Nya, ``Dan sesudah itu kalian boleh membebaskan mereka atau menerima tebusan." (Muhammad 4)\qt@no{67}}%
\qt@newcmd\qurantrans@id@mccxxviii{%
(Kalau sekiranya tidak ada ketetapan yang terdahulu dari Allah) dengan dihalalkannya ganimah dan tawanan bagi kalian (niscaya kalian ditimpa karena tebusan yang kalian ambil) (siksaan yang besar.)\qt@no{68}}%
\qt@newcmd\qurantrans@id@mccxxix{%
(Maka makanlah dari sebagian rampasan perang yang telah kalian ambil itu sebagai makanan yang halal lagi baik dan bertakwalah kepada Allah; sesungguhnya Allah Maha Pengampun lagi Maha Penyayang.)\qt@no{69}}%
\qt@newcmd\qurantrans@id@mccxxx{%
(Hai Nabi, katakanlah kepada tawanan-tawanan yang ada di tanganmu,) menurut suatu qiraat lafal al-asraa dibaca al-asaarii ("Jika Allah mengetahui ada kebaikan dalam hati kalian) yakni keimanan dan keikhlasan (niscaya Dia akan memberikan kepada kalian yang lebih baik daripada apa yang telah kalian berikan) artinya Dia pasti akan melipatgandakannya buat kalian di dunia ini dan kelak di akhirat Dia akan memberi kalian pahala (dan Dia akan mengampuni kalian.") dosa-dosa kalian (Dan Allah Maha Pengampun lagi Maha Penyayang).\qt@no{70}}%
\qt@newcmd\qurantrans@id@mccxxxi{%
(Akan tetapi jika mereka menghendaki) yakni para tawanan tersebut (berbuat khianat kepadamu) melalui perkataan mereka yang berbasa-basi di hadapanmu (maka sesungguhnya mereka telah berkhianat kepada Allah sebelum ini) sebelum perang Badar, mereka telah melakukan kekafiran (lalu Allah menjadikan nabi-Nya berkuasa terhadap mereka) dalam perang Badar sehingga banyak di antara orang-orang kafir yang terbunuh dan tertawan. Maka hendaknya mereka menunggu-nunggu saat seperti itu bilamana mereka kembali lagi melakukan pengkhianatan (dan Allah Maha Mengetahui) makhluk-Nya (lagi Maha Bijaksana) di dalam penciptaan-Nya.\qt@no{71}}%
\qt@newcmd\qurantrans@id@mccxxxii{%
(Sesungguhnya orang-orang yang beriman dan berhijrah serta berjihad dengan harta dan jiwanya pada jalan Allah) yang dimaksud adalah kaum Muhajirin (dan orang-orang yang memberikan tempat kediaman) kepada Nabi saw. (dan pertolongan) yang dimaksud adalah kaum Ansar (mereka itu satu sama lain lindung-melindungi) dalam hal saling tolong-menolong dan waris-mewarisi. (Dan terhadap orang-orang yang beriman, tetapi belum berhijrah, maka tiada kewajiban atas kalian untuk melindungi mereka) dapat dibaca walaayatihim dan wilaayatihim (sedikit pun) oleh karenanya tidak ada saling waris-mewaris antara kalian dan mereka, dan mereka tidak berhak untuk mendapatkan bagian dari ganimah yang kalian peroleh (sebelum mereka berhijrah) akan tetapi ayat ini telah dinasakh oleh ayat yang terdapat dalam akhir surah Al-Anfaal ini. (Akan tetapi jika mereka meminta pertolongan kepada kalian dalam urusan pembelaan agama, maka kalian wajib memberikan pertolongan) kepada mereka dari gangguan orang-orang kafir (kecuali terhadap kaum yang telah ada perjanjian antara kalian dengan mereka) yakni ada perjanjian pertahanan bersama, maka kala itu janganlah kalian menolong mereka, karena akan merusak perjanjian yang telah kalian buat bersama dengan kaum itu. (Dan Allah Maha Melihat apa yang kalian kerjakan).\qt@no{72}}%
\qt@newcmd\qurantrans@id@mccxxxiii{%
(Adapun orang-orang yang kafir, sebagian mereka menjadi pelindung bagi sebagian yang lain). Dalam hal saling tolong-menolong dan saling waris-mewarisi, maka tidak ada saling waris-mewarisi antara kalian dan mereka. (Jika kalian tidak melaksanakan apa yang telah diperintahkan Allah itu) yakni melindungi kaum Muslimin dan menekan orang-orang kafir (niscaya akan terjadi kekacauan di muka bumi dan kerusakan yang besar) karena kekafiran bertambah kuat sedangkan Islam makin melemah keadaannya.\qt@no{73}}%
\qt@newcmd\qurantrans@id@mccxxxiv{%
(Dan orang-orang yang beriman, berhijrah serta berjihad pada jalan Allah dan orang-orang yang memberi tempat kediaman dan memberi pertolongan kepada kaum Muhajirin, mereka itulah orang-orang yang benar-benar beriman. Mereka memperoleh ampunan dan rezeki/nikmat yang mulia) di surga nanti.\qt@no{74}}%
\qt@newcmd\qurantrans@id@mccxxxv{%
(Dan orang-orang yang beriman sesudah itu) sesudah orang-orang yang lebih dahulu beriman dan berhijrah (kemudian berhijrah dan berjihad bersama kalian, maka orang-orang itu termasuk golongan kalian) hai orang-orang Muhajirin dan orang-orang Ansar. (Orang-orang yang mempunyai hubungan kerabat itu) yakni orang-orang yang mempunyai hubungan persaudaraan (sebagiannya lebih berhak terhadap sesamanya) dalam hal waris-mewarisi daripada orang-orang yang mewarisi karena persaudaraan iman dan hijrah yang telah disebutkan pada ayat terdahulu tadi (di dalam Kitabullah) di Lohmahfuz. (Sesungguhnya Allah Maha Mengetahui segala sesuatu) yang antara lain ialah hikmah yang terkandung di dalam hal-ihwal waris-mewarisi.\qt@no{75}}%
\qt@newcmd\qurantrans@id@mccxxxvi{%
\basmalahid Inilah pernyataan (Pemutusan perhubungan daripada Allah dan Rasul-Nya) yang ditunjuk (kepada orang-orang musyrikin yang kalian telah mengadakan perjanjian dengan mereka) yakni perjanjian yang bersifat mutlak, atau perjanjian yang berlaku kurang dari empat bulan, atau lebih dari empat bulan kemudian perjanjian itu dirusak sebagaimana yang akan disebut pada ayat berikutnya.\qt@no{1}}%
\qt@newcmd\qurantrans@id@mccxxxvii{%
(Maka berjalanlah kalian) artinya berjalanlah kalian dengan aman, hai kaum musyrikin (di muka bumi selama empat bulan) dimulai pada bulan Syawal berdasarkan petunjuk yang akan disebutkan nanti. Tiada keamanan lagi bagi kalian sesudah empat bulan itu (dan ketahuilah bahwa sesungguhnya kalian tidak dapat melemahkan Allah) artinya terluput dari azab-Nya (dan sesungguhnya Allah menghinakan orang-orang kafir) Dialah yang membuat mereka hina di dunia melalui pembunuhan dan di akhirat kelak dengan siksaan neraka.\qt@no{2}}%
\qt@newcmd\qurantrans@id@mccxxxviii{%
(Dan inilah suatu permakluman) pengumuman (dari Allah dan Rasul-Nya kepada umat manusia pada hari haji akbar) yaitu hari raya kurban (bahwa) sesungguhnya (Allah berlepas diri dari orang-orang musyrik) dan perjanjian-perjanjian mereka (dan Rasul-Nya) demikian pula. Sehubungan dengan ayat ini Imam Bukhari telah meriwayatkan sebuah hadis, bahwa pada tahun itu juga, yaitu tahun sembilan Hijriah, Nabi saw. mengutus Ali untuk mempermaklumkan ayat-ayat ini pada hari raya kurban di Mina. (Yang isinya ialah), bahwasanya sesudah tahun ini tidak boleh lagi orang musyrik melakukan haji dan tawaf di Baitullah dan tidak boleh pula tawaf di Baitullah dengan telanjang. (Kemudian jika kalian, kaum musyrikin, bertobat) dari kekafiran (maka bertobat itu lebih baik bagi kalian dan jika kalian berpaling) dari iman (maka ketahuilah bahwa sesungguhnya kalian tidak dapat melemahkan Allah. Dan beritakanlah) beritahukanlah (kepada orang-orang kafir akan siksaan yang pedih) azab yang pedih dengan cara dibunuh dan ditawan dan mendapat siksaan neraka kelak di akhirat.\qt@no{3}}%
\qt@newcmd\qurantrans@id@mccxxxix{%
(Kecuali orang-orang musyrik yang kalian telah mengadakan perjanjian dengan mereka dan mereka tidak merusak sedikit pun) syarat-syarat yang tertera dalam perjanjian itu (dan tidak pula mereka membantu) bersekongkol dengan (seseorang untuk memusuhi kalian) dari kalangan orang-orang kafir (maka terhadap mereka itu penuhilah janjinya sampai) habis (batas waktunya.) yang telah kalian tentukan dalam perjanjian itu (Sesungguhnya Allah menyukai orang-orang yang bertakwa) yakni mereka yang memenuhi janjinya.\qt@no{4}}%
\qt@newcmd\qurantrans@id@mccxl{%
(Apabila sudah habis) telah habis (bulan-bulan haram itu) hal ini merupakan batas maksimal masa penangguhan (maka bunuhlah orang-orang musyrik itu di mana saja kalian jumpai mereka) baik di tanah suci maupun di luar tanah suci (dan tangkaplah mereka) dengan menahannya (kepunglah mereka) dalam benteng-benteng dan tempat-tempat perlindungan mereka sehingga mereka terpaksa harus bertempur dengan kalian atau menyerah masuk Islam (dan intailah mereka di tempat pengintaian.) yakni jalan-jalan yang biasa mereka lalui. Dinashabkannya lafal kulla karena huruf jarnya dicabut. (Jika mereka bertobat) dari kekafiran (dan mendirikan salat serta menunaikan zakat, maka berilah kebebasan kepada mereka.) jangan sekali-kali kalian menghambat dan mempersulit mereka (Sesungguhnya Allah Maha Pengampun lagi Maha Penyayang.) terhadap orang yang bertobat.\qt@no{5}}%
\qt@newcmd\qurantrans@id@mccxli{%
(Dan jika seorang di antara orang-orang musyrik itu) lafal ahadun dirafa'kan oleh fi'il/kata kerja yang menafsirkan maknanya (meminta perlindungan kepadamu) maksudnya meminta suaka kepadamu supaya jangan dibunuh (maka lindungilah dia) berilah ia jaminan keamanan (supaya ia sempat mendengar firman Allah) yaitu Alquran (kemudian antarkanlah ia ke tempat yang aman baginya) yaitu tempat tinggal kaumnya, bilamana ternyata ia masih belum mau beriman, supaya ia mempertimbangkan sikapnya itu (Demikian itu) hal yang disebut itu (disebabkan mereka kaum yang tidak mengetahui) agama Allah, maka merupakan suatu keharusan bagi mereka mendengarkan Alquran terlebih dahulu supaya mereka mengetahui dan mengerti akan agama Allah.\qt@no{6}}%
\qt@newcmd\qurantrans@id@mccxlii{%
(Bagaimana) tidak mungkin (bisa ada perjanjian aman dari Allah dan Rasul-Nya dengan orang-orang musyrik) sedangkan mereka masih tetap dalam kekafirannya terhadap Allah dan Rasul-Nya lagi berbuat khianat (kecuali orang-orang yang kalian telah mengadakan perjanjian dengan mereka di dekat Masjidilharam) ketika perang Hudaibiah; mereka adalah orang-orang Quraisy yang dikecualikan sebelumnya (maka selama mereka berlaku lurus terhadap kalian) selagi mereka menepati perjanjiannya dan tidak merusaknya (hendaklah kalian berlaku lurus pula terhadap mereka) dengan menunaikan perjanjian itu. Huruf maa pada lafal famastaqaamuu adalah maa syarthiyah. (Sesungguhnya Allah menyukai orang-orang yang bertakwa) Nabi saw. telah menepati perjanjiannya dengan mereka, sehingga mereka sendirilah yang merusak perjanjian itu, karena mereka membantu Bani Bakar untuk memerangi Bani Khuza'ah.\qt@no{7}}%
\qt@newcmd\qurantrans@id@mccxliii{%
(Bagaimana bisa) ada perjanjian bagi orang-orang musyrikin (padahal jika mereka memperoleh kemenangan atas kalian) mereka mendapat kemenangan atas kalian (mereka tidak memelihara) tidak lagi mengindahkan (hubungan kekerabatan) hubungan kefamilian (dan tidak pula mengindahkan perjanjian) bahkan mereka akan berupaya sekuat tenaga untuk menyakiti dan mengganggu kalian. Jumlah syarat merupakan hal atau kata keterangan. (Mereka menyenangkan hati kalian dengan mulutnya) yakni melalui kata-kata manis mereka (sedangkan hatinya menolak) untuk menunaikan perjanjian itu. (Dan kebanyakan mereka adalah orang-orang yang fasik) selalu merusak perjanjian.\qt@no{8}}%
\qt@newcmd\qurantrans@id@mccxliv{%
(Mereka menukarkan ayat-ayat Allah) yakni Alquran (dengan harga yang sedikit) berupa harta duniawi. Atau dengan kata lain, mereka tidak mau mengikuti Alquran demi memperturutkan hawa nafsunya dan ketamakannya (lalu mereka menghalangi manusia dari jalan Allah) dari agama-Nya. (Sesungguhnya amat buruklah) amat jeleklah (apa yang mereka kerjakan) itu, seburuk-buruk pekerjaan adalah apa yang mereka lakukan.\qt@no{9}}%
\qt@newcmd\qurantrans@id@mccxlv{%
(Mereka tidak memelihara hubungan kerabat terhadap orang-orang mukmin dan tidak pula mengindahkan perjanjian. Dan mereka itulah orang-orang yang melampaui batas).\qt@no{10}}%
\qt@newcmd\qurantrans@id@mccxlvi{%
(Jika mereka bertobat, mendirikan salat dan menunaikan zakat, maka mereka itu adalah saudara-saudara kalian) saudara bagi kalian (yang seagama. Dan Kami menjelaskan) Kami menerangkan (ayat-ayat itu bagi kaum yang mengetahui) kaum yang berpikir.\qt@no{11}}%
\qt@newcmd\qurantrans@id@mccxlvii{%
(Jika mereka merusak) melanggar (sumpahnya) janjinya (sesudah mereka berjanji dan mereka mencerca agama kalian) yakni mencelanya (maka perangilah pemimpin-pemimpin orang-orang kafir) ketua-ketuanya; di dalam ayat ini isim zhahir mengganti kedudukan isim dhamir, yakni lafal aimmatal kufri mengganti kedudukan aimmatahum (sesungguhnya tiada janji) yaitu perjanjian (dari mereka) yang dapat dipegang. Menurut suatu qiraat lafal aimaan dibaca iimaan dengan memakai harakat kasrah pada awal hurufnya (agar mereka berhenti) dari kekafirannya.\qt@no{12}}%
\qt@newcmd\qurantrans@id@mccxlviii{%
(Mengapakah tidak) sebagai suatu seruan (kalian perangi orang-orang yang telah merusak) mengingkari (janjinya) perjanjian mereka (padahal mereka telah keras kemauannya untuk mengusir Rasul) dari Mekah ketika mereka memusyawarahkan hal ini di Darun Nadwah (dan merekalah yang mulai) memerangi kalian (pada awal mulanya) di mana mereka telah memerangi Bani Khuzaah teman sepakta kalian untuk membantu Bani Bakar; apakah gerangan yang mencegah kalian untuk memerangi mereka (apakah kalian takut kepada mereka) merasa gentar menghadapi mereka (padahal Allah lah yang berhak untuk kalian takuti) bilamana kalian tidak memerangi mereka (jika kalian benar-benar orang yang beriman).\qt@no{13}}%
\qt@newcmd\qurantrans@id@mccxlix{%
(Perangilah mereka niscaya Allah akan menyiksa mereka) Allah pasti akan membunuh mereka (dengan perantaraan tangan kalian dan Allah akan menghinakan mereka) Dia akan membuat mereka hina melalui cara penahanan dan penindasan (dan menolong kalian terhadap mereka serta melegakan hati orang-orang yang beriman) melalui apa yang telah dilakukan oleh Bani Khuzaah terhadap mereka yang merusak perjanjian.\qt@no{14}}%
\qt@newcmd\qurantrans@id@mccl{%
(Dan menghilangkan panas hati orang-orang mukmin) kegelisahannya (Dan Allah menerima tobat orang yang dikehendaki-Nya) dengan masuk Islam seperti apa yang dilakukan oleh Abu Sofyan (Allah Maha Mengetahui lagi Maha Bijaksana).\qt@no{15}}%
\qt@newcmd\qurantrans@id@mccli{%
(Apakah) mengandung makna ingkar (kalian mengira bahwa kalian akan dibiarkan begitu saja dan tiada) tidaklah (Allah mengetahui) dengan pengetahuan yang jelas (akan orang-orang yang berjihad di antara kalian) dengan hati yang tulus (dan tidak mengambil menjadi teman yang setia selain Allah, Rasul-Nya dan orang-orang yang beriman) artinya sebagai teman sejawat dan kekasih. Orang-orang yang berhati tulus itu tidak nampak jelas; yang dimaksud dengan mereka ialah orang-orang yang memiliki sifat-sifat seperti apa yang telah disebutkan di atas, mereka berbeda dengan orang-orang lain. (Dan Allah Maha Mengetahui apa yang kalian kerjakan).\qt@no{16}}%
\qt@newcmd\qurantrans@id@mcclii{%
(Tidaklah pantas orang-orang musyrik itu memakmurkan mesjid-mesjid Allah) boleh dibaca mufrad dan boleh pula dibaca jamak, yakni dengan cara memasukinya dan duduk di dalamnya (sedangkan mereka mengakui bahwa mereka sendiri kafir. Itulah orang-orang yang sia-sia) batal (amal perbuatannya dan mereka kekal di dalam neraka).\qt@no{17}}%
\qt@newcmd\qurantrans@id@mccliii{%
(Sesungguhnya yang memakmurkan mesjid-mesjid Allah hanyalah orang-orang yang beriman kepada Allah dan hari kemudian serta tetap mendirikan salat, menunaikan zakat dan tidak takut) kepada seorang pun (selain kepada Allah, maka mereka orang-orang yang diharapkan termasuk orang-orang yang mendapat petunjuk).\qt@no{18}}%
\qt@newcmd\qurantrans@id@mccliv{%
(Apakah orang-orang yang memberi minum kepada orang-orang yang mengerjakan haji dan mengurus Masjidilharam kalian jadikan) orang-orang yang bertugas menunaikan hal-hal tersebut (sama dengan orang-orang yang beriman kepada Allah dan hari kemudian serta berjihad di jalan Allah? Mereka tidak sama di sisi Allah) dalam hal keutamaannya (dan Allah tidak memberikan petunjuk kepada kaum yang lalim) kepada orang-orang yang kafir. Ayat ini diturunkan berkenaan dengan sanggahan Allah terhadap orang yang mengatakan hal tersebut, dia adalah Abbas atau lainnya.\qt@no{19}}%
\qt@newcmd\qurantrans@id@mcclv{%
(Orang-orang yang beriman dan berhijrah serta berjihad di jalan Allah dengan harta dan diri mereka adalah lebih tinggi derajat) yaitu kedudukan (di sisi Allah) daripada orang-orang selain mereka (dan itulah orang-orang yang mendapat kemenangan) orang-orang yang memperoleh kebaikan.\qt@no{20}}%
\qt@newcmd\qurantrans@id@mcclvi{%
(Tuhan mereka menggembirakan mereka dengan memberikan rahmat daripada-Nya, keridaan dan surga, mereka memperoleh di dalamnya kesenangan yang kekal) abadi.\qt@no{21}}%
\qt@newcmd\qurantrans@id@mcclvii{%
(Mereka kekal) menjadi kata keterangan dari lafal yang muqaddarah/tidak disebutkan (di dalamnya selama-lamanya. Sesungguhnya di sisi Allahlah pahala yang besar.)\qt@no{22}}%
\qt@newcmd\qurantrans@id@mcclviii{%
Ayat ini diturunkan berkenaan dengan orang-orang yang tidak turut berhijrah karena alasan keluarga dan usaha perdagangannya yang tidak dapat ditinggalkan (Hai orang-orang yang beriman, janganlah kalian jadikan bapak-bapak dan saudara-saudara kalian menjadi wali, penguasa, kalian jika mereka lebih mengutamakan) lebih memilih (kekafiran atas keimanan dan siapa di antara kalian yang menjadikan mereka sebagai wali, maka mereka itulah orang-orang yang lalim).\qt@no{23}}%
\qt@newcmd\qurantrans@id@mcclix{%
(Katakanlah, ``Jika bapak-bapak, anak-anak, saudara-saudara, istri-istri dan kaum keluarga kalian) yaitu kaum kerabat kalian, menurut suatu qiraat lafal asyiiratukum dibaca asyiiraatukum (dan harta kekayaan yang kalian usahakan) harta hasil usaha kalian (dan perniagaan yang kalian khawatir kerugiannya) khawatir tidak laku (dan rumah-rumah tempat tinggal yang kalian sukai adalah lebih kalian cintai daripada Allah dan Rasul-Nya dan daripada berjihad di jalan-Nya) sehingga hal-hal tersebut mengakibatkan kalian enggan untuk melakukan hijrah dan berjihad di jalan-Nya (maka tunggulah) nantikanlah (sampai Allah mendatangkan keputusan-Nya) ayat ini mengandung makna ancaman buat mereka. (Dan Allah tidak memberi petunjuk kepada orang-orang fasik").\qt@no{24}}%
\qt@newcmd\qurantrans@id@mcclx{%
(Sesungguhnya Allah telah menolong kalian di tempat-tempat) peperangan (yang banyak) seperti dalam perang Badar, perang melawan Bani Quraizhah dan perang melawan Bani Nadhir (dan) ingatlah (peperangan Hunain) Hunain adalah nama sebuah lembah yang terletak di antara kota Mekah dan Thaif. Artinya ingatlah sewaktu kalian berperang melawan orang-orang Hawazin, yaitu dalam bulan Syawal, tahun 8 Hijriah (yaitu di waktu) lafal idz menjadi kata ganti dari lafal yaum (kalian menjadi congkak karena banyaknya jumlah kalian) lalu pada saat itu kalian mengatakan bahwa kami tidak akan dapat dikalahkan oleh golongan yang sedikit. Pada saat itu jumlah pasukan kaum Muslimin ada dua belas ribu orang sedangkan pasukan orang kafir hanya berjumlah empat ribu orang (maka jumlah yang banyak itu tidak memberi manfaat kepada kalian sedikit pun dan bumi yang luas itu telah terasa sempit oleh kalian) huruf maa adalah mashdariyah, artinya sekalipun bumi itu luas tetapi kalian tidak dapat menemukan tempat yang aman sebagai akibat dari pengaruh rasa takut yang menimpa pada saat itu (kemudian kalian lari ke belakang dengan bercerai-berai) karena terpukul akan tetapi Nabi saw. tetap bertahan pada posisinya seraya menaiki kendaraan bagal putihnya dan tiada yang menemaninya selain Abbas serta Abu Sofyan yang memegang tali kendali kendaraan beliau.\qt@no{25}}%
\qt@newcmd\qurantrans@id@mcclxi{%
(Kemudian Allah menurunkan ketenangan) rasa aman (kepada Rasul-Nya dan kepada orang-orang Mukmin) sehingga mereka kembali lagi bergabung dengan Nabi saw. sewaktu Abbas memanggil/menyeru mereka atas instruksi dari Nabi, lalu mereka meneruskan peperangan itu (dan Allah menurunkan bala tentara yang kalian tiada melihatnya) yakni para malaikat (dan Allah menimpakan bencana kepada orang-orang kafir) sehingga banyak di antara mereka yang terbunuh dan tertawan (dan demikianlah pembalasan kepada orang-orang kafir).\qt@no{26}}%
\qt@newcmd\qurantrans@id@mcclxii{%
(Sesudah itu Allah menerima tobat dari orang-orang yang dikehendaki-Nya) dari kalangan orang-orang kafir karena masuk Islam (Allah Maha Pengampun lagi Maha Penyayang).\qt@no{27}}%
\qt@newcmd\qurantrans@id@mcclxiii{%
(Hai orang-orang yang beriman, sesungguhnya orang-orang yang musyrik itu najis) maksudnya kotor karena batin mereka najis (maka janganlah mereka mendekati Masjidilharam) artinya, mereka tidak boleh memasuki tanah suci (sesudah tahun ini) yakni tahun kesembilan Hijriah. (Dan jika kalian khawatir menjadi beban) fakir oleh sebab orang-orang musyrik itu tidak mau lagi berdagang dengan kalian (maka Allah nanti akan memberikan kekayaan kepada kalian dari karunia-Nya, jika Dia menghendaki) dan memang Allah telah membuat mereka kaya sesudah itu melalui banyaknya futuh/kemenangan dan jizyah yang berhasil mereka peroleh. (Sesungguhnya Allah Maha Mengetahui lagi Maha Bijaksana).\qt@no{28}}%
\qt@newcmd\qurantrans@id@mcclxiv{%
(Perangilah orang-orang yang tidak beriman kepada Allah dan tidak pula kepada hari kemudian) jika tidak demikian niscaya dari dahulu mereka sudah beriman kepada Nabi saw. (dan mereka tidak mengharamkan apa yang telah diharamkan oleh Allah dan Rasul-Nya) seperti khamar (dan tidak beragama dengan agama yang benar) yakni agama yang telah ditetapkan oleh Allah yang mengganti agama-agama lainnya, yaitu agama Islam (yaitu orang-orang) lafal alladziina pada ayat ini berkedudukan menjelaskan lafal alladziina pada awal ayat (yang diberikan Alkitab kepada mereka) kepada orang-orang Yahudi dan orang-orang Nasrani (sampai mereka membayar jizyah) kharaj yang dibebankan kepada mereka untuk membayarnya setiap tahun (dengan patuh) lafal yadin berkedudukan menjadi hal/kata keterangan, artinya, secara taat dan patuh, atau mereka menyerahkannya secara langsung tanpa memakai perantara atau wakil (sedangkan mereka dalam keadaan tunduk) yaitu patuh dan taat terhadap peraturan/hukum Islam.\qt@no{29}}%
\qt@newcmd\qurantrans@id@mcclxv{%
(Orang-orang Yahudi berkata, ``Uzair itu putra Allah," dan orang-orang Nasrani berkata, ``Almasih itu) yakni Nabi Isa (adalah putra Allah." Demikian itulah ucapan mereka dengan mulut mereka tanpa ada sandaran dalil yang mendukung perkataannya itu, bahkan (mereka meniru-niru) perkataan mereka itu meniru (perkataan orang-orang kafir yang terdahulu) dari kalangan nenek moyang mereka, karena menuruti tradisi mereka. (Semoga mereka dilaknat) dikutuk (oleh Allah, bagaimana) mengapa (mereka sampai berpaling) maksudnya bagaimana mereka sampai berani berpaling dari kebenaran, padahal dalilnya sudah jelas dan gamblang.\qt@no{30}}%
\qt@newcmd\qurantrans@id@mcclxvi{%
(Mereka menjadikan orang-orang alimnya) dimaksud adalah ulama-ulama Yahudi (dan rahib-rahib mereka) para pendeta Nasrani (sebagai tuhan selain Allah) karena para pengikut agama Yahudi dan Nasrani mengikuti mereka dalam hal menghalalkan apa yang telah diharamkan oleh Allah dan mengharamkan apa yang telah dihalalkan oleh-Nya (dan juga mereka mempertuhankan Almasih putra Maryam, padahal mereka tidak diperintahkan) oleh kitab Taurat dan kitab Injil mereka (melainkan hanya menyembah) maksudnya mereka disuruh supaya menyembah (Tuhan Yang Maha Esa, tidak ada Tuhan selain Dia, Maha Suci Allah) lafal subhaanahu mengandung arti menyucikan Allah (dari apa yang mereka persekutukan).\qt@no{31}}%
\qt@newcmd\qurantrans@id@mcclxvii{%
(Mereka berkehendak memadamkan cahaya/agama Allah) yakni syariat dan bukti-bukti-Nya (dengan mulut mereka) melalui perkataan-perkataan mereka dalam hal ini (dan Allah tidak menghendaki selain menyempurnakan) memenangkan (cahaya-Nya walaupun orang-orang yang kafir tidak menyukai) hal tersebut.\qt@no{32}}%
\qt@newcmd\qurantrans@id@mcclxviii{%
(Dialah yang telah mengutus rasul-Nya) yakni Nabi Muhammad saw. (dengan membawa petunjuk dan agama yang benar untuk dimenangkan-Nya) Dialah yang meninggikan agama-Nya (atas segala agama) semua agama yang berbeda dengan agama-Nya (walaupun orang-orang musyrik tidak menyukai) hal tersebut.\qt@no{33}}%
\qt@newcmd\qurantrans@id@mcclxix{%
(Hai orang-orang yang beriman, sesungguhnya sebagian besar dari orang-orang alim Yahudi dan rahib-rahib Nasrani benar-benar memakan) yakni mengambil (harta benda orang lain dengan cara yang batil) seperti menerima suap dalam memutuskan hukum (dan mereka menghalang-halangi) manusia (dari jalan Allah) dari agama-Nya. (Dan orang-orang) lafal ini menjadi mubtada/permulaan kata (yang menyimpan emas dan perak dan tidak menafkahkannya) dimaksud ialah menimbunnya (pada jalan Allah) artinya mereka tidak menunaikan hak zakatnya dan tidak membelanjakannya ke jalan kebaikan (maka beritahukanlah kepada mereka) beritakanlah kepada mereka (akan siksa yang pedih) yang amat menyakitkan.\qt@no{34}}%
\qt@newcmd\qurantrans@id@mcclxx{%
(Pada hari dipanaskan emas dan perak itu dalam neraka Jahanam lalu disetrika) dibakar (dengannya dahi, lambung dan punggung mereka) bakaran emas-perak itu merata mengenai seluruh kulit tubuh mereka lalu dikatakan kepada mereka ("Inilah harta benda kalian yang kalian simpan untuk diri kalian sendiri, maka rasakanlah sekarang akibat dari apa yang kalian simpan itu") sebagai pembalasannya.\qt@no{35}}%
\qt@newcmd\qurantrans@id@mcclxxi{%
(Sesungguhnya bilangan bulan) jumlah bulan pertahunnya (pada sisi Allah adalah dua belas bulan dalam Kitabullah) dalam Lohmahfuz (di waktu Dia menciptakan langit dan bumi, di antaranya) bulan-bulan tersebut (empat bulan suci) yang disucikan, yaitu Zulkaidah, Zulhijah, Muharam dan Rajab. (Itulah) penyucian bulan-bulan yang empat tersebut (agama yang lurus) artinya agama yang mustaqim (maka janganlah kalian menganiaya dalam bulan-bulan tersebut) dalam bulan-bulan yang empat itu (diri kalian sendiri) dengan melakukan kemaksiatan. Karena sesungguhnya perbuatan maksiat yang dilakukan dalam bulan-bulan tersebut dosanya lebih besar lagi. Menurut suatu penafsiran disebutkan bahwa dhamir fiihinna kembali kepada itsnaa `asyara, artinya dalam bulan-bulan yang dua belas itu (dan perangilah kaum musyrikin itu semuanya) seluruhnya dalam bulan-bulan yang dua belas itu (sebagaimana mereka pun memerangi kalian semuanya; dan ketahuilah bahwasanya Allah beserta orang-orang yang takwa) pertolongan dan bantuan-Nya selalu menyertai mereka.\qt@no{36}}%
\qt@newcmd\qurantrans@id@mcclxxii{%
(Sesungguhnya mengundur-undurkan bulan haram itu) yaitu menangguhkan kesucian bulan haram tersebut kepada bulan yang lain seperti tradisi yang biasa dilakukan pada zaman jahiliah. Mereka biasa mengakhirkan kesucian bulan Muharam, bilamana waktu bulan Muharam tiba sedangkan mereka masih dalam peperangan, maka mereka memindahkan kesucian bulan Muharam kepada bulan Safar (adalah menambah kekafiran) karena kekafiran terhadap ketentuan hukum yang telah ditetapkan Allah dalam bulan Muharam itu (disesatkan) dapat dibaca yadhallu dan dapat pula dibaca yadhillu (orang-orang yang kafir dengan mengundur-undurkan itu, mereka menghalalkan) perbuatan mengundur-undurkan itu (pada suatu tahun dan mereka mengharamkannya pada tahun yang lain agar mereka dapat menyesuaikan) supaya penghalalan dan pengharaman bulan mereka dan pergantiannya cocok (dengan bilangan) hitungan (yang Allah mengharamkannya) yakni bulan-bulan yang diharamkan oleh Allah. Dalam hal ini mereka tidak menambah-nambahkan atas empat bulan yang diharamkan itu dan pula mereka tidak menguranginya hanya mereka tidak memperhatikan lagi ketentuan-ketentuan waktu yang telah ditetapkan Allah (maka mereka menghalalkan apa yang diharamkan Allah. Setan menjadikan mereka memandang baik perbuatan mereka yang buruk itu) sehingga mereka menduganya sebagai perbuatan yang baik (Dan Allah tidak memberi petunjuk kepada orang-orang yang kafir).\qt@no{37}}%
\qt@newcmd\qurantrans@id@mcclxxiii{%
Ayat ini diturunkan sewaktu Nabi saw. menyeru kaum muslimin untuk berangkat ke perang Tabuk sedangkan pada saat itu udara sangat panas dan cuacanya sulit sehingga hal itu membuat mereka berat untuk melakukannya (Hai orang-orang yang beriman apakah sebabnya apabila dikatakan kepada kalian, ``Berangkatlah untuk berperang pada jalan Allah lalu kalian merasa berat) lafal itstsaaqaltum pada asalnya tatsaaqaltum kemudian huruf ta diganti dengan huruf tsa lalu diidgamkan atau digabungkan dengan huruf tsa yang asli setelah itu ditarik hamzah washal sehingga jadilah itstsaaqaltum. Artinya kalian malas dan enggan untuk melakukan jihad (dan ingin tinggal di tempat kalian saja?) artinya ingin tetap di tempat tinggal, istifham/kata tanya pada permulaan ayat mengandung makna taubikh/celaan. (Apakah kalian puas dengan kehidupan di dunia) dengan kesenang-kesenangannya (sebagai ganti kehidupan akhirat?) sebagai ganti kenikmatan ukhrawi (padahal kenikmatan hidup di dunia ini di) dibandingkan dengan kenikmatan (akhirat hanyalah sedikit") sangat kecil dan tidak ada artinya.\qt@no{38}}%
\qt@newcmd\qurantrans@id@mcclxxiv{%
(Jika) lafal illaa di sini pada asalnya ialah gabungan antara in syarthiyah dan laa nafi (kalian tidak berangkat) keluar bersama dengan Nabi saw. untuk melakukan jihad (niscaya Allah menyiksa kalian dengan siksaan yang pedih)) yang menyakitkan (dan diganti-Nya kalian dengan kaum yang lain) artinya Allah akan mendatangkan kaum yang lain sebagai pengganti kalian (dan kalian tidak dapat memberi kemudaratan kepada-Nya) yakni kepada Allah atau kepada Nabi saw. (sedikit pun) dikarenakan kalian tidak mau membantunya, maka sesungguhnya Allahlah yang akan menolong agama-Nya (Dan Allah Maha Kuasa atas segala sesuatu) yang antara lain ialah menolong agama dan Nabi-Nya.\qt@no{39}}%
\qt@newcmd\qurantrans@id@mcclxxv{%
(Jika kalian tidak menolongnya) yakni Nabi Muhammad saw. (maka sesungguhnya Allah telah menolongnya, yaitu ketika) sewaktu (orang-orang kafir mengeluarkannya) dari Mekah, artinya mereka memaksanya supaya keluar dari Mekah sebagai tindak lanjut dari rencana yang telah mereka musyawarahkan di Darun Nadwah, yaitu membunuh, menahan atau mengusirnya (sedangkan dia salah seorang dari dua orang) lafal ayat ini menjadi hal/keterangan keadaan; maksudnya sewaktu dia menjadi salah seorang dari dua orang sedangkan yang lainnya ialah Abu Bakar. Pengertian yang tersirat dari ayat ini ialah semoga Allah menolongnya dalam keadaan seperti itu, maka semoga pula Dia tidak membiarkannya dalam keadaan yang lainnya. (Ketika) menjadi badal/kata ganti daripada lafal idz yang sebelumnya (keduanya berada dalam gua) di bukit Tsur (di waktu) menjadi badal daripada idz yang kedua (dia berkata kepada temannya,) kepada Abu Bakar yang pada saat melihat kaki kaum musyrikin ia berkata kepada Nabi saw., ``Seandainya salah seorang daripada mereka melihat ke arah bawah telapak kakinya niscaya dia akan dapat melihat kita berdua." ("Janganlah kamu berduka cita, sesungguhnya Allah beserta kita.") melalui pertolongan-Nya. (Maka Allah menurunkan ketenangan-Nya) rasa aman (kepadanya) menurut suatu pendapat dikatakan bahwa dhamir di sini kembali kepada Nabi Muhammad saw. sedangkan menurut pendapat yang lain kembali kepada Abu Bakar (dan membantunya) yakni Nabi Muhammad saw. (dengan tentara yang kalian tidak melihatnya) yaitu para malaikat, di dalam gua tersebut dan di medan-medan pertempuran yang dialaminya (dan Allah menjadikan seruan orang-orang kafir) yaitu seruan kemusyrikan (itulah yang rendah) yakni kalah. (Dan kalimat Allah) kalimat syahadat (itulah yang tinggi) yang tampak dan menang. (Allah Maha Perkasa) dalam kerajaan-Nya (lagi Maha Bijaksana) di dalam penciptaan-Nya.\qt@no{40}}%
\qt@newcmd\qurantrans@id@mcclxxvi{%
(Berangkatlah kalian baik dalam keadaan merasa ringan atau pun merasa berat) dalam keadaan bersemangat atau pun dalam keadaan tidak bersemangat. Menurut penafsiran yang lain dikatakan bahwa arti ayat ini ialah baik dalam keadaan kuat maupun dalam keadaan lemah atau baik dalam keadaan berkecukupan maupun dalam keadaan kekurangan. Akan tetapi ayat ini dinasakh oleh firman Allah swt. yang lain, yaitu, ``Tiada dosa (lantaran tidak pergi berjihad) atas orang-orang yang lemah..." (Q.S. At-Taubah 91). (dan berjihadlah dengan harta dan diri kalian di jalan Allah. Yang demikian itu adalah lebih baik bagi kalian jika kalian mengetahui) bahwasanya hal ini lebih baik bagi diri kalian, oleh sebab itu jangan sekali-kali kalian merasa berat. Ayat ini diturunkan berkenaan dengan sikap orang-orang munafik, yaitu mereka yang enggan pergi berperang.\qt@no{41}}%
\qt@newcmd\qurantrans@id@mcclxxvii{%
(Kalau) apa yang engkau serukan kepada mereka itu (berupa keuntungan) yaitu harta duniawi (yang mudah diperoleh) gampang diraih (dan perjalanan yang tidak berapa jauh) artinya pertengahan (pastilah mereka mengikutimu) dengan niat untuk mendapatkan ganimah (tetapi tempat yang dituju itu amat jauh terasa oleh mereka) karena itu mereka tidak mau ikut. (Mereka akan bersumpah atas nama Allah) bilamana kalian kembali kepada mereka ("Jika kami sanggup) berangkat (tentulah kami berangkat bersama-sama kalian." Mereka membinasakan diri mereka sendiri) dengan sumpah dusta (dan Allah mengetahui bahwa sesungguhnya mereka benar-benar orang-orang yang dusta) dalam perkataan mereka yang demikian itu.\qt@no{42}}%
\qt@newcmd\qurantrans@id@mcclxxviii{%
Rasulullah saw. memberi izin kepada segolongan orang-orang untuk tidak ikut berjihad yang keputusannya ini berdasarkan ijtihad dari diri beliau sendiri. Maka turunlah wahyu kepada Rasulullah saw. sebagai teguran hanya saja Allah swt. di dalam wahyu-Nya kali ini mendahulukan maaf atas perbuatan yang telah dilakukannya; dimaksud sebagai penenang hati. (Semoga Allah memaafkanmu, mengapa kamu memberi izin kepada mereka) untuk tidak ikut berjihad dan mengapa kamu tidak membiarkan mereka (sebelum jelas bagimu orang-orang yang benar) dalam keuzurannya (dan sebelum kamu ketahui orang-orang yang berdusta?) dalam hal ini.\qt@no{43}}%
\qt@newcmd\qurantrans@id@mcclxxix{%
(Orang-orang yang beriman kepada Allah dan hari kemudian, tidak akan meminta izin kepadamu) untuk tidak ikut (berjihad dengan harta dan diri mereka. Dan Allah mengetahui orang-orang yang bertakwa).\qt@no{44}}%
\qt@newcmd\qurantrans@id@mcclxxx{%
(Sesungguhnya yang akan meminta izin kepadamu) untuk tidak ikut berjihad (hanyalah orang-orang yang tidak beriman kepada Allah dan hari kemudian dan merasa ragu) yakni ragu-ragu (hatinya) akan kebenaran agama Islam (karena itu mereka selalu bimbang dalam keraguannya) artinya mereka selalu bingung di dalam menentukan sikapnya.\qt@no{45}}%
\qt@newcmd\qurantrans@id@mcclxxxi{%
(Dan jika mereka mau berangkat) bersamamu (tentulah mereka menyiapkan persiapan untuk keberangkatan itu) niscaya mereka akan mempersiapkan alat-alat perang dan perbekalan (tetapi Allah tidak menyukai keberangkatan mereka) artinya Dia tidak menghendaki mereka berangkat (maka Allah melemahkan keinginan mereka) Allah membuat mereka malas (dan dikatakan) kepada mereka ("Tinggallah kalian bersama orang-orang yang tinggal itu.") yaitu orang-orang yang sakit, kaum wanita dan anak-anak kecil. Artinya Allah swt. telah menakdirkan hal tersebut.\qt@no{46}}%
\qt@newcmd\qurantrans@id@mcclxxxii{%
(Jika mereka berangkat bersama-sama kalian, niscaya mereka tidak menambah kalian selain dari kekacauan) yaitu kerusakan melalui hasutan yang mereka lancarkan kepada kaum mukminin guna melemahkan semangat juangnya (dan niscaya mereka akan bergegas-gegas maju ke muka di celah-celah barisan kalian untuk melancarkan adu domba (mereka menghendaki kalian) yakni mempunyai tujuan supaya kalian (menjadi kacau) melalui siasat adu dombanya (sedangkan di antara kalian ada orang-orang yang suka mendengarkan perkataan mereka) artinya mau menerima apa yang mereka katakan. (Dan Allah mengetahui orang-orang yang lalim).\qt@no{47}}%
\qt@newcmd\qurantrans@id@mcclxxxiii{%
(Sesungguhnya mereka selalu ingin menjerumuskanmu) dirimu (ke dalam kekacauan sejak dahulu) yaitu semenjak kamu datang di Madinah (dan mereka mengatur berbagai macam tipu daya untuk merusakmu) mereka selalu berupaya untuk menipumu dan membatalkan agamamu (hingga datanglah kebenaran) yaitu pertolongan Allah (dan menanglah) berjayalah (perkara Allah) yakni agama-Nya (padahal mereka tidak menyukai)nya. Akhirnya dengan terpaksa mereka masuk Islam akan tetapi hanya lahiriah saja.\qt@no{48}}%
\qt@newcmd\qurantrans@id@mcclxxxiv{%
(Di antara mereka ada orang yang berkata, ``Berilah saya izin) untuk tidak ikut berperang (dan janganlah kamu menjadikan saya terjerumus ke dalam fitnah.") orang yang mengatakan demikian ialah Jaddu bin Qais. Nabi saw. telah berkata kepadanya, ``Apakah kamu mampu sabar di dalam memerangi orang-orang kulit kuning (putih)?" Maka Jaddu menjawab, ``Sesungguhnya saya tidak tahan menghadapi wanita dan saya takut bilamana melihat wanita kulit kuning tidak dapat menahan diri sehingga saya terjerumus ke dalam fitnah." Maka Allah swt. berfirman (Ketahuilah bahwa mereka telah terjerumus ke dalam fitnah) karena tidak ikut berangkat. Menurut suatu qiraat lafal saqathuu dibaca saqatha. (Dan sesungguhnya Jahanam itu betul-betul meliputi orang-orang kafir) tidak ada sesuatu pun yang dapat menyelamatkan mereka dari neraka Jahanam.\qt@no{49}}%
\qt@newcmd\qurantrans@id@mcclxxxv{%
(Jika kamu mendapat sesuatu kebaikan) seperti mendapat kemenangan dan ganimah (mereka merasa tidak senang karenanya dan jika kamu ditimpa oleh suatu bencana) yaitu keadaan yang kritis (mereka berkata, ``Sesungguhnya kami telah memikirkan urusan kami) secara matang sewaktu kami tidak ikut berangkat (sebelumnya.") sebelum terjadinya bencana ini (kemudian mereka berpaling dengan rasa gembira) atas musibah yang telah menimpamu.\qt@no{50}}%
\qt@newcmd\qurantrans@id@mcclxxxvi{%
(Katakanlah,) kepada mereka ("Sekali-kali tidak akan menimpa kami melainkan apa yang telah ditetapkan oleh Allah bagi kami) yaitu bencana. (Dialah pelindung kami) yang menolong dan yang mengatur urusan-urusan kami (dan hanya kepada Allahlah orang-orang yang beriman harus bertawakal.")\qt@no{51}}%
\qt@newcmd\qurantrans@id@mcclxxxvii{%
(Katakanlah, ``Tidak ada yang kalian tunggu-tunggu) asal kata tarabbashuuna adalah tatarabbashuuna, kemudian salah satu huruf ta-nya dibuang sehingga jadilah tarabbashuuna, artinya, tiada sesuatu pun yang kalian tunggu-tunggu akan terjadi (bagi kami kecuali salah satu) akibat (dari dua kebaikan) lafal husnayayni adalah bentuk kata tatsniyah dari lafal husnaa, dan sekaligus adalah bentuk muannats dari lafal ahsan; yang dimaksud ialah mendapat kemenangan atau gugur sebagai syuhada. (Dan kami menunggu-nunggu) menanti-nanti (bagi kalian bahwa Allah akan menimpakan kepada kalian azab dari sisi-Nya) melalui azab yang turun dari langit (atau azab dengan tangan kami) melalui perintah-Nya yang mengizinkan kami untuk memerangi kalian. (Sebab itu tunggulah) hal tersebut dari kami (sesungguhnya kami menunggu-nunggu bersama kalian.") akibat yang akan kalian terima.\qt@no{52}}%
\qt@newcmd\qurantrans@id@mcclxxxviii{%
(Katakanlah, ``Nafkahkanlah harta kalian) demi taat kepada Allah (baik dengan sukarela atau pun dengan terpaksa, namun nafkah itu sekali-kali tidak akan diterima dari kalian) harta yang telah kalian nafkahkan itu. (Sesungguhnya kalian adalah orang-orang yang fasik.") kalimat perintah di sini mengandung makna kalimat berita.\qt@no{53}}%
\qt@newcmd\qurantrans@id@mcclxxxix{%
(Dan tidak ada yang menghalangi mereka untuk diterima) dapat dibaca yuqbala dan dapat pula dibaca tuqbala (dari mereka nafkah-nafkahnya melainkan karena mereka) lafal annahum menjadi fa'il/subjek sedangkan lafal an tuqbala objek/maf'ulnya (kafir kepada Allah dan Rasul-Nya dan mereka tidak mengerjakan salat melainkan dengan malas) dengan berat melakukannya (dan tidak pula menafkahkan harta mereka melainkan dengan rasa enggan) untuk berinfak, karena mereka menganggapnya sebagai suatu kerugian.\qt@no{54}}%
\qt@newcmd\qurantrans@id@mccxc{%
(Maka janganlah harta benda dan anak-anak mereka menarik hatimu) artinya jangan sekali-kali kamu menganggap baik nikmat-nikmat Kami yang telah kami limpahkan kepada mereka, karena sesungguhnya hal itu adalah istidraj (Sesungguhnya Allah bermaksud menimpakan azab kepada mereka) yakni hendak mengazab mereka (dengan memberi harta benda dan anak-anak itu di dunia) melalui jerih payah yang mereka alami di dalam mengumpulkannya, dan sekaligus di dalamnya terkandung berbagai malapetaka dan musibah (dan kelak akan melayang) yakni dicabut (nyawa mereka, sedangkan mereka dalam keadaan kafir) maka Allah akan mengazab mereka di akhirat dengan siksaan yang amat keras.\qt@no{55}}%
\qt@newcmd\qurantrans@id@mccxci{%
(Dan mereka/orang-orang munafik bersumpah dengan nama Allah bahwa sesungguhnya mereka termasuk golongan kalian) yakni mengaku sebagai orang-orang mukmin (padahal mereka bukanlah dari golongan kalian akan tetapi mereka adalah orang-orang yang sangat takut kepada kalian) artinya mereka takut kalian akan memperlakukan diri mereka seperti apa yang kalian lakukan terhadap kaum musyrikin. Oleh karenanya mereka berani bersumpah demi untuk melindungi dirinya/taqiyah.\qt@no{56}}%
\qt@newcmd\qurantrans@id@mccxcii{%
(Jika mereka memperoleh tempat perlindungan) tempat yang dapat melindungi mereka (atau gua-gua) tempat berlindung (atau lubang-lubang) dalam tanah yang dapat dijadikan sebagai perlindungan (niscaya mereka pergi kepadanya dengan secepat-cepatnya) bergegas di dalam memasukinya, bergegas mereka lari dari kalian bagaikan kuda yang larat yang tidak dapat diharapkan untuk kembali lagi.\qt@no{57}}%
\qt@newcmd\qurantrans@id@mccxciii{%
(Dan di antara mereka ada orang yang mencelamu) mencacimu (tentang) pembagian (zakat; jika mereka diberi sebagian daripadanya mereka bersenang hati dan jika mereka tidak diberi sebagian daripadanya dengan serta merta mereka menjadi marah).\qt@no{58}}%
\qt@newcmd\qurantrans@id@mccxciv{%
(Jika mereka sungguh-sungguh rida dengan apa yang diberikan Allah dan Rasul-Nya) berupa ganimah dan hal-hal yang sejenis dengannya (lalu mereka mengatakan, ``Cukuplah bagi kami) yakni telah mencukupi kami (Allah, Dia akan memberikan kepada kami sebagian dari karunia-Nya dan demikian pula Rasul-Nya) ganimah yang lainnya yang dapat mencukupi kami (sesungguhnya kami adalah orang-orang yang berharap kepada Allah.") semoga Dia memberikan kecukupan kepada kami. Jawab daripada lafal lau ialah lakaana khairan lahum (tentulah yang demikian itu lebih baik dari mereka).\qt@no{59}}%
\qt@newcmd\qurantrans@id@mccxcv{%
(Sesungguhnya zakat-zakat) zakat-zakat yang diberikan (hanyalah untuk orang-orang fakir) yaitu mereka yang tidak dapat menemukan peringkat ekonomi yang dapat mencukupi mereka (orang-orang miskin) yaitu mereka yang sama sekali tidak dapat menemukan apa-apa yang dapat mencukupi mereka (pengurus-pengurus zakat) yaitu orang yang bertugas menarik zakat, yang membagi-bagikannya, juru tulisnya, dan yang mengumpulkannya (para mualaf yang dibujuk hatinya) supaya mau masuk Islam atau untuk memantapkan keislaman mereka, atau supaya mau masuk Islam orang-orang yang semisal dengannya, atau supaya mereka melindungi kaum Muslimin. Mualaf itu bermacam-macam jenisnya; menurut pendapat Imam Syafii jenis mualaf yang pertama dan yang terakhir pada masa sekarang (zaman Imam Syafii) tidak berhak lagi untuk mendapatkan bagiannya, karena Islam telah kuat. Berbeda dengan dua jenis mualaf yang lainnya, maka keduanya masih berhak untuk diberi bagian. Demikianlah menurut pendapat yang sahih (dan untuk) memerdekakan (budak-budak) yakni para hamba sahaya yang berstatus mukatab (orang-orang yang berutang) orang-orang yang mempunyai utang, dengan syarat bila ternyata utang mereka itu bukan untuk tujuan maksiat; atau mereka telah bertobat dari maksiat, hanya mereka tidak memiliki kemampuan untuk melunasi utangnya, atau diberikan kepada orang-orang yang sedang bersengketa demi untuk mendamaikan mereka, sekalipun mereka adalah orang-orang yang berkecukupan (untuk jalan Allah) yaitu orang-orang yang berjuang di jalan Allah tetapi tanpa ada yang membayarnya, sekalipun mereka adalah orang-orang yang berkecukupan (dan orang-orang yang sedang dalam perjalanan) yaitu yang kehabisan bekalnya (sebagai suatu ketetapan yang diwajibkan) lafal fariidhatan dinashabkan oleh fi'il yang keberadaannya diperkirakan (Allah; dan Allah Maha Mengetahui) makhluk-Nya (lagi Maha Bijaksana) dalam penciptaan-Nya. Ayat ini menyatakan bahwa zakat tidak boleh diberikan kepada orang-orang selain mereka, dan tidak boleh pula mencegah zakat dari sebagian golongan di antara mereka bilamana golongan tersebut memang ada. Selanjutnya imamlah yang membagi-bagikannya kepada golongan-golongan tersebut secara merata; akan tetapi imam berhak mengutamakan individu tertentu dari suatu golongan atas yang lainnya. Huruf lam yang terdapat pada lafal lilfuqaraa` memberikan pengertian wajib meratakan pembagian zakat kepada setiap individu-individu yang berhak. Hanya saja tidak diwajibkan kepada pemilik harta yang dizakati, bilamana ia membaginya sendiri, meratakan pembagiannya kepada setiap golongan, karena hal ini amat sulit untuk dilaksanakan. Akan tetapi cukup baginya memberikannya kepada tiga orang dari setiap golongan. Tidak cukup baginya bilamana ternyata zakatnya hanya diberikan kepada kurang dari tiga orang; demikianlah pengertian yang disimpulkan dari ungkapan jamak pada ayat ini. Sunah telah memberikan penjelasannya, bahwa syarat bagi orang yang menerima zakat itu, antara lain ialah muslim, hendaknya ia bukan keturunan dari Bani Hasyim dan tidak pula dari Bani Muthalib.\qt@no{60}}%
\qt@newcmd\qurantrans@id@mccxcvi{%
(Di antara mereka) orang-orang munafik (ada yang menyakiti Nabi) dengan mencelanya dan menyampaikan perkataannya kepada kaum munafikin (dan mereka mengatakan) bilamana mereka dicegah dari perbuatan tersebut supaya jangan menyakiti nabi ("Nabi mempercayai semua apa yang didengarnya.") yakni Nabi selalu mendengar apa yang dikatakan kepadanya dan selalu menerimanya. Bilamana kami bersumpah kepadanya bahwa kami tidak menyatakannya, maka dia mempercayai kami. (Katakanlah,) ``Ia (mempercayai) mendengarkan (semua yang baik bagi kalian) bukannya mendengarkan hal-hal yang buruk (ia beriman kepada Allah, mempercayai) artinya selalu percaya (orang-orang mukmin) atas semua berita yang telah disampaikan mereka, akan tetapi ia tidak mempercayai orang-orang selain mereka. Huruf lam di sini adalah lam zaidah; dimaksud untuk memberikan pengertian yang membedakan antara iman karena sadar dan iman karena faktor lainnya (dan menjadi rahmat) bila dibaca rafa' maka diathafkan kepada lafal udzunun, dan bila dibaca jar maka diathafkan kepada lafal khairin (bagi orang-orang yang beriman di antara kalian." Dan orang-orang yang menyakiti Rasulullah itu, bagi mereka siksa yang pedih).\qt@no{61}}%
\qt@newcmd\qurantrans@id@mccxcvii{%
(Mereka bersumpah dengan nama Allah kepada kalian) wahai orang-orang mukmin, atas apa yang kalian dengar dari mereka, yaitu berupa perbuatan yang menyakitkan Rasulullah. Mereka bersumpah bahwa mereka tidak melakukannya (untuk mencari keridaan kalian, padahal Allah dan Rasul-Nya itu yang lebih patut mereka cari keridaannya) dengan melalui ketaatan (jika mereka adalah orang-orang yang mukmin) sebenarnya. Disatukannya dhamir karena mengingat kaitan di antara dua keridaan. Khabar daripada lafal allaah atau lafal rasuuluhu dibuang atau tidak disebutkan.\qt@no{62}}%
\qt@newcmd\qurantrans@id@mccxcviii{%
(Tidakkah mereka mengetahui bahwasanya) dhamir di sini adalah dhamir sya`n (barang siapa menentang) melawan (Allah dan Rasul-Nya, maka sesungguhnya neraka Jahanamlah baqinya) sebagai pembalasan (dia kekal di dalamnya. Itu adalah kehinaan yang besar).\qt@no{63}}%
\qt@newcmd\qurantrans@id@mccxcix{%
(Merasa takut) merasa khawatir (orang-orang munafik itu akan diturunkan terhadap mereka) yaitu kaum Mukminin (suatu surah yang menerangkan apa yang tersembunyi dalam hati mereka) yakni tentang kemunafikan mereka, tetapi sekalipun demikian mereka masih tetap memperolok-olokkannya (Katakanlah, ``Teruskanlah ejekan-ejekan kalian.") perintah yang mengandung makna ancaman (Sesungguhnya Allah akan menyatakan) akan menampakkan (apa yang kalian takuti) yaitu kemunafikan kalian akan ditampakkan.\qt@no{64}}%
\qt@newcmd\qurantrans@id@mccc{%
(Dan jika) Lam bermakna qasam/sumpah (kamu tanyakan kepada mereka) tentang ejekan-ejekan mereka terhadap dirimu dan terhadap Alquran, padahal mereka berangkat bersamamu ke Tabuk (tentulah mereka akan menjawab) mengemukakan alasannya ("Sesungguhnya kami hanyalah bersenda-gurau dan bermain-main saja") dalam ucapan kami guna melenyapkan rasa bosan dalam menempuh perjalanan yang jauh ini, dan kami tidak bermaksud apa-apa selain daripada itu (Katakanlah)kepada mereka! ("Apakah dengan Allah, ayat-ayat-Nya dan Rasul-Nya kalian berolok-olok?").\qt@no{65}}%
\qt@newcmd\qurantrans@id@mccci{%
(Tidak usah kalian meminta maaf) akan hal tersebut (karena kalian kafir sesudah beriman) artinya kekafiran kalian ini tampak sesudah kalian menampakkan keimanan. (Jika Kami memaafkan) bila dibaca memakai ya berarti menjadi mabni maf'ul sehingga bacaannya menjadi ya'fa. Jika dibaca memakai huruf nun, berarti mabni fa'il, dan bacaannya seperti yang tertera pada ayat (segolongan daripada kalian) lantaran keikhlasan dan tobatnya, seperti apa yang dilakukan oleh Jahsy bin Humair (niscaya Kami akan mengazab) dapat dibaca tu`adzdzib dan dapat pula dibaca nu`adzdzib (golongan yang lain disebabkan mereka adalah orang-orang yang selalu berbuat dosa) yakni, karena mereka selalu menetapi kemunafikannya dan selalu melancarkan ejekan-ejekan.\qt@no{66}}%
\qt@newcmd\qurantrans@id@mcccii{%
(Orang-orang munafik laki-laki dan orang-orang munafik perempuan sebagian dari mereka dengan sebagian yang lain adalah sama) yakni mereka mempunyai sikap dan sepak terjang yang sama, perihalnya sama dengan setali tiga uang (mereka menyuruh membuat yang mungkar) berupa kekafiran dan maksiat-maksiat (dan melarang berbuat yang makruf) berupa keimanan dan ketaatan (dan mereka menggenggam tangannya) daripada berinfak di jalan ketaatan (mereka telah lupa kepada Allah) artinya mereka tidak mau taat kepada-Nya (maka Allah melupakan mereka) dibiarkannya mereka melupakan pertanda sifat pemurah Allah. (Sesungguhnya orang-orang munafik itulah orang-orang yang fasik).\qt@no{67}}%
\qt@newcmd\qurantrans@id@mccciii{%
(Allah mengancam orang-orang munafik laki-laki dan perempuan dan orang-orang kafir dengan neraka Jahanam, mereka kekal di dalamnya. Cukuplah neraka itu bagi mereka) sebagai pembalasan dan hukuman (dan Allah melaknat mereka) Dia menjauhkan mereka dari rahmat-Nya (dan bagi mereka azab yang kekal) yang abadi.\qt@no{68}}%
\qt@newcmd\qurantrans@id@mccciv{%
Keadaan kalian hai orang-orang munafik (seperti keadaan orang-orang yang sebelum kalian, mereka lebih kuat daripada kalian dan lebih banyak harta benda dan anak-anaknya daripada kalian. Maka mereka telah menikmati) mereka telah bersenang-senang (dengan bagian mereka) maksudnya bagian duniawi mereka (dan kalian telah menikmati) hai orang-orang munafik (bagian kalian sebagaimana orang-orang yang sebelum kalian menikmati bagiannya dan kalian mempercakapkan) hal-hal yang batil dan mencela Nabi saw. (sebagaimana mereka mempercakapkannya) seperti apa yang biasa mereka pergunjingkan. (Mereka itu amalannya menjadi sia-sia di dunia dan di akhirat dan mereka itulah orang-orang yang merugi).\qt@no{69}}%
\qt@newcmd\qurantrans@id@mcccv{%
(Belumkah datang kepada mereka berita penting) kabar penting (tentang orang-orang yang sebelum mereka; yaitu kaum Nuh, Ad) kaumnya Nabi Hud (Tsamud) kaumnya Nabi Saleh (kaum Ibrahim dan penduduk Madyan) kaumnya Nabi Syuaib (dan penduduk negeri-negeri yang telah musnah) negeri-negeri tempat tinggal kaumnya Nabi Luth, yang dimaksud ialah para penduduknya. (Telah datang kepada mereka rasul-rasul dengan membawa keterangan yang nyata) dengan membawa mukjizat-mukjizat akan tetapi mereka tetap mendustakannya, akhirnya mereka dibinasakan (maka Allah tidaklah sekali-kali menganiaya mereka) seumpamanya Dia mengazab mereka tanpa dosa (akan tetapi merekalah yang menganiaya diri mereka sendiri) oleh sebab dosa-dosa yang mereka lakukan.\qt@no{70}}%
\qt@newcmd\qurantrans@id@mcccvi{%
(Dan orang-orang yang beriman, lelaki dan perempuan sebagian mereka adalah menjadi penolong bagi sebagian yang lain. Mereka menyuruh mengerjakan yang makruf, mencegah dari yang mungkar, mendirikan salat, menunaikan zakat dan mereka taat kepada Allah dan Rasul-Nya. Mereka itu akan diberi rahmat oleh Allah; sesungguhnya Allah Maha Perkasa) tiada sesuatu pun yang dapat menghalang-halangi apa-apa yang akan dilaksanakan oleh janji dan ancaman-Nya (lagi Maha Bijaksana) Dia tidak sekali-kali meletakkan sesuatu melainkan persis pada tempat yang sesuai.\qt@no{71}}%
\qt@newcmd\qurantrans@id@mcccvii{%
(Allah menjanjikan kepada orang-orang yang mukmin, lelaki dan perempuan akan mendapat surga yang di bawahnya mengalir sungai-sungai, kekal mereka di dalamnya dan mendapat tempat-tempat yang bagus di surga Adn) yaitu tempat tinggal (Dan keridaan Allah adalah lebih besar) lebih agung daripada kesemuanya itu (itu adalah keberuntungan yang besar).\qt@no{72}}%
\qt@newcmd\qurantrans@id@mcccviii{%
(Hai Nabi, berjihadlah melawan orang-orang kafir) dengan senjata (dan orang-orang munafik itu) dengan memakai hujah dan lisan (dan bersikap keraslah terhadap mereka) dengan sikap keras dan benci. (Tempat mereka ialah neraka Jahanam. Dan itulah tempat kembali yang seburuk-buruknya) yakni tempat yang paling buruk adalah neraka Jahanam.\qt@no{73}}%
\qt@newcmd\qurantrans@id@mcccix{%
(Mereka berani bersumpah) yaitu orang-orang munafik (dengan memakai nama Allah bahwa mereka tidak mengatakan) sesuatu yang menyakiti hatimu. (Sesungguhnya mereka telah mengucapkan perkataan kekafiran dan telah menjadi kafir sesudah Islam) yakni mereka telah menampakkan kekafirannya sesudah terlebih dahulu mereka menampakkan keislamannya (dan mengingini apa yang mereka tidak dapat mencapainya) keinginan mereka untuk membunuh Nabi saw. pada malam Aqabah sewaktu beliau kembali dari Tabuk. Jumlah mereka yang mengadakan makar itu ada belasan orang lelaki akan tetapi Ammar bin Yasir segera bertindak memukuli muka-muka kendaraan mereka tatkala mereka mulai mengepung Nabi saw. sehingga mereka bubar (dan mereka tidak mencela) mengingkari Allah dan Rasul-Nya (kecuali karena Allah dan Rasul-Nya telah melimpahkan kecukupan kepada mereka sebagai karunia-Nya) berupa ganimah sesudah mereka sangat menginginkannya. Dengan kata lain mereka belum pernah menerima hal tersebut darinya melainkan hanya kali ini dan hal ini bukan merupakan hal yang diingkari. (Maka jika mereka bertobat) dari kemunafikannya lalu mereka benar-benar beriman kepadamu (itu adalah lebih baik bagi mereka, dan jika mereka berpaling) dari keimanan (niscaya Allah akan mengazab mereka dengan siksaan yang pedih di dunia) dengan dibunuhnya mereka (dan di akhirat) dengan neraka (dan mereka sekali-kali tidak mempunyai pelindung) yang dapat melindungi mereka dari azab Allah itu (dan tidak pula penolong di muka bumi yang dapat mempertahankan diri mereka.\qt@no{74}}%
\qt@newcmd\qurantrans@id@mcccx{%
(Dan di antara mereka ada orang yang telah berikrar kepada Allah, ``Sesungguhnya jika Allah memberikan sebagian karunia-Nya kepada kami, pastilah kami akan bersedekah) lafal lanashshaddaqanna pada asalnya lanatashaddaqanna, kemudian huruf ta dimasukkan ke dalam huruf shad yang bagian asal kalimat, sehingga jadilah lanashshaddaqanna (dan pastilah kami termasuk orang-orang yang saleh.") orang yang dimaksud ialah Tsa'labah bin Hathib, pada suatu hari ia meminta kepada Nabi saw. supaya mendoakannya, semoga Allah memberinya rezeki harta, kelak ia akan menunaikan hak-haknya kepada setiap orang yang berhak menerimanya. Kemudian Nabi saw. mendoakannya sesuai dengan permintaannya itu; akhirnya Allah memberinya harta yang banyak, sehingga ia lupa akan salat Jumat dan salat berjemaah yang biasa dilakukannya karena sibuk dengan hartanya yang banyak itu, dan lebih parah lagi ia tidak menunaikan zakatnya sebagaimana yang dijelaskan oleh Allah swt. dalam ayat berikutnya, yaitu:\qt@no{75}}%
\qt@newcmd\qurantrans@id@mcccxi{%
(Maka setelah Allah memberikan kepada mereka sebagian dari karunia-Nya, mereka kikir dengan karunia itu, dan berpaling) dari taat kepada Allah (dan mereka memanglah orang-orang yang selalu berpaling dari kebenaran).\qt@no{76}}%
\qt@newcmd\qurantrans@id@mcccxii{%
(Maka Allah menimpakan kepada mereka) yakni menjadikan akibat mereka (kemunafikan) yang tetap (pada hati mereka sampai kepada waktu mereka menemui-Nya) menemui Allah, yaitu pada hari kiamat nanti (karena mereka telah memungkiri terhadap Allah apa yang telah mereka ikrarkan kepada-Nya dan juga karena mereka selalu berdusta) dengan janjinya. Setelah itu Tsa'labah bin Hathib datang menghadap Nabi saw. sambil membawa zakatnya, akan tetapi Nabi saw. berkata kepadanya, ``Sesungguhnya Allah telah melarang aku menerima zakatmu." Setelah itu Rasulullah saw. lalu menaburkan tanah di atas kepalanya. Pada masa pemerintahan Khalifah Abu Bakar r.a. ia datang membawa zakatnya kepada Khalifah Abu Bakar, akan tetapi Khalifah Abu Bakar tidak mau menerimanya. Pada masa pemerintahan Khalifah Umar r.a. ia pun datang membawa zakatnya, akan tetapi Khalifah Umar juga tidak mau menerimanya. Pada masa pemerintahan Khalifah Usman ia pun datang lagi membawa zakatnya, akan tetapi ternyata Khalifah Usman sama saja juga tidak mau menerimanya. Ia mati pada masa pemerintahan Khalifah Usman r.a.\qt@no{77}}%
\qt@newcmd\qurantrans@id@mcccxiii{%
(Tidakkah mereka tahu) orang-orang munafik itu (bahwasanya Allah mengetahui rahasia mereka) apa-apa yang mereka simpan di dalam diri mereka (dan bisikan mereka) yakni apa-apa yang mereka bisikkan di antara sesama mereka (dan bahwasanya Allah amat mengetahui segala yang gaib) yang dimaksud dengan gaib ialah segala sesuatu yang tidak terlihat oleh mata. Ketika ayat mengenai sedekah ini diturunkan, ada seorang lelaki datang dengan membawa sedekah yang banyak sekali, lalu orang-orang munafik itu mengatakan, ``Dia hanya ingin pamer saja." Datang pula seorang lelaki lain seraya membawa sedekah satu sha', maka orang-orang munafik itu mengatakan pula, ``Sesungguhnya Allah Maha Kaya dari sedekahnya orang ini", maka pada saat itu juga turunlah firman- Nya berikut ini, yaitu:\qt@no{78}}%
\qt@newcmd\qurantrans@id@mcccxiv{%
(Orang-orang) menjadi mubtada (yang mencela) menganggap aib (orang-orang yang dengan suka rela) senang hati (memberi sedekah dari kalangan orang-orang mukmin, dan mencela orang-orang yang tidak memperoleh sekadar kesanggupannya) kemampuannya lalu mereka menyedekahkannya (maka orang-orang munafik itu menghina mereka) sedangkan khabar daripada mubtada tadi ialah (Allah akan membalas penghinaan mereka itu) artinya, Allah membalas penghinaannya (dan untuk mereka azab yang pedih).\qt@no{79}}%
\qt@newcmd\qurantrans@id@mcccxv{%
(Kamu memohonkan ampun) hai Muhammad (bagi mereka atau tidak kamu mohonkan ampun bagi mereka adalah sama saja) ayat ini mengandung pengertian takhyir, yakni boleh memilih memintakan ampun atau tidak. Sehubungan dengan hal ini Rasulullah saw. telah bersabda, ``Sesungguhnya aku disuruh memilih, maka aku memilih memintakan ampun." (H.R. Bukhari) (Kendatipun kamu memohonkan ampun bagi mereka tujuh puluh kali, namun Allah sekali-kali tidak akan memberi ampun kepada mereka). Menurut suatu pendapat pengertian tujuh puluh kali ini merupakan ungkapan mubalaghah yang menunjukkan banyaknya istigfar (memohonkan ampun). Di dalam kitab sahih Bukhari telah diketengahkan sebuah hadis mengenai hal ini yaitu, ``Seandainya aku mengetahui, bahwa jika permohonan ampunku diterima bila dibacakan lebih daripada tujuh puluh kali, maka niscaya aku akan menambahkannya." (H.R. Bukhari). Dalam pendapat yang lain dikatakan, bahwa pengertian yang dimaksud ialah bilangan tertentu, yaitu tujuh puluh itu sendiri. Hal ini pun berlandaskan pada hadis Nabi saw. pula, yaitu, ``Aku akan membacakannya lebih dari tujuh puluh kali." Kemudian Allah swt. menjelaskan kepada Nabi-Nya tentang pemutusan ampunan, yaitu melalui firman-Nya, ``Sama saja bagi mereka, kamu mintakan ampunan atau tidak kamu mintakan ampunan. Niscaya Allah sekali-kali tidak akan mengampuni mereka. Sesungguhnya Allah tidak memberi petunjuk kepada orang-orang yang fasik." (Q.S. Al-Munafiqun 6). (Yang demikian itu adalah karena mereka kafir kepada Allah dan Rasul-Nya. Dan Allah tidak memberi petunjuk kepada kaum yang fasik).\qt@no{80}}%
\qt@newcmd\qurantrans@id@mcccxvi{%
(Orang-orang yang ditinggalkan merasa gembira) yaitu mereka yang tidak ikut ke Tabuk (dengan tinggalnya mereka) dengan ketidakikutan mereka (sesudah) keberangkatan (Rasulullah, dan mereka tidak suka berjihad dengan harta dan jiwa mereka pada jalan Allah dan mereka berkata,) artinya sebagian dari mereka mengatakan kepada sebagian yang lain ("Janganlah kalian berangkat) maksudnya janganlah kalian pergi untuk berjihad (dalam panas terik ini." Katakanlah, ``Api neraka Jahanam itu lebih sangat panas) daripada panasnya Tabuk. Yang lebih utama ialah hendaknya mereka menghindarkan diri daripada panasnya Jahanam itu, yaitu dengan ikut berperang dan tidak tinggal di tempat (jika mereka mengetahui) artinya jika mereka mengetahui hal tersebut, tentulah mereka tidak akan tinggal di tempat dan pasti ikut berjihad.\qt@no{81}}%
\qt@newcmd\qurantrans@id@mcccxvii{%
(Maka hendaklah mereka tertawa sedikit) di dunia (dan hendaklah mereka menangis) di akhirat nanti (banyak sebagai pembalasan dari apa yang selalu mereka kerjakan) ayat ini merupakan berita tentang keadaan mereka, diungkapkan dalam bentuk ungkapan amar/perintah.\qt@no{82}}%
\qt@newcmd\qurantrans@id@mcccxviii{%
(Maka jika kamu telah dikembalikan) bila telah dipulangkan dengan selamat (oleh Allah) dari Tabuk (lalu kamu kembali kepada satu golongan dari mereka) yaitu dari kalangan orang-orang munafik yang tinggal di Madinah tidak ikut berangkat berjihad (kemudian mereka minta izin kepadamu untuk keluar) bersamamu dalam perang yang lain (maka katakanlah) kepada mereka ("Kalian tidak boleh keluar bersamaku selama-lamanya dan tidak boleh memerangi musuh bersamaku. Sesungguhnya kalian telah rela tidak pergi berperang kali yang pertama. Karena itu duduklah/tinggallah bersama orang-orang yang tidak ikut berperang.") maksudnya bersama mereka yang tidak ikut berperang, yaitu bersama kaum wanita, anak-anak dan lain-lainnya.\qt@no{83}}%
\qt@newcmd\qurantrans@id@mcccxix{%
Ketika Nabi saw. melakukan salat jenazah atas kematian Ibnu Ubay (pemimpin orang-orang munafik), maka turunlah firman-Nya: (Dan janganlah kamu sekali-kali menyalatkan jenazah seorang yang mati di antara mereka, dan janganlah kamu berdiri di kuburnya) untuk keperluan menguburkannya atau menziarahinya. (Sesungguhnya mereka telah kafir kepada Allah dan Rasul-Nya dan mereka mati dalam keadaan fasik) yaitu dalam keadaan kafir.\qt@no{84}}%
\qt@newcmd\qurantrans@id@mcccxx{%
(Dan janganlah harta benda dan anak-anak mereka menarik hatimu. Sesungguhnya Allah menghendaki akan mengazab mereka di dunia dengan harta dan anak-anak itu dan agar melayang) dicabut (nyawa mereka dalam keadaan kafir).\qt@no{85}}%
\qt@newcmd\qurantrans@id@mcccxxi{%
(Dan apabila diturunkan suatu surah) yakni sebagian daripada surah-surah Alquran (bahwa) yang memerintahkan mereka (berimanlah kalian kepada Allah dan berjihadlah beserta Rasul-Nya, niscaya akan meminta izin kepadamu orang-orang yang sanggup) yakni mereka yang memiliki kemampuan (di antara mereka untuk tidak berjihad dan mereka berkata, ``Biarkanlah kami berada bersama orang-orang yang duduk.").\qt@no{86}}%
\qt@newcmd\qurantrans@id@mcccxxii{%
(Mereka rela berada bersama dengan orang-orang yang tidak pergi berperang) lafal khawaalif merupakan bentuk jamak daripada lafal khaalifah, yang dimaksud adalah kaum wanita yang tinggal di rumah-rumahnya (dan hati mereka telah dikunci mati, maka mereka tidak mengetahui) kebaikan.\qt@no{87}}%
\qt@newcmd\qurantrans@id@mcccxxiii{%
(Tetapi Rasul dan orang-orang yang beriman bersama dia, mereka berjihad dengan harta dan diri mereka. Dan mereka itulah orang-orang yang memperoleh kebaikan) di dunia dan di akhirat (dan mereka itu pulalah orang-orang yang beruntung) orang-orang yang mendapatkan keberuntungan.\qt@no{88}}%
\qt@newcmd\qurantrans@id@mcccxxiv{%
(Allah telah menyediakan bagi mereka surga yang mengalir di bawahnya sungai-sungai, mereka kekal di dalamnya. Itulah kemenangan yang besar).\qt@no{89}}%
\qt@newcmd\qurantrans@id@mcccxxv{%
(Kemudian datanglah orang-orang yang mengemukakan uzur) asalnya lafal al-mu`adzdziruuna ialah al-mu`tadziruuna kemudian huruf ta diidgamkan ke dalam huruf dzal sehingga jadilah al-mu`adzdziruuna keduanya mempunyai arti yang sama lalu dibaca al-mu`adzdziruuna (yaitu orang-orang Arab penduduk padang pasir) kepada Nabi saw. (agar diberi izin bagi mereka) untuk tetap tinggal di kampungnya, tidak pergi berjihad karena berhalangan, akhirnya Nabi saw. memberi izin kepada mereka (sedangkan orang-orang yang mendustakan Allah dan Rasul-Nya duduk berdiam diri saja) mereka yang diam adalah orang-orang yang berpura-pura beriman dari kalangan orang-orang munafik penduduk padang pasir, mereka diam saja tidak datang menghadap kepada Nabi saw. untuk mengemukakan alasan ketidakikutannya. (Kelak orang-orang yang kafir di antara mereka itu akan ditimpa azab yang pedih).\qt@no{90}}%
\qt@newcmd\qurantrans@id@mcccxxvi{%
(Tiada dosa atas orang-orang yang lemah) yakni orang-orang jompo (atas orang-orang yang sakit) seperti orang buta dan orang yang sakit parah yang tak sembuh-sembuh (dan atas orang-orang yang tidak memperoleh apa yang akan mereka nafkahkan) untuk berjihad (apabila mereka berlaku ikhlas kepada Allah dan Rasul-Nya) sewaktu ia tidak pergi berjihad, yaitu tidak menimbulkan kekacauan dan rasa takut kepada orang-orang lain dan tetap menaati peraturan. (Tidak atas orang-orang yang berbuat baik) yakni orang-orang yang melaksanakan hal tersebut (jalan) alasan untuk menyalahkan mereka. (Dan Allah Maha Pengampun) kepada mereka (lagi Maha Penyayang) kepada mereka di dalam memberikan kelonggaran mengenai masalah tidak pergi berjihad ini.\qt@no{91}}%
\qt@newcmd\qurantrans@id@mcccxxvii{%
(Dan tiada pula dosa atas orang-orang yang apabila mereka datang kepadamu supaya kamu memberi mereka kendaraan) untuk berangkat berperang bersamamu; jumlah mereka ada tujuh orang yang semuanya berasal dari kalangan sahabat Ansar. Akan tetapi menurut pendapat lain dikatakan bahwa mereka semua berasal dari Bani Muqarrin (lalu kamu berkata, ``Aku tidak memperoleh kendaraan untuk membawa kalian.") jumlah ayat ini menjadi hal/kalimat keterangan (lalu mereka kembali) lafal ayat ini menjadi jawab dari kata idzaa, artinya mereka bubar kembali ke rumah masing-masing (sedangkan mata mereka bercucuran) yakni mengalirkan (berupa) lafal min di sini mempunyai arti bayan/kata penjelasan/kata penafsir (air mata karena kesedihan) lantaran mereka (tidak memperoleh apa yang akan mereka nafkahkan) untuk berjihad.\qt@no{92}}%
\qt@newcmd\qurantrans@id@mcccxxviii{%
(Sesungguhnya jalan untuk menyalahkan itu hanyalah terhadap orang-orang yang meminta izin kepadamu) untuk tidak ikut berangkat berjihad (padahal mereka itu orang-orang kaya. Mereka rela berada bersama-sama orang-orang yang tidak ikut berperang dan Allah telah mengunci mati hati mereka, maka mereka tidak mengetahui) akibat perbuatan mereka.\qt@no{93}}%
\qt@newcmd\qurantrans@id@mcccxxix{%
(Mereka mengemukakan uzurnya kepada kalian) untuk tidak pergi berperang (apabila kalian telah kembali kepada mereka) dari medan perang (Katakanlah) kepada mereka ("Janganlah kalian mengemukakan uzur, kami tidak percaya lagi kepada kalian) kami sudah tidak mempercayai lagi kalian (karena sesungguhnya Allah telah memberitahukan kepada kami di antara berita-berita rahasia kalian) Allah telah memberitahukan kepada kami tentang hal-ihwal kalian. (Dan Allah serta Rasul-Nya akan melihat pekerjaan kalian kemudian kalian dikembalikan) melalui dibangkitkan dari dalam kubur (kepada Yang Mengetahui yang gaib dan yang nyata) yakni Allah (lalu Dia memberitahu kepada kalian apa yang telah kalian kerjakan.") maka Dia membalasnya kepada kalian.\qt@no{94}}%
\qt@newcmd\qurantrans@id@mcccxxx{%
(Kelak mereka akan bersumpah kepada kalian dengan nama Allah, apabila kalian kembali) yakni pulang (kepada mereka) dari medan perang Tabuk untuk menunjukkan bahwa mereka benar-benar mempunyai alasan yang tepat sewaktu mereka tidak ikut berangkat (supaya kalian berpaling dari mereka) artinya supaya tidak mencela perbuatan mereka itu. (Maka berpalinglah dari mereka karena sesungguhnya mereka itu adalah najis) najis karena batin mereka kotor (dan tempat mereka Jahanam sebagai balasan atas apa yang telah mereka kerjakan.)\qt@no{95}}%
\qt@newcmd\qurantrans@id@mcccxxxi{%
(Mereka akan bersumpah kepada kalian agar kalian rida kepada mereka. Tetapi jika sekiranya kalian rida kepada mereka, maka sesungguhnya Allah tidak rida kepada orang-orang yang fasik itu) artinya Allah tidak rela kepada mereka dan kerelaan kalian kepada mereka sedikit pun tidak akan bermanfaat buat mereka, karena Allah telah murka kepada mereka.\qt@no{96}}%
\qt@newcmd\qurantrans@id@mcccxxxii{%
(Orang-orang Arab itu) yaitu penduduk daerah badui (lebih sangat kekafiran dan kemunafikannya) daripada penduduk daerah perkotaan; karena penduduk daerah badui berwatak keras dan kasar serta mereka jauh dari mendengarkan Alquran (dan lebih wajar) lebih patut (tidak mengetahui hukum-hukum yang diturunkan Allah kepada Rasul-Nya) berupa hukum-hukum dan syariat-syariat. Huruf allaa asalnya terdiri dari an dan laa kemudian keduanya digabungkan, sehingga jadilah allaa. (Dan Allah Maha Mengetahui) tentang makhluk-Nya (lagi Maha Bijaksana) di dalam mengatur penciptaan mereka.\qt@no{97}}%
\qt@newcmd\qurantrans@id@mcccxxxiii{%
(Di antara orang-orang Arab badui itu ada orang yang memandang apa yang dinafkahkannya) di jalan Allah (sebagai suatu kerugian) ketekoran dan kerugian sebab ia tidak mengharapkan akan pahalanya melainkan menginfakkannya karena rasa takut; mereka adalah Bani Asad dan Bani Ghathafan (dan menanti-nanti) malapetaka menimpa kalian sehingga ia bebas dari kalian (merekalah yang akan ditimpa marabahaya) dapat dibaca as-suu` dan dapat pula dibaca as-sau`, artinya azab dan kebinasaan itu justru akan menimpa mereka sendiri bukannya menimpa kalian. (Dan Allah Maha Mendengar) akan semua ucapan hamba-hamba-Nya (lagi Maha Mengetahui) perbuatan-perbuatan mereka.\qt@no{98}}%
\qt@newcmd\qurantrans@id@mcccxxxiv{%
(Dan di antara orang-orang Arab badui itu ada orang-orang yang beriman kepada Allah dan hari kemudian) seperti kabilah Juhainah dan kabilah Muzayyanah (dan menjadikan apa yang ia infakkan) di jalan Allah (sebagai amal taqarrub) maksudnya mendekatkan diri kepada-Nya (di sisi Allah dan) sebagai jalan untuk (memperoleh selawat) yakni doa-doa (Rasul) kepadanya. (Ketahuilah, sesungguhnya nafkah itu) artinya nafkah mereka itu (merupakan amal taqarrub) dapat dibaca qurubaatun dan dapat pula dibaca qurbatun (bagi mereka) di sisi-Nya. (Kelak Allah akan memasukkan mereka ke dalam rahmat-Nya) yaitu surga-Nya. (Sesungguhnya Allah Maha Pengampun) kepada orang-orang yang taat kepada-Nya (lagi Maha Penyayang) terhadap mereka yang taat.\qt@no{99}}%
\qt@newcmd\qurantrans@id@mcccxxxv{%
(Orang-orang yang terdahulu lagi yang pertama-tama masuk Islam di antara orang-orang Muhajirin dan Ansar) mereka adalah para sahabat yang ikut perang Badar atau yang dimaksud adalah semua para sahabat (dan orang-orang yang mengikuti mereka) sampai hari kiamat (dengan baik) dalam hal amal perbuatannya. (Allah rida kepada mereka) melalui ketaatan mereka kepada-Nya (dan mereka pun rida kepada Allah) rida akan pahala-Nya (dan Allah menyediakan bagi mereka surga-surga yang mengalir sungai-sungai di bawahnya) menurut suatu qiraat lafal tahtahaa dibaca dengan memakai huruf min sebelumnya sehingga bacaannya menjadi min tahtihaa (mereka kekal di dalamnya selama-lamanya. Itulah kemenangan yang besar).\qt@no{100}}%
\qt@newcmd\qurantrans@id@mcccxxxvi{%
(Di antara orang-orang yang di sekeliling kalian) hai penduduk Madinah (dari kalangan orang-orang Arab badui ada orang-orang munafik) seperti orang-orang kabilah Aslam, kabilah Asyja` dan kabilah Ghiffar (dan juga di antara penduduk Madinah) ada orang-orang munafik pula. (Mereka keterlaluan dalam kemunafikannya) artinya kemunafikan mereka telah mendalam dan sudah mengakar di hati mereka. (Kamu tidak mengetahui mereka) hai Muhammad (tetapi Kamilah yang mengetahui mereka. Nanti mereka akan Kami siksa dua kali) dengan terungkapnya kemunafikan mereka, atau dibunuh di dunia dan disiksa di alam kubur (kemudian mereka akan dikembalikan) di akhirat nanti (kepada azab yang besar) yaitu siksa neraka.\qt@no{101}}%
\qt@newcmd\qurantrans@id@mcccxxxvii{%
(Dan) ada pula suatu kaum (yang lain) lafal ayat ini menjadi mubtada (mereka mengakui dosa-dosa mereka) karena tidak ikut berangkat ke medan perang. Lafal ayat ini menjadi khabarnya (mereka mencampur-baurkan pekerjaan yang baik) yaitu jihad yang telah mereka lakukan sebelum peristiwa ini atau pengakuan mereka atas dosa-dosa yang telah mereka lakukan; atau dosa-dosa yang lainnya (dengan pekerjaan lain yang buruk) yaitu ketidakikutan mereka dalam berjihad kali ini. (Mudah-mudahan Allah menerima tobat mereka. Sesungguhnya Allah Maha Pengampun lagi Maha Penyayang). Ayat ini diturunkan berkenaan dengan apa yang dilakukan oleh Abu Lubabah dan segolongan orang-orang lainnya. Mereka mengikatkan diri mereka di tiang-tiang mesjid, hal ini mereka lakukan ketika mereka mendengar firman Allah swt. yang diturunkan berkenaan dengan orang-orang yang tidak berangkat berjihad, sedangkan mereka tidak ikut berangkat. Lalu mereka bersumpah bahwa ikatan mereka itu tidak akan dibuka melainkan oleh Nabi saw. sendiri. Kemudian setelah ayat ini diturunkan Nabi saw. melepaskan ikatan mereka.\qt@no{102}}%
\qt@newcmd\qurantrans@id@mcccxxxviii{%
(Ambillah sedekah dari sebagian harta mereka, dengan sedekah itu kamu membersihkan dan menyucikan mereka) dari dosa-dosa mereka, maka Nabi saw. mengambil sepertiga harta mereka kemudian menyedekahkannya (dan berdoalah untuk mereka). (Sesungguhnya doa kamu itu menjadi ketenangan jiwa) rahmat (bagi mereka) menurut suatu pendapat yang dimaksud dengan sakanun ialah ketenangan batin lantaran tobat mereka diterima. (Dan Allah Maha Mendengar lagi Maha Mengetahui).\qt@no{103}}%
\qt@newcmd\qurantrans@id@mcccxxxix{%
(Tidakkah mereka mengetahui bahwasanya Allah menerima tobat dari hamba-hamba-Nya dan mengambil) maksudnya menerima (zakat dan bahwasanya Allah Maha Penerima tobat) hamba-hamba-Nya, yakni dengan menerima tobat mereka (lagi Maha Penyayang) kepada mereka. Kata tanya pada awal ayat ini bermakna taqrir; pengertian yang dimaksud ialah untuk menggugah mereka agar mau bertobat dan berzakat atau bersedekah.\qt@no{104}}%
\qt@newcmd\qurantrans@id@mcccxl{%
(Dan katakanlah) kepada mereka atau kepada manusia secara umum ("Bekerjalah kalian) sesuka hati kalian (maka Allah dan Rasul-Nya serta orang-orang mukmin akan melihat pekerjaan kalian itu dan kalian akan dikembalikan) melalui dibangkitkan dari kubur (kepada Yang Mengetahui alam gaib dan alam nyata) yakni Allah (lalu diberikan-Nya kepada kalian apa yang telah kalian kerjakan.") lalu Dia akan membalasnya kepada kalian.\qt@no{105}}%
\qt@newcmd\qurantrans@id@mcccxli{%
(Dan ada pula orang-orang lain) di antara orang-orang yang tidak berangkat ke medan perang (yang ditangguhkan) dapat dibaca murjauna dan dapat pula dibaca murja'uuna; artinya tobat mereka ditangguhkan (sampai ada keputusan Allah) tentang perihal mereka sesuai dengan kehendak-Nya (adakalanya Allah akan mengazab mereka) seumpamanya mereka dimatikan oleh Allah tanpa sempat bertobat (dan adakalanya Allah akan menerima tobat mereka. Dan Allah Maha Mengetahui) tentang makhluk-Nya (lagi Maha Bijaksana) di dalam melakukan apa yang harus Ia lakukan terhadap mereka. Yang dimaksud dengan mereka ialah ketiga orang yang kedatangannya kepada Nabi saw. telah disebutkan tadi, mereka adalah Murarah bin Rabi', Kaab bin Malik dan Hilal bin Umayyah. Mereka tidak berangkat ke medan perang hanya karena malas dan cenderung kepada hidup yang serba santai dan enak, bukannya karena munafik. Dan mereka tidak mengemukakan uzurnya (alasannya) kepada Nabi saw. seperti halnya yang dilakukan oleh orang-orang lain. Akhirnya perihal mereka ditangguhkan selama lima puluh hari, selama itu mereka hidup diasingkan oleh semuanya sehingga turunlah ayat yang menjelaskan diterimanya tobat mereka.\qt@no{106}}%
\qt@newcmd\qurantrans@id@mcccxlii{%
(Dan) di antara mereka yang munafik itu (ada orang-orang yang mendirikan mesjid) jumlah mereka ada dua belas orang, semuanya orang-orang munafik (untuk menimbulkan kemudaratan) kepada orang-orang mukmin di mesjid Quba (dan karena kekafiran) karena mereka membangun mesjid itu berdasarkan perintah dari Abu Amir seorang rahib, dimaksud supaya menjadi basis pangkalan baginya dan bagi orang-orang yang berpihak kepadanya. Sedang ia (Amir) pergi untuk mendatangkan bala tentara Kaisar Romawi guna memerangi Nabi saw. (dan untuk memecah belah antara orang-orang mukmin) yang biasa salat di mesjid Quba, diharapkan sebagian dari orang-orang mukmin melakukan salat di mesjid mereka (serta menjadi tempat pemantauan) yakni tempat untuk memantau (bagi orang-orang yang memerangi Allah dan Rasul-Nya sejak dahulu) sebelum mesjid dhirar ini dibangun; yang dimaksud adalah Abu Amir tadi dan para pembantunya. (Mereka sesungguhnya bersumpah, ``Tiada lain) (kami menghendaki) dari pembangunan mesjid ini (hanyalah) untuk pekerjaan (yang baik semata.") yaitu berlaku belas-kasihan terhadap orang-orang miskin dalam musim hujan dan musim panas, serta memberikan tempat persinggahan bagi kaum Muslimin. (Dan Allah menjadi saksi bahwa sesungguhnya mereka itu adalah pendusta) dalam sumpahnya. Mereka pernah meminta kepada Nabi saw. supaya melakukan salat di dalam mesjidnya itu, akan tetapi kemudian turunlah firman Allah berikut ini, yaitu:\qt@no{107}}%
\qt@newcmd\qurantrans@id@mcccxliii{%
(Janganlah kamu berdiri) melakukan salat (dalam mesjid itu selama-lamanya) kemudian Nabi saw. mengirimkan segolongan para sahabatnya guna merobohkan dan membakarnya. Kemudian mereka menjadikan bekas mesjid itu sebagai tempat pembuangan bangkai. (Sesungguhnya mesjid yang didirikan) dibangun dengan berlandaskan kepada pondasi (takwa, sejak hari pertama) yaitu mesjid yang didirikan oleh Nabi saw. sewaktu pertama kali beliau menginjakkan kakinya di tempat hijrahnya itu, yang dimaksud adalah mesjid Quba. Demikianlah menurut penjelasan yang telah dikemukakan oleh Imam Bukhari (adalah lebih berhak) daripada mesjid dhirar itu (kamu salat) untuk melakukan salat (di dalamnya. Di dalamnya ada orang-orang) kaum Ansar (yang ingin membersihkan diri. Dan Allah menyukai orang-orang yang bersih) artinya, Allah akan memberikan pahala kepada mereka. Lafal al-muththahhiriina asalnya ialah al-mutathahhiriina kemudian huruf ta diidgamkan kepada huruf tha yang asal, kemudian jadilah al-muththahhiriina. Ibnu Khuzaimah di dalam kitab sahihnya telah meriwayatkan sebuah hadis melalui Uwaimir bin Saidah, bahwasanya pada suatu hari Nabi saw. mendatangi mereka (para sahabat) di mesjid Quba. Kemudian beliau bersabda, ``Sesungguhnya Allah swt. telah memuji kalian dengan baik atas pembersihan diri kalian sehubungan dengan kisah mesjid kalian ini (Quba). Maka cara pembersihan apakah yang sedang kalian lakukan sekarang ini?" Mereka menjawab, ``Demi Allah, wahai Rasulullah, kami tidak mengetahui apa-apa melainkan kami mempunyai tetangga-tetangga Yahudi; mereka lalu membasuh dubur mereka setelah buang air besar, maka kami pun melakukan pembasuhan seperti apa yang mereka lakukan." Menurut hadis yang lain, yang telah diriwayatkan oleh Imam Bazzar disebutkan bahwa para sahabat mengatakan, ``Akan tetapi kami memakai batu terlebih dahulu, kemudian baru kami memakai air." Maka Nabi saw. menjawab, ``Itulah yang benar, maka peganglah cara ini oleh kalian."\qt@no{108}}%
\qt@newcmd\qurantrans@id@mcccxliv{%
(Maka apakah orang-orang yang mendirikan mesjidnya di atas dasar takwa) karena takut (kepada Allah dan) selalu mengharapkan (keridaan)-Nya itu (yang lebih baik, ataukah orang-orang yang mendirikan bangunannya di tepi) dapat dibaca jurufin dan dapat pula dibaca jurfin, artinya di pinggir (jurang) yakni hampir roboh (lalu bangunannya itu jatuh bersama-sama dengan dia) maksudnya bangunannya roboh berikut orang-orang yang membangunnya (ke dalam neraka Jahanam?) ungkapan ayat ini merupakan tamtsil/perumpamaan yang paling baik, yaitu menggambarkan pembangunan mesjid yang berdasarkan bukan kepada takwa, kemudian akibat-akibat yang akan dialaminya. Kata tanya pada permulaan ayat ini mengandung makna taqrir, artinya mesjid pertamalah yang baik seperti halnya mesjid Quba. Sedangkan gambaran yang kedua adalah perumpamaan mesjid dhirar. (Dan Allah tidak memberikan petunjuk kepada orang-orang yang lalim).\qt@no{109}}%
\qt@newcmd\qurantrans@id@mcccxlv{%
(Bangunan-bangunan yang mereka dirikan itu senantiasa menjadi pangkal keraguan) yakni keragu-raguan (dalam hati mereka kecuali bila telah hancur) tercabik-cabik (hati mereka itu) lantaran mereka mati. (Dan Allah Maha Mengetahui) tentang makhluk-Nya (lagi Maha Bijaksana) dalam perlakuan-Nya terhadap makhluk-Nya.\qt@no{110}}%
\qt@newcmd\qurantrans@id@mcccxlvi{%
(Sesungguhnya Allah telah membeli dari orang-orang mukmin diri dan harta mereka) lantaran mereka menginfakkannya di jalan ketaatan kepada-Nya, seperti untuk berjuang di jalan-Nya (dengan memberikan surga untuk mereka. Mereka berperang pada jalan Allah lalu mereka membunuh atau dibunuh) ayat ini merupakan kalimat baru yang menjadi penafsir bagi makna yang terkandung di dalam lafal fa yuqtaluuna wa yaqtuluuna, artinya sebagian dari mereka ada yang gugur dan sebagian yang lain meneruskan pertempurannya (sebagai janji yang benar) lafal wa`dan dan haqqan keduanya berbentuk mashdar yang dinashabkan fi`ilnya masing-masing yang tidak disebutkan (di dalam Taurat, Injil dan Alquran?) artinya tiada seorang pun yang lebih menepati janjinya selain dari Allah. (Maka bergembiralah) dalam ayat ini terkandung pengertian iltifat/perpindahan pembicaraan dari gaib kepada mukhathab/dari orang ketiga kepada orang kedua (dengan jual-beli yang telah kalian lakukan itu dan yang demikian itu) yaitu jual-beli itu (adalah kemenangan yang besar) yang dapat mengantarkan kepada tujuan yang paling didambakan.\qt@no{111}}%
\qt@newcmd\qurantrans@id@mcccxlvii{%
(Mereka itu adalah orang-orang yang bertobat) lafal at-taa'ibuuna dirafa'kan untuk tujuan memuji, yaitu dengan memperkirakan adanya mubtada sebelumnya; artinya mereka itu adalah orang-orang yang bertobat dari kemusyrikan dan kemunafikan (yang beribadah) orang-orang yang ikhlas karena Allah dalam beribadah (yang memuji) kepada Allah dalam semua kondisi (yang melawat) makna yang dimaksud adalah mereka selalu mengerjakan shaum/puasa (yang rukuk, yang sujud) artinya mereka adalah orang-orang yang salat (yang menyuruh berbuat makruf dan mencegah berbuat mungkar dan yang memelihara batasan-batasan Allah) yakni hukum-hukum-Nya dengan cara mengamalkannya. (Dan gembirakanlah orang-orang mukmin itu) dengan surga.\qt@no{112}}%
\qt@newcmd\qurantrans@id@mcccxlviii{%
Ayat ini diturunkan berkenaan dengan permohonan ampunan Nabi saw. buat pamannya, yaitu Abu Thalib dan sekaligus berkenaan pula dengan permohonan ampunan sebagian para sahabat terhadap kedua orang-orang tua mereka masing-masing yang musyrik. (Tiadalah sepatutnya bagi Nabi dan orang-orang yang beriman memintakan ampun kepada Allah bagi orang-orang musyrik walaupun orang-orang musyrik itu kaum kerabat)nya, yakni familinya sendiri (sesudah jelas bagi mereka bahwasanya orang-orang yang musyrik itu adalah penghuni-penghuni Jahim) yakni neraka, lantaran mereka mati dalam keadaan kafir.\qt@no{113}}%
\qt@newcmd\qurantrans@id@mcccxlix{%
(Dan permintaan ampun dari Ibrahim kepada Allah untuk bapaknya (pamannya) tidak lain hanya karena suatu janji yang telah diikrarkannya kepada bapaknya itu) melalui perkataan Nabi Ibrahim sendiri, seperti apa yang diungkapkan oleh firman-Nya, ``Aku akan mintakan ampun bagimu kepada Rabbku." (Q.S. Maryam 47) Nabi Ibrahim menjanjikan demikian dengan harapan semoga bapak (paman)nya itu mau masuk Islam. (Maka tatkala jelas bagi Ibrahim bahwa bapaknya/pamannya itu adalah musuh Allah) lantaran ia mati dalam keadaan kafir (maka Ibrahim berlepas diri daripadanya) kemudian Nabi Ibrahim berhenti dari memintakan ampunannya. (Sesungguhnya Ibrahim adalah seorang yang sangat lembut) banyak merendahkan diri dan berdoa kepada Allah (lagi penyantun) sangat sabar di dalam menahan derita.\qt@no{114}}%
\qt@newcmd\qurantrans@id@mcccl{%
(Dan Allah sekali-kali tidak akan menyesatkan suatu kaum, sesudah Allah memberi petunjuk kepada mereka) kepada Islam (hingga dijelaskan-Nya kepada mereka apa yang harus mereka jauhi) yakni amal-amal perbuatan mana saja yang harus mereka jauhi, akan tetapi ternyata mereka tidak menjauhinya, maka mereka layak menjadi orang-orang yang disesatkan. (Sesungguhnya Allah Maha Mengetahui segala sesuatu) antara lain ialah mengetahui siapa yang berhak untuk disesatkan dan siapa yang berhak untuk mendapat hidayah-Nya.\qt@no{115}}%
\qt@newcmd\qurantrans@id@mcccli{%
(Sesungguhnya kepunyaan Allahlah kerajaan langit dan bumi. Dia menghidupkan dan mematikan. Dan sekali-kali tiada bagi kalian) hai umat manusia (selain dari Allah) (yang melindungi) kalian daripada-Nya (dan yang memberikan pertolongan) yang dapat mencegah diri kalian dari kepastian Allah.\qt@no{116}}%
\qt@newcmd\qurantrans@id@mccclii{%
(Sesungguhnya Allah telah menerima tobat) artinya Dia menerima tobat untuk selamanya (Nabi, orang-orang Muhajirin dan orang-orang Ansar yang mengikuti Nabi dalam masa kesulitan) yakni sewaktu keadaan sedang sulit-sulitnya. Hal ini terjadi sewaktu perang Tabuk; sebiji buah kurma dimakan oleh dua orang, dan sepuluh orang pasukan saling bergantian menaiki satu hewan kendaraan di antara sesama mereka, dan panas pada saat itu terik sekali sehingga mereka meminum air yang ada dalam perut unta karena persediaan air habis (setelah hampir berpaling) dapat dibaca yaziighu atau taziighu, artinya cenderung (hati segolongan dari mereka) dari mengikuti Nabi kemudian mereka bermaksud untuk kembali dan tidak ikut berperang lantaran kesulitan yang sedang mereka alami pada saat itu (kemudian Allah menerima tobat mereka itu) dengan memberikan keteguhan dan kesabaran kepada mereka. (Sesungguhnya Allah Maha Pengasih lagi Maha Penyayang).\qt@no{117}}%
\qt@newcmd\qurantrans@id@mcccliii{%
(Dan) Allah menerima tobat pula (terhadap tiga orang yang ditangguhkan) penerimaan tobat mereka melalui bukti yang menunjukkan hal itu (sehingga apabila bumi terasa sempit oleh mereka padahal bumi itu luas) sekalipun kenyataannya bumi itu luas lantaran mereka tidak dapat menemukan tempat yang dapat mengganti hati mereka (dan jika hati mereka pun terasa sempit pula) yakni hati mereka menjadi sempit lantaran susah dan asing disebabkan tobat mereka ditangguhkan penerimaannya sehingga hati mereka tidak gembira dan selalu tidak tenteram (serta mereka menduga) dan merasa yakin (bahwasanya) dibaca dengan takhfif, yaitu an (tidak ada tempat lari dari siksa Allah melainkan kepada-Nya saja. Kemudian Allah menerima tobat mereka) Allah memberikan taufik dan kekuatan kepada mereka untuk bertobat (agar mereka tetap dalam tobatnya. Sesungguhnya Allahlah Yang Maha Penerima tobat lagi Maha Penyayang).\qt@no{118}}%
\qt@newcmd\qurantrans@id@mcccliv{%
(Hai orang-orang yang beriman, bertakwalah kalian kepada Allah) dengan meninggalkan perbuatan-perbuatan maksiat (dan hendaklah kalian bersama orang-orang yang benar) dalam hal iman dan menepati janji untuk itu kalian harus menetapi kebenaran.\qt@no{119}}%
\qt@newcmd\qurantrans@id@mccclv{%
(Tidaklah patut bagi penduduk Madinah dan orang-orang Arab badui yang berdiam di sekitarnya tidak turut menyertai Rasulullah) bilamana beliau pergi berperang (dan tidak patut pula bagi mereka lebih mencintai diri mereka daripada mencintai diri Rasul) yaitu dengan cara mendahulukan kepentingan apa yang menjadi keridaannya daripada kemaslahatan diri sendiri di dalam menghadapi saat-saat yang sulit. Ungkapan ayat ini merupakan nahi atau larangan, akan tetapi diungkapkan dalam bentuk kalimat khabar atau kalimat berita. (Yang demikian itu) yaitu larangan untuk tidak pergi bersama Rasulullah ke medan perang (ialah karena mereka) disebabkan (tidak ditimpa kehausan) rasa dahaga (kepayahan) keletihan (dan kelaparan) yakni rasa lapar (pada jalan Allah dan tidak pula menginjak suatu tempat) lafal mauthi'an adalah mashdar akan tetapi maknanya sama dengan lafal wath'an (yang membangkitkan amarah) artinya yang membuat marah (orang-orang kafir dan tidak menimpakan kepada musuh) Allah (sesuatu bencana) membunuh, menawan atau membegal musuh (melainkan dituliskan bagi mereka dengan yang demikian itu suatu amal saleh) dimaksud supaya mereka mau melaksanakan hal tersebut. (Sesungguhnya Allah tidak menyia-nyiakan pahala orang-orang yang berbuat baik) pahala mereka tidak akan disia-siakan-Nya, bahkan Dia akan memberi mereka pahala.\qt@no{120}}%
\qt@newcmd\qurantrans@id@mccclvi{%
(Dan mereka tiada menafkahkan) dalam rangka melaksanakan hal tersebut (suatu nafkah yang kecil) sekali pun berupa sebiji buah kurma (dan tidak pula yang besar dan tidak melintasi suatu lembah) dengan berjalan kaki (melainkan dituliskan bagi mereka) amal saleh pula (karena Allah memberi balasan kepada mereka yang lebih baik dari apa yang telah mereka kerjakan) sebagai pahalanya.\qt@no{121}}%
\qt@newcmd\qurantrans@id@mccclvii{%
Tatkala kaum Mukminin dicela oleh Allah bila tidak ikut ke medan perang kemudian Nabi saw. mengirimkan sariyahnya, akhirnya mereka berangkat ke medan perang semua tanpa ada seorang pun yang tinggal, maka turunlah firman-Nya berikut ini: (Tidak sepatutnya bagi orang-orang yang mukmin itu pergi) ke medan perang (semuanya. Mengapa tidak) (pergi dari tiap-tiap golongan) suatu kabilah (di antara mereka beberapa orang) beberapa golongan saja kemudian sisanya tetap tinggal di tempat (untuk memperdalam pengetahuan mereka) yakni tetap tinggal di tempat (mengenai agama dan untuk memberi peringatan kepada kaumnya apabila mereka telah kembali kepadanya) dari medan perang, yaitu dengan mengajarkan kepada mereka hukum-hukum agama yang telah dipelajarinya (supaya mereka itu dapat menjaga dirinya) dari siksaan Allah, yaitu dengan melaksanakan perintah-Nya dan menjauhi larangan-Nya. Sehubungan dengan ayat ini Ibnu Abbas r.a. memberikan penakwilannya bahwa ayat ini penerapannya hanya khusus untuk sariyah-sariyah, yakni bilamana pasukan itu dalam bentuk sariyah lantaran Nabi saw. tidak ikut. Sedangkan ayat sebelumnya yang juga melarang seseorang tetap tinggal di tempatnya dan tidak ikut berangkat ke medan perang, maka hal ini pengertiannya tertuju kepada bila Nabi saw. berangkat ke suatu ghazwah.\qt@no{122}}%
\qt@newcmd\qurantrans@id@mccclviii{%
(Hai orang-orang yang beriman perangilah orang-orang kafir yang ada di sekitar kalian itu) yakni mereka yang tinggal berdekatan dengan kalian, kemudian mereka yang dibilang tinggal berdekatan dengan kalian (dan hendaklah mereka menemui kekerasan daripada kalian) artinya berlaku keraslah kalian terhadap mereka (dan ketahuilah bahwasanya Allah beserta orang-orang yang bertakwa) bantuan dan pertolongan-Nya akan selalu menyertainya.\qt@no{123}}%
\qt@newcmd\qurantrans@id@mccclix{%
(Dan apabila diturunkan suatu surah) dari Alquran (maka di antara mereka) orang-orang munafik (ada yang berkata) kepada teman-temannya dengan nada mengejek ("Siapakah di antara kalian yang bertambah imannya dengan turunnya surah ini?") yakni kepercayaannya. Maka Allah swt. langsung berfirman menjawab perkataan mereka. (Adapun orang-orang yang beriman, maka surah ini menambah imannya) karena mereka benar-benar percaya kepadanya (sedangkan mereka merasa gembira) dengan turunnya surah ini.\qt@no{124}}%
\qt@newcmd\qurantrans@id@mccclx{%
(Dan adapun orang-orang yang di dalam hati mereka ada penyakit) lemah keyakinan (maka dengan surah ini bertambah kekafiran mereka di samping kekafirannya) kekafiran mereka makin bertambah karena pada mulanya mereka sudah kafir kepada surah itu (dan mereka mati dalam keadaan kafir).\qt@no{125}}%
\qt@newcmd\qurantrans@id@mccclxi{%
(Dan tidakkah mereka memperhatikan) bila dibaca yarauna, fa'ilnya adalah orang-orang munafik, dan bila dibaca tarauna, fa`ilnya adalah orang-orang mukmin (bahwa mereka diuji) dicoba (sekali atau dua kali setiap tahun) dengan musim paceklik dan wabah penyakit (kemudian mereka tidak juga bertobat) dari kemunafikannya (dan tidak pula mengambil pelajaran) artinya pelajaran buat dirinya.\qt@no{126}}%
\qt@newcmd\qurantrans@id@mccclxii{%
(Dan apabila diturunkan satu surah) yang di dalamnya menyebutkan tentang perihal mereka, kemudian surah tersebut dibacakan oleh Nabi saw. (sebagian mereka memandang kepada sebagian yang lain) dengan maksud untuk lari dari tempat itu seraya berkata ("Adakah seorang dari orang-orang Muslimin yang melihat kalian?") bilamana kalian pergi dari tempat ini; jika ternyata tidak ada seorang pun dari kalangan kaum Muslimin yang melihat mereka, maka mereka segera beranjak pergi dari tempat itu. Apabila ternyata ada seseorang dari kaum Muslimin yang melihat mereka, maka mereka tetap di tempatnya (sesudah itu mereka pun pergi) dengan membawa kekafirannya. (Allah telah memalingkan hati mereka) dari hidayah (disebabkan mereka adalah kaum yang tidak mengerti) akan kebenaran, lantaran mereka tidak mau menggunakan pikirannya guna merenungkan kebenaran itu.\qt@no{127}}%
\qt@newcmd\qurantrans@id@mccclxiii{%
(Sesungguhnya telah datang kepada kalian seorang rasul dari kaum kalian sendiri) dari kalangan kalian sendiri, yaitu Nabi Muhammad saw. (berat terasa) dirasa berat (olehnya apa yang kalian derita) yaitu penderitaan kalian, yang dimaksud ialah penderitaan dan musibah yang menimpa diri kalian (sangat menginginkan bagi kalian) hidayah dan keselamatan (lagi terhadap orang-orang mukmin amat belas kasihan) sangat belas kasihan (lagi penyayang) ia selalu mengharapkan kebaikan bagi mereka.\qt@no{128}}%
\qt@newcmd\qurantrans@id@mccclxiv{%
(Jika mereka berpaling) dari iman kepadamu (maka katakanlah, ``Cukuplah bagiku) maksudnya cukup untukku (Allah; tidak ada Tuhan selain Dia. Hanya kepada-Nya aku bertawakal) percaya dan bukan kepada selain-Nya (dan Dia adalah Rabb yang memiliki Arasy) yakni Al-Kursiy (yang agung.") Arasy disebutkan secara khusus karena ia makhluk yang paling besar. Imam Hakim di dalam kitab Al-Mustadrak meriwayatkan sebuah atsar yang bersumber dari Ubay bin Kaab, bahwasanya Ubay bin Kaab telah mengatakan, ``Ayat yang diturunkan paling akhir ialah firman-Nya, 'Sesungguhnya telah datang kepada kalian seorang rasul.'" (Q.S. At-Taubah 128-129). Kedua ayat akhir surah At-Taubah itulah ayat yang paling terakhir diturunkan.\qt@no{129}}%
\qt@newcmd\qurantrans@id@mccclxv{%
\basmalahid (Alif, laam, raa) hanya Allahlah yang mengetahui maksudnya. (Inilah) artinya ayat-ayat ini (ayat-ayat Alkitab) yakni Alquran. Diidhafatkan lafal ayaatul pada lafal Alkitab mengandung makna min, yakni bagian daripada Alquran (yang mengandung hikmah) yang padat akan hikmah-hikmah.\qt@no{1}}%
\qt@newcmd\qurantrans@id@mccclxvi{%
(Patutkah manusia) artinya penduduk Mekah. Istifham atau kata tanya di sini mengandung makna ingkar sedangkan jar dan majrurnya menjadi hal atau kata keterangan daripada firman selanjutnya (menjadi keheranan) lafal ini dibaca `ajaban menjadi khabar dari kaana, bila dibaca rafa` menjadi isim kaana. Menurut pendapat yang masyhur adalah sebagai khabar daripada kaana. (bahwa Kami mewahyukan) artinya pemberian wahyu Kami (kepada seorang lelaki di antara mereka) yaitu Nabi Muhammad saw. (yaitu) huruf an di sini menjadi penafsir dari lafal an auhainaa ("Berilah peringatan) peringatkanlah (kepada manusia) yakni orang-orang kafir akan adanya siksaan buat mereka (dan gembirakanlah orang-orang beriman bahwa) bahwasanya (mereka mempunyai kedudukan) pahala (yang tinggi di sisi Rabb mereka") dimaksud adalah pahala yang baik sebagai pembalasan dari amal-amal yang telah mereka lakukan. (Orang-orang kafir berkata, ``Sesungguhnya orang ini) yaitu Nabi Muhammad saw. (benar-benar adalah tukang sihir yang nyata.") jelas tukang sihir. Menurut suatu qiraat lafal lasaahirun dibaca lasihrun, sedangkan musyar ilaihnya adalah Alquran yang dianggap mereka merupakan sihir.\qt@no{2}}%
\qt@newcmd\qurantrans@id@mccclxvii{%
(Sesungguhnya Rabb kalian ialah Allah yang menciptakan langit dan bumi dalam enam hari) dari hari-hari dunia, artinya dalam masa yang perkiraannya sama dengan enam hari karena sesungguhnya pada masa itu belum ada matahari dan bulan. Akan tetapi seandainya Allah berkehendak, maka Dia dapat menciptakannya dalam sekejap mata. Allah swt, tidak memakai cara tersebut dimaksud untuk memberikan pelajaran kepada makhluk-Nya tentang ketekunan dan kesabaran di dalam bertindak (kemudian Dia bersemayam di atas Arsy) bersemayamnya Allah disesuaikan dengan keagungan sifat-Nya (untuk mengatur segala urusan) di antara makhluk-makhluk-Nya (Tiada seorang pun) huruf min merupakan shilah atau penghubung (yang dapat memberikan syafaat) kepada seseorang (kecuali sesudah ada keizinan-Nya) ayat ini merupakan sanggahan terhadap perkataan orang-orang kafir yang menyatakan bahwa berhala-berhala mereka dapat memberikan syafaat kepada diri mereka. (Zat yang demikian itulah) yaitu yang menciptakan dan yang mengatur (Allah, Rabb kalian, maka sembahlah Dia) artinya tauhidkanlah Dia. (Maka apakah kalian tidak mengambil pelajaran?) lafal tadzakkaruuna asalnya tatadzakkaruuna, kemudian huruf ta yang kedua diidgamkan ke dalam huruf dzal asal kalimat, maka jadilah tadzakkaruuna.\qt@no{3}}%
\qt@newcmd\qurantrans@id@mccclxviii{%
(Hanya kepada-Nyalah) yaitu Allah swt. (kalian semuanya akan kembali; sebagai janji yang benar dari Allah) lafal wa'dan dan lafal haqqan keduanya merupakan mashdar yang dinashabkan oleh fi'ilnya masing-masing yang keberadaannya diperkirakan. (Sesungguhnya Allah) huruf hamzah inna dibaca kasrah karena menjadi isti'naf, sedangkan jika dibaca fatah maka memakai huruf lam yang keberadaannya diperkirakan sebelumnya (menciptakan makhluk pada permulaan) artinya Dia mulai menciptakan makhluk dengan mengadakan mereka (kemudian menghidupkannya kembali) pada hari berbangkit (agar Dia memberi pembalasan) pahala (kepada orang-orang yang beriman dan yang mengerjakan amal saleh dengan adil. Dan untuk orang-orang kafir disediakan minuman air yang panas) artinya air yang panasnya luar biasa (dan azab yang pedih) sangat menyakitkan (disebabkan kekafiran mereka) sebagai pembalasan atas kekafirannya.\qt@no{4}}%
\qt@newcmd\qurantrans@id@mccclxix{%
(Dialah yang menjadikan matahari bersinar) mempunyai sinar (dan bulan bercahaya dan ditetapkan-Nya bagi bulan) dalam perjalanannya (manzilah-manzilah) selama dua puluh delapan malam untuk setiap bulan, setiap malam daripada dua puluh delapan malam itu memperoleh suatu manzilah, kemudian tidak tampak selama dua malam, jika jumlah hari bulan yang bersangkutan ada tiga puluh hari. Atau tidak tampak selama satu malam jika ternyata jumlah hari bulan yang bersangkutan ada dua puluh sembilan hari (supaya kalian mengetahui) melalui hal tersebut (bilangan tahun dan perhitungan waktu, Allah tidak menciptakan yang demikian itu) hal-hal yang telah disebutkan itu (melainkan dengan hak) bukannya main-main, Maha Suci Allah dari perbuatan tersebut (Dia menjelaskan) dapat dibaca yufashshilu dan nufashshilu, artinya Dia menerangkan atau Kami menerangkan (tanda-tanda kepada orang-orang yang mengetahui) yakni orang-orang yang mau berpikir.\qt@no{5}}%
\qt@newcmd\qurantrans@id@mccclxx{%
(Sesungguhnya pada pertukaran malam dan siang itu) silih bergantinya malam dan siang hari kemudian panjang dan pendeknya malam dan siang hari (dan pada yang diciptakan Allah di langit) yakni para malaikat, matahari, bulan dan bintang-bintang serta lain sebagainya (Dan) di (bumi) berupa margasatwa, gunung-gunung, lautan, sungai-sungai, pohon-pohon dan lain sebagainya (benar-benar terdapat tanda-tanda) yang menunjukkan kepada kekuasaan-Nya (bagi orang-orang yang bertakwa) kepada-Nya kemudian mereka beriman. Allah secara khusus menyebutkan orang-orang yang bertakwa karena sesungguhnya merekalah yang dapat memanfaatkan keberadaan tanda-tanda tersebut.\qt@no{6}}%
\qt@newcmd\qurantrans@id@mccclxxi{%
(Sesungguhnya orang-orang yang tidak mengharapkan/tidak percaya akan pertemuan dengan Kami) pada hari berbangkit nanti (dan mereka merasa puas dengan kehidupan dunia) sebagai ganti daripada kehidupan akhirat karena mereka tidak mempercayai adanya hari akhirat itu (serta merasa tenteram dengan kehidupan itu) merasa tenang dengan kehidupan dunia (dan orang-orang yang terhadap ayat-ayat Kami) bukti-bukti yang menunjukkan kepada keesaan Kami (mereka melalaikan) mereka sama sekali tidak mau memikirkannya.\qt@no{7}}%
\qt@newcmd\qurantrans@id@mccclxxii{%
(Mereka itu tempatnya ialah neraka disebabkan apa yang selalu mereka kerjakan) berupa kemusyrikan dan perbuatan-perbuatan maksiat.\qt@no{8}}%
\qt@newcmd\qurantrans@id@mccclxxiii{%
(Sesungguhnya orang-orang yang beriman dan mengerjakan amal-amal saleh, mereka diberi petunjuk) diberi bimbingan (oleh Rabb mereka karena keimanannya) kepada-Nya; kelak pada hari kiamat Allah swt. akan menjadikan bagi mereka cahaya dengan cahaya itu mereka mendapat petunjuk (di bawah mereka mengalir sungai-sungai di dalam surga yang penuh kenikmatan).\qt@no{9}}%
\qt@newcmd\qurantrans@id@mccclxxiv{%
(Doa mereka di dalamnya) sewaktu mereka meminta apa yang mereka inginkan di dalam surga hanya tinggal mengatakan (Subhaanakallaahumma) artinya Maha Suci Engkau ya Allah. Bilamana mereka telah memintanya maka mereka menemukan apa yang mereka inginkan telah berada di hadapan mereka (dan salam penghormatan mereka) di antara sesama mereka (di dalam surga ialah salam. Dan penutup doa mereka ialah) huruf an di sini adalah kata penafsir (alhamdulillaahi rabbil aalamiin) segala puji bagi Allah Rabb alam semesta. Ayat ini diturunkan sewaktu orang-orang musyrik meminta disegerakan turunnya azab.\qt@no{10}}%
\qt@newcmd\qurantrans@id@mccclxxv{%
(Dan kalau sekiranya Allah menyegerakan kejahatan bagi manusia seperti permintaan mereka untuk menyegerakan) artinya sama seperti mereka meminta mendapatkan dengan segera (kebaikan, pastilah diakhiri) boleh dibaca laqudhiya atau laqadha (umur mereka) lafal ajaluhum dapat dibaca rafa` yakni menjadi ajaluhum dan dapat pula dibaca nashab hingga menjadi ajalahum; seumpamanya Allah membinasakan mereka dengan segera akan tetapi ternyata Allah menangguhkan (Maka Kami biarkan) Kami tinggalkan (orang-orang yang tidak mengharapkan pertemuan dengan Kami bergelimang di dalam kesesatan mereka) mereka hidup diselimuti oleh keraguan yang membingungkan.\qt@no{11}}%
\qt@newcmd\qurantrans@id@mccclxxvi{%
(Dan apabila manusia ditimpa) yang dimaksud adalah orang kafir (bahaya) berupa penyakit dan kefakiran (dia berdoa kepada Kami dalam keadaan berbaring) membaringkan diri (atau duduk, atau berdiri) artinya dalam semua keadaan (tetapi setelah Kami hilangkan bahaya itu daripadanya dia kembali) kepada kekafirannya (seolah-olah) lafal ka-an berasal dari ka-anna yang ditakhfifkan sedangkan isimnya tidak disebutkan. Lengkapnya ka-annahu, artinya seolah-olah dia (tidak pernah berdoa kepada Kami untuk menghilangkan bahaya yang telah menimpanya. Begitulah) sifat orang kafir, yaitu berdoa di kala tertimpa bahaya dan berpaling di kala hidup sejahtera (orang-orang yang melampaui batas itu memandang baik) yang dimaksud adalah orang-orang musyrik (apa yang selalu mereka kerjakan).\qt@no{12}}%
\qt@newcmd\qurantrans@id@mccclxxvii{%
(Dan sesungguhnya Kami telah membinasakan umat-umat) generasi-generasi (yang sebelum kalian) hai penduduk Mekah (ketika mereka berbuat kelaliman) yaitu dengan melakukan kemusyrikan (padahal) sungguh (telah datang kepada mereka rasul-rasul mereka dengan membawa keterangan-keterangan yang nyata) bukti-bukti yang menunjukkan kebenaran risalah mereka (tetapi mereka sekali-kali tidak hendak beriman) kalimat ayat ini di'athafkan pada lafal lammaa zhalamuu. (Demikianlah) seperti yang telah Kami binasakan mereka (Kami memberi pembalasan kepada orang-orang yang berbuat dosa) yaitu orang-orang kafir.\qt@no{13}}%
\qt@newcmd\qurantrans@id@mccclxxviii{%
(Kemudian Kami jadikan kalian) hai penduduk Mekah (pengganti-pengganti) lafal khalaaif adalah bentuk jamak dari lafal khaliifah (di muka bumi sesudah mereka supaya Kami memperhatikan bagaimana kalian berbuat) di muka bumi; apakah kalian mau mengambil pelajaran dari umat-umat terdahulu itu sehingga kalian mau percaya kepada rasul-rasul Kami.\qt@no{14}}%
\qt@newcmd\qurantrans@id@mccclxxix{%
(Dan apabila dibacakan kepada mereka ayat-ayat Kami) yakni Alquran (yang nyata) yang jelas; lafal bayyinaatin kedudukannya menjadi hal atau kata keterangan keadaan (orang-orang yang tidak mengharapkan pertemuan dengan Kami berkata) mereka adalah orang-orang yang tidak takut akan adanya hari pembalasan ("Datangkanlah Alquran yang lain dari ini) yang isinya tidak mengandung celaan kepada tuhan-tuhan kami (atau gantilah dia.") dengan buatanmu sendiri (Katakanlah,) kepada mereka ("Tidaklah pantas) tidak layak (bagiku menggantinya dari pihak) berdasarkan kemauan (diriku sendiri. Aku tidak) tiada lain (hanya mengikuti apa yang diwahyukan kepadaku. Sesungguhnya aku takut jika mendurhakai Rabbku) oleh sebab menggantikan Alquran (kepada siksa hari yang besar.") yaitu hari kiamat.\qt@no{15}}%
\qt@newcmd\qurantrans@id@mccclxxx{%
(Katakanlah, ``Jika Allah menghendaki, niscaya aku tidak membacakannya kepada kalian dan aku tidak pula memberitahukan kepada kalian) mengajarkan kepada kalian (mengenainya) huruf laa di sini bermakna nafi atau meniadakan, kemudian diathafkan kepada nafi yang sebelumnya. Menurut qiraat yang lain dianggap sebagai lam yang menjadi jawab daripada huruf lau, dengan demikian berarti niscaya aku akan mengajarkannya kepada kalian dengan bahasa yang bukan bahasaku (Sesungguhnya aku telah tinggal) diam (bersama dengan kalian beberapa lama) yaitu empat puluh tahun (sebelumnya.") selama itu aku belum pernah menceritakan sesuatu kepada kalian (Maka apakah kalian tidak memikirkannya?) bahwasanya Alquran itu bukanlah buatanku sendiri.\qt@no{16}}%
\qt@newcmd\qurantrans@id@mccclxxxi{%
(Maka siapakah) artinya, tiada seorang pun (yang lebih lalim daripada orang yang mengada-adakan kedustaan terhadap Allah) yaitu dengan melakukan kemusyrikan terhadap Allah (atau mendustakan ayat-ayat-Nya?) yakni Alquran. (Sesungguhnya) pada kenyataannya (tiadalah beruntung) tiadalah berbahagia (orang-orang yang berbuat dosa) yaitu orang-orang musyrik.\qt@no{17}}%
\qt@newcmd\qurantrans@id@mccclxxxii{%
(Dan mereka menyembah selain daripada Allah) (apa yang tidak dapat mendatangkan kemudaratan) jika mereka tidak menyembahnya (dan tidak pula kemanfaatan) jika mereka menyembahnya, yang dimaksud adalah berhala-berhala yang mereka sembah itu (dan mereka berkata,) tentang berhala-berhala itu ("Mereka itu adalah pemberi syafaat kepada kami di sisi Allah." Katakanlah) kepada mereka ("Apakah kalian mengabarkan kepada Allah) menceritakan kepada-Nya (apa yang tidak diketahui-Nya di langit dan tidak pula di bumi?") Istifham atau kata tanya di sini mengandung makna ingkar, karena seandainya Dia mempunyai sekutu niscaya Dia akan mengetahui sekutunya itu karena sesungguhnya tiada sesuatu pun yang samar bagi-Nya. (Maha Suci Allah) dari hal-hal yang tidak layak bagi-Nya (dan Maha Tinggi daripada apa yang mereka persekutukan itu) bersama Allah.\qt@no{18}}%
\qt@newcmd\qurantrans@id@mccclxxxiii{%
(Manusia dahulunya hanyalah satu umat) satu agama yaitu agama Islam, sejak dari zaman Nabi Adam sampai dengan zaman Nabi Nuh. Menurut pendapat yang lain dikatakan mulai dari zaman Nabi Ibrahim sampai dengan zamannya Amr bin Luhay (kemudian mereka berselisih) disebabkan sebagian daripada mereka tetap iman sedangkan sebagian yang lainnya kafir. (Kalau tidaklah karena suatu ketetapan yang telah ada dari Rabbmu dahulu) dengan menangguhkan pembalasan hingga hari kiamat (pastilah diberi keputusan di antara mereka) yaitu di antara manusia di dunia (tentang apa yang mereka perselisihkan itu) dalam masalah agama, yaitu dengan mengazab orang-orang kafir.\qt@no{19}}%
\qt@newcmd\qurantrans@id@mccclxxxiv{%
(Dan mereka berkata,) yakni penduduk Mekah ("Mengapa tidak) kenapa tidak (diturunkan kepadanya) dimaksud kepada Nabi Muhammad saw. (suatu keterangan dari Rabbnya?") sebagaimana yang telah diberikan kepada para nabi lainnya, seperti mukjizat unta, mukjizat tongkat dan mukjizat tangan (Maka katakanlah,) kepada mereka ("Sesungguhnya yang gaib itu) hal-hal yang gaib dari mata hamba-hamba Allah (kepunyaan Allah) antara lain ialah mukjizat-mukjizat, maka mukjizat-mukjizat itu tidak ada yang dapat mendatangkannya melainkan hanya seizin Allah. Sesungguhnya tugasku hanyalah menyampaikan (sebab itu tunggu sajalah oleh kalian) datangnya azab jika kalian tidak mau beriman (sesungguhnya aku bersama kalian termasuk orang-orang yang menunggu.")\qt@no{20}}%
\qt@newcmd\qurantrans@id@mccclxxxv{%
(Dan apabila Kami merasakan kepada manusia) kepada orang-orang kafir Mekah (suatu rahmat) berupa hujan dan kesuburan (sesudah datangnya bahaya) kesengsaraan dan kekeringan (menimpa mereka, tiba-tiba mereka mempunyai tipu daya dalam menentang tanda-tanda kekuasaan Kami) dengan memperolok-olokkannya dan mendustakannya. (Katakanlah,) kepada mereka ("Allah lebih cepat dalam membuat tipu daya") sebagai pembalasan dari-Nya. (Sesungguhnya utusan-utusan Kami) yaitu para malaikat (menuliskan tipu daya kalian) lafal tamkuruuna dapat dibaca dengan memakai huruf ta sehingga menjadi tamkuruuna, dapat pula dibaca dengan huruf ya sehingga bacaannya menjadi yamkuruuna.\qt@no{21}}%
\qt@newcmd\qurantrans@id@mccclxxxvi{%
(Dialah Tuhan yang menjadikan kalian dapat berjalan) menurut suatu qiraat yansyurukum bukannya yusayyirukum (di daratan, berlayar di laut. Sehingga apabila kalian berada di dalam bahtera) di dalam perahu-perahu (dan meluncurlah bahtera itu membawa orang-orang yang di dalamnya) di dalam lafal ini terkandung pengertian iltifat dari mukhathab menjadi ghaib (dengan tiupan angin yang baik) angin yang lembut (dan mereka bergembira karenanya, datanglah angin badai) angin yang kencang tiupannya dan dapat menghancurkan segala sesuatu yang dilandanya (dan gelombang dari segenap penjuru menimpanya, dan mereka yakin bahwa mereka telah dikepung bahaya) mereka pasti binasa (maka mereka berdoa kepada Allah dengan mengikhlaskan ketaatan kepada-Nya semata-mata) yakni berseru ("Sesungguhnya jika) huruf lam di sini bermakna qasam atau sumpah (Engkau menyelamatkan kami dari bahaya ini) dari malapetaka ini (pastilah kami termasuk orang-orang yang bersyukur.") yaitu akan menjadi orang-orang yang mentauhidkan Allah.\qt@no{22}}%
\qt@newcmd\qurantrans@id@mccclxxxvii{%
(Maha setelah Allah menyelamatkan mereka, tiba-tiba mereka membuat kelaliman di muka bumi tanpa alasan yang benar) mereka melakukan kemusyrikan. (Hai manusia, sesungguhnya perbuatan kelewat batas kalian) perbuatan kelaliman kalian (akan menimpa diri kalian sendiri) karena sesungguhnya yang menanggung dosanya adalah diri kalian sendiri (hal itu hanyalah kenikmatan duniawi) kalian bersenang-senang dengannya dalam waktu yang sedikit. (Kemudian kepada Kamilah kembali kalian) sesudah mati (lalu Kami kabarkan kepada kalian apa yang telah kalian kerjakan) maka Kami membalas kalian berdasarkannya. Menurut suatu qiraat lafal mataa'un dibaca nashab sehingga menjadi mataa'an, artinya kalian bersenang-senang.\qt@no{23}}%
\qt@newcmd\qurantrans@id@mccclxxxviii{%
(Sesungguhnya perumpamaan) gambaran (kehidupan duniawi itu adalah seperti air) hujan (yang Kami turunkan dari langit lalu tumbuhlah berkat air itu dengan suburnya) oleh sebab air itu (tanaman-tanaman bumi) sehingga sebagian di antaranya tampak bersatu dengan sebagian yang lain karena rimbunnya (di antaranya ada yang dimakan manusia) berupa biji jawawut, biji gandum dan lain sebagainya (dan binatang ternak) yaitu berupa rerumputan dan dedaunan. (Hingga apabila bumi itu telah sempurna keindahannya) menampakkan keindahannya berkat tumbuh-tumbuhannya (dan memakai pula perhiasannya) karena bunga-bungaannya. Asal kata wazzayyanat adalah tazayyanat, kemudian huruf ta diganti dengan huruf za, yang selanjutnya huruf za yang pengganti ini diidghamkan atau dimasukkan ke dalam huruf za asal, sehingga jadilah izzayyanat (dan pemilik-pemiliknya mengira bahwa mereka pasti menguasainya) mereka merasa pasti akan dapat memetik hasilnya (tiba-tiba datanglah kepadanya perkara Kami) kepastian atau azab Kami (di waktu malam hari atau siang, lalu Kami jadikan ia) yakni tanam-tanamannya (laksana tanam-tanaman yang sudah disabit) sudah dipanen dengan memakai sabit (seakan-akan) lafal ka-an adalah mukhaffafah dari lafal ka-anna, artinya seakan-akan ia (belum pernah tumbuh) belum pernah berujud (kemarin. Demikianlah Kami menjelaskan) Kami terangkan (tanda-tanda kekuasaan Kami kepada orang-orang yang berpikir).\qt@no{24}}%
\qt@newcmd\qurantrans@id@mccclxxxix{%
(Allah menyeru ke darussalam) kepada jalan keselamatan, yaitu surga; Dia menyeru manusia pada keimanan (dan menunjuki orang yang dikehendaki-Nya) untuk mendapat petunjuk (kepada jalan yang lurus) yakni agama Islam.\qt@no{25}}%
\qt@newcmd\qurantrans@id@mcccxc{%
(Bagi orang-orang yang berbuat baik) dengan keimanannya (ada pahala yang terbaik) yaitu surga (dan tambahannya) yaitu dapat melihat Allah swt. sebagaimana yang telah diterangkan di dalam hadis sahih Muslim. (Dan tidak pernah layu) tidak pernah tertutup (wajah mereka oleh kekelaman) kesusahan yang kelam (dan tidak pula oleh kehinaan) kesedihan. (Mereka itulah penghuni surga, mereka kekal di dalamnya.)\qt@no{26}}%
\qt@newcmd\qurantrans@id@mcccxci{%
(Dan orang-orang) lafal ayat ini diathafkan kepada lafal alladziina ahsanuu yang ada pada ayat sebelumnya; artinya dan bagi orang-orang (yang mengerjakan keburukan) orang-orang yang mengerjakan kemusyrikan (mendapat balasan yang setimpal dan mereka ditutupi oleh kehinaan. Tidak ada bagi mereka, dari azab Allah) huruf min pada ayat ini adalah huruf zaidah atau tambahan (seorang pelindung pun) yang dapat mencegahnya (seakan-akan tertutupi) diselimuti (muka mereka oleh kepingan-kepingan) dapat dibaca qitha`an dan dapat pula dibaca qith`an (malam yang gelap-gulita. Mereka itulah penghuni neraka; mereka kekal di dalamnya).\qt@no{27}}%
\qt@newcmd\qurantrans@id@mcccxcii{%
(Dan) ingatlah (suatu hari, ketika itu Kami mengumpulkan mereka) yakni semua makhluk (semuanya, kemudian Kami berkata kepada orang-orang yang mempersekutukan Tuhan, ``Tetaplah pada tempat kalian) lafal makaanakum dinashabkan oleh ilzamuu yang keberadaannya diperkirakan pada sebelumnya (kalian semuanya) lafal ini bersifat mengukuhkan dhamir mustatar yang terkandung di dalam fi'il yang keberadaannya diperkirakan tadi, kemudian diathafkan kepadanya (bersama dengan sekutu-sekutu kalian) yakni berhala-berhala sesembahan kalian. (Lalu Kami pisahkan) Kami bedakan (antara mereka") dan orang-orang yang beriman, sebagaimana yang telah disebutkan dalam ayat: (Dan dikatakan kepada orang-orang kafir), 'Berpisahlah kalian (dari orang-orang mukmin) pada hari ini, hai orang-orang yang berbuat jahat. (Yasin 59). (Dan berkatalah) kepada mereka (sekutu-sekutu mereka, ``Kalian sekali-kali tidak pernah menyembah kami) huruf maa bermakna nafi, kemudian maf'ul didahulukan demi untuk fashilah.\qt@no{28}}%
\qt@newcmd\qurantrans@id@mcccxciii{%
(Dan cukuplah Allah menjadi saksi antara kami dengan kalian, sesungguhnya) huruf in adalah mukhaffafah dari inna (kami tidak tahu-menahu tentang penyembahan kalian kepada kami.")\qt@no{29}}%
\qt@newcmd\qurantrans@id@mcccxciv{%
(Di tempat itu) yakni pada hari itu (akan merasakan pembalasan) lafal tabluu berasal dari mashdar al-balwaa. Akan tetapi menurut qiraat lainnya dibaca tatluu berasal dari mashdar tilaawah; artinya dibacakan (tiap-tiap diri dari apa yang telah dikerjakannya dahulu) amal-amal perbuatan yang telah mereka kerjakan di dunia (dan mereka dikembalikan kepada Allah Pelindung mereka yang sebenarnya) pelindung yang hak dan yang selama-lamanya (dan lenyaplah) hilanglah (dari mereka apa yang mereka ada-adakan) terhadap Allah swt. yaitu berupa sekutu-sekutu yang mereka sembah itu.\qt@no{30}}%
\qt@newcmd\qurantrans@id@mcccxcv{%
(Katakanlah,) kepada mereka ("Siapakah yang memberi rezeki kepada kalian dari langit) yaitu melalui hujan (dan bumi) yaitu melalui tumbuh-tumbuhan (atau siapakah yang kuasa menciptakan pendengaran) lafal as-sam`u di sini bermakna al-asma`; artinya yang menciptakan pendengaran (dan penglihatan dan siapakah yang mengeluarkan yang hidup dari yang mati dan mengeluarkan yang mati dari yang hidup dan siapakah yang mengatur segala urusan?") di antara makhluk semuanya. (Maka mereka katakan,) bahwa Dia ("Allah." Maka katakanlah,) kepada mereka ("Mengapa kalian tidak bertakwa.") kepada-Nya, oleh sebab itu berimanlah kalian.\qt@no{31}}%
\qt@newcmd\qurantrans@id@mcccxcvi{%
(Maka yang demikian itu) Zat Yang menciptakan segala sesuatu itu (adalah Allah, Rabb kalian yang sebenarnya) yang tetap dan wajib kalian sembah (maka tidak ada sesudah kebenaran itu melainkan kesesatan) Istifham atau kata tanya di sini bermakna menetapkan; artinya tidak ada sesudah kebenaran itu melainkan hanya kesesatan belaka. Barang siapa yang menyimpang dari kebenaran yaitu menyembah selain kepada Allah berarti ia terjerumus ke dalam kesesatan (Maka bagaimanakah) mengapa (kalian dipalingkan?) dari keimanan padahal bukti-bukti kebenaran telah cukup ada.\qt@no{32}}%
\qt@newcmd\qurantrans@id@mcccxcvii{%
(Demikianlah) sebagaimana mereka berpaling daripada iman (telah tetap hukuman Rabbmu terhadap orang-orang yang fasik) yakni orang-orang kafir, seperti yang diungkapkan oleh firman Allah yang lain, yaitu: ``Benar-benar Aku akan mengisi neraka Jahanam..." (Q.S. Al-A`raf 18, Hud 119, As-Sajdah 32, Shad 85), atau hukuman Allah itu disebabkan (karena mereka tidak beriman.)\qt@no{33}}%
\qt@newcmd\qurantrans@id@mcccxcviii{%
(Katakanlah, ``Apakah di antara sekutu-sekutu kalian ada yang dapat memulai penciptaan makhluk, kemudian mengulanginya atau menghidupkannya kembali?" Katakanlah, ``Allahlah yang memulai penciptaan makhluk kemudian mengulanginya atau menghidupkannya kembali; maka bagaimanakah kalian dipalingkan?") dari menyembah Allah swt. padahal bukti-bukti yang menunjukkan Allah disembah sudah ada.\qt@no{34}}%
\qt@newcmd\qurantrans@id@mcccxcix{%
(Katakanlah, ``Apakah di antara sekutu-sekutu kalian ada yang dapat menunjuki kepada kebenaran?") dengan menegakkan hujah-hujah dan memberikan petunjuk (Katakanlah, ``Allahlah yang menunjuki kepada kebenaran." Maka apakah Zat yang menunjuki kepada kebenaran itu) yang dimaksud adalah Allah (lebih berhak diikuti ataukah orang yang tidak dapat memberi petunjuk) lafal yahiddiy asalnya yahtadii; artinya mendapat petunjuk (kecuali bila diberi petunjuk?) lebih berhak untuk diikuti? Kata tanya di sini mengandung makna mengukuhkan dan sekaligus sebagai celaan, makna yang dimaksud ialah bahwa yang pertamalah yang lebih berhak untuk diikuti (Mengapa kalian berbuat demikian? Bagaimanakah kalian mengambil keputusan) dengan keputusan yang rusak ini, yaitu mengikuti orang-orang yang tidak berhak untuk diikuti.\qt@no{35}}%
\qt@newcmd\qurantrans@id@mcd{%
(Dan kebanyakan mereka tidak mengikuti) di dalam penyembahan mereka terhadap berhala-berhala (kecuali persangkaan saja) dalam hal ini mereka hanya menirukan apa yang telah diperbuat oleh nenek-moyang mereka (Sesungguhnya prasangka itu tidak sedikit pun berguna untuk mencapai kebenaran) yang membutuhkan ilmu pengetahuan tentangnya (Sesungguhnya Allah Maha Mengetahui apa yang mereka kerjakan) oleh sebab itu maka Dia membalas semua amal perbuatan yang telah mereka kerjakan itu.\qt@no{36}}%
\qt@newcmd\qurantrans@id@mcdi{%
(Tidaklah mungkin Alquran ini dibuat) artinya dibuat-buat (oleh selain Allah) hanya Dialah yang membuatnya bukan selainnya (akan tetapi) Alquran itu diturunkan (membenarkan apa-apa yang sebelumnya) yaitu berupa kitab-kitab sebelumnya (dan menjelaskan hukum-hukum yang telah ditetapkan-Nya) artinya Alquran itu menjelaskan hukum-hukum yang telah ditentukan oleh Allah dan masalah-masalah lainnya (tidak ada keraguan) tidak ada syakwasangka lagi (di dalamnya, diturunkan dari Rabb semesta alam) lafal min rabbil `aalamiina berkaitan dengan lafal tashdiiqan, atau berkaitan dengan lafal unzila yang tidak disebutkan. Lafal tashdiiqan dan lafal tafshiilan dapat pula dibaca rafa' sehingga menjadi tashdiiqun dan tafshiilun akan tetapi berdasarkan perkiraan adanya lafal huwa sebelumnya.\qt@no{37}}%
\qt@newcmd\qurantrans@id@mcdii{%
(Atau) patutkah (mereka mengatakan, ``Muhammad membuat-buatnya.") yakni Nabi Muhammad saw. telah membuatnya sendiri. (Katakanlah, ``Kalau benar yang kalian katakan itu, maka cobalah datangkan sebuah surah seumpamanya) dalam hal kefasihan dan keparamasastraannya yang kalian buat sendiri, bukankah kalian itu adalah orang-orang Arab yang fasih dalam berbahasa sama denganku (dan panggillah) untuk membantu dalam hal ini (siapa-siapa yang dapat kalian panggil selain Allah) selain daripada Allah (jika kalian orang-orang yang benar") bahwasanya Alquran itu adalah buatan belaka, niscaya kalian tidak akan mampu melakukannya. Selanjutnya Allah berfirman:\qt@no{38}}%
\qt@newcmd\qurantrans@id@mcdiii{%
(Yang sebenarnya, mereka mendustakan apa yang mereka belum mengetahuinya dengan sempurna) subjek yang dimaksud adalah Alquran; mereka sama sekali tidak mau memikirkan tentangnya (dan belum pernah) tidak pernah (datang kepada mereka penjelasannya) akibat dari apa yang terkandung di dalamnya, yaitu berupa ancaman. (Demikianlah) yakni kedustaan itu (orang-orang yang sebelum mereka telah mendustakan) rasul-rasul mereka (Maka perhatikanlah bagaimana akibat orang-orang yang lalim itu) yaitu mereka yang mendustakan para rasul, makna yang dimaksud ialah kebinasaan yang telah menimpa mereka, demikian pula Kami akan membinasakan mereka yang mendustakannya.\qt@no{39}}%
\qt@newcmd\qurantrans@id@mcdiv{%
(Di antara mereka) penduduk Mekah (ada arang-orang yang beriman kepada Alquran) hal ini diketahui oleh Allah (dan di antara mereka ada pula orang-orang yang tidak beriman kepadanya) untuk selama-lamanya. (Rabbmu lebih mengetahui tentang orang-orang yang berbuat kerusakan) hal ini merupakan ancaman yang ditujukan kepada mereka yang tidak beriman kepadanya,\qt@no{40}}%
\qt@newcmd\qurantrans@id@mcdv{%
(Jika mereka mendustakan kamu, maka katakanlah,) kepada mereka ("Bagiku pekerjaanku dan bagi kalian pekerjaan kalian) artinya bagi masing-masing pihak menanggung akibat perbuatannya sendiri. Kalian berlepas diri terhadap apa yang aku kerjakan dan aku berlepas diri terhadap apa yang kalian kerjakan.") akan tetapi ayat itu dinasakh oleh ayatus-saif atau ayat yang menganjurkan memerangi mereka.\qt@no{41}}%
\qt@newcmd\qurantrans@id@mcdvi{%
(Dan di antara mereka ada orang yang mendengarkanmu) jika kamu membacakan Alquran (apakah kamu dapat menjadikan orang-orang tuli itu mendengar) keadaan mereka yang tidak mau mengambil manfaat daripada Alquran yang dibacakan kepada mereka diserupakan dengan keadaan orang-orang yang tuli (walaupun keadaan mereka) di samping tuli itu (tidak mengerti) tidak mau berpikir.\qt@no{42}}%
\qt@newcmd\qurantrans@id@mcdvii{%
(Dan di antara mereka ada orang yang melihat kepadamu, apakah dapat kamu memberi petunjuk kepada orang-orang yang buta, walaupun mereka tidak dapat memperhatikan) Allah swt. menyerupakan keadaan mereka dengan keadaan orang-orang yang tidak dapat melihat, karena mereka tidak mau mengambil petunjuk dari apa yang mereka lihat. Bahkan keadaan mereka lebih parah lagi; gambaran ini diungkapkan pula di dalam firman-Nya yang lain, yaitu, ``Karena sesungguhnya bukanlah mata itu yang buta, tetapi yang buta ialah hati yang di dalam dada." (Al-Hajj 46).\qt@no{43}}%
\qt@newcmd\qurantrans@id@mcdviii{%
(Sesungguhnya Allah tidak berbuat lalim kepada manusia sedikit pun, akan tetapi manusia itulah yang berbuat lalim kepada diri mereka sendiri).\qt@no{44}}%
\qt@newcmd\qurantrans@id@mcdix{%
(Dan di hari ketika Allah mengumpulkan mereka, seakan-akan) artinya keadaan mereka seolah-olah (tidak pernah tinggal) di dunia atau di alam kubur (melainkan hanya sesaat saja di siang hari) mengingat kengerian yang mereka lihat pada saat itu. Jumlah tasybih atau kalimat ka-allam yalbatsuu illaa saa'atan minan nahaar menjadi hal atau kata keterangan daripada dhamir maf'ul yang terdapat di dalam lafal yahsyuruhum (mereka saling berkenalan di antara sesama mereka) sebagian di antara mereka berkenalan dengan sebagian yang lain bila mereka dibangkitkan dari alam kubur, kemudian terputuslah perkenalan mereka mengingat ngerinya keadaan yang sedang mereka hadapi. Kalimat ayat ini menjadi jumlah hal yang muqaddarah atau berta'alluq pada zharaf. (Sesungguhnya rugilah orang-orang yang mendustakan pertemuan mereka dengan Allah) yaitu mereka yang tidak mempercayai adanya hari berbangkit (dan mereka tidak mendapat petunjuk).\qt@no{45}}%
\qt@newcmd\qurantrans@id@mcdx{%
(Dan jika) lafal immaa ini asalnya adalah terdiri dari in syarthiyah dan maa zaidah yang digabungkan menjadi satu (Kami perlihatkan kepadamu sebagian dari apa yang Kami ancamkan kepada mereka) berupa azab, di dalam hidupmu. Jawab syarath dibuang, lengkapnya adalah fadzaaka, artinya tentulah kamu dapat menyaksikannya (atau jika Kami wafatkan kamu) sebelum mereka tertimpa azab (maka kepada Kamilah mereka kembali, dan Allah menjadi saksi) selalu melihat (atas apa yang mereka kerjakan) berupa kedustaan mereka dan kekafiran yang mereka lakukan itu, kelak Allah akan mengazab mereka dengan siksaan yang amat keras.\qt@no{46}}%
\qt@newcmd\qurantrans@id@mcdxi{%
(Tiap-tiap umat) dari umat-umat semuanya (mempunyai rasul, maka apabila telah datang rasul mereka) kepadanya mereka mendustakannya (diberikanlah keputusan antara mereka dengan adil) secara adil; untuk itu Allah mengazab mereka dan menyelamatkan rasul-Nya bersama orang-orang yang beriman kepadanya (dan mereka sedikit pun tidak dianiaya) seumpamanya mereka diazab tanpa dosa. Demikianlah Kami melakukan hal yang serupa terhadap mereka.\qt@no{47}}%
\qt@newcmd\qurantrans@id@mcdxii{%
(Mereka mengatakan, ``Bilakah datangnya ancaman itu) siksaan itu (jika memang kalian orang-orang yang benar?") dalam hal ini.\qt@no{48}}%
\qt@newcmd\qurantrans@id@mcdxiii{%
(Katakanlah, ``Aku tidak berkuasa untuk mendatangkan kemudaratan kepada diriku) yang aku dapat menolaknya (dan tidak pula kemanfaatan) yang aku dapat menariknya (melainkan apa yang dikehendaki Allah?") bila memang Allah telah memastikannya terhadap diriku. Bagaimana aku dapat berkuasa untuk menurunkan azab kepada kalian. (Tiap-tiap umat mempunyai ajal) masa yang telah dimaklumi bagi kebinasaan mereka. (Maka apabila telah datang ajal mereka, maka mereka tidak dapat menangguhkannya) tidak dapat menangguhkan kedatangan azab itu (barang sedikit pun dan tidak pula mendahulukannya) menyegerakan datangnya azab itu.\qt@no{49}}%
\qt@newcmd\qurantrans@id@mcdxiv{%
(Katakanlah, ``Terangkanlah) ceritakanlah kepadaku (jika datang kepada kalian siksaan-Nya) yakni azab Allah (di waktu malam hari) (atau di siang hari, apakah) benar (minta disegerakan juga datangnya azab itu) siksaan itu (oleh orang-orang yang berdosa?") yakni orang-orang musyrik. Di dalam ayat ini terkandung ungkapan meletakkan isim zhahir pada tempat isim dhamir. Jumlah istifham dalam ayat ini merupakan jawab syarat; perihalnya sama dengan ucapan anda, ``idzaa ataituka madzaa tu'thiiniy?" (Jika aku datang berkunjung kepadamu, apakah yang akan engkau berikan kepadaku). Adapun pengertian yang dimaksud daripada makna ayat ini ialah menggambarkan kengerian; atau dengan kata lain, alangkah ngerinya apa yang mereka minta supaya disegerakan.\qt@no{50}}%
\qt@newcmd\qurantrans@id@mcdxv{%
(Kemudian apakah setelah terjadinya azab itu) setelah siksaan menimpa kalian (kemudian itu kalian baru mempercayainya?) percaya kepada Allah atau percaya kepada azab-Nya sewaktu azab itu diturunkan. Hamzah di sini mengandung makna mengingkari adanya penangguhan azab. Kala itu iman kalian tidak dapat diterima, kemudian akan dikatakan kepada kalian (Apakah baru sekarang) kalian mempercayainya? (padahal sebelumnya kalian selalu meminta supaya disegerakan) kalimat ayat ini mengandung arti cemoohan.\qt@no{51}}%
\qt@newcmd\qurantrans@id@mcdxvi{%
(Kemudian dikatakan kepada orang-orang yang lalim atau musyrik itu, ``Rasakanlah oleh kalian siksaan yang kekal) artinya siksaan yang kalian kekal di dalamnya (tidaklah) (kalian diberi balasan melainkan) pembalasan (dengan apa yang telah kalian kerjakan").\qt@no{52}}%
\qt@newcmd\qurantrans@id@mcdxvii{%
(Dan mereka menanyakan kepadamu) meminta penjelasan darimu ("Benarkah hal itu?") artinya apa yang telah engkau ancamkan kepada kami berupa siksaan dan dibangkitkan dari kubur itu? (Katakanlah, ``Ya,) benar (demi Rabbku, sesungguhnya azab itu adalah benar dan kalian sekali-kali tidak dapat luput.") tidak dapat selamat daripadanya.\qt@no{53}}%
\qt@newcmd\qurantrans@id@mcdxviii{%
(Dan kalau setiap diri yang lalim itu) yang kafir itu (mempunyai segala apa yang ada di bumi ini) kekayaan yang terdapat di bumi ini (tentu dia menebus dirinya dengan itu) demi menyelamatkan diri dari azab di hari kiamat (dan mereka menyembunyikan penyesalannya) karena tidak mau beriman (ketika mereka telah menyaksikan azab itu) para pemimpin orang-orang musyrik itu dengan sengaja menyembunyikan rasa penyesalannya dari mata orang-orang lemah mereka yang telah mereka sesatkan, karena mereka takut mendapatkan celaan. (Dan telah diberikan keputusan di antara mereka) yakni di antara makhluk (dengan adil) secara adil (sedangkan mereka tidak dianiaya) sedikit pun.\qt@no{54}}%
\qt@newcmd\qurantrans@id@mcdxix{%
(Ingatlah, sesungguhnya kepunyaan Allah apa yang ada di langit dan di bumi. Ingatlah sesungguhnya janji Allah itu) mengenai hari berbangkit dan hari pembalasan (benar) pasti (tetapi kebanyakan mereka) manusia (tidak mengetahui) hal itu.\qt@no{55}}%
\qt@newcmd\qurantrans@id@mcdxx{%
(Dialah yang menghidupkan dan mematikan dan hanya kepada-Nyalah kalian dikembalikan) di hari kemudian, kemudian Dia membalas kalian atas amal perbuatan kalian.\qt@no{56}}%
\qt@newcmd\qurantrans@id@mcdxxi{%
(Hai manusia) yakni penduduk Mekah (sesungguhnya telah datang kepada kalian pelajaran dari Rabb kalian) berupa Alkitab yang di dalamnya dijelaskan hal-hal yang bermanfaat dan hal-hal yang mudarat bagi diri kalian, yaitu berupa kitab Alquran (dan penyembuh) penawar (bagi penyakit-penyakit yang ada di dalam dada) yakni penyakit akidah yang rusak dan keragu-raguan (dan petunjuk) dari kesesatan (serta rahmat bagi orang-orang yang beriman) kepadanya.\qt@no{57}}%
\qt@newcmd\qurantrans@id@mcdxxii{%
(Katakanlah, ``Dengan karunia Allah) yaitu agama Islam (dan rahmat-Nya) yaitu Alquran (maka dengan hal itu) dengan karunia dan rahmat tersebut (hendaklah mereka bergembira. Karunia Allah dan rahmat-Nya itu adalah lebih baik daripada apa yang mereka kumpulkan.") yaitu berupa duniawi. Lafal yajma'uuna dapat dibaca tajma'uuna.\qt@no{58}}%
\qt@newcmd\qurantrans@id@mcdxxiii{%
(Katakanlah, ``Terangkanlah kepadaku) ceritakanlah kepadaku (tentang apa yang telah diturunkan oleh Allah) tentang apa yang telah diciptakan oleh-Nya (bagi kalian berupa rezeki, lalu kalian jadikan sebagiannya haram dan sebagian yang lainnya halal.") seperti ternak bahirah, ternak saibah dan bangkai. (Katakanlah, ``Apakah Allah telah memberikan izin kepada kalian) tentang ini, yaitu tentang penghalalan dan pengharaman ini; tentu saja tidak (atau) bahkan (kalian mengada-adakan saja terhadap Allah?") kalian telah berdusta dengan mengaitkan hal tersebut dari Allah.\qt@no{59}}%
\qt@newcmd\qurantrans@id@mcdxxiv{%
(Apakah dugaan orang-orang yang mengada-adakan kebohongan terhadap Allah) maksudnya apakah dugaan mereka terhadap-Nya (pada hari kiamat) apakah mereka menduga bahwasanya Allah tidak akan menghukum mereka? Tentu saja tidak demikian. (Sesungguhnya Allah benar-benar mempunyai karunia yang dilimpahkan kepada manusia) yaitu dengan menangguhkan mereka dan selalu memberikan nikmat kepada mereka (tetapi kebanyakan mereka tidak bersyukur).\qt@no{60}}%
\qt@newcmd\qurantrans@id@mcdxxv{%
(Kamu tidak berada) hai Muhammad! (dalam suatu keadaan) dalam suatu perkara (dan tidak membaca suatu ayat) artinya mengenai perkara tersebut atau membaca dari Allah (dari Alquran) yang diturunkan oleh-Nya kepadamu (dan kamu tidak mengerjakan) khithab ayat ini ditujukan kepada Nabi Muhammad saw. dan umatnya (suatu pekerjaan, melainkan Kami menjadi saksi atas kalian) meneliti (di waktu kalian melakukan) mengerjakan (perbuatan itu) amal perbuatan itu. (Tidak luput) tidak samar (dari pengetahuan Rabbmu hal yang sebesar) seberat (zarrah) semut yang paling kecil (di bumi atau pun di langit. Tidak ada yang lebih kecil dan tidak pula yang lebih besar dari itu melainkan semua tercatat dalam kitab yang nyata) yang jelas, yaitu Lohmahfuz.\qt@no{61}}%
\qt@newcmd\qurantrans@id@mcdxxvi{%
(Ingatlah, sesungguhnya wali-wali Allah itu tidak ada kekhawatiran terhadap mereka dan tidak pula mereka bersedih hati) di akhirat nanti.\qt@no{62}}%
\qt@newcmd\qurantrans@id@mcdxxvii{%
(Yaitu orang-orang yang beriman dan mereka selalu bertakwa) kepada Allah dengan menjalankan perintah-Nya dan menjauhi larangan-Nya.\qt@no{63}}%
\qt@newcmd\qurantrans@id@mcdxxviii{%
(Bagi mereka berita gembira di dalam kehidupan dunia) makna ayat ini ditafsirkan oleh hadis sahih yang diketengahkan oleh Imam Hakim, bahwa berita gembira ini berupa mimpi yang baik yang dilihat oleh seorang wali Allah, atau mimpi yang baik itu diperlihatkan kepadanya (dan dalam kehidupan di akhirat) mereka mendapatkan surga dan pahala. (Tidak ada perubahan bagi kalimat-kalimat Allah) janji-janji Allah tidak akan diingkari. (Yang demikian itu) hal yang telah disebutkan itu (adalah kemenangan yang besar).\qt@no{64}}%
\qt@newcmd\qurantrans@id@mcdxxix{%
(Janganlah kamu sedih oleh perkataan mereka) terhadap dirimu, seperti perkataan mereka, ``Engkau adalah bukan utusan Allah," dan lain sebagainya. (Sesungguhnya) huruf inna di sini merupakan pertanda isti'naf atau kalimat baru (kekuatan itu) kekuatan (adalah kepunyaan Allah seluruhnya. Dialah Yang Maha Mendengar) semua perkataan (lagi Maha Mengetahui) semua perbuatan, maka karenanya Dia membalas perbuatan mereka dan menolong kamu.\qt@no{65}}%
\qt@newcmd\qurantrans@id@mcdxxx{%
(Ingatlah, sesungguhnya kepunyaan Allah semua yang ada di langit dan semua yang ada di bumi) sebagai hamba-Nya, milik-Nya dan sebagai makhluk-Nya. (Dan tidaklah mengikuti orang-orang yang menyeru) yang menyembah (selain daripada Allah) selain Allah, yaitu berupa berhala-berhala (berupa sekutu-sekutu) bagi-Nya secara nyata, Maha Suci Allah dari sekutu-sekutu (tidaklah) tiada lain (mereka mengikuti) dalam hal tersebut (melainkan hanya dugaan saja) mereka menduga bahwa berhala-berhala sesembahan mereka itu adalah tuhan yang dapat memberikan syafaat terhadap diri mereka (dan tidaklah) tiadalah (keadaan mereka melainkan hanya berdusta belaka) yakni berbuat dusta dalam hal tersebut.\qt@no{66}}%
\qt@newcmd\qurantrans@id@mcdxxxi{%
(Dialah yang menjadikan malam hari bagi kalian supaya kalian beristirahat padanya dan menjadikan siang terang) diisnadkannya lafal al-ibshaar yang artinya melihat kepada lafal an-nahaar yang artinya siang hari mengandung pengertian majaz, karena seseorang dapat melihat pada siang hari. (Sesungguhnya pada yang demikian itu terdapat tanda-tanda) bukti-bukti yang menunjukkan keesaan-Nya (bagi orang-orang yang mendengar) dengan pendengaran yang dibarengi dengan perasaan mengambil pelajaran dan nasihat dari apa yang didengarnya.\qt@no{67}}%
\qt@newcmd\qurantrans@id@mcdxxxii{%
(Mereka berkata) yang dimaksud adalah orang-orang Yahudi, orang-orang Nasrani dan orang-orang yang menduga bahwa para malaikat itu adalah anak-anak perempuan Allah ("Allah mempunyai anak,") maka Allah berfirman kepada mereka (Maha Suci Allah) memahasucikan Allah dari tuduhan mempunyai anak (Dialah Yang Maha Kaya) tidak membutuhkan kepada seseorang pun, dan sesungguhnya orang-orang yang meminta punya anak itu adalah orang yang membutuhkannya. (Kepunyaan-Nya apa yang ada di langit dan apa yang ada di bumi) sebagai milik-Nya, makhluk-Nya dan hamba-Nya (tidak) tiada (bagi kalian suatu hujah pun) bukti (tentang ini) seperti apa yang telah kalian katakan itu. (Pantaskah kalian mengatakan terhadap Allah apa yang kalian tidak ketahui?) kata tanya di sini mengandung pengertian cemoohan.\qt@no{68}}%
\qt@newcmd\qurantrans@id@mcdxxxiii{%
(Katakanlah, ``Sesungguhnya orang-orang yang mengada-adakan kebohongan terhadap Allah) dengan menisbatkan mempunyai anak kepada-Nya (tidak beruntung.") tidak bahagia.\qt@no{69}}%
\qt@newcmd\qurantrans@id@mcdxxxiv{%
Bagi mereka (kesenangan) yang sedikit atau sementara (di dunia) yang mereka bersenang-senang dengannya selama hidup mereka di dunia (kemudian kepada Kamilah mereka kembali) dengan dimatikannya mereka (kemudian Kami rasakan kepada mereka siksa yang berat) sesudah mati (disebabkan kekafiran mereka).\qt@no{70}}%
\qt@newcmd\qurantrans@id@mcdxxxv{%
(Dan bacakanlah) hai Muhammad (kepada mereka) orang-orang kafir Mekah (berita penting) cerita penting (tentang Nuh) yaitu (di waktu dia berkata kepada kaumnya, ``Hai kaumku, jika terasa berat) keberatan (bagi kalian tinggal bersamaku) aku berdiam di antara kalian (dan peringatanku) nasihatku terhadap kalian (dengan ayat-ayat Allah, maka kepada Allahlah aku bertawakal, karena itu bulatkanlah keputusan kalian) bulatkanlah tekad kalian tentang perkara yang akan kalian lakukan terhadap diriku (bersama dengan sekutu-sekutu kalian) wawu di sini bermakna ma'a. (Kemudian janganlah keputusan kalian itu dirahasiakan) disembunyikan, akan tetapi tampakkanlah dan berterus-teranglah kepadaku tentang hal itu (lalu lakukanlah terhadap diriku) laksanakanlah apa yang telah kalian kehendaki itu (dan janganlah kalian memberi tangguh kepadaku) menangguh-nangguhkannya, karena sesungguhnya aku tidak akan mempedulikan kalian lagi.\qt@no{71}}%
\qt@newcmd\qurantrans@id@mcdxxxvi{%
(Jika kalian berpaling) dari peringatanku (aku tidak meminta upah sedikit pun daripada kalian) sebagai imbalan dan upah atas jerih payahku itu, maka berpalinglah kalian (tiada lain) tidak lain (upahku) pahalaku (hanyalah dari Allah belaka dan aku disuruh supaya aku termasuk golongan orang-orang yang berserah diri) kepada-Nya.\qt@no{72}}%
\qt@newcmd\qurantrans@id@mcdxxxvii{%
(Lalu mereka mendustakan Nuh, maka Kami selamatkan dia dan orang-orang yang bersamanya di dalam bahtera) perahu (dan Kami jadikan mereka itu) orang-orang yang bersama dengan Nabi Nuh (pemegang kekuasaan) di muka bumi (dan Kami tenggelamkan orang-orang yang mendustakan ayat-ayat Kami) dengan banjir besar (Maka perhatikanlah bagaimana kesudahan orang-orang yang diberi peringatan itu) yaitu dengan binasanya mereka; maka demikian pula Kami akan berlaku sama terhadap orang yang mendustakan rasul.\qt@no{73}}%
\qt@newcmd\qurantrans@id@mcdxxxviii{%
(Kemudian sesudahnya Kami utus) yakni sesudah Nabi Nuh (beberapa rasul kepada kaum mereka) seperti Nabi Ibrahim, Nabi Hud dan Nabi Saleh (maka rasul-rasul itu datang kepada mereka dengan membawa keterangan-keterangan yang nyata), yakni mukjizat-mukjizat (tetapi mereka tidak hendak beriman karena mereka dahulu telah biasa mendustakannya) sebelum rasul-rasul diutus kepada mereka. (Demikianlah Kami mengunci mati) menutup rapat-rapat (hati orang-orang yang melampaui batas) sehingga hati mereka tidak mau menerima iman, seperti Kami mengunci mati hati mereka yang melampaui batas.\qt@no{74}}%
\qt@newcmd\qurantrans@id@mcdxxxix{%
(Kemudian sesudah rasul-rasul itu, Kami utus Musa dan Harun kepada Firaun dan pemuka-pemuka kaumnya) kaumnya Firaun (dengan membawa ayat-ayat Kami) yang berjumlah sembilan buah ayat (maka mereka menyombongkan diri) tidak mau beriman kepadanya (dan mereka adalah orang-orang yang berdosa).\qt@no{75}}%
\qt@newcmd\qurantrans@id@mcdxl{%
(Dan tatkala telah datang kepada mereka kebenaran dari sisi Kami, mereka berkata, ``Sesungguhnya ini adalah sihir yang nyata.") jelas dan gamblang.\qt@no{76}}%
\qt@newcmd\qurantrans@id@mcdxli{%
(Musa berkata, ``Apakah kalian mengatakan terhadap kebenaran waktu ia datang kepada kalian) sesungguhnya adalah sihir (sihirkah ini?) padahal sungguh telah mendapat kemenangan orang yang mendatangkannya dan kalahlah sihir yang dilakukan oleh para ahli tenung (dan sungguh ahli sihir itu tidaklah mendapat kemenangan.") kedua kata tanya yang terdapat di dalam ayat ini mengandung makna ingkar.\qt@no{77}}%
\qt@newcmd\qurantrans@id@mcdxlii{%
(Mereka berkata, ``Apakah kamu datang kepada kami untuk memalingkan kami) untuk membuat kami murtad (dari apa yang kami dapati nenek moyang kami mengerjakannya dan supaya kamu berdua mempunyai kekuasaan) kerajaan (di muka bumi?) yang dimaksud adalah negeri Mesir (Kami tidak akan mempercayai kamu berdua.") tidak mau beriman.\qt@no{78}}%
\qt@newcmd\qurantrans@id@mcdxliii{%
(Firaun berkata, ``Datangkanlah kepadaku semua ahli-ahli sihir yang pandai.") yang mahir di dalam ilmu sihir.\qt@no{79}}%
\qt@newcmd\qurantrans@id@mcdxliv{%
(Maka tatkala ahli-ahli sihir itu datang, Musa berkata kepada mereka,) sesudah mereka mengatakan kepadanya, ``Kamukah yang akan melemparkan terlebih dahulu ataukah kami yang akan melemparkan?" (Al-A`raf 115) ("Lemparkanlah apa yang hendak kalian lemparkan.")\qt@no{80}}%
\qt@newcmd\qurantrans@id@mcdxlv{%
(Maka setelah mereka lemparkan) tali-tali dan tongkat-tongkat mereka (Musa berkata, ``Apa) huruf maa di sini bermakna istifham sekaligus menjadi mubtada sedangkan khabarnya ialah berikutnya (yang kalian datangkan itu itulah sihir) lafal as-sihr menjadi badal. Sedangkan menurut qiraat yang lain dengan memakai hamzah, berarti keduanya menjadi khabar, dan maa bukannya istifhamiyah melainkan maushul dan sekaligus menjadi mubtada. (Sesungguhnya Allah akan menampakkan ketidakbenarannya.") Allah akan melenyapkannya (Sesungguhnya Allah tidak akan membiarkan terus berlangsungnya pekerjaan orang-orang yang membuat kerusakan).\qt@no{81}}%
\qt@newcmd\qurantrans@id@mcdxlvi{%
(Dan Allah akan mengukuhkan) meneguhkan dan memenangkan (yang benar dengan kalimat-kalimat-Nya) yakni janji-janji-Nya (walaupun orang-orang yang berbuat dosa tidak menyukainya.)\qt@no{82}}%
\qt@newcmd\qurantrans@id@mcdxlvii{%
(Maka tidak ada yang beriman kepada Musa melainkan pemuda-pemuda) segolongan orang (dari) anak-anak (kaumnya) kaumnya Firaun (dalam keadaan takut bahwa Firaun dan pemuka-pemuka kaumnya akan menyiksa mereka.) dalam upayanya untuk memalingkan mereka dari agama Nabi Musa melalui siksaan (Sesungguhnya Firaun itu berbuat sewenang-wenang) berlaku sombong (di muka bumi.) negeri Mesir (Dan sesungguhnya dia termasuk orang-orang yang melampaui batas) dia sudah sangat keterlaluan karena mengaku menjadi tuhan.\qt@no{83}}%
\qt@newcmd\qurantrans@id@mcdxlviii{%
(Berkata Musa, ``Hai kaumku! Jika kalian beriman kepada Allah, maka bertawakallah kepada-Nya saja jika kalian benar-benar orang-orang yang berserah diri.")\qt@no{84}}%
\qt@newcmd\qurantrans@id@mcdxlix{%
(Lalu mereka berkata, ``Kepada Allahlah kami bertawakal. Ya Rabb kami! Janganlah Engkau jadikan kami sasaran fitnah bagi kaum yang zalim) artinya janganlah Engkau membuat mereka menang atas diri kami sehingga mereka menduga bahwa mereka berada dalam jalan yang benar lalu mereka berani menyiksa kami.\qt@no{85}}%
\qt@newcmd\qurantrans@id@mcdl{%
(Dan selamatkanlah kami dengan rahmat Engkau dari tipu daya orang-orang kafir.")\qt@no{86}}%
\qt@newcmd\qurantrans@id@mcdli{%
(Dan Kami wahyukan kepada Musa dan saudaranya, ``Ambillah oleh kamu berdua) tempatilah oleh kamu berdua (beberapa buah rumah di Mesir untuk tempat tinggal bagi kaummu dan jadikanlah olehmu rumah-rumah itu tempat untuk salat) sebagai mushalla tempat kalian melakukan salat di dalamnya supaya kalian merasa aman dari ketakutan, dan tersebutlah bahwa Firaun melarang mereka melakukan salat (dan dirikanlah oleh kalian salat) sempurnakanlah salat itu oleh kalian (serta gembirakanlah orang-orang yang beriman.") bahwa mereka akan mendapatkan pertolongan dan surga.\qt@no{87}}%
\qt@newcmd\qurantrans@id@mcdlii{%
(Musa berkata, ``Ya Rabb kami! Sesungguhnya Engkau telah memberi kepada Firaun dan pemuka-pemuka kaumnya perhiasan dan harta kekayaan dalam kehidupan dunia. Ya Rabb kami) Engkau telah memberikan mereka hal-hal tersebut (yang akhirnya mereka menyesatkan) pada kesudahannya mereka menyesatkan manusia (dari jalan Engkau) agama Engkau. (Ya Rabb kami, binasakanlah harta benda mereka) lenyapkanlah harta benda mereka (dan kunci matilah hati mereka) artinya tutuplah rapat-rapat hati mereka (maka mereka tidak beriman hingga mereka melihat siksaan yang pedih) yang menyakitkan. Nabi Musa berdoa mengutuk Firaun dan pemuka-pemuka kaumnya, sedangkan Nabi Harun mengamini doanya.\qt@no{88}}%
\qt@newcmd\qurantrans@id@mcdliii{%
(Allah berfirman,) Maha Tinggi Allah ("Sesungguhnya telah diperkenankan permohonan kamu berdua) akhirnya harta benda milik Firaun diserapah menjadi batu, dan Firaun masih tetap belum mau beriman hingga ia mati tenggelam (sebab itu tetaplah kamu berdua pada jalan yang lurus) menunaikan risalah dan dakwah sampai datang azab atas mereka (dan janganlah sekali-kali kamu mengikuti jalan orang-orang yang tidak mengetahui") bahwa keputusan-Ku akan disegerakan. Diriwayatkan bahwa setelah peristiwa itu Nabi Musa tinggal di negeri Mesir selama empat puluh tahun.\qt@no{89}}%
\qt@newcmd\qurantrans@id@mcdliv{%
(Dan Kami memungkinkan Bani Israel melintasi laut lalu mereka diikuti) disusul dan dikejar (oleh Firaun dan bala tentaranya, karena hendak menganiaya dan menindas) mereka, lafal baghyan dan `adwan menjadi maf'ul lah (hingga bila Firaun itu telah hampir tenggelam berkata dia, ``Saya percaya bahwa) bahwasanya; dan menurut suatu qiraat lafal annahu dibaca innahu sebagai jumlah isti'naf (tidak ada Tuhan melainkan Tuhan yang dipercayai oleh Bani Israil, dan saya termasuk orang-orang yang berserah diri.") Firaun sengaja mengulang-ulang perkataannya itu supaya diterima oleh Allah, akan tetapi Allah tidak mau menerimanya. Kemudian malaikat Jibril menyumbat mulutnya dengan lumpur laut, karena merasa khawatir Firaun akan mendapatkan rahmat dari Allah. Lalu Allah berfirman kepadanya:\qt@no{90}}%
\qt@newcmd\qurantrans@id@mcdlv{%
(Apakah sekarang) baru kamu percaya (padahal sesungguhnya kamu telah durhaka sejak dahulu, dan kamu termasuk orang-orang yang berbuat kerusakan) karena kesesatanmu dan penyesatan yang kamu lakukan dari jalan keimanan.\qt@no{91}}%
\qt@newcmd\qurantrans@id@mcdlvi{%
(Maka pada hari ini Kami selamatkan) Kami keluarkan dari laut (badanmu) jasadmu yang sudah tidak bernyawa (supaya kamu dijadikan oleh orang-orang yang datang sesudahmu) generasi sesudahmu (sebagai pelajaran) bahan pelajaran, sehingga mereka mengetahui sifat kehambaanmu. Dengan demikian mereka tidak akan berani lagi melakukan perbuatan seperti yang pernah dilakukan olehmu. Ibnu Abbas r.a. menceritakan, bahwa sebagian orang-orang Bani Israel merasa ragu-ragu akan kematian Firaun, maka dikeluarkan-Nyalah mayat Firaun dari laut supaya mereka melihat dan menyaksikannya dengan mata kepala sendiri (dan sesungguhnya kebanyakan dari manusia) penduduk Mekah (lengah dari tanda-tanda kekuasaan-Ku) artinya mereka tidak mau mengambil pelajaran daripadanya.\qt@no{92}}%
\qt@newcmd\qurantrans@id@mcdlvii{%
(Dan sesungguhnya Kami telah menempatkan) memberikan tempat (Bani Israel di tempat kediaman yang bagus) tempat yang terhormat, yaitu negeri Syam dan negeri Mesir (dan Kami beri mereka rezeki dari yang baik-baik. Maka mereka tidak berselisih) sekalipun sebagian di antara mereka beriman dan sebagian yang lain kafir (kecuali setelah datang kepada mereka pengetahuan, yang tersebut dalam Taurat. Sesungguhnya Rabb kamu akan memutuskan antara mereka di hari kiamat tentang apa yang mereka perselisihkan itu) dalam masalah agama, yaitu dengan menyelamatkan orang-orang beriman dan mengazab orang-orang kafir.\qt@no{93}}%
\qt@newcmd\qurantrans@id@mcdlviii{%
(Maka jika kamu) hai Muhammad (berada dalam keragu-raguan tentang apa yang Kami turunkan kepadamu) yaitu berupa kisah-kisah, seumpamanya (maka tanyakanlah kepada orang-orang yang telah membaca kitab) Taurat (sebelum kamu) maka sesungguhnya hal itu telah tertera di dalam kitab mereka, mereka akan memberitakannya kepadamu sesuai dengannya; untuk itu maka Rasulullah saw. bersabda, ``Aku tidak ragu dan tidak menanyakannya." (Sesungguhnya telah datang kebenaran kepadamu dari Rabbmu, sebab itu janganlah sekali-kali kamu termasuk orang-orang yang ragu) menaruh keraguan padanya.\qt@no{94}}%
\qt@newcmd\qurantrans@id@mcdlix{%
(Dan sekali-kali janganlah kamu termasuk orang-orang yang mendustakan ayat-ayat Allah yang menyebabkan kamu termasuk orang-orang yang rugi).\qt@no{95}}%
\qt@newcmd\qurantrans@id@mcdlx{%
(Sesungguhnya orang-orang yang telah pasti) telah dipastikan (terhadap mereka kalimat Rabbmu) yaitu azab Allah telah pasti atas mereka (tidaklah akan beriman).\qt@no{96}}%
\qt@newcmd\qurantrans@id@mcdlxi{%
(Meskipun datang kepada mereka segala macam keterangan hingga mereka menyaksikan azab yang pedih) maka pada saat itu tidak bermanfaat lagi keimanan mereka.\qt@no{97}}%
\qt@newcmd\qurantrans@id@mcdlxii{%
(Dan mengapa tidak) hendaknyalah (ada suatu kota) yakni penduduknya (yang beriman) sebelum azab turun atas mereka (lalu imannya itu bermanfaat kepadanya selain kaum Yunus. Tatkala mereka beriman) yaitu sewaktu mereka melihat adanya tanda-tanda azab lalu mereka segera beriman sebelum azab diturunkan atas diri mereka (Kami hilangkan dari mereka azab yang menghinakan dalam kehidupan dunia dan Kami beri kesenangan kepada mereka sampai pada waktu yang tertentu) sampai ajal mereka tiba.\qt@no{98}}%
\qt@newcmd\qurantrans@id@mcdlxiii{%
(Dan jika Rabbmu menghendaki tentulah beriman semua orang yang di muka bumi seluruhnya. Maka apakah kamu hendak memaksa manusia) terhadap apa yang Allah tidak kehendaki mereka untuk melakukannya (supaya mereka menjadi orang-orang yang beriman semuanya?) tentu saja tidak.\qt@no{99}}%
\qt@newcmd\qurantrans@id@mcdlxiv{%
(Dan tidak ada seorang pun akan beriman kecuali dengan izin Allah) dengan kehendak-Nya (dan Allah menimpakan kemurkaan) azab-Nya (kepada orang-orang yang tidak mempergunakan akalnya) yaitu orang-orang yang tidak mau memikirkan ayat-ayat Allah.\qt@no{100}}%
\qt@newcmd\qurantrans@id@mcdlxv{%
(Katakanlah,) kepada orang-orang kafir Mekah ("Perhatikanlah apa) apa-apa (yang ada di langit dan di bumi) yaitu tanda-tanda yang menunjukkan akan keesaan Allah swt. (Tidaklah bermanfaat tanda kekuasaan Allah dan rasul-rasul yang memberi peringatan) lafal an-nudzur adalah bentuk jamak dari kata tunggal nadzir yang artinya para rasul (bagi orang-orang yang tidak beriman.") yang hal ini diketahui oleh Allah swt. atau dengan kata lain, hal-hal tersebut tidak ada manfaatnya bagi mereka.\qt@no{101}}%
\qt@newcmd\qurantrans@id@mcdlxvi{%
(Tiada) tidak ada (yang mereka tunggu-tunggu) dengan perbuatan mereka yang mendustakan kamu (melainkan kejadian-kejadian yang sama dengan kejadian-kejadian yang menimpa orang-orang terdahulu sebelum mereka) umat-umat terdahulu. Artinya, mereka akan tertimpa siksaan yang sama seperti siksaan yang menimpa umat-umat terdahulu (Katakanlah, ``Maka tunggulah) hal tersebut (sesungguhnya aku pun orang yang menunggu bersama kalian.")\qt@no{102}}%
\qt@newcmd\qurantrans@id@mcdlxvii{%
(Kemudian Kami selamatkan) bentuk mudhari' di sini dimaksud untuk menceritakan keadaan di masa lampau (rasul-rasul Kami dan orang-orang yang beriman) dari azab (demikianlah) penyelamatan itu (menjadi kewajiban atas Kami menyelamatkan orang-orang yang beriman) Nabi dan para sahabatnya ketika orang-orang musyrik disiksa.\qt@no{103}}%
\qt@newcmd\qurantrans@id@mcdlxviii{%
(Katakanlah, ``Hai manusia) hai penduduk Mekah! (Jika kalian masih dalam keragu-raguan tentang agamaku) bahwasanya agamaku itu adalah hak dan benar (maka ketahuilah aku tidak menyembah yang kalian sembah selain Allah) selain-Nya, yang dimaksud adalah berhala-berhala; hal ini merupakan pertanda bahwa kalian ragu-ragu terhadap agamaku (tetapi aku menyembah Allah yang akan mematikan kalian) yang akan mencabut ruh kalian (dan aku telah diperintah supaya) hendaknya (aku termasuk orang-orang yang beriman.")\qt@no{104}}%
\qt@newcmd\qurantrans@id@mcdlxix{%
(Dan) aku diperintahkan ("Hadapkanlah mukamu kepada agama dengan tulus dan ikhlas) dalam keadaan cenderung dan menggandrunginya (dan janganlah kamu termasuk orang-orang yang musyrik).\qt@no{105}}%
\qt@newcmd\qurantrans@id@mcdlxx{%
(Dan janganlah kamu menyeru) menyembah (kepada selain Allah, yaitu apa-apa yang tidak dapat memberikan manfaat kepadamu) jika kamu menyembahnya (dan pula tidak dapat memberikan mudarat kepadamu) jika kamu tidak menyembahnya (sebab jika kamu berbuat) hal itu, umpamanya (maka sesungguhnya kamu kalau begitu termasuk orang-orang yang lalim.")\qt@no{106}}%
\qt@newcmd\qurantrans@id@mcdlxxi{%
(Jika Allah menimpakan kepadamu) mengenakan kepadamu (sesuatu kemudaratan) seperti kemiskinan dan sakit (maka tidak ada yang dapat menghilangkan) yang melenyapkan (hal itu kecuali Dia. Dan jika Allah menghendaki kebaikan bagi kamu, maka tak ada yang dapat menolak) menahan (karunia-Nya) yang telah Dia kehendaki buatmu (Dia memberikan hal itu) kebaikan itu (kepada siapa yang dikehendaki-Nya di antara hamba-hamba-Nya dan Dialah Yang Maha Pengampun lagi Maha Penyayang.)\qt@no{107}}%
\qt@newcmd\qurantrans@id@mcdlxxii{%
(Katakanlah, ``Hai manusia) yakni penduduk Mekah! (Sesungguhnya telah datang kepada kalian kebenaran dari Rabb kalian, sebab itu barang siapa yang mendapat petunjuk maka sesungguhnya petunjuk itu untuk kebaikan dirinya.) karena sesungguhnya pahala hidayahnya itu hanya dialah yang berhak menerimanya (Dan barang siapa yang sesat maka sesungguhnya kesesatannya itu untuk kecelakaan dirinya sendiri) karena akibat kesesatannya itu akan menimpa dirinya sendiri (Dan aku bukanlah seorang penjaga terhadap diri kalian.") karenanya bagaimana aku akan memaksakan kepada kalian untuk mengikuti petunjuk.\qt@no{108}}%
\qt@newcmd\qurantrans@id@mcdlxxiii{%
(Dan ikutilah apa yang diwahyukan kepadamu) dari Rabbmu (dan bersabarlah) di dalam berdakwah dan menghadapi permusuhan mereka (hingga Allah memberi keputusan) terhadap mereka dengan perintah-Nya (dan Dia adalah hakim yang sebaik-baiknya) hakim yang paling adil. Ternyata Nabi saw. bersabar di dalam menghadapi kesemuanya itu, hingga Allah memberikan keputusan terhadap orang-orang musyrik, yaitu dengan memerintahkan supaya mereka diperangi dan bagi ahli Kitab supaya ditarik jizyah/upeti.\qt@no{109}}%
\qt@newcmd\qurantrans@id@mcdlxxiv{%
\basmalahid (Alif laam raa) hanya Allahlah yang mengetahui maksudnya; inilah (suatu Kitab yang ayat-ayatnya disusun dengan rapi) hal ini tampak pada susunan ayat-ayatnya yang memukau dan keindahan makna-maknanya (serta dijelaskan secara rinci) yang kandungannya menjelaskan tentang hukum-hukum, kisah-kisah dan nasihat-nasihat (yang diturunkan dari sisi Yang Maha Bijaksana lagi Maha Waspada) yaitu Allah.\qt@no{1}}%
\qt@newcmd\qurantrans@id@mcdlxxv{%
(agar) supaya (kalian tidak menyembah selain Allah. Sesungguhnya aku, Muhammad, adalah pemberi peringatan kepada kalian dari-Nya) yaitu dengan azab jika kalian berbuat kekafiran (dan pembawa berita gembira) dengan pahala jika kalian beriman.\qt@no{2}}%
\qt@newcmd\qurantrans@id@mcdlxxvi{%
(Dan hendaklah kalian meminta ampun kepada Rabb kalian) dari kemusyrikan (dan bertobatlah kalian) kembalilah kalian (kepada-Nya) dengan menjalankan ketaatan (niscaya Dia akan memberi kenikmatan kepada kalian) di dunia (dengan kenikmatan yang baik) dengan kehidupan yang baik dan rezeki yang banyak (sampai pada waktu yang telah ditentukan) yaitu mati (dan Dia akan memberi) kelak di akhirat (kepada tiap-tiap orang yang mempunyai keutamaan) di dalam beramal (keutamaannya) yakni balasannya (Dan jika kalian berpaling) lafal tawallau pada asalnya adalah tatawallau kemudian salah satu dari dua huruf ta dibuang sehingga jadilah tawallau, artinya berpaling (maka sesungguhnya aku takut kalian akan ditimpa siksa di hari kiamat) yaitu hari akhir.\qt@no{3}}%
\qt@newcmd\qurantrans@id@mcdlxxvii{%
(Kepada Allahlah kembali kalian, dan Dia Maha Kuasa atas segala sesuatu) antara lain ialah memberi pahala dan menentukan azab.\qt@no{4}}%
\qt@newcmd\qurantrans@id@mcdlxxviii{%
Ayat ini seperti yang diriwayatkan oleh Imam Bukhari melalui Ibnu Abbas r.a. diturunkan berkenaan dengan orang-orang yang merasa malu untuk membuang air besar atau merasa malu berjimak karena kemaluan mereka terlihat dari atas langit. Akan tetapi menurut pendapat yang lain dikatakan bahwa ayat ini diturunkan berkenaan dengan perihal orang-orang munafik (Ingatlah sesungguhnya orang-orang munafik itu memalingkan dada mereka untuk menyembunyikan diri daripada-Nya) daripada Allah (Ingatlah, di waktu mereka menyelimuti dirinya dengan kain) menutupi dirinya dengan kain (Allah mengetahui) Maha Tinggi Allah (apa yang mereka sembunyikan dan apa yang mereka lahirkan) sehingga sembunyi mereka tidak ada gunanya lagi (sesungguhnya Allah Maha Mengetahui segala isi hati) artinya Dia mengetahui semua apa yang ada di dalam hati.\qt@no{5}}%
\qt@newcmd\qurantrans@id@mcdlxxix{%
(Dan tidak ada) huruf min di sini zaidah (suatu binatang melata pun di bumi) yaitu hewan yang melata di atas bumi (melainkan Allahlah yang memberi rezekinya) Dialah yang menanggung rezekinya sebagai karunia daripada-Nya (dan Dia mengetahui tempat berdiam binatang itu) tempat hidupnya di dunia atau pada tulang sulbi (dan tempat penyimpanannya) sesudah mati atau di dalam rahim. (Semuanya) yang telah disebutkan itu (tertulis dalam kitab yang nyata) kitab yang jelas, yaitu Lohmahfuz.\qt@no{6}}%
\qt@newcmd\qurantrans@id@mcdlxxx{%
(Dan Dialah yang menciptakan langit dan bumi dalam enam hari) yang permulaannya adalah hari Ahad dan berakhir pada hari Jumat (dan adalah Arasy-Nya) sebelum diciptakan langit dan bumi (di atas air) yaitu berada di atas angin (agar Dia menguji kalian) lafal liyabluwakum berta'alluq kepada lafal khalaqa artinya, Allah menciptakan langit dan bumi beserta isinya yaitu berupa manfaat-manfaat dan maslahat-maslahat bagi kalian untuk menguji kalian (siapakah di antara kalian yang lebih baik amalnya) artinya yang lebih taat kepada Allah (dan jika kamu berkata) hai Muhammad, kepada penduduk Mekah ("Sesungguhnya kalian akan dibangkitkan sesudah mati," niscaya orang-orang yang kafir itu akan berkata, ``Tiada lain) tidak lain (ini) yakni Alquran yang menceritakan adanya hari berbangkit seperti yang telah engkau katakan itu (hanyalah sihir yang nyata") sihir yang jelas. Menurut qiraat dibaca saahirun bukannya sihrun; sedangkan yang diisyaratkan oleh musyar ilaih adalah Nabi Muhammad saw. bukannya Alquran.\qt@no{7}}%
\qt@newcmd\qurantrans@id@mcdlxxxi{%
(Dan sesungguhnya jika Kami undurkan azab dari mereka sampai pada) datangnya (suatu waktu) beberapa waktu (yang ditentukan, niscaya mereka akan berkata) yang dimaksud dari keterangan ini adalah cemoohan ("Apakah yang menghalanginya?") apakah gerangan yang mencegah turunnya azab. Sebagai sanggahannya Allah berfirman: (Ingatlah, di waktu azab itu datang kepada mereka tidaklah dapat dipalingkan) tidak dapat ditahan lagi (dari mereka dan mereka diliputi) dikepung (oleh azab yang dahulunya mereka selalu memperolok-olokkannya) yang dimaksud adalah mereka memperolok-olokkan azab itu sebelumnya.\qt@no{8}}%
\qt@newcmd\qurantrans@id@mcdlxxxii{%
(Dan jika Kami rasakan kepada manusia) yang kafir (suatu rahmat dari Kami) yaitu berupa kekayaan dan kesehatan (kemudian rahmat itu Kami cabut daripadanya pastilah dia menjadi putus asa) merasa putus asa dari rahmat Allah (lagi tidak berterima kasih) sangat mengingkari-Nya.\qt@no{9}}%
\qt@newcmd\qurantrans@id@mcdlxxxiii{%
(Dan jika kami rasakan kepadanya kebahagiaan sesudah bencana) kemiskinan dan kesengsaraan (yang menimpanya, niscaya dia akan berkata, ``Telah hilang keburukan-keburukan itu) yaitu bencana-bencana tersebut (dariku.") akan tetapi ia tidak mempunyai perasaan bahwa kebahagiaan itu bakal lenyap darinya dan pula ia tidak mensyukurinya (Sesungguhnya dia sangat gembira) meluap (lagi bangga) terhadap manusia atas apa yang diberikan kepadanya.\qt@no{10}}%
\qt@newcmd\qurantrans@id@mcdlxxxiv{%
(Kecuali) tetapi (orang-orang yang sabar) terhadap bencana (dan mengerjakan amal-amal saleh) sewaktu diberi kebahagiaan (mereka itu beroleh ampunan dan pahala yang besar) yaitu surga.\qt@no{11}}%
\qt@newcmd\qurantrans@id@mcdlxxxv{%
(Maka boleh jadi kamu) hai Muhammad (meninggalkan sebagian dari apa yang diwahyukan kepadamu) sehingga kamu tidak menyampaikannya kepada mereka karena mereka menganggap remeh terhadapnya (dan sempit karenanya dadamu) sewaktu engkau membacakannya kepada mereka, karena khawatir bahwa (mereka akan mengatakan, ``Mengapa tidak) bagaimana tidak (diturunkan kepadanya perbendaharaan atau datang bersama-sama dengan dia satu malaikat?") yang membenarkannya sesuai dengan apa yang kami minta. (Sesungguhnya kamu hanyalah seorang pemberi peringatan) tugasmu hanyalah menyampaikan bukannya mendatangkan apa yang mereka kehendaki. (Dan Allah Pemelihara segala sesuatu) yakni Dia hafal kesemuanya, maka Dia membalas mereka karenanya.\qt@no{12}}%
\qt@newcmd\qurantrans@id@mcdlxxxvi{%
(Bahkan) akan tetapi apakah (mereka mengatakan, ``Muhammad telah membuat-buatnya") yakni Alquran itu (Katakanlah, ``Kalau demikian, maka datangkanlah sepuluh surah-surah semisal dengannya) dalam masalah kefasihan bahasa dan ketinggian paramasastranya (yang dibuat-buat) karena sesungguhnya kalian sama denganku adalah orang-orang Arab yang fasih dalam berbahasa. Allah swt. menantang mereka untuk pertama kalinya supaya mereka mendatangkan sepuluh surah, kemudian pada tantangan yang berikutnya cukup hanya dengan satu surah saja (dan panggillah orang-orang yang kalian sanggup memanggilnya selain Allah) selain dari Allah (jika kalian memang orang-orang yang benar.") di dalam tuduhan kalian yang menyatakan, bahwa Alquran itu hanyalah buat-buatan belaka.\qt@no{13}}%
\qt@newcmd\qurantrans@id@mcdlxxxvii{%
(Jika) bila (mereka yang kalian seru tidak menerima seruan/ajakan kalian) yaitu orang-orang yang kalian ajak untuk membantu kalian (maka ketahuilah) khithab atau pembicaraan ditujukan kepada orang-orang musyrik (sesungguhnya Alquran itu diturunkan) berdasarkan (ilmu Allah) dan bukannya buat-buatan yang dilakukan terhadap-Nya (dan bahwasanya) an di sini adalah bentuk takhfif daripada anna (tidak ada Tuhan selain Dia, maka maukah kalian berserah diri kepada-Nya) sesudah adanya hujah-hujah yang pasti ini. Makna yang dimaksud ialah hendaknya kalian masuk Islam.\qt@no{14}}%
\qt@newcmd\qurantrans@id@mcdlxxxviii{%
(Barang siapa yang menghendaki kehidupan dunia dan perhiasannya) seumpamanya ia tetap bersikeras dalam kemusyrikannya. Menurut suatu pendapat ayat ini ditujukan kepada orang-orang yang berbuat ria atau pamer (niscaya Kami berikan kepada mereka balasan pekerjaannya dengan sempurna) pembalasan dari amal baik yang telah dikerjakannya, seperti sedekah dan bersilaturahmi (di dunia) umpamanya Kami meluaskan lapangan rezeki mereka (dan mereka di dalamnya) yakni di dunia (tidak dirugikan) artinya tidak akan dikurangi sedikit pun balasannya.\qt@no{15}}%
\qt@newcmd\qurantrans@id@mcdlxxxix{%
(Itulah orang-orang yang tidak memperoleh di akhirat kecuali neraka dan lenyaplah) dileburlah (apa yang telah mereka usahakan) itu (di akhirat nanti) sehingga mereka tidak mempunyai pahala lagi (dan sia-sialah apa yang telah mereka kerjakan.)\qt@no{16}}%
\qt@newcmd\qurantrans@id@mcdxc{%
(Apakah orang yang mempunyai bukti) penjelasan (dari Rabbnya) yaitu Nabi saw. atau orang-orang mukmin yang dimaksud dengan bukti adalah Alquran (dan diikuti pula) dipanuti (oleh saksi) baginya yang membenarkannya (dari-Nya) yaitu dari Allah, yang dimaksud adalah malaikat Jibril (dan sebelumnya) sebelum Alquran (telah ada kitab Musa) yaitu kitab Taurat yang menyaksikan kebenaran Alquran pula (yang menjadi pedoman dan rahmat?) menjadi kata keterangan dari Alquran. Apakah keadaannya sama dengan orang-orang yang tidak demikian keadaannya? Tentu saja tidak (mereka itu) yakni orang-orang yang mempunyai bukti (beriman kepadanya) kepada Alquran, maka bagi mereka surga. (Dan barang siapa di antara golongan yang bersekutu ingkar kepada Alquran) semua orang-orang kafir (maka nerakalah tempat yang diancamkan baginya, karena itu janganlah kamu ragu-ragu) menaruh syak (kepadanya) kepada Alquran (Sesungguhnya Alquran itu benar-benar dari Rabbmu tetapi kebanyakan manusia) penduduk Mekah (tidak beriman).\qt@no{17}}%
\qt@newcmd\qurantrans@id@mcdxci{%
(Dan siapakah) tidak ada seorang pun (yang lebih lalim daripada orang yang membuat-buat dusta terhadap Allah?) dengan menisbatkan sekutu terhadap-Nya dan menganggapnya mempunyai anak. (Mereka itu akan dihadapkan kepada Rabb mereka) kelak di hari kiamat di antara semua makhluk-Nya (dan para saksi akan berkata) lafal asyhaad adalah bentuk jamak dari lafal syahiid yang artinya saksi. Mereka adalah para malaikat; mereka memberikan kesaksian, bahwa para rasul telah menyampaikan risalahnya, adapun orang-orang kafir mereka cap sebagai pendusta ("Orang-orang inilah yang telah berdusta terhadap Rabb mereka." Ingatlah, kutukan Allah dilimpahkan atas orang-orang yang lalim) yaitu orang-orang musyrik.\qt@no{18}}%
\qt@newcmd\qurantrans@id@mcdxcii{%
(Yaitu orang-orang yang menghalangi manusia dari jalan Allah) dari agama Islam (dan menghendaki supaya jalan itu) (bengkok) tidak lurus (Dan mereka terhadap hari kemudian adalah) lafal hum kedua mengukuhkan makna lafal hum pertama (orang-orang yang tidak percaya).\qt@no{19}}%
\qt@newcmd\qurantrans@id@mcdxciii{%
(Orang-orang itu tidak mampu menghalang-halangi) Allah (di bumi ini dan sekali-kali tidak adalah bagi mereka selain Allah) selain-Nya (yang menolong mereka) maksudnya para penolong yang dapat mencegah azab Allah terhadap mereka. (Siksaan itu dilipatgandakan kepada mereka) karena mereka menyesatkan orang lain. (Mereka selalu tidak dapat mendengar) kebenaran (dan mereka selalu tidak melihat) kebenaran itu karena kebencian mereka yang sangat terhadap kebenaran itu sehingga digambarkan seolah-olah mereka tidak mampu untuk mendengar dan melihatnya.\qt@no{20}}%
\qt@newcmd\qurantrans@id@mcdxciv{%
(Mereka itulah orang-orang yang merugikan dirinya sendiri) karena mereka menjerumuskan dirinya ke dalam neraka yang abadi (dan lenyaplah) terhapuslah (dari mereka apa yang selalu mereka ada-adakan) terhadap Allah, yaitu tuduhan mereka yang menyekutukan Allah.\qt@no{21}}%
\qt@newcmd\qurantrans@id@mcdxcv{%
(Pasti) sungguh (mereka itu di akhirat menjadi orang-orang yang paling merugi).\qt@no{22}}%
\qt@newcmd\qurantrans@id@mcdxcvi{%
(Sesungguhnya orang-orang yang beriman dan mengerjakan amal-amal saleh dan merendahkan diri) merasa tenang dan aman, atau kembali (kepada Rabb mereka, mereka itu adalah penghuni-penghuni surga; mereka kekal di dalamnya).\qt@no{23}}%
\qt@newcmd\qurantrans@id@mcdxcvii{%
(Perumpamaan) gambaran (kedua golongan itu) yakni orang-orang kafir dan orang-orang mukmin (seperti orang buta dan tuli) ini perumpamaan orang kafir (dengan orang yang dapat melihat dan dapat mendengar) ini perumpamaan orang mukmin. (Adakah kedua golongan itu sama keadaan dan sifatnya?) Tentu saja tidak. (Maka tidakkah kalian mengambil pelajaran) lafal tadzakkaruuna asalnya tatadzakkaruuna, kemudian huruf ta asal diidgamkan kepada huruf dzal sehingga jadilah tadzakkaruuna, artinya sama dengan lafal tatta'izhuuna, yaitu mengambil pelajaran.\qt@no{24}}%
\qt@newcmd\qurantrans@id@mcdxcviii{%
(Dan sesungguhnya Kami telah mengutus Nuh kepada kaumnya, ia berkata, ``Sesungguhnya aku) bahwa aku. Menurut suatu qiraat lafal innii dengan memperkirakan adanya makna al-qaul yang artinya, dia berkata (adalah pemberi peringatan yang nyata bagi kalian) yakni jelas peringatannya.\qt@no{25}}%
\qt@newcmd\qurantrans@id@mcdxcix{%
(Agar) supaya (kalian jangan menyembah selain Allah. Sesungguhnya aku takut kalian) jika kalian menyembah selain-Nya (akan ditimpa azab pada hari yang sangat menyakitkan.") azab yang menyakitkan di dunia dan di akhirat.\qt@no{26}}%
\qt@newcmd\qurantrans@id@md{%
(Maka berkatalah pemimpin-pemimpin yang kafir dari kaumnya,) mereka adalah terdiri dari orang-orang terhormat kaumnya ("Kami tidak melihat kamu melainkan sebagai manusia biasa seperti kami) tidak ada kelebihan bagimu atas diri kami (dan kami tidak melihat orang-orang yang mengikuti kamu, melainkan orang-orang yang hina-dina di antara kami) yaitu orang-orang yang rendah di antara kami, seperti tukang tambal pakaian dan tukang sol sepatu (yang lekas percaya saja) dapat dibaca baadiya dan baadia yang artinya, mereka lekas percaya kepadamu tanpa berpikir lebih matang lagi. Lafal ini dinashabkan karena menjadi zharaf yang artinya, mereka terus percaya dengan begitu saja (dan kami tidak melihat kalian memiliki suatu kelebihan apa pun atas kami) sehingga karena kelebihan itulah kalian berhak untuk diikuti daripada kami (bahkan kami yakin bahwa kalian adalah orang-orang yang dusta") dalam pengakuan risalah yang kalian bawa. Dalam hal ini mereka mengikut sertakan sebutan Nabi Nuh beserta kaum yang mengikutinya.\qt@no{27}}%
\qt@newcmd\qurantrans@id@mdi{%
(Berkata Nuh, ``Hai kaumku! Bagaimana pikiranmu) coba katakan kepadaku (jika aku ada mempunyai bukti yang nyata) penjelasan yang nyata (dari Rabbku dan diberi-Nya aku rahmat) kenabian (dari sisi-Nya tetapi rahmat itu disamarkan) disembunyikan (bagi kalian) dan menurut suatu qiraat dibaca fa`amiyat (apa akan kami paksakan kalian menerimanya) artinya apakah kami harus memaksakan kalian untuk menerimanya (padahal kalian tiada menyukainya?") tidak mampu untuk melakukan hal tersebut.\qt@no{28}}%
\qt@newcmd\qurantrans@id@mdii{%
(Dan dia berkata, ``Hai kaumku! Aku tiada meminta kepada kalian sebagai upah bagi seruanku) di dalam menyampaikan risalahku (harta benda) yang kalian berikan kepadaku sebagai imbalannya (tiada lain) (upahku) pahalaku (hanyalah dari Allah dan aku sekali-kali tidak akan mengusir orang-orang yang telah beriman) seperti apa yang kalian perintahkan supaya aku melakukannya. (Sesungguhnya mereka pasti akan bertemu dengan Rabbnya) melalui hari berbangkit kemudian Allah membalas mereka dan menghukum orang-orang yang menyakiti dan mengusir orang-orang yang beriman (tetapi aku memandang kalian suatu kaum yang tidak mengetahui.") akibat dari perbuatan kalian yang demikian itu.\qt@no{29}}%
\qt@newcmd\qurantrans@id@mdiii{%
(Dan dia berkata, ``Hai kaumku! Siapakah yang akan menolongku) yang dapat membentengi diriku (dari Allah) dari azab-Nya (jika aku mengusir mereka) orang-orang yang beriman kepadaku, tentu saja tidak ada seorang penolong pun. (Maka tidakkah) mengapa tidak (kalian mengambil pelajaran) lafal tadzakkaruuna asalnya adalah tatadzakkaruuna, kemudian huruf ta asal diidgamkan kepada dzal sehingga jadilah tadzdzakkaruuna, artinya sama dengan tatta`izhuuna, yaitu mengambil pelajaran.\qt@no{30}}%
\qt@newcmd\qurantrans@id@mdiv{%
(Dan aku tidak mengatakan kepada kalian, bahwa, 'Aku mempunyai gudang-gudang rezeki dan kekayaan dari Allah dan tiada pula) aku (mengetahui yang gaib dan tidak pula aku mengatakan bahwa sesungguhnya aku adalah malaikat.') akan tetapi sesungguhnya aku adalah manusia biasa sama dengan kalian (dan tidak juga aku mengatakan kepada orang-orang yang dipandang hina) dipandang remeh (oleh penglihatan kalian, ``Sekali-kali Allah tidak akan mendatangkan kebaikan kepada mereka." Allah lebih mengetahui apa yang ada pada diri mereka) yang terpendam di dalam kalbu mereka (sesungguhnya aku kalau begitu) maksudnya jika aku mengatakan demikian (benar-benar termasuk orang-orang yang lalim).\qt@no{31}}%
\qt@newcmd\qurantrans@id@mdv{%
(Mereka berkata, ``Hai Nuh! Sesungguhnya kamu telah berbantah dengan kami) telah memusuhi kami (dan kamu memperpanjang bantahanmu terhadap kami, maka datangkanlah kepada kami apa yang kamu ancamkan kepada kami) yaitu azab (jika kamu termasuk orang-orang yang benar") di dalam ancaman yang kamu katakan itu.\qt@no{32}}%
\qt@newcmd\qurantrans@id@mdvi{%
(Nuh menjawab, ``Hanyalah Allah yang akan mendatangkan azab itu kepada kalian jika Dia menghendaki) supaya azab itu disegerakan terhadap kalian karena sesungguhnya urusan penurunan azab itu kembali kepada-Nya (dan kalian sekali-kali tidak dapat melepaskan diri) dari azab-Nya.\qt@no{33}}%
\qt@newcmd\qurantrans@id@mdvii{%
(Dan tidaklah bermanfaat kepada kalian nasihatku jika aku hendak memberi nasihat kepada kalian sekiranya Allah hendak menyesatkan kalian) artinya berkehendak untuk membuat kalian sesat. Jawab syarat tersirat dari makna yang terkandung di dalam kalimat, 'Dan tidaklah bermanfaat kepada kalian nasihatku.' (Dia adalah Rabb kalian dan kepada-Nyalah kalian dikembalikan"). Selanjutnya Allah swt. berfirman:\qt@no{34}}%
\qt@newcmd\qurantrans@id@mdviii{%
(Bahkan) malahan (mereka mengatakan) yang dimaksud adalah orang-orang kafir Mekah ("Dia cuma membuat-buatnya saja.") artinya Muhammad hanya membuat-buat Alquran saja (Katakanlah, ``Jika aku membuat-buatnya, maka hanya akulah yang memikul dosanya) azab sebagai akibat dari perbuatan itu (dan aku berlepas diri dari dosa yang kalian lakukan.") yaitu dosa tuduhan kalian yang mencap diriku sebagai pembuat Alquran.\qt@no{35}}%
\qt@newcmd\qurantrans@id@mdix{%
(Dan diwahyukan kepada Nuh, bahwasanya sekali-kali tidak akan beriman di antara kaummu kecuali orang yang telah beriman saja, karena itu janganlah kamu bersedih hati) merasa susah (tentang apa yang selalu mereka kerjakan) yaitu perbuatan syirik. Maka Nabi Nuh mendoakan kebinasaan bagi mereka yang tidak beriman, yaitu yang disitir oleh firman-Nya, ``Wahai Rabbku! Janganlah Engkau biarkan di atas muka bumi ini..." (Nuh 26) kemudian Allah mengabulkan doanya seraya berfirman:\qt@no{36}}%
\qt@newcmd\qurantrans@id@mdx{%
(Dan buatlah bahtera) perahu (dengan pengawasan Kami) dengan pengawasan dan pemeliharaan Kami (dan petunjuk wahyu Kami) yakni perintah Kami (dan janganlah kamu bicarakan dengan Aku tentang orang-orang yang lalim itu) orang-orang kafir itu, biarkanlah mereka binasa (sesungguhnya mereka itu akan ditenggelamkan).\qt@no{37}}%
\qt@newcmd\qurantrans@id@mdxi{%
(Dan mulailah Nuh membuat bahtera) dimaksud menceritakan keadaan masa lampau (Dan setiap kali lewat kepada Nuh segolongan) sebagian (dari kaumnya, mereka mengejeknya) mereka memperolok-olokkannya. (Berkatalah Nuh, ``Jika kalian mengejek kami, maka sesungguhnya kami pun akan mengejek kalian sebagaimana kalian mengejek kami) jika kami selamat dan kalian tenggelam nanti.\qt@no{38}}%
\qt@newcmd\qurantrans@id@mdxii{%
(Kelak kalian akan mengetahui siapa) lafal man di sini maushul atau kata sambung, kedudukannya menjadi maf`ul atau objek dari lafal ta`lamuuna (yang akan ditimpa oleh azab yang menghinakannya dan yang akan ditimpa) akan dikenakan (kepadanya azab yang kekal.")\qt@no{39}}%
\qt@newcmd\qurantrans@id@mdxiii{%
(Hingga) mengisahkan batas pembuatan bahtera (apabila perintah Kami datang) yang membinasakan mereka (dan dapur telah memancarkan air) yang dimaksud adalah dapur pemanggangan roti, hal itu merupakan pertanda bagi Nabi Nuh. (Kami berfirman, ``Muatkanlah ke dalam bahtera itu) ke dalam perahu itu (dari masing-masing binatang sepasang) yaitu jenis jantan dan betina dari semua jenis binatang (yaitu sejodoh) jantan dan betina. Lafal itsnain ini berkedudukan menjadi maf'ul atau objek. Dan disebutkan di dalam kisah Nabi Nuh, bahwasanya Allah swt. mengumpulkan kepada Nabi Nuh semua binatang buas dan semua jenis unggas atau burung. Kemudian Nabi Nuh a.s. memukulkan tangannya kepada setiap jenis binatang itu; maka tangan kanannya mengenai jenis jantan sedangkan tangan kirinya mengenai jenis betina, lalu ia memuatkannya ke dalam perahu (dan keluargamu) yaitu istri dan anak-anaknya (kecuali orang yang telah terdahulu ketetapan terhadapnya) di antara keluargamu yang sudah dipastikan akan binasa, yaitu anaknya yang bernama Kan'an dan istrinya. Sedangkan Sam, Ham, dan Yafits dibawa oleh Nabi Nuh ke dalam bahtera berikut istri-istri mereka yang berjumlah tiga orang (dan muatkan pula orang-orang yang beriman." Dan tidak beriman terhadap Nabi Nuh itu melainkan sedikit). Dikatakan, bahwa jumlah mereka yang beriman itu hanya ada enam orang lelaki dan istri-istri mereka. Menurut pendapat yang lain dikatakan, bahwa jumlah orang-orang yang termuat di dalam bahtera itu ada delapan puluh orang; separuh di antara mereka terdiri dari kaum laki-laki sedangkan separuh yang lainnya terdiri dari kaum wanita.\qt@no{40}}%
\qt@newcmd\qurantrans@id@mdxiv{%
(Dan ia berkata) yakni Nabi Nuh ("Naiklah kamu sekalian ke dalamnya dengan menyebut nama Allah di waktu berlayar dan berlabuhnya.") artinya sewaktu berlayar dan sewaktu berlabuh. (Sesungguhnya Rabbku benar-benar Maha Pengampun lagi Maha Penyayang) di mana Dia tidak membinasakan kami.\qt@no{41}}%
\qt@newcmd\qurantrans@id@mdxv{%
(Dan bahtera itu berlayar membawa mereka dalam gelombang laksana gunung) menggambarkan tentang tinggi dan besarnya gelombang. (Dan Nuh memanggil anaknya) yaitu Kan`an (sedangkan anaknya itu berada di tempat yang jauh) dari bahtera ("Hai anakku! Naiklah bersama kami dan janganlah kamu berada bersama orang-orang yang kafir.")\qt@no{42}}%
\qt@newcmd\qurantrans@id@mdxvi{%
(Anaknya menjawab, ``Aku akan mencari perlindungan ke gunung yang dapat memelihara diriku) yang dapat menyelamatkan diriku (dari air bah ini." Nuh berkata, ``Tidak ada yang melindungi hari ini dari azab Allah) dari siksaan-Nya (selain) kecuali hanya (Zat Yang Maha Penyayang.") yaitu Allah sendiri, hanya Dialah yang dapat menolong. Selanjutnya Allah berfirman mengisahkan kelanjutannya. (Dan gelombang menjadi penghalang antara keduanya, maka jadilah anak itu termasuk orang-orang yang ditenggelamkan.)\qt@no{43}}%
\qt@newcmd\qurantrans@id@mdxvii{%
(Dan difirmankan, ``Hai bumi! Telanlah airmu) yang bersumberkan darimu, maka langsung bumi menelan airnya akan tetapi yang turun dari langit masih tetap, sehingga jadilah sungai-sungai dan laut-laut (dan hai hujan berhentilah.") hentikanlah air hujanmu, maka seketika itu juga hujan berhenti (dan surutlah) berkuranglah (air itu hingga selesailah perintah Allah) kaum Nabi Nuh telah selesai dibinasakan (dan bahtera itu berlabuh) bahtera Nabi Nuh berhenti (di atas bukit Al-Judi) nama sebuah bukit yang terletak di suatu pulau dekat dengan negeri Maushul (dan dikatakan, ``Binasalah) hancurlah (orang-orang yang lalim.") yaitu orang-orang yang kafir.\qt@no{44}}%
\qt@newcmd\qurantrans@id@mdxviii{%
(Dan Nuh berseru kepada Rabbnya seraya berkata, ``Ya Rabbku! Sesungguhnya anakku) yaitu Kan'an (termasuk keluargaku) sedangkan Engkau telah menjanjikan kepadaku akan menyelamatkan mereka (dan sesungguhnya janji Engkau itulah yang benar) janji yang tidak akan diingkari. (Dan Engkau adalah hakim yang seadil-adilnya.") paling mengetahui masalah kehakiman dan paling adil.\qt@no{45}}%
\qt@newcmd\qurantrans@id@mdxix{%
(Dan berfirmanlah) Allah swt. ("Hai Nuh! Sesungguhnya dia bukan termasuk keluargamu) yang dijanjikan akan diselamatkan, atau dia bukan termasuk pemeluk agamamu (sesungguhnya) permintaanmu kepada-Ku yang memohon supaya dia diselamatkan (perbuatan yang tidak baik) karena sesungguhnya dia adalah orang kafir, dan tidak ada keselamatan bagi orang-orang kafir. Menurut qiraat lain dibaca `amila sedangkan lafal ghairu dibaca ghaira dan dhamir kembali kepada anaknya Nabi Nuh, artinya sesungguhnya dia telah mengerjakan perbuatan yang tidak baik (sebab itu janganlah kamu memohon kepada-Ku) dapat dibaca tas-alanna dan tas-alan (sesuatu yang kamu tidak mengetahuinya) yaitu memohon supaya anakmu diselamatkan. (Sesungguhnya Aku memperingatkan kepadamu supaya kamu jangan termasuk orang-orang yang tidak berpengetahuan") yang menyebabkan kamu meminta kepada-Ku apa-apa yang kamu tidak ketahui hakikatnya.\qt@no{46}}%
\qt@newcmd\qurantrans@id@mdxx{%
(Nuh berkata, ``Ya Rabbku! Sesungguhnya aku berlindung kepada Engkau) daripada perbuatan (memohon kepada Engkau sesuatu yang aku tiada mengetahui hakikatnya. Dan sekiranya Engkau tidak memberi ampun kepadaku) atas apa yang aku telah terlanjur melakukannya (dan tidak menaruh belas kasihan kepadaku, niscaya aku akan termasuk orang-orang yang merugi")\qt@no{47}}%
\qt@newcmd\qurantrans@id@mdxxi{%
(Difirmankan, ``Hai Nuh! Turunlah) turunlah dari bahtera (dengan selamat) dengan selamat atau dengan hormat (dari Kami dan penuh keberkahan) penuh kebaikan (atasmu dan atas umat-umat yang mukmin dan orang-orang yang bersamamu") di dalam bahtera, yang dimaksud adalah anak cucu dan keturunannya, yaitu orang-orang yang beriman (Dan ada pula umat-umat) dibaca rafa` yaitu umamun, makna yang dimaksud adalah umat-umat yang bersamamu (yang Kami beri kesenangan pada mereka) di dunia (kemudian mereka akan ditimpa azab yang pedih dari Kami) di akhirat kelak; mereka adalah orang-orang kafir.\qt@no{48}}%
\qt@newcmd\qurantrans@id@mdxxii{%
(Itu adalah) ayat-ayat yang mengandung kisah Nabi Nuh (di antara berita-berita penting yang gaib) berita-berita yang belum engkau ketahui (yang Kami wahyukan kepadamu) hai Muhammad (tidak pernah kamu mengetahuinya dan tidak pula kaummu sebelum ini) sebelum diturunkannya Alquran ini. (Maka bersabarlah) di dalam menyampaikan risalah dan menghadapi perlakuan kaummu yang menyakitkan itu, sebagaimana Nabi Nuh bersabar (sesungguhnya kesudahan yang baik) yang terpuji (adalah bagi orang-orang yang bertakwa).\qt@no{49}}%
\qt@newcmd\qurantrans@id@mdxxiii{%
(Dan) Kami utuskan (kepada kaum Ad saudara mereka) dari kabilah mereka sendiri (Hud. Ia berkata, ``Hai kaumku! Sembahlah Allah) artinya esakanlah Allah (sekali-kali tidak ada bagi kalian) huruf min di sini zaidah (Tuhan selain Dia, tiada lain) (kalian) yang dimaksud adalah penyembahan kalian terhadap berhala-berhala itu (hanyalah mengada-adakan saja) kalian berdusta terhadap Allah.\qt@no{50}}%
\qt@newcmd\qurantrans@id@mdxxiv{%
(Hai kaumku! Aku tidak meminta kepada kalian atas hal ini) yakni menganjurkan mentauhidkan Allah (upah. Tiada lain) (upahku hanyalah dari Allah yang telah menciptakanku) yang telah menjadikan aku (Maka tidakkah kalian memikirkannya?")\qt@no{51}}%
\qt@newcmd\qurantrans@id@mdxxv{%
(Dan dia berkata, ``Hai kaumku! Mohonlah ampun kepada Rabb kalian) dari kemusyrikan (lalu bertobatlah kalian) kembalilah kalian (kepada-Nya) dengan menjalankan ketaatan (niscaya Dia menurunkan hujan) air hujan yang sebelumnya mereka kekeringan (kepada kalian dengan derasnya) sangat deras (dan Dia akan menambahkan kekuatan kepada) bersama dengan (kekuatanmu) yaitu berupa harta benda dan anak-anak (dan janganlah kalian berpaling dengan berbuat dosa.") yakni berbuat kemusyrikan.\qt@no{52}}%
\qt@newcmd\qurantrans@id@mdxxvi{%
(Kaum Ad berkata, ``Hai Hud! Kamu tidak mendatangkan kepada kami suatu bukti yang nyata) yang menunjukkan kebenaran perkataanmu itu (dan kami sekali-kali tidak akan meninggalkan sembahan-sembahan kami karena perkataanmu) hanya karena ucapanmu itu (dan kami sekali-kali tidak akan mempercayai kamu).\qt@no{53}}%
\qt@newcmd\qurantrans@id@mdxxvii{%
(Tidaklah) tiadalah (kami mengatakan) perihal dirimu (melainkan, akan menimpamu) kamu akan tertimpa (penyakit gila karena sebagian sembahan kami") karena sesembahan kami itu akan menyerapah kamu hingga menjadi orang gila, sebab kamu mencacinya, setelah itu kamu akan mengigau sendirian. (Hud menjawab, ``Sesungguhnya aku bersaksi kepada Allah) atas diriku sendiri (dan saksikanlah olehmu sekalian, bahwa sesungguhnya aku berlepas diri dari apa yang kalian persekutukan) itu terhadap Allah.\qt@no{54}}%
\qt@newcmd\qurantrans@id@mdxxviii{%
(Dari selain-Nya, sebab itu jalankanlah tipu daya terhadapku) lancarkanlah tipu daya untuk membinasakan diriku (oleh kalian semuanya) oleh kalian dan berhala-berhala sesembahan kalian itu (dan janganlah kalian memberi tangguh kepadaku) janganlah kalian menangguh-nangguhkannya.\qt@no{55}}%
\qt@newcmd\qurantrans@id@mdxxix{%
(Sesungguhnya aku bertawakal kepada Allah, Rabbku dan Rabb kalian. Tidak ada) huruf min di sini adalah zaidah (suatu binatang) makhluk yang melata di bumi (melainkan Dialah yang memegang ubun-ubunnya) artinya, Dialah yang menguasai dan yang memaksakannya, maka tidak dapat memberikan manfaat dan tidak pula mudarat melainkan seizin-Nya. Dalam ayat ini disebutkan lafal an-naashiyah secara khusus, yang artinya ubun-ubun, karena seseorang yang dipegang ubun-ubunnya berarti sangat hina. Ini menggambarkan hinanya makhluk dibandingkan dengan Allah. (Sesungguhnya Rabbku di atas jalan yang lurus) yaitu jalan kebenaran dan keadilan.\qt@no{56}}%
\qt@newcmd\qurantrans@id@mdxxx{%
(Jika kalian berpaling) asalnya ialah tatawallau, kemudian salah satu dari huruf ta dibuang sehingga jadilah tawallau, artinya berpaling (maka sesungguhnya aku telah menyampaikan kepada kalian apa/amanat yang aku diutus untuk menyampaikannya kepada kalian. Dan Rabbku akan mengganti kalian dengan kaum yang lain dari kalian; dan kalian tidak dapat membuat mudarat kepada-Nya sedikit pun) oleh sebab kemusyrikan kalian. (Sesungguhnya Rabbku adalah Maha Pemelihara segala sesuatu") yang mengawasinya.\qt@no{57}}%
\qt@newcmd\qurantrans@id@mdxxxi{%
(Dan tatkala datang perintah Kami) azab Kami (Kami selamatkan Hud dan orang-orang yang beriman bersama dia dengan rahmat) yakni petunjuk (dari Kami; dan Kami selamatkan pula mereka dari azab yang berat) dari siksaan yang keras di akhirat.\qt@no{58}}%
\qt@newcmd\qurantrans@id@mdxxxii{%
(Dan itulah kisah kaum Ad) ini mengisyaratkan kepada peninggalan-peninggalan mereka. Makna yang dimaksud ialah berjalanlah kalian di muka bumi ini dan lihatlah bekas-bekas peninggalan mereka. Kemudian Allah swt. menggambarkan keadaan mereka, untuk itu Dia berfirman: (Mereka mengingkari tanda-tanda kekuasaan Rabb mereka dan mendurhakai rasul-rasul Allah) ungkapan di sini memakai bentuk jamak, dimaksud karena orang yang mendurhakai seorang rasul berarti sama saja dengan mendurhakai semua rasul. Karena pada apa yang didatangkan oleh para rasul itu hakikatnya bersumberkan dari asal yang sama, yaitu dari ajaran tauhid (dan mereka menuruti) artinya orang-orang yang rendah (perintah semua penguasa yang sewenang-wenang lagi menentang kebenaran) yakni selalu menentang perkara yang hak, yang dimaksud adalah para pemimpinnya.\qt@no{59}}%
\qt@newcmd\qurantrans@id@mdxxxiii{%
(Dan mereka selalu diikuti dengan kutukan di dunia ini) dari manusia (dan begitu pula di hari kiamat) mereka akan dikutuk di hadapan makhluk semuanya. (Ingatlah sesungguhnya kaum Ad itu kafir) mereka ingkar (terhadap Rabb mereka. Ingatlah, sesungguhnya amat jauh) dari rahmat Allah (bagi kaum Ad yaitu kaumnya Hud).\qt@no{60}}%
\qt@newcmd\qurantrans@id@mdxxxiv{%
(Dan) Kami utus (kepada Tsamud saudara mereka) yang satu kabilah (Saleh. Saleh berkata, ``Hai kaumku! Sembahlah Allah) artinya esakanlah Dia (sekali-kali tidak ada bagi kalian Tuhan selain Dia. Dia telah menciptakan kalian) Dialah yang mula-mula menciptakan kalian (dari bumi) yaitu dengan menciptakan bapak moyang kalian, Adam, dari tanah (dan menjadikan kalian pemakmurnya) Dia menjadikan kalian sebagai para penghuni bumi (karena itu mohonlah ampunan-Nya) dari kemusyrikan (kemudian bertobatlah) kembali kalian (kepada-Nya) dengan menjalankan ketaatan. (Sesungguhnya Rabbku amat dekat) kepada makhluk-Nya melalui pengetahuan-Nya (lagi memperkenankan.") doa orang yang meminta kepada-Nya.\qt@no{61}}%
\qt@newcmd\qurantrans@id@mdxxxv{%
(Kaum Tsamud berkata, ``Hai Saleh! Sesungguhnya engkau adalah seorang di antara kami yang kami harapkan) kami mengharapkan semoga engkau menjadi penghulu dan pemimpin kami (sebelum ini) sebelum apa yang kamu lakukan itu (apakah kamu melarang kami untuk menyembah apa yang disembah oleh bapak-bapak kami) yaitu berhala-berhala (dan sesungguhnya kami betul-betul dalam keraguan terhadap agama yang kamu serukan kepada kami) yaitu agama tauhid (lagi sangat gelisah.") maksudnya yang diserukannya itu amat meresahkan.\qt@no{62}}%
\qt@newcmd\qurantrans@id@mdxxxvi{%
(Saleh berkata, ``Hai kaumku! Bagaimana pikiran kalian jika aku mempunyai bukti) bukti yang jelas (dari Rabbku dan diberi-Nya aku rahmat daripada-Nya?) kenabian (Maka siapakah yang akan menolong aku) yang dapat memelihara diriku (dari Allah) maksudnya dari azab-Nya (jika aku mendurhakai-Nya. Sebab itu kalian tidak menambah apa pun kepadaku) dengan perintah kalian yang menyuruhku untuk melakukan hal tersebut (selain daripada kerugian.") penyesatan.\qt@no{63}}%
\qt@newcmd\qurantrans@id@mdxxxvii{%
("Hai kaumku! Inilah unta betina dari Allah sebagai mukjizat yang menunjukkan kebenaran untuk kalian) lafal aayatan berkedudukan menjadi hal atau kata keterangan sedangkan yang menjadi amilnya adalah isim isyarah atau lafal haadzihii tadi (sebab itu biarkanlah dia makan di bumi Allah, dan janganlah kalian mengganggunya dengan gangguan apa pun) seperti menyembelihnya (yang akan menyebabkan kalian ditimpa azab yang dekat.") jika kalian menyembelihnya.\qt@no{64}}%
\qt@newcmd\qurantrans@id@mdxxxviii{%
(Maka mereka menyembelihnya) unta betina itu disembelih oleh seseorang yang kuat atas perintah mereka (maka ia berkata) Nabi Saleh ("Bersuka-rialah kalian) bersenang-senanglah kalian (di rumah kalian selama tiga hari) kemudian kalian akan binasa (itu adalah janji yang tidak dapat didustakan.") janji yang tidak diingkari lagi.\qt@no{65}}%
\qt@newcmd\qurantrans@id@mdxxxix{%
(Maka tatkala datang perintah Kami) yang memerintahkan supaya mereka dibinasakan (Kami selamatkan Saleh beserta orang-orang yang beriman bersama dia) jumlah mereka ada empat ribu orang (dengan rahmat dari Kami dan) Kami selamatkan pula mereka (dari kehinaan di hari itu) kalau dibaca yaumi-idzin dianggap sebagai isim yang mu`rab dan kalau dibaca yaumaidzin dianggap sebagai isim yang mabni karena diidhafatkan kepada isim yang mabni pula; demikianlah menurut pendapat kebanyakan ahli nahwu. (Sesungguhnya Rabbmu Dialah Yang Maha Kuasa lagi Maha Perkasa) Maha Menang.\qt@no{66}}%
\qt@newcmd\qurantrans@id@mdxl{%
(Dan satu suara yang keras yang mengguntur menimpa orang-orang yang lalim itu lalu mereka mati bergelimpangan di tempat tinggal mereka) dalam keadaan bersimpuh pada lutut mereka padahal mereka telah mati semuanya.\qt@no{67}}%
\qt@newcmd\qurantrans@id@mdxli{%
(Seolah-olah) lafal ka-an adalah takhfif daripada ka-anna sedangkan isimnya tidak disebutkan, kepanjangannya adalah ka-annahum, artinya seolah-olah mereka (belum pernah berdiam) belum pernah tinggal (di tempat itu) di dalam rumah mereka. (Ingatlah, sesungguhnya kaum Tsamud mengingkari Tuhan mereka. Ingatlah, kebinasaanlah bagi kaum Tsamud) lafal tsamuud dapat ditanwinkan sehingga menjadi tsamuudan dan dapat pula dibaca tanpa memakai tanwin sehingga menjadi tsamuuda. Makna yang dimaksud ialah kabilahnya.\qt@no{68}}%
\qt@newcmd\qurantrans@id@mdxlii{%
(Dan sesungguhnya utusan-utusan Kami telah datang kepada Ibrahim dengan membaca kabar gembira) yaitu akan diberi anak bernama Ishak dan menyusul Yakub anak Ishak sesudah itu. (mereka mengucapkan, ``Selamat.") lafal salaaman menjadi mashdar (Ibrahim menjawab, ``Selamatlah.") atas kalian (Maka tidak lama kemudian Ibrahim menyuguhkan daging anak sapi yang dipanggang) daging panggang anak sapi.\qt@no{69}}%
\qt@newcmd\qurantrans@id@mdxliii{%
(Maka tatkala dilihatnya tangan mereka tidak menjamahnya, Ibrahim memandang aneh perbuatan mereka) merasa heran dengan kelakuan mereka itu (dan mulai timbul) memendam rasa di dalam hati (rasa takut terhadap mereka) ketakutan. (Malaikat itu berkata, ``Jangan kamu takut, sesungguhnya kami adalah malaikat-malaikat yang diutus kepada kaum Luth.") untuk membinasakan mereka.\qt@no{70}}%
\qt@newcmd\qurantrans@id@mdxliv{%
(Dan istrinya) yakni istri Nabi Ibrahim, yaitu Siti Sarah (berdiri) melayani mereka (lalu dia tersenyum) merasa gembira dengan akan dibinasakannya kaum Luth (maka Kami sampaikan kepadanya berita gembira tentang kelahiran Ishak dan menyusul sesudah) (Ishak Yakub) yaitu anak Nabi Ishak yang sempat melihat Nabi Ibrahim.\qt@no{71}}%
\qt@newcmd\qurantrans@id@mdxlv{%
(Istrinya berkata, ``Sungguh mengherankan) lafal wailataa ini merupakan kalimat yang biasa diucapkan di kala seseorang melihat perkara yang besar. Huruf ya yang ada padanya merupakan pergantian dari huruf alif (apakah aku akan melahirkan anak padahal aku adalah seorang perempuan tua) aku berumur sembilan puluh sembilan tahun (dan ini suamiku pun dalam keadaan yang sudah tua pula) Nabi Ibrahim pada saat itu berumur seratus atau seratus dua puluh tahun. Lafal syaikhan dinashabkan karena menjadi hal, sedangkan amilnya adalah isim isyarah yaitu lafal haadzaa tadi. (Sesungguhnya ini benar-benar suatu yang aneh") kedua pasangan yang sama-sama telah tua dapat mempunyai anak.\qt@no{72}}%
\qt@newcmd\qurantrans@id@mdxlvi{%
(Para malaikat itu berkata, ``Apakah kamu merasa heran tentang perintah Allah) yakni kekuasaan-Nya (itu adalah rahmat Allah dan keberkatan-Nya dicurahkan atas kalian) hai (ahlul bait) keluarga Nabi Ibrahim. (Sesungguhnya Allah Maha Terpuji) sangat terpuji (lagi Maha Pemurah") Maha Pengasih.\qt@no{73}}%
\qt@newcmd\qurantrans@id@mdxlvii{%
(Maka tatkala rasa takut hilang dari Ibrahim) perasaan takut telah lenyap dari hatinya (dan berita gembira telah datang kepadanya) yaitu memperoleh anak, mulailah (dia pun bersoal jawab dengan Kami) yakni dengan malaikat-malaikat utusan Kami (tentang) mengenai perihal (kaum Luth).\qt@no{74}}%
\qt@newcmd\qurantrans@id@mdxlviii{%
(Sesungguhnya Ibrahim itu benar-benar penyantun) sangat sabar (lagi penghiba dan suka kembali kepada Allah) banyak istighfarnya atau ia banyak mengucapkan kalimat innaa lillaahi wa innaa ilaihi raaji`uuna. Maka Nabi Ibrahim berkata kepada para malaikat itu, ``Apakah kalian akan membinasakan suatu kota yang di dalamnya terdapat tiga ratus orang beriman?" Para malaikat menjawab, ``Tidak." Ia kembali bertanya, ``Apakah kalian akan membinasakan suatu kota yang di dalamnya terdapat dua ratus orang yang beriman?" Para malaikat menjawab, ``Tidak." Ia bertanya lagi, ``Apakah kalian akan membinasakan suatu kota yang di dalamnya terdapat empat puluh orang yang beriman." Para malaikat menjawab, ``Tidak." Ia kembali bertanya, ``Apakah kalian akan membinasakan suatu kota yang di dalamnya terdapat empat belas orang yang beriman?" Mereka menjawab, ``Tidak." Nabi Ibrahim kembali bertanya, ``Bagaimana pendapat kalian jika di dalam sebuah kota terdapat hanya seorang yang beriman?" Mereka menjawab, ``Tidak pula." Maka Nabi Ibrahim berkata kepada mereka, ``Sesungguhnya di dalam kota tersebut terdapat Nabi Luth." Mereka menjawab, ``Kami lebih mengetahui tentang orang-orang beriman yang terdapat di dalamnya\qt@no{75}}%
\qt@newcmd\qurantrans@id@mdxlix{%
Maka tatkala Nabi Ibrahim berkepanjangan di dalam bertanya jawab dengan mereka, lalu mereka mengatakan: ("Hai Ibrahim! Tinggalkanlah soal jawab ini) perbantahan ini (sesungguhnya telah datang ketetapan Rabbmu) untuk membinasakan mereka (dan sesungguhnya mereka itu akan didatangi azab yang tidak dapat ditolak.")\qt@no{76}}%
\qt@newcmd\qurantrans@id@mdl{%
(Dan tatkala datang utusan-utusan Kami itu kepada Luth, dia merasa susah) merasa repot dengan kedatangan mereka itu (dan merasa sempit dadanya karena kedatangan mereka) mereka datang dalam rupa yang tampan menyamar sebagai tamu-tamu. Hal inilah yang membuat Nabi Luth merasa takut terhadap kaumnya yang tentunya akan berlaku tidak senonoh terhadap tamu-tamunya ini (dan dia berkata, ``Ini adalah hari yang amat berat.") hari yang sangat keras.\qt@no{77}}%
\qt@newcmd\qurantrans@id@mdli{%
(Datanglah kepadanya kaumnya) ketika mereka mengetahui tentang tamu-tamunya itu (dengan bergegas-gegas) dengan segera (menuju kepadanya. Dan sejak dahulu) sebelum kedatangan para tetamu itu (mereka selalu mengerjakan perbuatan-perbuatan keji) yaitu menyetubuhi anus laki-laki. (Ia pernah berkata,) yakni Nabi Luth ("Hai kaumku! Inilah putri-putriku) maka kawinilah mereka (mereka lebih suci bagi kalian, maka bertakwalah kepada Allah dan janganlah kalian membuat malu) mempermalukan diriku (terhadap tamuku ini) tamu-tamu ini. (Tidak adakah di antara kalian seorang yang berakal?") yang memerintahkan kalian berbuat kebajikan dan melarang kalian melakukan perbuatan yang mungkar.\qt@no{78}}%
\qt@newcmd\qurantrans@id@mdlii{%
(Mereka menjawab, ``Sesungguhnya kamu telah mengetahui bahwa kami tak mempunyai keinginan terhadap putri-putrimu itu) kami tidak membutuhkannya (dan sesungguhnya kamu tentu mengetahui apa yang sekiranya kami kehendaki.") yaitu suka menyetubuhi anus laki-laki.\qt@no{79}}%
\qt@newcmd\qurantrans@id@mdliii{%
(Luth berkata, ``Seandainya aku mempunyai kekuatan untuk menolak kalian) mempunyai kemampuan untuk menolak keinginan kalian (atau kalau aku dapat berlindung kepada keluarga yang kuat") yakni keluarga yang mau menolongku, tentu aku akan menghajar kalian atas kekurangajaran kalian itu. Maka tatkala para malaikat itu melihat hal tersebut, lalu mereka mengatakan:\qt@no{80}}%
\qt@newcmd\qurantrans@id@mdliv{%
(Para utusan itu berkata, ``Hai Luth! Sesungguhnya kami adalah utusan-utusan Rabbmu, sekali-kali mereka tidak akan dapat mengganggu kamu) dengan berlaku jahat terhadap dirimu (sebab itu bawalah pergi keluarga dan pengikut-pengikut kamu di akhir) pada bagian yang terakhir dari (malam dan janganlah ada seorang pun di antara kalian yang tertinggal) supaya ia tidak melihat kengerian azab yang menimpa mereka (kecuali istrimu) dengan dibaca rafa`, yaitu imra-atuka, berkedudukan menjadi badal dari lafal ahadin. Menurut qiraat lain dibaca nashab, yaitu imra-ataka, berkedudukan menjadi istitsna dari lafal al-ahl. Artinya janganlah engkau membawa pergi dia. (Sesungguhnya dia akan ditimpa azab yang menimpa mereka) menurut suatu pendapat dikatakan bahwa Nabi Luth tidak membawa istrinya pergi. Akan tetapi menurut pendapat yang lain dikatakan bahwa Nabi Luth membawanya pergi. Hanya saja ia menoleh ke belakang seraya mengatakan, 'Aduh kaumku!' Lalu ia ditimpa oleh batu besar sehingga matilah dia." Nabi Luth bertanya kepada utusan tentang waktu pembinasaan kaumnya, maka para utusan itu berkata. ("Sesungguhnya saat jatuhnya azab kepada mereka ialah di waktu subuh) Nabi Luth meminta, 'Aku minta supaya lebih disegerakan lagi.' Mereka menjawab ('Bukankah subuh itu sudah dekat?'")\qt@no{81}}%
\qt@newcmd\qurantrans@id@mdlv{%
(Maka tatkala datang perintah Kami) untuk membinasakan mereka (Kami jadikan bagian atas) dari negeri kaum Luth (ke bawah) artinya malaikat Jibril mengangkat negeri mereka ke atas kemudian menjatuhkannya ke bumi dalam keadaan terbalik (dan Kami hujani mereka dengan batu dari tanah yang terbakar) yaitu lumpur yang panas membara (dengan bertubi-tubi) secara terus-menerus.\qt@no{82}}%
\qt@newcmd\qurantrans@id@mdlvi{%
(Yang diberi tanda) telah ditandai masing-masing tanah yang membara itu dengan nama orang yang dikenainya (oleh Rabbmu) menjadi zharaf bagi lafal mu`allamatan (dan hal itu) makna yang diisyaratkan di sini adalah azab yang berupa batu itu atau negeri mereka (dari orang-orang yang lalim) artinya penduduk Mekah (tidak jauh).\qt@no{83}}%
\qt@newcmd\qurantrans@id@mdlvii{%
(Dan) Kami utus (kepada penduduk Madyan saudara mereka Syuaib. Ia berkata, ``Hai kaumku! Sembahlah Allah) tauhidkanlah Dia (sekali-kali tiada Tuhan bagi kalian selain Dia. Dan janganlah kalian kurangi takaran dan timbangan, sesungguhnya aku melihat kalian dalam keadaan yang baik) kalian hidup dalam keadaan yang menyenangkan sehingga kalian tidak perlu melakukan pengurangan takaran dan timbangan (dan sesungguhnya aku) (khawatir terhadap kalian) jika kalian tidak mau beriman (akan azab hari yang membinasakan") hari yang meliputi kalian dengan kebinasaan. Lafal yaum disifati dengan lafal muhith mengandung pengertian majaz, karena terjadinya azab itu pada hari tersebut.\qt@no{84}}%
\qt@newcmd\qurantrans@id@mdlviii{%
(Dan Syuaib berkata, ``Hai kaumku!) (Cukupkanlah takaran dan timbungan) sempurnakanlah keduanya (dengan adil) secara tetap (dan janganlah kalian merugikan manusia terhadap hak-hak mereka) janganlah kalian mengurangi hak-hak mereka sedikit pun (dan janganlah kalian membuat kejahatan di muka bumi dengan membuat kerusakan) dengan melakukan pembunuhan dan kejahatan lainnya. Lafal ta'tsau berasal dari fi'il madhi `atsiya, artinya mengadakan kerusakan. Sedangkan lafal mufsidiina berkedudukan menjadi hal atau keterangan yang mengukuhkan makna amilnya yaitu ta'tsau.\qt@no{85}}%
\qt@newcmd\qurantrans@id@mdlix{%
(Sisa keuntungan dari Allah) yaitu rezeki yang masih tersisa bagi kalian sesudah kalian mencukupkan takaran dan timbangan (adalah lebih baik bagi kalian) daripada perbuatan mengurangi takaran dan timbangan (jika kalian orang-orang yang beriman. Dan aku bukanlah seorang penjaga atas diri kalian.") aku bukanlah pengawas yang membalas kalian terhadap amal perbuatan kalian, akan tetapi sesungguhnya aku adalah orang yang diutus bagi kalian sebagai pembawa peringatan.\qt@no{86}}%
\qt@newcmd\qurantrans@id@mdlx{%
(Mereka berkata) kepada Nabi Syuaib dengan nada mengejek ("Hai Syuaib! Apakah salatmu menyuruhmu) membebankan kepadamu (agar kami meninggalkan apa yang disembah oleh bapak-bapak kami) yaitu berhala-berhala (atau) melarang kami (mencegah kami melakukan apa yang kami kehendaki tentang harta kami) maksudnya hal ini tidak benar sama sekali, tidak ada seorang pun yang menyeru kepada kebaikan. (Sesungguhnya kamu adalah orang yang sangat penyantun lagi berakal.") mereka mengatakan demikian dengan nada mengejek dan mencemoohkan Nabi Syuaib.\qt@no{87}}%
\qt@newcmd\qurantrans@id@mdlxi{%
(Syuaib berkata, ``Bagaimana pikiran kalian jika aku mempunyai bukti yang nyata dari Rabbku dan dianugerahi-Nya aku daripada-Nya rezeki yang baik) rezeki yang halal lalu apakah patut jika aku mencampurinya dengan barang yang haram hasil mengurangi takaran dan timbangan (Dan aku tidak berkehendak menyalahi kalian) melakukan (apa yang aku larang kalian daripadanya) kemudian aku mengerjakannya. (Aku tidak) aku tiada (bermaksud kecuali mendatangkan perbaikan) bagi kalian supaya menegakkan keadilan (selama aku masih berkesanggupan. Dan tidak ada taufik bagiku) berkemampuan untuk melakukan hal tersebut dan perkara ketaatan lainnya (melainkan dengan pertolongan Allah. Hanya kepada Allah aku bertawakal dan hanya kepada-Nyalah aku kembali.") mengembalikan semua perkara.\qt@no{88}}%
\qt@newcmd\qurantrans@id@mdlxii{%
("Hai kaumku! Janganlah membuat kalian jahat) menyebabkan kalian melakukannya (adanya pertentangan dengan aku) pertentangan antara aku dan kalian. Lafal syiqaaqii menjadi fa'il atau subjek daripada fi'il yajrimannakum, dan lafal qaum yang terkandung di dalamnya berkedudukan menjadi maf'ul awwal atau objek pertama, sedangkan maf'ul yang kedua ialah (hingga kalian ditimpa azab seperti yang menimpa kaum Nuh atau kaum Hud atau kaum Saleh) ditimpa azab yang sama (sedangkan kaum Luth tidaklah) artinya tempat tinggal kaum Luth atau waktu mereka dibinasakan (jauh dari kalian) maka ambillah hal itu sebagai pelajaran buat kalian.\qt@no{89}}%
\qt@newcmd\qurantrans@id@mdlxiii{%
(Dan mohonlah ampun kepada Rabb kalian, kemudian bertobatlah kepada-Nya. Sesungguhnya Rabbku Maha Penyayang) terhadap orang-orang yang beriman (lagi Maha Pengasih.") sangat mencintai orang-orang yang beriman.\qt@no{90}}%
\qt@newcmd\qurantrans@id@mdlxiv{%
(Mereka berkata) dengan nada yang menunjukkan kurang perhatian mereka terhadap perkataan Nabi Syuaib ("Hai Syuaib! Kami tidak mengerti) kurang memahami (banyak tentang apa yang kamu katakan itu dan sesungguhnya kami benar-benar melihat kamu seorang yang lemah di antara kami) maksudnya orang yang rendah (kalau tidaklah karena keluargamu) familimu (tentulah kami telah merajam kamu) dengan batu (sedangkan kamu pun bukanlah seorang yang berwibawa di sisi kami.") bukan orang-orang tidak pantas untuk dihukum rajam; dan sesungguhnya hanya keluargamu sajalah orang-orang yang berwibawa itu.\qt@no{91}}%
\qt@newcmd\qurantrans@id@mdlxv{%
(Syuaib menjawab, ``Hai kaumku! Apakah keluargaku lebih terhormat menurut pandangan kalian daripada Allah) oleh sebab itu lalu kalian tidak mau membunuhku demi mereka dan kalian tidak mau membiarkan aku demi karena Allah (sedangkan kalian menjadikan Dia) yakni kalian menganggap Allah (sebagai sesuatu yang terbuang di belakang kalian) terasing di belakang kalian tanpa kalian hiraukan Dia. (Sesungguhnya Rabbku meliputi apa yang kalian kerjakan.") Dia Maha Mengetahui kesemuanya; oleh karena itu kelak Dia akan membalas kalian.\qt@no{92}}%
\qt@newcmd\qurantrans@id@mdlxvi{%
(Dan dia berkata, ``Hai kaumku! Berbuatlah menurut kemampuan kalian) sesuai dengan keadaan kalian (sesungguhnya aku pun berbuat pula) sesuai dengan kedudukanku. (Kelak kalian akan mengetahui siapa) lafal man di sini adalah maushul yang berkedudukan menjadi maf'ul dari lafal ta'lamuuna (yang akan ditimpa azab yang menghinakannya dan siapa yang berdusta. Dan tunggulah) akibat daripada perbuatan kalian itu (sesungguhnya aku pun menunggu bersama kalian.") ikut mengawasinya.\qt@no{93}}%
\qt@newcmd\qurantrans@id@mdlxvii{%
(Dan tatkala datang perintah Kami) yang memerintahkan supaya mereka dibinasakan (Kami selamatkan Syuaib dan orang-orang yang beriman bersama-sama dengan dia sebagai rahmat dari Kami, dan orang-orang yang lalim dibinasakan oleh suatu suara yang mengguntur) malaikat Jibril mengeluarkan suara yang mengguntur terhadap mereka (lalu jadilah mereka mati bergelimpangan di tempat tinggalnya) mereka mati dalam keadaan bersimpuh.\qt@no{94}}%
\qt@newcmd\qurantrans@id@mdlxviii{%
(Seolah-olah) mereka; lafal ka-an adalah bentuk takhfif daripada lafal ka-anna (belum pernah tinggal di tempat tinggalnya itu, di tempat mereka bermukim. Ingatlah, kebinasaanlah bagi penduduk Madyan sebagaimana kaum Tsamud telah binasa).\qt@no{95}}%
\qt@newcmd\qurantrans@id@mdlxix{%
(Dan sesungguhnya Kami telah mengutus Musa dengan membawa tanda-tanda kekuasaan Kami dan mukjizat yang nyata) bukti yang jelas dan gamblang.\qt@no{96}}%
\qt@newcmd\qurantrans@id@mdlxx{%
(Kepada Firaun dan pemimpin-pemimpin kaumnya, tetapi mereka mengikuti perintah Firaun, padahal perintah Firaun sekali-kali bukanlah perintah yang benar) perintah yang lurus.\qt@no{97}}%
\qt@newcmd\qurantrans@id@mdlxxi{%
(Ia berjalan di muka) berada paling depan (kaumnya di hari kiamat) sehingga para pengikutnya mengikutinya sebagaimana mereka mengikutinya sewaktu hidup di dunia (lalu memasukkan mereka) menjerumuskan mereka (ke dalam neraka. Neraka itu seburuk-buruk tempat yang didatangi.)\qt@no{98}}%
\qt@newcmd\qurantrans@id@mdlxxii{%
(Dan mereka telah diikuti di dalam) dunia ini (oleh kutukan, dan begitu pula di hari kiamat) mereka dikutuk pula (seburuk-buruk pemberian) bantuan (adalah yang diberikan kepada mereka) kutukan yang diberikan kepada mereka.\qt@no{99}}%
\qt@newcmd\qurantrans@id@mdlxxiii{%
(Yang demikian itu) hal yang telah disebutkan tadi; lafal dzaalika berkedudukan menjadi mubtada sedangkan khabarnya ialah (adalah sebagian berita-berita negeri yang Kami ceritakan kepadamu) hai Muhammad (di antaranya) di antara negeri-negeri itu (ada yang masih kedapatan bekas-bekasnya) artinya penduduknya telah binasa tetapi bekas-bekasnya masih ada (dan) di antaranya ada pula (yang telah musnah) telah binasa berikut penduduknya, sehingga tidak ada bekasnya sama sekali. Perumpamaan mereka sama dengan tanaman yang dipanen dengan memakai sabit.\qt@no{100}}%
\qt@newcmd\qurantrans@id@mdlxxiv{%
(Dan Kami tidak menganiaya mereka) dengan membinasakan mereka tanpa dosa (tetapi merekalah yang menganiaya dirinya sendiri) dengan melakukan perbuatan syirik (karena itu tiadalah bermanfaat) tidak ada gunanya (kepada diri mereka, sesembahan-sesembahan yang mereka seru) yang mereka sembah (selain Allah). Huruf min di sini zaidah atau tidak mengandung makna (sedikit pun, di waktu perintah Rabbmu datang) yaitu azab-Nya. (Dan sesembahan-sesembahan itu tidaklah menambah kepada mereka) penyembahan mereka terhadapnya itu tidak dapat memberikan kepada mereka (selain kerugian belaka) yaitu kebinasaan.\qt@no{101}}%
\qt@newcmd\qurantrans@id@mdlxxv{%
(Dan begitulah) perumpamaan azab-Nya (azab Rabbmu apabila Dia mengazab penduduk negeri-negeri) yang dimaksud adalah penduduknya (yang berbuat lalim) dengan melakukan perbuatan-perbuatan dosa. Jelasnya tidak ada sesuatu pun yang dapat memberi manfaat kepada mereka bila azab Allah diturunkan kepada mereka. (Sesungguhnya azab-Nya itu adalah sangat pedih lagi keras) sehubungan dengan ayat ini Imam Bukhari dan Imam Muslim meriwayatkan sebuah hadis melalui Abu Musa Al-Asyari r.a. yang menceritakan bahwasanya Rasulullah saw. telah bersabda, ``Sesungguhnya Allah selalu mencatat semua perbuatan orang yang aniaya sehingga apabila Dia mengazabnya, maka ia tidak dapat luput daripada-Nya." Kemudian Rasulullah saw. membacakan firman-Nya, ``Dan begitulah azab Rabbmu.." (Q.S. Hud 102)\qt@no{102}}%
\qt@newcmd\qurantrans@id@mdlxxvi{%
(Sesungguhnya pada yang demikian itu) pada kisah-kisah yang telah disebutkan tadi (benar-benar terdapat pelajaran) bahan pelajaran (bagi orang-orang yang takut kepada azab akhirat. Hari itu) yakni hari kiamat itu (adalah suatu hari yang dikumpulkan menghadap kepada-Nya) pada hari itu (semua manusia, dan hari itu adalah suatu hari yang disaksikan) artinya hari itu disaksikan oleh semua makhluk.\qt@no{103}}%
\qt@newcmd\qurantrans@id@mdlxxvii{%
(Dan Kami tiadalah mengundur-undurkannya melainkan sampai waktu yang tertentu) waktu yang hanya diketahui oleh Allah.\qt@no{104}}%
\qt@newcmd\qurantrans@id@mdlxxviii{%
(Di kala datang hari itu) sudah tiba saatnya (tidak dapat berbicara) lafal takallama pada asalnya adalah tatakallama, kemudian salah satu huruf tanya dibuang sehingga jadilah ia takallama (seorang pun melainkan dengan izin-Nya) izin Allah swt. (maka di antara mereka) makhluk (ada yang celaka dan) yang lainnya (ada yang berbahagia) masing-masing telah dipastikan nasibnya di zaman azali.\qt@no{105}}%
\qt@newcmd\qurantrans@id@mdlxxix{%
(Adapun orang-orang yang celaka) menurut pengetahuan Allah swt. (maka tempatnya di dalam neraka, di dalamnya mereka mengeluarkan jeritan) suara yang sangat keras (dan rintihan) suara yang lemah.\qt@no{106}}%
\qt@newcmd\qurantrans@id@mdlxxx{%
(Mereka kekal di dalamnya selama ada langit dan bumi) artinya selama keberadaan langit dan bumi di alam dunia (kecuali) melainkan (jika Rabbmu menghendaki yang lain) yaitu perpanjangan waktu yang melebihi umur langit dan bumi. Makna yang dimaksud adalah tidak terbatas; mereka kekal di dalamnya untuk selama-lamanya. (Sesungguhnya Rabbmu Maha Pelaksana terhadap apa yang Dia kehendaki.)\qt@no{107}}%
\qt@newcmd\qurantrans@id@mdlxxxi{%
(Adapun orang-orang yang berbahagia) dapat dibaca sa`iduu atau su`iduu (maka tempatnya di dalam surga, mereka kekal di dalamnya selama ada langit dan bumi kecuali) melainkan (jika Rabbmu menghendaki) penafsirannya seperti apa yang telah dikemukakan pada ayat terdahulu yang hal ini ditunjukkan oleh firman selanjutnya, yaitu (sebagai karunia yang tiada putus-putusnya) tidak pernah terputus, dan penakwilan yang terdahulu itulah penakwilan yang paling kuat karena ia terlepas dari pengertian yang dipaksakan. Akhirnya hanya Allah jualah Yang Maha Mengetahui akan maksud-Nya.\qt@no{108}}%
\qt@newcmd\qurantrans@id@mdlxxxii{%
(Maka janganlah kamu) hai Muhammad (berada dalam keraguan) menaruh syak (tentang apa yang disembah oleh mereka) yaitu berhala-berhala sesembahan mereka karena sesungguhnya Kami akan mengazab mereka sebagaimana Kami mengazab orang-orang sebelum mereka yang melakukan perbuatan yang sama. Ayat ini dimaksud sebagai penghibur hati Nabi saw. (Mereka tidak menyembah melainkan sebagaimana nenek moyang mereka menyembah) artinya sama dengan penyembahan mereka (dahulu) dan sungguh dahulu Kami telah mengazab mereka. (Dan sesungguhnya Kami pasti akan menunaikan terhadap mereka) sama dengan apa yang telah Kami tunaikan kepada nenek moyang mereka (bagian mereka) pembalasan azab mereka (dengan tidak dikurangi sedikit pun) artinya secukup-cukupnya.\qt@no{109}}%
\qt@newcmd\qurantrans@id@mdlxxxiii{%
(Dan sesungguhnya Kami telah memberikan Kitab kepada Musa) yaitu kitab Taurat (lalu diperselisihkan tentang Kitab itu) ada yang membenarkan dan ada yang mendustakan, sama halnya dengan nasib yang menimpa Alquran (Dan seandainya tidak ada ketetapan yang terdahulu dari Rabbmu) dengan ditangguhkannya penghisaban dan pembalasan terhadap semua makhluk hingga hari kiamat nanti (niscaya telah ditetapkan peradilan di antara mereka) di dunia tentang apa yang mereka perselisihkan mengenai masalah Kitab itu. (Dan sesungguhnya mereka) yaitu orang-orang yang mendustakannya (dalam keraguan yang menggelisahkan terhadap Alquran) mereka ragu terhadapnya.\qt@no{110}}%
\qt@newcmd\qurantrans@id@mdlxxxiv{%
(Dan sesungguhnya) dapat dibaca wain dan wainna (kepada masing-masing) artinya kepada setiap makhluk (pasti) huruf maa adalah zaidah, sedangkan huruf lam adalah mauthiah atau pendahuluan bagi qasam atau sumpah, atau lam fariqah. Menurut qiraat yang lain lamaa dibaca tasydid sehingga menjadi lammaa yang maknanya sama dengan illaa sedangkan huruf in sebelumnya bermakna nafi (Rabbmu akan menyempurnakan dengan cukup amal perbuatan mereka) yakni pembalasannya. (Sesungguhnya Dia Maha Mengetahui apa yang mereka kerjakan) Dia Maha Mengetahui apa yang tersembunyi dan yang terlahirkan daripadanya.\qt@no{111}}%
\qt@newcmd\qurantrans@id@mdlxxxv{%
(Maka tetaplah kamu pada jalan yang benar) yaitu mengamalkan perintah Rabbmu dan menyembah kepada-Nya (sebagaimana diperintahkan kepadamu dan) juga tetaplah pada jalan yang benar (orang yang telah bertobat) yaitu orang yang telah beriman (beserta kamu dan janganlah kalian melampuai batas) melanggar batasan-batasan Allah. (Sesungguhnya Dia Maha Melihat apa yang kalian kerjakan) oleh sebab itu Dia membalas kalian.\qt@no{112}}%
\qt@newcmd\qurantrans@id@mdlxxxvi{%
(Dan janganlah kalian cenderung) condong hati (kepada orang-orang yang lalim) dengan menyukai mereka atau berbasa-basi terhadap mereka atau menyenangi perbuatan mereka (yang menyebabkan kalian disentuh) kalian terkena (api neraka dan sekali-kali kalian tiada mempunyai selain daripada Allah) selain-Nya (seorang penolong pun) yang dapat memelihara diri kalian dari azab-Nya. Huruf min di sini zaidah (kemudian kalian tidak akan diberi pertolongan) sehingga kalian tidak dapat selamat dari azab-Nya.\qt@no{113}}%
\qt@newcmd\qurantrans@id@mdlxxxvii{%
(Dan dirikanlah salat itu pada kedua tepi siang) yaitu di waktu pagi dan sore; yang dimaksud adalah salat subuh, zuhur dan asar (dan pada bagian permulaan) lafal zulafan adalah bentuk jamak dari kata tunggal zulfatan, artinya beberapa bagian (dari malam hari) yaitu salat isyak dan magrib. (Sesungguhnya perbuatan-perbuatan yang baik itu) seperti menjalankan salat lima waktu (menghapuskan perbuatan-perbuatan yang buruk) yakni dosa-dosa yang kecil. Ayat ini diturunkan berkenaan dengan seorang sahabat yang mencium perempuan bukan muhrimnya. Kemudian sahabat itu menceritakannya kepada Nabi saw. Maka Nabi saw. bersabda sampai dengan perkataannya berikut ini, ``... hal ini berlaku bagi umatku seluruhnya." Hadis ini diriwayatkan oleh Imam Bukhari dan Imam Muslim. (Itulah peringatan bagi orang-orang yang ingat) sebagai pelajaran bagi orang-orang yang mau mengambil pelajaran.\qt@no{114}}%
\qt@newcmd\qurantrans@id@mdlxxxviii{%
(Dan bersabarlah) hai Muhammad, di dalam menghadapi perlakuan kaummu yang menyakitkan itu; atau bersabarlah kamu di dalam menjalankan salat (karena sesungguhnya Allah tidak menyia-nyiakan pahala orang-orang yang berbuat kebaikan) bersabar di dalam menjalankan ketaatan.\qt@no{115}}%
\qt@newcmd\qurantrans@id@mdlxxxix{%
(Maka mengapa tidak ada) mengapa tidak (dari umat-umat) dari bangsa-bangsa terdahulu (sebelum kamu orang-orang yang mempunyai keutamaan) orang-orang yang teguh dalam beragama dan memiliki keutamaan (yang melarang daripada mengerjakan kerusakan di muka bumi) makna yang dimaksud adalah meniadakan, artinya hal tersebut jelas tidak akan terjadi di kalangan mereka (kecuali) hanya (sebagian kecil di antara orang-orang yang telah Kami selamatkan di antara mereka) yang melakukan nahi mungkar sehingga selamatlah mereka. Huruf min di sini mengandung makna bayan atau penjelasan (dan orang-orang yang lalim hanya mementingkan) mereka tidak mau melakukan nahi mungkar dan selalu senang dengan perbuatan kerusakan (kenikmatan yang mewah yang ada pada mereka) mereka hanya bersenang-senang saja (dan mereka adalah orang-orang yang berdosa).\qt@no{116}}%
\qt@newcmd\qurantrans@id@mdxc{%
(Dan Rabbmu sekali-kali tidak akan membinasakan negeri-negeri secara lalim) dengan sesuka-Nya terhadap negeri-negeri tersebut (sedangkan penduduknya orang-orang yang berbuat kebaikan) orang-orang yang beriman.\qt@no{117}}%
\qt@newcmd\qurantrans@id@mdxci{%
(Jikalau Rabbmu menghendaki, tentu Dia menjadikan manusia umat yang satu) pemeluk agama yang satu (tetapi mereka senantiasa berselisih pendapat) dalam masalah agama.\qt@no{118}}%
\qt@newcmd\qurantrans@id@mdxcii{%
(Kecuali orang-orang yang diberi rahmat oleh Rabbmu) artinya Allah telah menghendaki kebaikan bagi mereka sehingga mereka tidak berselisih pendapat tentangnya. (Dan untuk itulah Allah menciptakan mereka) sebagian di antara mereka ada yang suka berselisih dan sebagian yang lain ada yang diberi rahmat oleh-Nya sehingga mereka tidak berselisih mengenai agama. (Kalimat Rabbmu telah diputuskan) yaitu (sesungguhnya Aku akan memenuhi Jahanam dengan jin dan manusia semuanya.)\qt@no{119}}%
\qt@newcmd\qurantrans@id@mdxciii{%
(Dan setiap) lafal kullan ini dinashabkan dengan alamat naqsh sedangkan tanwinnya merupakan pergantian dari mudhaf ilaih, artinya semua kisah rasul-rasul yang diperlukan (Kami ceritakan kepadamu, yaitu kisah-kisah para rasul) lafal maa di sini menjadi badal daripada lafal kullan (yang dengannya Kami teguhkan) Kami tenangkan (hatimu) kalbumu (dan dalam surah ini telah datang kepadamu kebenaran) yang dimaksud adalah kisah-kisah para rasul ini atau ayat-ayat ini (serta pengajaran dan peringatan bagi orang-orang yang beriman) orang-orang yang beriman disebutkan di sini secara khusus, mengingat hanya merekalah yang dapat memanfaatkan adanya kisah-kisah atau ayat-ayat ini untuk mempertebal keimanan mereka, berbeda dengan orang-orang kafir.\qt@no{120}}%
\qt@newcmd\qurantrans@id@mdxciv{%
(Dan katakanlah kepada orang-orang yang tidak beriman, ``Berbuatlah menurut kemampuan kalian) sesuai dengan keadaan dan kondisi kalian (sesungguhnya Kami pun berbuat pula.") sesuai dengan keadaan Kami; ungkapan ini dimaksud sebagai ancaman buat orang-orang yang tidak beriman.\qt@no{121}}%
\qt@newcmd\qurantrans@id@mdxcv{%
("Dan tunggulah) akibat perbuatan kalian (sesungguhnya kami pun menunggu pula.") hal tersebut.\qt@no{122}}%
\qt@newcmd\qurantrans@id@mdxcvi{%
(Dan kepunyaan Allahlah apa yang gaib di langit dan di bumi) artinya Allah mengetahui semua yang samar atau yang gaib di dalam keduanya (dan kepada-Nyalah dikembalikan) jika dibaca yarji'u artinya sama dengan lafal ya'uudu yaitu kembali. Jika dibaca yurja'u maka artinya sama dengan lafal yuraddu yaitu dikembalikan (urusan-urusan semuanya) oleh sebab itu Dia menghukum orang-orang yang durhaka terhadap-Nya (maka sembahlah Dia) artinya esakanlah Dia (dan bertawakallah kepada-Nya) artinya percayalah kepada-Nya karena sesungguhnya Dialah yang mencukupimu. (Dan sekali-kali Rabbmu tidak lalai dari apa yang mereka kerjakan) sesungguhnya Dia sengaja menangguhkan mereka hanya sampai pada saatnya nanti. Menurut suatu qiraat lafal ya'maluuna dibaca ta`maluuna, artinya yang kalian kerjakan.\qt@no{123}}%
\qt@newcmd\qurantrans@id@mdxcvii{%
\basmalahid (Alif laam raa) hanya Allahlah yang mengetahui maksudnya (ini) ayat-ayat ini (adalah ayat-ayat Kitab) yakni Alquran; idhafat di sini mengandung makna min, artinya bagian daripada Alquran (yang jelas) yang membedakan perkara hak daripada perkara yang batil.\qt@no{1}}%
\qt@newcmd\qurantrans@id@mdxcviii{%
(Sesungguhnya Kami menurunkannya berupa Alquran dengan berbahasa Arab) dengan memakai bahasa Arab (agar kalian) hai penduduk Mekah (memahaminya) memahami makna-maknanya.\qt@no{2}}%
\qt@newcmd\qurantrans@id@mdxcix{%
(Kami menceritakan kepadamu kisah yang paling baik dengan mewahyukan) melalui apa yang Kami wahyukan (Alquran ini kepadamu dan sesungguhnya) lafal in merupakan takhfif daripada lafal inna (kamu sebelumnya adalah termasuk orang-orang yang belum mengetahui).\qt@no{3}}%
\qt@newcmd\qurantrans@id@mdc{%
Ingatlah (Ketika Yusuf berkata kepada ayahnya) Nabi Yakub ("Wahai ayahku!) dibaca kasrah, yaitu abati untuk menunjukkan adanya ya idhafat yang tidak disebutkan. Sedangkan bila dibaca fatah, maka menunjukkan adanya huruf alif yang tidak disebutkan, yaitu abata, kemudian alif ditukar dengan ya (Sesungguhnya aku telah melihat) di dalam tidurku, yakni bermimpi (sebelas buah bintang dan matahari serta bulan, kulihat semuanya) lafal ra-aytuhum berkedudukan menjadi taukid atau pengukuh dari lafal ra-aytu di muka tadi (sujud kepadaku.") lafal saajidiina adalah bentuk jamak, yang alamat i'rabnya memakai ya dan nun karena menggambarkan keadaan sujud, hal ini merupakan ciri khas daripada makhluk yang berakal.\qt@no{4}}%
\qt@newcmd\qurantrans@id@mdci{%
(Ayahnya berkata, ``Hai anakku! Janganlah kamu ceritakan mimpimu itu kepada saudara-audaramu, maka mereka membuat makar kepadamu) maksudnya mereka pasti akan membuat tipu muslihat guna membinasakanmu, karena terdorong oleh rasa dengki mereka kepadamu. Tentu mereka menakwilkan impianmu itu, bahwa bintang-bintang itu adalah mereka sendiri dan matahari itu adalah ibumu, sedangkan bulan adalah ayahmu. (Sesungguhnya setan itu adalah musuh yang nyata bagi manusia.") jelas permusuhannya.\qt@no{5}}%
\qt@newcmd\qurantrans@id@mdcii{%
(Dan demikianlah) seperti apa yang kamu lihat dalam mimpimu itu (telah memilih kamu) telah mengangkatmu (Rabbmu dan diajarkan-Nya kepadamu sebagian dari takwil-takwil mimpi) makna mimpi (dan disempurnakan-Nya kepadamu nikmat-Nya) yaitu kenabian (dan kepada keluarga Yakub) yakni anak-anaknya (sebagaimana Dia telah menyempurnakan nikmat-Nya) yaitu nikmat kenabian (kepada kedua orang tuamu sebelum itu, yaitu Ibrahim dan Ishak. Sesungguhnya Rabbmu Maha Mengetahui) tentang makhluk-Nya (lagi Maha Bijaksana) di dalam memperlakukan mereka.\qt@no{6}}%
\qt@newcmd\qurantrans@id@mdciii{%
(Sesungguhnya telah ada pada) kisah (Yusuf dan saudara-saudaranya) jumlah mereka ada sebelas orang (tanda-tanda) bahan-bahan pelajaran (bagi orang-orang yang bertanya).\qt@no{7}}%
\qt@newcmd\qurantrans@id@mdciv{%
Ingatlah (ketika mereka berkata) yaitu sebagian saudara-saudara Nabi Yusuf kepada sebagian yang lain ("Sesungguhnya Yusuf) lafal Yusuf berkedudukan menjadi mubtada (dan saudaranya) yang sekandung yaitu Bunyamin (lebih dicintai) menjadi khabar dari lafal Yusuf tadi (oleh ayah kita daripada kita sendiri, padahal kita ini adalah satu golongan) kelompok yang kuat. (Sesungguhnya ayah kita adalah dalam kesesatan) kekeliruan (yang nyata) kekeliruan yang jelas dikarenakan ia lebih menyayangi Yusuf dan saudara sekandungnya daripada kita.\qt@no{8}}%
\qt@newcmd\qurantrans@id@mdcv{%
(Bunuhlah Yusuf atau buanglah dia ke suatu daerah) ke tempat yang jauh dan belum dikenal (supaya perhatian ayah kalian tertumpah kepada kalian) sehingga beliau hanya memperhatikan kalian dan tidak kepada yang lainnya (dan sesudah itu hendaklah kalian) sesudah membunuh Yusuf atau membuangnya (menjadi orang-orang yang baik.") dengan jalan bertobat.\qt@no{9}}%
\qt@newcmd\qurantrans@id@mdcvi{%
(Seorang di antara mereka berkata,) yaitu Yahudza ("Janganlah kalian bunuh Yusuf, tetapi lemparkanlah dia) masukkanlah dia (ke dasar sumur) yang gelap sekali. Menurut qiraat lafal al-jub dibaca dalam bentuk jamak (supaya dia dipungut oleh beberapa orang musafir) orang-orang yang sedang melakukan perjalanan (jika kalian hendak berbuat.") apa yang kalian kehendaki, yaitu ingin memisahkan antara Yusuf dan ayahnya, maka cukuplah dengan cara tersebut.\qt@no{10}}%
\qt@newcmd\qurantrans@id@mdcvii{%
(Mereka berkata, ``Wahai ayah kami! Apa sebabnya engkau tidak mempercayai kami terhadap Yusuf, padahal sesungguhnya kami adalah orang-orang yang menginginkan kebaikan baginya.") orang-orang yang bersedia mengurusi semua kepentingan-kepentingannya.\qt@no{11}}%
\qt@newcmd\qurantrans@id@mdcviii{%
("Biarkanlah dia pergi bersama kami besok pagi) ke padang sahara (agar dia dapat bersenang-senang dan bermain-main) dapat dibaca yarta' dan yal'ab, atau narta' dan nal`ab; artinya supaya dia atau kami dapat semangat yang baru dan pikiran yang segar (dan sesungguhnya kami pasti menjaganya").\qt@no{12}}%
\qt@newcmd\qurantrans@id@mdcix{%
(Berkata Yakub, ``Sesungguhnya amat menyedihkan aku kepergian kalian) bila kalian pergi (bersama Yusuf) karena merasa berat berpisah dengannya (dan aku khawatir kalau-kalau dia dimakan serigala) makna yang dimaksud adalah jenis, yaitu mencakup semua binatang buas. Tersebutlah bahwa daerah tempat tinggal mereka terkenal banyak hewan buasnya (sedangkan kalian lengah daripadanya.") lalai daripadanya.\qt@no{13}}%
\qt@newcmd\qurantrans@id@mdcx{%
(Mereka berkata, ``Jika benar-benar) lam di sini bermakna qasam atau sumpah (ia dimakan oleh serigala sedangkan kami adalah golongan yang kuat) kelompok yang kuat (sesungguhnya kami kalau demikian adalah orang-orang yang merugi.") orang-orang yang tidak mampu membela diri. Kemudian setelah itu Nabi Yakub mengizinkan kepergian mereka membawa Nabi Yusuf.\qt@no{14}}%
\qt@newcmd\qurantrans@id@mdcxi{%
(Maka tatkala mereka membawanya dan sepakat) telah bertekad bulat (untuk memasukkannya ke dalam sumur) jawab dari lafal lammaa tidak disebutkan, yaitu maka mereka melakukan niatnya itu. Untuk itu mereka melepas baju Nabi Yusuf setelah terlebih dahulu dipukuli dan dicaci maki, kemudian mereka mengulurkan tali timba ke dalam sumur tersebut sedangkan Nabi Yusuf diikatkan padanya. Ketika tali timba mencapai setengah kedalaman sumur, lalu mereka melepaskannya, supaya Nabi Yusuf jatuh ke bawah lalu mati. Akan tetapi Nabi Yusuf jatuh di air, kemudian ia duduk di atas batu besar yang ada dalam sumur itu. Lalu saudara-saudaranya menyerunya, dan Nabi Yusuf menjawab seruan mereka; akan tetapi mereka menganggap bahwa Nabi Yusuf meminta pertolongan kepada mereka. Mereka bermaksud untuk menimpakan batu besar kepadanya, akan tetapi mereka dicegah oleh Yahudza. (Dan Kami wahyukan kepadanya) sewaktu ia berada di dalam sumur. Nabi Yusuf hidup di dalam sumur selama tujuh belas tahun atau kurang daripadanya. Allah memberikan wahyu kepadanya sebagai penenang hatinya ("Sesungguhnya kamu akan menceritakan kepada mereka) sesudah peristiwa ini (tentang perbuatan mereka ini) tentang perlakuan mereka ini (sedangkan mereka tiada ingat lagi.") terhadap dirimu sewaktu kamu bercerita kepada mereka.\qt@no{15}}%
\qt@newcmd\qurantrans@id@mdcxii{%
(Kemudian mereka datang kepada ayah mereka di sore hari) pada waktu sore (sambil menangis).\qt@no{16}}%
\qt@newcmd\qurantrans@id@mdcxiii{%
(Mereka berkata, ``Wahai ayah kami! Sesungguhnya kami pergi berlomba-lomba) memanah (dan kami tinggalkan Yusuf di dekat barang-barang kami) yakni pakaian-pakaian kami (lalu dia dimakan oleh serigala dan engkau sekali-kali tidak akan percaya) mempercayai (kepada kami sekali pun kami adalah orang-orang yang benar.") terhadapmu. Pasti engkau akan menuduh kami dengan tuduhan yang bukan-bukan sehubungan dengan perihal Yusuf ini karena kecintaanmu terhadapnya. Mengapa sampai sedemikian buruknya persangkaanmu terhadap diri kami?\qt@no{17}}%
\qt@newcmd\qurantrans@id@mdcxiv{%
(Mereka datang membawa baju gamisnya) lafal `alaa qamiishihi beri'rab mahal nashab karena menjadi zharaf. Artinya yang berlumuran padanya (dengan darah palsu) darah yang bukan darah Nabi Yusuf; hal ini mereka lakukan dengan menyembelih seekor kambing, kemudian mereka lumurkan darahnya pada baju gamis Nabi Yusuf, akan tetapi mereka lupa merobek-robeknya. Lalu mereka menghadap kepada ayahnya seraya berkata, ``Sesungguhnya ini adalah darah Yusuf." (Yakub berkata) sewaktu ia melihat baju Yusuf dalam keadaan utuh dan ia mengetahui bahwa mereka berdusta dalam hal ini ("Sebenarnya telah menghiasi) menganggap baik (diri kalian suatu perbuatan yang buruk) kemudian kalian mengerjakannya (maka kesabaran yang baik itulah kesabaranku) kesabaran yang tidak disertai rasa kaget dan gelisah. Lafal fashabrun jamiil ini adalah mubtada sedangkan khabarnya tidak disebutkan, yaitu amri yang artinya adalah kesabaranku. (Dan Allah sajalah yang dimohon pertolongan-Nya) hanya Allahlah yang diminta pertolongan-Nya (terhadap apa yang kalian ceritakan.") apa yang kalian kisahkan tentang perkara Yusuf ini.\qt@no{18}}%
\qt@newcmd\qurantrans@id@mdcxv{%
(Kemudian datanglah kelompok orang-orang musafir) rombongan orang-orang yang melakukan perjalanan dari Madyan ke Mesir, lalu mereka istirahat di dekat sumur Nabi Yusuf (lalu mereka menyuruh seorang pengambil air) yang khusus untuk mencari air buat minum rombongan musafir (maka dia menurunkan) melepaskan (timbanya) ke dalam sumur kemudian Nabi Yusuf bergantung ke tali timba, sehingga keluarlah Nabi Yusuf dari dalam sumur itu. Ketika pengambil air melihat Nabi Yusuf (dia berkata, ``Oh, kabar gembira) menurut suatu qiraat dibaca busyraaya seruan di sini mengandung makna majaz, artinya cepatlah ini sudah masanya bagimu (ini seorang anak muda.") maka hal itu diketahui oleh teman-teman penimba air, lalu mereka mendatanginya. (Kemudian mereka menyembunyikan dia) artinya, mereka merahasiakan perkara Nabi Yusuf ini, dengan maksud untuk menjadikannya (sebagai barang dagangan) seumpamanya mereka menganggapnya sebagai budak yang telah minggat kemudian ditemukan lagi. Sedangkan Nabi Yusuf diam saja karena ia merasa khawatir akan dibunuh oleh mereka. (Dan Allah Maha Mengetahui apa yang mereka kerjakan.)\qt@no{19}}%
\qt@newcmd\qurantrans@id@mdcxvi{%
(Dan mereka menjual Yusuf) orang-orang musafir itu membelinya dari tangan penimba air dan teman-temannya (dengan harga yang murah) kurang dari semestinya (yaitu hanya beberapa dirham saja) sekitar dua puluh atau dua puluh dua dirham saja (dan mereka) yakni saudara-saudara penimba air itu (merasa tidak tertarik hatinya kepada Yusuf) kemudian rombongan musafir itu membawa Yusuf ke negeri Mesir selanjutnya Nabi Yusuf dijual oleh orang yang membelinya dengan harga dua puluh dinar, dua pasang terompah dan dua buah baju.\qt@no{20}}%
\qt@newcmd\qurantrans@id@mdcxvii{%
(Dan orang Mesir yang membelinya berkata) dia bernama Qithfir Al-Aziz (kepada istrinya) yaitu Zulaikha ("Berikanlah kepadanya tempat dan layanan yang baik) muliakanlah dia di antara kita (boleh jadi dia bermanfaat bagi kita atau kita pungut dia sebagai anak.") disebutkan bahwa Qithfir Al-Aziz tidak mempunyai anak atau impoten. (Dan demikian pulalah) artinya sebagaimana Kami selamatkan dia dari pembunuhan dan sewaktu di dalam sumur serta Kami jadikan hati Al-Aziz merasa sayang kepadanya (Kami memberikan kedudukan yang baik kepada Yusuf di muka bumi) negeri Mesir sehingga sampai pada waktunya (dan agar Kami ajarkan kepadanya takwil mimpi) makna mimpi; lafal linu`allimahu diathafkan kepada fi`il yang keberadaannya diperkirakan dan berta`alluq kepada lafal makkannaa; artinya Kami ajarkan kepadanya makna mimpi sehingga ia menguasainya. Atau huruf wawu yang sebelum linu`allimahu ini adalah huruf tambahan. (Dan Allah berkuasa terhadap urusan-Nya) tidak ada sesuatu pun yang dapat menghalang-halangi-Nya (tetapi kebanyakan manusia) yang dimaksud adalah orang-orang kafir (tidak mengetahui) hal tersebut.\qt@no{21}}%
\qt@newcmd\qurantrans@id@mdcxviii{%
(Dan tatkala dia cukup dewasa) yaitu mencapai umur tiga puluh tahun atau tiga puluh tiga tahun (Kami berikan kepadanya hikmah) kebijaksanaan (dan ilmu) pengetahuan agama sebelum ia diangkat menjadi nabi. (Demikianlah) sebagaimana Kami berikan imbalan kepadanya (Kami memberi balasan kepada orang-orang yang berbuat baik) terhadap diri mereka sendiri.\qt@no{22}}%
\qt@newcmd\qurantrans@id@mdcxix{%
(Dan wanita, yang Yusuf tinggal di rumahnya menggoda Yusuf) yaitu Zulaikha (untuk menundukkan dirinya kepadanya) yakni ia meminta kepada Yusuf supaya mau memenuhi kehendaknya (dan dia menutup pintu-pintu) rumah (seraya berkata) kepada Yusuf ("Marilah ke sini.") artinya kemarilah; huruf lam dari lafal haitalak bermakna tabyin atau untuk menjelaskan. Menurut qiraat dibaca dengan dikasrahkan huruf ha-nya, sehingga bacaannya menjadi hiitalak. Sedangkan menurut qiraat lainnya dapat dibaca haytulak dengan mendamahkan huruf ta-nya. (Yusuf berkata, ``Aku berlindung kepada Allah) artinya aku berlindung kepada Allah dari perbuatan itu (sesungguhnya dia) artinya orang yang telah membelinya (adalah tuanku) majikanku (telah memperlakukan aku dengan baik) telah berlaku baik terhadap diriku maka aku tidak akan mengkhianatinya dengan berlaku tidak baik terhadap istrinya (sesungguhnya) pada kenyataannya (orang-orang yang lalim tiada akan beruntung) yang dimaksud adalah orang-orang yang suka berzina.\qt@no{23}}%
\qt@newcmd\qurantrans@id@mdcxx{%
(Sesungguhnya wanita itu telah mempunyai maksud terhadap Yusuf) artinya dia telah bermaksud terhadap Nabi Yusuf supaya menyetubuhinya (dan Yusuf pun bermaksud melakukannya pula dengan wanita itu) artinya Yusuf pun mempunyai keinginan yang sama (andaikata dia tidak melihat tanda dari Rabbnya) menurut Ibnu Abbas r.a. bahwa pada saat yang kritis itu tiba-tiba Nabi Yakub atau ayahnya tampak di hadapannya, lalu memukul dadanya sehingga keluarlah nafsu syahwat yang telah membara itu dari semua ujung-ujung jarinya. Jawab dari lafal laulaa ialah lajaama`ahaa; artinya niscaya Yusuf menyetubuhinya. (Demikianlah) Kami perlihatkan tanda kekuasaan-Ku kepadanya (agar Kami memalingkan daripadanya kemungkaran) perbuatan khianat (dan kekejian) perbuatan zina. (Sesungguhnya Yusuf itu termasuk hamba-hamba Kami yang terikhlas) dalam hal ketaatan. Menurut suatu qiraat dibaca mukhlishiin dengan dikasrahkan huruf lam-nya; artinya sama dengan lafal al-mukhtaariina atau orang-orang yang terpilih.\qt@no{24}}%
\qt@newcmd\qurantrans@id@mdcxxi{%
(Dan keduanya berlomba-lomba menuju pintu) Yusuf segera lari menuju ke pintu rumah untuk melepaskan diri daripadanya. Sedangkan Zulaikha yang sudah kerasukan nafsu syahwatnya memegang baju bagian belakang Yusuf kemudian berupaya menariknya (dan robeklah) menjadi sobek (baju gamis Yusuf dari arah belakangnya dan kedua-duanya mendapati) menemukan (suami wanita itu) suami Zulaikha (di muka pintu) maka secara spontan Zulaikha membersihkan dirinya selanjutnya. (Wanita itu berkata, ``Tiadalah pembalasan terhadap orang yang bermaksud berbuat serong dengan istrimu) yakni berzina (selain dipenjarakan) ditahan di dalam penjara (atau dihukum dengan siksaan yang pedih?") siksaan yang menyakitkan, dipukuli umpamanya.\qt@no{25}}%
\qt@newcmd\qurantrans@id@mdcxxii{%
(Yusuf berkata) membela dirinya ("Dia menggodaku untuk menundukkan diriku kepadanya," dan seorang saksi dari keluarga wanita itu memberikan kesaksiannya) sepupu Zulaikha. Tetapi menurut suatu riwayat disebutkan, bahwa saksi itu adalah bayi yang masih dalam ayunan. Kemudian saksi itu mengatakan ("Jika baju gamisnya koyak di muka) pada bagian muka Yusuf (maka wanita itu benar dan Yusuf termasuk orang-orang yang dusta.").\qt@no{26}}%
\qt@newcmd\qurantrans@id@mdcxxiii{%
("Dan jika baju gamisnya koyak di belakangnya) pada bagian belakang Yusuf (maka wanita itulah yang dusta dan Yusuf termasuk orang-orang yang benar.")\qt@no{27}}%
\qt@newcmd\qurantrans@id@mdcxxiv{%
(Maka tatkala suami wanita itu melihat) suami Zulaikha (baju gamis Yusuf koyak di belakang berkatalah dia, ``Sesungguhnya kejadian itu) yang kamu katakan, apakah pembalasan terhadap orang yang bermaksud memperkosa istrimu (adalah di antara tipu daya kalian) hai kaum wanita (sesungguhnya tipu daya kalian adalah besar.").\qt@no{28}}%
\qt@newcmd\qurantrans@id@mdcxxv{%
Selanjutnya suami wanita itu berkata, ``Hai (Yusuf! Berpalinglah dari ini) dari peristiwa ini, lupakanlah supaya jangan tersiar beritanya (dan kamu mohon ampunlah) hai Zulaikha istriku (atas dosamu itu, karena kamu sesungguhnya termasuk orang-orang yang berbuat salah.") yakni orang-orang yang telah berbuat dosa. Akan tetapi peristiwa itu beritanya tidak dapat disembunyikan lalu tersiarlah di kalangan masyarakat.\qt@no{29}}%
\qt@newcmd\qurantrans@id@mdcxxvi{%
(Dan wanita-wanita di kota berkata) yaitu kota Mesir ("Istri Aziz menggoda bujangnya) yaitu hamba sahaya lakinya (untuk menundukkan dirinya menuruti kemauannya, sesungguhnya cintanya kepada bujangnya itu adalah sangat mendalam) lafal hubban berkedudukan menjadi tamyiz; artinya cinta Zulaikha terhadap Yusuf telah merasup ke dalam lubuk hatinya. (Sesungguhnya kami memandangnya dalam kesesatan yang nyata.") jelas sesat karena mencintai hambanya sendiri.\qt@no{30}}%
\qt@newcmd\qurantrans@id@mdcxxvii{%
(Maka tatkala wanita itu mendengar cercaan mereka) pergunjingan mereka terhadap dirinya (diundangnyalah wanita-wanita itu dan disediakannya) Zulaikha mempersiapkan (bagi mereka makanan) yang harus dipotong terlebih dahulu dengan pisau dan beralaskan pada talenan (dan diberikannya) Zulaikha memberikan (kepada masing-masing mereka sebuah pisau, kemudian dia berkata) kepada Yusuf ("Keluarlah kepada mereka." Maka tatkala wanita-wanita itu melihatnya, mereka merasa kagum terhadapnya) kepada ketampanan dan keelokan rupanya (dan mereka melukai jari tangannya) dengan pisau-pisau yang mereka pegang itu tanpa mereka sadari dan tanpa merasa sakit karena kekaguman mereka terhadap ketampanan Yusuf (dan berkatalah mereka, ``Maha Sempurna Allah) dimaksud sebagai ungkapan memahasucikan Allah swt. (ini bukanlah) artinya Nabi Yusuf ini (manusia tetapi) melainkan (ia adalah malaikat yang mulia.") mengingat ketampanan dan keelokan rupanya hal ini tidak akan ditemui pada manusia. Di dalam sebuah hadis disebutkan bahwasanya Nabi Yusuf telah dianugerahi separuh dari ketampanan dan keelokan rupa.\qt@no{31}}%
\qt@newcmd\qurantrans@id@mdcxxviii{%
(Wanita itu berkata) yang dimaksud adalah istri Al-Aziz sewaktu ia melihat apa yang terjadi pada diri mereka ("Itulah dia) dialah (orangnya yang kalian cela aku karena tertarik kepadanya) karena aku mencintainya. Kalimat ini merupakan penjelasan tentang alasan Zulaikha (dan sesungguhnya aku telah menggoda dia untuk menundukkan dirinya kepadaku akan tetapi ia mempertahankan dirinya) menolak. (Dan sesungguhnya jika dia tidak menaati apa yang aku perintahkan kepadanya) untuk dilakukannya (niscaya dia akan dipenjarakan dan dia akan termasuk golongan orang-orang yang hina") orang-orang yang tidak terpandang. Maka wanita-wanita itu berkata kepada Yusuf, ``Turutilah kemauan tuan wanitamu ini."\qt@no{32}}%
\qt@newcmd\qurantrans@id@mdcxxix{%
(Yusuf berkata, ``Wahai Rabbku! Penjara lebih aku sukai daripada memenuhi ajakan mereka kepadaku. Dan jika tidak Engkau hindarkan aku dari tipu daya mereka, tentu aku akan cenderung untuk) memenuhi (kemauan mereka dan tentulah aku) menjadi (termasuk orang-orang yang bodoh") yakni orang-orang yang berbuat dosa. Makna yang dimaksud adalah berdoa. Pada ayat selanjutnya Allah berfirman:\qt@no{33}}%
\qt@newcmd\qurantrans@id@mdcxxx{%
(Maka Rabbnya memperkenankan doa Yusuf) permintaannya (dan Dia menghindarkan Yusuf dari tipu daya mereka. Sesungguhnya Dialah Yang Maha Mendengar) semua pembicaraan (lagi Maha Mengetahui) semua pekerjaan.\qt@no{34}}%
\qt@newcmd\qurantrans@id@mdcxxxi{%
(Kemudian timbul pikiran) tampak nyata (pada mereka setelah melihat tanda-tanda) yang menunjukkan kebersihan diri Nabi Yusuf, yaitu memenjarakannya. Hal ini terbukti dengan adanya penjelasan pada ayat selanjutnya (bahwa mereka harus memenjarakannya sampai) hingga (sesuatu waktu) semua yang hadir setuju dengan pendapat ini akhirnya Nabi Yusuf dipenjarakan.\qt@no{35}}%
\qt@newcmd\qurantrans@id@mdcxxxii{%
(Dan bersama dengan dia masuk pula ke dalam penjara dua orang pemuda) dua orang pelayan raja; salah seorang di antaranya bekas atau mantan penyuguh minumannya dan yang seorang lainnya mantan penyuguh makanannya. Kemudian mereka berdua melihat bahwa Nabi Yusuf pandai menakwilkan arti mimpi lalu keduanya sepakat untuk mengujinya. (Berkatalah salah seorang di antara keduanya) yaitu mantan penyuguh minuman raja ("Sesungguhnya aku bermimpi bahwa aku memeras khamar.") yang dimaksud adalah memeras anggur (Dan yang lainnya berkata) yaitu mantan penyuguh hidangan raja ("Sesungguhnya aku bermimpi bahwa aku membawa roti di atas kepalaku, sebagiannya dimakan burung. Berikanlah kepada kami) ceritakanlah kepada kami (takbirnya) arti impian itu (sesungguhnya kami memandang kamu termasuk orang-orang yang pandai menakwilkan mimpi.").\qt@no{36}}%
\qt@newcmd\qurantrans@id@mdcxxxiii{%
(Yusuf berkata) kepada kedua pemuda itu seraya menegaskan, bahwa dirinya pandai di dalam menakbirkan arti mimpi ("Tidak disampaikan kepada kamu berdua makanan yang akan diberikan kepadamu) di dalam mimpi kamu berdua (melainkan aku telah dapat menerangkan takwilnya) apa yang akan terjadi di alam kenyataan (sebelum makanan itu sampai kepada kamu berdua) sebelum kenyataan mimpi itu menimpa kalian berdua. (Yang demikian itu adalah sebagian dari apa yang diajarkan kepadaku oleh Rabbku) di dalam ungkapan ini terkandung pengertian yang menganjurkan supaya mereka berdua beriman kepada Allah. Selanjutnya hal ini diperkuat oleh perkataannya lagi, yaitu: (Sesungguhnya aku telah meninggalkan tuntunan) agama (orang-orang yang tidak beriman kepada Allah sedangkan mereka terhadap hari kiamat benar-benar) sungguh (ingkar").\qt@no{37}}%
\qt@newcmd\qurantrans@id@mdcxxxiv{%
("Dan aku mengikuti agama bapak-bapakku, yaitu Ibrahim, Ishak dan Yakub. Tiadalah patut) tidak pantas (bagi kami mempersekutukan Allah dengan) huruf min di sini zaidah (sesuatu pun) karena kami selalu memelihara (yang demikian itu) yakni ajaran tauhid (adalah karunia Allah kepada kami dan kepada manusia seluruhnya tetapi kebanyakan manusia itu) dimaksud adalah orang-orang kafir (tidak mensyukuri.") terhadap Allah; lalu mereka menyekutukan-Nya. Kemudian Nabi Yusuf menjelaskan ajakannya kepada mereka berdua agar keduanya beriman seraya berkata:\qt@no{38}}%
\qt@newcmd\qurantrans@id@mdcxxxv{%
("Hai kedua temanku) yang satu tempat tinggal (dalam penjara! Manakah yang baik tuhan yang bermacam-macam itu ataukah Allah Yang Maha Esa lagi Maha Perkasa?") pilihlah! Istifham atau kata tanya di sini mengandung pengertian taqrir atau menetapkan.\qt@no{39}}%
\qt@newcmd\qurantrans@id@mdcxxxvi{%
("Kamu berdua tidak menyembah yang selain-Nya) selain Allah (melainkan hanya menyembah nama-nama yang dibuat-buat) yaitu kalian namakan mereka berhala-berhala (oleh kalian dan nenek moyang kalian sendiri, Allah tidak menurunkan tentang nama-nama itu) untuk disembah (suatu keterangan pun) hujah dan argumentasi. (Tiada lain) tiadalah (keputusan itu) kepastian itu (hanya kepunyaan Allah) semata (Dia telah memerintahkan agar kalian tidak menyembah selain Dia. Itulah) yakni agama tauhid itulah (agama yang lurus) agama yang mustaqim (tetapi kebanyakan manusia) orang-orang kafir (tidak mengetahui.") apa yang bakal menimpa mereka, yaitu berupa azab; mereka benar-benar orang-orang yang menyekutukan-Nya.\qt@no{40}}%
\qt@newcmd\qurantrans@id@mdcxxxvii{%
("Hai kedua temanku dalam penjara! Adapun salah seorang di antara kamu berdua) yang dimaksud adalah mantan penyuguh minuman raja; maka setelah tiga hari kemudian ia akan keluar dari penjara ini (akan memberi minum tuannya) rajanya (dengan khamar) sebagaimana biasa (dan adapun yang seorang lain) ia bakal keluar dari penjara ini setelah tiga hari (maka ia akan disalib, lalu burung memakan sebagian dari kepalanya) itulah makna mimpi kalian berdua. Kemudian keduanya menjawab, ``Kami sebenarnya tidak bermimpi melihat apa-apa." Nabi Yusuf berkata: ("Telah diputuskan perkara yang kamu berdua menanyakannya.") yang kamu berdua telah menanyakan perihalnya, apakah kamu berdua mempercayainya atau tidak, itu terserah.\qt@no{41}}%
\qt@newcmd\qurantrans@id@mdcxxxviii{%
(Dan Yusuf berkata kepada orang yang diketahuinya) yang telah ia yakini (akan selamat di antara mereka berdua) yaitu mantan penyuguh minum raja ("Jelaskanlah keadaanku kepada tuanmu") yaitu kepada rajamu, bahwa sesungguhnya di dalam penjara ini terdapat seorang pemuda yang ditahan secara lalim, kemudian penyuguh minuman itu dikeluarkan dari penjara. (Maka ia dijadikan lupa) orang yang dimaksud adalah mantan penyuguh minuman (oleh setan menceritakan) tentang Nabi Yusuf (kepada tuannya. Karena itu tetaplah dia) Nabi Yusuf tetap tinggal (dalam penjara beberapa tahun lamanya) menurut suatu pendapat tujuh tahun dan menurut pendapat yang lain dua belas tahun.\qt@no{42}}%
\qt@newcmd\qurantrans@id@mdcxxxix{%
(Raja berkata) raja negeri Mesir, yaitu Ar-Rayyan bin Walid ("Sesungguhnya aku bermimpi melihat) fi'il mudhari' di sini bermakna fi'il madhi (tujuh ekor sapi betina yang gemuk-gemuk dimakan oleh) ditelan oleh (tujuh ekor) sapi (sapi betina yang kurus-kurus) lafal `ijaaf adalah bentuk jamak dari kata tunggal `ajfau, artinya sapi betina yang kurus (dan tujuh bulir gandum yang hijau dan yang lainnya) yakni tujuh bulir pula (kering) telah melingkar pada tujuh bulir yang hijau itu dan menutupinya. (Hai orang-orang yang terkemuka, terangkanlah kepadaku tentang takbir mimpiku itu) jelaskanlah kepadaku makna mimpiku itu (jika kalian dapat menakbirkan mimpi.") ceritakanlah maknanya kepadaku sekarang juga.\qt@no{43}}%
\qt@newcmd\qurantrans@id@mdcxl{%
(Mereka menjawab,) ``itu (adalah mimpi-mimpi yang kosong) mimpi yang tidak ada artinya (dan kami sekali-kali tidak mengetahui tentang mentakwilkan mimpi.")\qt@no{44}}%
\qt@newcmd\qurantrans@id@mdcxli{%
(Dan berkatalah orang yang selamat di antara mereka berdua) yaitu salah satu di antara kedua teman sepenjara Nabi Yusuf, mantan penyuguh minuman raja (dan ia teringat) kepada Nabi Yusuf. Lafal waddakara pada asalnya ialah tadzakkara, kemudian huruf ta diganti dal, selanjutnya huruf dzal asal diidghamkan kepada dal sehingga jadilah iddakara, artinya sama dengan lafal tadzakkara, yaitu ingat (sesudah beberapa waktu lamanya) setelah Nabi Yusuf tinggal beberapa lama di penjara, lalu mantan penyuguh minuman raja itu berkata ("Aku akan memberitahukan kepada kalian tentang orang yang pandai menakwilkan mimpi itu, maka utuslah aku kepadanya.") lalu mereka mengirimkan orang itu kepada orang yang dimaksudnya; kemudian orang itu mendatangi Nabi Yusuf seraya berkata kepadanya:\qt@no{45}}%
\qt@newcmd\qurantrans@id@mdcxlii{%
``Hai (Yusuf, hai orang yang amat dipercaya!) artinya orang yang jujur (Terangkanlah kepada kami tentang tujuh ekor sapi betina yang gemuk-gemuk yang dimakan oleh tujuh ekor sapi betina yang kurus-kurus dan tujuh bulir gandum yang hijau dan tujuh lainnya yang kering agar aku kembali kepada orang-orang itu) yaitu raja dan pembantu-pembantunya (agar mereka mengetahui") takwil mimpi itu.\qt@no{46}}%
\qt@newcmd\qurantrans@id@mdcxliii{%
(Yusuf berkata, ``Supaya kalian bertanam) artinya tanamlah oleh kalian (tujuh tahun lamanya sebagaimana biasa) yakni secara terus-menerus; hal ini merupakan takbir daripada tujuh ekor sapi betina yang gemuk-gemuk (maka apa yang kalian panen hendaklah kalian biarkan) biarkanlah ia (dibulirnya) supaya jangan rusak (kecuali sedikit untuk kalian makan) maka boleh kalian menumbuknya.\qt@no{47}}%
\qt@newcmd\qurantrans@id@mdcxliv{%
(Kemudian sesudah itu akan datang) artinya sesudah tujuh musim yang subur-subur itu (tujuh tahun yang amat sulit) kekeringan dan masa sulit; hal ini merupakan takbir daripada tujuh ekor sapi betina yang kurus-kurus (yang menghabiskan apa yang kalian simpan untuk menghadapinya) akan memakan semua biji-bijian dari hasil panen yang selama tujuh tahun yang subur itu; dimaksud kalian memakannya selama tujuh tahun paceklik itu (kecuali sedikit dari yang kalian simpan) artinya simpanan yang sedikit itu jadikanlah sebagai bibit.\qt@no{48}}%
\qt@newcmd\qurantrans@id@mdcxlv{%
(Kemudian setelah itu akan datang) yaitu sesudah tujuh tahun musim paceklik itu (tahun yang padanya manusia diberi hujan) yakni hujan yang cukup (dan di masa itu mereka memeras anggur.") dapat memeras anggur dan buah-buahan lainnya karena suburnya musim.\qt@no{49}}%
\qt@newcmd\qurantrans@id@mdcxlvi{%
(Raja berkata) ketika utusannya datang dan mengisahkan kepadanya tentang takbir mimpinya itu ("Bawalah dia kepadaku.") bawalah orang yang telah menakbirkannya itu. (Maka tatkala datang kepadanya) kepada Nabi Yusuf (utusan raja itu) kemudian utusan itu meminta kepadanya supaya keluar dari penjara (berkatalah Yusuf) dengan maksud untuk membersihkan dirinya ("Kembalilah kepada tuanmu dan tanyakanlah kepadanya) dimaksud supaya utusan raja itu menanyakan kepada raja (bagaimana) halnya (dengan wanita-wanita yang telah melukai tangannya. Sesungguhnya Rabbku) Tuhanku (Maha Mengetahui tipu daya mereka.") kemudian utusan itu kembali, lalu ia menceritakan semuanya kepada sang raja, maka sang raja mengumpulkan wanita-wanita itu.\qt@no{50}}%
\qt@newcmd\qurantrans@id@mdcxlvii{%
(Raja berkata, ``Bagaimana keadaan kalian) bagaimana perihal kalian (ketika kalian menggoda Yusuf untuk menundukkan dirinya kepada kemauan kalian?") apakah kalian memandang Yusuf mempunyai kecenderungan pada permintaan kalian itu? (Mereka berkata, ``Maha Sempurna Allah, kami tiada mengetahui sesuatu keburukan daripadanya." Berkatalah istri Al-Aziz, ``Sekarang jelaslah) menjadi gamblanglah (kebenaran itu, akulah yang menggodanya untuk menundukkan dirinya kepada kemauanku, dan sesungguhnya dia termasuk orang-orang yang benar.") di dalam pengakuannya, sewaktu ia mengatakan dialah yang menggodaku untuk menundukkan diriku kepada kemauannya. Setelah itu sang raja memberitahukan pengakuan itu kepada Nabi Yusuf dan setelah mendengar hal tersebut, lalu Nabi Yusuf berkata:\qt@no{51}}%
\qt@newcmd\qurantrans@id@mdcxlviii{%
("Yang demikian itu) yang diisyaratkan adalah permintaan bersih diri (agar dia mengetahui) yang dimaksud adalah Al-Aziz (bahwa sesungguhnya aku tidak berkhianat kepadanya) terhadap istrinya (di belakangnya) lafal bil-gaib berkedudukan sebagai hal atau kata keterangan keadaan (dan bahwasanya Allah tidak meridai tipu daya orang-orang yang berkhianat.") kemudian Nabi Yusuf bertawadhu` atau merendahkan diri terhadap Allah seraya mengatakan:\qt@no{52}}%
\qt@newcmd\qurantrans@id@mdcxlix{%
("Dan aku tidak membebaskan diriku) dari kesalahan-kesalahan (karena sesungguhnya nafsu itu) yaitu hawa nafsu (selalu menyuruh) banyak menyuruh (kepada kejahatan kecuali orang) lafal maa di sini bermakna man, yaitu orang atau diri (yang diberi rahmat oleh Rabbku) sehingga terpeliharalah ia dari kesalahan-kesalahan. (Sesungguhnya Rabbku Maha Pengampun lagi Maha Penyayang.").\qt@no{53}}%
\qt@newcmd\qurantrans@id@mdcl{%
(Dan raja berkata, ``Bawalah Yusuf kepadaku, agar aku memilih dia sebagai orang yang dekat kepadaku.") artinya aku akan jadikan ia sebagai orang yang paling kupercayai tanpa tandingan. Kemudian utusan sang raja datang kepada Nabi Yusuf seraya berkata, ``Turutilah kemauan sang raja!" Maka Nabi Yusuf bangkit dan berpamit kepada semua penghuni penjara, kemudian ia pun berdoa bagi mereka. Setelah itu Nabi Yusuf mandi dan memakai pakaian yang bagus, lalu barulah ia menemui sang raja. (Maka tatkala raja telah bercakap-cakap dengan dia, dia berkata) kepadanya ("Sesungguhnya kamu mulai hari ini menjadi orang yang berkedudukan tinggi lagi dipercayai pada sisi kami.") artinya mulai hari ini engkau menjadi orang yang berkedudukan tinggi dan sangat dipercaya terhadap urusan-urusan kami. Lalu bagaimana pendapatmu apakah yang harus kami lakukan sekarang? Nabi Yusuf berkata kepadanya, ``Kumpulkanlah semua bibit-bibit, kemudian mari kita tanamkan dengan secara massal pada tahun-tahun yang subur sekarang ini. Simpanlah hasilnya pada bulir-bulirnya. Kelak akan datang orang-orang menitipkan hasil panennya kepadamu." Maka sang raja berkata, ``Lalu siapakah yang akan mengurusi dan menangani hal ini untuk membantuku?"\qt@no{54}}%
\qt@newcmd\qurantrans@id@mdcli{%
(Berkatalah ia) Nabi Yusuf ("Jadikanlah aku bendaharawan negeri ini,) yakni negeri Mesir (sesungguhnya aku adalah orang yang pandai menjaga lagi berpengetahuan.") orang yang mempunyai keahlian dalam hal perbendaharaan. Menurut suatu pendapat ditakwilkan, bahwa Nabi Yusuf pandai dalam hal menulis dan menghitung.\qt@no{55}}%
\qt@newcmd\qurantrans@id@mdclii{%
(Dan demikianlah) sebagaimana Kami berikan nikmat kepada Yusuf, yaitu dibebaskan dari penjara (Kami memberi kedudukan kepada Yusuf di negeri) Mesir (pergi) ia dapat bepergian (menuju ke mana saja ia kehendaki di bumi Mesir) yang pada sebelumnya ia hidup dalam kesempitan dan dalam sekapan tahanan. Menurut suatu riwayat dikisahkan bahwa sang raja memberinya mahkota dan cincin kebesaran kemudian sang raja memecat Al-Aziz lalu mengangkat Yusuf menggantikan kedudukannya. Tidak lama kemudian Al-Aziz wafat lalu Yusuf menikahi istrinya yang bernama Zulaikha. Ternyata setelah Nabi Yusuf menggaulinya, Zulaikha masih perawan; Nabi Yusuf mempunyai dua orang putra dari Zulaikha ini. Nabi Yusuf mampu menegakkan keadilan di negeri Mesir dan semua orang menaatinya.\qt@no{56}}%
\qt@newcmd\qurantrans@id@mdcliii{%
(Dan sesungguhnya pahala di akhirat itu lebih baik) daripada upah di dunia (bagi orang-orang beriman dan selalu bertakwa.) ketika musim paceklik tiba, musim paceklik itu menimpa pula negeri Kan`an dan negeri Syam.\qt@no{57}}%
\qt@newcmd\qurantrans@id@mdcliv{%
(Dan saudara-saudara Yusuf datang) kecuali Bunyamin, mereka datang untuk meminta makanan, karena mereka telah mendengar bahwa Aziz negeri Mesir membagi-bagikan makanan dengan memakai bayaran atau cara barter (lalu mereka masuk ke tempatnya. Maka Yusuf mengenal mereka) bahwasanya mereka adalah saudara-saudaranya (sedangkan mereka sudah tidak kenal lagi kepadanya) mereka tidak mengenalnya lagi karena sudah terlalu lama berpisah, dan pula mereka telah memastikan bahwa Yusuf telah mati. Lalu mereka berbicara dengan Yusuf memakai bahasa Ibrani. Nabi Yusuf berkata kepada mereka seolah-olah tidak mengenal mereka, ``Apakah gerangan yang menyebabkan kalian datang ke negeriku ini?" Lalu mereka menjawab, ``Untuk membeli makanan." Lalu Nabi Yusuf berkata, ``Jangan-jangan kalian ini mata-mata musuh." Mereka menjawab, ``Kami berlindung kepada Allah dari hal itu." Nabi Yusuf bertanya, ``Dari manakah kalian ini?" Mereka menjawab, ``Dari negeri Kan'an dan bapak kami bernama Yakub seorang nabi." Nabi Yusuf bertanya kembali, ``Apakah dia mempunyai anak lagi selain kalian?" Mereka menjawab, ``Ya, dahulu kami berjumlah dua belas orang, kemudian saudara yang paling kecil di antara kami, kami ajak bepergian, lalu ia binasa di tengah padang sahara. Dia adalah anak yang paling disayang oleh bapak kami, dan saudara sekandungnya sajalah kini yang tinggal bersama bapak kami, lalu bapak kami melarangnya pergi ke mana-mana karena khawatir akan terjadi hal yang serupa. Ia kini menjadi penghibur hati bapak kami." Kemudian Nabi Yusuf memerintahkan supaya mereka diberi tempat dan dihormati sebagaimana layaknya tamu.\qt@no{58}}%
\qt@newcmd\qurantrans@id@mdclv{%
(Dan tatkala Yusuf menyiapkan untuk mereka bahan makanannya) lalu Nabi Yusuf menyempurnakan takaran bahan makanan itu buat mereka (ia berkata, ``Bawalah kepadaku saudara kalian yang seayah dengan kalian) yaitu Bunyamin, untuk mengecek kebenaran cerita kalian itu (tidakkah kalian melihat, bahwa aku menyempurnakan sukatan) yakni, aku telah menyempurnakannya tanpa menguranginya sedikit pun (dan aku adalah sebaik-baik penerima tamu?).\qt@no{59}}%
\qt@newcmd\qurantrans@id@mdclvi{%
(Jika kalian tidak membawanya kepadaku, maka kalian tidak akan mendapat sukatan lagi daripadaku) artinya kalian tidak akan mendapatkan bantuan makanan lagi (dan jangan kalian mendekatiku lagi.") lafal wala taqrabuuni bermakna nahi atau melarang; atau di'athafkan kepada mahal lafal falaa kaila, sehingga artinya menjadi kalian tidak akan mendapatkan bantuan makanan dan kalian tidak dapat mendekat kepadaku.\qt@no{60}}%
\qt@newcmd\qurantrans@id@mdclvii{%
(Mereka berkata, ``Kami akan membujuk ayahnya untuk membawanya ke mari) artinya kami akan berupaya sekuat tenaga dengan meminta kepada ayahnya untuk dapat membawanya (dan sesungguhnya kami benar-benar akan melaksanakannya.") yakni melaksanakan hal tersebut.\qt@no{61}}%
\qt@newcmd\qurantrans@id@mdclviii{%
(Yusuf berkata kepada pembantu-pembantunya) menurut suatu qiraat lafal lifityaanihi dibaca lifatayaanihi yang artinya, kedua pembantunya ("Masukkanlah barang-barang mereka) yang mereka bawa sebagai pengganti harga makanan; barang-barang tersebut berupa uang dirham (ke dalam karung-karung mereka) ke dalam kantung-kantung tempat makanan mereka (supaya mereka mengetahuinya apabila mereka telah kembali kepada keluarganya) kemudian mereka menumpahkan isi karung-karung mereka itu (mudah-mudahan mereka kembali lagi.") kepada kita karena sesungguhnya mereka adalah kaum yang tidak menghalalkan menahannya.\qt@no{62}}%
\qt@newcmd\qurantrans@id@mdclix{%
(Maka tatkala mereka telah kembali kepada ayah mereka, mereka berkata, ``Wahai ayah kami! Kami tidak akan mendapat sukatan) gandum lagi, jika ayah tidak mengizinkan saudara kami Bunyamin untuk menghadap kepadanya (sebab itu biarkanlah saudara kami pergi bersama kami supaya kami mendapat sukatan) menurut suatu qiraat dibaca yaktal artinya, supaya mendapat sukatan (dan sesungguhnya kami akan benar-benar menjaganya.").\qt@no{63}}%
\qt@newcmd\qurantrans@id@mdclx{%
(Berkata Yakub, ``Bagaimana) tiada (aku akan mempercayakannya kepada kalian, kecuali seperti aku mempercayakan saudaranya kepada kalian) yang dimaksud adalah Nabi Yusuf (dahulu?) dan ternyata kalian telah mencelakakannya. (Maka Allah adalah sebaik-baik penjaga) menurut qiraat yang lain lafal haafizhan dibaca hifzhan dengan kedudukan menjadi tamyiz; perihalnya sama dengan perkataan mereka/orang-orang Arab lillaahi darruhu faarisan (dan Dia adalah Maha Penyayang di antara para penyayang.") maka aku memohon semoga Dia menganugerahkan pemeliharaan-Nya terhadap Nabi Yusuf.\qt@no{64}}%
\qt@newcmd\qurantrans@id@mdclxi{%
(Tatkala mereka membuka barang-barangnya, mereka menemukan kembali barang-barang penukaran mereka dikembalikan kepada mereka. Mereka berkata, ``Wahai ayah kami! Apalagi yang kita inginkan) huruf maa di sini merupakan kata tanya, artinya apalagi yang kita cari lebih dari penghormatan yang telah diberikan oleh sang raja? Menurut qiraat lafal nabghii dibaca tabghii sebagai khithab atau pembicaraan yang ditujukan kepada Nabi Yakub. Karena mereka menceritakan kepadanya tentang penghormatan sang raja terhadap mereka. (Ini barang-barang kita dikembalikan kepada kita dan kami akan dapat memberi makan keluarga kami) artinya kami dapat membawa perbekalan makanan buat mereka (dan kami akan menjaga saudara kami dan kami akan mendapat tambahan sukatan seberat beban seekor unta) untuk saudara kami Bunyamin. (Itulah sukatan yang mudah.") bagi raja Mesir, karena ia orangnya sangat dermawan.\qt@no{65}}%
\qt@newcmd\qurantrans@id@mdclxii{%
(Yakub berkata, ``Aku sekali-kali tidak akan melepaskannya pergi bersama kalian sebelum kalian memberikan kepadaku janji yang teguh) sumpah (atas nama Allah) seumpamanya kalian bersumpah (bahwa kalian pasti akan membawanya kepadaku kembali kecuali jika kalian dikepung musuh.") seumpamanya kalian semuanya mati, atau kalian dikalahkan oleh musuh sehingga kalian tidak mampu membawa Bunyamin kembali kepadaku. Lalu mereka menyetujui hal tersebut. (Tatkala mereka memberikan janji mereka) mengikrarkan hal tersebut (maka Yakub berkata, ``Allah terhadap apa yang kita ucapkan) ini, yaitu saya dan kalian (adalah menjadi saksi.") menyaksikannya kemudian Nabi Yakub memberikan izin kepada mereka untuk membawa serta Bunyamin.\qt@no{66}}%
\qt@newcmd\qurantrans@id@mdclxiii{%
(Dan Yakub berkata, ``Hai anak-anakku! Janganlah kalian masuk) ke negeri Mesir (dari satu pintu gerbang, tetapi masuklah dari pintu-pintu gerbang yang berlainan) supaya kalian tidak menjadi sial karenanya (namun demikian aku tidak dapat menghindarkan) menolak (diri kalian) dengan melalui saranku ini (dari takdir Allah) huruf min di sini adalah zaidah (barang sedikit pun) yang telah ditakdirkan-Nya terhadap kalian; sesungguhnya hal tersebut hanyalah terdorong oleh rasa sayangku. (Tiada lain) (keputusan hanyalah hak Allah) semata (dan hanya kepada-Nyalah aku bertawakal) artinya hanya kepada-Nyalah aku percaya (dan hanya kepada-Nyalah hendaknya orang-orang yang bertawakal berserah diri.")\qt@no{67}}%
\qt@newcmd\qurantrans@id@mdclxiv{%
Allah berfirman: (Dan tatkala mereka masuk menurut yang diperintahkan oleh ayah mereka) yaitu masuk secara berpencar-pencar (maka hal itu tidak dapat melepaskan diri mereka dari Allah) yakni dari kepastian-Nya (barang) huruf min di sini adalah zaidah (sedikit pun akan tetapi itu hanya) tetapi hal itu hanyalah (suatu keinginan pada diri Yakub yang telah ditunaikannya) yaitu bermaksud untuk menghindarkan mereka dari kesialan karena terdorong oleh rasa sayang (dan sesungguhnya dia mempunyai pengetahuan karena Kami telah mengajarkan kepadanya) disebabkan Kami telah mengajarkan kepadanya (akan tetapi kebanyakan manusia) mereka adalah orang-orang kafir (tiada mengetahui.) ilham Allah yang dianugerahkan kepada orang-orang pilihan-Nya.\qt@no{68}}%
\qt@newcmd\qurantrans@id@mdclxv{%
(Dan tatkala mereka masuk ke tempat Yusuf, Yusuf menempatkan) yakni membawa saudaranya Bunyamin (saudaranya ke tempatnya. Yusuf berkata, ``Sesungguhnya aku ini adalah saudaramu, maka janganlah kamu berduka cita) bersedih hati (terhadap apa yang telah mereka lakukan.") yaitu kedengkian mereka terhadap kita. Kemudian Nabi Yusuf menyuruh Bunyamin supaya jangan menceritakan hal ini kepada mereka. Yusuf telah bersepakat dengan Bunyamin, bahwa ia akan membuat siasat supaya Bunyamin tetap tinggal bersamanya.\qt@no{69}}%
\qt@newcmd\qurantrans@id@mdclxvi{%
(Maka tatkala telah disiapkan untuk mereka bahan makanan mereka, Yusuf memasukkan piala tempat minum) teko yang terbuat dari emas dan dihiasi dengan permata (ke dalam karung saudaranya) yaitu karung kepunyaan Bunyamin (kemudian berteriaklah seseorang yang menyerukan) setelah mereka berpisah dari majelis Yusuf, tiba-tiba terdengar ada seseorang yang berseru ("Hai kafilah!) rombongan musafir (Sesungguhnya kalian adalah orang-orang yang mencuri.").\qt@no{70}}%
\qt@newcmd\qurantrans@id@mdclxvii{%
(Mereka menjawab sambil) seraya (menghadap kepada penyeru-penyeru itu, ``Barang apakah) sesuatu apakah yang (hilang daripada kalian.").\qt@no{71}}%
\qt@newcmd\qurantrans@id@mdclxviii{%
(Penyeru-penyeru itu berkata, ``Kami kehilangan piala) teko (raja dan bagi siapa yang dapat mengembalikannya akan memperoleh hadiah seberat beban unta) berupa bahan makanan (dan aku terhadapnya) tentang hadiah itu (menjadi penjamin.") yang menanggungnya.\qt@no{72}}%
\qt@newcmd\qurantrans@id@mdclxix{%
(Saudara-saudara Yusuf menjawab, ``Demi Allah) sumpah yang di dalamnya terkandung makna takjub (sesungguhnya kalian mengetahui bahwa kami datang bukan untuk membuat kerusakan di negeri ini dan kami bukanlah orang-orang pencuri.") kami sama sekali belum pernah mencuri.\qt@no{73}}%
\qt@newcmd\qurantrans@id@mdclxx{%
(Penyeru-penyeru itu berkata) yakni juru penyeru dan teman-temannya ("Tetapi apa balasannya) bagi si pencuri (jika kalian betul-betul pendusta?") kalian berdusta di dalam pengakuan kalian yang mengatakan bahwa kalian tidak mencuri. Kemudian ternyata piala tersebut ditemukan dalam barang kalian.\qt@no{74}}%
\qt@newcmd\qurantrans@id@mdclxxi{%
(Mereka menjawab, ``Balasannya) lafal jazaauhu ini menjadi mubtada, sedangkan khabarnya ialah (ialah pada siapa ditemukan barang yang hilang itu dalam karungnya) maka ia harus dijadikan budak. Kemudian diperkuat dengan berikutnya (maka dia sendirilah) si pencuri itu sendiri (balasannya.") sebagai tebusan dari barang yang dicurinya, bukan orang lain. Ketentuan ini yaitu orang yang mencuri dihukum menjadi budak, merupakan syariat Nabi Yakub. (Demikianlah) seperti pembalasan itu (Kami memberi pembalasan kepada orang-orang yang lalim.) yaitu karena mencuri. Kemudian para penyeru itu mengajukan usul kepada Nabi Yusuf supaya karung-karung mereka diperiksa.\qt@no{75}}%
\qt@newcmd\qurantrans@id@mdclxxii{%
(Maka mulailah Yusuf dengan karung-karung mereka) yaitu memeriksanya (sebelum memeriksa karung saudaranya sendiri) supaya mereka tidak menaruh rasa curiga terhadapnya (kemudian dia mengeluarkan piala raja itu) yakni tempat minum raja. (dari karung saudaranya.) Selanjutnya Allah berfirman mengisahkan (Demikianlah) tipu muslihat itu (Kami atur untuk mencapai maksud Yusuf) artinya, Kami ajarkan kepadanya tentang siasat untuk mengambil saudara sekandungnya (Tiada patut) Yusuf (menghukum saudaranya) dengan menjadikannya sebagai budak karena terbukti telah mencuri (menurut undang-undang raja) sesuai dengan ketentuan raja Mesir, karena hukuman bagi pencuri menurut undang-undang raja Mesir ialah dipukuli dan dikenai denda sebanyak dua kali lipat harga barang yang dicurinya, bukannya dijadikan sebagai budak (kecuali Allah menghendaki-Nya) yakni menghendaki supaya Yusuf menghukum saudaranya sesuai dengan ketentuan syariat Nabi Yakub. Artinya Nabi Yusuf tidak dapat menghukumnya kecuali Allah menghendaki melalui wahyu-Nya supaya Nabi Yusuf menghukum saudaranya itu sesuai dengan syariat yang berlaku pada mereka (Kami tinggikan derajat orang yang Kami kehendaki) melalui ilmu seperti yang Kami lakukan terhadap Yusuf. Lafal ayat ini dapat dibaca secara idhafah, yaitu menjadi darajaati man nasyaau, dan dapat pula dibaca darajaatin man nasyaau (dan di atas tiap-tiap orang berpengetahuan itu) di antara semua makhluk (ada lagi yang Maha Mengetahui.) artinya yang lebih mengetahui daripadanya sehingga rentetannya selesai pada Allah swt.\qt@no{76}}%
\qt@newcmd\qurantrans@id@mdclxxiii{%
(Mereka berkata, ``Jika ia mencuri maka sesungguhnya telah pernah mencuri pula saudaranya sebelum itu.") yang dimaksud oleh mereka adalah Yusuf. Disebutkan bahwa Nabi Yusuf dahulu pernah mencuri sebuah berhala yang terbuat dari emas milik ayah ibunya kemudian berhala tersebut dihancurkannya; dimaksud supaya ia tidak menyembahnya. (Maka Yusuf menyembunyikan kejengkelan itu pada dirinya dan tidak menampakkannya) tidak melahirkannya (kepada mereka) dhamir atau kata ganti yang ada pada kalimat ayat ini merujuk kepada pengertian yang tersirat di dalam perkataan Nabi Yusuf berikut ini, yaitu: (Dia berkata,) di dalam hatinya ("Kalian lebih buruk kedudukannya) daripada Yusuf dan saudara sekandungnya karena kalian telah mencuri saudara kalian, yaitu Nabi Yusuf sendiri dari tangan ayah kalian kemudian kalian telah berbuat aniaya terhadap dirinya (dan Allah Maha Mengetahui) mengetahui (apa yang kalian terangkan itu.") apa yang kalian sebutkan tentang perkara Yusuf itu.\qt@no{77}}%
\qt@newcmd\qurantrans@id@mdclxxiv{%
(Mereka berkata, ``Wahai Al-Aziz! Sesungguhnya ia mempunyai ayah yang sudah lanjut usianya) yang sangat mencintainya lebih daripada kecintaannya terhadap kami. Ia selalu menghibur dirinya dengan dia dari anaknya yang hilang dahulu karena ia sangat sedih sekali dengan kehilangannya (oleh karena itu ambillah salah seorang di antara kami) kemudian jadikanlah dia sebagai hamba sahayamu (sebagai gantinya.) penggantinya (Sesungguhnya kami melihat kamu termasuk orang-orang yang berbuat baik.") dalam semua tindakan-tindakanmu.\qt@no{78}}%
\qt@newcmd\qurantrans@id@mdclxxv{%
(Berkata Yusuf, ``Aku berlindung kepada Allah) lafal ini dinashabkan karena menjadi mashdar sedangkan fi`ilnya tidak disebutkan kemudian dimudhafkan kepada maf`ulnya; artinya aku mohon perlindungan kepada Allah (daripada menahan seorang kecuali orang yang kami temukan harta benda kami padanya) Nabi Yusuf dalam hal ini tidak memakai kata mencuri demi untuk memelihara diri daripada perkataan dusta (jika kami berbuat demikian, maka benar-benarlah kami) yaitu jika kami menghukum selainnya (orang-orang yang lalim.")\qt@no{79}}%
\qt@newcmd\qurantrans@id@mdclxxvi{%
(Maka tatkala mereka berputus asa) tidak mempunyai harapan lagi (daripada putusan Yusuf, mereka menyendiri) berkumpul menyendiri (sambil berunding dengan berbisik-bisik) lafal najiyyan adalah mashdar yang maknanya boleh untuk seorang dan orang banyak; artinya sebagian dari mereka berbisik-bisik kepada sebagian yang lain (Berkatalah yang tertua di antara mereka) yang umurnya paling besar, yaitu Rubel atau Raya yang dikenal juga dengan nama Yahudza ("Tidakkah kalian ketahui bahwa sesungguhnya ayah kalian telah mengambil janji dari kalian) kalian telah bersumpah terhadapnya (dengan nama Allah) tentang saudara kalian ini, yaitu Bunyamin (dan sebelum itu) huruf maa pada kalimat ini zaidah (kalian telah menyia-nyiakan Yusuf) tetapi menurut pendapat yang lain huruf maa di sini adalah mashdariyah dan berkedudukan menjadi mubtada, sedangkan khabarnya adalah lafal min qablu. (Sebab itu aku tidak akan meninggalkan) tidak akan angkat kaki dari (negeri ini) yaitu negeri Mesir (sampai ayahku mengizinkan kepadaku) untuk kembali kepadanya (atau Allah memberi keputusan terhadapku) tentang pembebasan saudaraku Bunyamin ini. (Dan Dia adalah Hakim yang sebaik-baiknya.") yakni yang paling adil di antara kesemuanya.\qt@no{80}}%
\qt@newcmd\qurantrans@id@mdclxxvii{%
(Kembalilah kepada ayah kalian, dan katakanlah, ``Wahai ayah kami! Sesungguhnya anakmu telah mencuri; dan kami tiada menyaksikan) terhadapnya (melainkan berdasarkan apa yang telah kami ketahui) karena mereka merasa yakin setelah melihat dan menyaksikan adanya piala raja di dalam karung Bunyamin (dan sekali-kali terhadap barang yang gaib kami tidak) hal-hal yang gaib daripada kami sewaktu kami memberikan janji kepadamu (dapat menjaganya.) seandainya kami mengetahui apa yang akan terjadi kemudian, yaitu bahwasanya dia akan mencuri, niscaya kami tidak akan membawanya ikut bersama kami.\qt@no{81}}%
\qt@newcmd\qurantrans@id@mdclxxviii{%
(Dan tanyalah penduduk negeri yang kami berada di situ) yakni negeri Mesir; artinya kirimkanlah utusan ke negeri Mesir kemudian tanyakanlah kepada penduduknya (dan kafilah) rombongan musafir (yang kami datang bersamanya) mereka adalah terdiri dari kaum Kan`an (dan sesungguhnya kami adalah orang-orang yang benar.") di dalam perkataan kami ini. Kemudian mereka kembali kepada ayah mereka dan mengatakan seperti yang diajarkan oleh saudara mereka yang tertua.\qt@no{82}}%
\qt@newcmd\qurantrans@id@mdclxxix{%
(Yakub berkata, ``Bahkan telah menggoda) menganggap baik (kalian diri kalian sendiri perbuatan buruk itu) kemudian kalian mengerjakan perbuatan itu lagi. Nabi Yakub menuduh mereka seperti tuduhannya terhadap mereka mengenai peristiwa yang menimpa Nabi Yusuf dahulu. (Maka kesabaran yang baik itu) adalah kesabaranku. (Mudah-mudahan Allah mendatangkan mereka kepadaku) yaitu Yusuf dan saudaranya (semuanya; sesungguhnya Dialah Yang Maha Mengetahui) tentang keadaanku (lagi Maha Bijaksana.") di dalam perbuatan-Nya.\qt@no{83}}%
\qt@newcmd\qurantrans@id@mdclxxx{%
(Dan Yakub berpaling dari mereka) seraya tidak meladeni pembicaraan mereka (seraya berkata, ``Aduhai, duka-citaku) huruf alif yang terdapat pada kata yaa asafaa merupakan pergantian daripada huruf ya idhafat; artinya aduhai alangkah sedihnya (terhadap Yusuf," dan kedua matanya menjadi putih) bagian yang hitam dari matanya tertutup oleh benda yang putih karena terlalu banyak menangis (karena kesedihan) terhadap Yusuf (dan dia adalah seorang yang menahan amarah) terhadap anak-anaknya akan tetapi ia tidak menampakkan kemarahannya itu dan menahannya.\qt@no{84}}%
\qt@newcmd\qurantrans@id@mdclxxxi{%
(Mereka berkata, ``Demi Allah) tiada (henti-hentinya) terus-menerus (engkau masih mengingat Yusuf sehingga kamu mengidap penyakit yang amat berat) hampir binasa, karena penyakitmu yang berkepanjangan itu. Lafal haradhan berbentuk mashdar yang maknanya dapat diartikan untuk satu orang dan lebih (atau termasuk orang-orang yang binasa.") orang-orang yang akan mati.\qt@no{85}}%
\qt@newcmd\qurantrans@id@mdclxxxii{%
(Yakub menjawab) terhadap anak-anaknya ("Sesungguhnya aku mengadukan kesedihanku) yaitu kesusahan yang besar yang tidak dapat ditahan lagi; sehingga orang yang bersangkutan tidak mampu lagi menahannya lalu mengadukannya kepada orang lain (dan kesusahanku hanya kepada Allah) bukan kepada yang lain-Nya, karena hanya Dialah yang dapat menyelesaikan pengaduanku ini (dan aku mengetahui dari Allah apa yang tidak kalian ketahui.") yaitu bahwasanya mimpi Yusuf itu adalah benar, dia masih tetap hidup. Kemudian ia berkata:\qt@no{86}}%
\qt@newcmd\qurantrans@id@mdclxxxiii{%
("Hai anak-anakku! Pergilah kalian, maka carilah berita tentang Yusuf dan saudara sekandungnya) artinya carilah berita tentang keduanya (dan jangan kalian berputus asa) putus harapan (dari rahmat Allah) dari rahmat-Nya (Sesungguhnya tiada berputus asa dari rahmat Allah melainkan kaum yang kafir.") Lalu mereka berangkat menuju ke negeri Mesir.\qt@no{87}}%
\qt@newcmd\qurantrans@id@mdclxxxiv{%
(Maka ketika mereka masuk ke tempat Yusuf mereka berkata, ``Hai Al-Aziz! Kami dan keluarga kami ditimpa kesengsaraan) yakni kelaparan (dan kami datang membawa barang-barang yang tak berharga) artinya barang-barang yang buruk; setiap orang yang melihatnya pasti akan menolaknya karena mutunya sangat rendah sekali. Disebutkan bahwa barang-barang tersebut berupa dirham-dirham palsu atau barang-barang lainnya (maka sempurnakanlah) genapkanlah (sukatan untuk kami dan bersedekahlah kepada kami) bertoleransilah terhadap kami sekali pun barang-barang kami rendah mutunya (sesungguhnya Allah memberi balasan kepada orang-orang yang bersedekah.") artinya Allah memberi mereka pahala. Akhirnya Nabi Yusuf merasa belas kasihan kepada mereka timbullah rasa sayangnya. Kemudian Nabi Yusuf berbicara secara terus terang terhadap mereka untuk menyingkapkan tabir antara dirinya dan mereka.\qt@no{88}}%
\qt@newcmd\qurantrans@id@mdclxxxv{%
(Berkatalah Yusuf) kepada mereka dengan nada mencela ("Apakah kalian mengetahui kejelekan apa yang telah kalian lakukan terhadap Yusuf) yaitu dengan memukuli dan menjualnya serta hal-hal lainnya yang menyakitkan (dan saudaranya) yakni penekanan kalian terhadapnya sesudah ia terpisah dari saudaranya (ketika kalian tidak mengetahui akibat perbuatan kalian itu?") akibat perbuatan kalian terhadap Nabi Yusuf\qt@no{89}}%
\qt@newcmd\qurantrans@id@mdclxxxvi{%
(Mereka berkata) sesudah mengetahuinya, ketika mereka mulai meneliti dan memperhatikan secara seksama tingkah laku raja ("Apakah kamu ini) dapat dibaca ainnaka dan ayinnaka (benar-benar Yusuf?" Yusuf menjawab, ``Akulah Yusuf dan ini saudaraku. Sesungguhnya telah mendapat karunia) telah memperoleh nikmat (kami dari Allah) sehingga kami dapat berkumpul. (Sesungguhnya barang siapa yang bertakwa) merasa takut kepada Allah (dan bersabar) atas apa yang menimpa dirinya (maka sesungguhnya Allah tidak menyia-nyiakan pahala orang-orang yang berbuat baik.") di dalam ungkapan ini terkandung pengertian meletakkan isim zahir pada tempat isim mudhmar.\qt@no{90}}%
\qt@newcmd\qurantrans@id@mdclxxxvii{%
(Mereka berkata, ``Demi Allah, sesungguhnya telah melebihkan kamu) telah mengutamakan kamu (Allah atas kami) dengan memperoleh kerajaan dan nikmat-nikmat lainnya (dan sesungguhnya) huruf in di sini adalah bentuk takhfif daripada inna, artinya sesungguhnya (kami adalah orang-orang yang bersalah") yakni orang-orang yang berdosa disebabkan kami telah merendahkanmu.\qt@no{91}}%
\qt@newcmd\qurantrans@id@mdclxxxviii{%
(Yusuf berkata, ``Tidak ada cercaan) tidak ada celaan (terhadap kalian pada hari ini) kata hari ini secara khusus disebutkan, sebab celaan pasti terjadi di dalamnya akan tetapi pengertiannya menunjukkan, bahwa selainnya lebih utama lagi untuk tidak mendapatkan cercaan (mudah-mudahan Allah mengampuni kalian, dan Dia adalah Maha Penyayang di antara para penyayang.") Lalu Nabi Yusuf menanyakan kepada mereka tentang keadaan ayahnya, mereka menjawab bahwa matanya telah rabun dan tidak dapat melihat dengan jelas lagi. Kemudian Nabi Yusuf berkata kepada mereka,\qt@no{92}}%
\qt@newcmd\qurantrans@id@mdclxxxix{%
("Pergilah kalian dengan membawa baju gamisku ini) yaitu baju gamis Nabi Ibrahim yang dipakainya sewaktu ia dicampakkan ke dalam api. Baju tersebut dikalungkan Nabi Yusuf sewaktu ia berada di dalam sumur. Baju tersebut dari surga; malaikat Jibril memerintahkan Nabi Yusuf supaya mengirimkannya kepada ayahnya, seraya berkata, 'Sesungguhnya pada baju itu terdapat bau surga, dan tidak sekali-kali ia diusapkan kepada orang yang sakit melainkan orang sakit itu akan sembuh dengan seketika (lalu letakkanlah dia ke wajah ayahku, nanti ia akan) menjadi (melihat kembali, dan bawalah keluarga kalian semuanya kepadaku.'").\qt@no{93}}%
\qt@newcmd\qurantrans@id@mdcxc{%
(Tatkala kafilah itu telah keluar) dari negeri Mesir (berkata ayah mereka) kepada anak-anak dan cucu-cucunya yang ada bersamanya ("Sesungguhnya aku mencium bau Yusuf) bau itu tercium oleh Nabi Yakub karena dibawa oleh angin berkat kekuasaan Allah dari jarak perjalanan tiga hari, atau delapan hari atau lebih dari itu (sekiranya kalian tidak menuduhku sebagai orang yang lemah akalnya.") maka niscaya kalian akan membenarkan aku.\qt@no{94}}%
\qt@newcmd\qurantrans@id@mdcxci{%
(Keluarganya berkata) kepadanya (Demi Allah, sesungguhnya engkau masih dalam kekeliruanmu) kesalahanmu (yang dahulu) disebabkan kecintaanmu yang berlebihan terhadap Yusuf, dan harapanmu yang selalu tak padam untuk bersua kembali dengannya sekali pun sudah lama masanya.\qt@no{95}}%
\qt@newcmd\qurantrans@id@mdcxcii{%
(Tatkala) huruf an di sini adalah zaidah (telah tiba pembawa kabar gembira) yaitu Yahudza dengan membawa baju gamis Nabi Yusuf. Dahulu dialah yang membawa baju darah Nabi Yusuf, maka kali ini ia bermaksud untuk membuat bahagia ayahnya sebagai ganti daripada perbuatannya dahulu yang membuatnya sedih (maka diletakannya baju gamis itu) ditaruhnya baju gamis itu (ke wajah Yakub, lalu kembalilah) sehat seperti semula (dapat melihat. Berkata Yakub, ``Tidakkah aku katakan kepada kalian, bahwa aku mengetahui dari Allah apa yang kalian tidak mengetahuinya.")\qt@no{96}}%
\qt@newcmd\qurantrans@id@mdcxciii{%
(Mereka berkata, ``Wahai ayah kami, mohonkanlah ampun bagi kami terhadap dosa-dosa kami, sesungguhnya kami adalah orang-orang yang bersalah.")\qt@no{97}}%
\qt@newcmd\qurantrans@id@mdcxciv{%
(Yakub berkata, ``Aku akan memohonkan ampun bagi kalian kepada Rabbku. Sesungguhnya Dialah Yang Maha Pengampun lagi Maha Penyayang.") Nabi Yakub mengakhirkan atau menangguhkan doanya itu sampai dengan waktu sahur, dimaksud supaya lebih dekat untuk diperkenankan. Atau doanya itu ia tangguhkan sampai dengan malam Jumat. Kemudian mereka semua berangkat menuju ke negeri Mesir; dan Nabi Yusuf beserta pembesar-pembesar negeri Mesir lainnya keluar untuk menjemput kedatangan mereka.\qt@no{98}}%
\qt@newcmd\qurantrans@id@mdcxcv{%
(Maka tatkala mereka masuk ke tempat Yusuf) yaitu ke kemah Nabi Yusuf (Yusuf merangkul) memeluk (ibu-bapaknya) kedua orang tuanya atau bapak dan bibinya (dan dia berkata) kepada mereka ("Masuklah kalian ke negeri Mesir dalam keadaan aman.") lalu mereka memasuki negeri Mesir dan Nabi Yusuf lalu duduk di atas singgasananya.\qt@no{99}}%
\qt@newcmd\qurantrans@id@mdcxcvi{%
(Dan ia menaikkan kedua ibu-bapaknya) yakni Yusuf mendudukkan kedua orang tuanya sejajar dengannya (ke atas singgasananya.) tempat duduknya (Dan mereka merebahkan diri) yakni kedua orang tuanya dan semua saudara-saudaranya (kepada Yusuf seraya bersujud) yang dimaksud adalah sujud dengan membungkukkan badan bukannya sujud dalam arti kata meletakkan kening; cara itu merupakan penghormatan yang berlaku pada zamannya. (Dan berkata Yusuf, ``Wahai ayahku! Inilah takwil mimpiku yang dahulu itu, sesungguhnya Rabbku telah menjadikannya suatu kenyataan. Dan sesungguhnya Rabbku telah berbuat baik kepadaku) terhadap diriku (ketika Dia membebaskan aku dari rumah penjara) Nabi Yusuf tidak menyinggung masalah sumur, hal ini sengaja ia lakukan demi menghormati saudara-saudaranya supaya mereka tidak malu (dan ketika membawa kalian dari dusun padang pasir) dari kampung padang pasir (setelah dirusak) dikacaukan (oleh setan hubungan antara aku dan saudara-saudaraku. Sesungguhnya Rabbku Maha Lembut terhadap apa yang Dia kehendaki. Sesungguhnya Dialah Yang Maha Mengetahui) tentang makhluk-Nya (lagi Maha Bijaksana.") di dalam pekerjaan-Nya. Kemudian ayah Nabi Yusuf (Yakub) bermukim bersama Yusuf selama dua puluh empat tahun atau tujuh belas tahun. Disebutkan bahwa masa perpisahan mereka delapan belas tahun lamanya atau empat puluh tahun atau delapan puluh tahun. Kemudian Nabi Yakub menjelang ajalnya, sebelum itu ia berwasiat kepada Nabi Yusuf supaya ia dikebumikan di dekat ayahnya, yaitu Nabi Ishak. Lalu Nabi Yusuf membawa jenazah ayahnya ke tempat yang diisyaratkannya dalam wasiat dan mengebumikannya di tempat tersebut. Setelah itu Nabi Yusuf kembali ke Mesir dan ia tinggal di negeri itu sesudah Nabi Yakub meninggal dunia selama dua puluh tiga tahun. Ketika urusannya telah sempurna kemudian ia mengetahui bahwa dirinya tidak akan abadi dalam keadaan demikian lalu hatinya menginginkan agar ia hijrah ke kerajaan yang abadi, yakni akhirat. Untuk itu berkata seraya berdoa:\qt@no{100}}%
\qt@newcmd\qurantrans@id@mdcxcvii{%
(Ya Rabbku! Sesungguhnya Engkau telah menganugerahkan kepadaku sebagian kerajaan dan telah mengajarkan kepadaku sebagian takbir mimpi) takwil-takwil mimpi (Ya Rabb Pencipta) yang menjadikan (langit dan bumi! Engkaulah Pelindungku) yang mengatur kebaikanku (di dunia dan di akhirat, wafatkanlah aku dalam keadaan Islam dan kumpulkanlah aku dengan orang-orang yang saleh) di antara bapak moyangku. Maka setelah ia berdoa, ia hidup hanya seminggu atau lebih dari seminggu. Kemudian ia wafat, pada saat itu usianya telah mencapai seratus dua puluh tahun. Lalu semua orang Mesir mengiringkan jenazahnya sampai ke tempat kuburannya; mereka meletakkan jenazah Nabi Yusuf di dalam sebuah tabelah yang terbuat dari marmer, dan mereka mengebumikannya di tempat yang terletak di antara kedua tepi sungai Nil, dimaksud supaya keberkahan terlimpahkan kepada kedua tepi sungai Nil. Maha Suci Allah yang tiada akhir bagi kerajaan-Nya.\qt@no{101}}%
\qt@newcmd\qurantrans@id@mdcxcviii{%
(Demikian itu) hal yang telah disebutkan itu menyangkut kisah tentang Nabi Yusuf (di antara berita-berita yang gaib) kisah-kisah yang tidak diketahui olehmu hai Muhammad sebelumnya (yang Kami wahyukan kepadamu padahal kamu tidak berada pada sisi mereka) yang dimaksud adalah saudara-saudara Nabi Yusuf (ketika mereka memutuskan rencananya) untuk berbuat makar terhadap Nabi Yusuf, yaitu memasukkannya ke dalam sumur (dan mereka sedang mengatur tipu daya) terhadap Nabi Yusuf. Artinya engkau tidak hadir bersama mereka, maka bagaimana engkau dapat mengetahui kisah mereka lalu engkau menceritakannya, tetapi hal ini hanya dapat kamu ketahui melalui wahyu.\qt@no{102}}%
\qt@newcmd\qurantrans@id@mdcxcix{%
(Dan tiadalah sebagian besar manusia) yang dimaksud adalah penduduk kota Mekah (walaupun kamu sangat menginginkannya) menginginkan mereka supaya mau beriman (akan beriman).\qt@no{103}}%
\qt@newcmd\qurantrans@id@mdcc{%
(Dan kamu sekali-kali tidak meminta kepada mereka atas seruanmu) yakni Alquran (suatu upah pun) yang kamu ambil sebagai imbalannya (Tidak lain) (ia) yakni Alquran (hanyalah pengajaran) nasihat (bagi semesta alam).\qt@no{104}}%
\qt@newcmd\qurantrans@id@mdcci{%
(Dan banyak sekali) sudah berapa banyak (tanda-tanda) yang menunjukkan keesaan Allah (di langit dan di bumi yang mereka melaluinya) artinya mereka menyaksikannya (sedangkan mereka berpaling daripadanya.) tidak mau memikirkan tentangnya.\qt@no{105}}%
\qt@newcmd\qurantrans@id@mdccii{%
(Dan sebagian besar dari mereka tidak beriman kepada Allah) mereka tidak mau mengakui bahwa Allah adalah Yang Menciptakan dan Yang Memberi rezeki (melainkan dalam keadaan mempersekutukan) Allah melalui penyembahan mereka kepada berhala-berhala. Oleh karenanya mereka mengatakan di dalam seruan-seruan mereka, ``Kupenuhi seruan-Mu; tiada sekutu bagi-Mu kecuali sekutu yang bagi-Mu; Kamu memilikinya akan tetapi dia tidak memiliki." Yang mereka maksud adalah berhala-berhala yang mereka sembah itu.\qt@no{106}}%
\qt@newcmd\qurantrans@id@mdcciii{%
(Apakah mereka merasa aman dari kedatangan pembalasan) yang meliputi mereka semuanya (berupa siksa Allah atau kedatangan kiamat kepada mereka secara mendadak) secara tiba-tiba (sedang mereka tidak menyadarinya?) sebelumnya akan kedatangan hari kiamat itu.\qt@no{107}}%
\qt@newcmd\qurantrans@id@mdcciv{%
(Katakanlah) kepada mereka ("Inilah jalanku) pengertian jalan di sini dijelaskan oleh firman berikutnya; yaitu: (aku mengajak kepada) agama (Allah dengan hujah yang nyata) hujah yang jelas lagi gamblang (yaitu aku dan orang-orang yang mengikutiku) orang-orang yang beriman kepadaku. Lafal man diathafkan kepada lafal ana yang berkedudukan menjadi mubtada daripada khabar yang disebutkan sebelumnya (Maha Suci Allah) kalimat ini dimaksud mensucikan Allah daripada semua jenis sekutu (dan aku tiada termasuk orang-orang yang musyrik.") kalimat ini termasuk ke dalam rangkaian keterangan daripada lafal sabiilii di atas.\qt@no{108}}%
\qt@newcmd\qurantrans@id@mdccv{%
(Kami tidak mengutus sebelum kamu melainkan orang laki-laki yang Kami berikan wahyu) dan menurut suatu qiraat dibaca yuuhaa; artinya yang diberikan wahyu (kepada mereka) bukannya malaikat (di antara penduduk negeri) yakni penduduk kota-kota, sebab penduduk kota lebih mengetahui dan lebih menyantun, berbeda halnya dengan penduduk kampung yang terkenal dengan kekasaran sikap mereka dan kebodohannya itu (Maka tidaklah mereka bepergian) yang dimaksud adalah penduduk Mekah (di muka bumi lalu melihat bagaimana kesudahan orang-orang sebelum mereka) akibat daripada perbuatan mereka yang mendustakan rasul-rasul mereka, yaitu mereka dibinasakan (dan sesungguhnya kampung akhirat) yakni surga Allah (lebih baik bagi orang-orang yang bertakwa) kepada Allah (Maka tidakkah kalian memikirkannya?) hai penduduk Mekah, lalu kalian menjadi beriman karenanya. Lafal ta`qiluuna dapat pula dibaca ya`qiluuna yang artinya apakah mereka tidak memikirkannya?\qt@no{109}}%
\qt@newcmd\qurantrans@id@mdccvi{%
(Sehingga) lafal hattaa menunjukkan makna batas atau limit waktu daripada pengertian yang terkandung di dalam firman-Nya, ``Kami tidak mengutus sebelum kalian melainkan seorang laki-laki..." Artinya: Maka Allah menangguhkan pertolongan-Nya terhadap mereka hingga (bila merasa putus asa) putus harapan (para rasul itu dan mereka telah menyakini) para rasul itu merasa yakin (bahwasanya mereka benar-benar telah didustakan) sungguh-sungguh didustakan sehingga mereka tidak dapat diharapkan lagi untuk beriman; makna ini dibaca kudzdzibuu. Bila dibaca kudzibuu tanpa memakai tasydid, artinya umat-umat tersebut merasa yakin bahwa para rasul telah mengingkari ancaman yang telah mereka berikan kepadanya, yaitu mendapat pertolongan dari Allah (maka datanglah pertolongan Kami kepada mereka lalu Kami selamatkan) dibaca dengan memakai dua huruf nun yang pertama dibaca takhfif sedang yang kedua dibaca tasydid, atau dibaca nujjiya menjadi fi`il madhi (orang-orang yang Kami kehendaki. Dan tidak dapat ditolak siksa Kami) azab Kami (daripada orang-orang yang berdosa.) yakni orang-orang musyrik.\qt@no{110}}%
\qt@newcmd\qurantrans@id@mdccvii{%
(Sesungguhnya pada kisah mereka itu terdapat) yang dimaksud adalah kisah-kisah para rasul (pengajaran bagi orang-orang yang mempunyai akal) orang-orang yang berakal (Ini bukanlah) Alquran ini bukanlah (cerita yang dibuat-buat) sengaja dibuat-buat (akan tetapi) tetapi (membenarkan kitab-kitab yang sebelumnya) kitab-kitab yang diturunkan sebelum Alquran (dan menjelaskan) menerangkan (segala sesuatu) yang diperlukan dalam agama (dan sebagai petunjuk) dari kesesatan (dan rahmat bagi kaum yang beriman) mereka disebutkan secara khusus dalam ayat ini mengingat hanya mereka sajalah yang dapat mengambil manfaat Alquran bukan orang-orang selain mereka.\qt@no{111}}%
\qt@newcmd\qurantrans@id@mdccviii{%
\basmalahid (Alif laam raa) hanya Allahlah yang mengetahui maksudnya (Ini adalah) ayat-ayat ini (sebagian dari Alkitab) yakni Alquran; idhafat mengandung makna min, yaitu bermakna sebagian (Dan kitab yang diturunkan kepadamu dari Rabbmu itu) maksudnya Alquran. Kalimat ayat ini berkedudukan menjadi mubtada sedangkan khabarnya ialah (adalah benar) tiada keraguan di dalamnya (akan tetapi kebanyakan manusia) yakni penduduk kota Mekah (tidak beriman) bahwasanya Alquran itu dari sisi Allah swt.\qt@no{1}}%
\qt@newcmd\qurantrans@id@mdccix{%
(Allahlah yang meninggikan langit tanpa tiang sebagaimana yang kalian lihat) lafal `amad merupakan bentuk jamak dari kata tunggal `imaad, yang artinya ialah tiang penyanggah. Dan memang sebagaimana yang terlihat langit itu tidak mempunyai tiang penyanggah (kemudian Dia berkuasa di atas Arsy) dalam arti kata kekuasaan yang layak bagi keagungan-Nya (dan menundukkan) menjinakkan (matahari dan bulan. Masing-masing) daripada matahari dan bulan itu (beredar) pada garis edarnya (hingga waktu yang ditentukan) yaitu hari kiamat. (Allah mengatur semua urusan) yakni memutuskan semua perkara kerajaan-Nya (menjelaskan) menerangkan (tanda-tanda) yang menunjukkan akan kekuasaan-Nya (supaya kalian) hai penduduk kota Mekah (terhadap hari pertemuan dengan Rabb kalian) melalui hari berbangkit (meyakininya).\qt@no{2}}%
\qt@newcmd\qurantrans@id@mdccx{%
(Dan Dialah yang membentangkan) menghamparkan (bumi dan menjadikan) membuat (gunung-gunung padanya) gunung-gunung yang kokoh (dan sungai-sungai. Dan menjadikan padanya semua buah-buahan berpasang-pasangan) dari setiap jenis yang ada (Allah menutupkan) menutup (malam) dengan kegelapannya (kepada siang. Sesungguhnya pada yang demikian itu) dalam hal yang telah disebutkan itu (terdapat tanda-tanda) bukti-bukti yang menunjukkan akan keesaan Allah swt. (bagi kaum yang memikirkan) tentang ciptaan Allah.\qt@no{3}}%
\qt@newcmd\qurantrans@id@mdccxi{%
(Dan di bumi terdapat bagian-bagian) berbagai macam daerah (yang berdampingan) yang saling berdekatan; di antaranya ada yang subur dan ada yang tandus; dan di antaranya lagi ada yang kekurangan air dan yang banyak airnya; hal ini merupakan bukti-bukti yang menunjukkan kepada kekuasaan-Nya (dan kebun-kebun) ladang-ladang (anggur, tanam-tanaman) dibaca rafa', yaitu zar'un karena diathafkan kepada lafal jannatun. Kalau dibaca jar, yaitu zar'in diathafkan kepada lafal a'naabin, demikian pula firman-Nya: (dan pohon kurma yang bercabang) lafal shinwaanun adalah bentuk jamak dari kata tunggal shinwun, artinya pohon kurma yang banyak cabangnya (dan yang tidak bercabang) pohon kurma yang tidak banyak cabangnya (disirami) kalau dibaca tusqaa, artinya kebun-kebun dan pohon-pohon yang ada padanya disirami. Dan kalau dibaca yusqa, artinya hal tersebut disirami (dengan air yang sama. Kami melebihkan) dapat dibaca nufadhdhilu dan yufadhdhilu (sebagian tanam-tanaman itu atas sebagian yang lain tentang rasanya) dapat dibaca al-ukuli dan al-ukli, artinya dalam hal rasa; yaitu ada yang manis dan ada yang masam. Hal ini merupakan tanda yang menunjukkan kepada kekuasaan Allah swt. (Sesungguhnya pada yang demikian itu) dalam hal tersebut (terdapat tanda-tanda bagi kaum yang berpikir) yaitu bagi orang-orang yang mau memikirkannya.\qt@no{4}}%
\qt@newcmd\qurantrans@id@mdccxii{%
(Dan jika kamu merasa heran) hai Muhammad, tentang pendustaan yang dilakukan oleh orang-orang kafir terhadap dirimu (maka yang patut mengherankan) lebih berhak untuk ditakjubi (adalah ucapan mereka) orang-orang yang mengingkari adanya hari berbangkit ("Apabila kami telah menjadi tanah, apakah kami sesungguhnya akan menjadi makhluk yang baru?") karena sesungguhnya Dzat yang mampu menciptakan makhluk dan hal-hal yang telah disebutkan tadi yang tanpa tandingan mampu pula untuk mengembalikan mereka menjadi hidup kembali. Sehubungan dengan kedua huruf hamzah pada dua tempat dalam ayat ini, yaitu a-idzaa dan a-innaa dengan menyebutkan secara jelas keduanya. Dan dapat pula dibaca secara nyata pada yang pertama sedangkan pada yang kedua diringankan kemudian dimasukkan huruf alif di antara keduanya sebagaimana boleh pula huruf alif tidak dimasukkan. Akan tetapi menurut suatu qiraat, pada tempat yang pertama memakai huruf istifham sehingga menjadi a-idzaa sedangkan pada yang kedua dibaca dalam bentuk kalimat berita sehingga bacaannya menjadi innaa lafii khalqin jadiid. Dan menurut qiraat yang lainnya lagi dibaca secara kebalikannya sehingga menjadi idzaa kunnaa turaaban a-innaa lafii khalqin jadiid (orang-orang itulah yang kafir kepada Rabb mereka dan orang-orang itulah yang diletakkan belenggu di lehernya; mereka itulah penghuni neraka, mereka kekal di dalamnya.)\qt@no{5}}%
\qt@newcmd\qurantrans@id@mdccxiii{%
Ayat ini diturunkan berkenaan dengan permintaan mereka yang menginginkan disegerakannya azab; mereka kemukakan hal ini dengan nada mengejek (Mereka meminta kepadamu supaya disegerakan datangnya keburukan) yakni azab (sebelum mereka meminta kebaikan) rahmat (padahal telah terjadi bermacam-macam contoh siksa sebelum mereka) lafal matsulaat merupakan bentuk jamak dari kata tunggal al-matslah dengan wazan ats-tsamrah; artinya siksaan-siksaan yang telah menimpa orang-orang seperti mereka dari kalangan orang-orang yang mendustakan. Mengapa mereka tidak mengambil pelajaran daripadanya? (Dan sesungguhnya Rabbmu benar-benar mempunyai ampunan yang luas bagi manusia sekali pun) walaupun (mereka zalim) dan jika tidak demikian, niscaya tidak akan tersisa di permukaan bumi ini makhluk yang melata di atasnya. (Dan sesungguhnya Rabbmu benar-benar sangat keras siksaan-Nya) terhadap orang-orang yang durhaka kepada-Nya.\qt@no{6}}%
\qt@newcmd\qurantrans@id@mdccxiv{%
(Orang-orang yang kafir berkata, ``Mengapa tidak) (diturunkan kepadanya) yakni kepada Muhammad (suatu tanda dari Rabbnya?") yakni mukjizat, seperti tongkat dan tangannya Nabi Musa, dan seperti untanya Nabi Saleh. Maka Allah berfirman, ("Sesungguhnya kamu hanyalah seorang pemberi peringatan) juru peringat bagi orang-orang yang kafir; dan tugasmu bukanlah untuk mendatangkan mukjizat-mukjizat (dan bagi tiap-tiap kaum ada orang yang memberi petunjuk") seorang nabi yang mengajak mereka untuk menyembah Rabb mereka dengan membawa mukjizat-mukjizat yang telah diberikan oleh-Nya, bukannya mukjizat-mukjiat seperti apa yang orang-orang kafir minta.\qt@no{7}}%
\qt@newcmd\qurantrans@id@mdccxv{%
(Allah mengetahui apa yang dikandung oleh setiap perempuan) apakah ia laki-laki atau perempuan, dan apakah kandungan itu berisi satu atau kembar dan lain sebagainya (dan apa yang kurang sempurna) kekurangan (pada kandungan rahim) tentang masa kandungan (dan apa yang lebih) daripada masa kandungan itu. (Dan segala sesuatu pada sisi-Nya ada ukurannya) menurut kadar dan ukuran yang tidak berlebihan.\qt@no{8}}%
\qt@newcmd\qurantrans@id@mdccxvi{%
(Yang mengetahui semua yang gaib dan yang tampak) hal-hal yang gaib dan hal-hal yang kelihatan (Yang Maha Besar) Maha Agung (lagi Maha Tinggi) di atas semua makhluk-Nya dengan cara paksa. Lafal al-muta`aal dapat pula di baca al-muta`aaliy dengan memakai huruf ya di akhirnya.\qt@no{9}}%
\qt@newcmd\qurantrans@id@mdccxvii{%
(Sama saja) menurut ilmu Allah swt. (siapa yang merahasiakan ucapannya, dan siapa yang berterus terang, dan siapa yang bersembunyi) menyembunyikan dirinya (di malam hari) di dalam kegelapannya (dan yang berjalan) yang tampak kepergiannya di dalam perjalanannya (di siang hari).\qt@no{10}}%
\qt@newcmd\qurantrans@id@mdccxviii{%
(Baginya) manusia (ada malaikat-malaikat yang selalu mengikutinya bergiliran) para malaikat yang bertugas mengawasinya (di muka) di hadapannya (dan di belakangnya) dari belakangnya (mereka menjaganya atas perintah Allah) berdasarkan perintah Allah, dari gangguan jin dan makhluk-makhluk yang lainnya. (Sesungguhnya Allah tidak mengubah keadaan sesuatu kaum) artinya Dia tidak mencabut dari mereka nikmat-Nya (sehingga mereka mengubah keadaan yang ada pada diri mereka sendiri) dari keadaan yang baik dengan melakukan perbuatan durhaka. (Dan apabila Allah menghendaki keburukan terhadap suatu kaum) yakni menimpakan azab (maka tak ada yang dapat menolaknya) dari siksaan-siksaan tersebut dan pula dari hal-hal lainnya yang telah dipastikan-Nya (dan sekali-kali tak ada bagi mereka) bagi orang-orang yang telah dikehendaki keburukan oleh Allah (selain Dia) selain Allah sendiri (seorang penolong pun) yang dapat mencegah datangnya azab Allah terhadap mereka. Huruf min di sini adalah zaidah.\qt@no{11}}%
\qt@newcmd\qurantrans@id@mdccxix{%
(Dialah Tuhan yang memperlihatkan kilat kepada kalian untuk menimbulkan ketakutan) terhadap orang-orang yang sedang musafir disebabkan suara halilintar (dan harapan) bagi orang yang bermukim terhadap turunnya hujan (dan Dia mengadakan) menciptakan (awan yang tebal) karena mengandung air hujan.\qt@no{12}}%
\qt@newcmd\qurantrans@id@mdccxx{%
(Dan guruh itu bertasbih) yaitu malaikat yang diserahi tugas untuk menggiring mendung seraya (memuji Allah) artinya ia selalu mengucapkan kalimat 'subhaanallaah wa bihamdihi' (dan) demikian pula bertasbih (para malaikat karena takut kepada-Nya) kepada Allah (dan Allah melepaskan halilintar) yaitu api yang keluar dari mendung (lalu menimpakannya kepada siapa yang Dia kehendaki) kemudian halilintar itu membakarnya. Ayat ini diturunkan berkenaan dengan seorang laki-laki yang Nabi saw. mengutus seseorang untuk menyerunya menyembah Allah. Akan tetapi laki-laki itu menjawab, ``Siapakah utusan Allah itu, dan siapakah Allah itu; apakah ia dari emas atau dari perak atau dari tembaga." Ketika itu juga turunlah halilintar menyambarnya sehingga hancur tulang batok kepalanya (dan mereka) orang-orang kafir (berbantah-bantahan) selalu membantah Nabi saw. (tentang Allah dan Dialah Tuhan Yang Maha Keras siksa-Nya) Maha Kuat atau Maha Keras azab-Nya.\qt@no{13}}%
\qt@newcmd\qurantrans@id@mdccxxi{%
(Hanya bagi Dia) bagi Allah swt. (doa yang benar) artinya kalimat-Nya, yaitu kalimat laa ilaaha illallaah (tiada Tuhan selain Allah). (Dan berhala-berhala yang mereka seru) dapat dibaca yad'uuna dan tad`uuna, artinya yang mereka sembah (selain Dia) yakni selain dari Allah, yaitu berhala-berhala (tidak dapat memperkenankan sesuatu pun bagi mereka) yakni sesuatu dari hal-hal yang mereka minta (melainkan) berkenaan (yang mirip dengan orang yang membukakan) artinya perihalnya sama dengan seseorang yang membukakan (kedua telapak tangannya ke dalam air) sedangkan ia berada di pinggir sumur, seraya menyeru air (supaya sampai kepada mulutnya) sekali pun tempat ia berada jauh dari air yang ada di dalam sumur itu (padahal air itu tidak dapat sampai kepadanya) ke mulutnya untuk selama-lamanya. Demikian pula keadaan para penyembah berhala itu, berhala-berhala yang mereka sembah itu tidak akan dapat memperkenankan kepada mereka. (Dan doa orang-orang kafir itu) penyembahan mereka terhadap berhala-berhala atau makna yang dimaksud adalah doa yang sesungguhnya (hanyalah sia-sia belaka) tidak ada artinya.\qt@no{14}}%
\qt@newcmd\qurantrans@id@mdccxxii{%
(Hanya kepada Allahlah sujud segala apa yang ada di langit dan di bumi, baik dengan kemauan sendiri) seperti orang-orang yang beriman (atau pun terpaksa) seperti orang-orang munafik dan orang-orang yang dipaksa dengan kekerasan (dan) sujud pula (bayang-bayangnya di waktu pagi) pada pagi hari (dan petang hari) sore hari.\qt@no{15}}%
\qt@newcmd\qurantrans@id@mdccxxiii{%
(Katakanlah) hai Muhammad kepada kaummu ("Siapakah Rabb langit dan bumi?" Jawabnya, ``Allah.") jika mereka tidak mau mengatakannya, maka tiada jawaban lain kecuali itu. (Katakanlah) kepada mereka ("Maka patutkah kalian mengambil selain Allah) selain-Nya (sebagai pelindung-pelindung) berhala-berhala yang kalian sembah (padahal mereka tidak memiliki kekuasaan untuk memberikan kemanfaatan dan tidak pula kemudaratan bagi diri mereka sendiri?") kemudian kalian meninggalkan untuk menyembah kepada Yang memiliki dan Yang menguasai kemanfaatan dan kemudaratan? Kata tanya di sini mengandung pengertian cemoohan dan ejekan. (Katakanlah, ``Adakah sama orang buta dan orang yang melihat?) orang kafir dan orang mukmin itu apakah sama? (atau samakah gelap-gulita) yakni kekafiran (dan terang-benderang?) yakni keimanan? Tentu saja tidak. (Apakah mereka menjadikan beberapa sekutu bagi Allah yang dapat menciptakan seperti ciptaan-Nya sehingga kedua ciptaan itu serupa) artinya sekutu-sekutu itu dapat menciptakan seperti ciptaan Allah (menurut pandangan mereka?") sehingga mereka berkeyakinan bahwa berhala-berhala atau sekutu-sekutu itu berhak untuk disembah oleh sebab kemampuan mereka dalam hal menciptakan? Kata tanya di sini mengandung makna ingkar; atau dengan kata lain berarti bahwa hakikatnya tidaklah demikian karena sesungguhnya tidak ada yang berhak untuk disembah selain daripada Yang Maha Pencipta. (Katakanlah, ``Allah adalah pencipta segala sesuatu) tiada sekutu bagi-Nya di dalam penciptaan ini, maka tiada sekutu pula bagi-Nya dalam hal disembah (dan Dialah Tuhan Yang Maha Esa lagi Maha Perkasa.") di atas semua hamba-hamba-Nya.\qt@no{16}}%
\qt@newcmd\qurantrans@id@mdccxxiv{%
Kemudian Allah membuat suatu perumpamaan mengenai perkara yang hak dan perkara yang batil untuk itu Dia berfirman: (Allah telah menurunkan) Maha Tinggi Allah (air dari langit) yakni air hujan (maka mengalirlah air di lembah-lembah menurut ukurannya) sesuai dengan daya tampungnya (maka arus itu membawa buih yang mengembang) mengapung di atas air yang mengandung kotoran dan lain sebagainya. (Dan dari apa yang mereka lebur) dapat dibaca tuuqiduuna dan yuuqiduuna (dalam api) yaitu berupa logam yang dikeluarkan dari dalam bumi, seperti emas, perak dan tembaga (untuk membuat) untuk dijadikan (perhiasan) barang perhiasan (atau alat-alat) perabot-perabot yang diperlukan, jika kesemuanya itu dilebur (ada pula buihnya) yakni sama seperti buih arus tadi, yaitu kotorannya kemudian kotoran itu dibuang oleh orang yang mencetaknya. (Demikianlah) hal yang telah disebutkan itu (Allah membuat perumpamaan bagi yang benar dan yang batil) perumpamaan mengenai keduanya. (Adapun buih itu) buih arus itu dan kotoran barang logam yang dilebur (akan hilang sebagai sesuatu yang tak ada harganya) menjadi limbah yang dibuang (adapun yang memberi manfaat kepada manusia) yaitu air bersih dan inti logam (maka ia tetap) terkandung (di bumi) selama beberapa masa. Demikianlah perumpamaan tentang hal yang batil; akan pudar dan lenyap, sekalipun dalam beberapa waktu dapat mengalahkan perkara yang hak. Akan tetapi pada akhirnya perkara yang hak jugalah yang akan tetap tegak dan menang. (Demikian) hal yang disebutkan itu (Allah menjelaskan) menerangkan (perumpamaan-perumpamaan).\qt@no{17}}%
\qt@newcmd\qurantrans@id@mdccxxv{%
(Bagi orang-orang yang memenuhi seruan Rabbnya) yaitu mereka yang menjalankan seruan-Nya dengan melakukan ketaatan (disediakan pembalasan yang baik) yaitu surga (Dan orang-orang yang tidak memenuhi seruan Rabb) mereka adalah orang-orang kafir (sekiranya mereka mempunyai semua kekayaan sebanyak isi bumi itu beserta hal yang serupa niscaya mereka akan menebus dirinya dengan kekayaan itu) dari azab. (Orang-orang itu disediakan baginya hisab yang buruk) yaitu menghukum semua amal perbuatan yang telah dilakukannya tanpa ada pengampunan barang sedikit pun daripadanya (dan tempat kediaman mereka ialah Jahanam dan itulah seburuk-buruk tempat kediaman) tempat yang paling buruk ialah Jahanam.\qt@no{18}}%
\qt@newcmd\qurantrans@id@mdccxxvi{%
Ayat berikut ini diturunkan berkenaan dengan sahabat Hamzah dan Abu Jahal. (Adakah orang yang mengetahui bahwasanya apa yang diturunkan kepadamu dari Rabbmu itu benar) lalu ia beriman kepadanya (sama dengan orang yang buta?) yaitu orang yang tidak mengetahuinya dan tidak mau beriman kepadanya. Tentu saja tidak. (Sesungguhnya yang mau mengambil pelajaran itu) orang-orang yang menasihati dirinya sendiri (hanyalah orang-orang yang berakal saja) orang-orang yang memiliki akal sehat.\qt@no{19}}%
\qt@newcmd\qurantrans@id@mdccxxvii{%
(Yaitu orang-orang yang memenuhi janji Allah) yang telah mereka ikrarkan di hadapan-Nya, yang hal ini terjadi di alam arwah, atau makna yang dimaksud adalah setiap janji (dan tidak merusak perjanjian) dengan meninggalkan keimanan atau meninggalkan hal-hal yang fardu.\qt@no{20}}%
\qt@newcmd\qurantrans@id@mdccxxviii{%
(Dan orang-orang yang menghubungkan apa-apa yang Allah perintahkan supaya dihubungkan) yaitu iman, silaturahmi dan lain sebagainya (dan mereka takut kepada Rabb mereka) ancaman-Nya (dan takut kepada hisab yang buruk) penafsiran kalimat ini telah dijelaskan sebelumnya.\qt@no{21}}%
\qt@newcmd\qurantrans@id@mdccxxix{%
(Dan orang-orang yang sabar) di dalam menjalankan ketaatan dan menghadapi musibah serta teguh di dalam menjauhi kemaksiatan (karena mencari) demi karena (Rabbnya) bukan karena mengharapkan kebendaan (dan mendirikan salat dan menafkahkan) di jalan ketaatan (sebagian rezeki yang Kami berikan kepada mereka secara sembunyi atau terang-terangan serta menolak) menghadapi (kejahatan dengan kebaikan) seperti menghadapi kebodohan dengan sifat penyantun dan menghadapi perlakuan yang menyakitkan dengan bersabar diri (orang-orang itulah yang mendapat tempat kesudahan yang baik) yakni mendapat akibat yang terpuji di kampung akhirat, yaitu:\qt@no{22}}%
\qt@newcmd\qurantrans@id@mdccxxx{%
(Surga Adn) sebagai tempat tinggalnya (yang mereka masuk ke dalamnya) bersama (dengan orang-orang yang saleh) orang-orang yang beriman (dari bapak-bapaknya, istri-istrinya dan anak-cucunya) sekali pun mereka tidak mengamalkan seperti apa yang diamalkannya, maka mereka tetap sederajat dengannya sebagai penghormatan terhadapnya (sedangkan malaikat-malaikat masuk ke tempat-tempat mereka dari setiap pintu) dari pintu-pintu surga atau pintu-pintu gedung surga, sewaktu pertama kali mereka memasukinya sebagai penghormatan dari para malaikat terhadap mereka.\qt@no{23}}%
\qt@newcmd\qurantrans@id@mdccxxxi{%
Malaikat-malaikat itu mengucapkan (Kesejahteraan buat kalian) yakni pahala ini (berkat kesabaran kalian) sewaktu kalian di dunia (maka alangkah baiknya tempat kesudahan ini) akibat dari perbuatan kalian itu.\qt@no{24}}%
\qt@newcmd\qurantrans@id@mdccxxxii{%
(Orang-orang yang merusak janji Allah setelah diikrarkan dengan teguh dan memutuskan apa-apa yang Allah perintahkan supaya dihubungkan dan mengadakan kerusakan di bumi) dengan melakukan kekafiran dan perbuatan-perbuatan maksiat (orang-orang itulah yang memperoleh kutukan) yaitu dijauhkan dari rahmat Allah (dan bagi mereka tempat kediaman yang buruk) akibat yang buruk di kampung akhirat nanti, yaitu ditempatkan di neraka Jahanam.\qt@no{25}}%
\qt@newcmd\qurantrans@id@mdccxxxiii{%
(Allah meluaskan rezeki) melebarkannya (bagi siapa yang dikehendaki-Nya dan menyempitkannya) artinya Allah pun menyempitkan rezeki bagi siapa yang dikehendaki-Nya. (Mereka bergembira) yang dimaksud ialah penduduk Mekah, yaitu dengan kegembiraan yang sombong (dengan kehidupan di dunia) dengan apa yang telah mereka peroleh daripada perkara duniawi (padahal kehidupan dunia itu) dibanding dengan (kehidupan di akhirat hanyalah kesenangan yang sedikit) kesenangan yang bersifat sementara lalu lenyap.\qt@no{26}}%
\qt@newcmd\qurantrans@id@mdccxxxiv{%
(Orang-orang kafir berkata) mereka adalah dari kalangan penduduk Mekah ("Mengapa tidak) (diturunkan kepadanya) yakni kepada Muhammad (suatu mukjizat dari Rabbnya?") seperti tongkat dan tangan Nabi Musa dan unta Nabi Saleh. (Katakanlah) kepada mereka (Allah menyesatkan siapa yang Dia kehendaki) untuk disesatkan oleh sebab itu tiada gunanya sedikit pun baginya mukjizat-mukjizat itu (dan menunjuki) memberikan petunjuk (kepada-Nya) kepada agama-Nya (orang-orang yang bertobat) kepada-Nya. Kemudian pada ayat selanjutnya diterangkan, siapa yang dimaksud orang-orang yang bertobat itu.\qt@no{27}}%
\qt@newcmd\qurantrans@id@mdccxxxv{%
(Yaitu orang-orang yang beriman dan yang merasa tenang) tenteram (hati mereka dengan mengingat Allah) mengingat janji-Nya. (Ingatlah, hanya dengan mengingat Allahlah hati menjadi tenteram) yakni hati orang-orang yang beriman.\qt@no{28}}%
\qt@newcmd\qurantrans@id@mdccxxxvi{%
(Orang-orang yang beriman dan beramal saleh) kalimat ini menjadi mubtada sedangkan khabarnya ialah (alangkah bahagianya) lafal thuubaa mashdar daripada lafal ath-thiib, adalah nama sebuah pohon di surga, seseorang yang berkendaraan tidak akan dapat menempuh naungannya sekali pun berjalan seratus tahun (bagi mereka dan tempat kembali yang baik) tempat kembali di akhirat.\qt@no{29}}%
\qt@newcmd\qurantrans@id@mdccxxxvii{%
(Demikianlah) sebagaimana Kami mengutus nabi-nabi sebelummu (Kami mengutus kamu kepada suatu umat yang sungguh telah berlalu beberapa umat sebelumnya supaya kamu membacakan) mengajarkan (kepada mereka apa yang Kami wahyukan kepadamu) yaitu Alquran (padahal mereka kafir kepada Tuhan Yang Maha Pemurah) karena mereka mengatakan sewaktu mereka disuruh sujud atau menyembah kepada-Nya siapakah Tuhan Yang Maha Pemurah? (Katakanlah) kepada mereka hai Muhammad ("Dialah Rabbku, tidak ada Tuhan selain Dia, hanya kepada-Nya aku bertawakal dan hanya kepada-Nya aku bertobat.")\qt@no{30}}%
\qt@newcmd\qurantrans@id@mdccxxxviii{%
Ayat ini diturunkan ketika orang-orang kafir Mekah berkata kepada Nabi saw., ``Jika engkau ini benar-benar seorang nabi, maka lenyapkanlah gunung-gunung Mekah ini daripada kami, kemudian jadikanlah pada tempatnya sungai-sungai dan mata air-mata air supaya kami dapat bercocok tanam, dan bangkitkanlah nenek moyang kami yang telah mati menjadi hidup kembali, untuk berbicara kepada kami." (Dan sekiranya ada suatu bacaan yang dengan bacaan itu gunung-gunung dapat dipindahkan) artinya dapat dipindahkan dari tempatnya yang semula (atau dapat dibelah) dapat dipotong (karenanya bumi, atau oleh karenanya orang-orang yang sudah mati dapat berbicara) seumpamanya mereka dapat dihidupkan kembali karenanya, niscaya mereka tetap tidak akan beriman juga. (Sebenarnya segala urusan itu adalah kepunyaan Allah) bukan kepunyaan yang lain-Nya. Oleh sebab itu maka tiada beriman melainkan orang-orang yang telah dikehendaki oleh Allah untuk beriman, bukannya orang-orang selain mereka sekali pun didatangkan kepada mereka apa yang dipintanya itu. Sedangkan ayat selanjutnya ini diturunkan ketika para sahabat berkehendak untuk menampakkan apa yang mereka minta, karena para sahabat sangat menginginkan mereka mau beriman, yaitu firman-Nya: (Maka tidakkah mengetahui) mengerti (orang-orang yang beriman itu, bahwasanya) huruf an di sini adalah bentuk takhfif daripada anna (seandainya Allah menghendaki tentu Allah memberi petunjuk kepada manusia semuanya) kepada keimanan tanpa melalui mukjizat lagi. (Dan orang-orang yang kafir senantiasa) yakni penduduk Mekah yang kafir (ditimpa bencana disebabkan perbuatan mereka sendiri) yakni oleh sebab kekafiran mereka itu (yaitu berupa malapetaka) yang menimpa mereka dengan berbagai macam cobaan, seperti dibunuh, ditawan, diperangi dan paceklik (atau bencana itu terjadi) hai Muhammad terhadap pasukanmu (dekat tempat kediaman mereka) yaitu kota Mekah (sehingga datanglah janji Allah) yaitu memberikan pertolongan-Nya untuk mengalahkan mereka. (Sesungguhnya Allah tidak menyalahi janji) hal ini telah terjadi di Hudaibiah sehingga tibalah saatnya penaklukan kota Mekah.\qt@no{31}}%
\qt@newcmd\qurantrans@id@mdccxxxix{%
(Dan sesungguhnya telah diperolok-olokkan beberapa rasul sebelum kamu) sebagaimana kamu diperolok-olokkan. Hal ini merupakan penghibur bagi hati Nabi saw. (maka Aku beri tangguh) menangguhkan (kepada orang-orang kafir itu, kemudian Aku binasakan mereka) dengan siksaan (maka sebagaimana siksaan-Ku terdahulu) artinya siksaan itu benar-benar telah menimpa orang-orang yang memperolok-olokkan para rasul, demikian pula Aku akan melakukan hal yang sama terhadap orang-orang yang memperolok-olokkan kamu.\qt@no{32}}%
\qt@newcmd\qurantrans@id@mdccxl{%
(Maka apakah Tuhan yang menjaga) yakni mengawasi (setiap diri terhadap apa yang diperbuatnya) yaitu berupa amal kebaikan dan keburukan, sama keadaan-Nya dengan berhala-berhala yang tidak demikian keadaannya; tentu saja tidak. Pengertian ini ditunjukkan oleh firman selanjutnya, yaitu (Mereka menjadikan beberapa sekutu bagi Allah. Katakanlah, ``Sebutkanlah sifat-sifat mereka itu.") kepada-Nya, siapakah berhala-berhala itu (atau) bahkan apakah (kalian hendak memberitakan kepada Allah) menceritakan kepada-Nya (mengenai apa) yakni sekutu (yang tidak diketahui)-Nya (di bumi) istifham atau kata tanya di sini mengandung pengertian ingkar; artinya jelas tidak ada sekutu itu, sebab jika sekutu itu ada niscaya Dia akan mengetahuinya, Maha Tinggi Allah dari semua sekutu (atau) bahkan mereka menamakannya sebagai sekutu-sekutu Allah (kalian mengatakan sekadar perkataan pada lahirnya) dengan sangkaan yang batil, lagi hal itu tidak ada kenyataannya pada batinnya. (Sebenarnya orang-orang kafir itu dijadikan memandang baik tipu daya mereka) yang dimaksud ialah kekafiran mereka (dan dihalanginya dari jalan yang benar) yaitu hidayah. (Dan barang siapa yang disesatkan Allah, maka tak ada seorang pun baginya yang akan memberi petunjuk).\qt@no{33}}%
\qt@newcmd\qurantrans@id@mdccxli{%
(Bagi mereka azab dalam kehidupan dunia) yaitu dengan dibunuh dan ditawan (dan sesungguhnya azab akhirat adalah lebih keras) lebih keras daripada siksaan di dunia (dan tak ada bagi mereka terhadap Allah) terhadap siksaan-Nya (seorang pelindung pun) yang dapat mencegah siksaan itu.\qt@no{34}}%
\qt@newcmd\qurantrans@id@mdccxlii{%
(Perumpamaan) gambaran (surga yang dijanjikan kepada orang-orang yang takwa) kalimat ayat ini menjadi mubtada, sedangkan khabarnya tidak disebutkan, lengkapnya mengatakan: yaitu seperti apa yang akan Kami ceritakan kepada kalian (mengalir sungai-sungai di bawahnya; buah-buahannya) artinya apa-apa yang dimakan di dalam surga (tiada henti-hentinya) tidak pernah lenyap (sedang naungannya) tiada henti-hentinya pula, tidak pernah terhapus oleh matahari, karena di dalam surga tidak ada matahari. (Itulah) yakni surga itu (tempat kesudahan) akhir daripada kesudahan (orang-orang yang bertakwa) takut kepada perbuatan syirik (sedangkan tempat kesudahan bagi orang-orang kafir ialah neraka).\qt@no{35}}%
\qt@newcmd\qurantrans@id@mdccxliii{%
(Orang-orang yang Kami berikan kitab kepada mereka) seperti Abdullah bin Salam dan lain-lainnya dari kalangan orang-orang Yahudi yang beriman (mereka bergembira dengan kitab yang diturunkan kepadamu) karena Alquran yang diturunkan kepadanya tidak bertentangan dengan kitab Taurat yang ada pada mereka (dan di antara golongan-golongan) yang telah bersekutu untuk melawan kamu, yaitu mereka yang terdiri dari kalangan kaum musyrikin dan orang-orang Yahudi (ada yang menginginkan sebagiannya) yaitu yang menyangkut tentang penyebutan lafal Ar-Rahman dan hal-hal yang lain selain yang menyangkut kisah-kisah. (Katakanlah, ``Sesungguhnya aku hanya diperintahkan) oleh apa yang diturunkan kepadaku (untuk) supaya (menyembah Allah dan tidak menyekutukan-Nya dengan sesuatu pun. Hanya kepada-Nya aku berseru dan hanya kepada-Nya aku kembali.") tempat kembaliku.\qt@no{36}}%
\qt@newcmd\qurantrans@id@mdccxliv{%
(Dan demikianlah) penurunan itu (Kami telah menurunkannya) Alquran itu (sebagai peraturan dalam bahasa Arab) yaitu dengan memakai bahasa Arab, yang dengannya engkau putuskan hukum-hukum di antara manusia. (Dan seandainya kamu mengikuti hawa nafsu mereka) hawa nafsu orang-orang kafir, dalam hal apa yang mereka inginkan, supaya kamu melakukannya menurut peraturan agama mereka. Ini hanyalah merupakan perumpamaan (setelah datang pengetahuan kepadamu) tentang tauhid (maka sekali-kali tidak ada bagimu terhadap Allah) huruf min di sini adalah zaidah (seorang penolong pun) penolong yang mau membantu menyelamatkanmu (dan tidak pula seorang pemelihara) yang dapat mencegah azab Allah yang menimpa dirimu.\qt@no{37}}%
\qt@newcmd\qurantrans@id@mdccxlv{%
Ayat ini diturunkan ketika orang-orang kafir mencela Nabi saw. karena istrinya banyak, yaitu: (Dan sesungguhnya Kami telah mengutus beberapa rasul sebelum kamu dan Kami memberikan kepada mereka istri-istri dan keturunan) yakni anak-anak, sedangkan engkau adalah salah satu di antara para rasul itu. (Dan tidak ada hak bagi seorang rasul) di antara para rasul itu (mendatangkan sesuatu ayat melainkan dengan izin Allah) karena para rasul itu tiada lain hanyalah hamba-hamba yang diasuh-Nya. (Bagi tiap-tiap masa) zaman (ada kitab) yang tertera di dalamnya tentang batas masa berlakunya.\qt@no{38}}%
\qt@newcmd\qurantrans@id@mdccxlvi{%
(Allah menghapuskan) daripada kitab itu (apa yang dikehendaki-Nya dan menetapkan) dapat dibaca yutsbitu atau yutsabbitu, artinya hukum-hukum dan masalah-masalah lainnya yang dikehendaki-Nya untuk dihapus atau ditetapkan (dan di sisi-Nyalah terdapat Ummul Kitab) asal kitab yang tidak berubah sedikit pun daripadanya, yaitu kitab-kitab-Nya di zaman azali.\qt@no{39}}%
\qt@newcmd\qurantrans@id@mdccxlvii{%
(Dan jika) asalnya lafal immaa ini terdiri daripada in syarthiyah dan maa zaidah, kemudian keduanya dijadikan satu sehingga jadilah immaa, artinya seandainya (Kami perlihatkan kepadamu sebagian apa yang Kami ancamkan kepada mereka) yaitu sebagian daripada azab-Ku sewaktu kamu masih hidup. Jawab dari in syarthiyah tidak disebutkan, lengkapnya ialah fadzaaka: itulah azab-Ku (atau Kami wafatkan kamu) sebelum orang-orang kafir itu diazab (karena sesungguhnya tugasmu hanya menyampaikan saja) hal itu tidak penting bagimu, tugasmu tiada lain hanya menyampaikan (sedangkan Kamilah yang menghisab amalan mereka) jika mereka telah kembali kepada Kami, maka Kami akan membalas semua amal perbuatan mereka.\qt@no{40}}%
\qt@newcmd\qurantrans@id@mdccxlviii{%
(Dan apakah mereka tidak melihat) yang dimaksud adalah penduduk Mekah (bahwa sesungguhnya Kami mendatangkan daerah-daerah) orang-orang kafir (lalu Kami kurangi daerah-daerah itu dari tepi-tepinya?) yaitu melalui pembukaan/penaklukan yang dilakukan oleh Nabi saw. (Dan Allah menetapkan hukum) atas makhluk-Nya menurut kehendak-Nya (tidak ada yang dapat menolak) tiada seorang pun yang dapat menolak (ketetapan-Nya; dan Dialah Yang Maha Cepat hisab-Nya.)\qt@no{41}}%
\qt@newcmd\qurantrans@id@mdccxlix{%
(Dan sungguh orang-orang kafir yang sebelum mereka telah mengadakan tipu-daya) yang dimaksud adalah umat-umat terdahulu sebelum orang-orang kafir Mekah; mereka telah berbuat makar terhadap nabi-nabi-Nya sebagaimana orang-orang kafir Mekah telah berbuat makar terhadapmu (tetapi semua tipu-daya itu adalah dalam kekuasaan Allah) tipu daya mereka tidaklah sama dengan tipu daya-Nya, karena Allah swt. (Dia mengetahui apa yang diusahakan oleh setiap diri) maka untuk itu Dia telah mempersiapkan balasan usaha itu; dan inilah yang dinamakan tipu daya secara keseluruhan. Karena sesungguhnya balasan itu menimpa mereka sewaktu mereka tidak menyadarinya. (Dan orang-orang kafir akan mengetahui) lafal al-kaafir yang dimaksud adalah makna jenis sehingga artinya menunjukkan jamak sekalipun lafalnya mufrad. Akan tetapi menurut qiraat yang lain dibaca al-kuffaaru dalam bentuk jamak (untuk siapakah tempat kesudahan yang baik itu) akibat yang paling baik di akhirat kelak; apakah untuk mereka ataukah untuk Nabi saw. dan para sahabatnya?\qt@no{42}}%
\qt@newcmd\qurantrans@id@mdccl{%
(Berkatalah orang-orang kafir) kepadamu ("Kamu bukan seorang yang dijadikan rasul." Katakanlah) kepada mereka ("Cukuplah Allah menjadi saksi antaraku dan kalian) atas kebenaranku (dan antara orang yang mempunyai ilmu Kitab.") dari kalangan orang-orang yang beriman, Yahudi dan Nasrani.\qt@no{43}}%
\qt@newcmd\qurantrans@id@mdccli{%
\basmalahid (Alif laam raa) hanya Allahlah yang mengetahui maksudnya. Alquran ini adalah (Kitab yang Kami turunkan kepadamu) Muhammad (supaya kamu mengeluarkan manusia dari kegelapan) dari kekafiran (kepada cahaya) yaitu agama Islam. (Dengan izin) perintah (Rabb mereka) lafal an-nuur diterangkan secara jelas pada ayat berikut ini: (yaitu ke jalan) tuntunan (Tuhan Yang Maha Perkasa) Maha Menang (lagi Maha Terpuji.) Yang Maha Terpuji.\qt@no{1}}%
\qt@newcmd\qurantrans@id@mdcclii{%
(Dialah Allah) kalau dibaca jar kedudukannya menjadi badal atau athaf bayan, sedangkan kedudukan kalimat yang sesudahnya menjadi sifat. Jika dibaca rafa` jadilah mubtada, sedangkan khabarnya adalah firman berikut ini: (yang memiliki segala apa yang ada di langit dan di bumi) semuanya adalah milik-Nya, hamba-Nya dan makhluk-Nya. (Dan kecelakaanlah bagi orang-orang kafir karena siksa yang sangat pedih.)\qt@no{2}}%
\qt@newcmd\qurantrans@id@mdccliii{%
(Yaitu orang-orang) kedudukannya sebagai sifat (yang lebih menyukai kehidupan dunia daripada kehidupan akhirat dan menghalang-halangi) manusia (dari jalan Allah) yaitu agama Islam (dan menginginkan supaya ia) jalan Allah tersebut (bengkok) tidak lurus. (Mereka itu berada dalam kesesatan yang jauh) yakni sesat dari jalan yang hak dan benar.\qt@no{3}}%
\qt@newcmd\qurantrans@id@mdccliv{%
(Kami tidak mengutus seorang rasul pun melainkan dengan bahasa) memakai bahasa (kaumnya, supaya ia dapat memberi pelajaran dengan terang kepada mereka) supaya mereka dapat memahami apa yang disampaikannya. (Maka Allah menyesatkan siapa yang Dia kehendaki dan memberi petunjuk kepada siapa yang Dia kehendaki. Dan Dialah Tuhan Yang Maha Kuasa) di dalam kerajaan-Nya (lagi Maha Bijaksana.) di dalam tindakan-Nya.\qt@no{4}}%
\qt@newcmd\qurantrans@id@mdcclv{%
(Dan sesungguhnya Kami telah mengutus Musa dengan membawa ayat-ayat Kami) yang berjumlah sembilan ayat lalu Kami firmankan kepadanya ("Keluarkanlah kaummu) yaitu kaum Bani Israel (dari gelap-gulita) dari kekafiran (kepada cahaya yang terang-benderang) yaitu keimanan (dan ingatkanlah mereka kepada hari-hari Allah.") yakni nikmat-nikmat-Nya. (Sesungguhnya pada yang demikian itu) yakni di dalam peringatan itu (terdapat tanda-tanda bagi setiap orang penyabar) di dalam mengerjakan ketaatan (dan banyak bersyukur) terhadap semua nikmat-nikmat-Nya.\qt@no{5}}%
\qt@newcmd\qurantrans@id@mdcclvi{%
(Dan) ingatlah (ketika Musa berkata kepada kaumnya, ``Ingatlah nikmat Allah atas kalian ketika Dia menyelamatkan kalian dari Firaun dan pengikut-pengikutnya; mereka menyiksa kalian dengan siksa yang pedih, mereka menyembelih anak laki-laki kalian) yang baru lahir (dan membiarkan hidup) membiarkan tetap hidup (anak-anak perempuan) karena ada sebagian tukang tenung yang mengatakan bahwasanya akan lahir seorang anak lelaki dari kalangan kaum Bani Israel, dia adalah penyebab bagi runtuhnya kerajaan Firaun. (Sesungguhnya pada yang demikian itu) penyelamatan atau penyiksaan (ada cobaan) baik berupa pemberian nikmat maupun penimpaan malapetaka (yang besar dari Rabb kalian.")\qt@no{6}}%
\qt@newcmd\qurantrans@id@mdcclvii{%
(Dan ingatlah pula ketika mempermaklumkan) memberitahukan (Rabb kalian sesungguhnya jika kalian bersyukur) akan nikmat-Ku dengan menjalankan ketauhidan dan ketaatan (pasti Kami akan menambah nikmat kepada kalian dan jika kalian mengingkari nikmat-Ku) apabila kalian ingkar terhadap nikmat-Ku itu dengan berlaku kekafiran dan kedurhakaan niscaya Aku akan menurunkan azab kepada kalian. Pengertian ini diungkapkan oleh firman selanjutnya: ("Sesungguhnya azab-Ku sangat keras.")\qt@no{7}}%
\qt@newcmd\qurantrans@id@mdcclviii{%
(Dan Musa berkata) kepada kaumnya ("Jika kalian dan orang-orang yang ada di muka bumi semuanya mengingkari nikmat Allah, maka sesungguhnya Allah Maha Kaya) tidak membutuhkan makhluk-Nya (lagi Maha Terpuji.") Maha Terpuji di dalam tindakan-Nya terhadap mereka.\qt@no{8}}%
\qt@newcmd\qurantrans@id@mdcclix{%
(Belumkah sampai kepada kalian) Istifham atau kata tanya di sini mengandung makna menetapkan (berita) kisah (tentang orang-orang sebelum kalian, yaitu kaum Nuh dan Ad) kaum Nabi Hud (dan Tsamud) kaum Nabi Saleh (dan orang-orang sesudah mereka, yang tiada seorang pun mengetahui jumlah mereka selain Allah) karena saking banyaknya. (Telah datang rasul-rasul kepada mereka dengan membawa bukti-bukti yang nyata) yakni dengan membawa hujah-hujah yang jelas untuk membuktikan kebenaran mereka (lalu mereka menutupkan) yang dimaksud adalah umat-umat terdahulu itu (tangan mereka ke mulutnya) dengan menggigitnya sebagai pertanda kebencian mereka yang sangat terhadap ajakan para rasul itu (dan berkata, ``Sesungguhnya kami mengingkari apa yang kalian disuruh menyampaikannya) menurut anggapan kalian itu (dan sesungguhnya kami benar-benar dalam keraguan yang menggelisahkan terhadap apa yang kalian ajak kami kepadanya.") artinya mereka benar-benar ragu terhadapnya.\qt@no{9}}%
\qt@newcmd\qurantrans@id@mdcclx{%
(Berkata rasul-rasul mereka, ``Apakah ada keraguan terhadap Allah) istifham di sini mengandung makna ingkar; artinya tentu saja tidak ada keraguan di dalam mentauhidkan-Nya mengingat adanya bukti-bukti yang jelas menunjukkan ke arah itu (Pencipta) yang menciptakan (langit dan bumi? Dia menyeru kalian) supaya taat kepada-Nya (untuk memberi ampunan kepada kalian dari dosa-dosa kalian) huruf min adalah huruf zaidah. Karena sesungguhnya Islam itu menghapus semua dosa yang sebelumnya. Atau huruf min itu bermakna tab`idh yang artinya sebagian daripada dosa-dosa kalian. Dimaksud untuk mengecualikan dosa-dosa yang menyangkut hak-hak hamba-hamba Allah (dan menangguhkan kalian) tanpa mengazab kalian (sampai masa yang ditentukan?") sampai kalian mati. (Mereka berkata, ``Tiada lain) tidak lain (kalian adalah manusia biasa seperti kami juga. Kalian menghendaki untuk menghalang-halangi kami dari apa yang selalu disembah oleh nenek moyang kami) yaitu berhala-berhala sesembahan mereka (karena itu datangkanlah kepada kami bukti yang nyata.") hujah yang jelas untuk membuktikan kebenaran kalian itu.\qt@no{10}}%
\qt@newcmd\qurantrans@id@mdcclxi{%
(Rasul-rasul mereka berkata kepada mereka, ``Tiada lain) tidak lain (kami ini hanyalah manusia biasa sama dengan kalian) persis seperti apa yang kalian katakan itu (akan tetapi Allah memberi karunia kepada siapa yang Dia kehendaki di antara hamba-hamba-Nya) berupa kenabian. (Dan tidak patut) tidak layak (bagi kami mendatangkan suatu bukti kepada kalian melainkan dengan izin Allah) berdasarkan perintah-Nya karena sesungguhnya kami ini adalah hamba-hamba yang dipelihara oleh-Nya (Dan hanya kepada Allah sajalah hendaknya orang-orang yang beriman bertawakal.") hanya percaya kepada-Nya.\qt@no{11}}%
\qt@newcmd\qurantrans@id@mdcclxii{%
("Mengapa kami) huruf allaa asalnya adalah gabungan daripada an dan laa (tidak bertawakal kepada Allah) artinya tidak ada yang melarang kami untuk melakukan hal tersebut (padahal Dia telah menunjukkan jalan kepada kami dan kami sungguh-sungguh akan bersabar terhadap perlakuan-perlakuan kalian yang menyakitkan kami) di dalam menghadapi gangguan-gangguan yang kalian lakukan terhadap kami. (Dan hanya kepada Allah saja orang-orang yang bertawakal berserah diri.")\qt@no{12}}%
\qt@newcmd\qurantrans@id@mdcclxiii{%
(Orang-orang kafir berkata kepada rasul-rasul mereka, ``Kami sungguh-sungguh akan mengusir kalian dari negeri kami atau kalian kembali) menjadi pemeluk (kepada tuntunan kami.") yakni agama kami. (Maka Rabb mewahyukan kepada mereka, ``Kami pasti akan membinasakan orang-orang yang lalim itu.") yakni orang-orang kafir itu.\qt@no{13}}%
\qt@newcmd\qurantrans@id@mdcclxiv{%
("Dan Kami pasti akan menempatkan kalian di negeri-negeri itu) di negeri tempat mereka tinggal (sesudah mereka) dibinasakan. (Yang demikian itu) yakni pertolongan dan mewariskan negeri itu (adalah untuk orang-orang yang takut akan menghadap kepada-Ku) pada hari ia menghadap kepada-Nya (dan yang takut kepada ancaman-Ku.") takut kepada azab-Ku.\qt@no{14}}%
\qt@newcmd\qurantrans@id@mdcclxv{%
(Dan mereka memohon kemenangan) para rasul itu memohon pertolongan Allah di dalam menghadapi kaumnya (dan merugilah) binasalah (setiap orang yang berlaku sewenang-wenang) setiap orang yang takabur tidak mau taat kepada Allah (lagi keras kepala) artinya tidak mau tunduk kepada perkara yang hak.\qt@no{15}}%
\qt@newcmd\qurantrans@id@mdcclxvi{%
(Di hadapannya) di depannya (ada Jahanam) yang akan dimasukinya (dan dia akan diberi minum) di dalam Jahanam itu (dengan air nanah) yaitu cairan yang meleleh dari perut ahli neraka bercampur dengan nanah dan darah.\qt@no{16}}%
\qt@newcmd\qurantrans@id@mdcclxvii{%
(Diminumnya air nanah itu) diteguknya air nanah itu seteguk demi seteguk karena rasanya teramat pahit (dan hampir dia tidak dapat menelannya) ia merasa amat jijik mengingat baunya yang sangat busuk dan rupanya yang sangat menjijikkan (dan datanglah bahaya maut kepadanya) hal-hal yang menyebabkan kematian, berupa berbagai macam azab (dari segenap penjuru, tetapi dia tidak juga mati dan di hadapannya) sesudah mengalami azab tersebut (masih ada siksaan yang berat) siksaan yang keras lagi terus-menerus.\qt@no{17}}%
\qt@newcmd\qurantrans@id@mdcclxviii{%
(Perumpamaan) gambaran (tentang orang-orang yang ingkar kepada Rabb mereka) kalimat ayat ini berkedudukan menjadi mubtada kemudian dijelaskan oleh badalnya pada firman selanjutnya, yaitu: (amalan-amalan mereka) yang baik, seperti silaturahmi dan sedekah, yaitu dalam hal tiada kemanfaatan (seperti abu yang ditiup angin dengan keras pada suatu hari yang berangin keras) sangat keras tiupannya sehingga angin keras itu menjadikannya debu-debu yang beterbangan yang tiada manfaatnya. Jar dan majrurnya merupakan khabar daripada mubtada (mereka tidak dapat) yakni orang-orang kafir itu (mengambil manfaat dari apa yang telah mereka upayakan itu) dari apa yang telah mereka amalkan sewaktu di dunia (barang sedikit pun) artinya mereka sama sekali tidak menemukan pahala daripada amal-amal mereka karena tidak memenuhi syarat, yaitu tiadanya iman. (Yang demikian itu adalah kesesatan) kebinasaan (yang jauh.)\qt@no{18}}%
\qt@newcmd\qurantrans@id@mdcclxix{%
(Tidakkah kamu perhatikan) hai orang yang diajak bicara, tidakkah kamu memperhatikan. Istifham atau kata tanya di sini mengandung makna menetapkan (bahwa sesungguhnya Allah telah menciptakan langit dan bumi dengan hak) lafal bilhaqqi bertaalluq atau berkaitan maknanya dengan lafal khalaqa. (Jika Dia menghendaki, niscaya Dia membinasakan kalian) hai manusia (dan mengganti kalian dengan makhluk yang baru) sebagai pengganti kalian.\qt@no{19}}%
\qt@newcmd\qurantrans@id@mdcclxx{%
(Dan yang demikian itu sekali-kali tidak sukar bagi Allah) tidak sulit bagi-Nya.\qt@no{20}}%
\qt@newcmd\qurantrans@id@mdcclxxi{%
(Dan mereka akan berkumpul menghadap) semua makhluk itu menghadap. Ungkapan pada ayat ini dan ayat sebelumnya memakai fi`il madhi, dimaksud untuk memberikan pengertian kepastian bahwa hal itu benar-benar akan terjadi (kepada Allah semuanya, lalu berkatalah orang-orang yang lemah) yakni para pengikut (kepada orang-orang yang sombong) yaitu orang-orang yang diikuti ("Sesungguhnya kami dahulu adalah pengikut-pengikut kalian) lafal taba`an merupakan bentuk jamak dari kata tunggal tabi`un (maka dapatkah kalian menghindarkan) menolak (daripada kami azab Allah walau sedikit saja?") huruf min yang pertama tadi bermakna lit-tabyin atau untuk menjelaskan, sedangkan huruf min pada ayat ini bermakna lit-tab`idh atau menunjukkan makna sebagian. (Mereka berkata) orang-orang yang diikuti itu ("Seandainya Allah memberi petunjuk kepada kami niscaya kami dapat memberi petunjuk kepada kalian) artinya nicaya kami akan menyeru kalian ke jalan hidayah. (Sama saja bagi kita, apakah kita mengeluh atau bersabar, sekali-kali tidak mempunyai) huruf min di sini adalah zaidah (tempat untuk melarikan diri.") tempat berlindung dari azab-Nya.\qt@no{21}}%
\qt@newcmd\qurantrans@id@mdcclxxii{%
(Dan berkatalah setan) yakni iblis (tatkala perkara hisab telah diselesaikan) kemudian orang-orang yang berhak masuk surga dimasukkan ke dalam surga dan orang-orang yang berhak masuk neraka dimasukkan ke dalam neraka, lalu mereka semuanya mengerumuni iblis ("Sesungguhnya Allah telah menjanjikan kepada kalian janji yang benar) yaitu dengan kebangkitan dari kubur dan pembalasan amal perbuatan lalu Dia telah memenuhi kalian (dan aku pun telah menjanjikan kepada kalian) bahwasanya hal ini tidak ada (tetapi aku menyalahinya. Sekali-kali aku terhadap kalian tidak memiliki) huruf min di sini zaidah (kekuasaan) kekuatan dan kemampuan yang dapat memaksakan kalian untuk mengikutiku (melainkan) kecuali (sekedar aku menyeru kalian, lalu kalian mematuhi seruanku, oleh sebab itu janganlah kalian mencerca aku, akan tetapi cercalah diri kalian sendiri) disebabkan kalian telah mengikuti seruanku itu. (Aku sekali-kali tidak dapat menolong kalian) dapat memberikan pertolongan kepada kalian (dan kalian pun tidak dapat menolongku) dapat dibaca mushrikhiyya dan mushrikhiyyi. (Sesungguhnya aku tidak membenarkan perbuatan kalian mempersekutukan aku) dengan Allah (sebelumnya.") sewaktu di dunia. Lalu Allah berfirman: ("Sesungguhnya orang-orang yang lalim itu mendapat siksaan yang pedih) siksaan yang sangat pedih.\qt@no{22}}%
\qt@newcmd\qurantrans@id@mdcclxxiii{%
(Dan dimasukkanlah orang-orang yang beriman dan beramal saleh ke alam surga yang mengalir di bawahnya sungai-sungai; mereka kekal) lafal khaalidiina menjadi hal daripada kalimat yang keberadaannya diperkirakan (di dalamnya dengan seizin Rabb mereka. Ucapan penghormatan mereka dalam surga itu) dari Allah dan dari para malaikat, serta di antara sesama mereka (salaam.)\qt@no{23}}%
\qt@newcmd\qurantrans@id@mdcclxxiv{%
(Tidakkah kamu perhatikan) memperhatikan (bagaimana Allah telah membuat perumpamaan) lafal matsalan ini dijelaskan oleh badalnya, yaitu (kalimat yang baik) yakni kalimat laa ilaaha illallaah/tiada Tuhan selain Allah (seperti pohon yang baik) yaitu pohon kurma (akarnya teguh) menancap dalam di bumi (dan cabangnya) ranting-rantingnya (menjulang ke langit).\qt@no{24}}%
\qt@newcmd\qurantrans@id@mdcclxxv{%
(Pohon itu memberikan) membuahkan (buahnya) buah-buahannya (pada setiap musim dengan seizin Rabbnya) dengan kehendak-Nya demikian pula kalimat iman tertanam di dalam kalbu orang mukmin sedangkan amalnya naik ke langit kemudian memperoleh berkah dan pahala amalannya itu setiap saat (dibuatkan) dijelaskan (oleh Allah perumpamaan-perumpamaan itu untuk manusia supaya mereka selalu ingat) mau mengambil pelajaran daripadanya kemudian mereka mau beriman karenanya.\qt@no{25}}%
\qt@newcmd\qurantrans@id@mdcclxxvi{%
(Dan perumpamaan kalimat yang buruk) yaitu kalimat kekafiran (seperti pohon yang buruk) yaitu pohon hanzhal yang buahnya sangat pahit (yang telah dicabut) telah dibongkar sampai ke akar-akarnya (dari permukaan bumi, ia tidak dapat tetap sedikit pun) artinya tidak mempunyai tempat untuk berpijak lagi, maka demikian pula keadaan kalimat kekafiran tidak mempunyai tempat berpijak, tidak mempunyai ranting dan pula tidak ada keberkahannya.\qt@no{26}}%
\qt@newcmd\qurantrans@id@mdcclxxvii{%
(Allah meneguhkan iman orang-orang yang beriman dengan ucapan yang teguh itu) yaitu kalimat tauhid itu (di dunia dan di akhirat) yaitu di alam kubur, ketika dua orang malaikat menanyakan kepadanya tentang Rabb mereka, agama mereka dan nabi mereka. Maka orang-orang yang beriman dapat menjawabnya dengan benar; demikianlah menurut keterangan yang disebutkan di dalam hadis Imam Bukhari dan Imam Muslim (dan Allah menyesatkan orang-orang yang lalim) yaitu orang-orang kafir; oleh sebab itu mereka tidak mendapat petunjuk untuk memberikan jawaban yang benar. Bahkan mereka hanya mengatakan, ``Kami tidak tahu," demikian menurut keterangan dalam hadis (dan memperbuat apa yang Dia kehendaki.)\qt@no{27}}%
\qt@newcmd\qurantrans@id@mdcclxxviii{%
(Tidakkah kamu perhatikan) artinya melihat (orang-orang yang telah menukar nikmat Allah) yang dimaksud ialah bersyukur kepada Allah atas nikmat-Nya (dengan kekafiran) mereka adalah orang-orang yang kafir Quraisy (dan menjatuhkan) menyeret (kaumnya) yakni mereka menyesatkan kaumnya (ke lembah kebinasaan) ke dalam kebinasaan.\qt@no{28}}%
\qt@newcmd\qurantrans@id@mdcclxxix{%
(Yaitu neraka Jahanam) lafal Jahanam merupakan athaf bayan (mereka masuk ke dalamnya) dijebloskan ke dalamnya (dan itulah seburuk-buruk tempat kediaman) tempat yang paling buruk ialah Jahanam itu.\qt@no{29}}%
\qt@newcmd\qurantrans@id@mdcclxxx{%
(Orang-orang yang kafir itu telah menjadikan sekutu-sekutu bagi Allah) tandingan-tandingan (supaya mereka menyesatkan manusia) dapat dibaca liyudhilluu dan liyadhilluu (dari jalan-Nya) yaitu agama Islam. (Katakanlah) kepada mereka ("Bersenang-senanglah kalian) dengan keduniaan kalian dalam waktu yang sedikit (karena sesungguhnya tempat kembali kalian) yaitu tempat menetap kalian (ialah neraka.")\qt@no{30}}%
\qt@newcmd\qurantrans@id@mdcclxxxi{%
(Katakanlah kepada hamba-hamba-Ku yang telah beriman, ``Hendaklah mereka mendirikan salat, menafkahkan sebagian rezeki yang Kami berikan kepada mereka secara sembunyi atau pun terang-terangan sebelum datang hari kiamat yang pada hari itu tidak ada jual-beli) tebusan (dan persahabatan.") persahabatan yang dapat menolong; yang dimaksud adalah hari kiamat.\qt@no{31}}%
\qt@newcmd\qurantrans@id@mdcclxxxii{%
(Allahlah yang telah menciptakan langit dan bumi dan menurunkan air hujan dari langit kemudian Dia mengeluarkan dengan air hujan itu berbagai buah-buahan menjadi rezeki untuk kalian dan Dia telah menundukkan bahtera bagi kalian) yang dimaksud adalah perahu (supaya bahtera itu berlayar di lautan) sehingga kalian dapat menaikinya dan memuat barang-barang di atasnya (dengan kehendak-Nya) dengan seizin-Nya (dan Dia telah menundukkan pula bagi kalian sungai-sungai.)\qt@no{32}}%
\qt@newcmd\qurantrans@id@mdcclxxxiii{%
(Dan Dia telah menundukkan pula bagi kalian matahari dan bulan yang terus-menerus beredar) di dalam garis edarnya secara terus-menerus dan tidak pernah berhenti (dan Dia telah menundukkan pula bagi kalian malam) supaya kalian tenang di dalamnya (dan siang) dan supaya kalian mencari kemurahan Allah di dalamnya.\qt@no{33}}%
\qt@newcmd\qurantrans@id@mdcclxxxiv{%
(Dan Dia telah memberikan kepada kalian dari segala apa yang kalian mohonkan kepada-Nya) sesuai dengan keperluan kalian (Dan jika kalian menghitung nikmat Allah) pemberian nikmat-Nya kepada kalian (tidaklah dapat kalian menghitungnya) kalian tidak akan mampu menghitung-hitungnya. (Sesungguhnya manusia itu) yang dimaksud adalah orang kafir (sangat lalim dan sangat ingkar) artinya banyak berbuat aniaya terhadap dirinya dengan cara melakukan maksiat dan banyak ingkar terhadap nikmat Rabbnya.\qt@no{34}}%
\qt@newcmd\qurantrans@id@mdcclxxxv{%
(Dan) ingatlah (ketika Ibrahim berkata, ``Ya Rabbku! Jadikanlah negeri ini) yakni kota Mekah (negeri yang aman) memiliki keamanan dan ternyata Allah telah memperkenankan doanya, maka Dia menjadikan Mekah sebagai kota yang suci; dilarang di dalamnya mengalirkan darah manusia, menganiaya seseorang, berburu binatang buruannya dan menebang pepohonannya (dan jauhkanlah aku) hindarkanlah aku (beserta anak cucuku) daripada (menyembah berhala-berhala.")\qt@no{35}}%
\qt@newcmd\qurantrans@id@mdcclxxxvi{%
("Ya Rabbku! Sesungguhnya mereka itu) yakni berhala-berhala itu (telah menyesatkan kebanyakan daripada manusia) karena mereka menyembahnya (maka barang siapa yang mengikutiku) berpegang pada ajaran tauhid (maka sesungguhnya orang itu termasuk golonganku) termasuk pemeluk agamaku (dan barang siapa yang mendurhakai aku, maka sesungguhnya Engkau Maha Pengampun lagi Maha Penyayang.) pernyataan ini sebelum Nabi Ibrahim mengetahui, bahwa Allah swt. tidak mengampuni dosa syirik.\qt@no{36}}%
\qt@newcmd\qurantrans@id@mdcclxxxvii{%
(Ya Rabb kami! Sesungguhnya aku telah menempatkan sebagian keturunanku) sebagian daripada mereka, yaitu Nabi Ismail dan Siti Hajar ibunya (di lembah yang tidak mempunyai tanam-tanaman) yaitu Mekah (di dekat rumah Engkau yang suci) sebelum banjir besar terjadi (ya Rabb agar mereka mendirikan salat, maka jadikanlah hati) kalbu-kalbu (sebagian manusia cenderung) condong dan merindukan (kepada mereka) Sahabat Ibnu Abbas mengatakan, seandainya Nabi Ibrahim mengatakan di dalam doanya, yaitu af-idatan naasi yang artinya semua hati manusia, maka orang-orang Persia, Romawi dan semua manusia niscaya akan cenderung ke Baitullah (dan beri rezekilah mereka dari buah-buahan; mudah-mudahan mereka bersyukur.") dan memang doanya diperkenankan, yaitu dengan disuplaikannya buah-buahan dari Thaif ke Mekah.\qt@no{37}}%
\qt@newcmd\qurantrans@id@mdcclxxxviii{%
(Ya Rabb kami! Sesungguhnya Engkau mengetahui apa yang kami sembunyikan) apa yang kami tidak lahirkan (dan apa yang kami lahirkan; dan tidak ada yang tersembunyi bagi Allah) huruf min di sini adalah zaidah (sesuatu pun, baik yang ada di bumi maupun yang ada di langit) ayat ini dapat diartikan kalam Rabb dan dapat pula dianggap sebagai doa Nabi Ibrahim.\qt@no{38}}%
\qt@newcmd\qurantrans@id@mdcclxxxix{%
(Segala puji bagi Allah yang telah menganugerahkan kepada diriku) memberiku (sekalipun) walaupun (sudah tua, Ismail) Nabi Ismail dilahirkan sewaktu Nabi Ibrahim berumur sembilan puluh sembilan tahun (dan Ishak.) dilahirkan sewaktu Nabi Ibrahim berumur seratus dua belas tahun (Sesungguhnya Rabbku benar-benar Maha Mendengar doa).\qt@no{39}}%
\qt@newcmd\qurantrans@id@mdccxc{%
(Ya Rabbku! Jadikanlah aku orang-orang yang tetap mendirikan salat dan) jadikan pula (anak cucuku) orang-orang yang tetap mendirikannya. Nabi Ibrahim sengaja di dalam doanya ini memakai ungkapan min yang menunjukkan makna sebagian karena Allah swt. telah memberitahukan kepadanya bahwa di antara anak cucunya itu terdapat orang yang kafir (Ya Rabb kami! Kabulkanlah doaku) semua doa yang telah disebutkan tadi.\qt@no{40}}%
\qt@newcmd\qurantrans@id@mdccxci{%
(Ya Rabb kami! Beri ampunlah aku dan kedua ibu bapakku) doa ini diucapkan sebelum jelas bagi Nabi Ibrahim bahwa kedua orang tuanya memusuhi Allah swt. Akan tetapi menurut suatu pendapat dikatakan bahwa ibu Nabi Ibrahim masuk Islam. Lafal waalidayya menurut qiraat yang lain dapat dibaca mufrad sehingga bacaannya menjadi waalidiy (dan sekalian orang-orang mukmin pada hari terjadinya) ditegakkannya (hisab) selanjutnya Allah berfirman:\qt@no{41}}%
\qt@newcmd\qurantrans@id@mdccxcii{%
(Dan janganlah sekali-kali kamu mengira bahwa Allah lalai dari apa yang diperbuat oleh orang-orang yang lalim) yakni orang-orang kafir dari kalangan penduduk Mekah. (Sesungguhnya Allah hanya memberi tangguh kepada mereka) tanpa diazab (sampai hari yang pada waktu itu mata mereka terbelalak) karena ngerinya pemandangan yang mereka saksikan kala itu. Di dalam istilah bahasa atau lugah jika dikatakan bashara fulaanun syakhshan, artinya si polan melihat seseorang tanpa mengedipkan matanya.\qt@no{42}}%
\qt@newcmd\qurantrans@id@mdccxciii{%
(Mereka datang bergegas) dengan segera memenuhi panggilan. Lafal ayat ini berkedudukan menjadi hal atau kata keterangan (dengan mengangkat) mendongakkan (kepalanya) ke langit (sedangkan mata mereka tidak berkedip-kedip) melotot (dan hati mereka kosong) tidak ada suatu pikiran pun yang terbetik di dalamnya saking kaget dan ngerinya.\qt@no{43}}%
\qt@newcmd\qurantrans@id@mdccxciv{%
(Dan berikanlah peringatan) hai Muhammad, peringatkanlah (kepada manusia) yakni orang-orang kafir (terhadap hari yang pada waktu itu datang azab kepada mereka) yaitu hari kiamat (maka berkatalah orang-orang yang lalim) yakni orang-orang kafir ("Ya Rabb kami! Beri tangguhlah kami) seumpamanya Engkau mengembalikan kami ke dunia (walaupun dalam waktu yang sedikit, niscaya kami akan mematuhi seruan Engkau) dengan mengamalkan ajaran tauhid (dan akan mengikuti rasul-rasul.") lalu dikatakan kepada mereka dengan nada celaan ("Bukankah kalian telah bersumpah) telah berikrar (sebelumnya dahulu) yaitu sewaktu di dunia (bahwa sekali-kali kalian tidak akan) huruf min di sini adalah zaidah (binasa?") setelah meninggalkan dunia menuju ke akhirat.\qt@no{44}}%
\qt@newcmd\qurantrans@id@mdccxcv{%
("Dan kalian telah berdiam) di dunia (di tempat-tempat kediaman orang-orang yang menganiaya dirinya sendiri) dengan melakukan kekafiran, yaitu bekas tempat tinggal umat-umat terdahulu yang durhaka (dan telah nyata bagi kalian bagaimana Kami telah berbuat terhadap mereka) yaitu berupa siksaan, akan tetapi kalian masih tetap tidak mau kapok juga (dan telah Kami berikan) telah Kami jelaskan (kepada kalian beberapa perumpamaan.") di dalam Alquran, akan tetapi kalian tidak mau mengambilnya sebagai pelajaran.\qt@no{45}}%
\qt@newcmd\qurantrans@id@mdccxcvi{%
(Dan sesungguhnya mereka telah membuat makar) terhadap Nabi saw. (makar yang besar) yaitu mereka bermaksud untuk membunuh Nabi saw. atau membelenggunya, atau mengusirnya (padahal di sisi Allahlah makar mereka) yakni pengetahuan makar tersebut, atau pembalasan makar itu. (Dan tidak akan) tidak bisa (makar mereka itu) betapa pun besarnya (dapat melenyapkan gunung-gunung) pengertiannya ialah makar tersebut dibiarkan dan tidak memberikan mudarat melainkan hanya terhadap diri mereka sendiri. Yang dimaksud dengan pengertian gunung-gunung di sini, menurut suatu pendapat adalah hakiki, yakni gunung yang sesungguhnya, dan menurut pendapat yang lain dimaksud adalah syariat-syariat Islam yang digambarkan seperti gunung-gunung dalam hal ketetapan dan keteguhannya. Menurut suatu qiraat yang lain litazuula ini dibaca latazuulu, yakni dengan harakat fatah pada huruf lamnya kemudian akhir fi'ilnya dibaca rafa', maka berdasarkan qiraat ini berarti huruf in di sini adalah bentuk takhfif atau keringanan daripada huruf inna yang ditasydidkan huruf nunnya, makna yang dimaksud adalah menggambarkan tentang besarnya makar orang-orang kafir itu terhadap diri Nabi saw. Akan tetapi menurut pendapat yang lain dikatakan, yang dimaksud dengan lafal al-makru ialah kekafiran mereka. Makna yang terakhir ini sesuai pula dengan apa yang disebutkan di dalam firman Allah swt. yang. lainnya, yaitu, ``Hampir-hampir langit pecah karena ucapan itu (mendakwa Tuhan mempunyai anak), bumi belah, dan gunung-gunung runtuh." (Q.S. Maryam 90) Sedangkan pengertian yang pertama sesuai dengan bacaan yang tertera.\qt@no{46}}%
\qt@newcmd\qurantrans@id@mdccxcvii{%
(Karena itu janganlah sekali-kali kalian mengira Allah akan menyalahi janji-Nya kepada rasul-rasul-Nya) yaitu akan memberikan pertolongan kepadanya. (Sesungguhnya Allah Maha Perkasa) Maha Menang, tiada sesuatu pun yang dapat menghalang-halangi-Nya (lagi mempunyai pembalasan) terhadap orang-orang yang mendurhakai-Nya.\qt@no{47}}%
\qt@newcmd\qurantrans@id@mdccxcviii{%
Ingatlah (Pada hari ketika bumi diganti dengan bumi yang lain dan demikian pula langit) yaitu hari kiamat, kemudian manusia digiring untuk dikumpulkan di suatu tanah yang putih bersih sebagaimana yang telah disebutkan di dalam hadis kitab Sahih Bukhari dan Muslim. Sehubungan dengan hal ini Imam Muslim meriwayatkan sebuah hadis bahwasanya Nabi saw. ditanya mengenai manusia pada saat itu. Lalu Nabi saw. menjawab, ``Berada di shirath." (dan mereka semuanya tampak bermunculan) artinya mereka keluar dari kuburan mereka masing-masing (untuk menghadap kepada Allah Yang Maha Esa lagi Maha Perkasa.)\qt@no{48}}%
\qt@newcmd\qurantrans@id@mdccxcix{%
(Dan kamu akan melihat) hai Muhammad (orang-orang yang berdosa) yakni orang-orang kafir (pada hari itu diikat) dalam keadaan terikat beserta setan-setan mereka (dengan belenggu) tali-tali atau rantai-rantai.\qt@no{49}}%
\qt@newcmd\qurantrans@id@mdccc{%
(Pakaian mereka) baju-baju mereka (adalah dari aspal) yang sangat mudah menyala (dan tertutuplah) ditutuplah (muka mereka oleh api neraka).\qt@no{50}}%
\qt@newcmd\qurantrans@id@mdccci{%
(Agar pembalasan diberikan) lafal ini bertaalluq kepada lafal barazuu (oleh Allah kepada tiap-tiap orang terhadap apa yang ia usahakan) baik berupa kebaikan atau pun keburukan. (Sesungguhnya Allah Maha cepat hisab-Nya) Dia menghisab semua makhluk selama setengah hari menurut ukuran hari dunia, demikianlah menurut penjelasan hadis.\qt@no{51}}%
\qt@newcmd\qurantrans@id@mdcccii{%
(Ini) yakni Alquran ini (adalah penjelasan yang cukup bagi manusia) artinya diturunkan untuk disampaikan kepada mereka (dan supaya mereka diberi peringatan dengannya dan supaya mereka mengetahui) apa-apa yang terkandung di dalamnya berupa hujah-hujah (bahwasanya Dia) yakni Allah (adalah Tuhan Yang Maha Esa dan agar mau mengambil pelajaran) asalnya adalah liyatadzakkara, kemudian huruf ta diidgamkan kepada huruf dzal sehingga jadilah bacaannya liyadzdzakkara artinya, supaya mengambil pelajaran (orang-orang yang berakal) yang berakal sehat.\qt@no{52}}%
\qt@newcmd\qurantrans@id@mdccciii{%
\basmalahid (Alif laam raa) hanya Allahlah yang mengetahui maksudnya. (Ini) ayat-ayat ini (adalah sebagian dari ayat-ayat kitab) Alquran; idhafat di sini mengandung makna min yang berarti sebagian (yaitu Alquran yang memberi penjelasan) yang memenangkan perkara yang hak atas perkara yang batil. Lafal ayat ini diathafkan kepada lafal sebelumnya dengan ditambah sifat.\qt@no{1}}%
\qt@newcmd\qurantrans@id@mdccciv{%
(Sering kali) dapat dibaca rubbamaa dan rubamaa (berkeinginan) mengharapkan (orang-orang yang kafir itu) kelak di hari kiamat, yaitu sewaktu diperlihatkan kepada mereka keadaan diri mereka dan keadaan kaum Muslimin (seandainya mereka menjadi orang-orang muslim) lafal rubba menunjukkan makna littaktsir/sering, karena sesungguhnya mereka sering kali mengharapkan hal tersebut. Akan tetapi menurut pendapat lain menunjukkan makna littaqlil, artinya sedikit, karena sesungguhnya kengerian-kengerian pemandangan di hari kiamat membuat mereka terkejut dengan sangat, sehingga mereka tidak sadar untuk berharap seperti itu melainkan hanya dalam masa yang sedikit.\qt@no{2}}%
\qt@newcmd\qurantrans@id@mdcccv{%
(Biarkanlah mereka) biarkanlah orang-orang kafir itu, hai Muhammad (makan dan bersenang-senang) di dunia mereka ini (dan dilalaikan) disibukkan (oleh angan-angan kosong) dengan dipanjangkan umur mereka dan lain-lainnya sehingga mereka lupa daratan akan iman (maka kelak mereka akan mengetahui) akibat daripada perbuatan mereka. Ayat ini diturunkan sebelum ada perintah untuk memerangi mereka.\qt@no{3}}%
\qt@newcmd\qurantrans@id@mdcccvi{%
(Dan Kami tiada membinasakan) huruf min adalah zaidah (sesuatu negeri pun) yang dimaksud adalah para penduduknya (melainkan ada baginya ketentuan) masa (yang telah ditetapkan) yang terbatas untuk pembinasaan mereka.\qt@no{4}}%
\qt@newcmd\qurantrans@id@mdcccvii{%
(Tiada yang dapat mendahului) huruf min adalah zaidah (suatu umat pun akan ajalnya, dan tiada pula yang dapat mengundurkannya) menangguhkan saat ajalnya dari waktu yang telah ditentukan oleh Allah.\qt@no{5}}%
\qt@newcmd\qurantrans@id@mdcccviii{%
(Dan mereka berkata) yaitu orang-orang kafir Mekah kepada Nabi saw. ("Hai orang yang diturunkan Adz-Dzikru kepadanya!) yakni Alquran, menurut perkiraan (Sesungguhnya kamu benar-benar orang yang gila.")\qt@no{6}}%
\qt@newcmd\qurantrans@id@mdcccix{%
("Mengapa tidak) (kamu datangkan malaikat kepada kami, jika kamu termasuk orang-orang yang benar?") di dalam ucapanmu itu yang mengatakan, bahwa kamu adalah seorang nabi, dan Alquran ini dari sisi Allah?\qt@no{7}}%
\qt@newcmd\qurantrans@id@mdcccx{%
Allah berfirman (Kami tidak menurunkan) dan menurut suatu qiraat dibaca tanazzalu dengan membuang salah satu huruf ta-nya (malaikat melainkan dengan benar) untuk membawa azab (dan tiadalah mereka ketika itu) sewaktu malaikat turun dengan membawa azab (diberi tangguh) ditangguhkan azabnya.\qt@no{8}}%
\qt@newcmd\qurantrans@id@mdcccxi{%
(Sesungguhnya Kamilah) lafal nahnu mentaukidkan atau mengukuhkan makna yang terdapat di dalam isimnya inna, atau sebagai fashl (yang menurunkan Adz-Dzikr) Alquran (dan sesungguhnya Kami benar-benar memeliharanya) dari penggantian, perubahan, penambahan dan pengurangan.\qt@no{9}}%
\qt@newcmd\qurantrans@id@mdcccxii{%
(Dan sesungguhnya Kami telah mengutus sebelum kamu) beberapa rasul (kepada umat-umat) golongan-golongan (terdahulu.)\qt@no{10}}%
\qt@newcmd\qurantrans@id@mdcccxiii{%
(Dan tidak) sekali-kali (datang seorang rasul pun kepada mereka melainkan mereka selalu memperolok-olokkannya) sebagaimana kaummu memperolok-olokkanmu. Ayat ini dimaksudkan untuk menghibur hati Nabi saw.\qt@no{11}}%
\qt@newcmd\qurantrans@id@mdcccxiv{%
(Demikianlah Kami memasukkannya) artinya seperti itulah gambarannya bila Kami memasukkan ke dalam hati orang-orang kafir rasa ingkar dan memperolok-olokkan (ke dalam hati orang-orang yang berdosa) yaitu orang-orang kafir Mekah.\qt@no{12}}%
\qt@newcmd\qurantrans@id@mdcccxv{%
(Mereka tidak beriman kepadanya) kepada Nabi saw. (dan sesungguhnya telah berlalu sunatullah terhadap orang-orang yang dahulu) artinya kebiasaan yang dilakukan oleh Allah swt. terhadap orang-orang yang tidak beriman, yaitu mengazab mereka disebabkan perbuatan dusta mereka terhadap nabi-nabi mereka. Orang-orang kafir Mekah pun akan mengalami hal yang serupa.\qt@no{13}}%
\qt@newcmd\qurantrans@id@mdcccxvi{%
(Dan seandainya Kami membukakan kepada mereka salah satu dari pintu-pintu langit, lalu mereka terus-menerus padanya) pada pintu tersebut (dalam keadaan naik) selalu naik.\qt@no{14}}%
\qt@newcmd\qurantrans@id@mdcccxvii{%
(Tentulah mereka berkata, ``Sesungguhnya benar-benar telah dikaburkan) telah ditutup (pandangan kami bahkan kami adalah orang-orang yang kena sihir.") seolah-olah tampak hal itu di mata kami secara ilusi.\qt@no{15}}%
\qt@newcmd\qurantrans@id@mdcccxviii{%
(Dan sesungguhnya Kami menciptakan gugusan bintang-bintang di langit) yang berjumlah dua belas, yaitu: Aries, Taurus, Gemini, Cancer, Leo, Virgo, Libra, Scorpio, Sagitarius, Capricorn, Aquarius dan Pisces. Bintang-bintang tersebut merupakan garis-garis peredaran daripada tujuh bintang yang beredar, yaitu Mars mempunyai garis edar pada bintang Aries dan bintang Scorpio; Venus mempunyai garis edar pada bintang Taurus dan bintang Libra; Utarid mempunyai garis edar pada bintang Gemini dan bintang Virgo; bulan mempunyai garis edar pada bintang Cancer; matahari mempunyai garis edar pada bintang Leo; Jupiter mempunyai garis edar pada bintang Sagitarius dan Pisces; Saturnus mempunyai garis edar pada bintang Capricorn dan Aquarius (dan Kami telah menghiasi langit itu) dengan bintang-bintang yang gemerlapan (bagi orang-orang yang memandang.)\qt@no{16}}%
\qt@newcmd\qurantrans@id@mdcccxix{%
(Dan Kami menjaganya) dengan meteor-meteor (dari tiap-tiap setan yang terkutuk) yang terlaknat.\qt@no{17}}%
\qt@newcmd\qurantrans@id@mdcccxx{%
(Akan tetapi) tetapi (setan yang mencuri-curi berita yang dapat didengar) yang menyadapnya (maka ia pasti dikejar oleh semburan api yang terang) yakni bintang yang menyala terang dan dapat membakar atau menembus atau membuatnya cacat.\qt@no{18}}%
\qt@newcmd\qurantrans@id@mdcccxxi{%
(Dan Kami telah menghamparkan bumi) telah membuatnya terbentang (dan Kami menjadikan padanya gunung-gunung) yang kokoh dan tegak supaya jangan bergerak-gerak mengguncangkan penduduknya (dan Kami tumbuhkan padanya segala sesuatu menurut ukuran) yang telah ditentukan secara pasti.\qt@no{19}}%
\qt@newcmd\qurantrans@id@mdcccxxii{%
(Dan Kami telah menjadikan untuk kalian di muka bumi keperluan-keperluan hidup) berupa buah-buahan dan biji-bijian (dan) Kami jadikan pula untuk kalian (makhluk-makhluk yang kalian sekali-kali bukan pemberi rezeki kepadanya) yaitu berupa hamba-hamba sahaya, binatang-binatang dan berbagai macam jenis ternak; hanya Allahlah yang memberi rezeki kepada mereka.\qt@no{20}}%
\qt@newcmd\qurantrans@id@mdcccxxiii{%
(Dan tiada) tidak ada (sesuatu pun melainkan pada sisi Kamilah khazanahnya) huruf min adalah zaidah; yang dimaksud adalah kunci-kunci perbendaharaan segala sesuatu itu (dan Kami tidak menurunkannya melainkan dengan ukuran-ukuran yang tertentu) sesuai dengan kepentingan-kepentingannya.\qt@no{21}}%
\qt@newcmd\qurantrans@id@mdcccxxiv{%
(Dan Kami telah meniupkan angin untuk mengumpulkan awan) menggiring mendung sehingga terkumpul lalu penuh dengan air (lalu Kami turunkan dari langit) dari mendung itu (air) air hujan (kemudian Kami beri minum kamu dengan air itu, dan sekali-kali bukanlah kalian yang menyimpannya) artinya, bukanlah kalian yang menyimpannya dengan upaya tangan kalian.\qt@no{22}}%
\qt@newcmd\qurantrans@id@mdcccxxv{%
(Dan sesungguhnya benar-benar Kamilah yang menghidupkan dan mematikan dan Kami pula yang mewarisi) yang tetap hidup dan mewarisi semua makhluk.\qt@no{23}}%
\qt@newcmd\qurantrans@id@mdcccxxvi{%
(Dan sesungguhnya Kami telah mengetahui orang-orang yang terdahulu daripada kalian) yaitu makhluk-makhluk yang terdahulu sejak Nabi Adam (dan sesungguhnya Kami mengetahui pula orang-orang yang terkemudian) orang-orang yang akan datang kemudian hingga hari kiamat.\qt@no{24}}%
\qt@newcmd\qurantrans@id@mdcccxxvii{%
(Sesungguhnya Rabbmu, Dialah yang akan menghimpunkan mereka. Sesungguhnya Dia adalah Maha Bijaksana) di dalam pekerjaan-Nya (lagi Maha Mengetahui.) tentang makhluk-Nya.\qt@no{25}}%
\qt@newcmd\qurantrans@id@mdcccxxviii{%
(Dan sesungguhnya Kami telah menciptakan manusia) yaitu Nabi Adam (dari tanah liat kering) tanah liat kering yang apabila diketuk akan terdengar daripadanya suara melenting (yang berasal dari lumpur hitam) tanah liat yang hitam (yang diberi bentuk) diubah bentuknya.\qt@no{26}}%
\qt@newcmd\qurantrans@id@mdcccxxix{%
(Dan jin) maksudnya biangnya jin, yaitu iblis (Kami telah menciptakan sebelumnya) sebelum Nabi Adam diciptakan (dari api yang sangat panas) yaitu api yang sama sekali tidak berasap dan dapat menembus pori-pori.\qt@no{27}}%
\qt@newcmd\qurantrans@id@mdcccxxx{%
(Dan) ingatlah (ketika Rabbmu berfirman kepada para malaikat, ``Sesungguhnya Aku akan menciptakan seorang manusia dari tanah liat kering yang berasal dan lumpur hitam yang diberi bentuk).\qt@no{28}}%
\qt@newcmd\qurantrans@id@mdcccxxxi{%
(Maka apabila Aku telah menyempurnakan kejadiannya) telah merampungkan bentuknya (dan Aku telah meniupkan) maksudnya telah mengalirkan (ke dalam tubuhnya roh ciptaan-Ku) sehingga ia menjadi hidup; diidhafatkannya lafal ruuh kepada-Nya sebagai penghormatan kepada Adam (maka tunduklah kalian kepadanya dengan bersujud) yaitu sujud penghormatan dengan cara membungkuk.\qt@no{29}}%
\qt@newcmd\qurantrans@id@mdcccxxxii{%
(Maka bersujudlah para malaikat itu semuanya bersama-sama) di dalam ayat ini terdapat dua taukid, yaitu lafal kulluhum dan lafal ajma'uuna.\qt@no{30}}%
\qt@newcmd\qurantrans@id@mdcccxxxiii{%
(Kecuali iblis) dia adalah biangnya jin yang dahulu hidup di antara para malaikat (ia enggan) menolak untuk (ikut bersama-sama malaikat yang sujud itu.")\qt@no{31}}%
\qt@newcmd\qurantrans@id@mdcccxxxiv{%
(Allah berfirman) Maha Tinggi Allah ("Hai iblis! Apa sebabnya kamu) apa yang menyebabkan kamu enggan (tidak mau) huruf laa adalah zaidah (ikut sujud bersama-sama mereka yang sujud itu?")\qt@no{32}}%
\qt@newcmd\qurantrans@id@mdcccxxxv{%
(Berkata iblis, ``Aku sekali-kali tidak akan sujud) tidak layak bagiku untuk sujud (kepada manusia yang Engkau telah menciptakannya dari tanah liat kering yang berasal dari lumpur hitam yang diberi bentuk.")\qt@no{33}}%
\qt@newcmd\qurantrans@id@mdcccxxxvi{%
(Allah berfirman, ``Keluarlah dari surga) menurut suatu pendapat dari langit (karena sesungguhnya kamu terkutuk.") terusir.\qt@no{34}}%
\qt@newcmd\qurantrans@id@mdcccxxxvii{%
(Dan sesungguhnya kutukan itu tetap menimpamu sampai hari kiamat) sampai hari pembalasan\qt@no{35}}%
\qt@newcmd\qurantrans@id@mdcccxxxviii{%
(Berkata iblis, ``Ya Rabbku! Kalau begitu maka beri tangguhlah kepadaku sampai hari dibangkitkan.") nya manusia\qt@no{36}}%
\qt@newcmd\qurantrans@id@mdcccxxxix{%
(Allah berfirman, ``Kalau begitu, maka sesungguhnya kamu termasuk orang-orang yang diberi tangguh).\qt@no{37}}%
\qt@newcmd\qurantrans@id@mdcccxl{%
(sampai hari suatu waktu yang telah ditentukan.") yaitu sampai tiupan sangkakala yang pertama.\qt@no{38}}%
\qt@newcmd\qurantrans@id@mdcccxli{%
(Iblis berkata, ``Ya Rabbku! Oleh sebab Engkau telah memutuskan bahwa aku sesat) artinya disebabkan Engkau telah menetapkan aku sesat; huruf ba pada lafal bimaa adalah bermakna qasam, sedangkan jawabnya ialah (pasti aku akan menjadikan mereka memandang baik di muka bumi ini) terhadap perbuatan-perbuatan maksiat (dan pasti aku akan menyesatkan mereka semuanya).\qt@no{39}}%
\qt@newcmd\qurantrans@id@mdcccxlii{%
(Kecuali hamba-hamba Engkau yang mukhlis di antara mereka") yakni orang-orang yang beriman.\qt@no{40}}%
\qt@newcmd\qurantrans@id@mdcccxliii{%
(Berfirmanlah Allah) swt. ("Inilah jalan yang lurus; kewajiban Akulah memeliharanya")\qt@no{41}}%
\qt@newcmd\qurantrans@id@mdcccxliv{%
(Sesungguhnya hamba-hamba-Ku) yang beriman (tidak ada kekuasaan bagimu terhadap mereka) kamu tidak mempunyai kekuatan (kecuali) hanyalah (orang-orang yang mengikut kalian; yaitu orang-orang yang sesat) yakni orang-orang kafir.\qt@no{42}}%
\qt@newcmd\qurantrans@id@mdcccxlv{%
(Dan sesungguhnya Jahanam itu benar-benar tempat yang telah dijanjikan kepada mereka semuanya) yaitu kepada orang-orang yang mengikutimu.\qt@no{43}}%
\qt@newcmd\qurantrans@id@mdcccxlvi{%
(Jahanam itu mempunyai tujuh pintu) tujuh lapis (Tiap-tiap pintu) daripadanya (adalah untuk segolongan di antara mereka bagian) yakni jatah (yang tertentu).\qt@no{44}}%
\qt@newcmd\qurantrans@id@mdcccxlvii{%
(Sesungguhnya orang-orang yang bertakwa itu berada di dalam surga) kebun-kebun surga (dan mata air-mata air) yang mengalir di dalamnya.\qt@no{45}}%
\qt@newcmd\qurantrans@id@mdcccxlviii{%
Dan dikatakan kepada mereka ("Masuklah ke dalamnya dengan sejahtera) dengan perasaan yang aman dari setiap hal yang menakutkan. Atau masuklah ke dalamnya dengan bersalam artinya, bersalamlah lalu masuklah (lagi aman") dari setiap hal-hal yang mengerikan.\qt@no{46}}%
\qt@newcmd\qurantrans@id@mdcccxlix{%
(Dan Kami lenyapkan segala rasa dendam yang berada dalam hati mereka) maksudnya semua perasaan dengki (sedangkan mereka merasa bersaudara) lafal ikhwaanan ini menjadi hal tentang keadaan mereka (duduk berhadap-hadapan di atas dipan-dipan) kalimat ayat ini pun menggambarkan tentang keadaan mereka; artinya sebagian dari mereka tidak melihat kepada tengkuk sebagian yang lain karena tempat duduk mereka saling berhadap-hadapan.\qt@no{47}}%
\qt@newcmd\qurantrans@id@mdcccl{%
(Mereka tidak merasa lelah di dalamnya) tidak pernah merasa penat (dan mereka sekali-kali tidak akan dikeluarkan daripadanya) untuk selama-lamanya.\qt@no{48}}%
\qt@newcmd\qurantrans@id@mdcccli{%
(Kabarkanlah) beritakanlah, hai Muhammad (kepada hamba-hamba-Ku bahwa sesungguhnya Akulah Yang Maha Pengampun) terhadap orang-orang mukmin (lagi Maha Penyayang) terhadap mereka yang beriman.\qt@no{49}}%
\qt@newcmd\qurantrans@id@mdccclii{%
(Dan bahwa sesungguhnya azab-Ku) terhadap orang-orang yang durhaka (adalah azab yang sangat pedih) sangat menyakitkan.\qt@no{50}}%
\qt@newcmd\qurantrans@id@mdcccliii{%
(Dan kabarkanlah kepada mereka tentang tamu-tamu Ibrahim) yaitu malaikat-malaikat yang berjumlah dua belas malaikat, atau sepuluh malaikat, atau tiga malaikat yang salah satu di antara mereka adalah malaikat Jibril.\qt@no{51}}%
\qt@newcmd\qurantrans@id@mdcccliv{%
(Ketika mereka masuk ke tempatnya, lalu mereka mengucapkan, ``Salam.") mereka mengucapkan lafal itu. (Berkata Ibrahim) ketika disuguhkan hidangan makanan kepada mereka, akan tetapi mereka tidak memakannya ("Sesungguhnya kami merasa takut kepada kalian.") yakni merasa ngeri.\qt@no{52}}%
\qt@newcmd\qurantrans@id@mdccclv{%
(Mereka berkata, ``Janganlah kamu merasa takut) merasa ngeri terhadap kami (sesungguhnya kami) adalah utusan-utusan Rabbmu (memberi kabar gembira kepadamu dengan kelahiran seorang anak laki-laki yang akan menjadi orang yang alim.") anak yang mempunyai ilmu yang banyak, yaitu Nabi Ishak, seperti yang telah kami sebutkan dalam surah Hud.\qt@no{53}}%
\qt@newcmd\qurantrans@id@mdccclvi{%
(Berkata Ibrahim, ``Apakah kalian memberi kabar gembira kepadaku) dengan melahirkan seorang anak (padahal usiaku telah lanjut) kalimat ini menjadi hal; artinya padahal usia tua telah kualami (maka dengan cara manakah) dengan cara apakah (terlaksananya berita gembira seperti apa yang kalian katakan itu?") Istifham di sini mengandung makna takjub.\qt@no{54}}%
\qt@newcmd\qurantrans@id@mdccclvii{%
(Mereka berkata, ``Kami menyampaikan kabar gembira kepadamu dengan benar) dengan sungguh-sungguh (maka janganlah kamu termasuk orang-orang yang berputus asa.") putus harapan.\qt@no{55}}%
\qt@newcmd\qurantrans@id@mdccclviii{%
(Ibrahim berkata, ``Tiada) tidak ada (orang orang berputus asa) dapat dibaca yaqnithu dan yaqnathu (dari rahmat Rabbnya melainkan orang-orang yang sesat.") yakni orang-orang kafir.\qt@no{56}}%
\qt@newcmd\qurantrans@id@mdccclix{%
(Berkata pula Ibrahim, ``Apakah urusan kalian) yakni kepentingan kalian (hai para utusan?").\qt@no{57}}%
\qt@newcmd\qurantrans@id@mdccclx{%
(Mereka menjawab, ``Kami sesungguhnya diutus kepada kaum yang berdosa) orang-orang kafir, yang dimaksud adalah kaum Nabi Luth, untuk membinasakan mereka.\qt@no{58}}%
\qt@newcmd\qurantrans@id@mdccclxi{%
(Kecuali Luth dan pengikut-pengikutnya. Sesungguhnya Kami akan menyelamatkan mereka-semuanya) karena mereka adalah orang-orang yang beriman.\qt@no{59}}%
\qt@newcmd\qurantrans@id@mdccclxii{%
(Kecuali istrinya, kami telah menentukan, bahwa sesungguhnya ia itu termasuk orang-orang yang tertinggal.") bersama orang-rang kafir lainnya yang tertimpa azab.\qt@no{60}}%
\qt@newcmd\qurantrans@id@mdccclxiii{%
(Maka tatkala datang kepada kaum Luth) yang dimaksud adalah Nabi Luth (para utusan itu).\qt@no{61}}%
\qt@newcmd\qurantrans@id@mdccclxiv{%
(Ia berkata) kepada para utusan itu ("Sesungguhnya kalian adalah orang-orang yang tidak dikenal.")\qt@no{62}}%
\qt@newcmd\qurantrans@id@mdccclxv{%
(Para utusan menjawab, ``Sebenarnya kami ini datang kepadamu dengan membawa apa yang mereka) yakni kaummu (mendustakannya.") mereka meragukan tentangnya; subjek yang dimaksud adalah azab.\qt@no{63}}%
\qt@newcmd\qurantrans@id@mdccclxvi{%
("Dan kami datang kepadamu membawa kebenaran dan sesungguhnya kami betul-betul orang-orang yang benar.") di dalam pengakuan kami ini.\qt@no{64}}%
\qt@newcmd\qurantrans@id@mdccclxvii{%
(Maka pergilah kamu di akhir malam dengan membawa keluargamu dan ikutilah mereka dari belakang) berjalanlah kamu di belakang keluargamu (dan janganlah seorang pun di antara kalian menoleh ke belakang) supaya ia tidak melihat besarnya azab yang menimpa mereka (dan teruskanlah perjalanan ke tempat yang diperintahkan kepada kalian) yaitu negeri Syam.\qt@no{65}}%
\qt@newcmd\qurantrans@id@mdccclxviii{%
(Dan telah Kami putuskan) telah Kami wahyukan (kepada Luth perkara itu) yaitu (bahwa mereka akan ditumpas habis di waktu subuh) lafal mushbihiin menjadi hal; artinya pembinasaan mereka dilakukan pada waktu subuh.\qt@no{66}}%
\qt@newcmd\qurantrans@id@mdccclxix{%
(Dan datanglah penduduk kota) yaitu kota Sodom yang para penduduknya adalah kaum Nabi Luth; mereka datang sewaktu mendengar bahwa di dalam rumah Nabi Luth terdapat beberapa laki-laki tampan yang masih muda-muda, mereka adalah para malaikat itu (dengan gembira) lafal yastabsyiruun menjadi hal, artinya keadaan mereka sangat gembira sekali dengan kedatangan para tamu itu, karena mereka berniat untuk melampiaskan nafsu homonya terhadap tamu-tamu itu.\qt@no{67}}%
\qt@newcmd\qurantrans@id@mdccclxx{%
(Ia berkata) yakni Nabi Luth ("Sesungguhnya mereka adalah tamuku; maka janganlah kalian memberi malu kepadaku.")\qt@no{68}}%
\qt@newcmd\qurantrans@id@mdccclxxi{%
("Dan bertakwalah kepada Allah dan janganlah kalian membuat aku terhina.") dengan niat kalian yang ingin melampiaskan nafsu homo kalian terhadap mereka itu.\qt@no{69}}%
\qt@newcmd\qurantrans@id@mdccclxxii{%
(Mereka berkata, ``Bukankah kami telah melarangmu dari menerima manusia?") yakni menerima mereka sebagai tamumu.\qt@no{70}}%
\qt@newcmd\qurantrans@id@mdccclxxiii{%
(Luth berkata, ``Inilah putri-putriku, jika kalian hendak berbuat,") untuk melampiaskan nafsu syahwat kalian, oleh sebab itu maka kawinilah mereka. Lalu Allah berfirman:\qt@no{71}}%
\qt@newcmd\qurantrans@id@mdccclxxiv{%
("Demi umurmu) khithab atau pembicaraan ini ditujukan kepada Nabi saw.; artinya demi hidupmu (sesungguhnya mereka terombang-ambing di dalam kemabukan atau kesesatan") yakni mereka bergelimang di dalam kesesatannya.\qt@no{72}}%
\qt@newcmd\qurantrans@id@mdccclxxv{%
(Maka mereka dibinasakan oleh suara keras yang mengguntur) oleh suara keras malaikat Jibril (ketika matahari akan terbit).\qt@no{73}}%
\qt@newcmd\qurantrans@id@mdccclxxvi{%
(Maka Kami jadikan bagian atasnya) yakni bagian atas kota mereka (terbalik ke bawah) malaikat Jibril mengangkatnya ke langit kemudian menjatuhkannya dalam keadaan terbalik ke tanah (dan Kami hujani mereka dengan batu dari tanah yang keras) yaitu tanah liat yang dibakar dengan api.\qt@no{74}}%
\qt@newcmd\qurantrans@id@mdccclxxvii{%
(Sesungguhnya pada yang demikian itu) hal yang telah disebutkan itu (benar-benar terdapat tanda-tanda) yang menunjukkan kepada keesaan Allah (bagi orang-orang yang memperhatikan tanda-tanda) bagi orang-orang yang mau memperhatikannya kemudian mau mengambilnya sebagai pelajaran.\qt@no{75}}%
\qt@newcmd\qurantrans@id@mdccclxxviii{%
(Dan sesungguhnya kota itu) yaitu kota kaum Nabi Luth (benar-benar terletak di jalan yang masih tetap dilalui manusia) yakni jalan yang masih dipakai oleh orang-orang Quraisy untuk menuju ke negeri Syam; jalan itu masih tetap ada; mengapa mereka tidak mau menjadikannya sebagai pelajaran?\qt@no{76}}%
\qt@newcmd\qurantrans@id@mdccclxxix{%
(Sesungguhnya pada yang demikian itu benar-benar terdapat tanda-tanda) yakni pelajaran-pelajaran (bagi orang-orang yang beriman).\qt@no{77}}%
\qt@newcmd\qurantrans@id@mdccclxxx{%
(Dan sesungguhnya) lafal in adalah bentuk takhfif daripada inna (adalah penduduk Aikah itu) yang terkenal dengan pohon-pohonnya yang subur dan rindang, terletak di dekat kota Madyan, dan mereka adalah kaum Nabi Syuaib (benar-benar kaum yang zalim) disebabkan mereka mendustakan Nabi Syuaib.\qt@no{78}}%
\qt@newcmd\qurantrans@id@mdccclxxxi{%
(Maka Kami membalas perbuatan mereka itu) yaitu membinasakan mereka dengan musim panas yang sangat (Dan sesungguhnya kedua kota itu) yaitu kota kaum Nabi Luth dan kota kaum Nabi Syuaib (benar-benar terletak di jalan umum) yakni jalan raya (yang terang) jelas; mengapa kalian hai penduduk Mekah tidak mau mengambil pelajaran daripadanya?\qt@no{79}}%
\qt@newcmd\qurantrans@id@mdccclxxxii{%
(Dan sesungguhnya penduduk kota Al-Hijr telah mendustakan) Al-Hijr, nama sebuah lembah yang terletak di antara kota Madinah dan negeri Syam; tempatnya kaum Tsamud (rasul-rasulnya) mereka mendustakan nabi mereka yaitu Nabi Saleh, hal ini berarti sama saja dengan mendustakan rasul-rasul lainnya, karena sesungguhnya ajaran yang disampaikan oleh para rasul itu pada hakikatnya sama, yaitu ajaran tauhid.\qt@no{80}}%
\qt@newcmd\qurantrans@id@mdccclxxxiii{%
(Dan Kami telah mendatangkan kepada mereka tanda-tanda kekuasaan Kami) melalui seekor unta betina tetapi mereka selalu berpaling daripadanya) tidak mau memikirkan tentangnya.\qt@no{81}}%
\qt@newcmd\qurantrans@id@mdccclxxxiv{%
(Dan mereka memahat rumah-rumah dari gunung-gunung batu yang didiami dengan aman.)\qt@no{82}}%
\qt@newcmd\qurantrans@id@mdccclxxxv{%
(Maka mereka dibinasakan oleh suara keras yang mengguntur di waktu pagi) pada waktu subuh.\qt@no{83}}%
\qt@newcmd\qurantrans@id@mdccclxxxvi{%
(Maka tidak dapat menolong) tidak dapat menolak (mereka) daripada azab (apa yang telah mereka usahakan) yaitu berupa bangunan-bangunan benteng dan harta benda yang mereka miliki dan mereka kumpulkan itu.\qt@no{84}}%
\qt@newcmd\qurantrans@id@mdccclxxxvii{%
(Dan tidaklah Kami ciptakan langit dan bumi dan apa yang ada di antara keduanya melainkan dengan benar. Dan sesungguhnya hari kiamat itu pasti akan datang) setiap orang akan menemukan pembalasan amal perbuatannya (maka maafkanlah) hai Muhammad kaummu (dengan cara yang baik) berpalinglah engkau dari mereka tanpa dibarengi dengan rasa menggerutu; akan tetapi ayat ini dinasakh oleh ayat yang memerintahkan memerangi mereka.\qt@no{85}}%
\qt@newcmd\qurantrans@id@mdccclxxxviii{%
(Sesungguhnya Rabbmu, Dialah Yang Maha Pencipta) segala sesuatu (lagi Maha Mengetahui) segala sesuatu.\qt@no{86}}%
\qt@newcmd\qurantrans@id@mdccclxxxix{%
(Dan sesungguhnya Kami telah berikan kepadamu tujuh ayat yang dibaca berulang-ulang) Nabi saw. telah bersabda bahwa yang dimaksud adalah surah Al-Fatihah. Demikianlah menurut riwayat yang dikemukakan oleh Bukhari dan Muslim; surah Al-Fatihah dinamakan demikian karena selalu dibaca berulang-ulang dalam setiap salat (dan Alquran yang agung).\qt@no{87}}%
\qt@newcmd\qurantrans@id@mdcccxc{%
(Janganlah sekali-kali kamu menunjukkan pandangan matamu kepada berbagai macam kenikmatan hidup yang telah Kami berikan kepada beberapa golongan) maksudnya terhadap berbagai macam kemewahan hidup (di antara mereka, dan janganlah kamu bersedih hati terhadap mereka) jika mereka tidak beriman (dan berendah dirilah kamu) bersikap lembutlah kamu (terhadap orang-orang yang beriman.)\qt@no{88}}%
\qt@newcmd\qurantrans@id@mdcccxci{%
(Dan katakanlah, ``Sesungguhnya aku adalah pemberi peringatan) tentang azab Allah supaya jangan menimpa kalian (yang menjelaskan.") artinya yang jelas peringatannya.\qt@no{89}}%
\qt@newcmd\qurantrans@id@mdcccxcii{%
(Sebagaimana Kami telah menurunkan) azab (kepada orang-orang yang membagi-bagi kitab Allah) yaitu Yahudi dan Nasrani.\qt@no{90}}%
\qt@newcmd\qurantrans@id@mdcccxciii{%
(Yaitu orang-orang yang telah menjadikan kitab bacaan) yaitu kitab-kitab yang diturunkan kepada mereka (terbagi-bagi) menjadi beberapa bagian; mereka beriman terhadap sebagiannya dan ingkar terhadap sebagian yang lainnya. Menurut pendapat orang lain dikatakan, yang dimaksud dengan mereka adalah orang-orang yang menguasai jalan-jalan yang menuju ke Mekah dengan maksud untuk menghalang-halangi manusia masuk Islam. Sebagian dari mereka mengatakan tentang Alquran, bahwa Alquran itu adalah sihir; sebagian lainnya mengatakan, Alquran adalah peramal; sedangkan sebagian yang lainnya lagi mengatakan, bahwa Alquran adalah syair.\qt@no{91}}%
\qt@newcmd\qurantrans@id@mdcccxciv{%
(Maka demi Rabbmu, Kami pasti akan menanyai mereka semuanya) dengan pertanyaan yang bernada mengejek.\qt@no{92}}%
\qt@newcmd\qurantrans@id@mdcccxcv{%
(Tentang apa yang telah mereka kerjakan dahulu.)\qt@no{93}}%
\qt@newcmd\qurantrans@id@mdcccxcvi{%
(Maka sampaikanlah olehmu secara terang-terangan) hai Muhammad (segala apa yang diperintahkan kepadamu) untuk melakukannya, artinya sampaikanlah secara terang-terangan dan laksanakanlah dengan rutin (dan berpalinglah dari orang-orang yang musyrik) ayat ini diturunkan sebelum diperintahkan untuk berjihad.\qt@no{94}}%
\qt@newcmd\qurantrans@id@mdcccxcvii{%
(Sesungguhnya Kami memelihara kamu daripada kejahatan orang-orang yang memperolok-olokkan) kamu, Kami akan membinasakan masing-masing dari mereka dengan malapetaka. Mereka yang memperolok-olokkan ialah Walid bin Mughirah, Ashi bin Wa'il, Addi bin Qais, Aswad bin Abdul Mutthalib dan Aswad bin Abdu Yaghuts.\qt@no{95}}%
\qt@newcmd\qurantrans@id@mdcccxcviii{%
(Yaitu orang-orang yang menganggap adanya tuhan yang lain di samping Allah) kalimat ayat ini berkedudukan menjadi sifat. Akan tetapi menurut suatu pendapat dianggap sebagai mubtada, oleh karena mengandung makna syarat, maka khabarnya dimasuki huruf fa, yaitu (maka mereka kelak akan mengetahui) akibat-akibat perbuatannya itu.\qt@no{96}}%
\qt@newcmd\qurantrans@id@mdcccxcix{%
(Dan sungguh) lafal qad menunjukkan makna littahqiq (Kami telah mengetahui, bahwa dadamu menjadi sempit disebabkan apa yang mereka katakan) yaitu disebabkan perolok-olokkan dan pendustaan mereka itu.\qt@no{97}}%
\qt@newcmd\qurantrans@id@mcm{%
(Maka bertasbihlah) seraya (memuji Rabbmu) artinya katakanlah subhaanallaah wa bihamdihi (dan jadilah kamu di antara orang-orang yang bersujud) yakni orang-orang yang mendirikan salat.\qt@no{98}}%
\qt@newcmd\qurantrans@id@mcmi{%
(Dan sembahlah Rabbmu sampai datang kepadamu yang diyakini) yaitu ajal.\qt@no{99}}%
\qt@newcmd\qurantrans@id@mcmii{%
\basmalahid Ketika orang-orang musyrik merasa lambat akan datangnya azab yang diancamkan kepada mereka, lalu turunlah firman-Nya: (Telah pasti datangnya ketetapan Allah) yakni hari kiamat. Lafal ataa diungkapkan dalam bentuk fi`il madhi untuk menunjukkan kepastian kejadiannya, artinya telah dekat (maka janganlah kalian meminta disegerakan datangnya) artinya janganlah kalian meminta disegerakan sebelum saatnya karena sesungguhnya hari kiamat itu pasti akan terjadi (Maha Suci Allah) kalimat ini mengandung makna memahasucikan Dia (dan Maha Tinggi dari apa yang mereka persekutukan) di samping-Nya.\qt@no{1}}%
\qt@newcmd\qurantrans@id@mcmiii{%
(Dia menurunkan malaikat) yakni malaikat Jibril (dengan wahyu) dengan membawa wahyu (atas perintah-Nya) berdasarkan kehendak-Nya (kepada siapa yang Dia kehendaki di antara hamba-hamba-Nya) mereka adalah para nabi (yaitu) huruf an di sini bermakna mufassirah atau kata penafsir (peringatkanlah olehmu sekalian) peringatkanlah orang-orang kafir dengan azab, dan beritahukanlah kepada mereka (bahwasanya tidak ada Tuhan melainkan Aku, maka hendaklah kalian bertakwa kepada-Ku) artinya takutlah kalian kepada-Ku.\qt@no{2}}%
\qt@newcmd\qurantrans@id@mcmiv{%
(Dia menciptakan langit dan bumi dengan hak) artinya secara sungguh-sungguh. (Maha Tinggi Allah daripada apa yang mereka persekutukan) bersama-Nya yaitu berhala-berhala.\qt@no{3}}%
\qt@newcmd\qurantrans@id@mcmv{%
(Dia telah menciptakan manusia dari mani) mulai dari mani hingga menjadi manusia yang kuat lagi kekar (tiba-tiba ia menjadi pembantah) sangat memusuhi (yang nyata) lalu Allah menjelaskan tentang bantahan manusia itu yang tidak mempercayai adanya hari berbangkit, yaitu melalui firman-Nya yang lain: ``Siapakah yang dapat menghidupkan tulang-belulang yang telah hancur luluh." (Q.S. Yasin 78)\qt@no{4}}%
\qt@newcmd\qurantrans@id@mcmvi{%
(Dan binatang ternak) yakni unta, sapi dan kambing. Lafal al-an`aam dibaca nashab karena dinashabkan oleh fi`il yang diperkirakan keberadaannya lalu fi`il tersebut ditafsirkan atau dijelaskan oleh lafal berikut ini, yaitu: (Dia telah menciptakannya untuk kalian) sebagian dari manusia (padanya ada kehangatan) yaitu bulu dan kulitnya dapat dibuat pakaian dan selimut untuk penghangat tubuh kalian (dan berbagai manfaat) yaitu dari anak-anaknya, air susunya dan dapat dijadikan sebagai kendaraan (dan sebagiannya kalian makan) zharaf didahulukan karena untuk tujuan fashilah.\qt@no{5}}%
\qt@newcmd\qurantrans@id@mcmvii{%
(Dan kalian memperoleh pandangan yang indah padanya) yakni sebagai perhiasan kalian (ketika kalian membawanya kembali ke kandang) ketika kalian menggiringnya kembali ke kandangnya di waktu sore hari (dan ketika kalian melepaskannya ke tempat penggembalaan) kalian mengeluarkannya dari kandangnya menuju ke tempat penggembalaan di waktu pagi hari.\qt@no{6}}%
\qt@newcmd\qurantrans@id@mcmviii{%
(Dan ia dapat memikul beban-beban kalian) barang-barang kalian (ke suatu negeri yang kalian tidak sanggup sampai kepadanya) kalian tidak sanggup mencapainya tanpa memakai kendaraan unta (melainkan dengan kesukaran-kesukaran yang memayahkan diri) yang membuat payah diri kalian. (Sesungguhnya Rabb kalian benar-benar Maha Pengasih lagi Maha Penyayang) terhadap kalian, Dia telah menciptakannya untuk kalian manfaatkan.\qt@no{7}}%
\qt@newcmd\qurantrans@id@mcmix{%
(Dan) Dia telah menciptakan (kuda, bighal dan keledai agar kalian menungganginya dan menjadikannya sebagai perhiasan) lafal ziinatan menjadi maf`ul lah. Disebutkannya kedua `illat itu, yaitu untuk ditunggangi dan dianggap sebagai perhiasan hal ini sama sekali tidak bertentangan dengan manfaat lain yang ada padanya. Seperti halnya pada kuda, selain dapat ditunggangi dan dijadikan perhiasan dagingnya dapat dimakan, hal ini telah ditetapkan berdasarkan hadis kitab Sahih Bukhari dan Muslim. (Dan Allah menciptakan apa yang kalian tidak mengetahuinya) berupa hal-hal yang aneh dan menakjubkan.\qt@no{8}}%
\qt@newcmd\qurantrans@id@mcmx{%
(Dan hak bagi Allah menerangkan jalan yang lurus) hak bagi Allah menjelaskannya (dan di antara jalan-jalan) tersebut (ada yang bengkok) menyimpang dari jalan yang lurus. (Dan jika Dia menghendaki) untuk memberi petunjuk kepada kalian (niscaya Dia memberi petunjuk kepada kalian) ke jalan yang lurus (semuanya) sehingga kalian semua mendapat petunjuk ke jalan yang lurus itu atas kehendak kalian sendiri.\qt@no{9}}%
\qt@newcmd\qurantrans@id@mcmxi{%
(Dialah Yang telah menurunkan air hujan itu dari langit untuk kalian, sebagiannya menjadi minuman) untuk kalian minum (dan sebagiannya menjadi tumbuh-tumbuhan) maksudnya oleh sebab air itu menjadi suburlah tumbuh-tumbuhan (yang pada tempat tumbuhnya kalian menggembalakan ternak kalian) kalian jadikan sebagai tempat menggembalakan ternak.\qt@no{10}}%
\qt@newcmd\qurantrans@id@mcmxii{%
(Dia menumbuhkan bagi kalian dengan air itu tanam-tanaman, zaitun, kurma, anggur dan segala macam buah-buahan. Sesungguhnya pada yang demikian itu) hal yang telah disebutkan itu (benar-benar ada tanda) yang menunjukkan akan keesaan Allah swt. (bagi kaum yang memikirkan) mengenai ciptaan-Nya sehingga mereka mau beriman karenanya.\qt@no{11}}%
\qt@newcmd\qurantrans@id@mcmxiii{%
(Dan Dia menundukkan malam dan siang untuk kalian, dan matahari) lafal wasysyamsa bila dibaca nashab berarti diathafkan kepada lafal sebelumnya, bila dibaca rafa' berarti menjadi mubtada (bulan dan bintang-bintang) kedua lafal ini dapat dibaca nashab dan rafa` (ditundukkan) kalau dibaca nashab, maka berkedudukan menjadi hal, dan kalau dibaca rafa` maka menjadi khabar (dengan perintah-Nya) berdasarkan kehendak-Nya (Sesungguhnya pada yang demikian itu benar-benar ada tanda-tanda kekuasaan Allah bagi kaum yang memahami-Nya) bagi kaum yang mau memikirkannya.\qt@no{12}}%
\qt@newcmd\qurantrans@id@mcmxiv{%
(Dan) Dia menundukkan pula bagi kalian (apa yang Dia ciptakan) makhluk yang telah Dia ciptakan (untuk kalian di bumi ini) berupa hewan-hewan dan tumbuh-tumbuhan serta lain-lainnya (dengan berlain-lainan warnanya) seperti ada yang merah, kuning, hijau dan lain sebagainya (Sesungguhnya pada yang demikian itu benar-benar terdapat tanda kekuasaan Allah bagi kaum yang mengingatnya) mengambilnya sebagai pelajaran.\qt@no{13}}%
\qt@newcmd\qurantrans@id@mcmxv{%
(Dan Dialah yang menundukkan lautan) Dia telah membuatnya jinak sehingga dapat dinaiki dan diselami (agar kalian dapat memakan daripadanya daging yang segar) yaitu ikan (dan kalian mengeluarkan dari lautan itu perhiasan yang kalian pakai) yaitu berupa mutiara dan marjan (dan kamu melihat) menyaksikan (bahtera) perahu-perahu (berlayar padanya) dapat melaju di atas air; artinya dapat membelah ombak melaju ke depan atau ke belakang hanya ditiup oleh satu arah angin (dan supaya kalian mencari) lafal ini diathafkan kepada lafal lita'kuluu, artinya supaya kalian mencari keuntungan (dari karunia-Nya) karunia Allah swt. lewat berniaga (dan supaya kalian bersyukur) kepada Allah swt. atas karunia itu.\qt@no{14}}%
\qt@newcmd\qurantrans@id@mcmxvi{%
(Dan Dia menancapkan gunung-gunung di bumi dengan kokohnya) gunung-gunung yang tegak kokoh supaya (tidak) jangan (bumi itu goncang) bergerak (bersama kalian dan) Dia telah menciptakan padanya (sungai-sungai) seperti sungai Nil (dan jalan-jalan) jalan untuk dilalui (agar kalian mendapat petunjuk) untuk sampai kepada tujuan-tujuan kalian.\qt@no{15}}%
\qt@newcmd\qurantrans@id@mcmxvii{%
(Dan Dia ciptakan, tanda-tanda) dengan melaluinya kalian mendapat petunjuk arah jalan yang kalian lalui, seperti gunung-gunung dan sungai-sungai. (Dan dengan bintang-bintang itulah) yang dimaksud adalah bentuk jamak sekalipun lafalnya mufrad (mereka mendapat petunjuk) jalan dan arah kiblat di waktu malam hari.\qt@no{16}}%
\qt@newcmd\qurantrans@id@mcmxviii{%
(Maka apakah Tuhan yang menciptakan itu) itu Allah (sama dengan yang tidak menciptakan apa-apa) yang dimaksud adalah berhala-berhala, karena mereka menyekutukannya bersama dengan Allah dalam hal beribadah? Tentu saja tidak. (Maka mengapa kalian tidak mengambil pelajaran) dari hal ini, karenanya kemudian kalian beriman?\qt@no{17}}%
\qt@newcmd\qurantrans@id@mcmxix{%
(Dan jika kalian menghitung-hitung nikmat Allah, niscaya kalian tak dapat menentukan jumlahnya) tidak dapat menghitungnya terlebih lagi untuk mensyukurinya secara layak kalian tidak akan mampu melakukannya (Sesungguhnya Allah benar-benar Maha Pengampun lagi Maha Penyayang) karena Dia telah melimpahkan nikmat-Nya kepada kalian padahal kalian meremehkan dan mendurhakai-Nya.\qt@no{18}}%
\qt@newcmd\qurantrans@id@mcmxx{%
(Dan Allah mengetahui apa yang kalian rahasiakan dan apa yang kalian lahirkan.)\qt@no{19}}%
\qt@newcmd\qurantrans@id@mcmxxi{%
(Dan berhala-berhala yang mereka seru) dapat dibaca yad`uuna dan tad`uuna, artinya yang mereka sembah (selain Allah) yang dimaksud adalah berhala-berhala (tidak dapat membuat sesuatu apa pun sedangkan berhala-berhala itu sendiri dibuat orang) mereka pahat dari batu atau dari bahan-bahan yang lain.\qt@no{20}}%
\qt@newcmd\qurantrans@id@mcmxxii{%
(Berhala-berhala itu benda mati) tidak ada rohnya; lafal ini menjadi khabar yang kedua (tidak hidup) berkedudukan menjadi taukid atau pengukuh (dan mereka tidak mengetahui) berhala-berhala tersebut tidak mengetahui (bilakah) menunjukkan makna waktu (mereka akan dibangkitkan) yang dimaksud adalah makhluk semuanya; maka jika keadaannya demikian mengapa berhala-berhala itu mereka sembah? Kalau demikian berarti tiada tuhan melainkan hanya Yang Maha Pencipta, Yang Maha Hidup dan Yang Maha Mengetahui semua yang gaib.\qt@no{21}}%
\qt@newcmd\qurantrans@id@mcmxxiii{%
(Tuhan kalian) berhak untuk disembah oleh kalian (adalah Tuhan Yang Maha Esa) tidak ada tandingan-Nya, baik dalam Dzat-Nya maupun sifat-Nya, yaitu Allah swt. (Maka orang-orang yang tidak beriman kepada akhirat hati mereka mengingkari) keesaan Allah (sedangkan mereka sendiri adalah orang-orang yang sombong) orang-orang yang takabur tidak mau beriman kepada adanya hari akhirat.\qt@no{22}}%
\qt@newcmd\qurantrans@id@mcmxxiv{%
(Tidak diragukan lagi) memang benar (bahwa sesungguhnya Allah mengetahui apa yang mereka rahasiakan dan apa yang mereka lahirkan) maka Dia membalas mereka berdasarkan hal tersebut. (Sesungguhnya Allah tidak menyukai orang-orang yang sombong) dengan pengertian, bahwa Dia akan menyiksa mereka.\qt@no{23}}%
\qt@newcmd\qurantrans@id@mcmxxv{%
Ayat ini diturunkan berkenaan dengan Nadhr bin Harits (Dan apabila dikatakan kepada mereka, ``Apakah) maa di sini bermakna istifham atau kata tanya (yang) dzaa di sini berfungsi sebagai maushul (telah diturunkan Rabb kalian?") kepada Muhammad. (Mereka menjawab,) yaitu ("Dongeng-dongengan) buat-buatan (orang-orang dahulu.") untuk menyesatkan manusia.\qt@no{24}}%
\qt@newcmd\qurantrans@id@mcmxxvi{%
(Ucapan mereka, menyebabkan mereka memikul) akibatnya mereka akan memikul (dosa-dosanya) kesalahan-kesalahannya (dengan sepenuhnya) artinya tidak ada sesuatu pun yang dapat dijadikan sebagai tebusan daripadanya (pada hari kiamat, dan sebagian) ditimpakan pula kepada mereka sebagian (dosa-dosa orang-orang yang mereka sesatkan yang tidak mengetahui sedikit pun) bahwa mereka disesatkan, karena mereka mengajak orang-orang yang diserunya ke jalan yang sesat, kemudian orang-orang yang diserunya itu mengikuti langkah mereka. Dengan demikian maka orang-orang yang menyeru mereka ikut andil dalam dosanya. (Ingatlah, amat buruklah) amat jeleklah (apa yang mereka pikul itu) yakni, dosa-dosa yang mereka pikul itu adalah seburuk-buruk dosa.\qt@no{25}}%
\qt@newcmd\qurantrans@id@mcmxxvii{%
(Sesungguhnya orang-orang yang sebelum mereka telah mengadakan makar) yaitu seperti apa yang telah dilakukan oleh raja Namrudz; ia membangun sebuah pencakar langit, lalu ia menaikinya dengan maksud untuk memerangi penduduk langit (maka Allah menghancurkan) bertujuan untuk menghancurkan (rumah-rumah mereka dari fondasinya) untuk itu maka Allah mengirimkan angin topan dan gempa bumi yang keras sehingga hancur leburlah apa yang telah mereka bangun itu (lalu atap rumah-rumah mereka jatuh menimpa mereka dari atas) artinya mereka ada di bawahnya lalu tertimpa hal tersebut (dan datanglah azab itu kepada mereka dari tempat yang tidak mereka sadari) artinya azab itu datang kepada mereka dari arah yang tidak mereka duga sebelumnya. Akan tetapi menurut pendapat yang lain dikatakan bahwa ini hanya tamtsil tentang dibinasakannya makar mereka yang telah direncanakan sebelumnya terhadap rasul.\qt@no{26}}%
\qt@newcmd\qurantrans@id@mcmxxviii{%
(Kemudian Allah menghinakan mereka di hari kiamat) membuat mereka hina (dan berfirman)-lah Allah kepada mereka melalui lisan malaikat-Nya dengan nada mengejek ("Di manakah sekutu-sekutu-Ku itu?) yang menurut dugaan kalian itu (yang karena membelanya kalian selalu memusuhi) menentang kaum mukminin (tentang perihal mereka.") mengenai perkara mereka. (Berkatalah) artinya nanti akan berkata/menjawab (orang-orang yang diberi ilmu) yaitu para nabi dan orang-orang mukmin ("Sesungguhnya kehinaan dan azab hari ini ditimpakan atas orang-orang yang kafir.") para nabi dan orang-orang mukmin mengatakan demikian sebagai ejekan yang ditujukan kepada orang-orang kafir.\qt@no{27}}%
\qt@newcmd\qurantrans@id@mcmxxix{%
(Orang-orang yang dimatikan) dapat dibaca tatawaffaahum dan yatawaffaahum (oleh para malaikat dalam keadaan berbuat zalim kepada diri mereka sendiri) karena melakukan kekufuran (lalu mereka menyerahkan diri) mereka tunduk dan berserah diri ketika maut menjelang mereka seraya berkata ("Kami sekali-kali tidak ada mengerjakan suatu kejahatan pun.") yaitu perbuatan musyrik. Maka para malaikat berkata kepada mereka ("Ada, sesungguhnya Allah Maha Mengetahui apa yang telah kalian kerjakan.") oleh sebab itu Dia membalaskannya kepada diri kalian.\qt@no{28}}%
\qt@newcmd\qurantrans@id@mcmxxx{%
Lalu dikatakan kepada mereka ("Maka masukilah pintu-pintu neraka Jahanam, kalian kekal di dalamnya. Maka amat buruklah tempat) menetap (orang-orang yang menyombongkan diri itu.")\qt@no{29}}%
\qt@newcmd\qurantrans@id@mcmxxxi{%
(Dan dikatakan kepada orang-orang yang bertakwa) yang memelihara diri dari kemusyrikan ("Apakah yang telah diturunkan oleh Rabb kalian?" Mereka menjawab, ``Kebaikan." Orang-orang yang telah berbuat baik) karena beriman (di dunia ini mendapat pembalasan yang baik) yakni kehidupan yang baik. (Dan sesungguhnya kampung akhirat) yakni surga (lebih baik) daripada kehidupan dunia berikut semua isinya. Lalu Allah berfirman di dalam kampung akhirat itu. (Dan sebaik-baik tempat bagi orang-orang yang bertakwa) adalah surga itu.\qt@no{30}}%
\qt@newcmd\qurantrans@id@mcmxxxii{%
(Yaitu surga Adn) sebagai tempat tinggal. Lafal jannaatu Adn adalah mubtada sedangkan khabarnya ialah (mereka masuk ke dalamnya; mengalir di bawahnya sungai-sungai, di dalam surga itu mereka mendapat segala apa yang mereka kehendaki. Demikianlah) pembalasan itu (Allah memberi balasan kepada orang-orang yang bertakwa.)\qt@no{31}}%
\qt@newcmd\qurantrans@id@mcmxxxiii{%
(Yaitu orang-orang) lafal alladziina di sini menjadi na`at atau sifat (yang diwafatkan oleh para malaikat dalam keadaan baik) yakni suci dari kekafiran (dengan mengatakan) para malaikat itu berkata kepada mereka ketika akan diwafatkan ("Salaamun `alaikum.") dan dikatakan pula kepada mereka kelak di hari akhirat ("Masuklah kalian ke dalam surga itu disebabkan apa yang telah kalian kerjakan.")\qt@no{32}}%
\qt@newcmd\qurantrans@id@mcmxxxiv{%
(Tidak ada) tiada (yang ditunggu-tunggu) oleh orang-orang kafir (selain datang kepada mereka) dapat dibaca ta'tiyahum atau ya'tiyahum (para malaikat) untuk mencabut nyawa mereka (atau datangnya perintah Rabbmu) yakni azab atau hari kiamat yang terdapat di dalamnya azab buat mereka. (Demikianlah) seperti apa yang telah dilakukan oleh mereka (telah dilakukan pula oleh orang-orang sebelum mereka) daripada umat-umat terdahulu yang mendustakan rasul-rasul mereka kemudian mereka dibinasakan. (Dan sekali-kali Allah tidak menganiaya mereka) dengan membinasakan mereka tanpa dosa (akan tetapi merekalah yang selalu menganiaya diri mereka sendiri) karena melakukan kekafiran.\qt@no{33}}%
\qt@newcmd\qurantrans@id@mcmxxxv{%
(Maka mereka ditimpa oleh akibat kejahatan perbuatan mereka sendiri) yakni pembalasannya (dan dibinasakanlah) diazablah (mereka oleh apa yang selalu mereka perolok-olokkan) yaitu azab.\qt@no{34}}%
\qt@newcmd\qurantrans@id@mcmxxxvi{%
(Dan berkatalah orang-orang musyrik) dari kalangan penduduk Mekah ("Jika Allah menghendaki niscaya kami tidak akan menyembah sesuatu apa pun selain Dia, baik kami maupun bapak-bapak kami, dan tidak pula kami mengharamkan sesuatu pun tanda izin-Nya) yaitu mengharamkan bahirah dan saibah. Ini berarti bahwa kemusyrikan kami dan pengharaman kami ini berdasarkan kehendak-Nya karena Dia rela terhadapnya. Maka Allah berfirman menyanggah mereka: (Demikianlah yang diperbuat oleh orang-orang sebelum mereka) artinya mereka telah mendustakan rasul-rasul mereka tentang apa yang didatangkan oleh para rasul itu (maka tidak ada) (kewajiban atas para rasul selain dari menyampaikan amanat Allah dengan terang) dan mereka tidak berkewajiban untuk memberi hidayah.\qt@no{35}}%
\qt@newcmd\qurantrans@id@mcmxxxvii{%
(Dan sesungguhnya Kami telah mengutus rasul pada tiap-tiap umat) seperti Aku mengutus kamu kepada mereka (untuk) artinya untuk menyerukan ('Sembahlah Allah) esakanlah Dia (dan jauhilah thaghut,') berhala-berhala itu janganlah kalian sembah (maka di antara umat itu ada orang-orang yang diberi petunjuk oleh Allah) lalu ia beriman (dan ada pula di antaranya orang-orang yang telah pasti) telah ditentukan (kesesatan baginya) menurut ilmu Allah, sehingga ia tidak beriman. (Maka berjalanlah kalian) hai orang-orang kafir Mekah (di muka bumi dan perhatikanlah bagaimana kesudahan orang-orang yang mendustakan) rasul-rasul mereka, yakni kebinasaan yang akan mereka alami nanti.\qt@no{36}}%
\qt@newcmd\qurantrans@id@mcmxxxviii{%
(Jika kamu sangat mengharapkan) hai Muhammad (agar mereka dapat petunjuk) sedangkan Allah telah menyesatkan mereka niscaya kamu tidak akan mampu melakukan hal itu (maka sesungguhnya Allah tiada memberi petunjuk kepada orang yang disesatkan-Nya) dapat dibaca yudhillu dan yudhallu, artinya orang yang dikehendaki-Nya sesat (dan sekali-kali mereka tiada mempunyai penolong") yang dapat mencegah azab Allah atas diri mereka.\qt@no{37}}%
\qt@newcmd\qurantrans@id@mcmxxxix{%
(Mereka bersumpah dengan nama Allah dengan sumpahnya yang sungguh-sungguh) artinya mereka bersumpah dengan sungguh-sungguh ("Allah tidak akan membangkitkan orang yang mati.") maka Allah berfirman menyanggah mereka (Tidak demikian, bahkan) Allah pasti akan membangkitkan mereka (sebagai suatu janji yang benar dari Allah) lafal wa`dan dan haqqan kedua-duanya adalah bentuk mashdar yang fungsinya mengukuhkan makna fi`ilnya dan dinashabkan oleh fi`ilnya yang keberadaannya diperkirakan; artinya Allah sungguh telah menjanjikan hal tersebut dan Allah akan membuktikannya dengan benar (akan tetapi kebanyakan manusia) penduduk Mekah (tiada mengetahui) hal tersebut.\qt@no{38}}%
\qt@newcmd\qurantrans@id@mcmxl{%
(Agar Allah menjelaskan) lafal liyubayyina ini berta`lluq kepada lafal yab`atsuhum yang keberadaannya diperkirakan (kepada mereka apa yang mereka perselisihkan itu) bersama dengan orang-orang mukmin (tentangnya) tentang masalah agama; melalui cara mengazab orang-orang kafir dan memberi pahala orang-orang mukmin (agar orang-orang kafir itu mengetahui bahwasanya mereka adalah orang-orang yang berdusta) disebabkan mereka mengingkari adanya hari berbangkit.\qt@no{39}}%
\qt@newcmd\qurantrans@id@mcmxli{%
(Sesungguhnya perkataan Kami terhadap sesuatu apabila Kami menghendakinya) artinya Kami berkehendak untuk mengadakannya. Lafal qaulunaa adalah mubtada sedangkan khabarnya ialah (Kami hanya mengatakan kepadanya, ``Jadilah," maka jadilah ia) artinya, maka sesuatu yang dikehendaki-Nya itu ada seketika. Menurut qiraat lafal fayakuunu dibaca nashab sehingga menjadi fayakuuna karena diathafkan kepada lafal naquula. Ayat ini menunjukkan makna menetapkan kekuasaan Allah di dalam membangkitkan makhluk.\qt@no{40}}%
\qt@newcmd\qurantrans@id@mcmxlii{%
(Dan orang-orang yang berhijrah karena Allah) untuk menegakkan agama-Nya (sesudah mereka dianiaya) mengalami penganiayaan dari penduduk kota Mekah yang dimaksud adalah Nabi saw. dan para sahabatnya (pasti Kami akan memberikan tempat buat mereka) menempatkan mereka (di dunia ini) pada suatu tempat tinggal (yang baik) yakni kota Madinah. (Dan sesungguhnya pahala di akhirat) yaitu surga itu (adalah lebih besar) lebih agung (kalau mereka mengetahui) maksudnya kalau orang-orang kafir itu atau orang-orang yang tidak ikut hijrah benar-benar mengetahui tentang kemuliaan yang diperoleh oleh orang-orang yang berhijrah, niscaya mereka akan ikut hijrah bersama dengan orang-orang yang berhijrah.\qt@no{41}}%
\qt@newcmd\qurantrans@id@mcmxliii{%
Mereka adalah (orang-orang yang sabar) di dalam menghadapi penganiayaan kaum musyrikin dan berhijrah demi untuk memenangkan agama Islam (dan hanya kepada Rabb saja mereka bertawakal) maka Allah pasti memberi mereka rezeki dari jalan yang tiada mereka perhitungkan sebelumnya.\qt@no{42}}%
\qt@newcmd\qurantrans@id@mcmxliv{%
(Dan Kami tidak mengutus sebelum kamu kecuali orang-orang lelaki yang Kami beri wahyu kepada mereka) bukannya para malaikat (maka bertanyalah kepada orang yang mempunyai pengetahuan) yakni para ulama yang ahli dalam kitab Taurat dan kitab Injil (jika kalian tidak mengetahui) hal tersebut, mereka pasti mengetahuinya karena kepercayaan kalian kepada mereka lebih dekat daripada kepercayaan kalian terhadap Nabi Muhammad saw.\qt@no{43}}%
\qt@newcmd\qurantrans@id@mcmxlv{%
(Dengan membawa keterangan-keterangan) lafal ini berta`alluq kepada fi`il yang tidak disebutkan; artinya Kami utus mereka dengan membawa hujah-hujah yang jelas (dan kitab-kitab) yakni kitab-kitab suci. (Dan Kami turunkan kepadamu Adz-Dzikr) yakni Alquran (agar kamu menerangkan kepada umat manusia apa yang diturunkan kepada mereka) yang di dalamnya dibedakan antara halal dan haram (dan supaya mereka memikirkan) tentang hal tersebut kemudian mereka mengambil pelajaran daripadanya.\qt@no{44}}%
\qt@newcmd\qurantrans@id@mcmxlvi{%
(Maka apakah merasa aman orang-orang yang membuat makar) tipu daya (yang jahat itu) terhadap diri Nabi saw. sewaktu mereka berunding di Darun Nadwah untuk mengikatnya, atau membunuhnya atau mengusirnya sebagaimana penjelasan yang telah dikemukakan dalam surah Al-Anfal (dari bencana ditenggelamkannya bumi oleh Allah bersama mereka) seperti apa yang terjadi terhadap diri Qarun (atau datangnya azab kepada mereka dari tempat yang tidak mereka sadari) dari arah yang tidak pernah mereka duga sebelumnya; dan sungguh mereka benar-benar dibinasakan dalam perang Badar, hal tersebut tidak masuk ke dalam perhitungan mereka sebelumnya.\qt@no{45}}%
\qt@newcmd\qurantrans@id@mcmxlvii{%
(Atau Allah mengazab mereka di waktu mereka dalam perjalanan) sewaktu mereka sedang dalam perjalanan untuk berniaga (maka sekali-kali mereka tidak dapat menolak) azab itu.\qt@no{46}}%
\qt@newcmd\qurantrans@id@mcmxlviii{%
(Atau Allah mengazab mereka secara berangsur-angsur) sedikit demi sedikit hingga semuanya binasa; lafal takhawwufin menjadi hal dari fa`il atau dari maf'ul (maka sesungguhnya Rabb kalian adalah Maha Pengasih lagi Maha Penyayang) karena Dia tidak menyegerakan siksa-Nya terhadap mereka.\qt@no{47}}%
\qt@newcmd\qurantrans@id@mcmxlix{%
(Dan apakah mereka tidak memperhatikan segala sesuatu yang telah diciptakan Allah) yang ia mempunyai bayangan, seperti pohon dan gunung (yang berbolak-balik) condong ke sana dan condong ke mari (bayangannya ke kanan dan ke kiri) lafal asysyamaail adalah bentuk jamak dari lafal syimaal; artinya bayangan itu condong ke arah dua sisinya, pertama di permulaan siang hari dan yang kedua pada sore harinya (dalam keadaan sujud kepada Allah) lafal sujjadan menjadi hal; artinya mereka lakukan demikian dalam keadaan tunduk kepada Allah sesuai dengan karakter mereka (sedangkan mereka) yakni bayangan-bayangan itu (berendah diri?) merendahkan dirinya terhadap Allah; bayangan-bayangan tersebut diungkapkan seolah-olah mereka berakal.\qt@no{48}}%
\qt@newcmd\qurantrans@id@mcml{%
(Dan kepada Allah sajalah bersujud segala apa yang berada di langit dan semua makhluk yang melata di bumi) artinya semua makhluk itu tunduk kepada-Nya. Sesuai dengan karakternya; kemudian mereka diungkapkan dalam bentuk yang tidak berakal, mengingat mereka yang tidak berakal jumlahnya lebih banyak (dan juga para malaikat) mereka disebutkan secara khusus di sini karena mengingat keutamaan yang mereka miliki (sedangkan para malaikat itu tidak menyombongkan diri) tidak pernah sekejap pun meninggalkan beribadah kepada-Nya.\qt@no{49}}%
\qt@newcmd\qurantrans@id@mcmli{%
(Mereka takut) yakni para malaikat; lafal ini menjadi hal dari dhamir yang terkandung di dalam lafal yastakbiruuna (kepada Rabb mereka yang berkuasa atas mereka) lafal fauqahum menjadi hal daripada dhamir hum; artinya yang menguasai mereka dengan keperkasaan-Nya (dan melaksanakan apa yang diperintahkan kepada mereka) untuk melakukannya.\qt@no{50}}%
\qt@newcmd\qurantrans@id@mcmlii{%
(Allah berfirman, ``Janganlah kalian menyembah dua tuhan) lafal istnaini berfungsi sebagai taukid atau pengukuhan makna (Sesungguhnya Dialah Tuhan Yang Maha Esa) disebutkannya lafal ilaahun dan waahidun untuk menetapkan sifat uluhiah dan sifat wahdaniah Allah (maka hendaklah kepada-Ku saja kalian takut.") janganlah kalian takut kepada selain Aku. Di dalam ungkapan ini terkandung pengertian iltifat dari dhamir gaib.\qt@no{51}}%
\qt@newcmd\qurantrans@id@mcmliii{%
(Dan kepunyaan-Nyalah segala apa yang ada di langit dan di bumi) sebagai milik, makhluk dan hamba-Nya (dan untuk-Nyalah agama itu) ketaatan itu (selama-lamanya) untuk selamanya; lafal waashiban menjadi hal dari lafal ad-diin, sedangkan sebagai `amilnya adalah makna zharaf. (Maka mengapa kalian bertakwa kepada selain Allah?) sedangkan Dia adalah Tuhan yang sebenarnya, dan tiada Tuhan selain-Nya. Istifham atau kata tanya di sini mengandung pengertian ingkar dan celaan.\qt@no{52}}%
\qt@newcmd\qurantrans@id@mcmliv{%
(Dan apa saja nikmat yang ada pada kalian maka dari Allahlah datangnya) tiada yang dapat mendatangkannya selain Dia. Huruf maa di sini adalah syarthiyah atau maushulah (dan bila kalian ditimpa) tertimpa (kemudaratan) seperti kemiskinan dan sakit (maka hanya kepada-Nyalah kalian meminta pertolongan) mengangkat suara kalian untuk meminta pertolongan seraya berdoa kepada-Nya, dan niscaya kalian tidak akan meminta kepada selain-Nya.\qt@no{53}}%
\qt@newcmd\qurantrans@id@mcmlv{%
(Kemudian apabila Dia telah menghilangkan kemudaratan itu daripada kalian, tiba-tiba sebagian daripada kalian mempersekutukan Rabbnya dengan yang lain).\qt@no{54}}%
\qt@newcmd\qurantrans@id@mcmlvi{%
(Biarkanlah mereka mengingkari apa yang telah Kami berikan kepada mereka) yaitu nikmat (maka bersenang-senanglah kalian) sebab kesepakatan kalian untuk menyembah berhala-berhala. Amar atau perintah di sini mengandung pengertian ancaman. (Kelak kalian akan mengetahui) akibat daripada hal tersebut.\qt@no{55}}%
\qt@newcmd\qurantrans@id@mcmlvii{%
(Dan mereka menyediakan) yakni orang-orang musyrik itu (untuk apa-apa yang mereka tiada mengetahui) bahwa hal itu mendatangkan mudarat dan tidak bermanfaat sama sekali; yang dimaksud adalah untuk berhala-berhala (satu bagian dari rezeki yang telah Kami berikan kepada mereka) berupa ladang dan ternak, yaitu melalui perkataan mereka, ini adalah untuk Allah dan ini adalah untuk sekutu-sekutu kami. (Demi Allah sesungguhnya kalian akan ditanya) dengan pertanyaan yang bernada mencela; di dalam ungkapan ini iltifat dari ghaibah (tentang apa yang telah kalian ada-adakan) terhadap Allah di mana kalian telah mengatakan bahwa Allah telah memerintahkan kalian untuk berbuat hal itu.\qt@no{56}}%
\qt@newcmd\qurantrans@id@mcmlviii{%
(Dan mereka menetapkan bagi Allah anak-anak perempuan) yaitu melalui perkataan mereka, bahwa para malaikat itu adalah anak-anak perempuan Allah (Maha Suci Allah) ungkapan yang menyucikan-Nya daripada apa yang mereka duga (sedangkan untuk mereka sendiri apa yang mereka sukai) memilihnya, artinya anak-anak lelaki. Jumlah kalimat ini menjadi mahal rafa', atau menjadi mahal nashab dari fi'il yaj'aluuna. Artinya mereka menetapkan bagi Allah anak-anak perempuan yang mereka sendiri membencinya, sedangkan pada kenyataannya Dia Maha Suci dari mempunyai anak, kemudian mereka menetapkan untuk diri mereka sendiri anak-anak lelaki yang mereka pilih sendiri. Dengan demikian berarti mereka ingin merasa lebih unggul, sebagaimana yang telah dijelaskan oleh firman-Nya yang lain, yaitu, ``Tanyakanlah (hai Muhammad) kepada mereka (orang-orang kafir Mekah) apakah untuk Rabb kalian anak-anak perempuan dan untuk mereka anak-anak laki-laki." (Ash-Shaffat 149).\qt@no{57}}%
\qt@newcmd\qurantrans@id@mcmlix{%
(Dan apabila seorang dari mereka diberi kabar dengan kelahiran anak perempuan) ia mempunyai anak perempuan yang baru dilahirkan (maka jadilah) maka berubahlah (roman mukanya menjadi hitam) dengan perubahan yang menunjukkan kedukaan dan kesusahan (dan dia sangat marah) marah sekali, maka mengapa mereka menisbatkan anak-anak perempuan terhadap Allah swt.?\qt@no{58}}%
\qt@newcmd\qurantrans@id@mcmlx{%
(Ia menyembunyikan dirinya) menghilang (dari orang banyak) dari pandangan kaumnya (disebabkan buruknya berita yang disampaikan kepadanya) karena ia takut akan mendapat celaan, sedangkan ia dalam keadaan bingung untuk melakukan tindakan selanjutnya sebagai pemecahannya. (Apakah dia akan memeliharanya) yakni membiarkannya tanpa dibunuh (dengan menanggung kehinaan) hina dan direndahkan (ataukah akan menguburkannya ke dalam tanah hidup-hidup) seumpamanya ia memendam anak perempuan itu ke dalam tanah. (Ketahuilah, alangkah buruknya) alangkah jeleknya (apa yang mereka tetapkan itu) keputusan mereka itu karena mereka telah menisbatkan kepada Tuhan yang menciptakan mereka mempunyai anak-anak perempuan padahal anak-anak perempuan itu kedudukannya di kalangan mereka serendah itu.\qt@no{59}}%
\qt@newcmd\qurantrans@id@mcmlxi{%
(Bagi orang-orang yang tidak beriman kepada kehidupan akhirat) yaitu orang-orang kafir (ada perumpamaan yang buruk) sifat yang buruk, yaitu kebiasaan mereka mengubur hidup-hidup anak-anak perempuan padahal mereka membutuhkannya (dan bagi Allah ada perumpamaan yang maha tinggi) sifat yang maha tinggi, yaitu bahwasanya tidak ada Tuhan selain Dia (dan Dialah Yang Maha Perkasa) di dalam kerajaan-Nya (lagi Maha Bijaksana) di dalam mengatur makhluk-Nya.\qt@no{60}}%
\qt@newcmd\qurantrans@id@mcmlxii{%
(Jika Allah menghukum manusia karena kezalimannya) disebabkan kedurhakaan-kedurhakaan mereka (niscaya tidak akan ditinggalkan-Nya padanya) yakni di muka bumi ini sesuatu pun (dari makhluk yang melata) makhluk yang hidup di permukaannya (tetapi Allah menangguhkan mereka sampai pada waktu yang ditentukan. Maka apabila telah tiba waktu yang ditentukan bagi mereka, tidaklah mereka dapat mengundurkan) waktunya (barang sesaat pun dan tidak pula mendahulukan) waktunya.\qt@no{61}}%
\qt@newcmd\qurantrans@id@mcmlxiii{%
(Dan mereka menetapkan bagi Allah apa yang mereka sendiri membencinya) untuk diri mereka sendiri, yaitu anak-anak perempuan; menisbatkan sekutu kepada-Nya dan menghina rasul-rasul (dan keluarlah) perkataan (dari lidah mereka) selain dari hal-hal tersebut (kedustaan) yaitu (bahwa sesungguhnya merekalah yang akan mendapat kebaikan) di sisi Allah, yaitu mendapat surga; hal ini dijelaskan oleh firman Allah swt. yang lain, yaitu, ``Dan jika aku dikembalikan kepada Rabbku, maka sesungguhnya aku akan memperoleh kebaikan pada sisi-Nya." (Fushshilat 50). Selanjutnya Allah swt. berfirman: (Tiadalah diragukan) sudah dipastikan (bahwa nerakalah bagi mereka, dan sesungguhnya mereka segera dimasukkan ke dalamnya) artinya mereka dibiarkan di dalam neraka, atau mereka dijebloskan ke dalamnya. Menurut suatu qiraat lafal mufrathuuna dibaca mufrithuuna, artinya sesungguhnya mereka adalah orang-orang yang melampaui batas.\qt@no{62}}%
\qt@newcmd\qurantrans@id@mcmlxiv{%
(Demi Allah, sesungguhnya Kami telah mengutus kepada umat-umat sebelum kamu) telah mengutus rasul-rasul Kami (tetapi setan menjadikan umat-umat itu memandang baik perbuatan mereka) yang buruk itu sehingga perbuatan-perbuatan mereka yang buruk itu dilihatnya baik; oleh karenanya mereka mendustakan rasul-rasul (maka setan menjadi pemimpin mereka) yang mengatur urusan-urusan mereka (di hari itu) yakni di dalam kehidupan dunia (dan bagi mereka azab yang sangat pedih) yang sangat menyakitkan kelak di hari kemudian. Menurut suatu pendapat dikatakan bahwa makna yang dimaksud dengan hari ini ialah hari kiamat; ungkapan ini menggambarkan tentang kejadian di masa mendatang dalam bentuk sekarang; artinya tidak ada seorang penolong pun bagi mereka selain Dia, sedangkan setan sendiri tidak mampu untuk menyelamatkan dirinya sendiri, mana mungkin ia dapat menyelamatkan orang lain.\qt@no{63}}%
\qt@newcmd\qurantrans@id@mcmlxv{%
(Dan Kami tidak menurunkan kepadamu) hai Muhammad (Alkitab ini) Alquran ini (melainkan agar kamu dapat menjelaskan kepada mereka apa yang mereka perselisihkan itu) yaitu tentang perkara agama (dan menjadi petunjuk) diathafkan kepada lafal litubayyina (dan rahmat bagi kaum yang beriman) kepada Alquran itu.\qt@no{64}}%
\qt@newcmd\qurantrans@id@mcmlxvi{%
(Dan Allah menurunkan dari langit air hujan dan dengan air itu dihidupkan-Nya bumi) dengan tumbuh-tumbuhan (sesudah matinya) dimaksud sesudah mengalami kekeringan. (Sesungguhnya pada yang demikian itu) dalam hal yang telah disebutkan itu (benar benar terdapat tanda) yang menunjukkan adanya hari berbangkit (bagi orang-orang yang mendengarkan) dengan pendengaran dibarengi dengan pemikiran.\qt@no{65}}%
\qt@newcmd\qurantrans@id@mcmlxvii{%
(Dan sesungguhnya pada binatang ternak itu benar-benar terdapat pelajaran bagi kalian) bahan pelajaran. (Kami memberi kalian minum) lafal ini berfungsi sebagai penjelas daripada pengertian pelajaran tadi (daripada apa yang berada dalam perutnya) dalam perut binatang ternak itu (di) huruf min di sini menunjukkan makna ibtida dan bertaalluq kepada lafal nusqiikum (antara kotoran) yakni lemak ususnya (dan darah berupa air susu yang bersih) sedikit pun tidak bercampur kotoran dan darah baik dari segi rasa, bau atau warnanya atau campuran di antara keduanya (yang mudah ditelan bagi orang-orang yang meminumnya) lewat dengan mudah di tenggorokan mereka dan tidak sulit untuk ditelan.\qt@no{66}}%
\qt@newcmd\qurantrans@id@mcmlxviii{%
(Dan dari buah kurma dan anggur) terdapat jenis buah-buahan (yang kalian dapat membuat minuman yang memabukkan daripadanya) dimaksud khamar yang dapat memabukkan. Di sini kata muskiran disebutkan dengan memakai mashdarnya, yaitu sakaran. Hal ini diturunkan sebelum adanya pengharaman khamar (dan rezeki yang baik) seperti selai kurma, anggur kering, cuka dan sirup. (Sesungguhnya pada yang demikian itu) hal yang telah disebutkan itu (benar-benar terdapat tanda) yang menunjukkan kekuasaan Allah swt. (bagi orang-orang yang berakal) yang memikirkannya.\qt@no{67}}%
\qt@newcmd\qurantrans@id@mcmlxix{%
(Dan Rabbmu mewahyukan kepada lebah) dalam bentuk ilham (hendaknya) huruf an di sini dapat diartikan sebagai an mashdariyah atau an mufassirah (buatlah sarang-sarang di bukit-bukit) tempat kamu berdiam (dan di pohon-pohon) sebagai tempat tinggal (dan di tempat-tempat yang dibikin manusia) sarang-sarang buatan manusia untuk kamu, jika kamu tidak suka kepada sarang buatan manusia, kamu boleh menempati tempat yang lainnya.\qt@no{68}}%
\qt@newcmd\qurantrans@id@mcmlxx{%
(Kemudian makanlah dari setiap buah-buahan dan tempuhlah) masukilah (jalan Rabbmu) jalan-jalan yang telah ditunjukkan oleh-Nya kepadamu di dalam mencari rezekimu (yang telah dimudahkan) lafal dzululan ini adalah bentuk jamak dari lafal tunggal dzaluulun; berkedudukan menjadi hal dari lafal subula rabbiki. Artinya jalan yang telah dimudahkan bagimu sehingga amat mudah ditempuh sekali pun sangat sulit dan kamu tidak akan sesat untuk kembali ke sarangmu dari tempat itu betapa pun jauhnya. Akan tetapi menurut pendapat yang lain dikatakan bahwa lafal dzululan ini menjadi hal daripada dhamir yang terdapat di dalam lafal uslukiy sehingga artinya menjadi: yang telah ditundukkan untuk memenuhi kehendakmu. (Dari perut lebah itu keluar minuman) yakni berupa madu (yang bermacam-macam warnanya di dalamnya terdapat obat yang menyembuhkan bagi manusia) dari berbagai macam penyakit. Menurut suatu pendapat dikatakan dari sebagian penyakit saja karena ditunjukkan oleh pengertian ungkapan lafal syifaaun yang memakai nakirah. Atau sebagai obat untuk berbagai macam penyakit bila digabungkan dengan obat-obat lainnya. Aku katakan bila tidak dicampur dengan obat yang lain, maka sesuai dengan niat peminumnya. Sungguh Nabi saw. telah memerintahkan untuk meminum madu bagi orang yang perutnya kembung demikianlah menurut riwayat yang telah dikemukakan oleh Imam Bukhari dan Muslim. (Sesungguhnya pada yang demikian itu benar-benar terdapat tanda kebesaran Allah bagi orang-orang yang memikirkan) ciptaan-Nya\qt@no{69}}%
\qt@newcmd\qurantrans@id@mcmlxxi{%
(Allah menciptakan kalian) yang sebelumnya kalian bukan merupakan apa-apa (kemudian mewafatkan kalian) bila ajal kalian telah tiba (dan di antara kalian ada yang dikembalikan kepada umur yang paling lemah) umur yang sangat lanjut dan pikun (supaya dia tidak mengetahui lagi sesuatu pun yang pernah diketahuinya) Ikrimah mengatakan, bahwa barang siapa yang selalu membaca Alquran, maka ia tidak akan sampai kepada keadaan seperti ini. (Sesungguhnya Allah Maha Mengetahui) di dalam mengatur makhluk-Nya (lagi Maha Kuasa) terhadap apa yang dikehendaki-Nya.\qt@no{70}}%
\qt@newcmd\qurantrans@id@mcmlxxii{%
(Dan Allah melebihkan sebagian kalian dari sebagian yang lain dalam hal rezeki) di antara kalian ada yang kaya dan ada pula yang miskin, serta ada pula yang menjadi raja dan yang menjadi hamba sahaya (tetapi orang-orang yang dilebihkan rezekinya tidak mau) yakni tuan-tuan pemilik hamba sahaya (memberikan rezeki mereka kepada budak-budak yang mereka miliki) artinya mereka tidak mau menjadikan rezeki yang Kami limpahkan kepada mereka menjadi milik bersama antara mereka dan hamba-hamba sahaya mereka (agar mereka) yakni para pemilik hamba sahaya dan para hamba sahaya yang dimilikinya (sama merasakan rezeki itu) bersekutu memilikinya. Makna yang dimaksud ialah, bahwa mereka tidak akan mau menjadikan harta mereka untuk milik bersama dengan hamba-hamba sahaya mereka, maka mengapa mereka menjadikan sebagian daripada milik-milik Allah menjadi sekutu-sekutu-Nya. (Maka mengapa mereka mengingkari nikmat Allah?) karena ternyata mereka telah menjadikan bagi-Nya sekutu-sekutu.\qt@no{71}}%
\qt@newcmd\qurantrans@id@mcmlxxiii{%
(Allah menjadikan bagi kalian istri-istri dari jenis kalian sendiri) maka Allah menciptakan Siti Hawa dari tulang rusuk Nabi Adam dan semua manusia lainnya dari mani kaum laki-laki dan wanita (dan menjadikan bagi kalian dari istri-istri kalian itu, anak-anak dan cucu-cucu) keturunan dari anak-anaknya (dan memberi kalian rezeki dari yang baik-baik) berupa berbagai macam buah-buahan, biji-bijian dan hewan-hewan ternak (maka mengapa kepada yang batil) kepada berhala (mereka beriman dan mengapa mereka ingkar terhadap nikmat Allah) dengan menyekutukan-Nya.\qt@no{72}}%
\qt@newcmd\qurantrans@id@mcmlxxiv{%
(Dan mereka menyembah selain Allah) (sesuatu yang tidak dapat memberikan rezeki kepada mereka dari langit) yang dimaksud adalah hujan (dan bumi) yakni tumbuh-tumbuhan (barang sedikit pun) lafal syaian berkedudukan menjadi badal atau pengganti dari lafal rizqan (dan tidak berkuasa) tidak mampu berbuat apa-apa sedikit pun, yang dimaksud adalah berhala-berhala.\qt@no{73}}%
\qt@newcmd\qurantrans@id@mcmlxxv{%
(Maka janganlah kalian menjadikan bagi Allah tandingan-tandingan) artinya janganlah kalian menjadikan bagi Allah persamaan-persamaan yang kalian sekutukan mereka dengan-Nya. (Sesungguhnya Allah mengetahui) bahwa tiada tandingan bagi-Nya (sedangkan kalian tidak mengetahui) hal tersebut.\qt@no{74}}%
\qt@newcmd\qurantrans@id@mcmlxxvi{%
(Allah membuat perumpamaan) lafal matsalan ini kemudian dijelaskan oleh badalnya yaitu (dengan seorang hamba sahaya yang dimiliki) lafal mamlukan ini berkedudukan menjadi sifat dari lafal `abdan, dimaksud untuk membedakannya dari manusia yang merdeka, karena manusia yang merdeka disebutkan dengan istilah Abdullaah atau hamba Allah (yang tidak dapat bertindak terhadap sesuatu) karena ia tidak memiliki apa pun (dan seorang) lafal man di sini nakirah maushufah, artinya seorang yang merdeka, bukan hamba sahaya (yang Kami beri rezeki yang baik dari Kami, lalu dia menafkahkan sebagian dari rezeki itu secara sembunyi dan secara terang-terangan) artinya dia menafkahkannya sekehendak hatinya. Misal yang pertama untuk menggambarkan tentang berhala dan misal yang kedua untuk menggambarkan tentang Allah swt. (adakah mereka itu sama?) antara hamba sahaya dan orang merdeka yang bebas dalam bertindak; tentu saja tidak. (Segala puji bagi Allah) semata (tetapi kebanyakan mereka) yakni penduduk kota Mekah (tidak mengetahui) apa yang bakal menimpa mereka kelak yaitu berupa azab, yang karena ketidaktahuan mereka itu akhirnya mereka menyekutukan Allah swt.\qt@no{75}}%
\qt@newcmd\qurantrans@id@mcmlxxvii{%
(Dan Allah membuat pula perumpamaan) lafal matsalan ini kemudian dijelaskan oleh badalnya, yaitu (dua orang lelaki yang seorang bisu) dilahirkan dalam keadaan cacat tidak dapat berbicara (tidak dapat berbuat sesuatu pun) karenanya ia tidak dapat menangkap pemahaman dan tidak pula dapat memberikan pemahaman (dan dia menjadi beban) yang berat (atas orang yang menanggungnya) atas walinya (ke mana saja dia diarahkan) disuruh (dia tidak dapat mendatangkan) dari tindakannya itu (suatu kebaikan pun) artinya ia tidak pernah berhasil; ini perumpamaan orang kafir. (Samakah orang itu) orang yang bisu itu (dengan orang yang menyuruh berbuat keadilan) artinya dengan orang yang dapat berbicara dan pembicaraannya itu bermanfaat bagi manusia karena ia menyuruh dan menganjurkan manusia untuk berbuat keadilan (dan dia berada pula di atas jalan) di jalan (yang lurus) ini perumpamaan orang yang kedua, yaitu orang muslim. Tentu saja keduanya tidak sama. Akan tetapi menurut suatu pendapat dikatakan bahwa yang kedua ini merupakan misal bagi Allah sedangkan misal yang pertama ditujukan untuk berhala-berhala. Sedangkan perumpamaan yang ada pada ayat sebelumnya adalah perumpamaan antara orang kafir dan orang mukmin.\qt@no{76}}%
\qt@newcmd\qurantrans@id@mcmlxxviii{%
(Dan kepunyaan Allahlah segala apa yang tersembunyi di langit dan di bumi) artinya Allah mengetahui semua yang gaib pada keduanya (Tidak adalah kejadian kiamat itu melainkan seperti sekejap mata atau lebih cepat lagi) karena hal itu berlangsung hanya dengan kalimat kun terjadilah ia. (Sesungguhnya Allah Maha Kuasa atas segala sesuatu.)\qt@no{77}}%
\qt@newcmd\qurantrans@id@mcmlxxix{%
(Dan Allah mengeluarkan kalian dari perut ibu kalian dalam keadaan tidak mengetahui sesuatu pun) jumlah kalimat laa ta'lamuuna syaian berkedudukan menjadi hal atau kalimat keterangan (dan Dia memberi kalian pendengaran) lafal as-sam'u bermakna jamak sekali pun lafalnya mufrad (penglihatan dan hati) kalbu (agar kalian bersyukur) kepada-Nya atas hal-hal tersebut, oleh karenanya kalian beriman kepada-Nya.\qt@no{78}}%
\qt@newcmd\qurantrans@id@mcmlxxx{%
(Tidakkah mereka memperhatikan burung-burung yang dimudahkan) terbang (di angkasa bebas) di udara antara langit dan bumi. (Tidak ada yang menahannya) sewaktu ia melipat sayap atau mengembangkannya sehingga ia tidak jatuh ke bawah (selain daripada Allah) yakni dengan kekuasaan-Nya. (Sesungguhnya pada yang demikian itu benar-benar terdapat tanda-tanda kekuasaan Allah bagi orang-orang yang beriman) yaitu penciptaan burung itu sehingga dapat terbang dan penciptaan udara sehingga dapat memungkinkan bagi burung untuk terbang mengarunginya dan menahan burung untuk tidak jatuh ke tanah.\qt@no{79}}%
\qt@newcmd\qurantrans@id@mcmlxxxi{%
(Dan Allah menjadikan bagi kalian rumah-rumah kalian sebagai tempat tinggal) tempat kalian menetap di dalamnya (dan Dia menjadikan bagi kalian rumah-rumah dari kulit binatang ternak) seperti kemah-kemah dan tenda-tenda (yang kalian merasa ringan) ketika membawanya (di waktu kalian berjalan) mengadakan perjalanan (dan waktu kalian bermukim, dan dijadikan-Nya pula, dari bulunya) dari bulu domba (bulu unta) (dan bulu kambing) (alat-alat) perabot rumah tangga kalian; seperti permadani dan perhiasan dinding rumah (dan perhiasan) yang kalian dapat menikmatinya (sampai waktu yang tertentu) sehingga barang-barang itu rusak.\qt@no{80}}%
\qt@newcmd\qurantrans@id@mcmlxxxii{%
(Dan Allah menjadikan bagi kalian dari apa yang telah Dia ciptakan) seperti rumah-rumah, pohon-pohon dan mendung (sebagai tempat bernaung) lafal zhilaalan adalah bentuk jamak dari lafal zhillun; yang dapat melindungi diri kalian dari sengatan panas matahari (dan Dia jadikan bagi kalian tempat-tempat tinggal di gunung-gunung) lafal aknaanan adalah bentuk jamak dari lafal kinnun, yang artinya tempat untuk tinggal seperti gua dan liang besar (dan Dia jadikan bagi kalian pakaian) baju-baju gamis (yang memelihara kalian dari panas) dan dari dingin (dan pakaian/baju besi yang memelihara kalian dalam peperangan) sewaktu kalian berperang yakni dari tusukan dan pukulan senjata di dalam peperangan, seperti baju dan topi besi. (Demikianlah) sebagaimana Dia telah menciptakan semuanya itu (Allah menyempurnakan nikmat-Nya) di dunia (atas kalian) dengan menciptakan segala sesuatu yang menjadi keperluan kalian (agar kalian) hai penduduk Mekah (masuk Islam) agar kalian mengesakan-Nya.\qt@no{81}}%
\qt@newcmd\qurantrans@id@mcmlxxxiii{%
(Jika mereka tetap berpaling) tidak juga mau masuk Islam (maka sesungguhnya kewajiban yang dibebankan kepadamu) hai Muhammad (hanyalah menyampaikan amanat Allah, dengan terang) ayat ini diturunkan sebelum ada perintah untuk memerangi orang-orang kafir.\qt@no{82}}%
\qt@newcmd\qurantrans@id@mcmlxxxiv{%
(Mereka mengetahui nikmat Allah) artinya mereka mengakui bahwa semua nikmat itu dari sisi-Nya (kemudian mereka mengingkarinya) karena ternyata mereka menyekutukan-Nya (dan kebanyakan mereka adalah orang-orang yang kafir).\qt@no{83}}%
\qt@newcmd\qurantrans@id@mcmlxxxv{%
(Dan) ingatlah (akan hari ketika Kami membangkitkan dari tiap-tiap umat seorang saksi) yakni nabinya yang berkesaksian tentang kebaikan atau keburukan yang dilakukan oleh umatnya, yaitu pada hari kiamat nanti (kemudian tidak diizinkan kepada orang-orang yang kafir) untuk mengemukakan alasannya (dan tidak pula mereka dibolehkan meminta maaf) artinya mereka tidak diperkenankan untuk minta maaf kepada Allah swt.\qt@no{84}}%
\qt@newcmd\qurantrans@id@mcmlxxxvi{%
(Dan apabila orang-orang lalim telah menyaksikan) yang dimaksud adalah orang-orang yang kafir (azab) yakni neraka (maka tidak diringankan bagi mereka) azab itu (dan tidak pula mereka diberi tangguh) ditangguhkan dari siksa neraka bila mereka telah melihatnya.\qt@no{85}}%
\qt@newcmd\qurantrans@id@mcmlxxxvii{%
(Dan apabila orang-orang yang mempersekutukan Allah melihat sekutu-sekutu mereka) yang terdiri daripada setan-setan dan lain-lainnya (mereka berkata, ``Ya Rabb kami! Mereka inilah sekutu-sekutu kami yang dahulu kami seru) kami sembah (selain dari Engkau." Lalu sekutu-sekutu mereka mengatakan kepada mereka) artinya para sekutu mereka itu berkata kepada mereka ("Sesungguhnya kalian benar-benar orang-orang yang dusta.") di dalam pengakuan kalian itu, yang mengatakan bahwa kalian telah menyembah kami, sebagaimana yang telah dijelaskan di dalam ayat yang lain, yaitu melalui firman-Nya, ``Mereka sekali-kali tidak menyembah kami." (Al-Qashash 63). Sekutu-sekutu itu pasti akan mengingkari penyembahan mereka terhadap dirinya.\qt@no{86}}%
\qt@newcmd\qurantrans@id@mcmlxxxviii{%
(Dan mereka menyatakan ketundukannya kepada Allah pada hari itu) artinya mereka tunduk terhadap keputusan Allah (dan hilanglah) lenyaplah (dari mereka apa yang selalu mereka ada-adakan) yang menyatakan bahwa sekutu-sekutu mereka itu dapat memberikan syafaat bagi mereka.\qt@no{87}}%
\qt@newcmd\qurantrans@id@mcmlxxxix{%
(Orang-orang yang kafir dan menghalang-halangi) manusia (dari jalan Allah) dari agama-Nya (Kami tambahkan kepada mereka siksaan di atas siksaan) yakni di atas siksaan yang berhak mereka terima dikarenakan kekafiran mereka. Ibnu Masud r.a. mengatakan, bahwa siksaan tambahan itu berupa kelabang-kelabang yang taringnya bagaikan batang-batang pohon kurma yang tinggi (disebabkan mereka selalu berbuat kerusakan) karena mereka telah mencegah manusia untuk beriman kepada Allah.\qt@no{88}}%
\qt@newcmd\qurantrans@id@mcmxc{%
(Dan) ingatlah (akan hari ketika Kami bangkitkan pada tiap-tiap umat seorang saksi atas mereka dari mereka sendiri) yakni nabi mereka sendiri (dan Kami datangkan kamu) hai Muhammad (menjadi saksi atas mereka) bagi kaummu. (Dan Kami turunkan kepadamu Alkitab) yakni Alquran (untuk menjelaskan) untuk menerangkan (segala sesuatu) yang diperlukan oleh umat manusia menyangkut masalah syariat (dan petunjuk) supaya jangan tersesat (serta rahmat dan kabar gembira) memperoleh surga (bagi orang-orang yang beriman) bagi orang-orang yang mentauhidkan Allah.\qt@no{89}}%
\qt@newcmd\qurantrans@id@mcmxci{%
(Sesungguhnya Allah menyuruh kalian berlaku adil) bertauhid atau berlaku adil dengan sesungguhnya (dan berbuat kebaikan) menunaikan fardu-fardu, atau hendaknya kamu menyembah Allah seolah-olah kamu melihat-Nya sebagaimana yang telah dijelaskan oleh hadis (memberi) bantuan (kepada kaum kerabat) famili; mereka disebutkan secara khusus di sini, sebagai pertanda bahwa mereka harus dipentingkan terlebih dahulu (dan Allah melarang dari perbuatan keji) yakni zina (dan kemungkaran) menurut hukum syariat, yaitu berupa perbuatan kekafiran dan kemaksiatan (dan permusuhan) menganiaya orang lain. Lafal al-baghyu disebutkan di sini secara khusus sebagai pertanda, bahwa ia harus lebih dijauhi; dan demikian pula halnya dengan penyebutan lafal al-fahsyaa (Dia memberi pengajaran kepada kalian) melalui perintah dan larangan-Nya (agar kalian dapat mengambil pelajaran) mengambil pelajaran dari hal tersebut. Di dalam lafal tadzakkaruuna menurut bentuk asalnya ialah huruf ta-nya diidghamkan kepada huruf dzal. Di dalam kitab Al-Mustadrak disebutkan suatu riwayat yang bersumber dari Ibnu Masud yang telah mengatakan, bahwa ayat ini yakni ayat 90 surah An-Nahl, adalah ayat yang paling padat mengandung anjuran melakukan kebaikan dan menjauhi keburukan di dalam Alquran.\qt@no{90}}%
\qt@newcmd\qurantrans@id@mcmxcii{%
(Dan tepatilah perjanjian dengan Allah) dalam masalah jual beli dan sumpah-sumpah serta masalah-masalah yang lain (apabila kalian berjanji dan janganlah kalian membatalkan sumpah-sumpah itu sesudah meneguhkannya) artinya sesudah sumpah-sumpah itu kalian teguhkan (sedangkan kalian telah menjadikan Allah sebagai saksi kalian) untuk memenuhinya, karena kalian telah bersumpah dengan memakai nama-Nya; jumlah ayat ini berkedudukan menjadi hal atau kalimat keterangan. (Sesungguhnya Allah mengetahui apa yang kalian perbuat) ayat ini merupakan ancaman buat mereka yang membatalkan sumpahnya.\qt@no{91}}%
\qt@newcmd\qurantrans@id@mcmxciii{%
(Dan janganlah kalian seperti seorang perempuan yang menguraikan) merusak (benangnya) hasil apa yang telah dipintalnya (yang sudah dipintal dengan kuat) sudah dijadikan benang (menjadi cerai-berai kembali) lafal ankaatsan berkedudukan menjadi hal, bentuk jamak daripada lafal naktsun; artinya mencerai-beraikan benang yang sudah dipintal kuat. Hal ini merupakan gambaran tentang seorang wanita penduduk kota Mekah; ia setiap hari memintal benang, tetapi sesudah benang itu jadi, lalu ia uraikan kembali; wanita itu dikenal sebagai wanita yang tolol (kalian menjadikan) lafal tattakhidzuuna menjadi hal dari dhamir lafal takuunuu; artinya janganlah kalian seperti wanita yang tolol itu, yaitu kalian menjadikan (sumpah kalian sebagai alat penipu) arti dakhalan ialah memasukkan sesuatu bukan pada tempatnya dan ia bukan merupakan bagian daripadanya; makna yang dimaksud ialah menimbulkan kerusakan atau tipu muslihat (di antara kalian) seumpamanya kalian merusak sumpah itu (disebabkan) lafal an di sini asalnya lian (adanya satu golongan) satu kelompok (yang lebih banyak) jumlahnya (dari golongan yang lain). Disebutkan bahwa mereka mengadakan sumpah perjanjian pertahanan dengan suatu golongan, tetapi bila mereka melihat ada golongan yang lain yang lebih kuat dan lebih banyak jumlahnya, lalu mereka merusak dan membatalkan perjanjiannya dengan golongan yang pertama itu, kemudian mereka mengadakan perjanjian pertahanan dengan golongan yang baru dan yang lebih kuat itu. (Sesungguhnya kalian dicoba) diuji (oleh Allah dengannya) yakni dengan perintah supaya kalian memenuhi sumpah, agar Dia melihat siapakah yang taat di antara kalian dan siapa yang durhaka. Atau membuat suatu umat yang kuat agar Dia melihat apakah mereka memenuhi janjinya atau tidak. (Dan sesungguhnya di hari kiamat akan dijelaskan-Nya kepada kalian apa yang dahulu kalian perselisihkan itu) sewaktu di dunia menyangkut masalah sumpah dan masalah-masalah lainnya; kelak Dia akan mengazab orang yang melanggar sumpahnya dan akan memberi pahala kepada orang yang memenuhinya.\qt@no{92}}%
\qt@newcmd\qurantrans@id@mcmxciv{%
(Dan kalau Allah menghendaki, niscaya Dia menjadikan kalian satu umat) menjadi pemeluk satu agama (tetapi Allah menyesatkan siapa yang dikehendaki-Nya dan memberi petunjuk kepada siapa yang dikehendaki-Nya. Dan sesungguhnya kalian akan ditanya) kelak di hari kiamat dengan pertanyaan yang keras (tentang apa yang telah kalian kerjakan) kemudian kalian mendapatkan balasannya.\qt@no{93}}%
\qt@newcmd\qurantrans@id@mcmxcv{%
(Dan janganlah kalian jadikan sumpah-sumpah kalian sebagai alat penipu di antara kalian) Allah swt. mengulang-ulang kalimat ini untuk mengukuhkannya (yang menyebabkan tergelincir kaki kalian) artinya kalian tergelincir dari ajaran Islam (sesudah kokoh tegaknya) sesudah kalian teguh memegangnya (dan kalian rasakan azab) siksaan (karena kalian menghalangi manusia dari jalan Allah) artinya disebabkan kalian tidak mau memenuhi janji kalian sendiri, atau disebabkan kalian menghalang-halangi orang lain untuk memenuhi sumpah dan janjinya, kemudian orang lain itu menuruti perintah kalian (dan bagi kalian azab yang besar) di akhirat nanti.\qt@no{94}}%
\qt@newcmd\qurantrans@id@mcmxcvi{%
(Dan janganlah kalian tukar perjanjian kalian dengan Allah dengan harga yang sedikit) berupa keduniaan, seumpamanya kalian membatalkan janji itu demi karena perkara duniawi (sesungguhnya apa yang ada di sisi Allah) berupa pahala (itulah yang lebih baik bagi kalian) daripada apa yang terdapat di dunia (jika kalian mengetahui) hal tersebut; maka oleh sebab itu janganlah kalian merusak janji kalian.\qt@no{95}}%
\qt@newcmd\qurantrans@id@mcmxcvii{%
(Apa yang di sisi kalian) berupa duniawi (akan lenyap) akan musnah (dan apa yang ada di sisi Allah adalah kekal) abadi. (Dan sesungguhnya Kami akan memberi balasan) dapat dibaca walayajziyanna dan walanajziyanna (orang-orang yang sabar) demi menunaikan janjinya (dengan pahala yang lebih baik dari apa yang telah mereka kerjakan) lafal ahsana di sini maknanya sama dengan hasuna.\qt@no{96}}%
\qt@newcmd\qurantrans@id@mcmxcviii{%
(Barang siapa yang mengerjakan amal saleh baik laki-laki maupun perempuan dalam keadaan beriman, maka sesungguhnya akan Kami berikan kepadanya kehidupan yang baik) menurut suatu pendapat dikatakan bahwa yang dimaksud adalah kehidupan di surga. Menurut pendapat yang lain dikatakan adalah kehidupan dunia, yaitu dengan mendapatkan rasa qana`ah atau menerima apa adanya atau ia mendapatkan rezeki yang halal (dan sesungguhnya akan Kami beri balasan kepada mereka dengan pahala yang lebih baik dari apa yang telah mereka kerjakan).\qt@no{97}}%
\qt@newcmd\qurantrans@id@mcmxcix{%
(Apabila kamu membaca Alquran) artinya bila kamu hendak membaca Alquran (hendaklah kamu meminta perlindungan kepada Allah dari setan yang terkutuk) artinya ucapkanlah a`uudzu billaahi minasy syaithaanirrajiim.\qt@no{98}}%
\qt@newcmd\qurantrans@id@mm{%
(Sesungguhnya setan itu tidak ada kekuasaan baginya) tidak mempunyai pengaruh (atas orang-orang yang beriman dan bertawakal kepada Rabbnya.)\qt@no{99}}%
\qt@newcmd\qurantrans@id@mmi{%
(Sesungguhnya kekuasaannya hanyalah atas orang-orang yang mengambilnya sebagai pemimpin) yaitu yang taat kepadanya (dan atas orang-orang yang terhadap-Nya) maksudnya kepada Allah (mereka mempersekutukan.)\qt@no{100}}%
\qt@newcmd\qurantrans@id@mmii{%
(Dan apabila Kami letakkan suatu ayat di tempat ayat yang lain) artinya dengan memansukhnya kemudian menggantinya dengan ayat yang lain demi kemaslahatan semua hamba (padahal Allah lebih mengetahui apa yang diturunkan-Nya, mereka berkata) orang-orang kafir kepada Nabi saw. ("Sesungguhnya kamu adalah orang yang mengada-ada saja.") seorang pendusta yang pandai membuat-buat perkataan dari dirimu sendiri. (Bahkan kebanyakan mereka tiada mengetahui) hakikat Alquran dan faedah yang terkandung di dalam penasikhan ini.\qt@no{101}}%
\qt@newcmd\qurantrans@id@mmiii{%
(Katakanlah) kepada mereka! ("Ruh Quduslah yang telah menurunkannya) yakni Alquran itu (dari sisi Rabbmu dengan benar) lafal bilhaqqi berta`alluq kepada lafal nazzalahu (untuk meneguhkan hati orang-orang yang beriman) dengan keimanan mereka kepada Alquran (dan menjadi petunjuk serta kabar gembira bagi orang-orang yang berserah diri.")\qt@no{102}}%
\qt@newcmd\qurantrans@id@mmiv{%
(Dan sesungguhnya) lafal qad di sini menunjukkan makna tahqiq (Kami mengetahui bahwa mereka berkata, ``Sesungguhnya ia itu diajarkan kepadanya) yakni Alquran itu (oleh seorang manusia.") dimaksud adalah seorang pendeta Nasrani yang Nabi saw. pernah berkunjung kepadanya; lalu Allah swt. menyanggah melalui firman-Nya: (Padahal bahasa) atau logat (yang mereka tuduhkan) mereka sangkakan (kepada Muhammad) bahwa ia belajar daripadanya (adalah bahasa ajam sedangkan ini) yakni Alquran ini (adalah dalam bahasa Arab yang terang) memiliki kejelasan dan kefasihan, maka mengapa bahasa ini diajarkan oleh orang asing?\qt@no{103}}%
\qt@newcmd\qurantrans@id@mmv{%
(Sesungguhnya orang-orang yang tidak beriman kepada ayat-ayat Allah, Allah tidak akan memberi petunjuk kepada mereka dan bagi mereka azab yang pedih) azab yang menyakitkan.\qt@no{104}}%
\qt@newcmd\qurantrans@id@mmvi{%
(Sesungguhnya yang mengada-adakan kebohongan, hanyalah orang-orang yang tidak beriman kepada ayat-ayat Allah) yakni Alquran; melalui tuduhan mereka yang mengatakan, bahwa Alquran adalah perkataan manusia (dan mereka itulah orang-orang pendusta) pengertian taukid di sini disimpulkan dari pengulangan dhamir. Ayat ini merupakan sanggahan terhadap perkataan mereka sebagaimana yang disitir oleh firman-Nya yang lain, yaitu, ``Sesungguhnya kamu adalah orang yang mengada-ada saja." (Q.S. An-Nahl 101).\qt@no{105}}%
\qt@newcmd\qurantrans@id@mmvii{%
(Barang siapa yang kafir kepada Allah sesudah dia beriman, kecuali orang yang dipaksa) untuk mengucapkan kalimat kekafiran kemudian ia terpaksa mengucapkannya (padahal hatinya tetap tenang dalam beriman) lafal man dianggap sebagai mubtada, atau syarthiyah sedangkan khabar atau jawabnya ialah: maka bagi mereka ancaman yang keras. Pengertian ini ditunjukkan oleh firman selanjutnya, yaitu: (akan tetapi orang yang melapangkan dadanya untuk kekafiran) yakni hatinya menerima kekafiran dengan lapang (maka kemurkaan Allah menimpanya dan baginya azab yang besar).\qt@no{106}}%
\qt@newcmd\qurantrans@id@mmviii{%
(Yang demikian itu) ancaman yang ditujukan kepada mereka itu (disebabkan karena sesungguhnya mereka mencintai kehidupan di dunia) mereka memilihnya (lebih dari akhirat dan bahwasanya Allah tiada memberi petunjuk kepada kaum yang kafir.)\qt@no{107}}%
\qt@newcmd\qurantrans@id@mmix{%
(Mereka itulah orang-orang yang hatinya, pendengarannya dan penglihatannya telah dikunci mati oleh Allah dan mereka itulah orang-orang yang lalai) dari apa yang dikehendaki terhadap diri mereka.\qt@no{108}}%
\qt@newcmd\qurantrans@id@mmx{%
(Tidak diragukan lagi) pastilah (bahwa mereka di akhirat nanti adalah orang-orang yang merugi) karena tempat kembali mereka adalah neraka dan mereka kekal di dalamnya.\qt@no{109}}%
\qt@newcmd\qurantrans@id@mmxi{%
(Dan sesungguhnya Rabbmu terhadap orang-orang yang berhijrah) ke Madinah (sesudah menderita cobaan) sesudah mereka disiksa dan dipaksa mengucapkan kalimat kekafiran. Menurut qiraat lafal futinuu dibaca fatanuu; artinya sesudah mereka kafir, atau sesudah mereka memfitnah manusia supaya jangan beriman (kemudian mereka berjihad dan sabar) di dalam melakukan ketaatan (sesungguhnya Rabbmu sesudah itu) sesudah cobaan itu (benar-benar Maha Pengampun) kepada mereka (lagi Maha Penyayang) terhadap mereka. Khabarnya inna yang pertama sama dengan khabar inna yang kedua.\qt@no{110}}%
\qt@newcmd\qurantrans@id@mmxii{%
Ingatlah (suatu hari ketika tiap-tiap diri datang untuk membela) berhujah untuk membela (dirinya sendiri) ia tidak menghiraukan selain daripada dirinya sendiri, yaitu hari kiamat (dan bagi tiap-tiap diri disempurnakan) balasan (apa yang telah dikerjakannya, sedangkan mereka tidak dianiaya) sedikit pun juga.\qt@no{111}}%
\qt@newcmd\qurantrans@id@mmxiii{%
(Dan Allah telah membuat suatu perumpamaan) kata perumpamaan ini dijelaskan oleh badalnya, yaitu (dengan sebuah negeri) yaitu Mekah, yang dimaksud adalah penduduknya (dahulunya aman) dari serbuan musuh dan tidak pernah ada kerusuhan (lagi tenteram) tidak perlu pindah karena alasan sempit atau takut (rezekinya datang kepadanya melimpah-ruah) dengan luas (dari segenap tempat, tetapi penduduknya mengingkari nikmat-nikmat Allah) disebabkan mereka mendustakan Nabi saw. (karena itu Allah merasakan kepada mereka pakaian kelaparan) sehingga mereka mengalami paceklik selama tujuh tahun (dan ketakutan) terhadap pasukan-pasukan tentara Nabi saw. (disebabkan apa yang selalu mereka perbuat).\qt@no{112}}%
\qt@newcmd\qurantrans@id@mmxiv{%
(Dan sesungguhnya telah datang kepada mereka seorang rasul dari mereka sendiri) yaitu Nabi Muhammad saw. (tetapi mereka mendustakannya karena itu mereka ditimpa azab) yaitu berupa kelaparan dan dicekam rasa takut (sedangkan mereka adalah orang-orang yang zalim).\qt@no{113}}%
\qt@newcmd\qurantrans@id@mmxv{%
(Maka makanlah) hai orang-orang yang beriman (yang halal lagi baik dari rezeki yang telah diberikan Allah kepada kalian dan syukurilah nikmat Allah jika kalian hanya kepada-Nya saja menyembah).\qt@no{114}}%
\qt@newcmd\qurantrans@id@mmxvi{%
(Sesungguhnya Allah hanya mengharamkan atas kalian bangkai, darah, daging babi dan apa yang disembelih dengan menyebut nama selain Allah; tetapi barang siapa yang terpaksa memakannya dengan tidak menganiaya dan tidak pula melampaui batas, maka sesungguhnya Allah Maha Pengampun lagi Maha Penyayang.)\qt@no{115}}%
\qt@newcmd\qurantrans@id@mmxvii{%
(Dan janganlah kalian mengatakan terhadap apa yang disebut-sebut oleh lidah kalian) yang sering digambarkan oleh lisan kalian (secara dusta, ``Ini halal dan ini haram.") terhadap apa yang tidak dihalalkan oleh Allah dan apa yang tidak diharamkan oleh-Nya (untuk mengada-adakan kebohongan terhadap Allah) dengan menisbatkan hal itu kepada-Nya. (Sesungguhnya orang-orang yang mengada-adakan kebohongan terhadap Allah tiadalah beruntung).\qt@no{116}}%
\qt@newcmd\qurantrans@id@mmxviii{%
Bagi mereka yang mengada-adakan kedustaan atas nama Allah (kesenangan yang sedikit) di dunia (dan bagi mereka) kelak di akhirat (azab yang pedih) azab yang menyakitkan.\qt@no{117}}%
\qt@newcmd\qurantrans@id@mmxix{%
(Dan terhadap orang-orang Yahudi) dimaksud para pemeluk agama Yahudi (Kami haramkan apa yang telah Kami ceritakan dahulu kepadamu) di dalam firman-Nya yang lain, yaitu, ``Dan kepada orang-orang Yahudi, Kami haramkan segala binatang yang berkuku..." (Q.S. Al-An'am 146) (dan Kami tiada menganiaya mereka) dengan mengharamkan hal tersebut kepada mereka (akan tetapi merekalah yang menganiaya diri mereka sendiri) dengan melakukan perbuatan-perbuatan maksiat yang menyebabkan diharamkannya hal-hal tersebut.\qt@no{118}}%
\qt@newcmd\qurantrans@id@mmxx{%
(Kemudian sesungguhnya Rabbmu terhadap orang-orang yang mengerjakan keburukan) kemusyrikan (karena kebodohannya kemudian mereka bertobat) kembali kepada Allah (sesudah itu dan memperbaiki dirinya) memperbaiki amal perbuatannya (sesungguhnya Rabbmu sesudah itu) sesudah kebodohannya dan sesudah bertobat (benar-benar Maha Pengampun) kepada mereka (lagi Maha Penyayang) kepada mereka.\qt@no{119}}%
\qt@newcmd\qurantrans@id@mmxxi{%
(Sesungguhnya Ibrahim adalah seorang imam) seorang penghulu yang menjadi panutan dan di dalam dirinya terkandung semua akhlak yang baik (lagi patuh) sangat taat (kepada Allah dan hanif) cenderung kepada agama yang lurus. (Dan sekali-kali dia bukanlah termasuk orang-orang yang mempersekutukan Tuhan.)\qt@no{120}}%
\qt@newcmd\qurantrans@id@mmxxii{%
(Lagi yang mensyukuri nikmat-nikmat Allah, Allah telah memilihnya) menjadikannya sebagai pilihan-Nya (dan menunjukkannya kepada jalan yang lurus.)\qt@no{121}}%
\qt@newcmd\qurantrans@id@mmxxiii{%
(Dan Kami berikan kepadanya) di dalam ungkapan ini terkandung pengertian iltifat dari gaibah, atau perpindahan ungkapan dari dhamir gaib kepada dhamir mutakallim (kebaikan di dunia) yaitu mendapatkan pujian dari kalangan semua agama. (Dan sesungguhnya dia di akhirat benar-benar termasuk orang-orang yang saleh) yaitu orang-orang yang memiliki derajat yang tinggi di akhirat.\qt@no{122}}%
\qt@newcmd\qurantrans@id@mmxxiv{%
(Kemudian Kami wahyukan kepadamu) hai Muhammad (ikutilah millah) yakni agama (Ibrahim seorang yang hanif. Dan bukanlah dia termasuk orang-orang yang mempersekutukan Tuhan) Allah swt. mengulangi ayat ini untuk menyanggah anggapan orang-orang Yahudi dan orang-orang Nasrani yang mengakui bahwa Nabi Ibrahim adalah pemeluk agama mereka.\qt@no{123}}%
\qt@newcmd\qurantrans@id@mmxxv{%
(Sesungguhnya telah dijadikan hari Sabtu) diwajibkan menghormatinya (atas orang-orang Yahudi yang berselisih mengenainya) dengan nabi mereka; mereka adalah orang-orang Yahudi yang diperintahkan oleh Allah supaya mereka menyibukkan dirinya untuk beribadah di hari Jumat, akan tetapi mereka mengatakan, ``Kami tidak menghendakinya," lalu mereka memilih hari Sabtu sebagai hari untuk ibadah. Akhirnya Allah memperketat peraturan kepada mereka di hari Sabtu. (Dan sesungguhnya Rabbmu benar-benar akan memberi putusan di antara mereka di hari kiamat terhadap apa yang telah mereka perselisihkan itu) yaitu Dia kelak akan memberi pahala kepada orang yang taat, dan Dia akan mengazab orang-orang yang durhaka melanggar hal-hal yang diharamkan-Nya.\qt@no{124}}%
\qt@newcmd\qurantrans@id@mmxxvi{%
(Serulah) manusia, hai Muhammad (kepada jalan Rabbmu) yakni agama-Nya (dengan hikmah) dengan Alquran (dan pelajaran yang baik) pelajaran yang baik atau nasihat yang lembut (dan bantahlah mereka dengan cara) bantahan (yang baik) seperti menyeru mereka untuk menyembah Allah dengan menampilkan kepada mereka tanda-tanda kebesaran-Nya atau dengan hujah-hujah yang jelas. (Sesungguhnya Rabbmu Dialah Yang lebih mengetahui) Maha Mengetahui (tentang siapa yang tersesat dari jalan-Nya dan Dialah yang lebih mengetahui orang-orang yang mendapat petunjuk) maka Dia membalas mereka; ayat ini diturunkan sebelum diperintahkan untuk memerangi orang-orang kafir. Dan diturunkan ketika Hamzah gugur dalam keadaan tercincang; ketika Nabi saw. melihat keadaan jenazahnya, lalu beliau saw. bersumpah melalui sabdanya, ``Sungguh aku bersumpah akan membalas tujuh puluh orang dari mereka sebagai penggantimu."\qt@no{125}}%
\qt@newcmd\qurantrans@id@mmxxvii{%
(Dan jika kalian memberikan balasan, maka balaslah dengan balasan yang sama dengan siksaan yang ditimpakan kepada kalian. Akan tetapi jika kalian bersabar) tidak mau membalas (sesungguhnya itulah) bersikap sabar itulah (yang lebih baik bagi orang-orang yang sabar) kemudian Nabi saw. membatalkan sumpahnya itu, dan membayar kafaratnya. Demikianlah menurut hadis yang telah diriwayatkan oleh Imam Bazzar.\qt@no{126}}%
\qt@newcmd\qurantrans@id@mmxxviii{%
(Bersabarlah dan tiadalah kesabaranmu itu melainkan dengan pertolongan Allah) berkat taufiq-Nya (dan janganlah kamu bersedih hati terhadap kekafiran mereka) terhadap kekafiran orang-orang kafir, jika mereka tidak juga mau beriman, karena kamu menginginkan dengan sangat akan keimanan mereka (dan janganlah kamu bersempit dada terhadap apa yang mereka tipu-dayakan) artinya janganlah engkau hiraukan tipu muslihat mereka, karena sesungguhnya Akulah yang akan menolongmu dalam menghadapi mereka.\qt@no{127}}%
\qt@newcmd\qurantrans@id@mmxxix{%
(Sesungguhnya Allah beserta orang-orang yang bertakwa) orang-orang yang takut terhadap kekafiran dan kemaksiatan (dan orang-orang yang berbuat kebaikan) dengan menjalankan ketaatan, kesabaran; Allah akan menolong mereka dengan bantuan dan pertolongan-Nya.\qt@no{128}}%
\qt@newcmd\qurantrans@id@mmxxx{%
\basmalahid (Maha Suci) artinya memahasucikan (Allah yang telah memperjalankan hamba-Nya) yaitu Nabi Muhammad saw. (pada suatu malam) lafal lailan dinashabkan karena menjadi zharaf. Arti lafal al-isra ialah melakukan perjalanan di malam hari; disebutkan untuk memberikan pengertian bahwa perjalanan yang dilakukan itu dalam waktu yang sedikit; oleh karenanya diungkapkan dalam bentuk nakirah untuk mengisyaratkan kepada pengertian itu (dari Masjidilharam ke Masjidilaksa) yakni Baitulmakdis; dinamakan Masjidilaksa mengingat tempatnya yang jauh dari Masjidilharam (yang telah Kami berkahi sekelilingnya) dengan banyaknya buah-buahan dan sungai-sungai (agar Kami perlihatkan kepadanya sebagian tanda-tanda Kami) yaitu sebagian daripada keajaiban-keajaiban kekuasaan Kami. (Sesungguhnya Dia adalah Maha Mendengar lagi Maha Mengetahui) artinya yang mengetahui semua perkataan dan pekerjaan Nabi saw. Maka Dia melimpahkan nikmat-Nya kepadanya dengan memperjalankannya di suatu malam; di dalam perjalanan itu antara lain ia sempat berkumpul dengan para nabi; naik ke langit; melihat keajaiban-keajaiban alam malakut dan bermunajat langsung dengan Allah swt. Sehubungan dengan peristiwa ini Nabi saw. menceritakannya melalui sabdanya, ``Aku diberi buraq; adalah seekor hewan yang berbulu putih; tingginya lebih dari keledai akan tetapi lebih pendek daripada bagal; bila ia terbang kaki depannya dapat mencapai batas pandangan matanva. Lalu aku menaikinya dan ia membawaku hingga sampai di Baitulmakdis. Kemudian aku tambatkan ia pada tempat penambatan yang biasa dipakai oleh para nabi. Selanjutnya aku memasuki Masjidilaksa dan melakukan salat dua rakaat di dalamnya. Setelah itu aku keluar dari Masjidilaksa datanglah kepadaku malaikat Jibril seraya membawa dua buah cawan; yang satu berisikan khamar sedangkan yang lain berisikan susu. Aku memilih cawan yang berisikan susu, lalu malaikat Jibril berkata, 'Engkau telah memilih fitrah (yakni agama Islam).' Nabi saw. melanjutkan kisahnya, kemudian malaikat Jibril membawaku naik ke langit dunia (langit pertama), lalu malaikat Jibril mengetuk pintu langit; ditanyakan lagi kepadanya, 'Siapakah kamu?' Malaikat Jibril menjawab, 'Jibril.' Ditanyakan lagi kepadanya, 'Siapakah yang bersamamu itu?' Malaikat Jibril menjawab, 'Muhammad.' Ditanyakan lagi kepadanya, 'Apakah dia telah diutus untuk menemui-Nya?' Malaikat Jibril menjawab, 'Dia telah diutus untuk menemui-Nya.' Kemudian pintu langit pertama dibukakan bagi kami; tiba-tiba di situ aku bertemu dengan Nabi Adam. Nabi Adam menyambut kedatanganku, dan ia mendoakan kebaikan untukku. Kemudian malaikat Jibril membawaku naik ke langit yang kedua, malaikat Jibril mengetuk pintu langit yang kedua. Lalu ditanyakan kepadanya, 'Siapakah kamu?' Malaikat Jibril menjawab, 'Jibril.' Ditanyakan lagi kepadanya, 'Siapakah orang yang bersamamu itu?' Malaikat Jibril menjawab, 'Muhammad.' Ditanyakan lagi kepadanya, 'Apakah dia telah diutus untuk menghadap kepada-Nya?' Malaikat Jibril menjawab, 'Dia telah diutus untuk menemui-Nya.' Maka pintu langit yang kedua dibukakan bagi kami; tiba-tiba aku bertemu dengan dua orang anak bibiku, yaitu Nabi Yahya dan Nabi Isa. Lalu keduanya menyambut kedatanganku, dan keduanya mendoakan kebaikan buatku. Kemudian malaikat Jibril membawaku naik ke langit yang ketiga, maka malaikat Jibril mengetuk pintu langit yang ketiga, lalu ditanyakan kepadanya, 'Siapakah kamu?' Malaikat Jibril menjawab, 'Jibril.' Ditanyakan lagi kepadanya, 'Siapakah orang yang bersamamu itu?' Malaikat Jibril menjawab, 'Muhammad.' Ditanyakan lagi kepadanya, 'Apakah dia telah diutus untuk menemui-Nya?' Malaikat Jibril menjawab, 'Dia telah diutus untuk menemui-Nya.' Maka dibukakanlah pintu langit ketiga bagi kami, tiba-tiba aku bertemu dengan Nabi Yusuf; dan ternyata ia telah dianugerahi separuh daripada semua keelokan. Nabi Yusuf menyambut kedatanganku, lalu ia mendoakan kebaikan bagiku. Kemudian malaikat Jibril membawaku naik ke langit yang keempat, maka malaikat Jibril mengetuk pintu langit. Lalu ditanyakan kepadanya, 'Siapakah kamu?' Malaikat Jibril menjawab. 'Jibril.' Ditanyakan lagi kepadanya, 'Siapakah orang yang bersamamu itu?' Malaikat Jibril menjawab, 'Muhammad.' Ditanyakan lagi kepadanya, 'Apakah dia telah diutus untuk menemui-Nya?' Malaikat Jibril menjawab, 'Dia telah diutus untuk menemui-Nya.' Maka pintu langit yang keempat dibukakan bagi kami; tiba-tiba aku bertemu dengan Nabi Idris, ia menyambut kedatanganku dan mendoakan kebaikan bagiku. Kemudian malaikat Jibril membawaku ke langit yang kelima, lalu malaikat Jibril mengetuk pintu langit yang kelima, maka ditanyakan kepadanya, 'Siapakah kamu?' Malaikat Jibril menjawab, 'Jibril.' Dan ditanyakan lagi kepadanya, 'Siapakah orang yang bersamamu itu?' Malaikat Jibril menjawab, 'Muhammad.' Ditanyakan lagi kepadanya, 'Apakah dia telah diutus untuk menemui-Nya?' Malaikat Jibril menjawab, 'Dia telah diutus untuk menemui-Nya.' Lalu dibukakanlah pintu langit yang kelima bagi kami; tiba-tiba aku bertemu dengan Nabi Harun, ia menyambut kedatanganku dan mendoakan kebaikan bagiku. Selanjutnya malaikat Jibril membawaku naik ke langit yang keenam, lalu ia mengetuk pintunva, ditanyakan kepadanya, 'Siapakah kamu?' Malaikat Jibril menjawab, 'Jibril.' Ditanyakan lagi kepadanya, 'Siapakah orang yang bersamamu itu?' Malaikat Jibril menjawab, 'Muhammad.' Ditanyakan lagi kepadanya, 'Apakah dia telah diutus untuk menemui-Nya?' Malaikat Jibril menjawab, 'Dia telah diutus untuk menemui-Nya.' Maka dibukakanlah pintu langit yang keenam buat kami, tiba-tiba aku bertemu dengan Nabi Musa, lalu Nabi Musa menyambut kedatanganku, dan ia mendoakan kebaikan bagiku. Kemudian malaikat Jibril membawaku naik ke langit yang ketujuh, lalu ia mengetuk pintunya. Ditanyakan kepadanya, 'Siapakah kamu?' Malaikat Jibril menjawab, 'Jibril.' Ditanyakan lagi kepadanya, 'Siapakah orang yang bersamamu itu?' Malaikat Jibril menjawab, 'Muhammad.' Ditanyakan lagi kepadanya, 'Apakah dia telah diutus untuk menemui-Nya?' Malaikat Jibril menjawab, 'Dia telah diutus untuk menemui-Nya.' Maka dibukakanlah pintu langit yang ketujuh bagi kami; tiba-tiba aku bertemu dengan Nabi Ibrahim. Kedapatan ia bersandar pada Baitulmakmur. Ternyata Baitulmakmur itu setiap harinya dimasuki oleh tujuh puluh ribu malaikat, yang selanjutnya mereka tidak kembali lagi padanya. Kemudian malaikat Jibril membawaku naik ke Sidratul Muntaha, kedapatan daun-daunnya bagaikan telinga-telinga gajah dan buah-buahan bagaikan tempayan-tempayan yang besar. Ketika semuanya tertutup oleh nur Allah, semuanya menjadi berubah. Maka kala itu tidak ada seorang makhluk Allah pun yang dapat menggambarkan keindahannya. Rasulullah saw. melanjutkan kisahnya, maka Allah mewahyukan kepadaku secara langsung, dan Dia telah (mewajibkan) kepadaku lima puluh kali salat untuk setiap hari. Setelah itu lalu aku turun hingga sampai ke tempat Nabi Musa (langit yang keenam). Maka Nabi Musa bertanya kepadaku, 'Apakah yang diwajibkan oleh Rabbmu atas umatmu?' Aku menjawab, 'Lima puluh kali salat untuk setiap harinya.' Nabi Musa berkata, 'Kembalilah kepada Rabbmu, lalu mintalah keringanan dari-Nya karena sesungguhnya umatmu niscava tidak akan kuat melaksanakannya; aku telah mencoba Bani Israel dan telah menguji mereka.' Rasulullah saw. melanjutkan kisahnya, maka aku kembali kepada Rabbku, lalu aku memohon, 'Wahai Rabbku, ringankanlah buat umatku.' Maka Allah meringankan lima waktu kepadaku. Lalu aku kembali menemui Nabi Musa. Dan Nabi Musa bertanya, 'Apakah yang telah kamu lakukan?' Aku menjawab, 'Allah telah meringankan lima waktu kepadaku.' Maka Nabi Musa bertanya, 'Sesungguhnya umatmu niscaya tidak akan kuat melakukan hal tersebut, maka kembalilah lagi kepada Rabbmu dan mintalah keringanan buat umatmu kepada-Nya.' Rasulullah melanjutkan kisahnya, maka aku masih tetap mondar-mandir antara Rabbku dan Nabi Musa, dan Dia meringankan kepadaku lima waktu demi lima waktu. Hingga akhirnya Allah berfirman, 'Hai Muhammad, salat lima waktu itu untuk tiap sehari semalam; pada setiap salat berpahala sepuluh salat, maka itulah lima puluh kali salat. Dan barang siapa yang berniat untuk melakukan kebaikan, kemudian ternyata ia tidak melakukannya dituliskan untuknya pahala satu kebaikan. Dan jika ternyata ia melakukannya, dituliskan baginva pahala sepuluh kali kebaikan. Dan barang siapa yang berniat melakukan keburukan, lalu ia tidak mengerjakannya maka tidak dituliskan dosanya. Dan jika ia mengerjakannya maka dituliskan baginva dosa satu keburukan.' Setelah itu aku turun hingga sampai ke tempat Nabi Musa, lalu aku ceritakan hal itu kepadanya. Maka ia berkata, 'Kembalilah kepada Rabbmu, lalu mintalah kepada-Nya keringanan buat umatmu, karena sesungguhnya umatmu tidak akan kuat melaksanakannya.' Maka aku menjawab, 'Aku telah mondar-mandir kepada Rabbku hingga aku malu terhadap-Nya.'" (Hadis ini diriwayatkan oleh Imam Bukhari dan Imam Muslim; dan lafal hadis ini berdasarkan Imam Muslim). Imam Hakim di dalam kitab Mustadrak meriwayatkan sebuah hadis melalui Ibnu Abbas r.a. yang menceritakan, bahwa Rasulullah saw. telah bersabda, ``Aku melihat Rabbku Azza Wajalla."\qt@no{1}}%
\qt@newcmd\qurantrans@id@mmxxxi{%
Allah swt. berfirman: (Dan Kami berikan kepada Musa kitab) yakni kitab Taurat (dan Kami jadikan kitab Taurat itu petunjuk bagi Bani Israel) dengan firman: ("Janganlah kalian mengambil penolong selain Aku") di mana mereka menyerahkan semua perkara mereka kepada-Nya. Menurut suatu qiraat lafal tattakhidzuu dibaca yattakhidzuu dengan versi ungkapan iltifat; dan huruf an adalah zaidah, sedangkan makna al-qaul diperkirakan keberadaannya.\qt@no{2}}%
\qt@newcmd\qurantrans@id@mmxxxii{%
(Yaitu anak cucu dari orang-orang yang Kami bawa bersama-sama Nuh) di dalam bahtera. (Sesungguhnya dia adalah hamba Allah yang banyak bersyukur) kepada Kami dan selalu memuji dalam semua sepak terjangnya.\qt@no{3}}%
\qt@newcmd\qurantrans@id@mmxxxiii{%
(Dan telah Kami tetapkan) telah Kami wahyukan (terhadap Bani Israel dalam kitab itu) yaitu kitab Taurat ("Sesungguhnya kalian akan membuat kerusakan di muka bumi ini) di negeri Syam dengan perbuatan-perbuatan maksiat (dua kali dan pasti kalian akan menyombongkan diri dengan kesombongan yang besar) kalian akan menimbulkan kelaliman yang besar.\qt@no{4}}%
\qt@newcmd\qurantrans@id@mmxxxiv{%
(Maka apabila datang saat hukuman bagi yang pertama dari keduanya) kejahatan yang pertama dari kedua kejahatan itu (Kami datangkan kepada kalian hamba-hamba Kami yang mempunyai kekuatan yang besar) orang-orang yang kuat dalam berperang dan memiliki kekuatan yang luar biasa (lalu mereka merajalela) mereka mengejar-ngejar kalian (di kampung-kampung) di perkampungan kalian untuk membunuh kalian dan menawan kalian (dan itulah ketetapan yang pasti terlaksana) dan memang mereka benar membunuh Nabi Zakaria. Maka Allah mengirimkan Jalut dan tentara-tentaranya untuk menghukum mereka; akhirnya Jalut dapat membunuh mereka dan menawan anak-anak mereka serta memporak-porandakan Baitulmakdis.\qt@no{5}}%
\qt@newcmd\qurantrans@id@mmxxxv{%
(Kemudian Kami berikan kepada kalian giliran) kesempatan dan kemenangan (untuk mengalahkan mereka kembali) sesudah selang seratus tahun yang terakhir dengan terbunuhnya Jalut (dan Kami membantu kalian dengan harta kekayaan dan anak-anak dan Kami jadikan kalian kelompok yang lebih besar) keluarga yang besar.\qt@no{6}}%
\qt@newcmd\qurantrans@id@mmxxxvi{%
Kemudian Kami katakan (Jika kalian berbuat baik) dengan mengerjakan ketaatan (berarti kalian berbuat baik bagi diri kalian sendiri) karena sesungguhnya pahala kebaikan itu untuk diri kalian sendiri (dan jika kalian berbuat jahat) dengan menimbulkan kerusakan (maka kejahatan itu bagi diri kalian sendiri) sebagai pembalasan atas kejahatan kalian. (Dan apabila datang saat hukuman) bagi kejahatan yang (kedua) maka Kami kembali mengutus mereka (untuk menyuramkan muka-muka kalian) untuk membuat kalian sedih karena terbunuh dan tertawan hingga pengaruh kesedihan itu dapat terbaca dari roman muka kalian (dan mereka masuk ke dalam mesjid) yakni Baitulmakdis untuk menghancurkannya (sebagaimana musuh-musuh kalian memasukinya) dan menghancurkannya (pada kali pertama dan untuk menghancurkan) untuk mengadakan pembinasaan (terhadap apa saja yang mereka kuasai) yang dapat mereka kalahkan (dengan penghancuran habis-habisan) dengan pembinasaan yang sehabis-habisnya. Ternyata mereka melakukan kerusakan untuk kedua kalinya, yaitu dengan membunuh Nabi Yahya. Maka Allah mengirimkan untuk membinasakan mereka Raja Bukhtanashar. Raja Bukhtanashar akhirnya membunuh ribuan orang dari kalangan mereka dan menahan anak cucu mereka serta memporak-porandakan Baitulmakdis.\qt@no{7}}%
\qt@newcmd\qurantrans@id@mmxxxvii{%
Dan Kami katakan di dalam kitab (Mudah-mudahan Rabb kalian akan melimpahkan rahmat-Nya kepada kalian) sesudah kali yang kedua ini jika kalian bertobat (dan sekiranya kalian kembali) melakukan kejahatan (niscaya Kami kembali) mengazab kalian. Dan memang mereka kembali melakukan kejahatan lagi, yaitu mendustakan Nabi saw., maka Allah swt. membinasakan mereka dengan terbunuhnya orang-orang Bani Quraizhah dan Bani Nadhir serta mereka dikenakan membayar jizyah. (Dan Kami jadikan neraka Jahanam penjara bagi orang-orang kafir") sebagai tempat tahanan dan penjara bagi mereka.\qt@no{8}}%
\qt@newcmd\qurantrans@id@mmxxxviii{%
(Sesungguhnya Alquran ini memberikan petunjuk kepada) jalan (yang lebih lurus) lebih adil dan lebih besar (dan memberi kabar gembira kepada orang-orang mukmin yang mengerjakan amal saleh bahwa bagi mereka ada pahala yang besar.)\qt@no{9}}%
\qt@newcmd\qurantrans@id@mmxxxix{%
(Dan) membawa berita (bahwasanya orang-orang yang tidak beriman kepada kehidupan akhirat Kami sediakan) Kami persiapkan (bagi mereka azab yang pedih) yang menyakitkan, yaitu neraka.\qt@no{10}}%
\qt@newcmd\qurantrans@id@mmxl{%
(Dan manusia mendoa untuk kejahatan) terhadap dirinya dan keluarganya jika ia menggerutu (sebagaimana ia mendoa) sebagaimana ia berdoa untuk dirinya sendiri (untuk kebaikan. Dan adalah manusia) yang dimaksud adalah jenisnya (bersifat tergesa-gesa) di dalam mendoakan dirinya tanpa memikirkan lebih lanjut akan akibatnya.\qt@no{11}}%
\qt@newcmd\qurantrans@id@mmxli{%
(Dan Kami jadikan malam dan siang sebagai dua tanda) yang kedua-duanya menunjukkan kekuasaan Kami (lalu Kami hapuskan tanda malam) Kami tutup cahayanya dengan kegelapan malam hari supaya kalian tenang berada di dalamnya; idhafat di sini menunjukkan makna bayan (dan Kami jadikan tanda siang itu terang) seseorang dapat melihat berkat adanya cahaya (agar kalian mencari) pada siang hari (karunia dari Rabb kalian) dengan berusaha (dan supaya kalian mengetahui) melalui malam dan siang hari itu (bilangan tahun-tahun dan perhitungan) waktu-waktu. (Dan segala sesuatu) yang diperlukan (telah Kami terangkan dengan jelas) artinya Kami telah menjelaskannya secara rinci.\qt@no{12}}%
\qt@newcmd\qurantrans@id@mmxlii{%
(Dan tiap-tiap manusia itu telah Kami tetapkan amal perbuatannya) artinya dia telah membawa amal perbuatannya sendiri (pada lehernya) lafal ini disebutkan secara khusus mengingat lafal ini menunjukkan pengertian tetap yang paling akurat. Dan sehubungan dengan pengertian ini Mujahid telah berkata, bahwa tiada seorang anak pun yang dilahirkan melainkan pada lehernya telah ada suatu lembaran yang tertulis di dalamnya apakah ia celaka atau bahagia. (Dan Kami keluarkan baginya pada hari kiamat sebuah kitab) yang tertulis di dalamnya semua amal perbuatannya (yang dijumpainya terbuka) kedua lafal ini menjadi sifat daripada lafal kitaaban.\qt@no{13}}%
\qt@newcmd\qurantrans@id@mmxliii{%
Dan dikatakan kepadanya: ("Bacalah kitabmu, cukuplah dirimu sendiri pada waktu itu sebagai penghisab terhadapmu.") menjadi penghisab sendiri.\qt@no{14}}%
\qt@newcmd\qurantrans@id@mmxliv{%
(Barang siapa berbuat sesuai dengan hidayah Allah, maka sesungguhnya dia berbuat itu untuk keselamatan dirinya) karena pahala hidayahnya itu dia sendirilah yang memetiknya (dan barang siapa yang sesat, maka sesungguhnya dia tersesat bagi kerugian dirinya sendiri) karena sesungguhnya dia sendirilah yang menanggung dosa sesatnya itu. (Dan tidak dapat menanggung) seseorang (yang berdosa) pelaku dosa; artinya ia tidak dapat menanggung (dosa) orang (lain, dan Kami tidak akan mengazab) seorang pun (sebelum Kami mengutus seorang rasul) yang menjelaskan kepadanya apa yang seharusnya ia lakukan.\qt@no{15}}%
\qt@newcmd\qurantrans@id@mmxlv{%
(Dan jika Kami hendak membinasakan suatu negeri, maka Kami perintahkan kepada orang-orang yang hidup mewah di negeri itu) yakni orang-orang kaya yang dimaksud para pemimpinnya, yaitu untuk taat kepada Kami melalui lisan rasul-rasul Kami (tetapi mereka melakukan kefasikan di negeri itu) maka menyimpanglah mereka dari perintah Kami (maka sudah sepantasnya berlaku terhadapnya perkataan Kami) azab Kami (kemudian Kami hancurkan negeri itu sehancur-hancurnya) artinya Kami binasakan negeri itu dengan membinasakan penduduknya serta menghancurkan negerinya.\qt@no{16}}%
\qt@newcmd\qurantrans@id@mmxlvi{%
(Dan sudah berapa banyak) telah banyak (Kami binasakan umat-umat) bangsa-bangsa (sesudah Nuh. Dan cukuplah Rabbmu Maha Mengetahui lagi Maha Melihat dosa hamba-hamba-Nya) Dia mengetahui dosa-dosa mereka yang tersembunyi dan dosa-dosa mereka yang terang-terangan. Lafal bidzunuubi bertaalluq kepada lafal khabiiran dan bashiiran.\qt@no{17}}%
\qt@newcmd\qurantrans@id@mmxlvii{%
(Barang siapa yang menghendaki) dengan amalnya (kehidupan sekarang) yakni perkara duniawi (maka Kami segerakan baginya di dunia itu apa yang Kami kehendaki bagi orang yang Kami kehendaki) lafal liman menjadi badal dari lafal lahuu yang juga disertai pengulangan huruf jar (dan Kami tentukan baginya) di akhirat kelak (neraka Jahanam; ia akan memasukinya) dijebloskan ke dalamnya (dalam keadaan tercela) terhina (lagi terusir) dijauhkan dari rahmat Allah.\qt@no{18}}%
\qt@newcmd\qurantrans@id@mmxlviii{%
(Dan barang siapa yang menghendaki kehidupan akhirat dan berusaha ke arah itu dengan sungguh-sungguh) yakni ia beramal dengan amal yang dengannya ia berhak untuk mendapatkan kehidupan akhirat (sedangkan ia adalah mukmin) kalimat ini berkedudukan menjadi hal (maka mereka itu adalah orang-orang yang usahanya dibalas dengan baik) di sisi Allah; artinya amalnya diterima oleh-Nya dan mendapat pahala dari-Nya.\qt@no{19}}%
\qt@newcmd\qurantrans@id@mmxlix{%
(Kepada masing-masing) dari kedua golongan itu (Kami membantu) memberikan bantuan (baik kepada golongan ini maupun golongan itu) kalimat ayat ini menjadi badal (dari) bertaalluq kepada lafal numiddu (kemurahan Rabbmu) di dunia (Dan tiadalah kemurahan Rabbmu) di dunia ini (dapat dihalangi) artinya tiada seorang pun yang terhalang dari kemurahan-Nya itu.\qt@no{20}}%
\qt@newcmd\qurantrans@id@mml{%
(Perhatikanlah bagaimana kami lebihkan sebagian dari mereka atas sebagian yang lain) dalam hal rezeki dan derajat (Dan pasti kehidupan akhirat lebih tinggi) lebih agung (kedudukannya dan lebih besar keutamaannya) daripada kehidupan dunia, oleh karenanya harus lebih dipentingkan dalam meraihnya.\qt@no{21}}%
\qt@newcmd\qurantrans@id@mmli{%
(Janganlah kamu adakan tuhan yang lain di samping Allah agar kamu tidak tercela dan terhina) artinya tidak ada yang menolongmu.\qt@no{22}}%
\qt@newcmd\qurantrans@id@mmlii{%
(Dan telah memutuskan) telah memerintahkan (Rabbmu supaya janganlah) lafal allaa berasal dari gabungan antara an dan laa (kalian menyembah selain Dia dan) hendaklah kalian berbuat baik (pada ibu bapak kalian dengan sebaik-baiknya) yaitu dengan berbakti kepada keduanya. (Jika salah seorang di antara keduanya sampai berumur lanjut dalam pemeliharaanmu) lafal ahaduhumaa adalah fa`il (atau kedua-duanya) dan menurut suatu qiraat lafal yablughanna dibaca yablughaani dengan demikian maka lafal ahaduhumaa menjadi badal daripada alif lafal yablughaani (maka sekali-kali janganlah kamu mengatakan ah kepada keduanya) dapat dibaca uffin dan uffan; atau uffi dan uffa; lafal ini adalah mashdar yang artinya adalah celaka dan sial (dan janganlah kamu membentak mereka) jangan kamu menghardik keduanya (dan ucapkanlah kepada mereka perkataan yang mulia) perkataan yang baik dan sopan.\qt@no{23}}%
\qt@newcmd\qurantrans@id@mmliii{%
(Dan rendahkanlah dirimu terhadap mereka berdua) artinya berlaku sopanlah kamu terhadap keduanya (dengan penuh kesayangan) dengan sikap lemah lembutmu kepada keduanya (dan ucapkanlah, ``Wahai Rabbku! Kasihanilah mereka keduanya, sebagaimana) keduanya mengasihaniku sewaktu (mereka berdua mendidik aku waktu kecil.").\qt@no{24}}%
\qt@newcmd\qurantrans@id@mmliv{%
(Rabb kalian lebih mengetahui apa yang ada dalam hati kalian) apa yang terpendam di dalamnya berupa perasaan berbakti dan menyakiti (jika kalian orang-orang yang baik) taat kepada Allah (maka sesungguhnya Dia kepada orang-orang yang bertobat) orang-orang yang kembali kepada Allah dengan berbuat taat kepada-Nya (Maha Pengampun) terhadap apa yang telah mereka lakukan sehubungan dengan hak-hak kedua orang tua, yaitu berupa perbuatan yang menyakitkan lalu dengan segera mereka bertobat dan tidak akan berbuat yang menyakitkan lagi kepada keduanya.\qt@no{25}}%
\qt@newcmd\qurantrans@id@mmlv{%
(Dan berikanlah) kasihkanlah (kepada keluarga-keluarga yang dekat) famili-famili terdekat (akan haknya) yaitu memuliakan mereka dan menghubungkan silaturahmi kepada mereka (kepada orang-orang miskin dan orang-orang yang dalam perjalanan; dan janganlah kamu menghambur-hamburkan hartamu secara boros) yaitu menginfakkannya bukan pada jalan ketaatan kepada Allah.\qt@no{26}}%
\qt@newcmd\qurantrans@id@mmlvi{%
(Sesungguhnya orang-orang pemboros itu adalah saudara-saudara setan) artinya berjalan pada jalan setan (dan setan itu adalah sangat ingkar kepada Rabbnya) sangat ingkar kepada nikmat-nikmat yang dilimpahkan oleh-Nya, maka demikian pula saudara setan yaitu orang yang pemboros.\qt@no{27}}%
\qt@newcmd\qurantrans@id@mmlvii{%
(Dan jika kamu berpaling dari mereka) artinya dari orang-orang yang telah disebutkan tadi, yaitu kaum kerabat yang dekat dan orang-orang lain sesudahnya, dalam arti kata kamu masih belum mampu untuk memberi mereka akan hak-haknya (untuk memperoleh rahmat dari Rabbmu yang kamu harapkan) artinya kamu masih mencari rezeki yang kamu harap-harapkan kedatangannya, kemudian setelah kamu mendapatkannya akan memberikan sebagian daripadanya kepada mereka (maka katakanlah kepada mereka ucapan yang pantas) yakni ucapan yang lemah lembut; seumpamanya kamu menjanjikan kepada mereka akan memberi jika rezeki telah datang kepadamu.\qt@no{28}}%
\qt@newcmd\qurantrans@id@mmlviii{%
(Dan janganlah kamu jadikan tanganmu terbelenggu pada lehermu) artinya janganlah kamu menahannya dari berinfak secara keras-keras; artinya pelit sekali (dan janganlah kamu mengulurkannya) dalam membelanjakan hartamu (secara keterlaluan, karena itu kamu menjadi tercela) pengertian tercela ini dialamatkan kepada orang yang pelit (dan menyesal) hartamu habis ludes dan kamu tidak memiliki apa-apa lagi karenanya; pengertian ini ditujukan kepada orang yang terlalu berlebihan di dalam membelanjakan hartanya.\qt@no{29}}%
\qt@newcmd\qurantrans@id@mmlix{%
(Sesungguhnya Rabbmu melapangkan rezeki) meluaskannya (kepada siapa yang Dia kehendaki dan membatasinya) menyempitkannya kepada siapa yang Dia kehendaki (sesungguhnya Dia Maha Mengetahui lagi Maha Melihat akan hamba-hamba-Nya) mengetahui apa yang tersembunyi dan apa yang terlahirkan tentang diri mereka karena itu Dia memberi rezeki kepada mereka sesuai dengan kebutuhan-kebutuhan mereka.\qt@no{30}}%
\qt@newcmd\qurantrans@id@mmlx{%
(Dan janganlah kalian membunuh anak-anak kalian) dengan menguburnya hidup-hidup (karena takut) merasa ngeri (kemiskinan) menjadi melarat (Kamilah yang akan memberi rezeki kepada mereka dan juga kepada kalian. Sesungguhnya membunuh mereka adalah suatu kesalahan) dosa (yang besar) teramat besar.\qt@no{31}}%
\qt@newcmd\qurantrans@id@mmlxi{%
(Dan janganlah kalian mendekati zina) larangan untuk melakukannya jelas lebih keras lagi (sesungguhnya zina itu adalah suatu perbuatan yang keji) perbuatan yang buruk (dan seburuk-buruknya) sejelek-jelek (jalan) adalah perbuatan zina itu.\qt@no{32}}%
\qt@newcmd\qurantrans@id@mmlxii{%
(Dan janganlah kalian membunuh jiwa yang diharamkan Allah membunuhnya melainkan dengan suatu alasan yang benar. Dan barang siapa dibunuh secara zalim, maka sesungguhnya Kami telah memberi kepada wali si terbunuh) yakni para ahli warisnya (kekuasaan) terhadap si pembunuhnya (tetapi janganlah ahli waris itu berlebihan-lebihan) melampaui batas (dalam membunuh) seumpamanya ahli waris itu membunuh orang yang bukan si pembunuh atau ia membunuh si pembunuh dengan cara yang lain. (Sesungguhnya ia adalah orang yang mendapat pertolongan.)\qt@no{33}}%
\qt@newcmd\qurantrans@id@mmlxiii{%
(Dan janganlah kalian mendekati harta anak yatim kecuali dengan cara yang lebih baik/bermanfaat sampai ia dewasa dan penuhilah janji) jika kalian berjanji kepada Allah atau kepada manusia (sesungguhnya janji itu pasti akan diminta pertanggungjawaban)nya.\qt@no{34}}%
\qt@newcmd\qurantrans@id@mmlxiv{%
(Dan sempurnakanlah takaran) penuhilah dengan tepat (apabila kalian menakar dan timbanglah dengan neraca yang benar) timbangan yang tepat (itulah yang lebih utama dan lebih baik akibatnya.)\qt@no{35}}%
\qt@newcmd\qurantrans@id@mmlxv{%
(Dan janganlah kamu mengikuti) menuruti (apa yang kami tidak mempunyai pengetahuan tentangnya. Sesungguhnya pendengaran, penglihatan dan hati) yakni kalbu (semuanya itu akan diminta pertanggungjawabannya) pemiliknya akan dimintai pertanggungjawabannya, yaitu apakah yang diperbuat dengannya?\qt@no{36}}%
\qt@newcmd\qurantrans@id@mmlxvi{%
(Dan janganlah kamu berjalan di muka bumi ini dengan sombong) artinya berjalan dengan sombong dan takabur (karena sesungguhnya kamu sekali-kali tidak dapat menembus bumi) melubanginya hingga sampai batas akhir bumi dengan ketakaburanmu itu (dan sekali-kali kamu tidak akan sampai setinggi gunung) maknanya bahwa sesungguhnya kamu tidak akan dapat mencapai hal tersebut, mengapa kamu bersikap sombong?\qt@no{37}}%
\qt@newcmd\qurantrans@id@mmlxvii{%
(Semua itu) hal telah disebutkan itu (Kejahatannya amat dibenci di sisi Rabbmu)\qt@no{38}}%
\qt@newcmd\qurantrans@id@mmlxviii{%
(Itulah sebagian apa yang diwahyukan kepadamu) hai Muhammad (oleh Rabbmu yaitu berupa hikmah) pelajaran (Dan janganlah kamu mengadakan tuhan yang lain di samping Allah, yang menyebabkan kamu dilemparkan ke dalam neraka dalam keadaan tercela lagi dijauhkan) artinya dijauhkan dari rahmat Allah\qt@no{39}}%
\qt@newcmd\qurantrans@id@mmlxix{%
(Maka apakah patut telah memilihkan bagi kalian) telah mengkhususkan bagi kalian, hai penduduk Mekah (Rabb kalian akan anak-anak laki-laki sedangkan Dia sendiri mengambil anak-anak perempuan di antara para Malaikat) yakni sebagai anak-anak perempuan-Nya sesuai dengan dugaan kalian itu (Sesungguhnya kalian benar-benar mengucapkan) melalui perkataan kalian itu (kata-kata yang besar dosanya)\qt@no{40}}%
\qt@newcmd\qurantrans@id@mmlxx{%
(Dan sesungguhnya telah Kami jelaskan) kami terangkan (di dalam Alquran ini) misal-misal, janji dan ancaman (agar mereka selalu ingat) maksudnya mengambil pelajaran darinya (Akan tetapi tidak menambahkan kepada mereka) hal tersebut (melainkan hanya menambah mereka lari) dari perkara yang hak\qt@no{41}}%
\qt@newcmd\qurantrans@id@mmlxxi{%
(Katakanlah) kepada mereka ("Jikalau ada di samping-Nya) yakni di samping Allah (tuhan-tuhan lain sebagaimana yang mereka katakan, niscaya tuhan-tuhan itu mencari) mencari-cari (kepada Tuhan Yang mempunyai Arasy) yakni Allah (jalan) untuk memerangi-Nya\qt@no{42}}%
\qt@newcmd\qurantrans@id@mmlxxii{%
(Maha Suci) ungkapan untuk memahasucikan-Nya (dan Maha Tinggi Dia dari apa yang mereka katakan) dari dakwaan sekutu-sekutu itu (dengan ketinggian yang sebesar-besarnya).\qt@no{43}}%
\qt@newcmd\qurantrans@id@mmlxxiii{%
(Bertasbih kepada-Nya) memahasucikan-Nya (langit yang tujuh, bumi dan semua yang ada di dalamnya. Dan tak ada) tiada (suatu pun) di antara semua makhluk (melainkan bertasbih) seraya (memuji kepada-Nya) artinya mereka selalu mengucapkan kalimat subhaanallaah wa bihamdihi (tetapi kalian tidak mengerti) tidak memahami (tasbih mereka) karena hal itu dilakukan bukan memakai bahasa kalian. (Sesungguhnya Dia adalah Maha Penyantun lagi Maha Pengampun) karena itu Dia tidak menyegerakan azab-Nya kepada kalian, bila kalian berbuat durhaka.\qt@no{44}}%
\qt@newcmd\qurantrans@id@mmlxxiv{%
(Dan apabila kalian membaca Alquran niscaya Kami adakan antara kamu dan orang-orang yang tidak beriman kepada kehidupan akhirat suatu dinding yang tertutup rapat) artinya Kami menjadikan penutup yang rapat bagimu dari mereka sehingga mereka tidak dapat melihatmu. Ayat ini diturunkan berkenaan dengan orang-orang musyrik yang hendak membunuh Nabi saw.\qt@no{45}}%
\qt@newcmd\qurantrans@id@mmlxxv{%
(Dan Kami adakan tutupan di atas hati mereka) yakni penutup-penutup (agar mereka tidak dapat memahaminya) yakni Alquran; oleh karenanya mereka tidak dapat mengerti tentang isinya (dan di telinga mereka sumbatan) menyumbat sehingga mereka tidak dapat mendengarkannya (Dan apabila kamu menyebut Rabbmu saja dalam Alquran niscaya mereka berpaling ke belakang karena bencinya) kebencian mereka terhadap-Nya.\qt@no{46}}%
\qt@newcmd\qurantrans@id@mmlxxvi{%
(Kami lebih mengetahui dalam keadaan bagaimana mereka mendengarkan) karena mereka memperolok-olokkanmu (sewaktu mereka mendengarkan kamu) sewaktu mendengarkan bacaan Alquranmu (dan sewaktu berbisik-bisik) di antara sesama mereka (yaitu ketika) kata idz di sini menjadi badal daripada kata idz yang sebelumnya (orang-orang zalim itu berkata) di dalam bisikan-bisikan mereka ("Tiada lain) tidak lain (orang yang kalian ikuti ini hanyalah seorang laki-laki yang kena sihir.") orang yang tidak sadar dan hilang akal warasnya. Maka Allah berfirman:\qt@no{47}}%
\qt@newcmd\qurantrans@id@mmlxxvii{%
(Lihatlah bagaimana mereka membuat perumpamaan-perumpamaan terhadap dirimu) yaitu dengan menuduhmu sebagai orang yang terkena sihir, juru peramal, dan seorang penyair (karena itu mereka menjadi sesat) dari jalan hidayah (dan tidak dapat lagi menemukan jalan) yang benar untuk mencapai hidayah.\qt@no{48}}%
\qt@newcmd\qurantrans@id@mmlxxviii{%
(Dan mereka berkata) dalam keingkaran mereka terhadap adanya hari berbangkit ("Apakah bila kami telah menjadi tulang-belulang dan benda-benda yang hancur, apa benar-benarkah kami akan dibangkitkan kembali sebagai makhluk yang baru?").\qt@no{49}}%
\qt@newcmd\qurantrans@id@mmlxxix{%
(Katakanlah) kepada mereka ("Jadilah kamu sekalian batu atau besi).\qt@no{50}}%
\qt@newcmd\qurantrans@id@mmlxxx{%
(Atau suatu makhluk dari makhluk yang tidak mungkin hidup menurut pikiran kalian.") artinya hal itu tidak mungkin dapat hidup lebih daripada tulang-belulang dan benda-benda yang hancur, maka pasti roh akan kembali kepada kalian. (Maka mereka akan bertanya, ``Siapakah yang akan mengembalikan kami?") untuk dapat hidup kembali (Katakanlah, ``Yang telah menjadikan kalian) yakni yang telah menciptakan kalian (pada kali yang pertama.") sedangkan kalian pada waktu itu belum menjadi apa-apa; karena sesungguhnya Tuhan yang mampu menciptakan mampu pula untuk mengembalikannya lagi, bahkan untuk mengembalikan ciptaan jauh lebih mudah daripada memulainya. (Lalu mereka akan menggeleng-gelengkan) menggerak-gerakkan (kepala mereka kepadamu) sebagai ungkapan rasa takjub mereka (dan berkatalah mereka) dengan nada mengejek ("Kapan itu?") hari berbangkit itu terjadi (Katakanlah, ``Mudah-mudahan waktu berbangkit itu dekat").\qt@no{51}}%
\qt@newcmd\qurantrans@id@mmlxxxi{%
(Yaitu pada hari Dia memanggil kalian) memanggil kalian dari alam kubur melalui lisan malaikat Israfil (lalu kalian mematuhi-Nya) menaati seruan-Nya dari alam kubur (sambil memuji-Nya) dengan seizin-Nya; dan menurut suatu pendapat dikatakan bahwa yang diucapkan itu adalah kalimat walahul hamdu; artinya bagi-Nya segala puji (dan kalian mengira, bahwa tiada lain) tidak lain (kalian tinggal) di dunia (kecuali sebentar saja) karena kalian sangat ngeri dan kaget melihat pemandangan pada hari itu.\qt@no{52}}%
\qt@newcmd\qurantrans@id@mmlxxxii{%
(Dan katakanlah kepada hamba-hamba-Ku) yang beriman ("Hendaklah mereka mengucapkan) kepada orang-orang kafir kalimat (yang lebih baik." Sesungguhnya setan itu menimbulkan perselisihan) yakni kerusakan (di antara mereka. Sesungguhnya setan itu adalah musuh yang nyata bagi manusia) jelas permusuhannya. Sedangkan yang dimaksud dengan kalimat yang lebih baik itu ialah dijelaskan oleh firman selanjutnya, yaitu:\qt@no{53}}%
\qt@newcmd\qurantrans@id@mmlxxxiii{%
(Rabb kalian lebih mengetahui tentang kalian. Dia akan memberi rahmat kepada kalian jika Dia menghendaki) sehingga kalian mau bertobat dan beriman (atau jika Dia menghendaki) untuk mengazab kalian (akan mengazab kalian) dengan mematikan kalian dalam keadaan kafir. (Dan Kami tidaklah mengutusmu untuk menjadi penjaga bagi mereka.) oleh karenanya kamu memaksa mereka untuk beriman. Ayat ini diturunkan sebelum ada perintah berperang.\qt@no{54}}%
\qt@newcmd\qurantrans@id@mmlxxxiv{%
(Dan Rabbmu lebih mengetahui siapa yang ada di langit dan di bumi) maka Dia mengkhususkan bagi mereka apa-apa yang Dia kehendaki sesuai dengan kondisi mereka. (Dan sesungguhnya telah Kami lebihkan sebagian nabi-nabi itu atas sebagian yang lain) dengan memberikan keistimewaan-keistimewaan tersendiri kepada masing-masing dengan keutamaan, sebagaimana yang pernah diberikan kepada Nabi Musa yaitu dapat berbicara dengan-Nya, dan Nabi Ibrahim dijadikan-Nya sebagai kekasih-Nya, serta Nabi Muhammad dengan perjalanan isranya (dan Kami berikan kitab Zabur kepada Daud).\qt@no{55}}%
\qt@newcmd\qurantrans@id@mmlxxxv{%
(Katakanlah) kepada mereka ("Panggillah mereka yang kalian anggap) bahwa mereka adalah tuhan-tuhan sesembahan kalian (selain-Nya) seperti para malaikat, Nabi Isa dan Nabi Uzair (maka mereka tidak akan mempunyai kekuasaan untuk menghilangkan bahaya daripada kalian dan tidak pula memindahkannya.") memindahkan bahaya itu kepada orang selain kalian.\qt@no{56}}%
\qt@newcmd\qurantrans@id@mmlxxxvi{%
(Orang-orang yang mereka seru itu) sebagai tuhan-tuhan sesembahan mereka (mereka sendiri mencari)-cari (jalan kepada Rabb mereka) dengan mendekatkan diri melalui ketaatan kepada-Nya (siapakah di antara mereka) lafal ini menjadi badal daripada wawu yang terdapat dalam lafal yabtaghuuna; artinya mencari jalan itu (yang lebih dekat) kepada Allah; maka mengapa mencarinya kepada selain-Nya (dan mengharapkan rahmat-Nya dan takut akan azab-Nya) sama dengan orang-orang selain mereka; maka mengapa kalian menganggap mereka sebagai tuhan-tuhan. (Sesungguhnya azab Rabbmu adalah suatu yang harus ditakuti).\qt@no{57}}%
\qt@newcmd\qurantrans@id@mmlxxxvii{%
(Dan tak ada) tiada (suatu negeri pun) yang dimaksud adalah penduduknya (melainkan Kami membinasakannya sebelum hari kiamat) dengan mematikan mereka (atau Kami mengazabnya dengan azab yang sangat keras) dengan cara membunuhnya atau dengan cara yang lain. (Adalah yang demikian itu di dalam kitab) di Lohmahfuz (telah tertulis) telah tertera di dalamnya.\qt@no{58}}%
\qt@newcmd\qurantrans@id@mmlxxxviii{%
(Dan sekali-kali tidak ada yang menghalangi Kami untuk mengirimkan ayat-ayat) yakni mukjizat-mukjizat yang diminta oleh penduduk Mekah (melainkan karena tanda-tanda itu telah didustakan oleh orang-orang dahulu) yaitu ketika Kami mengirimkannya, maka karenanya Kami membinasakan mereka. Jika kami mengirimkan tanda-tanda kekuasaan Kami itu kepada penduduk Mekah, niscaya pula mereka akan mendustakannya, kemudian mereka berhak untuk dibinasakan. Sedangkan Kami telah memutuskan untuk menangguhkan azab bagi mereka, supaya risalah Nabi Muhammad saw. sempurna. (Dan telah Kami berikan kepada Tsamud unta betina itu) sebagai tanda kekuasaan Kami (yang dapat dilihat) terang dan gamblang (tetapi mereka menganiaya) mereka mengingkari mukjizat itu dengan menganiaya (unta betina itu) maka dibinasakanlah mereka (Dan Kami tidak memberi tanda-tanda itu) mukjizat-mukjizat itu (melainkan untuk menakuti) hamba-hamba-Ku oleh karena itu mereka mau beriman.\qt@no{59}}%
\qt@newcmd\qurantrans@id@mmlxxxix{%
(Dan) ingatlah (ketika Kami wahyukan kepadamu, ``Sesungguhnya Rabbmu meliputi segala manusia.") yakni ilmu dan kekuasaan-Nya meliputi mereka, dengan demikian maka mereka berada di dalam genggaman kekuasaan-Nya. Maka sampaikanlah kepada mereka jangan sekali-kali engkau merasa takut terhadap seseorang pun karena Rabbmu akan memelihara dirimu dari mereka. (Dan Kami tidak menjadikan rukyah yang telah Kami perlihatkan kepadamu) secara kenyataan pada malam isra (melainkan sebagai batu ujian bagi manusia) bagi penduduk Mekah karena mereka ternyata mendustakannya sedang sebagian yang lainnya yang telah beriman menjadi murtad sewaktu hal itu diceritakan kepadanya (dan begitu pula pohon kayu yang terkutuk di dalam Alquran) yaitu pohon zaqqum yang tumbuh di dasar neraka Jahim; Kami jadikan kisah itu sebagai batu ujian bagi keimanan mereka. Karena mereka mengatakan bahwa api itu membakar pohon apa saja, mengapa pohon zaqqum dapat tumbuh di dalamnya? (Dan Kami takuti mereka) dengan pohon zaqqum itu (tetapi yang demikian itu tidak menambah kepada mereka) untuk takut (melainkan hanyalah kedurhakaan yang besar saja.)\qt@no{60}}%
\qt@newcmd\qurantrans@id@mmxc{%
(Dan) ingatlah (tatkala Kami berfirman kepada para malaikat, ``Sujudlah kalian kepada Adam.") dengan sujud penghormatan yaitu dengan membungkukkan badan (lalu sujudlah mereka kecuali iblis. Dia berkata, ``Apakah aku akan sujud kepada orang yang Engkau ciptakan dari tanah liat?") lafal thiinan ini dinashabkan dengan cara mencabut huruf jarnya, yang asalnya adalah min thiinin; artinya dari tanah liat.\qt@no{61}}%
\qt@newcmd\qurantrans@id@mmxci{%
(Iblis berkata, ``Terangkanlah kepadaku) jelaskanlah kepadaku! ('Inikah orangnya yang Engkau muliakan) yang Engkau utamakan (atas diriku?') sehingga Engkau memerintahkan aku supaya bersujud kepadanya; di dalam ayat lain disebutkan bahwa ketika itu iblis berkata sebagaimana yang dikisahkan oleh firman-Nya: 'Saya lebih baik daripadanya; Engkau ciptakan saya dari api.' (Q.S. Al-A`raf 12) (Sesungguhnya jika) huruf lam di sini bermakna qasam (Engkau memberi tangguh kepadaku sampai hari kiamat niscaya benar-benar akan aku sesatkan) menyesatkan (anak cucunya) dengan menggoda mereka (kecuali sebagian kecil.") daripada mereka yang mendapat pemeliharaan dari-Mu.\qt@no{62}}%
\qt@newcmd\qurantrans@id@mmxcii{%
(Berfirmanlah) Allah swt. kepada iblis ("Pergilah) sambil menunggu hingga waktu sangkakala ditiup (barang siapa di antara mereka yang mengikuti kamu, maka sesungguhnya neraka Jahanam adalah pembalasan kalian semua) kamu dan mereka yang mengikutimu (sebagai suatu pembalasan yang cukup) dicukupkan sepenuhnya.\qt@no{63}}%
\qt@newcmd\qurantrans@id@mmxciii{%
(Dan godalah) bujuklah (siapa yang kamu sanggupi di antara mereka dengan rayuanmu) dengan ajakanmu melalui nyanyian dan tiupan serulingmu serta semua seruanmu yang menjurus kepada perbuatan maksiat (dan kerahkanlah) mintalah bantuan (terhadap mereka dengan pasukan berkuda dan pasukanmu yang berjalan kaki) mereka adalah pasukan yang berkendaraan dan berjalan kaki dalam keadaan maksiat (dan berserikatlah dengan mereka pada harta benda) yang diharamkan; seperti hasil dari riba dan rampasan atau rampokan (dan anak-anak) dari perbuatan zina (dan beri janjilah mereka) bahwasanya hari berbangkit dan hari pembalasan itu tidak ada. (Dan tidak ada yang dijanjikan oleh setan kepada mereka) tentang hal-hal tersebut (melainkan tipuan belaka) kebatilan belaka.\qt@no{64}}%
\qt@newcmd\qurantrans@id@mmxciv{%
(Sesungguhnya hamba-hamba-Ku) yang beriman (kamu tidak dapat berkuasa atas mereka) dengan kekuasaan dan kekuatanmu itu. (Dan cukuplah Rabbmu sebagai penjaga.") yang memelihara mereka yang beriman dari godaan dan rayuanmu.\qt@no{65}}%
\qt@newcmd\qurantrans@id@mmxcv{%
(Rabb kalian adalah yang menjalankan) melayarkan (kapal-kapal bagi kalian) yakni perahu-perahu (di lautan agar kalian mencari) berupaya mencari (sebagian dari karunia-Nya) dari karunia Allah swt. melalui berniaga. (Sesungguhnya Dia adalah Maha Penyayang terhadap kalian) karenanya Dia menundukkan bahtera-bahtera itu buat kalian.\qt@no{66}}%
\qt@newcmd\qurantrans@id@mmxcvi{%
(Dan apabila kalian ditimpa bahaya) maksudnya marabahaya (di lautan) karena takut tenggelam (niscaya hilanglah) lenyaplah dari hati kalian (siapa yang kalian seru) tuhan-tuhan yang kalian sembah itu, karena itu kalian tidak menyeru mereka (kecuali Dia) Allah swt. maka pada saat itu kalian hanya berseru kepada-Nya semata, karena kalian berada dalam marabahaya, sedangkan kalian mengetahui, bahwa tiada yang dapat melenyapkannya melainkan hanyalah Dia (maka tatkala Dia menyelamatkan kalian) dari tenggelam, lalu Dia menyampaikan kalian (ke daratan, kalian berpaling) dari mentauhidkan-Nya. (Dan manusia itu adalah selalu tidak berterima kasih) banyak mengingkari nikmat-nikmat Allah.\qt@no{67}}%
\qt@newcmd\qurantrans@id@mmxcvii{%
(Apakah kalian merasa aman manakala Dia meruntuhkan sebagian daratan bersama kalian) artinya bumi itu menelan kalian sebagaimana yang terjadi atas diri Qarun (atau Dia mengirimkan kepada kalian batu-batu kerikil) yakni Allah melempar kalian dengan batu-batu kerikil sebagaimana yang terjadi atas kaum Nabi Luth (kemudian kalian tidak akan mendapat seorang pelindung pun bagi diri kalian) yang dapat memelihara diri kalian daripada hukuman-Nya.\qt@no{68}}%
\qt@newcmd\qurantrans@id@mmxcviii{%
(Atau apakah kalian merasa aman dari dikembalikan-Nya kalian ke dalamnya) yakni ke lautan (sekali) satu kali (lagi, lalu Dia meniupkan atas kalian angin topan) artinya angin yang sangat keras, jika melanggar sesuatu pasti jebol kemudian memporak-porandakannya sehingga hancurlah bahtera-bahtera kalian (dan ditenggelamkan-Nya kalian disebabkan kekafiran kalian) karena kekafiran kalian. (Kemudian kalian tidak akan mendapat seorang penolong pun, dalam hal ini dari siksaan Kami) yaitu seorang penolong dan pengikut yang menuntut kepada Kami apa yang telah Kami timpakan terhadap diri kalian.\qt@no{69}}%
\qt@newcmd\qurantrans@id@mmxcix{%
(Dan sesungguhnya telah Kami muliakan) Kami utamakan (anak-anak Adam) dengan pengetahuan, akal, bentuk yang paling baik, setelah wafat jenazahnya dianggap suci dan lain sebagainya (dan Kami angkut mereka di daratan) dengan menaiki kendaraan (dan di lautan) dengan menaiki perahu-perahu (dan Kami beri mereka rezeki dari yang baik-baik dan Kami lebihkan mereka atas kebanyakan makhluk yang telah Kami ciptakan) seperti hewan-hewan ternak dan hewan-hewan liar (dengan kelebihan yang sempurna.) Lafal man di sini bermakna maa; atau makna yang dimaksudnya menurut bab yang berlaku padanya. Maknanya menyangkut juga para malaikat; sedangkan makna yang dimaksud adalah pengutamaan jenisnya, dan tidak mesti semua individu manusia itu lebih utama dari malaikat karena mereka lebih utama daripada manusia yang selain para nabi.\qt@no{70}}%
\qt@newcmd\qurantrans@id@mmc{%
(Di hari ketika kami memanggil tiap manusia dengan pemimpinnya) yakni dengan nabi-nabi mereka kemudian dikatakan, ``Hai umat fulan," atau dipanggil dengan kitab-kitab hasil catatan amal perbuatan mereka, lalu dikatakan kepada mereka, ``Hai orang yang jahat." Hari yang dimaksud adalah hari kiamat (maka barangsiapa yang diberikan) di antara mereka (kitab catatan amalnya di tangan kanannya) mereka adalah orang-orang yang berbahagia; yaitu orang-orang yang memiliki pandangan hati sewaktu hidup di dunia (maka mereka ini akan membaca kitabnya itu dan mereka tidak dianiaya) catatan amal perbuatan baik mereka tidak dikurangi (barang sedikit pun.) walaupun hanya sebesar kulit biji sawi.\qt@no{71}}%
\qt@newcmd\qurantrans@id@mmci{%
(Dan barang siapa yang di alam ini) di dunia ini (buta) tidak dapat melihat perkara yang hak (niscaya di akhirat nanti ia akan lebih buta lagi) lebih tidak dapat melihat jalan keselamatan dan lebih tidak dapat membaca Alquran (dan lebih tersesat jalannya) lebih jauh dari jalan yang hak. Ayat ini diturunkan berkenaan dengan orang-orang Bani Tsaqif, yaitu sewaktu mereka meminta kepada Nabi saw. supaya ia menjadikan lembah tempat tinggal mereka sebagai tanah suci dan dengan mendesak mereka mengajukan permintaan itu kepada Nabi saw.\qt@no{72}}%
\qt@newcmd\qurantrans@id@mmcii{%
(Dan sesungguhnya) huruf in di sini adalah bentuk takhfif daripada inna (mereka hampir) hampir-hampir saja (memalingkan kamu) menyimpangkan kamu (dari apa yang telah Kami wahyukan kepadamu agar kamu membuat yang lain secara bohong terhadap Kami; dan kalau sudah begitu) seandainya kamu melakukan hal itu (tentulah mereka mengambil kamu jadi sahabat-sahabat yang setia.)\qt@no{73}}%
\qt@newcmd\qurantrans@id@mmciii{%
(Dan kalau Kami tidak memperkuat kamu) dalam perkara yang hak dengan pemeliharaan-Ku (niscaya kamu hampir-hampir) sedikit lagi (condong) cenderung (kepada mereka barang) dengan kecenderungan yang (sedikit) karena gencarnya tipu muslihat yang dipakai oleh mereka dan permintaan mereka yang terus-menerus; ayat ini jelas menunjukkan kepada pengertian bahwa Nabi saw. tidak cenderung dan tidak pula hampir cenderung terhadap tawaran mereka.\qt@no{74}}%
\qt@newcmd\qurantrans@id@mmciv{%
(Kalau terjadi demikian) seandainya kamu cenderung (benar-benarlah Kami akan rasakan kepadamu berlipat kali) azab (di dunia ini dan begitu pula berlipat ganda) azab (sesudah mati) sama dengan dua kali lipat azab yang ditimpakan kepada selainmu di dunia dan di akhirat (dan kamu tidak akan mendapat seorang penolong pun terhadap Kami) yang dapat mencegah azab yang ditimpakan kepadamu.\qt@no{75}}%
\qt@newcmd\qurantrans@id@mmcv{%
Ayat ini diturunkan ketika orang-orang Yahudi berkata kepada Nabi saw., ``Jika kamu benar-benar seorang nabi, pergilah kamu ke negeri Syam karena negeri itu adalah negeri para nabi." (Dan sesungguhnya) huruf in di sini adalah bentuk takhfif daripada inna (benar-benar mereka hampir membuatmu gelisah di negeri ini) di kota Madinah (untuk mengusirmu daripadanya dan kalau terjadi demikian) seandainya mereka benar-benar mengusirmu (niscaya sepeninggalmu mereka tidak tinggal) di dalam kota Madinah (melainkan sebentar saja) lalu mereka akan dibinasakan oleh azab-Ku.\qt@no{76}}%
\qt@newcmd\qurantrans@id@mmcvi{%
(Hal itu sebagai suatu ketetapan terhadap rasul-rasul Kami yang Kami utus sebelum kamu) yakni sebagaimana kebiasaan Kami terhadap para rasul Kami, yaitu membinasakan orang-orang yang mengusir mereka (dan tidak akan kamu dapati perubahan bagi ketetapan Kami) maksudnya tidak ada pergantian baginya.\qt@no{77}}%
\qt@newcmd\qurantrans@id@mmcvii{%
(Dirikanlah salat dari sesudah matahari tergelincir) artinya sejak dari matahari tergelincir (sampai gelap malam) hingga kegelapan malam tiba; yang dimaksud adalah salat zuhur, asar, magrib dan isyak (dan bacaan di waktu fajar) yakni salat subuh (sesungguhnya bacaan di waktu fajar/salat subuh itu disaksikan) oleh malaikat-malaikat yang berjaga pada malam hari dan malaikat-malaikat yang berjaga pada siang hari.\qt@no{78}}%
\qt@newcmd\qurantrans@id@mmcviii{%
(Dan pada sebagian malam hari bertahajudlah kamu) salatlah (dengan membacanya) yakni Alquran (sebagai suatu ibadah tambahan bagimu) sebagai amal fardu tambahan bagimu secara khusus bukan bagi umatmu, atau sebagai tambahan di samping salat-salat fardu (mudah-mudahan mengangkatmu) mendudukanmu (Rabbmu) di akhirat kelak (pada tempat yang terpuji) di mana semua orang yang terdahulu hingga orang yang kemudian memujimu karena kamu menduduki tempat tersebut; yaitu kedudukan memberi syafaat pada hari diputuskan-Nya segala perkara. Ayat berikut diturunkan sewaktu Allah memerintahkan Nabi saw. untuk melakukan hijrah.\qt@no{79}}%
\qt@newcmd\qurantrans@id@mmcix{%
(Dan katakanlah, ``Ya Rabbku! Masukkanlah aku) ke Madinah (dengan cara yang baik) yakni dengan cara memasukkan yang disukai di mana aku tidak melihat sewaktu masuk hal-hal yang tidak aku sukai (dan keluarkanlah aku) dari Mekah (dengan cara yang baik) dengan cara mengeluarkan yang membuat hatiku tidak berpaling lagi kepadanya (dan berikanlah kepadaku dari sisi Engkau kekuasaan yang menolong.") kekuatan yang dapat membantuku untuk dapat mengalahkan musuh-musuh-Mu.\qt@no{80}}%
\qt@newcmd\qurantrans@id@mmcx{%
(Dan katakanlah) sewaktu kamu memasuki kembali Mekah ("Yang benar telah datang) yakni agama Islam (dan yang batil telah lenyap.") batilnya kekafiran telah lenyap. (Sesungguhnya yang batil itu adalah sesuatu yang pasti lenyap) akan surut, lalu lenyap. Memang ketika Nabi saw. memasuki kota Mekah, beliau menemukan tiga ratus enam puluh berhala berada di sekitar Kakbah, kemudian Nabi saw. menusukinya dengan tongkat yang berada di tangannya sehingga semuanya runtuh, seraya mengucapkan kalimat tadi. Demikianlah menurut hadis yang diriwayatkan oleh Bukhari dan Muslim.\qt@no{81}}%
\qt@newcmd\qurantrans@id@mmcxi{%
(Dan Kami turunkan dari) huruf min di sini menunjukkan makna bayan atau penjelasan (Alquran suatu yang menjadi penawar) dari kesesatan (dan rahmat bagi orang-orang yang beriman) kepadanya (dan Alquran itu tidaklah menambah kepada orang-orang yang zalim) yakni orang-orang yang kafir (selain kerugian) dikarenakan kekafiran mereka\qt@no{82}}%
\qt@newcmd\qurantrans@id@mmcxii{%
(Dan apabila Kami berikan kesenangan kepada manusia) yang kafir (niscaya berpalinglah dia) daripada bersyukur (dan membelakangkan badannya) yakni membelakangkan tubuhnya dengan sikap yang sombong (dan apabila dia ditimpa kesusahan) kemiskinan dan kesengsaraan (niscaya dia berputus asa) dari rahmat Allah.\qt@no{83}}%
\qt@newcmd\qurantrans@id@mmcxiii{%
(Katakanlah, ``Tiap-tiap orang) di antara kami dan kalian (berbuat menurut keadaannya masing-masing) yakni menurut caranya sendiri-sendiri (Maka Rabb kalian lebih mengetahui siapa yang lebih benar jalannya") maka Dia akan memberi pahala kepada orang yang lebih benar jalannya.\qt@no{84}}%
\qt@newcmd\qurantrans@id@mmcxiv{%
(Dan mereka bertanya kepadamu) yaitu orang-orang Yahudi (tentang roh,) yang karenanya jasad ini dapat hidup ("Katakanlah) kepada mereka! ('Roh itu termasuk urusan Rabbku) artinya termasuk ilmu-Nya oleh karenanya kalian tidak akan dapat mengetahuinya (dan tidaklah kalian diberi pengetahuan melainkan sedikit.'") dibandingkan dengan ilmu Allah swt.\qt@no{85}}%
\qt@newcmd\qurantrans@id@mmcxv{%
(Dan sesungguhnya jika) lam di sini bermakna qasam (Kami menghendaki, niscaya Kami lenyapkan apa yang telah Kami wahyukan kepadamu) yakni Alquran; seumpamanya Dia menghapuskannya dari ingatanmu dan dari mushaf-mushaf yang ada (dan dengan pelenyapan itu kamu tidak akan mendapatkan seorang pembela pun terhadap Kami).\qt@no{86}}%
\qt@newcmd\qurantrans@id@mmcxvi{%
(Kecuali) tetapi sengaja Kami menetapkannya (karena rahmat dari Rabbmu. Sesungguhnya karunia-Nya atasmu adalah besar) agung karena Dia telah menurunkan Alquran kepadamu dan Dia memberimu kedudukan yang terpuji serta keutamaan-keutamaan lain yang Dia berikan kepadamu.\qt@no{87}}%
\qt@newcmd\qurantrans@id@mmcxvii{%
(Katakanlah, ``Sesungguhnya jika manusia dan jin berkumpul untuk membuat yang serupa dengan Alquran ini) dalam hal kefasihan dan ketinggian paramasasteranya (niscaya mereka tidak akan dapat membuat yang serupa dengan dia sekali pun sebagian mereka menjadi pembantu bagi sebagian yang lain.") saling bantu-membantu. Ayat ini diturunkan sebagai sanggahan terhadap perkataan mereka sebagaimana yang disitir oleh firman-Nya: ``Kalau kami menghendaki niscaya kami dapat membacakan yang seperti ini (Alquran)." (Q.S. Al-Anfal 31).\qt@no{88}}%
\qt@newcmd\qurantrans@id@mmcxviii{%
(Dan sesungguhnya Kami telah jelaskan) telah Kami terangkan (kepada manusia dalam Alquran ini tiap-tiap macam perumpamaan) lafal min kulli matsalin menjadi sifat bagi lafal yang tidak disebutkan artinya, contoh dari setiap perumpamaan supaya mereka mengambil pelajaran darinya (tapi kebanyakan manusia tidak mau) yakni penduduk Mekah (kecuali mengingkarinya) mengingkari kebenaran yang dibawanya.\qt@no{89}}%
\qt@newcmd\qurantrans@id@mmcxix{%
(Dan mereka berkata) diathafkan kepada lafal abaa ("Kami sekali-kali tidak percaya kepadamu sebelum engkau memancarkan sumber air dari tanah buat kami) mata air yang berlimpah airnya.\qt@no{90}}%
\qt@newcmd\qurantrans@id@mmcxx{%
(Atau kamu mempunyai sebuah kebun) taman yang penuh dengan pohon-pohon (kurma dan anggur lalu kamu alirkan sungai-sungai di celah-celah kebun itu) di tengah-tengah (yang deras airnya.)\qt@no{91}}%
\qt@newcmd\qurantrans@id@mmcxxi{%
(Atau kamu jatuhkan langit berkeping-keping atas kami sebagaimana kamu katakan) yakni hancur berkeping-keping (atau kamu datangkan Allah dan malaikat-malaikat berhadapan muka dengan kami.) secara berhadap-hadapan dan terang-terangan dengan kami sehingga kami dapat melihat mereka.\qt@no{92}}%
\qt@newcmd\qurantrans@id@mmcxxii{%
(Atau kamu mempunyai rumah dari emas) logam mulia (atau kamu memanjat) naik (ke langit) dengan memakai tangga (Dan kami sekali-kali tidak akan mempercayai kenaikanmu) seandainya kamu dapat menaiki langit (hingga kamu turunkan atas kami) dari langit itu (sebuah kitab) yang di dalamnya tertera tulisan yang membenarkanmu (yang kami baca." Katakanlah) kepada mereka! ("Maha Suci Rabbku) ungkapan rasa takjub (bukankah) tidak lain (aku ini hanyalah manusia yang menjadi rasul.") sama halnya dengan rasul-rasul yang lain sedangkan mereka tidak dapat mendatangkan suatu mukjizat pun melainkan dengan seizin Allah.\qt@no{93}}%
\qt@newcmd\qurantrans@id@mmcxxiii{%
(Dan tidak ada sesuatu yang menghalang-halangi manusia untuk beriman tatkala datang petunjuk kepadanya kecuali perkataan mereka) perkataan mereka dengan nada ingkar ("Adakah Allah mengutus seorang manusia menjadi rasul?") dan Dia tidak mengutus seorang malaikat?\qt@no{94}}%
\qt@newcmd\qurantrans@id@mmcxxiv{%
(Katakanlah) kepada mereka ("Seandainya di bumi ini ada) lafal fil ardhi menjadi badal daripada lafal basyaran (malaikat-malaikat yang berjalan-jalan sebagai penghuni di bumi niscaya Kami turunkan dari langit kepada mereka malaikat menjadi rasul.") sebab tidak diutus seorang rasul terhadap suatu kaum melainkan ia berasal dari jenis mereka sendiri sehingga memungkinkan bagi mereka untuk berbicara kepadanya dan memahami darinya.\qt@no{95}}%
\qt@newcmd\qurantrans@id@mmcxxv{%
(Katakanlah, ``Cukuplah Allah menjadi saksi antara aku dan kamu sekalian) yang membenarkan aku. (Sesungguhnya Dia adalah Maha Mengetahui lagi Maha Melihat akan hamba-hamba-Nya.") mengetahui apa-apa yang tersembunyi dalam diri mereka dan apa-apa yang terlahirkan.\qt@no{96}}%
\qt@newcmd\qurantrans@id@mmcxxvi{%
(Dan barang siapa yang ditunjuki Allah, dialah yang mendapat petunjuk dan barang siapa yang Dia sesatkan maka sekali-kali kamu tidak akan mendapat penolong-penolong bagi mereka) yang dapat memberikan petunjuk kepada mereka (selain dari Dia. Dan Kami akan mengumpulkan mereka pada hari kiamat) seraya diseret (atas muka-muka mereka dalam keadaan buta, bisu dan pekak. Tempat kediaman mereka adalah neraka Jahanam. Tiap-tiap kali nyala api Jahanam itu akan padam) mulai redup nyalanya (Kami tambahkan bagi mereka nyalanya) kobaran dan nyala api itu semakin ditambahkan.\qt@no{97}}%
\qt@newcmd\qurantrans@id@mmcxxvii{%
(Itulah balasan bagi mereka karena sesungguhnya mereka kafir kepada ayat-ayat Kami dan karena mereka berkata) seraya ingkar terhadap adanya hari berbangkit ("Apakah bila kami telah menjadi tulang-belulang dan benda-benda yang hancur, apakah benar-benar akan dibangkitkan kembali sebagai makhluk baru?")\qt@no{98}}%
\qt@newcmd\qurantrans@id@mmcxxviii{%
(Dan apakah mereka tidak memperhatikan) apakah mereka tidak mengetahui (bahwasanya Allah yang menciptakan langit dan bumi) padahal keduanya sangat besar sekali (adalah kuasa pula menciptakan yang serupa dengan mereka) serupa dengan manusia dalam hal kekecilannya (dan telah menetapkan waktu yang tertentu bagi mereka) untuk mati dan dibangkitkan (yang tidak ada keraguan padanya? Maka orang-orang yang zalim itu tidak menghendaki kecuali kekafiran) yaitu keingkaran terhadap-Nya.\qt@no{99}}%
\qt@newcmd\qurantrans@id@mmcxxix{%
(Katakanlah) kepada mereka ("Seandainya kalian menguasai perbendaharaan-perbendaharaan rahmat Rabbku) berupa perbendaharaan rezeki dan hujan (niscaya kalian tahan perbendaharaan itu) maksudnya niscaya kalian akan bersikap kikir (karena takut membelanjakannya.") karena takut harta menjadi habis dibelanjakan oleh karenanya kalian bersikap kikir. (Dan adalah manusia itu sangat kikir) maksudnya sangat bakhil.\qt@no{100}}%
\qt@newcmd\qurantrans@id@mmcxxx{%
(Dan sesungguhnya Kami telah memberikan kepada Musa sembilan buah mukjizat yang nyata) yaitu tangan, tongkat, topan, belalang, kutu, kodok, darah atau kutukan paceklik dan kekurangan buah-buahan (maka tanyakanlah) hai Muhammad (kepada Bani Israel) perihalnya dengan pertanyaan yang menetapkan kebenaranmu terhadap kaum musyrikin; atau artinya Kami berfirman kepada Muhammad, ``Tanyakanlah." Menurut qiraat yang lain diungkapkan dalam bentuk fi`il madhi (tatkala Musa datang kepada mereka lalu Firaun berkata kepadanya, ``Sesungguhnya aku sangka kamu hai Musa seorang yang kena sihir.") orang yang tidak sadar dan akal warasmu sudah hilang.\qt@no{101}}%
\qt@newcmd\qurantrans@id@mmcxxxi{%
(Musa menjawab, ``Sesungguhnya kamu telah mengetahui, tiada yang menurunkannya) mukjizat-mukjizat itu (melainkan Rabb yang memelihara langit dan bumi sebagai bukti-bukti yang nyata) pelajaran-pelajaran, tetapi ternyata kamu masih tetap ingkar. Menurut qiraat lain lafal `alimta dibaca `alimtu (dan sesungguhnya aku mengira kamu, hai Firaun, seorang yang binasa.") hancur atau dipalingkan dari kebaikan.\qt@no{102}}%
\qt@newcmd\qurantrans@id@mmcxxxii{%
(Maka terbetiklah maksud) dalam diri Firaun (untuk mengusir mereka) maksudnya mengusir Nabi Musa dan kaumnya (dari tanah itu) yaitu negeri Mesir (maka Kami tenggelamkan dia serta orang-orang yang bersama dia seluruhnya.)\qt@no{103}}%
\qt@newcmd\qurantrans@id@mmcxxxiii{%
(Dan Kami berfirman sesudah itu kepada Bani Israel, ``Diamlah di negeri ini, maka apabila tiba masa berbangkit) hari kiamat (niscaya Kami datangkan kalian dalam keadaan bercampur-baur") dengan semua manusia, yaitu kalian dan mereka.\qt@no{104}}%
\qt@newcmd\qurantrans@id@mmcxxxiv{%
(Dan Kami turunkan dia itu dengan sebenar-benarnya) Alquran itu (dan dengan membawa kebenaran) mengandung kebenaran (Alquran itu telah turun) dalam keadaan utuh sebagaimana waktu diturunkan tidak akan terjadi perubahan dan penggantian padanya. (Dan Kami tidak mengutus kamu) hai Muhammad (melainkan sebagai pembawa berita gembira) kepada orang yang percaya akan adanya surga (dan pemberi peringatan) terhadap orang yang ingkar kepada adanya neraka.\qt@no{105}}%
\qt@newcmd\qurantrans@id@mmcxxxv{%
(Dan Alquran itu) lafal Alquran ini dinashabkan oleh fi`il yang dijelaskan oleh firman selanjutnya (telah Kami turunkan secara berangsur-angsur) Kami turunkan secara bertahap selama dua puluh tahun atau dua puluh tiga tahun (agar kamu membacakannya perlahan-lahan kepada manusia) secara perlahan-lahan dan tenang supaya mereka dapat memahaminya (dan Kami menurunkannya bagian demi bagian) sedikit demi sedikit sesuai dengan kemaslahatan.\qt@no{106}}%
\qt@newcmd\qurantrans@id@mmcxxxvi{%
(Katakanlah) kepada orang-orang kafir Mekah ("Berimanlah kalian kepadanya atau tidak usah beriman) ungkapan ini dimaksud sebagai ancaman buat mereka (Sesungguhnya orang-orang yang diberi pengetahuan sebelumnya) sebelum diturunkan Alquran mereka adalah orang-orang yang beriman dari kalangan ahli kitab (apabila Alquran dibacakan kepada mereka, mereka menyungkur atas muka mereka sambil bersujud.")\qt@no{107}}%
\qt@newcmd\qurantrans@id@mmcxxxvii{%
(Dan mereka berkata, ``Maha Suci Rabb kami) dimaksud memahasucikan Dia dari ingkar janji (sesungguhnya) lafal in di sini adalah bentuk takhfif dari inaa (janji Rabb kami) untuk menurunkan Alquran dan mengutus Nabi Muhammad saw. (pasti dipenuhi.")\qt@no{108}}%
\qt@newcmd\qurantrans@id@mmcxxxviii{%
(Dan mereka menyungkur atas muka mereka sambil menangis) diathafkan seraya diberi tambahan sifat (dan mereka makin bertambah) berkat Alquran (kekhusyuannya) merendahkan dirinya kepada Allah swt.\qt@no{109}}%
\qt@newcmd\qurantrans@id@mmcxxxix{%
Disebutkan bahwa Nabi saw. sering mengucapkan kalimat ya Allah, ya Rahman; artinya wahai Allah, wahai Yang Maha Pemurah. Maka orang-orang musyrik mengatakan, ``Dia melarang kita untuk menyembah dua tuhan sedangkan dia sendiri menyeru tuhan lain di samping-Nya," maka turunlah ayat berikut ini, yaitu: (Katakanlah) kepada mereka ("Serulah Allah atau serulah Ar-Rahman) artinya namailah Dia dengan mana saja di antara kedua nama itu; atau serulah Dia seumpamanya kamu mengatakan, 'Ya Allah, ya Rahman,' artinya wahai Allah, wahai Yang Maha Pemurah (nama yang mana saja") huruf ayyan di sini bermakna syarath sedangkan huruf maa adalah zaidah; artinya mana saja di antara kedua nama itu (kamu seru) maka ia adalah baik; makna ini dijelaskan oleh ayat selanjutnya, yaitu: (Dia mempunyai) Dzat yang mempunyai kedua nama tersebut (asmaul husna) yaitu nama-nama yang terbaik, dan kedua nama tersebut, yaitu lafal Allah dan lafal Ar-Rahman adalah sebagian daripadanya. Sesungguhnya asmaul husna itu sebagaimana yang dijelaskan dalam hadis ialah seperti berikut ini, yaitu: Allah Yang tiada Tuhan selain Dia, Yang Maha Pemurah, Yang Maha Penyayang, Raja di dunia dan akhirat, Yang Maha Suci, Yang Maha Sejahtera, Yang Maha Memberi keamanan, Yang Maha Memelihara, Yang Maha Mulia, Yang Maha Perkasa, Yang Maha Memiliki segala keagungan, Yang Maha Menciptakan, Yang Maha Mengadakan, Yang Maha Memberi rupa, Yang Maha Penerima tobat, Yang Maha Mengalahkan, Yang Maha Memberi, Yang Maha Pemberi rezeki, Yang Maha Membuka, Yang Maha Mengetahui, Yang Maha Menyempitkan rezeki, Yang Maha Melapangkan rezeki, Yang Maha Merendahkan, Yang Maha Mengangkat, Yang Maha Memuliakan, Yang Maha Menghinakan, Yang Maha Mendengar, Yang Maha Melihat, Yang Maha Memberi keputusan, Yang Maha Adil, Yang Maha Lembut, Yang Maha Waspada, Yang Maha Penyantun, Yang Maha Agung, Yang Maha Pengampun, Yang Maha Mensyukuri, Yang Maha Tinggi, Yang Maha Besar, Yang Maha Memelihara, Yang Maha Memberi azab, Yang Maha Penghisab, Yang Maha Besar, Yang Maha Dermawan, Yang Maha Mengawasi, Yang Maha Memperkenankan, Yang Maha Luas, Yang Maha Bijaksana, Yang Maha Pengasih, Yang Maha Mulia, Yang Maha Membangkitkan, Yang Maha Menyaksikan, Yang Maha Hak, Yang Maha Menolong, Yang Maha Kuat, Yang Maha Teguh, Yang Maha Menguasai, Yang Maha Terpuji, Yang Maha Menghitung, Yang Maha Memulai, Yang Maha Mengembalikan, Yang Maha Menghidupkan, Yang Maha Mematikan, Yang Maha Hidup, Yang Maha Memelihara makhluk-Nya, Yang Maha Mengadakan, Yang Maha Mengagungkan, Yang Maha Satu, Yang Maha Esa, Yang Maha Melindungi, Yang Maha Kuasa, Yang Maha Berkuasa, Yang Maha Mendahulukan, Yang Maha Mengakhirkan, Yang Maha Awal, Yang Maha Akhir, Yang Maha Lahir, Yang Maha Batin, Yang Maha Menguasai, Yang Maha Tinggi, Yang Maha Melimpahkan kebaikan, Yang Maha Memberi tobat, Yang Maha Membalas, Yang Maha Memaafkan, Yang Maha Penyayang, Raja Diraja, Yang Maha Memiliki kebesaran dan kemuliaan, Yang Maha Adil, Yang Maha Mengumpulkan, Yang Maha Kaya, Yang Maha Memberi Kekayaan, Yang Maha Mencegah, Yang Maha Memberi kemudaratan, Yang Maha Memberi kemanfaatan, Yang Maha Memiliki cahaya, Yang Maha Memberi petunjuk, Yang Maha Menciptakan keindahan, Yang Maha Kekal, Yang Maha Mewarisi, Yang Maha Membimbing, Yang Maha Penyabar, Yang Maha. Demikianlah menurut hadis yang diriwayatkan oleh Imam Tirmizi. Selanjutnya Allah swt. berfirman: (Dan janganlah kamu mengeraskan suaramu dalam salatmu) dengan mengeraskan bacaanmu dalam salatmu, maka orang-orang musyrik akan mendengar bacaanmu itu jika kamu mengerasi suaramu karena itu mereka akan mencacimu dan mencaci Alquran serta mencaci pula Allah yang telah menurunkannya (dan janganlah pula merendahkan) melirihkan (bacaannya) supaya para sahabatmu dapat mengambil manfaat darinya (dan carilah) bersengajalah (di antara kedua itu) yakni di antara suara keras dan suara pelan (jalan tengah) yaitu cara yang pertengahan.\qt@no{110}}%
\qt@newcmd\qurantrans@id@mmcxl{%
(Dan katakanlah, ``Segala puji bagi Allah yang tidak mempunyai anak dan tidak mempunyai sekutu dalam kerajaan-Nya dan tidak mempunyai penolong) untuk menjaga-Nya (dari) sebab (kehinaan) artinya Dia tidak dapat dihina karenanya Dia tidak membutuhkan penolong (dan agungkanlah Dia dengan pengagungan yang sebesar-besarnya) artinya besarkanlah Dia dengan pengagungan yang sempurna daripada sifat memiliki anak, mempunyai sekutu, hina dan hal-hal lain yang tidak layak bagi keagungan dan kebesaran-Nya. Urutan pujian dalam bentuk demikian untuk menunjukkan bahwa Dialah yang berhak untuk mendapatkan semua pujian mengingat kesempurnaan Zat-Nya dan kesendirian-Nya di dalam sifat-sifat-Nya. Imam Ahmad dalam kitab Musnadnya meriwayatkan sebuah hadis melalui Muaz Al-Juhani dari Rasulullah saw. bahwa Rasulullah saw. telah bersabda, ``Tanda kemuliaan ialah (kalimat): Segala puji bagi Allah yang tidak mempunyai anak dan tidak mempunyai sekutu dalam kerajaan-Nya," sampai dengan akhir surat. Wallahu a`lam.\qt@no{111}}%
\qt@newcmd\qurantrans@id@mmcxli{%
\basmalahid (Segala puji) Memuji ialah menyifati dengan yang baik, yang tetap (bagi Allah) Maha Tinggi Dia. Apakah yang dimaksud dengan Alhamdulillah ini bersifat pemberitahuan untuk diimani, atau dimaksudkan hanya untuk memuji kepada-Nya belaka, atau dimaksudkan untuk keduanya. Memang di dalam menanggapi masalah ini ada beberapa hipotesis, akan tetapi yang lebih banyak mengandung faedah adalah pendapat yang ketiga, yaitu untuk diimani dan sekaligus sebagai pujian kepada-Nya (yang telah menurunkan kepada hamba-Nya) yaitu Nabi Muhammad (Al-Kitab) Alquran (dan Dia tidak menjadikan padanya) di dalam Alquran (kebengkokan) perselisihan atau pertentangan. Jumlah kalimat Walam yaj'al lahu 'iwajan berkedudukan menjadi Hal atau kata keterangan keadaan daripada lafal Al-Kitab.\qt@no{1}}%
\qt@newcmd\qurantrans@id@mmcxlii{%
(Sebagai jalan yang lurus) bimbingan yang lurus; lafal Qayyiman menjadi Hal yang kedua dari lafal Al-Kitab di atas tadi dan sekaligus mengukuhkan makna yang pertama (untuk memperingatkan) menakut-nakuti orang-orang kafir dengan Alquran itu (akan siksaan) akan adanya azab (yang sangat keras dari sisi-Nya) dari sisi Allah (dan memberi berita gembira kepada orang-orang yang beriman, yang mengadakan amal saleh, bahwa mereka akan mendapat pembalasan yang baik).\qt@no{2}}%
\qt@newcmd\qurantrans@id@mmcxliii{%
(Mereka kekal di dalamnya untuk selama-lamanya) yaitu mendapatkan surga.\qt@no{3}}%
\qt@newcmd\qurantrans@id@mmcxliv{%
(Dan untuk memperingatkan) kepada semua orang kafir (kepada orang-orang yang berkata, ``Allah mengambil seorang anak)".\qt@no{4}}%
\qt@newcmd\qurantrans@id@mmcxlv{%
(Tiadalah mereka dengannya) dengan perkataan tersebut (mempunyai pengetahuan tentang hal itu, begitu pula nenek moyang mereka) sebelum mereka yang juga mengatakan hal yang sama. (Alangkah jeleknya) alangkah besar dosanya (kata-kata yang keluar dari mulut mereka) lafal Kalimatan berkedudukan menjadi Tamyiz yang maknanya menafsirkan pengertian Dhamir yang dimubhamkan, sedangkan subjek yang dicelanya tidak disebutkan, yaitu perkataan mereka yang tadi. (Tiada Lain) (mereka mengatakan) hal tersebut (hanyalah) perkataan (yang dusta belaka).\qt@no{5}}%
\qt@newcmd\qurantrans@id@mmcxlvi{%
(Maka barangkali kamu akan membinasakan) membunuh (dirimu sendiri sesudah mereka) sesudah mereka berpaling darimu (sekiranya mereka tidak beriman kepada keterangan ini) yakni kepada Alquran (karena bersedih hati) karena perasaan jengkel dan sedihmu, disebabkan kamu sangat menginginkan mereka beriman. Lafal Asafan dinashabkan karena menjadi Maf'ul Lah.\qt@no{6}}%
\qt@newcmd\qurantrans@id@mmcxlvii{%
(Sesungguhnya Kami telah menjadikan apa yang ada di bumi) berupa hewan, tumbuh-tumbuhan, pepohonan, sungai-sungai dan lain sebagainya (sebagai perhiasan baginya, agar Kami menguji mereka) supaya Kami menguji manusia, seraya memperhatikan dalam hal ini (siapakah di antara mereka yang terbaik perbuatannya) di dunia ini; yang dimaksud adalah siapakah yang lebih berzuhud/menjauhi keduniaan.\qt@no{7}}%
\qt@newcmd\qurantrans@id@mmcxlviii{%
(Dan sesungguhnya Kami benar-benar akan menjadikan pula apa yang di atasnya menjadi tanah rata) merata dengan tanah (lagi tandus) kering tidak subur.\qt@no{8}}%
\qt@newcmd\qurantrans@id@mmcxlix{%
(Atau kamu mengira) kamu menduga (bahwa Ashhabul Kahfi) orang-orang yang mendiami gua di suatu bukit (dan Raqim) yaitu lempengan batu yang tertulis padanya nama-nama mereka dan nasab-nasabnya; Nabi saw. pernah ditanya mengenai kisah mereka (adalah mereka) dalam kisah mereka (termasuk) sebagian (tanda-tanda kekuasaan Kami yang menakjubkan?) lafal 'Ajaban menjadi khabar Kana, sedangkan lafal yang sebelumnya berkedudukan menjadi hal; artinya: Mereka adalah hal yang menakjubkan yang berbeda dengan tanda-tanda kekuasaan Kami lainnya; atau mereka adalah tanda-tanda kekuasaan Kami yang paling menakjubkan, padahal kenyataannya tidak demikian.\qt@no{9}}%
\qt@newcmd\qurantrans@id@mmcl{%
Ingatlah (tatkala pemuda-pemuda itu mencari tempat berlindung ke dalam gua) Lafal Al-Fityah adalah bentuk jamak dari lafal Fataa, artinya pemuda; mereka khawatir iman mereka akan dipengaruhi oleh kaumnya yang kafir (lalu mereka berdoa, ``Wahai Rabb kami! Berikanlah kepada kami dari sisi-Mu) dari hadirat-Mu (rahmat, dan sempurnakanlah) perbaikilah (bagi kami bimbingan yang lurus dalam urusan kami ini.)" yakni petunjuk yang lurus.\qt@no{10}}%
\qt@newcmd\qurantrans@id@mmcli{%
(Maka kami tutup telinga mereka) yakni kami buat mereka tidur (bertahun-tahun dalam gua itu) selama bertahun-tahun.\qt@no{11}}%
\qt@newcmd\qurantrans@id@mmclii{%
(Kemudian Kami bangunkan mereka) Kami buat mereka bangun (agar Kami mengetahui) menyaksikan secara nyata (manakah di antara kedua golongan itu) di antara kedua kelompok yang memperselisihkan tentang lamanya mereka tinggal di dalam gua itu (yang lebih tepat) lebih cocok, lafal Ahshaa ini berwazan Af'ala (mengenai diamnya mereka dalam gua itu) tentang tinggalnya mereka. Lafal 'Lima Labitsuu' berta'alluq kepada lafal berikutnya (yakni masanya) batas waktunya.\qt@no{12}}%
\qt@newcmd\qurantrans@id@mmcliii{%
(Kami ceritakan) Kami membacakan (kisah mereka kepadamu dengan sebenarnya) dengan sesungguhnya. (Sesungguhnya mereka itu adalah pemuda-pemuda yang beriman kepada Rabb mereka dan Kami tambahkan kepada mereka petunjuk).\qt@no{13}}%
\qt@newcmd\qurantrans@id@mmcliv{%
(Dan Kami telah meneguhkan hati mereka) Kami memperkuat hati mereka berpegangan kepada kalimat yang hak (di waktu mereka berdiri) di hadapan raja mereka yang menyuruh mereka supaya bersujud kepada berhala-berhala (lalu mereka berkata, ``Rabb kami adalah Rabb langit dan bumi, kami sekali-kali tidak menyeru kepada selain-Nya) yakni selain Allah (sebagai Tuhan, sesungguhnya kami kalau demikian telah mengucapkan perkataan yang amat jauh dari kebenaran)" perkataan yang keterlaluan lagi sangat kafir jika seumpamanya kami menyeru kepada tuhan selain Allah.\qt@no{14}}%
\qt@newcmd\qurantrans@id@mmclv{%
(Mereka) lafal 'Haaulaa-i' berkedudukan menjadi Mubtada (kaum kami ini) menjadi Athaf Bayan (telah menjadikan selain Dia sebagai tuhan-tuhan. Mengapa tidak) (mereka mengemukakan atas perbuatan mereka itu) atas penyembahan yang mereka lakukan itu (alasan yang terang?) hujah yang jelas. (Siapakah yang lebih zalim) maksudnya tidak ada seorang pun yang lebih zalim (daripada orang-orang yang mengada-adakan kebohongan terhadap Allah?) yaitu dengan menisbatkan sekutu kepada Allah swt. Lalu sebagian di antara pemuda itu berkata kepada sebagian yang lain:\qt@no{15}}%
\qt@newcmd\qurantrans@id@mmclvi{%
(Dan apabila kamu meninggalkan mereka beserta apa yang mereka sembah selain Allah, maka carilah tempat berlindung ke dalam gua itu, niscaya Rabb kalian akan melimpahkan sebagian rahmat-Nya kepada kalian dan menyediakan sesuatu yang berguna bagi kalian dalam urusan kalian) Lafal mirfaqan dapat dibaca marfiqan artinya apa-apa yang menjadi keperluan kalian berupa makan siang dan makan malam.\qt@no{16}}%
\qt@newcmd\qurantrans@id@mmclvii{%
(Dan kamu akan melihat matahari ketika terbit, condong) Lafal Tazaawaru dapat dibaca dengan memakai Tasydid atau Takhfif, artinya melenceng (dari gua mereka ke sebelah kanan) ke arah sebelah kanan (dan bila matahari itu terbenam menjauhi mereka ke sebelah kiri) yakni membiarkan mereka dan melewati mereka, hingga sinar matahari sama sekali tidak mengenai mereka (sedangkan mereka berada di tempat yang luas dalam gua itu) yakni gua yang luas, sehingga mereka selalu mendapatkan tiupan angin yang segar lagi menyejukkan. (Itu) yakni hal yang telah disebutkan (adalah sebagian tanda-tanda Allah) bukti-bukti yang menunjukkan akan kekuasaan-Nya. (Barang siapa yang diberi petunjuk oleh Allah, maka dialah yang mendapat petunjuk dan barang siapa yang disesatkan-Nya, maka kamu tak akan mendapatkan seorang pemimpin pun yang dapat memberi petunjuk kepadanya).\qt@no{17}}%
\qt@newcmd\qurantrans@id@mmclviii{%
(Dan kamu akan mengira mereka itu) seandainya kamu melihat mereka (adalah orang-orang yang bangun) yakni tidak tidur, karena mata mereka terbuka. Lafal Ayqaazhan adalah bentuk jamak dari lafal tunggal Yaqizhun (padahal mereka adalah orang-orang yang tidur) lafal Ruquudun adalah bentuk jamak daripada lafal Raqidun (dan Kami bolak-balikkan mereka ke kanan dan kiri) supaya daging mereka tidak dimakan oleh tanah (sedangkan anjing mereka mengunjurkan kedua lengannya) kedua kaki depannya (di muka pintu gua) ke luar mulut gua itu, dan apabila mereka membalikkan badannya, maka anjing itu pun berbuat yang sama, ia pun sama tidur dengan mereka walaupun matanya terbuka. (Dan jika kamu menyaksikan mereka tentulah kamu akan berpaling dari mereka dengan melarikan diri dan tentulah hati kamu akan dipenuhi) lafal Muli'ta dapat pula dibaca Mulli'ta (dengan ketakutan terhadap mereka) lafal Ru'ban dapat pula dibaca Ru'uban; Allah memelihara mereka dengan menimpakan rasa takut kepada setiap orang yang hendak memasuki gua tempat mereka, sehingga mereka terpelihara dengan aman.\qt@no{18}}%
\qt@newcmd\qurantrans@id@mmclix{%
(Dan demikianlah) yang telah Kami perbuat terhadap Ashhabul Kahfi, seperti yang telah Kami sebutkan tadi (Kami bangunkan mereka) Kami bangkitkan mereka (agar mereka saling bertanya di antara mereka sendiri) tentang keadaan mereka dan lamanya masa menetap mereka di dalam gua itu (Berkatalah seorang di antara mereka, ``Sudah berapa lamakah kalian tinggal di sini?" Mereka menjawab, ``Kita berada di sini sehari atau setengah hari)" sebab mereka memasuki gua ketika matahari mulai terbit, dan mereka bangun sewaktu matahari terbenam, maka oleh karena itu mereka menduga bahwa saat itu adalah terbenamnya matahari, kemudian (berkata sebagian yang lainnya lagi) seraya menyerahkan pengetahuan hal tersebut kepada Allah (Rabb kalian lebih mengetahui berapa lamanya kalian berada di sini, maka suruhlah salah seorang di antara kalian dengan membawa uang perak kalian ini) lafal Wariqikum dapat pula dibaca Warqikum, artinya uang perak kalian ini (pergi ke kota) menurut suatu pendapat dikatakan bahwa kota tersebut yang sekarang dinamakan Tharasus (dan hendaklah dia lihat manakah makanan yang lebih baik) artinya, manakah makanan di kota yang paling halal (maka hendaklah dia membawa makanan itu untuk kalian, dan hendaklah dia berlaku lemah lembut dan janganlah sekali-kali menceritakan hal kalian kepada seseorang pun).\qt@no{19}}%
\qt@newcmd\qurantrans@id@mmclx{%
(Sesungguhnya jika mereka dapat mengetahui tempat kalian, niscaya mereka akan melempar kalian dengan batu) niscaya mereka akan membunuh kalian dengan lemparan batu (atau memaksa kalian kembali kepada agama mereka, dan jika demikian niscaya kalian tidak akan beruntung) yakni jika kalian kembali kepada agama mereka (selama-lamanya)".\qt@no{20}}%
\qt@newcmd\qurantrans@id@mmclxi{%
(Dan demikianlah) sebagaimana Kami bangunkan mereka (Kami memperlihatkan) (kepada mereka) yakni kaum Ashhabul Kahfi dan kaum Mukminin pada umumnya (agar mereka mengetahui) artinya khusus bagi kaum Ashhabul Kahfi (bahwa janji Allah itu) yaitu adanya hari berbangkit (benar) dengan kesimpulan, bahwa Allah Yang Maha Kuasa mematikan mereka dalam masa yang sangat lama, kemudian mereka tetap utuh sekalipun tanpa makan dan minum, maka Dia Maha Kuasa pula untuk menghidupkan orang-orang yang sudah mati (dan bahwa kedatangan hari kiamat tidak ada keraguan) (padanya. Ketika) lafal Idz ini menjadi Ma'mul daripada lafal A'tsarnaa (orang-orang itu berselisih) orang-orang Mukmin dan orang-orang kafir (tentang urusan mereka) maksudnya mengenai perkara para pemuda itu dalam hal bangunan yang akan didirikan di sekitar tempat Ashhabul Kahfi itu (orang-orang itu berkata) yakni orang-orang kafir (Dirikanlah di atas gua mereka) di sekitar tempat mereka (sebuah bangunan) untuk menutupi mereka (Rabb mereka lebih mengetahui tentang mereka". Orang-orang yang berkuasa atas urusan mereka berkata,) yang dimaksud adalah yang menguasai perkara para pemuda tersebut, yaitu orang-orang yang beriman, ("Sesungguhnya kami akan mendirikan di atasnya) yakni di sekitarnya (sebuah rumah peribadatan.") tempat orang-orang melakukan salat; akhirnya dibuatlah sebuah rumah peribadatan di pintu gua tersebut.\qt@no{21}}%
\qt@newcmd\qurantrans@id@mmclxii{%
(Nanti mereka akan mengatakan) yaitu orang-orang yang berselisih pendapat di zaman Nabi saw. tentang bilangan para pemuda itu. Atau dengan kata lain sebagian di antara mereka mengatakan bahwa jumlah mereka ada (tiga orang yang keempat adalah anjingnya dan yang lain mengatakan) sebagian yang lain daripada mereka (lima orang dan yang keenam adalah anjingnya) kedua pendapat tersebut dikatakan oleh orang-orang Nasrani dari Najran (sebagai terkaan terhadap barang yang gaib) hanya berlandaskan kepada dugaan belaka tanpa bukti yang nyata; kedua pendapat tersebut hanyalah main terka saja. Lafal Rajman dinashabkan karena menjadi Maf'ul Lah, artinya: sebagai terkaan mereka terhadap barang yang gaib (dan yang lain lagi mengatakan) yakni orang-orang Mukmin (Jumlah mereka, tujuh orang, yang kedelapan adalah anjingnya) Jumlah ayat ini berkedudukan menjadi Mubtada, sedangkan Khabarnya adalah Sifat daripada lafal Sab'atun, dengan ditambahi huruf Wawu sesudahnya. Menurut pendapat yang lain, berkedudukan menjadi Taukid, atau menunjukkan tentang menempelnya sifat kepada Maushufnya. Dan disifatinya kedua pendapat yang tadi dengan istilah Ar-Rajmi yakni terkaan, berbeda dengan pendapat yang ketiga sekarang ini, hal ini menunjukkan bahwa pendapat yang ketiga ini adalah pendapat yang sahih dan dibenarkan (Katakanlah, ``Rabbku lebih mengetahui jumlah mereka; tidak ada orang yang mengetahui bilangan mereka kecuali sedikit") Sahabat Ibnu Abbas r.a. mengatakan, ``Saya adalah salah seorang daripada orang-orang yang sedikit itu." Selanjutnya ia menuturkan bahwa jumlah mereka ada tujuh orang. (Karena itu janganlah kamu bertengkar) yakni memperdebatkan (tentang hal mereka, kecuali pertengkaran yang lahir saja) daripada sebagian apa yang diturunkan kepadamu (dan jangan kamu menanyakan tentangnya) maksudnya kamu meminta penjelasan tentang Ashkabul Kahfi itu (dari mereka) mempertanyakan kepada sebagian daripada orang-orang ahli kitab, yaitu orang-orang Yahudi (seseorang pun) pada suatu ketika penduduk Mekah menanyakan tentang kisah Ashhabul Kahfi itu. Lalu Nabi saw. menjawab, ``Saya akan menceritakannya kepada kalian besok", tanpa memakai kata Insya Allah, maka turunlah firman-Nya:\qt@no{22}}%
\qt@newcmd\qurantrans@id@mmclxiii{%
(Dan jangan sekali-kali kamu mengatakan terhadap sesuatu) tentang sesuatu (Sesungguhnya aku akan mengerjakan itu besok pagi) lafal Ghadan artinya di masa mendatang.\qt@no{23}}%
\qt@newcmd\qurantrans@id@mmclxiv{%
(Kecuali dengan menyebut ``Insya Allah") artinya, mengecualikannya dengan menggantungkan hal tersebut kepada kehendak Allah, seumpamanya kamu mengatakan Insya Allah (Dan ingatlah kepada Rabbmu) yaitu kepada kehendak-Nya seraya menggantungkan diri kepada kehendak-Nya (jika kamu lupa) ini berarti jika ingat kepada kehendak-Nya sesudah lupa, sama dengan ingat kepada kehendak-Nya sewaktu mengatakan hal tersebut. Hasan dan lain-lainnya mengatakan, ``Selagi seseorang masih dalam majelisnya" (dan katakanlah, ``Mudah-mudahan Rabbku akan memberiku petunjuk kepada yang lebih dekat daripada ini) yaitu berita tentang Ashhabul Kahfi untuk menunjukkan kebenaran kenabianku (kebenarannya") yakni petunjuk yang lebih benar, dan memang Allah memperkenankan hal tersebut.\qt@no{24}}%
\qt@newcmd\qurantrans@id@mmclxv{%
(Dan mereka tinggal dalam gua mereka tiga ratus) lafal Miatin dibaca dengan memakai harakat Tanwin pada akhirnya (tahun) berkedudukan sebagai 'Athaf Bayan yang dikaitkan dengan lafal Tsalaatsu Miatin. Perhitungan tiga ratus tahun ini berdasarkan hisab yang berlaku di kalangan kaum Ashhabul Kahfi, yaitu berdasarkan perhitungan tahun Syamsiah. Dan bila menurut hisab tahun Qamariah sebagaimana yang berlaku di kalangan orang-orang Arab, maka menjadi bertambah sembilan tahun, dan hal ini disebutkan di dalam firman selanjutnya, yaitu (dan ditambah sembilan tahun) yakni hisab yang tiga ratus tahun berdasarkan tahun Syamsiah dan hisab yang tiga ratus sembilan tahun berdasarkan tahun Qamariyah.\qt@no{25}}%
\qt@newcmd\qurantrans@id@mmclxvi{%
(Katakanlah, ``Allah lebih mengetahui berapa lamanya mereka tinggal di gua) daripada orang-orang yang berselisih pendapat tentangnya, sebagaimana yang telah disebutkan tadi (Kepunyaan-Nyalah semua yang tersembunyi di langit dan di bumi) ilmu kesemuanya berada pada-Nya. (Alangkah terang penglihatan-Nya) penglihatan Allah, lafal Abshir bihi adalah Shighat Ta'ajjub (dan alangkah tajam pendengaran-Nya) pendengaran Allah, demikian pula lafal Asmi' bihi sama dengan lafal Maa Asma'ahu, dan yang sebelumnya sama dengan lafal Maa Absharahu, keduanya merupakan ungkapan cara Majaz. Makna yang dimaksud ialah, bahwa tiada sesuatu pun yang tidak diketahui oleh penglihatan dan pendengaran Allah swt. (tak ada bagi mereka) bagi semua penduduk langit dan bumi (seorang pelindung pun selain daripada-Nya) seorang yang dapat menolong (dan Dia tidak mengambil seorang pun menjadi sekutu-Nya dalam menetapkan keputusan") karena sesungguhnya Dia tidak membutuhkan adanya sekutu.\qt@no{26}}%
\qt@newcmd\qurantrans@id@mmclxvii{%
(Dan bacakanlah apa yang diwahyukan kepadamu, yaitu Kitab Rabb-Mu. Tidak ada seorang pun yang dapat mengubah kalimat-kalimat-Nya. Dan engkau tidak akan mendapatkan perlindungan selain perlindungan-Nya).\qt@no{27}}%
\qt@newcmd\qurantrans@id@mmclxviii{%
(Dan bersabarlah kamu) tahanlah dirimu (bersama-sama dengan orang-orang yang menyeru Rabbnya di pagi dan senja hari dengan mengharap) melalui ibadah mereka itu (keridaan-Nya) keridaan Allah swt., bukannya karena mengharapkan sesuatu daripada kebendaan duniawi sekali pun mereka adalah orang-orang miskin (dan janganlah berpaling) jangan kamu memalingkan (kedua matamu dari mereka) (karena mengharapkan perhiasan kehidupan dunia ini; dan janganlah kamu mengikuti orang yang hatinya telah Kami lalaikan dari mengingat Kami) maksudnya dilalaikan hatinya daripada Alquran, dan orang yang dimaksud adalah Uyaynah bin Hishn dan teman-temannya (serta memperturuti hawa nafsunya) yaitu melakukan perbuatan yang memusyrikkan (dan adalah keadaannya itu melewati batas) terlalu berlebih-lebihan.\qt@no{28}}%
\qt@newcmd\qurantrans@id@mmclxix{%
(Dan katakanlah) kepadanya dan kepada teman-temannya, bahwa Alquran ini (adalah benar datang dari Rabb kalian, maka barang siapa yang ingin beriman, hendaklah ia beriman dan barang siapa yang ingin kafir, biarlah ia kafir). Kalimat ayat ini merupakan ancaman buat mereka. (Sesungguhnya Kami telah sediakan bagi orang-orang zalim itu) yaitu bagi orang-orang kafir (neraka, yang gejolaknya mengepung mereka) yang melahap apa saja yang dikepungnya. (Dan jika mereka meminta minum, niscaya mereka akan diberi minum dengan air seperti besi yang mendidih) seperti minyak yang mendidih (yang menghanguskan muka) karena panasnya, jika seseorang mendekat kepadanya (seburuk-buruk minuman) adalah minuman itu (dan ia adalah sejelek-jelek) yakni neraka itu (tempat istirahat). Lafal Murtafaqan sebagai lawan makna yang telah disebutkan di dalam ayat yang lain sehubungan dengan gambaran surga, yaitu firman-Nya, ``Dan surga itu adalah tempat istirahat yang paling indah" (Q. S, 18 Al-Kahfi, 31). Jika tidak diartikan demikian, maka tidaklah pantas neraka dikatakan sebagai tempat istirahat.\qt@no{29}}%
\qt@newcmd\qurantrans@id@mmclxx{%
(Sesungguhnya orang-orang yang beriman dan beramal saleh, tentulah Kami tidak akan menyia-nyiakan pahala orang-orang yang mengerjakan amalnya dengan baik) Jumlah kalimat ``Innaa Laa Nudhii'u" berkedudukan menjadi Khabar daripada ``Innal Ladziina". Di dalam ungkapan ini terkandung pengertian meletakkan isim Zhahir pada tempat isim Mudhmar; makna yang dimaksud adalah Ajrahum atau pahalanya. Atau dengan kata lain, Kami akan memberi pahala kepada mereka sesuai dengan amal baik mereka.\qt@no{30}}%
\qt@newcmd\qurantrans@id@mmclxxi{%
(Mereka itulah orang-orang yang bagi mereka surga Adn) sebagai tempat tinggal mereka (mengalir sungai-sungai di bawahnya. Dalam surga itu mereka dihiasi dengan gelang) menurut suatu pendapat disebutkan, bahwa huruf Min di sini adalah Zaidah dan menurut pendapat yang lain dikatakan pula bahwa itu mengandung makna Tab'idh atau sebagian. Lafal Asaawira adalah bentuk jamak dari lafal Aswiratun yang wazannya sama dengan lafal Ahmiratun, dan lafal Aswiratun ini pun adalah bentuk jamak dari kata tunggal Siwaarun (emas dan mereka memakai pakaian hijau dari sutra halus) sutra yang paling halus (dan sutra tebal) sutra yang paling tebal. Di dalam surah Ar-Rahman disebutkan, ``Yang sebelah dalamnya dari sutra yang tebal." (Q.S. Ar-Rahman 54). (Sedangkan mereka duduk sambil bersandar di atas dipan-dipan) lafal Araaiki adalah bentuk jamak dari kata Ariikah, yaitu pelaminan yang dihiasi dengan berbagai macam pakaian dan kelambu buat pengantin. (Itulah sebaik-baik pahala) yaitu surga (dan tempat istirahat yang paling indah).\qt@no{31}}%
\qt@newcmd\qurantrans@id@mmclxxii{%
(Dan berikanlah) jadikanlah (buat mereka) buat orang-orang kafir beserta orang-orang Mukmin (sebuah perumpamaan dua orang laki-laki). Lafal Rajulaini menjadi Badal daripada lafal Matsalan, dan lafal Rajulaini dengan lafal-lafal yang sesudahnya berkedudukan sebagai penafsir daripada lafal Matsalan (Kami jadikan bagi seorang di antara keduanya) yakni bagi orang yang kafir (dua buah kebun) dua buah perkebunan (anggur dan Kami kelilingi kedua kebun itu dengan pohon-pohon kurma dan di antara kedua kebun itu Kami buatkan ladang) yang khusus menghasilkan makanan pokok.\qt@no{32}}%
\qt@newcmd\qurantrans@id@mmclxxiii{%
(Kedua buah kebun itu) lafal Kiltaa adalah Mufrad yang menunjukkan makna Tatsniyah; ia berkedudukan menjadi Mubtada (menghasilkan). Lafal Aatat ini menjadi Khabar Kiltaa (buahnya) yakni buah-buahannya (dan kebun itu tiada dizalimi) dikurangi (buahnya sedikit pun dan Kami alirkan) artinya, Kami bedahkan (sungai di celah-celah kedua kebun itu) yakni sungai itu mengalir di antara kedua kebun tersebut.\qt@no{33}}%
\qt@newcmd\qurantrans@id@mmclxxiv{%
(Dan dia mempunyai) di samping kedua kebun itu (buah-buahan yang banyak) lafal Tsamarun atau Tsumurun atau Tsumrun adalah bentuk jamak dari kata Tsamratun; keadaannya sama dengan lafal Syajaratun dan Syajarun, atau Khasyabatun dan Khasyabun, atau Badanatun dan Badanun (maka ia berkata kepada kawannya) yang mukmin (ketika ia bercakap-cakap dengan dia) seraya membanggakan miliknya, ``(Hartaku lebih banyak daripada hartamu dan pengikut-pengikutku lebih kuat)" keluargaku lebih kuat.\qt@no{34}}%
\qt@newcmd\qurantrans@id@mmclxxv{%
(Dan dia memasuki kebunnya) dengan membawa temannya yang Mukmin itu, seraya membawanya ke sekeliling kebun serta memperlihatkan kepadanya hasil buah-buahannya. Di sini tidak diungkapkan dengan memakai lafal Jannataihi dalam bentuk Tatsniyah karena pengertian yang dimaksud adalah tamannya. Menurut pendapat yang lain disebutkan, bahwa cukup hanya dengan menyebutkan satu saja (sedang dia lalim terhadap dirinya sendiri) dengan melakukan kekafiran (ia berkata, ``Aku kira tidak akan binasa) tidak akan lenyap (kebun ini untuk selama-lamanya).\qt@no{35}}%
\qt@newcmd\qurantrans@id@mmclxxvi{%
(Dan aku tidak mengira hari kiamat itu akan datang, dan jika sekiranya aku dikembalikan kepada Rabbku) di akhirat kelak sebagaimana dugaanmu itu (pasti aku akan mendapat tempat kembali yang lebih baik daripada kebun-kebun itu)" tempat tinggal yang lebih baik.\qt@no{36}}%
\qt@newcmd\qurantrans@id@mmclxxvii{%
(Kawannya yang Mukmin berkata kepadanya sedang dia bercakap-cakap dengannya) seraya menjawab apa yang telah dikatakannya tadi, ("Apakah kamu ingkar terhadap Rabb yang telah menciptakan kamu dari tanah) karena Nabi Adam diciptakan dari tanah dan dia sebagai anak cucunya (kemudian dari setetes air mani) setetes sperma (lalu Dia menyempurnakan bentukmu) merampungkan bentukmu dan menjadikanmu (sebagai seorang laki-laki)".\qt@no{37}}%
\qt@newcmd\qurantrans@id@mmclxxviii{%
(Tetapi aku) lafal Laakinna asalnya merupakan gabungan antara lafal Laakin dan Anaa, kemudian harakat huruf Hamzah Anaa dipindahkan kepada Nun lafal Laakin; atau huruf Hamzah Anaa dibuang kemudian huruf Nun lafal Laakin diidgamkan kepada Na, sehingga jadilah Laakinna (mengatakan) lafal Huwa mengandung dhamir Sya'an yang dijelaskan oleh kalimat sesudahnya; artinya, aku mengatakan, ("Allah adalah Rabbku, dan aku tidak mempersekutukan seorang pun dengan Rabbku)".\qt@no{38}}%
\qt@newcmd\qurantrans@id@mmclxxix{%
(Mengapa tidak) (kamu katakan sewaktu kamu memasuki kebunmu) sewaktu kamu merasa takjub dengan kebunmu itu, ("Ini adalah apa yang telah dikehendaki oleh Allah; tidak ada kekuatan kecuali dengan pertolongan Allah?)" di dalam sebuah hadis telah disebutkan, ``Barang siapa yang diberi kebaikan (nikmat), baik berupa istri yang cantik lagi saleh atau pun harta benda yang banyak, lalu ia mengatakan, 'Maasya Allaah Laa Quwwata Illaa Billaah' (Ini adalah apa yang dikehendaki oleh Allah, dan tiada kekuatan melainkan berkat pertolongan Allah), niscaya ia tidak akan melihat hal-hal yang tidak disukai akan menimpa kebaikan tersebut. (Jika kamu anggap aku ini) lafal Anaa merupakan dhamir Fashl yang memisahkan antara kedua Maf'u1 (lebih sedikit daripada kamu dalam hal harta dan anak).\qt@no{39}}%
\qt@newcmd\qurantrans@id@mmclxxx{%
(Maka mudah-mudahan Rabbku, akan memberi kepadaku kebun yang lebih baik daripada kebunmu ini) jumlah kalimat ayat ini menjadi Jawab daripada Syarat pada ayat sebelumnya (dan mudah-mudahan Dia mengirimkan ketentuan kepada kebunmu) lafal Husbanan adalah bentuk jamak dari kata Husbanah artinya petir (dan langit, hingga kebun itu menjadi tanah yang licin) tanah yang sangat licin sehingga telapak kaki tidak dapat berpijak padanya.\qt@no{40}}%
\qt@newcmd\qurantrans@id@mmclxxxi{%
(Atau airnya menjadi surut ke dalam tanah) lafal Ghauran bermakna Ghairan, diathafkan kepada lafal Yursila, bukan kepada lafal Tushbiha, karena pengertian Ghaural Mai atau kekeringan air tidak ada kaitannya dengan masalah petir (maka sekali-kali kamu tidak dapat menemukannya lagi)" kamu tidak akan menemukan upaya lagi untuk menjadikannya kembali.\qt@no{41}}%
\qt@newcmd\qurantrans@id@mmclxxxii{%
(Dan buah-buahannya diliputi) yakni ditimpa oleh berbagai macam musibah seperti yang telah disebutkan tadi sehingga binasalah semuanya berikut kebunnya (lalu ia membolak-balikkan kedua tangannya) karena menyesal dan kecewa (terhadap biaya yang telah dibelanjakannya untuk itu) untuk menggarap kebunnya (sedangkan pohon anggur itu roboh) tumbang (berikut para-paranya) penopang-penopangnya; pada mulanya pohon berikut penopangnya roboh maka berjatuhanlah buah-buah anggur itu (dan dia berkata, ``Aduhai) sebagai ungkapan kekecewaannya (kiranya dulu aku tidak mempersekutukan seorang pun dengan Rabbku)".\qt@no{42}}%
\qt@newcmd\qurantrans@id@mmclxxxiii{%
(Dan tidak ada) dapat dibaca Lam Takun atau Lam Yakun (bagi dia segolongan pun) sekelompok orang pun (yang akan menolongnya selain Allah) di waktu kebunnya binasa (dan sekali-kali ia tidak dapat membela dirinya) tak mampu mempertahankannya sendiri sewaktu kebunnya binasa.\qt@no{43}}%
\qt@newcmd\qurantrans@id@mmclxxxiv{%
(Di sana) kelak di hari kiamat (pertolongan itu) kalau dibaca Al-Walaayah artinya pertolongan, dan kalau dibaca Al-Wilaayah artinya kerajaan (hanya dari Allah Yang Hak) kalau dibaca Al-Haqqu menjadi sifat dari lafal Al-Walaayah dan kalau dibaca Al-Haqqi menjadi sifat dari Lafzhul Jalalah atau Allah (Dia adalah sebaik-baik Pemberi pahala) lebih baik daripada pahala selain-Nya seandainya ada yang dapat memberi pahala (dan sebaik-baik Pemberi balasan) lafal 'Uqban atau 'Uquban artinya balasan bagi orang-orang Mukmin; dinashabkan karena menjadi Tamyiz.\qt@no{44}}%
\qt@newcmd\qurantrans@id@mmclxxxv{%
(Dan berilah) jadikanlah (buat mereka) buat kaummu (suatu perumpamaan tentang kehidupan dunia ini) menjadi Maf'ul Awwal (adalah sebagai air hujan) menjadi Maf'ul Tsani (yang Kami turunkan dari langit, maka menjadi subur karenanya) menjadi tumbuh subur disebabkannya (tumbuh-tumbuhan di muka bumi) atau air hujan itu bercampur dengan tumbuh-tumbuhan, hingga tumbuh-tumbuhan itu menjadi segar dan tumbuh dengan suburnya (kemudian tumbuh-tumbuhan itu menjadi) (kering) layu dan bagian-bagiannya menjadi belah (yang diterbangkan) ditiup menjadi berantakan (oleh angin) sehingga tidak ada gunanya lagi. Makna ayat ini menyerupakan duniawi dengan tumbuh-tumbuhan yang subur, kemudian menjadi kering dan dipecahkan serta dihamburkan beterbangan oleh angin. Menurut suatu qiraat lafal Ar-Riyaah dibaca Ar-Riih (Dan adalah Allah berkuasa atas segala sesuatu) yakni Maha Kuasa.\qt@no{45}}%
\qt@newcmd\qurantrans@id@mmclxxxvi{%
(Harta dan anak-anak adalah perhiasan kehidupan dunia) keduanya dapat dijadikan sebagai perhiasan di dalam kehidupan dunia (tetapi amalan-amalan yang kekal lagi saleh) yaitu mengucapkan kalimat: Subhaanallaah Wal Hamdulillaah Wa Laa Ilaaha Illallaah Wallaahu Akbar; menurut sebagian ulama ditambahkan Walaa Haulaa Walaa Quwwata Illaa Billaahi (adalah lebih baik pahalanya di sisi Rabbmu serta lebih baik untuk menjadi harapan) hal yang diharap-harapkan dan menjadi dambaan manusia di sisi Allah swt.\qt@no{46}}%
\qt@newcmd\qurantrans@id@mmclxxxvii{%
(Dan) ingatlah (akan hari yang ketika itu Kami perjalankan gunung-gunung) Kami lenyapkan gunung-gunung itu dari muka bumi, hingga gunung-gunung itu menjadi debu yang beterbangan. Menurut qiraat yang lain dibaca Tusayyaru. (dan kamu akan melihat bumi itu datar) tidak ada sesuatu pun yang ada padanya, baik gunung maupun yang lain-lainnya (dan Kami kumpulkan seluruh manusia) baik mereka yang mukmin maupun mereka yang kafir (dan tidak Kami tinggalkan) Kami tidak membiarkan (seorang pun dari mereka.)\qt@no{47}}%
\qt@newcmd\qurantrans@id@mmclxxxviii{%
(Dan mereka akan dibawa ke hadapan Rabbmu dengan berbaris) lafal Shaffan menjadi Hal; artinya setiap umat mempunyai barisannya tersendiri, kemudian dikatakan kepada mereka: (Sesungguhnya kalian datang kepada Kami, sebagaimana Kami menciptakan kalian pada kali yang pertama) artinya, kalian datang menghadap dalam keadaan sendiri-sendiri, tidak pakai alas kaki, telanjang dan belum dikhitan. Kemudian dikatakan kepada orang-orang yang mengingkari adanya hari berbangkit (bahkan kalian mengatakan bahwa) lafal An adalah bentuk Takhfif daripada Anna, artinya bahwasanya (Kami sekali-kali tidak akan menetapkan bagi kalian waktu memenuhi perjanjian) untuk membangkitkan kalian.\qt@no{48}}%
\qt@newcmd\qurantrans@id@mmclxxxix{%
(Dan diletakkanlah kitab) yaitu kitab catatan amal perbuatan setiap orang; bagi orang-orang Mukmin diterima di sebelah kanannya, dan bagi orang-orang kafir di sebelah kirinya (lalu kamu akan melihat orang-orang yang berdosa) orang-orang kafir (ketakutan) merasa takut (terhadap apa yang tertulis di dalamnya, dan mereka berkata) sewaktu mereka melihat kesalahan-kesalahan yang terdapat di dalam kitab catatan amal masing-masing. (Aduhai) ungkapan rasa kecewa (celakalah kami) binasalah kami; lafal Wailata adalah Mashdar yang tidak mempunyai Fi'il dari lafal asalnya (kitab apakah ini yang tidak meninggalkan yang kecil dan tidak pula yang besar) dari dosa-dosa kami (melainkan ia mencatat semuanya)" semuanya telah tercatat dan terbukti di dalamnya; mereka merasa takjub akan hal tersebut (dan mereka dapati apa yang telah mereka kerjakan ada) tertulis di dalam catatan kitab-kitab mereka. (Dan Rabbmu tidak menganiaya seorang jua pun) Dia tidak akan menghukum seseorang tanpa dosa, dan Dia tidak akan mengurangi pahala orang Mukmin.\qt@no{49}}%
\qt@newcmd\qurantrans@id@mmcxc{%
(Dan ingatlah ketika) lafal Idz dinashabkan oleh lafal Udzkur yang tidak disebutkan (Kami berfirman kepada para Malaikat, ``Sujudlah kalian kepada Adam)" dengan cara membungkukkan badan sebagai tanda penghormatan kepadanya, bukan dengan cara meletakkan kening (maka sujudlah mereka kecuali iblis, dia adalah segolongan dari jin) menurut suatu pendapat dikatakan bahwa iblis itu adalah sejenis malaikat. Berdasarkan pengertian ini maka istitsnanya adalah Muttashil. Menurut pendapat yang lain Istitsna ini adalah Munqathi'. Berdasarkan pengertian ini maka iblis adalah biang jin, ia mempunyai keturunan yang telah disebutkan sebelumnya, sedangkan Malaikat tidak mempunyai keturunan (maka ia mendurhakai perintah Rabbnya) artinya, iblis itu membangkang tidak mau taat kepada-Nya, karena ia tidak mau bersujud kepada Nabi Adam. (Patutkah Engkau mengambil dia dan turunan-turunannya) pembicaraan ini ditujukan kepada Nabi Adam dan keturunannya, dan Dhamir Ha pada dua tempat kembali kepada iblis (sebagai pemimpin selain daripada-Ku) yang kemudian kalian taati mereka (sedangkan mereka adalah musuh kalian?) menjadi musuh. Lafal 'Aduwwun berkedudukan menjadi Hal karena bermakna A'daa-an. (Amat buruklah iblis itu sebagai pengganti Allah bagi orang-orang yang lalim) yakni iblis dan keturunannya untuk ditaati sebagai pengganti taat kepada Allah.\qt@no{50}}%
\qt@newcmd\qurantrans@id@mmcxci{%
(Aku tidak menghadirkan mereka untuk menyaksikan) yakni iblis dan anak cucunya (penciptaan langit dan bumi dan tidak pula penciptaan diri mereka sendiri) Kami tidak menghadirkan sebagian dari mereka untuk menyaksikan penciptaan sebagian yang lain (dan tidaklah Aku mengambil orang-orang yang menyesatkan) yakni setan-setan (sebagai penolong) yang membantu dalam penciptaan, maka mengapa kalian menaati mereka?\qt@no{51}}%
\qt@newcmd\qurantrans@id@mmcxcii{%
(Dan ingatlah akan hari) yang ketika itu; lafal Yauma dinashabkan oleh lafal Udzkur yang tidak disebutkan (Dia berfirman) dapat dibaca Yaquulu atau Naquulu, ("Panggillah oleh kalian sekutu-sekutu-Ku) yakni berhala-berhala itu (yang kalian katakan itu!)" untuk memberi syafaat atau pertolongan kepada diri kalian sebagaimana apa yang didugakan oleh kalian. (Mereka lalu memanggilnya tetapi sekutu-sekutu itu tidak membalas seruan mereka) tidak menjawab seruannya (dan Kami adakan untuk mereka) untuk berhala-berhala dan para pengabdinya (tempat kebinasaan) sebuah lembah di neraka Jahanam yang mereka semuanya dibinasakan di dalamnya. Lafal Maubiqan berasal dari lafal Wabaqa artinya telah binasa.\qt@no{52}}%
\qt@newcmd\qurantrans@id@mmcxciii{%
(Dan orang-orang yang berdosa melihat neraka, maka mereka meyakini) merasa yakin (bahwa mereka akan jatuh ke dalamnya) akan dicampakkan ke dalamnya (dan mereka tidak menemukan tempat berpaling daripadanya) tidak menemui jalan untuk menyelamatkan diri daripadanya.\qt@no{53}}%
\qt@newcmd\qurantrans@id@mmcxciv{%
(Dan sesungguhnya Kami telah menjelaskan) (bagi manusia dalam Alquran ini bermacam-macam perumpamaan) lafal Min Kulli Matsalin berkedudukan menjadi sifat daripada lafal yang tidak disebutkan, artinya: suatu perumpamaan dari setiap jenis perumpamaan, supaya mereka mengambil pelajaran daripadanya. (Dan manusia adalah makhluk) yakni orang kafir (yang paling banyak membantah) paling banyak permusuhannya dalam kebatilan; lafal Jadalan adalah Tamyiz yang dipindahkan dari Isim Kaana. Maknanya: Permusuhan yang paling banyak dilakukan oleh manusia adalah dalam hal kebatilan.\qt@no{54}}%
\qt@newcmd\qurantrans@id@mmcxcv{%
(Dan tidak ada sesuatu pun yang menghalangi manusia) orang-orang kafir Mekah (untuk beriman) menjadi Maf'ul Tsani atau subjek kedua (ketika petunjuk telah datang kepada mereka) yakni Alquran (dan memohon ampun kepada Rabbnya, kecuali datang kepada mereka hukum Allah yang telah berlaku pada umat-umat terdahulu) lafal Sunnatul Awwalin berkedudukan menjadi Fa'il atau objek, artinya: datang kepada mereka kebinasaan Kami, yaitu kebinasaan yang telah ditentukan bagi mereka (atau datang azab atas mereka dengan nyata) secara terang-terangan, yaitu kekalahan mereka dalam perang Badar. Menurut qiraat yang lain dibaca Qubulan sebagai bentuk jamak dari kata Qabilun artinya bermacam-macam.\qt@no{55}}%
\qt@newcmd\qurantrans@id@mmcxcvi{%
(Dan tidaklah Kami mengutus Rasul-rasul hanyalah sebagai pembawa berita gembira) bagi orang-orang yang beriman (dan sebagai pemberi peringatan) untuk menakut-nakuti orang-orang kafir (tetapi orang-orang yang kafir membantah dengan yang batil) yaitu melalui perkataan mereka sebagaimana yang disitir oleh ayat lain, yaitu firman-Nya, ``Adakah Allah mengutus seorang manusia menjadi Rasul?" (Q.S. Al-Isra, 94) dan ayat-ayat lainnya yang semakna (agar dengan demikian mereka dapat melenyapkan) dapat membatalkan melalui bantahan mereka (yang hak) yakni Alquran (dan mereka menganggap ayat-ayat-Ku) yakni Alquran (dan peringatan-peringatan terhadap mereka) yakni siksa neraka (sebagai olok-olokan) sebagai ejekan mereka.\qt@no{56}}%
\qt@newcmd\qurantrans@id@mmcxcvii{%
(Dan siapakah yang lebih lalim daripada orang yang telah diperingatkan dengan ayat-ayat dari Rabbnya lalu dia berpaling daripadanya dan melupakan apa yang telah dikerjakan oleh kedua tangannya) apa yang telah diperbuatnya berupa kekafiran dan kedurhakaan. (Sesungguhnya Kami telah meletakkan tutupan di atas hati mereka) penutup-penutup (hingga mereka tidak memahaminya) maksudnya, supaya mereka tidak dapat memahami Alquran, dengan demikian maka mereka tidak dapat memahaminya (dan di telinga mereka Kami letakkan sumbatan pula) yakni penyumbat sehingga mereka tidak dapat mendengarkannya (dan kendati pun kamu menyeru mereka kepada petunjuk, niscaya mereka tidak akan mendapat petunjuk) disebabkan adanya penutup dan sumbatan tadi (selama-lamanya).\qt@no{57}}%
\qt@newcmd\qurantrans@id@mmcxcviii{%
(Dan Rabbmulah Yang Maha Pengampun lagi mempunyai rahmat. Jika Dia mengazab mereka) di dunia (karena perbuatan mereka, tentu Dia akan menyegerakan azab bagi mereka) di dunia (Tetapi bagi mereka ada waktu yang tertentu) untuk menerima azab yaitu hari kiamat (yang mereka sekali-kali tidak akan menemukan tempat berlindung daripadanya) yaitu tempat untuk menyelamatkan diri.\qt@no{58}}%
\qt@newcmd\qurantrans@id@mmcxcix{%
(Dan negeri itu) yang dimaksud adalah penduduknya, seperti kaum Ad dan kaum Tsamud serta lain-lainnya (telah Kami binasakan, ketika mereka berbuat lalim) yakni kafir (dan telah Kami tetapkan bagi kebinasaan mereka) untuk membinasakan mereka. Dan menurut qiraat yang lain dibaca limahlakihim, artinya bagi tempat kebinasaan mereka (waktu tertentu).\qt@no{59}}%
\qt@newcmd\qurantrans@id@mmcc{%
(Dan) ingatlah (ketika Musa berkata) Nabi Musa adalah anak lelaki Imran (kepada muridnya) yang bernama Yusya bin Nun; ia selalu mengikutinya dan menjadi pelayannya serta mengambil ilmu daripadanya, ("Aku tidak akan berhenti) artinya, aku akan terus berjalan (sebelum sampai ke pertemuan dua buah lautan) tempat bertemunya Laut Romawi dan laut Persia dari sebelah Timurnya; yakni tempat bertemunya kedua lautan tersebut (atau aku akan berjalan sampai bertahun-tahun)" selama bertahun-tahun untuk mencapainya sekalipun jauh.\qt@no{60}}%
\qt@newcmd\qurantrans@id@mmcci{%
(Maka tatkala keduanya sampai ke pertemuan dua buah laut itu) yakni tempat bertemunya kedua laut itu (mereka berdua lupa akan ikannya) Yusya' lupa membawanya ketika berangkat, Nabi Musa pun lupa mengingatkannya (maka ia mengambil) yakni ikan itu melompat untuk mengambil (jalannya ke laut itu) Allahlah yang menjadikan jalan itu, yaitu dengan menjadikan baginya (dalam keadaan berlubang) seperti lubang bekasnya, yaitu lubang yang sangat panjang dan tak berujung. Demikian itu karena Allah swt. menahan arus air demi untuk ikan itu, lalu masuklah ikan itu ke dalamnya dengan meninggalkan bekas seperti lubang dan tidak terhapus karena bekasnya membeku.\qt@no{61}}%
\qt@newcmd\qurantrans@id@mmccii{%
(Maka tatkala mereka berdua melewati) tempat itu dengan berjalan kaki sampai dengan waktu makan siang, yaitu pada hari kedua Musa (berkatalah kepada muridnya, ``Bawalah ke mari makanan kita!) yaitu makanan yang biasa dimakan pada siang hari, yakni makan siang (sesungguhnya kita telah merasa letih karena perjalanan kita ini)" payah, yang hal ini baru mereka rasakan setelah berjalan jauh dari tempat itu.\qt@no{62}}%
\qt@newcmd\qurantrans@id@mmcciii{%
(Muridnya menjawab, ``Tahukah kamu) ingatkah kamu (tatkala kita mencari tempat berlindung di batu tadi) yakni di tempat tersebut (maka sesungguhnya aku lupa ikan itu dan tidak adalah yang melupakan aku kecuali setan) kemudian Dhamir Ha pada ayat ini dijelaskan oleh ayat berikutnya, yaitu (untuk mengingatnya) lafal ayat ini menjadi Badal Isytimal, artinya setan telah melupakan aku untuk mengingatnya (dan ia mengambil) yakni ikan itu (akan jalannya di laut dengan cara yang aneh sekali.)" Lafal 'Ajaban menjadi Maf'ul Tsani, artinya, Nabi Musa dan muridnya merasa heran terhadap perihal ikan itu sebagaimana yang telah disebutkan di atas tadi.\qt@no{63}}%
\qt@newcmd\qurantrans@id@mmcciv{%
(Berkatalah) Musa, ("Itulah) tempat kita kehilangan ikan itu (tempat) sesuatu (yang kita cari)" kita cari-cari, karena sesungguhnya hal itu merupakan pertanda bagi kita, bahwa kita akan dapat bertemu dengan orang yang sedang kita cari. (Lalu keduanya kembali) kembali lagi (mengikuti jejak mereka semula) menitinya (secara benar-benar) lalu keduanya sampai di batu besar tempat mereka beristirahat.\qt@no{64}}%
\qt@newcmd\qurantrans@id@mmccv{%
(Lalu mereka berdua bertemu dengan seorang hamba di antara hamba-hamba Kami) yaitu Khidhir (yang telah Kami berikan kepadanya rahmat dari sisi Kami) yakni kenabian, menurut suatu pendapat, dan menurut pendapat yang lain kewalian, pendapat yang kedua inilah yang banyak dianut oleh para ulama (dan yang telah Kami ajarkan kepadanya dari sisi Kami) dari Kami secara langsung (ilmu). Lafal 'ilman menjadi Maf'ul Tsani, yaitu ilmu-ilmu yang berkaitan dengan masalah-masalah kegaiban. Imam Bukhari telah meriwayatkan sebuah hadis, bahwa pada suatu ketika Nabi Musa berdiri berkhutbah di hadapan kaum Bani Israel. Lalu ada pertanyaan, ``Siapakah orang yang paling alim?" Maka Nabi Musa menjawab, ``Aku". Lalu Allah menegur Nabi Musa karena ia belum pernah belajar (ilmu gaib), maka Allah menurunkan wahyu kepadanya, ``Sesungguhnya Aku mempunyai seorang hamba yang tinggal di pertemuan dua laut, dia lebih alim daripadamu". Musa berkata, ``Wahai Rabbku! Bagaimanakah caranya supaya aku dapat bertemu dengan dia". Allah berfirman, ``Pergilah kamu dengan membawa seekor ikan besar, kemudian ikan itu kamu letakkan pada keranjang. Maka manakala kamu merasa kehilangan ikan itu, berarti dia ada di tempat tersebut". Lalu Nabi Musa mengambil ikan itu dan ditaruhnya pada sebuah keranjang, selanjutnya ia berangkat disertai dengan muridnya yang bernama Yusya bin Nun, hingga keduanya sampai pada sebuah batu yang besar. Di tempat itu keduanya berhenti untuk istirahat seraya membaringkan tubuh mereka, akhirnya mereka berdua tertidur. Kemudian ikan yang ada di keranjang berontak dan melompat keluar, lalu jatuh ke laut. Lalu ikan itu melompat mengambil jalannya ke laut itu. (Q.S. Al Kahfi, 61) Allah menahan arus air demi untuk jalannya ikan itu, sehingga pada air itu tampak seperti terowongan. Ketika keduanya terbangun dari tidurnya, murid Nabi Musa lupa memberitakan tentang ikan kepada Nabi Musa. Lalu keduanya berangkat melakukan perjalanan lagi selama sehari semalam. Pada keesokan harinya Nabi Musa berkata kepada muridnya, ``Bawalah ke mari makanan siang kita", sampai dengan perkataannya, ``lalu ikan itu melompat mengambil jalannya ke laut dengan cara yang aneh sekali". Bekas ikan itu tampak bagaikan terowongan dan Musa beserta muridnya merasa aneh sekali dengan kejadian itu.\qt@no{65}}%
\qt@newcmd\qurantrans@id@mmccvi{%
(Musa berkata kepada Khidhir, ``Bolehkah aku mengikutimu supaya kamu mengajarkan kepadaku ilmu yang benar di antara ilmu-ilmu yang telah diajarkan kepadamu?)" yakni ilmu yang dapat membimbingku. Menurut suatu qiraat dibaca Rasyadan. Nabi Musa meminta hal tersebut kepada Khidhir. karena menambah ilmu adalah suatu hal yang dianjurkan.\qt@no{66}}%
\qt@newcmd\qurantrans@id@mmccvii{%
(Dia menjawab, ``Sesungguhnya kamu sekali-kali tidak akan sanggup sabar bersamaku").\qt@no{67}}%
\qt@newcmd\qurantrans@id@mmccviii{%
("Dan bagaimana kamu dapat bersabar atas sesuatu yang kamu belum mempunyai pengetahuan yang cukup tentang hal itu?") di dalam hadis yang telah disebutkan tadi sesudah penafsiran ayat ini disebutkan, bahwa Khidhir berkata kepada Nabi Musa, ``Hai Musa! Sesungguhnya aku telah menerima ilmu dari Allah yang Dia ajarkan langsung kepadaku; ilmu itu tidak kamu ketahui. Tetapi kamu telah memperoleh ilmu juga dari Allah yang Dia ajarkan kepadamu, dan aku tidak mengetahui ilmu itu". Lafal Khubran berbentuk Mashdar maknanya kamu tidak menguasainya, atau kamu tidak mengetahui hakikatnya.\qt@no{68}}%
\qt@newcmd\qurantrans@id@mmccix{%
(Musa berkata, ``Insya Allah kamu akan mendapati aku sebagai seorang yang sabar, dan aku tidak akan menentang) yakni tidak akan mendurhakai (kamu dalam sesuatu urusan pun)" yang kamu perintahkan kepadaku. Nabi Musa mengungkapkan jawabannya dengan menggantungkan kemampuannya kepada kehendak Allah, karena ia merasa kurang yakin akan kemampuan dirinya di dalam menghadapi apa yang harus ia lakukan. Hal ini merupakan kebiasaan para nabi dan para wali Allah, yaitu mereka sama sekali tidak pernah merasa percaya terhadap dirinya sendiri walau hanya sekejap, sepenuhnya mereka serahkan kepada kehendak Allah.\qt@no{69}}%
\qt@newcmd\qurantrans@id@mmccx{%
(Dia mengatakan, ``Jika kamu ingin mengikuti saya, maka janganlah kamu menanyakan kepada saya) Dalam satu qiraat dibaca dengan Lam berbaris fatah dan Nun bertasydid (tentang sesuatu) yang kamu ingkari menurut pengetahuanmu dan bersabarlah kamu jangan menanyakannya kepadaku (sampai aku sendiri menerangkannya kepadamu)" hingga aku menuturkan perihalnya kepadamu berikut sebab musababnya. Lalu Nabi Musa menerima syarat itu, yaitu memelihara etika dan sopan santun murid terhadap gurunya.\qt@no{70}}%
\qt@newcmd\qurantrans@id@mmccxi{%
(Maka berjalanlah keduanya) menuruti pinggir pantai (hingga tatkala keduanya menaiki perahu) yang lewat pada keduanya (lalu Khidhir melubanginya) dengan cara mencabut satu keping atau dua keping papan yang ada pada bagian lambungnya dengan memakai kapak, sewaktu perahu telah sampai di tengah laut yang ombaknya besar (Musa berkata) kepada Khidir, ("Mengapa kamu melubangi perahu itu yang akibatnya kamu menenggelamkan penumpangnya?) menurut satu qiraat lafal Litughriqa dibaca Litaghraqa, dan lafal Ahlahaa dibaca Ahluhaa. (Sesungguhnya kamu telah berbuat sesuatu kesalahan yang besar)" yakni kekeliruan yang sangat besar. Menurut suatu riwayat disebutkan, bahwa air laut tidak masuk ke dalam perahu yang telah dilubanginya itu.\qt@no{71}}%
\qt@newcmd\qurantrans@id@mmccxii{%
(Dia berkata, ``Bukankah aku telah berkata, 'Sesungguhnya kamu sekali-kali tidak akan sabar bersamaku)".\qt@no{72}}%
\qt@newcmd\qurantrans@id@mmccxiii{%
(Musa berkata, ``Janganlah kamu menghukum aku karena kelupaanku) yakni atas kealpaanku sehingga aku lupa bahwa aku harus menurutimu dan tidak membantahmu (dan janganlah kamu membebani aku) memberikan beban kepadaku (dengan sesuatu kesulitan dalam urusanku)" kerepotan dalam persahabatanku denganmu, atau dengan kata lain, perlakukanlah aku di dalam berteman denganmu dengan penuh maaf dan lapang dada.\qt@no{73}}%
\qt@newcmd\qurantrans@id@mmccxiv{%
(Maka berjalanlah keduanya) sesudah keduanya keluar dari perahu (hingga tatkala keduanya berjumpa dengan seorang pemuda) yang masih belum mencapai usia balig, sedang bermain-main bersama dengan teman-temannya, dia adalah anak yang paling cakap parasnya di antara mereka (maka Khidhir membunuhnya) dengan cara menyembelihnya dengan memakai pisau besar, atau mencabut kepalanya dengan tangannya, atau memukulkan kepala anak muda itu ke tembok. Mengenai caranya banyak pendapat yang berbeda. Dalam ayat ini didatangkan huruf Fa 'Athifah, karena pembunuhan itu terjadi langsung sesudah bertemu. Jawabnya Idzaa adalah pada ayat berikutnya yaitu; (Berkatalah ia) yakni Nabi Musa, ("Mengapa kamu bunuh jiwa yang bersih) jiwa yang masih belum berdosa karena belum mencapai usia taklif. Dan menurut suatu qiraat lafal Zakiyyatan dibaca Zakiyatan (bukan karena dia membunuh orang lain?) dia tidak membunuh orang lain. (Sesungguhnya kamu telah melakukan suatu yang mungkar)." Lafal Nukran dapat pula dibaca Nukuran, artinya sesuatu hal yang mungkar.\qt@no{74}}%
\qt@newcmd\qurantrans@id@mmccxv{%
(Khidhir berkata, ``Bukankah sudah kukatakan kepadamu, bahwa sesungguhnya kamu tidak akan dapat sabar bersamaku)" hal ini sebagai teguran yang kedua bagimu di samping teguran yang pertama tadi, dalam hal ini alasanmu tidak dapat diterima.\qt@no{75}}%
\qt@newcmd\qurantrans@id@mmccxvi{%
Oleh sebab itu maka (berkatalah Musa, ``Jika aku bertanya kepadamu tentang sesuatu sesudah ini) sesudah kali ini (maka janganlah kamu menemani aku lagi) artinya janganlah kamu mengikuti aku lagi (sesungguhnya kamu telah cukup memberikan kepadaku) dapat dibaca Ladunii atau Ladunnii, artinya dari pihakku (udzur") alasan agar aku berpisah denganmu.\qt@no{76}}%
\qt@newcmd\qurantrans@id@mmccxvii{%
(Maka keduanya berjalan; hingga tatkala keduanya sampai kepada penduduk suatu negeri) yaitu kota Inthakiyah (mereka meminta dijamu kepada penduduk negeri itu) keduanya meminta kepada mereka supaya memberi makan kepadanya sebagaimana layaknya tamu (tetapi penduduk negeri itu tidak mau menjamu mereka, kemudian keduanya mendapatkan dalam negeri itu dinding rumah) yang tingginya mencapai seratus hasta (yang hampir roboh) mengingat kemiringannya yang sangat (maka Khidhir menegakkan dinding itu) dengan tangannya sendiri (Musa berkata) kepadanya, ("Jika kamu mau, niscaya kamu mengambil) menurut suatu qiraat dibaca Laittakhadzta (upah untuk itu)" yakni persenan karena mereka tidak mau menjamu kita, sedangkan kita sangat membutuhkan makanan.\qt@no{77}}%
\qt@newcmd\qurantrans@id@mmccxviii{%
(Khidhir berkata) kepada Nabi Musa, ("Inilah perpisahan) waktu perpisahan (antara aku dengan kamu). Lafal Baina dimudhafkan kepada hal yang tidak Muta'addi atau berbilang, pengulangan lafal Baina di sini diperbolehkan karena di antara keduanya terdapat huruf 'Athaf Wawu. (Aku akan memberitahukan kepadamu) sebelum perpisahanku denganmu (tujuan perbuatan-perbuatan yang kamu tidak sabar terhadapnya).\qt@no{78}}%
\qt@newcmd\qurantrans@id@mmccxix{%
(Adapun perahu itu adalah kepunyaan orang-orang miskin) yang jumlahnya ada sepuluh orang (yang bekerja di laut) dengan menyewakannya, mereka menjadikannya sebagai mata pencaharian (dan aku bertujuan merusakkan perahu itu, karena di hadapan mereka) jika mereka kembali, atau di hadapan mereka sekarang ini (ada seorang raja) kafir (yang mengambil tiap-tiap perahu) yang masih baik (secara ghashab) yakni dengan cara merampasnya. Lafal Ghashban dinashabkan karena menjadi Mashdar yang kedudukannya menjelaskan tentang cara pengambilan itu.\qt@no{79}}%
\qt@newcmd\qurantrans@id@mmccxx{%
(Adapun anak muda itu, kedua orang tuanya adalah orang-orang Mukmin, dan kami khawatir bahwa dia akan mendorong kedua orang tuanya itu kepada kesesatan dan kekafiran), karena sesungguhnya sebagaimana yang telah disebutkan di dalam hadis sahih Muslim, bahwa anak muda itu telah dicap oleh Allah menjadi orang kafir. Dan seandainya ia hidup niscaya dia akan mendorong kedua orang tuanya kepada kekafiran, disebabkan kecintaan keduanya kepadanya, hingga keduanya pasti akan mengikuti jejak anaknya.\qt@no{80}}%
\qt@newcmd\qurantrans@id@mmccxxi{%
(Dan kami menghendaki, supaya menggantikan bagi kedua orang tuanya) dapat dibaca Yubaddilahuma atau Yubdilahuma (Rabbnya dengan anak lain yang lebih baik kesuciannya daripada anaknya itu) artinya lebih baik dan lebih bertakwa (dan lebih) daripada anaknya itu (dalam kasih sayangnya) dapat dibaca Ruhman atau Ruhuman, artinya berbakti kepada kedua orang tuanya. Ternyata sesudah itu Allah menggantikan bagi keduanya seorang anak perempuan yang kemudian dikawini oleh seorang nabi, dan dari hasil perkawinannya itu lahirlah seorang nabi. Pada akhirnya Allah memberikan petunjuk kepada suatu umat melalui nabi itu.\qt@no{81}}%
\qt@newcmd\qurantrans@id@mmccxxii{%
(Adapun dinding rumah itu adalah kepunyaan dua orang anak muda yang yatim di kota ini, dan di bawahnya ada harta benda simpanan) yakni harta yang terpendam berupa emas dan perak (bagi mereka berdua, sedangkan ayahnya adalah seorang yang saleh) maka dengan kesalehannya itu ia dapat memelihara kedua anaknya dan harta benda bagi keduanya (maka Rabbmu menghendaki agar mereka berdua sampai kepada kedewasaannya) sampai kepada usia dewasa (dan mengeluarkan simpanannya itu, sebagai rahmat dari Rabbmu). Lafal Rahmatan menjadi Maf'ul Lah, sedangkan 'Amilnya adalah lafal Araada (dan bukanlah aku melakukannya itu) yaitu semua hal yang telah disebutkan tadi, yakni melubangi perahu, membunuh anak muda dan mendirikan tembok yang hampir roboh (menurut kemauanku sendiri) berdasarkan keinginanku sendiri, tetapi hal itu kulakukan berdasarkan perintah dan ilham dari Allah. (Demikian itu adalah tujuan perbuatan-perbuatan yang kamu tidak dapat sabar terhadapnya)" lafal Tasthi' menurut pendapat lain dibaca Isthaa'a dan Istathas'a artinya mampu. Di dalam ayat ini dan ayat-ayat sebelumnya terdapat berbagai macam ungkapan, yaitu terkadang memakai istilah Aradtu (aku menghendaki); terkadang memakai istilah Aradnaa (kami menghendaki), dan terkadang memakai istilah Araada Rabbuka (Rabbmu menghendaki). Hal ini dinamakan Jam'un Bainal Lughataini atau penganekaragaman ungkapan.\qt@no{82}}%
\qt@newcmd\qurantrans@id@mmccxxiii{%
(Dan mereka akan bertanya kepadamu) yakni orang-orang yahudi (tentang Zulkarnain) yang namanya adalah Iskandar; dia bukan seorang Nabi (Katakanlah, ``Aku akan bacakan) aku akan kisahkan (kepada kalian mengenainya) tentang perihalnya (sebagai kisah)".\qt@no{83}}%
\qt@newcmd\qurantrans@id@mmccxxiv{%
(Sesungguhnya Kami telah memberi kekuasaan kepadanya di muka bumi) dengan memudahkan perjalanan baginya di muka bumi ini (dan Kami telah memberikan kepadanya di dalam menghadapi segala sesuatu) yang ia perlukan (jalan untuk mencapainya) jalan yang dapat mengantarkannya kepada yang dikehendakinya.\qt@no{84}}%
\qt@newcmd\qurantrans@id@mmccxxv{%
(Maka dia pun menempuh suatu jalan) yakni dia menempuh jalan ke arah Barat.\qt@no{85}}%
\qt@newcmd\qurantrans@id@mmccxxvi{%
(Hingga apabila dia telah sampai ke tempat terbenamnya matahari) tempat matahari terbenam (dia melihat matahari terbenam di dalam laut yang berlumpur hitam) pengertian terbenamnya matahari di dalam laut hanyalah berdasarkan pandangan mata saja, karena sesungguhnya matahari jauh lebih besar daripada dunia atau bumi (dan dia mendapati di situ) di laut itu (segolongan umat) yang kafir (Kami berkata, ``Hai Zulkarnain!) dengan melalui ilham (Kamu boleh menyiksa) kaum itu dengan cara membunuh mereka (atau boleh berbuat kebaikan terhadap mereka)" dengan hanya menawan mereka.\qt@no{86}}%
\qt@newcmd\qurantrans@id@mmccxxvii{%
(Berkata Zulkarnain, ``Adapun orang yang aniaya) yang melakukan kemusyrikan (maka kami kelak akan mengazabnya) yaitu kami akan membunuhnya (kemudian dia dikembalikan kepada Rabbnya, lalu Rabb mengazabnya dengan azab yang tiada taranya). Lafal Nukran artinya yang sangat keras, yakni azab yang sangat keras di neraka.\qt@no{87}}%
\qt@newcmd\qurantrans@id@mmccxxviii{%
(Adapun orang-orang yang beriman dan beramal saleh, maka baginya pahala yang terbaik) yakni surga; diidhafatkannya lafal Jazaa-an kepada lafal Al Husna mengandung makna penjelasan. Dan menurut qiraat yang lain lafal Jazaa-an dibaca Jazaa-u'; sehubungan dengan bacaan ini Imam Al-Farra' mengatakan bahwa dinashabkannya lafal Jazaa-an karena dianggap sebagai kalimat penafsir, maksudnya bila ditinjau dari segi nisbatnya (dan akan Kami titahkan kepadanya perintah yang mudah dari perintah-perintah Kami)" maksudnya Kami akan memberikan perintah kepadanya dengan perintah yang mudah untuk ia laksanakan.\qt@no{88}}%
\qt@newcmd\qurantrans@id@mmccxxix{%
(Kemudian ia menempuh jalan yang lain) yaitu menuju ke arah Timur.\qt@no{89}}%
\qt@newcmd\qurantrans@id@mmccxxx{%
(Hingga apabila dia telah sampai ke tempat terbitnya matahari) tempat matahari terbit (dia mendapati matahari itu menyinari segolongan umat) mereka adalah bangsa Zunuj atau orang-orang Indian (yang Kami tidak menjadikan bagi mereka dari sinarnya) yaitu dari sinar matahari (sesuatu yang melindunginya) baik berupa pakaian atau pun atap-atap. Karena sesungguhnya tanah tempat mereka tinggal tidak dapat menopang bangunan, dan mereka hanya mempunyai tempat perlindungan berupa liang-liang, di tempat tersebut mereka masuk bila matahari terbit, dan bila matahari telah tinggi baru mereka keluar dari liang-liang itu.\qt@no{90}}%
\qt@newcmd\qurantrans@id@mmccxxxi{%
(Demikianlah) perkara itu sebagaimana yang telah Kami ceritakan. (Dan sesungguhnya Kami meliputi terhadap semua apa yang ada padanya) yaitu yang ada pada Zulkarnain berupa alat-alat persenjataan, balatentara dan lain sebagainya (dengan ilmu Kami) yakni Kami mengetahui semuanya.\qt@no{91}}%
\qt@newcmd\qurantrans@id@mmccxxxii{%
(Kemudian dia menempuh suatu jalan yang lain lagi).\qt@no{92}}%
\qt@newcmd\qurantrans@id@mmccxxxiii{%
(Hingga apabila dia telah sampai di antara dua buah bendungan) dibaca Saddaini atau Suddaini, dan sesudah kedua bendungan tersebut terdapat dua buah gunung, yaitu di salah satu wilayah negeri Turki. Bendungan raja Iskandar akan dibangun di antara kedua buah bukit itu, sebagaimana yang akan dijelaskan nanti (dia mendapati di hadapan kedua bendungan itu) yakni pada sebelah depan keduanya (suatu kaum yang hampir tidak mengerti pembicaraan) mereka tidak dapat memahami pembicaraan melainkan secara lambat sekali. Menurut qiraat yang lain lafal Yafqahuuna dibaca Yufqihuuna.\qt@no{93}}%
\qt@newcmd\qurantrans@id@mmccxxxiv{%
(Mereka berkata, ``Hai Zulkarnain! Sesungguhnya Yakjuj dan Makjuj itu) dikenal dengan nama Yakjuj dan Makjuj. Kedua nama tersebut merupakan nama 'Ajam bagi dua kabilah, dengan demikian maka I'rabnya tidak menerima tanwin (orang-orang yang membuat kerusakan di muka bumi) mereka gemar merampok dan membuat kerusakan di kala mereka keluar dari sarangnya menuju kami (maka dapatkah kami memberikan sesuatu pembayaran kepadamu) yakni upah berupa harta; dan menurut qiraat yang lain lafal Kharjan dibaca Kharaajan (supaya kamu membuat dinding antara kami dan mereka?)" tembok penghalang hingga mereka tidak dapat mencapai kami.\qt@no{94}}%
\qt@newcmd\qurantrans@id@mmccxxxv{%
(Zulkarnain berkata, ``Apa yang telah dikuasakan kepadaku) menurut qiraat yang lain lafal Makkannii dibaca Makkananii tanpa diidghamkan (oleh Rabbku terhadapnya) terhadap harta benda dan lain-lainnya (adalah lebih baik) daripada pembayaran kalian yang akan kalian berikan kepadaku, maka aku tidak memerlukannya lagi, dan aku akan membuat tembok penghalang buat kalian sebagai sumbangan suka rela dariku sendiri (maka tolonglah aku dengan kekuatan) apa saja yang aku perlukan dari kalian (agar aku membuatkan dinding antara kamu dan mereka) yakni tembok penghalang yang kuat dan tak dapat ditembus.\qt@no{95}}%
\qt@newcmd\qurantrans@id@mmccxxxvi{%
(Berilah aku potongan-potongan besi)" sebesar bata kecil yang akan dijadikan sebagai bahan bangunan tembok lalu Zulkarnain membangun tembok penghalang itu daripadanya, dan dia memakai kayu dan batu bara yang dimasukkan di tengah-tengah tembok besi itu. (Sehingga apabila besi itu telah sama rata dengan kedua puncak gunung itu) lafal Shadafaini dapat dibaca Shudufaini dan Shudfaini, artinya sisi bagian puncak kedua bukit itu telah rata dengan bangunan, kemudian dibuatkannyalah peniup-peniup dan api sepanjang bangunan tembok itu (berkatalah Zulkarnain, ``Tiuplah api itu)" lalu api itu mereka tiup (Hingga apabila besi itu menjadi) berubah bentuknya menjadi (merah) bagaikan api (dia pun berkata, ``Berilah aku tembaga yang mendidih agar kutuangkan ke atas besi panas itu)" maksudnya tembaga yang dilebur. Lafal Aatuunii dan lafal Ufrigh merupakan kedua Fi'il yang saling berebutan terhadap Ma'mulnya, kemudian dibuanglah Ma'mul dari Fi'il yang pertama karena beramalnya Fi'il yang kedua. Selanjutnya tembaga yang sudah dilebur itu dituangkan ke atas besi yang merah membara, sehingga masuklah tembaga itu ke dalam partikel-partikel potongan besi, akhirnya kedua logam itu menyatu.\qt@no{96}}%
\qt@newcmd\qurantrans@id@mmccxxxvii{%
(Maka mereka tidak dapat) yakni Yakjuj dan Makjuj itu (mendakinya) memanjat tembok itu karena terlalu tinggi dan terlalu licin (dan mereka tidak dapat pula melubanginya) karena tembok itu terlalu kuat dan tebal sekali.\qt@no{97}}%
\qt@newcmd\qurantrans@id@mmccxxxviii{%
(Dia berkata) yakni Zulkarnain, ("Ini) tembok ini atau bendungan ini, atau kemampuan di dalam membangun ini (adalah rahmat dari Rabbku) merupakan nikmat-Nya, sebab tembok ini dapat mencegah Yakjuj dan Makjuj untuk keluar (maka apabila sudah datang janji Rabbku) yakni saat mereka dapat keluar, bila hari kiamat telah dekat. (Dia akan menjadikannya hancur luluh) rata dengan tanah (dan janji Rabbku itu) tentang keluarnya mereka dan peristiwa-peristiwa lainnya (adalah benar)" pasti terjadi.\qt@no{98}}%
\qt@newcmd\qurantrans@id@mmccxxxix{%
Selanjutnya Allah berfirman: (Kami biarkan sebagian di antara mereka pada hari itu) pada hari mereka keluar dari tembok itu (bercampur aduk dengan sebagian yang lain) mereka bercampur aduk karena saking banyaknya jumlah mereka (kemudian ditiup lagi sangkakala) untuk membangkitkan mereka menjadi hidup kembali (lalu Kami kumpulkan mereka itu) yakni seluruh makhluk pada suatu tempat di hari kiamat (semuanya).\qt@no{99}}%
\qt@newcmd\qurantrans@id@mmccxl{%
(Dan Kami tampakkan) Kami dekatkan (Jahanam pada hari itu kepada orang-orang kafir dengan jelas).\qt@no{100}}%
\qt@newcmd\qurantrans@id@mmccxli{%
(Yaitu orang-orang yang matanya) menjadi Badal atau kata ganti dari lafal Al-Kaafiriina yang pada ayat sebelumnya (dalam keadaan tertutup dari memperhatikan ayat-yat-Ku) yakni Alquran, karenanya mereka buta tidak dapat mengambil petunjuk darinya (dan adalah mereka tidak sanggup mendengar) artinya, mereka tidak mampu untuk mendengarkan dari nabi apa yang telah dibacakan kepada mereka, karena mereka membencinya, oleh sebab itu mereka tidak beriman kepadanya.\qt@no{101}}%
\qt@newcmd\qurantrans@id@mmccxlii{%
(Maka apakah orang-orang kafir menyangka bahwa mereka dapat mengambil hamba-hamba-Ku) yakni para Malaikat-Ku, Nabi 'Isa dan Nabi 'Uzair (menjadi penolong-penolong selain Aku?) yakni tuhan-tuhan yang dapat menolong mereka. Lafal Auliyaa-a ini menjadi Maf'ul Tsani daripada lafal Liyattakhidzuu, sedangkan Maf'ul Tsani daripada lafal Hasiba tidak disebutkan. Maksud ayat: Apakah mereka menyangka bahwa pengambilan mereka terhadap hal-hal yang telah disebutkan itu sebagai sesembahan mereka tidak membuat-Ku murka, dan Aku hanya berdiam diri tidak menghukum mereka? Tentu saja tidak. (Sesungguhnya Kami telah menyediakan neraka Jahanam bagi orang-orang kafir) yaitu bagi mereka dan bagi orang-orang kafir lainnya yang seperti mereka (sebagai tempat tinggal) maksudnya Jahanam itu telah disediakan buat mereka sebagaimana disediakannya tempat tinggal bagi tamu.\qt@no{102}}%
\qt@newcmd\qurantrans@id@mmccxliii{%
(Katakanlah, ``Apakah akan Kami beritahukan kepada kalian tentang orang-orang yang paling merugi perbuatannya?)" lafal A'maalan menjadi Tamyiz atau keterangan pembeda yang bentuknya sama dengan Mumayyaz. Kemudian Allah swt. menjelaskan siapa mereka yang merugi itu, melalui firman berikutnya.\qt@no{103}}%
\qt@newcmd\qurantrans@id@mmccxliv{%
(Yaitu orang-orang yang telah sia-sia perbuatannya dalam kehidupan dunia ini) amal perbuatan mereka batil tidak diterima (sedangkan mereka menyangka) menduga (bahwa mereka berbuat sebaik-baiknya) yang pasti mereka akan menerima pahala karenanya.\qt@no{104}}%
\qt@newcmd\qurantrans@id@mmccxlv{%
(Mereka itu orang-orang yang kafir terhadap ayat-ayat Rabb mereka) kafir terhadap bukti-bukti yang menunjukkan kepada keesaan-Nya, baik berupa Alquran maupun lain-lainnya (dan kafir terhadap perjumpaan dengan Dia) ingkar pada adanya hari berbangkit, perhitungan amal perbuatan, pahala dan siksaan (maka hapuslah amalan-amalan mereka) yakni ditolak (dan Kami tidak mengadakan suatu penilaian bagi amalan mereka pada hari kiamat) Kami tidak menganggap sama sekali amal perbuatan mereka.\qt@no{105}}%
\qt@newcmd\qurantrans@id@mmccxlvi{%
(Demikianlah) yakni perihal yang telah Kusebutkan sehubungan dengan dihapusnya amal perbuatan mereka dan lain-lainnya. Lafal Dzaalika menjadi Mubtada sedangkan Khabarnya ialah: (balasan mereka itu neraka Jahanam, disebabkan kekafiran mereka dan disebabkan mereka menjadikan ayat-ayat-Ku dan Rasul-rasul-Ku sebagai olok-olok) keduanya menjadi ejekan dan olokan mereka.\qt@no{106}}%
\qt@newcmd\qurantrans@id@mmccxlvii{%
(Sesungguhnya orang-orang yang beriman dan beramal saleh, bagi mereka) menurut ilmu Allah (adalah surga Firdaus) yaitu bagian tengah dan bagian teratas daripada surga. Idhafah di sini memberikan pengertian Bayan atau menjelaskan (menjadi tempat tinggal) tempat menetap mereka.\qt@no{107}}%
\qt@newcmd\qurantrans@id@mmccxlviii{%
(Mereka kekal di dalamnya, mereka tidak ingin) tidak meminta (berpindah daripadanya) pindah ke tempat yang lain.\qt@no{108}}%
\qt@newcmd\qurantrans@id@mmccxlix{%
(Katakanlah, ``Kalau sekiranya lautan) airnya (menjadi tinta) yaitu sarana untuk menulis (untuk menulis kalimat-kalimat Rabbku) yang menunjukkan kepada kebijaksanaan-kebijaksanaan dan keajaiban-keajaiban ciptaan-Nya, seumpamanya hal itu ditulis (sungguh habislah lautan itu) untuk menulisnya (sebelum habis) dapat dibaca Tanfadza atau Yanfadza, yakni sebelum habis ditulis (kalimat-kalimat Rabbku, meskipun Kami datangkan sebanyak itu) lautan yang sama (sebagai tambahan tintanya.") niscaya tambahan ini pun akan habis pula, sedangkan kalimat-kalimat Rabbku masih belum habis ditulis. Lafal Madadan dinashabkan karena menjadi Tamyiz.\qt@no{109}}%
\qt@newcmd\qurantrans@id@mmccl{%
(Katakanlah, ``Sesungguhnya aku ini hanyalah seorang manusia) anak Adam (seperti kalian, yang diwahyukan kepadaku, 'Bahwa sesungguhnya Rabb kalian itu adalah Tuhan Yang Esa.') huruf Anna di sini Maktufah atau dicegah untuk beramal oleh sebab adanya Ma, sedangkan huruf Ma masih tetap status Mashdarnya. Maksudnya; yang diwahyukan kepadaku mengenai keesaan Tuhan (Barang siapa mengharap) bercita-cita (perjumpaan dengan Rabbnya) setelah dibangkitkan dan menerima pembalasan (maka hendaklah ia mengerjakan amal yang saleh dan janganlah ia mempersekutukan di dalam beribadah kepada Rabbnya) yakni sewaktu ia beribadah kepada-Nya, seumpamanya ia hanya ingin pamer (dengan seorang pun").\qt@no{110}}%
\qt@newcmd\qurantrans@id@mmccli{%
\basmalahid (Kaf Ha Ya 'Ain Shad) hanya Allah yang mengetahui maksudnya.\qt@no{1}}%
\qt@newcmd\qurantrans@id@mmcclii{%
Ini adalah (penjelasan tentang rahmat Rabb kamu kepada hamba-Nya) lafal 'abdahu menjadi Maf'ul dari Rahmah (Zakaria) sebagai penjelasan dari kata 'hamba' tadi.\qt@no{2}}%
\qt@newcmd\qurantrans@id@mmccliii{%
(Yaitu tatkala) lafal Idz berta'alluq kepada lafal Rahmah (ia berdoa kepada Rabbnya dengan seruan) yang mengandung doa (yang lembut) dengan suara yang pelan-pelan di tengah malam, karena berdoa di tengah malam itu lebih cepat untuk dikabulkan.\qt@no{3}}%
\qt@newcmd\qurantrans@id@mmccliv{%
(Ia berkata, ``Ya Rabbku! Sesungguhnya telah lemah) menjadi lemah (tulang-tulangku) semuanya (dan kepala ini telah dipenuhi) (oleh uban) lafal Syaiban menjadi Tamyiz yang dipindahkan dari Fa'ilnya, maksudnya uban telah merata di rambut kepalanya sebagaimana meratanya nyala api pada kayu dan sesungguhnya aku bermaksud berdoa kepada-Mu (dan aku belum pernah dengan doaku kepada-Mu) (merasa kecewa, ya Rabbku!) artinya, merasa dikecewakan di masa-masa lalu; maka janganlah Engkau kecewakan aku di masa mendatang.\qt@no{4}}%
\qt@newcmd\qurantrans@id@mmcclv{%
(Dan sesungguhnya aku khawatir terhadap mawaliku) yakni orang-orang dekat hubungan familinya denganku seperti anak-anak paman (sepeninggalku) yakni sesudah aku meninggal dunia, aku khawatir mereka akan menyia-nyiakan agama sebagaimana yang telah kusaksikan sendiri apa yang terjadi di kalangan orang-orang Bani Israel, yaitu mereka berani mengubah agamanya (sedangkan istriku adalah seorang yang mandul) tidak beranak (maka anugerahilah aku dari sisi Engkau) (seorang putra) anak lelaki.\qt@no{5}}%
\qt@newcmd\qurantrans@id@mmcclvi{%
(Yang akan mewarisi aku) kalau dibaca Jazm berarti lafal Yaritsni menjadi jawab dari Fi'il Amar, dan kalau dibaca Rafa' yaitu Yaritsuni berarti menjadi kata sifat dari lafal Waliyyan (dan mewarisi) dapat dibaca Yaritsu atau Yarits (sebagian keluarga Ya'qub) kakekku dalam hal ilmu dan kenabian (dan jadikanlah ia, ya Rabbku, seorang yang diridai)" di sisi Engkau.\qt@no{6}}%
\qt@newcmd\qurantrans@id@mmcclvii{%
(Hai Zakaria, sesungguhnya Kami memberi kabar gembira kepadamu akan beroleh seorang anak) yang akan menjadi waris, sebagaimana yang kamu minta (yang namanya Yahya, yang sebelumnya Kami tidak pernah menciptakan orang yang serupa dengan dia) dalam hal namanya, yakni seseorang yang diberi nama Yahya.\qt@no{7}}%
\qt@newcmd\qurantrans@id@mmcclviii{%
(Zakaria berkata, ``Ya Rabbku! Bagaimana) mana mungkin (akan ada anak bagiku, padahal istriku adalah seorang yang mandul dan aku sendiri sesungguhnya sudah mencapai umur yang sangat tua)" lafal 'itiyyan berasal dari lafal 'Ataa artinya Yabisa atau kering, maksudnya ia telah mencapai umur seratus dua puluh tahun, dan istrinya telah mencapai umur sembilan puluh delapan tahun. Kata 'Itiyyun pada asalnya adalah 'Ituwwun. Kemudian huruf Ta dikasrahkan untuk meringankan pengucapannya lalu jadilah 'Itiwwun. Selanjutnya huruf Wawu yang pertama diganti menjadi huruf Ya demi penyesuaian dengan harakat Kasrah sebelumnya, dan huruf Wawu yang kedua diganti pula dengan huruf Ya supaya huruf Ya yang pertama dapat diidgamkan atau dimasukkan kepadanya, sehingga jadilah 'Itiyyun.\qt@no{8}}%
\qt@newcmd\qurantrans@id@mmcclix{%
(Allah berfirman) perkaranya memang ("Demikianlah.") cara menciptakan seorang anak lelaki dari kamu berdua (Rabbmu berfirman, ``Hal itu adalah mudah bagi-Ku) yaitu dengan memberikan kekuatan bersetubuh kepadamu, kemudian menjadikan rahim istrimu dapat menerima spermamu (dan sesungguhnya telah Aku ciptakan kamu sebelum itu, padahal kamu belum ada sama sekali)" di waktu kamu belum diciptakan. Untuk menampilkan kekuasaan Allah yang mampu menciptakan hal yang besar ini, maka Dia memberikan ilham suatu pertanyaan, supaya pertanyaan itu kelak dijawab dengan hal yang membuktikan kekuasaan-Nya yang maha besar itu. Tatkala Zakaria merasa rindu akan kedatangan berita gembira kelahiran seorang putra itu.\qt@no{9}}%
\qt@newcmd\qurantrans@id@mmcclx{%
(Zakaria berkata, ``Ya Rabbku! Berilah aku suatu tanda)" pertanda yang menunjukkan istriku mulai mengandung (Allah berfirman, ``Tanda bagimu) yang menunjukkan hal itu (adalah bahwa kamu tidak boleh bercakap-cakap dengan manusia) mencegah dirimu untuk tidak berbicara dengan mereka selain dari berzikir kepada Allah (selama tiga malam) yakni tiga hari tiga malam (padahal kamu sehat)" lafal Sawiyyan berkedudukan menjadi Hal dari Fa'il lafal Takallama, maksudnya ia tidak berbicara dengan mereka tanpa sebab.\qt@no{10}}%
\qt@newcmd\qurantrans@id@mmcclxi{%
(Maka ia keluar dari mihrab menuju kaumnya) yakni dari mesjid, sedang orang-orang menunggu pintu mesjid itu dibuka, karena mereka hendak melakukan salat di dalamnya, sesuai dengan kebiasaan mereka menurut perintah Zakaria (lalu ia memberi isyarat) (kepada mereka; hendaklah kalian bertasbih) maksudnya melakukan salat (di waktu pagi dan petang) yakni pada permulaan siang hari dan akhirnya, sebagaimana biasa. Setelah Nabi Zakaria mencegah dirinya untuk bercakap-cakap dengan mereka, pada saat itu diketahui bahwa istrinya mengandung Yahya. Selang dua tahun kemudian setelah Yahya lahir, Allah berfirman kepadanya.\qt@no{11}}%
\qt@newcmd\qurantrans@id@mmcclxii{%
(Hai Yahya! Ambillah Kitab itu) yakni kitab Taurat (dengan sungguh-sungguh) secara sungguh-sungguh. (Dan Kami berikan kepadanya hikmah) kenabian (selagi ia masih kanak-kanak) sewaktu berumur tiga tahun.\qt@no{12}}%
\qt@newcmd\qurantrans@id@mmcclxiii{%
(Dan rasa belas kasihan yang mendalam) terhadap manusia (dari sisi Kami) dari haribaan Kami (dan zakat) yakni senang bersedekah kepada mereka (Dan ia adalah seorang yang bertakwa) menurut suatu riwayat disebutkan, bahwa Nabi Yahya tidak pernah melakukan suatu dosa pun, dan hatinya tidak pernah mempunyai keinginan untuk melakukannya.\qt@no{13}}%
\qt@newcmd\qurantrans@id@mmcclxiv{%
(Dan seorang yang berbakti kepada kedua orang tuanya) yaitu selalu berbuat baik kepada keduanya (dan bukanlah ia orang yang sombong) takabur (lagi bukan pula ia orang yang durhaka) terhadap Rabbnya.\qt@no{14}}%
\qt@newcmd\qurantrans@id@mmcclxv{%
(Kesejahteraan) dari Kami (terlimpahkan kepadanya pada hari ia dilahirkan dan pada hari ia meninggal dan pada hari ia dibangkitkan hidup kembali) di saat-saat yang mengerikan yakni hari kiamat. Pada hari itu belum pernah ada pemandangan yang sengeri itu, maka Nabi Yahya selamat daripadanya.\qt@no{15}}%
\qt@newcmd\qurantrans@id@mmcclxvi{%
(Dan ceritakanlah di dalam Kitab) yakni Alquran (tentang Maryam) kisahnya (yaitu ketika) (ia menjauhkan diri dari keluarganya ke suatu tempat di sebelah Timur) Maryam mengasingkan diri di suatu tempat di sebelah Timur rumahnya.\qt@no{16}}%
\qt@newcmd\qurantrans@id@mmcclxvii{%
(Maka ia mengadakan tabir yang menutupinya dari mereka) Maryam membuat tabir untuk melindungi dirinya sewaktu ia membuka penutup kepalanya, atau membuka pakaiannya atau menyucikan dirinya dari haid (lalu Kami mengutus kepadanya roh Kami) yakni malaikat Jibril (maka ia menjelma di hadapannya) sesudah Maryam memakai pakaiannya (dalam bentuk manusia yang sempurna) manusia sesungguhnya.\qt@no{17}}%
\qt@newcmd\qurantrans@id@mmcclxviii{%
(Maryam berkata, ``Sesungguhnya aku berlindung daripadamu kepada Tuhan Yang Maha Pemurah, jika kamu seorang yang bertakwa.") kamu pasti dapat menahan diri daripadaku dengan bacaan Ta'awwudzku ini.\qt@no{18}}%
\qt@newcmd\qurantrans@id@mmcclxix{%
(Ia berkata, ``Sesungguhnya aku ini adalah utusan Rabbmu, untuk memberimu seorang anak laki-laki yang suci)" yang kelak menjadi nabi.\qt@no{19}}%
\qt@newcmd\qurantrans@id@mmcclxx{%
(Maryam berkata, ``Bagaimana akan ada bagiku seorang anak laki-laki, sedangkan tidak pernah seorang manusia pun menyentuhku) yakni mengawiniku (dan aku bukan pula seorang pezina!)" seorang pelacur.\qt@no{20}}%
\qt@newcmd\qurantrans@id@mmcclxxi{%
(Jibril berkata,) perkaranya memang ("Demikianlah.") yaitu akan diciptakan bagimu seorang anak laki-laki tanpa ayah (Rabbmu berfirman, ``Hal itu adalah mudah bagi-Ku) yaitu dengan cara Aku memerintahkan kepada malaikat Jibril supaya meniup dirimu, lalu karena itu kamu mengandung. Mengingat kalimat yang telah disebutkan mengandung makna illat atau kausalita, maka kalimat berikutnya di'athafkan kepadanya, yaitu (dan agar dapat Kami menjadikannya suatu tanda bagi manusia) yang menunjukkan akan kekuasaan-Ku (dan sebagai rahmat dari Kami) bagi orang-orang yang beriman kepadanya (dan hal itu adalah) penciptaan itu merupakan (suatu perkara yang sudah diputuskan)" di dalam ilmu-Ku, malaikat Jibril meniupkan nafasnya ke dalam baju kurung Maryam, seketika itu juga Maryam merasakan di dalam kandungannya terdapat seorang bayi.\qt@no{21}}%
\qt@newcmd\qurantrans@id@mmcclxxii{%
(Maka Maryam mengandungnya, lalu ia mengasingkan diri) menjauhkan diri (dengan membawa kandungannya ke tempat yang jauh) jauh dari keluarganya.\qt@no{22}}%
\qt@newcmd\qurantrans@id@mmcclxxiii{%
(Maka sewaktu datang kepadanya) ketika ia mengalami (rasa sakit akan melahirkan) yaitu rasa mulas karena akan melahirkan (-terpaksa ia bersandar- pada pangkal pohon kurma) yakni menyandarkan diri padanya, lalu ia melahirkan. Perlu diketahui bahwa sejak peniupan malaikat Jibril hingga melahirkan hanya memakan waktu sesaat saja (dia berkata, ``Aduhai alangkah baiknya aku) lafal Ya di sini menunjukkan makna Tanbih atau ungkapan kekecewaan (mati sebelum ini) yakni sebelum perkara ini (dan aku menjadi barang yang tidak berarti, lagi dilupakan)" sebagai sesuatu yang tiada artinya, tidak dikenal dan tidak disebut-sebut.\qt@no{23}}%
\qt@newcmd\qurantrans@id@mmcclxxiv{%
(Maka Jibril menyerunya dari tempat yang lebih rendah,) pada saat itu malaikat Jibril berada di tempat yang lebih rendah dari tempat Maryam ("Janganlah kamu bersedih hati, sesungguhnya Rabbmu telah menjadikan anak sungai di bawahmu") yaitu sebuah sungai yang dahulunya kering kini berair kembali, berkat kekuasaan Allah.\qt@no{24}}%
\qt@newcmd\qurantrans@id@mmcclxxv{%
(Dan goyanglah pangkal pohon kurma itu ke arahmu) yang pada saat itu kering. Huruf Ba dalam lafal Bijidz'i adalah Zaidah atau tambahan (niscaya pohon itu akan menggugurkan) asal kata Tusaaqith adalah Tatasaaqath kemudian Ta yang kedua diganti menjadi Sin, selanjutnya diidgamkan pada Sin yang kedua. Menurut qiraat yang lain tetap dibaca seperti lafal asalnya (buah kurma kepadamu) lafal Ruthaban adalah Tamyiz (yang masak-masak) lafal Janiyyan menjadi sifat dari lafal Ruthaban.\qt@no{25}}%
\qt@newcmd\qurantrans@id@mmcclxxvi{%
(Maka makanlah) dari buah kurma yang masak itu (dan minumlah) dari air sungai kecil itu (serta bersenang hatilah kamu) dengan anakmu itu. Lafal 'Ainan berfungsi sebagai Tamyiz yang dipindahkan dari Fa'ilnya, maksudnya selamat bersenang hati dengan anakmu itu. Atau dengan kata lain, kamu menjadi tenang dengan adanya anakmu itu sehingga kamu tidak memikirkan hal-hal yang lain. (Jika) lafal Immaa ini pada asalnya terdiri dari In Syarthiyah dan Ma Zaidah yang kemudian diidgamkan menjadi satu hingga menjadi Immaa (kamu melihat) dan lafal Tarayinna terbuang huruf Lam Fi'il dan 'Ain Fi'ilnya, kemudian harakat 'Ain Fi'ilnya dipindahkan pada huruf Ra, selanjutnya Ya Dhamir dikasrahkan karena bertemu dua sukun, sehingga jadilah Tarayinna (seorang manusia) kemudian ia menanyakan kepadamu tentang anakmu itu (maka katakanlah, ``Sesungguhnya aku bernazar shaum untuk Tuhan Yang Maha Pemurah) dengan menahan diri untuk tidak berbicara, baik mengenai perihal anaknya atau orang-orang lainnya, hal ini terbukti dengan perkataan selanjutnya (maka aku tidak akan berkata dengan seorang manusia pun pada hari ini)" sesudah kejadian ini.\qt@no{26}}%
\qt@newcmd\qurantrans@id@mmcclxxvii{%
(Maka Maryam membawa anak itu kepada kaumnya dengan menggendongnya) lafal Tahmiluhu menjadi Hal atau kata keterangan keadaan. Sehingga kaumnya melihat anak itu (Kaumnya berkata, ``Hai Maryam! Sesungguhnya kamu telah melakukan sesuatu yang amat mungkar) suatu dosa yang sangat besar karena kamu memperoleh anak tanpa ayah.\qt@no{27}}%
\qt@newcmd\qurantrans@id@mmcclxxviii{%
(Hai saudara perempuan Harun!) dia adalah seorang lelaki yang saleh, hal ini berarti Maryam pun serupa dengannya dalam hal memelihara kehormatan (Ayahmu sekali-kali bukanlah seorang yang buruk) bukan seorang pezina (dan ibumu sekali-kali bukanlah seorang pelacur)" bukan pula seorang pezina, maka dari manakah anak ini.\qt@no{28}}%
\qt@newcmd\qurantrans@id@mmcclxxix{%
(Maka Maryam mengisyaratkan) kepada kaumnya (-seraya menunjuk- kepada anaknya) maksudnya supaya mereka bertanya kepada anaknya. (Mereka berkata, ``Bagaimana kami akan berbicara dengan anak) yang masih (kecil berada dalam ayunan?)".\qt@no{29}}%
\qt@newcmd\qurantrans@id@mmcclxxx{%
(Isa berkata, ``Sesungguhnya aku ini hamba Allah, Dia memberiku Alkitab) yakni kitab Injil (dan Dia menjadikan aku seorang nabi).\qt@no{30}}%
\qt@newcmd\qurantrans@id@mmcclxxxi{%
(Dan Dia menjadikan aku seorang yang diberkati di mana saja aku berada) maksudnya Dia menjadikan diriku orang yang banyak memberi manfaat kepada manusia. Ungkapan ini merupakan berita tentang kedudukan yang telah dipastikan baginya (dan Dia memerintahkan kepadaku mendirikan salat dan menunaikan zakat) Allah memerintahkan kepadaku untuk melakukan kedua hal tersebut (selama aku hidup).\qt@no{31}}%
\qt@newcmd\qurantrans@id@mmcclxxxii{%
(Dan berbakti kepada ibuku) lafal Barran dinashabkan oleh lafal Ja'alani yang keberadaannya diperkirakan, maksudnya, Dia menjadikan aku sebagai orang yang berbakti kepada ibuku (dan Dia tidak menjadikan aku seorang yang sombong) orang yang merasa tinggi diri (lagi celaka) yang durhaka kepada Rabbnya.\qt@no{32}}%
\qt@newcmd\qurantrans@id@mmcclxxxiii{%
(Dan kesejahteraan) dari Allah (semoga dilimpahkan kepadaku, pada hari aku dilahirkan, pada hari aku meninggal dan pada hari aku dibangkitkan hidup kembali)" hal ini telah dikatakan pada kisah yang lalu, yaitu dalam doa Nabi Yahya.\qt@no{33}}%
\qt@newcmd\qurantrans@id@mmcclxxxiv{%
(Itulah Isa putra Maryam, yang mengatakan perkataan yang benar) jika lafal Alqaul dibaca Rafa', berarti menjadi Khabar dari Mubtada yang diperkirakan keberadaannya, maksudnya, perkataan Isa bin Maryam adalah perkataan yang benar. Kalau dibaca Nashab berarti ada lafal Qultu yang diperkirakan keberadaannya sebelumnya, maksudnya Aku mengatakan perkataan yang benar (yang mereka berbantah-bantahan tentang kebenarannya) lafal Yamtaruuna berasal dari kata Al Miryah; mereka meragukan kebenarannya, mereka adalah orang-orang Nasrani; mereka mengatakan perkataan yang dusta, yaitu, ``Sesungguhnya Isa itu adalah anak Allah".\qt@no{34}}%
\qt@newcmd\qurantrans@id@mmcclxxxv{%
(Tidak layak bagi Allah mempunyai anak, Maha Suci Dia) dari hal tersebut. (Apabila Dia telah menetapkan sesuatu) yakni, Dia berkehendak untuk menciptakannya (maka Dia hanya berkata kepadanya, ``Jadilah" maka jadilah dia) kalau dibaca Rafa' yaitu Yakuunu berarti ada lafal Huwa atau dia yang diperkirakan keberadaannya, kalau dibaca Nashab yaitu berarti dengan memperkirakan lafal An sebelumnya. Oleh sebab itu maka Nabi Isa diciptakan tanpa ayah.\qt@no{35}}%
\qt@newcmd\qurantrans@id@mmcclxxxvi{%
(Sesungguhnya Allah adalah Rabbku dan Rabb kalian, maka sembahlah Dia) jika dibaca Anna maka dengan memperkirakan keberadaan lafal Udzkur, maksudnya: Ingatlah, sesungguhnya Allah dan seterusnya. Jika dibaca Kasrah yaitu Inna maka dengan memperkirakan keberadaan lafal Qul sebelumnya, maksudnya: Katakanlah, sesungguhnya Allah; hal ini dibuktikan oleh firman lainnya, yaitu: Aku tidak pernah mengatakan kepada mereka melainkan apa yang Engkau perintahkan kepadaku untuk mengatakannya, yaitu, ``Sembahlah Allah, Rabbku dan Rabb kalian." (Q.S. Al-Maidah, 117). (ini) hal yang telah disebutkan tadi (adalah jalan) penuntun (yang lurus) yang dapat mengantarkan ke surga.\qt@no{36}}%
\qt@newcmd\qurantrans@id@mmcclxxxvii{%
(Maka berselisihlah golongan-golongan yang ada di antara mereka) yakni orang-orang Nasrani, yaitu sehubungan dengan perihal Isa, apakah dia anak Allah, atau tuhan di samping Allah, ataukah tuhan yang ketiga. (Maka kecelakaanlah) azab yang sangat keras (bagi orang-orang kafir) disebabkan apa yang telah disebutkan tadi dan hal-hal lainnya (pada waktu menyaksikan hari yang besar) yakni kehadiran mereka di hari kiamat dan kengerian-kengerian yang terjadi pada waktu itu.\qt@no{37}}%
\qt@newcmd\qurantrans@id@mmcclxxxviii{%
(Alangkah terangnya pendengaran mereka dan alangkah tajamnya penglihatan mereka) kedua lafal ini merupakan Shighat atau ungkapan rasa takjub, maknanya sama dengan lafal Ma Asma'ahum dan Ma Absharahum (pada hari mereka datang kepada Kami) di akhirat kelak. (Tetapi orang-orang yang zalim) menurut ungkapan meletakkan isim Zhahir pada tempat isim Mudhmar' (pada hari ini) yakni di dunia (berada dalam kesesatan yang nyata) nyata kesesatannya, disebabkan mereka tuli tidak mau mendengarkan perkara yang hak, dan mereka buta tidak mau melihat yang benar. Maksudnya, hai orang yang diajak bicara sepatutnya kamu merasa takjub dan heran terhadap pendengaran dan penglihatan mereka di akhirat, sesudah di dunia mereka tuli dan buta.\qt@no{38}}%
\qt@newcmd\qurantrans@id@mmcclxxxix{%
(Dan berilah mereka peringatan) takut-takutilah hai Muhammad, orang-orang kafir Mekah itu (tentang hari penyesalan) yaitu hari kiamat sewaktu orang yang berbuat jahat merasa menyesal sekali karena tidak mau berbuat kebaikan di dunia (yaitu ketika segala perkara telah diputus) bagi mereka di hari kiamat, yaitu mereka harus menerima azab (Dan mereka) di dunia (dalam kelalaian) tentang hari penyesalan itu (dan mereka tidak pula beriman) kepada adanya hari penyesalan itu.\qt@no{39}}%
\qt@newcmd\qurantrans@id@mmccxc{%
(Sesungguhnya Kami) lafal Nahnu berfungsi sebagai Taukid atau kata pengukuh (mewarisi bumi dan semua orang-orang yang ada di dalamnya) baik yang berakal maupun yang lainnya, yaitu dengan membinasakan mereka (dan hanya kepada Kamilah mereka dikembalikan) pada hari kiamat untuk menerima pembalasan.\qt@no{40}}%
\qt@newcmd\qurantrans@id@mmccxci{%
(Dan ceritakanlah) kepada mereka (tentang Ibrahim di dalam Al-Kitab ini) Alquran, yaitu tentang kisahnya. (Sesungguhnya ia adalah seorang yang sangat membenarkan) seorang yang sangat jujur dalam keimanannya (lagi seorang nabi) hal ini dijelaskan dalam ayat selanjutnya.\qt@no{41}}%
\qt@newcmd\qurantrans@id@mmccxcii{%
(Yaitu ketika ia berkata kepada bapaknya) yang bernama Azar, ("Wahai bapakku!) huruf Ta pada lafal Abati ganti dari Ya Idhafah, karena keduanya tidak dapat dikumpulkan menjadi satu. Azar adalah penyembah berhala (Mengapa kamu menyembah sesuatu yang tidak mendengar, tidak melihat dan tidak dapat menolong kamu) tidak dapat mencukupimu (sedikit pun?) baik berupa manfaat maupun bahaya.\qt@no{42}}%
\qt@newcmd\qurantrans@id@mmccxciii{%
(Wahai bapakku! Sesungguhnya telah datang kepadaku sebagian ilmu pengetahuan yang tidak datang kepadamu, maka ikutilah aku, niscaya aku akan menunjukkan kepadamu jalan) penuntun (yang lurus) tidak menyimpang dari kebenaran.\qt@no{43}}%
\qt@newcmd\qurantrans@id@mmccxciv{%
(Wahai bapakku! Janganlah kamu menyembah setan) dengan ketaatanmu kepadanya, yaitu menyembah berhala. (Sesungguhnya setan itu durhaka kepada Tuhan Yang Maha Pemurah) yang banyak durhakanya.\qt@no{44}}%
\qt@newcmd\qurantrans@id@mmccxcv{%
(Wahai bapakku! Sesungguhnya aku khawatir bahwa kamu akan ditimpa azab dari Tuhan Yang Maha Pemurah) jika kamu tidak bertobat (maka kamu menjadi kawan bagi setan)" yaitu menjadi penolong dan temannya di neraka.\qt@no{45}}%
\qt@newcmd\qurantrans@id@mmccxcvi{%
(Bapaknya berkata, ``Bencikah kamu kepada tuhan-tuhanku, hai Ibrahim?) maka sebab itu kamu mencelanya. (Jika kamu tidak berhenti) mencaci makinya (maka niscaya kamu akan kurajam) dengan batu, atau dengan perkataan yang jelek, maka hati-hatilah kamu terhadapku (dan tinggalkanlah aku buat waktu yang lama)" yakni dalam masa yang lama.\qt@no{46}}%
\qt@newcmd\qurantrans@id@mmccxcvii{%
(Ibrahim berkata, ``Semoga keselamatan dilimpahkan kepadamu) dariku, maksudnya aku tidak akan lagi menimpakan hal-hal yang tidak diinginkan kepadamu (aku akan memintakan ampun bagimu kepada Rabbku. Sesungguhnya Dia sangat baik kepadaku") lafal Hafiyyan berasal dari lafal Hafaa, yang artinya sangat baik hingga Dia selalu memperkenankan doaku. Kemudian Nabi Ibrahim memenuhi janjinya itu, sebagaimana disebutkan di dalam surah Asy-Syu'ara, yaitu, ``.. dan ampunilah bapakku..." (Q.S. Asy-Syu'ara, 86). Hal ini dilakukan oleh Nabi Ibrahim sebelum jelas baginya bahwa bapaknya itu adalah musuh Allah, sebagaimana yang telah disebutkan di dalam surah At-Taubah.\qt@no{47}}%
\qt@newcmd\qurantrans@id@mmccxcviii{%
(Dan aku akan menjauhkan diri daripada kalian dan daripada apa yang kalian seru) yang kalian sembah (selain Allah, dan aku akan berdoa) yakni aku akan menyembah (kepada Rabbku, mudah-mudahan aku dengan berdoa kepada Rabbku) dengan beribadah kepada-Nya (tidak akan kecewa)" sebagaimana kalian kecewa karena menyembah berhala-berhala itu.\qt@no{48}}%
\qt@newcmd\qurantrans@id@mmccxcix{%
(Ketika Ibrahim sudah menjauhkan diri dari mereka dan dari apa yang mereka sembah selain Allah) dia pergi ke tanah suci (Kami anugerahkan kepadanya) dua orang putra yang menjadi penghibur hatinya (Ishak dan Yakub. Dan masing-masingnya) di antara keduanya (Kami angkat menjadi nabi).\qt@no{49}}%
\qt@newcmd\qurantrans@id@mmccc{%
(Dan Kami anugerahkan kepada mereka) bertiga Nabi Ibrahim, Nabi Ishak, dan Nabi Yakub (sebagian dari rahmat Kami,) berupa harta benda dan anak-anak (dan Kami jadikan mereka buah tutur yang baik lagi tinggi) mereka selalu menjadi pujian dan sanjungan semua pemeluk agama.\qt@no{50}}%
\qt@newcmd\qurantrans@id@mmccci{%
(Dan ceritakanlah kisah Musa di dalam Alquran ini. Sesungguhnya ia adalah seorang yang mukhlis) dapat dibaca Mukhlishan dan Mukhlashan, artinya seorang yang ikhlas di dalam beribadah dan Allah membersihkan dirinya dari hal-hal yang kotor (di samping ia adalah seorang rasul dan nabi).\qt@no{51}}%
\qt@newcmd\qurantrans@id@mmcccii{%
(Dan Kami telah memanggilnya) melalui firman-Nya, ``Hai Musa! Sesungguhnya Aku adalah Allah..." (Q.S. Al-Qashash, 30). (dari arah Thur) nama sebuah bukit (sebelah kanan) yakni dari sebelah kanan Nabi Musa ketika ia baru datang dari negeri Madyan (dan Kami telah mendekatkannya kepada Kami waktu dia munajat) bermunajat, yaitu Allah memperdengarkan Kalam-Nya kepadanya.\qt@no{52}}%
\qt@newcmd\qurantrans@id@mmccciii{%
(Dan Kami telah menganugerahkan kepadanya sebagian rahmat Kami) sebagian dari nikmat Kami (yaitu saudaranya, Harun) Lafal Haruna menjadi Badal atau Athaf Bayan (menjadi seorang nabi) lafal Nabiyyan ini menjadi Hal atau kata keterangan yang dimaksud daripada pemberian itu; hal ini merupakan pengabulan dari doa Nabi Musa sendiri yang meminta kepada Allah, supaya Dia mengangkat saudara tuanya menjadi rasul pula.\qt@no{53}}%
\qt@newcmd\qurantrans@id@mmccciv{%
(Dan ceritakanlah kisah Ismail di dalam Alquran. Sesungguhnya ia adalah seorang yang benar janjinya) sekali-kali ia tidak menjanjikan sesuatu melainkan ia memenuhinya. Disebutkan bahwa ia pernah menunggu seseorang yang telah berjanji kepadanya, selama tiga hari atau satu tahun, sehingga orang yang berjanji itu datang kepadanya di tempat yang dijanjikan itu, dan ternyata Nabi Ismail masih menunggu di tempat itu (dan dia adalah seorang rasul) untuk kabilah Jurhum (dan nabi).\qt@no{54}}%
\qt@newcmd\qurantrans@id@mmcccv{%
(Dan ia menyuruh ahlinya) yakni kaumnya (untuk salat dan menunaikan zakat dan ia adalah seorang yang diridai di sisi Rabbnya) lafal Mardhiyyan asalnya Mardhuwwun, kedua huruf Wawunya diganti menjadi Ya. Selanjutnya harakat Dhammah Dhadhnya diganti menjadi Kasrah, akhirnya jadi Mardhiyyun, oleh karena kedudukannya menjadi Khabar Kaana maka bacaannya menjadi Mardhiyyan.\qt@no{55}}%
\qt@newcmd\qurantrans@id@mmcccvi{%
(Dan ceritakanlah kisah Idris di dalam Alquran) Nabi Idris adalah buyut Nabi Ibrahim atau ayah kakek Nabi Nuh (Sesungguhnya ia adalah seorang yang sangat membenarkan dan seorang nabi).\qt@no{56}}%
\qt@newcmd\qurantrans@id@mmcccvii{%
(Dan Kami telah mengangkatnya ke martabat yang tinggi) ia masih tetap hidup sampai sekarang bertempat di langit keempat atau keenam, atau ketujuh atau berada di dalam surga. Ia dimasukkan ke dalam surga setelah terlebih dahulu mencicipi rasanya mati lalu dihidupkan kembali, setelah itu ia tidak mau keluar lagi dari dalam surga.\qt@no{57}}%
\qt@newcmd\qurantrans@id@mmcccviii{%
(Mereka itu) kalimat ini menjadi Mubtada (adalah orang-orang yang telah diberi nikmat oleh Allah) menjadi sifat daripada lafal Ulaaika (yaitu para nabi) menjadi Bayan atau keterangan dari lafal Ulaaika yang kedudukannya sama dengan sifat. Lafal-lafal yang sesudahnya sampai kepada Jumlah Syarat menjadi sifat dari lafal Nabiyyiin. Maka firman-Nya (dari keturunan Adam) yakni Nabi Idris (dan dari orang-orang yang Kami muatkan bersama Nuh) di dalam bahteranya, maksudnya adalah Nabi Ibrahim yaitu cucu daripada anak Nabi Nuh yang bernama Sam (dan dari keturunan Ibrahim) yakni Nabi Ismail dan Nabi Ishaq serta Nabi Yakub, (dan) dari keturunan (Israel) yang dimaksud adalah Nabi Musa, Nabi Harun, Nabi Zakaria, Nabi Yahya, dan Nabi Isa (dan dari orang-orang yang telah Kami beri petunjuk dan telah Kami pilih) daripada mereka. Khabar dari lafal Ulaaika yang di permulaan ayat tadi ialah ("Apabila dibacakan kepada mereka ayat-ayat Allah Yang Maha Pemurah, maka mereka menyungkur dengan bersujud dan menangis"). Lafal Sujjadan dan Bukiyyan adalah bentuk jamak dari lafal Saajidun dan Baakin. Maksudnya jadilah kalian orang-orang seperti mereka. Asal kata Bukiyyun adalah Bukiwyun, kemudian huruf Wawunya diganti menjadi Ya dan harakat Dhammahnya diganti pula dengan Kasrah, sehingga menjadi Buhiyyun.\qt@no{58}}%
\qt@newcmd\qurantrans@id@mmcccix{%
(Maka datanglah sesudah mereka pengganti yang jelek yang menyia-nyiakan salat) dengan cara meninggalkannya seperti orang-orang Yahudi dan Nasrani (dan memperturutkan hawa nafsunya) gemar melakukan perbuatan-perbuatan maksiat (maka mereka kelak akan menemui kesesatan) ghayya adalah nama sebuah lembah di neraka Jahanam, mereka akan dijerumuskan ke dalamnya.\qt@no{59}}%
\qt@newcmd\qurantrans@id@mmcccx{%
(Kecuali) yakni berbeda halnya dengan (orang yang bertobat, beriman dan beramal saleh, mereka itu akan masuk surga dan mereka tidak dianiaya) tidak dirugikan (barang sedikit pun) dari pahala mereka.\qt@no{60}}%
\qt@newcmd\qurantrans@id@mmcccxi{%
(Yaitu surga Adn) menjadi tempat tinggal mereka. Lafaz 'Adn menjadi Badal daripada lafal Jannatin (yang telah dijanjikan oleh Tuhan Yang Maha Pemurah kepada hamba-hamba-Nya, sekalipun surga itu tidak tampak). Lafal Bil Ghaibi menjadi Hal, maksudnya walaupun surga itu tidak kelihatan oleh mereka. (Sesungguhnya janji Allah itu) yakni apa yang telah dijanjikan oleh-Nya (pasti akan ditepati). Lafal Ma'tiyyan maknanya Aatiyan; asalnya adalah Ma'tiwyun. Yang dimaksud dengan janji-Nya adalah surga yang akan ditempati oleh orang-orang yang berhak memasukinya.\qt@no{61}}%
\qt@newcmd\qurantrans@id@mmcccxii{%
(Mereka tidak mendengar perkataan yang tidak berguna di dalam surga) pembicaraan yang tak berarti (kecuali) mereka hanya mendengar (ucapan Salam) dari para Malaikat buat mereka, atau dari sebagian mereka kepada sebagian yang lain. (Bagi mereka rezekinya di surga itu tiap-tiap pagi dan petang) dalam perkiraan kedua waktu tersebut menurut perhitungan waktu di dunia, karena sesungguhnya di dalam surga itu tidak ada siang dan malam tetapi yang ada hanyalah cahaya dan nur yang abadi.\qt@no{62}}%
\qt@newcmd\qurantrans@id@mmcccxiii{%
(Itulah surga yang akan Kami wariskan) Kami anugerahkan dan Kami tempatkan di dalamnya (kepada hamba-hamba Kami yang selalu bertakwa) yang berlaku taat kepada-Nya. Ayat berikut diturunkan ketika wahyu datang sangat terlambat selama beberapa hari, kemudian Nabi saw. berkata kepada malaikat Jibril ketika datang kepadanya, ``Apakah gerangan yang menyebabkan engkau tidak menziarahi aku selama ini".\qt@no{63}}%
\qt@newcmd\qurantrans@id@mmcccxiv{%
(Dan tidaklah kami turun melainkan dengan perintah Rabbmu, kepunyaan-Nyalah apa-apa yang ada di hadapan kita) yakni berupa semua perkara akhirat (apa-apa yang ada di belakang kita) berupa semua perkara duniawi (dan apa-apa yang ada di antara keduanya) apa yang ada dalam waktu sekarang sampai dengan datangnya hari kiamat. Yang dimaksud ialah bahwa pengetahuan mengenai kesemuanya itu berada pada-Nya (dan tidaklah Rabbmu lupa) lafal Nasiyyan bermakna Naasiyan, maksudnya, Allah tidak akan meninggalkanmu disebabkan wahyu yang terlambat datang kepadamu.\qt@no{64}}%
\qt@newcmd\qurantrans@id@mmcccxv{%
Dia adalah (Rabb) yang menguasai (langit dan bumi dan apa-apa yang ada di antara keduanya, maka sembahlah Dia dan berteguh hatilah dalam beribadah kepada-Nya) bersikap sabarlah dalam menjalankan dua perkara tersebut. (Apakah kamu mengetahui ada seorang yang sama dengan Dia) yang patut disembah seperti Dia, tentu saja tidak.\qt@no{65}}%
\qt@newcmd\qurantrans@id@mmcccxvi{%
(Dan berkata manusia,) mereka yang ingkar kepada adanya hari berbangkit, yaitu Ubay bin Khalaf atau Walid bin Mughirah, ayat ini diturunkan berkenaan dengan sikapnya itu ("Betulkah apabila) dapat dibaca Aidza dan Ayidza (aku telah mati, bahwa aku sungguh-sungguh akan dibangkitkan menjadi hidup kembali?") yakni akan dihidupkan kembali dari kuburan sebagaimana yang telah dikatakan oleh Muhammad. Kata tanya di sini mengandung makna Nafi atau kalimat negatif, maksudnya, Aku tidak akan dihidupkan kembali sesudah mati. Huruf Ma adalah Zaidah yang faedahnya untuk mengukuhkan kalimat, demikian pula huruf Lamnya. Kemudian Allah menyanggah perkataan mereka itu melalui firman-Nya:\qt@no{66}}%
\qt@newcmd\qurantrans@id@mmcccxvii{%
(Dan tidakkah manusia itu memikirkan) asal kata Yadzdzakkaru ini adalah Yatadzakkaru, kemudian huruf Ta diganti menjadi Dzal, lalu diidghamkan ke dalam huruf Dzal asal sehingga menjadi Yadzdzakkaru. Tetapi menurut qiraat yang lain dibaca Yadzkuru (bahwa sesungguhnya Kami telah menciptakannya dahulu, sedangkan ia tidak ada sama sekali) oleh karenanya mengapa ia tidak mengambil kesimpulan dari permulaan itu kepada pengembalian, yakni kembali kepada-Nya.\qt@no{67}}%
\qt@newcmd\qurantrans@id@mmcccxviii{%
(Demi Rabbmu, sesungguhnya akan Kami bangkitkan mereka) orang-orang yang ingkar kepada adanya hari berbangkit itu (bersama dengan setan) Kami mengumpulkan masing-masing dari mereka bersama setan-setannya dalam keadaan terbelenggu (kemudian akan Kami datangkan mereka ke sekeliling Jahanam) dari luarnya (dengan berlutut) berjalan dengan lututnya. Lafal Jitsiyyan adalah bentuk jamak dari lafal jaatsin, asal katanya adalah Jitsuwwun atau Jitsuwyun yang akar katanya berasal dari Jatsaa-Yajtsuu atau Jatsaa Yajtsii. Ada dua pendapat sehubungan dengan lafal ini.\qt@no{68}}%
\qt@newcmd\qurantrans@id@mmcccxix{%
(Kemudian pasti akan Kami tarik dari tiap-tiap golongan) yakni setiap kelompok dari mereka (siapa di antara mereka yang sangat durhaka kepada Tuhan Yang Maha Pemurah) sangat berani berbuat durhaka kepada-Nya.\qt@no{69}}%
\qt@newcmd\qurantrans@id@mmcccxx{%
(Dan kemudian Kami sungguh lebih mengetahui orang-orang yang lebih utama terhadapnya) lebih berhak terhadap Jahanam, yaitu orang yang sangat durhaka kepada-Nya dan orang-orang yang sama seperti mereka (untuk dimasukkan ke dalamnya) yang lebih utama masuk Jahanam dan lebih layak untuk menempatinya. Maka Kami memulai dengan mereka. Asal kata Shiliyyun adalah Shiliwyun, berasal dari Fi'il Shaliya atau Shalaa.\qt@no{70}}%
\qt@newcmd\qurantrans@id@mmcccxxi{%
(Dan tidak) (daripada kalian) seorang pun (melainkan mendatangi neraka itu) neraka Jahanam. (Hal itu bagi Rabbmu adalah suatu kemestian yang sudah ditetapkan) telah dipastikan dan telah diputuskan oleh-Nya, hal ini tidak akan diabaikan-Nya.\qt@no{71}}%
\qt@newcmd\qurantrans@id@mmcccxxii{%
(Kemudian Kami akan menyelamatkan) dapat dibaca Nunajjii dan Nunjii (orang-orang yang bertakwa) orang-orang yang memelihara dirinya dari kemusyrikan dan kekafiran, Kami akan selamatkan daripadanya (dan Kami akan membiarkan orang-orang yang zalim) orang-orang yang melakukan kemusyrikan dan kekafiran (di dalam neraka dalam keadaan berlutut) berdiri di atas lutut mereka.\qt@no{72}}%
\qt@newcmd\qurantrans@id@mmcccxxiii{%
(Dan apabila dibacakan kepada mereka) yaitu mereka orang-orang Mukmin dan orang-orang kafir (ayat-ayat Kami) dari Alquran (yang terang) jelas keadaan dan maksudnya (niscaya orang-orang yang kafir berkata kepada orang-orang yang beriman, ``Manakah di antara kedua golongan) kami dan kalian (yang lebih baik tempat tinggalnya) yaitu, tempat menetap dan rumahnya. Lafal Maqaaman berasal dari kata kerja Qaama, kalau dibaca Muqaaman berarti berasal dari kata kerja Aqaama (dan lebih indah tempat pertemuannya"). Lafal Nadiyyan bermakna An-Naadi artinya tempat berkumpulnya kaum, yang mereka berbincang-bincang di dalamnya. Mereka bermaksud bahwa kamilah yang lebih baik daripada kalian. Kemudian Allah berfirman,\qt@no{73}}%
\qt@newcmd\qurantrans@id@mmcccxxiv{%
("Berapa banyak) alangkah banyaknya (umat yang telah Kami binasakan sebelum mereka) yaitu umat-umat di masa silam (sedangkan mereka adalah lebih bagus alat rumah tangganya) yakni harta bendanya lebih banyak dan perabotan rumah tangga mereka jauh lebih bagus (dan lebih sedap dipandang mata") lebih indah dipandang mata. Lafal Ri'yan berasal dari kata Ar-Ru'yah. Maksudnya, sebagaimana Kami telah membinasakan umat-umat dahulu disebabkan kekafirannya, maka Kami pun akan membinasakan mereka pula.\qt@no{74}}%
\qt@newcmd\qurantrans@id@mmcccxxv{%
(Katakanlah! ``Barang siapa yang berada di dalam kesesatan) kalimat ayat ini mengandung syarat sedangkan Jawabnya ialah (maka biarlah diperpanjang) kalimat perintah di sini bermakna kalimat berita, artinya hendaknya diperpanjang (tempo baginya oleh Yang Maha Pemurah dengan sesungguhnya) di dunia ini dengan memperturutkan apa yang ia kehendaki (sehingga apabila mereka telah melihat apa yang diancamkan kepadanya, baik siksa) seperti dibunuh dan ditahan (maupun kiamat) yang pengertiannya mencakup juga neraka Jahanam tempat mereka dimasukkan ke dalamnya (maka mereka akan mengetahui siapa yang lebih jelek kedudukannya dan lebih lemah penolong-penolongnya") yakni pembantu-pembantunya; apakah mereka ataukah orang-orang yang beriman, pembantu-pembantu mereka adalah setan sedangkan pembantu-pembantu orang-orang yang beriman di dalam menghadapi mereka adalah para Malaikat.\qt@no{75}}%
\qt@newcmd\qurantrans@id@mmcccxxvi{%
(Dan Allah akan menambah kepada mereka yang telah mendapat petunjuk) berkat iman mereka (hidayah) berkat ayat-ayat yang diturunkan kepada mereka (Dan amal-amal saleh yang kekal itu) yaitu ketaatan kepada Allah yang selalu dilakukan oleh seseorang (lebih baik pahalanya di sisi Rabbmu dan lebih baik kesudahannya) akhir dan kesudahan daripadanya, berbeda dengan amal perbuatan orang-orang kafir. Pengertian perbandingan kebaikan di sini sebagai kebalikan daripada perkataan orang-orang kafir, yaitu ketika mereka mengatakan, ``Manakah di antara kedua golongan yang lebih baik kedudukannya?"\qt@no{76}}%
\qt@newcmd\qurantrans@id@mmcccxxvii{%
(Maka apakah kamu telah melihat orang yang kafir kepada ayat-ayat Kami) maksudnya 'Ashi bin Wa'il (dan ia mengatakan,) kepada Khabbab bin Art yang mengatakan kepadanya, bahwa engkau kelak akan dibangkitkan hidup kembali sesudah mati. Pada saat itu Khabbab sedang menagih utang kepadanya ("Pasti aku akan diberi) seandainya aku dibangkitkan hidup kembali (harta dan anak") maka pada saat itu aku akan membayar utangku kepadamu. Allah berfirman menyanggahnya:\qt@no{77}}%
\qt@newcmd\qurantrans@id@mmcccxxviii{%
(Adakah dia melihat yang gaib) apakah dia mengetahuinya sehingga ia berani mengatakan, bahwa dia akan diberi seperti apa yang dikatakannya itu. Lafal Aththala'a ini disebabkan sudah cukup hanya dengan memakai Hamzah Istifham, maka Hamzah Washalnya dibuang (atau ia telah membuat perjanjian di sisi Tuhan Yang Maha Pemurah?) sehingga ia berani mengatakan, bahwa Allah akan memberikan kepadanya apa yang telah dikatakannya itu.\qt@no{78}}%
\qt@newcmd\qurantrans@id@mmcccxxix{%
(Sekali-kali tidak) hal itu tidak akan diberikan kepadanya (Kami akan menulis) Kami memerintahkan untuk menuliskan (apa yang ia katakan itu dan benar-benar Kami akan memperpanjang azab baginya) Kami akan menambahkan kepada azab kekafirannya azab yang lain, karena perkataannya itu.\qt@no{79}}%
\qt@newcmd\qurantrans@id@mmcccxxx{%
(Dan Kami akan mewarisi apa yang ia katakan itu) yaitu harta benda dan anak (dan ia akan datang kepada Kami) kelak pada hari kiamat (dengan seorang diri) dalam keadaan tidak punya harta benda dan tidak punya anak.\qt@no{80}}%
\qt@newcmd\qurantrans@id@mmcccxxxi{%
(Dan mereka telah mengambil) orang-orang kafir Mekah (selain dari Allah) yakni berhala-berhala (sebagai tuhan-tuhan) yang mereka sembah (agar tuhan-tuhan itu menjadi pelindung bagi mereka) maksudnya memberikan syafaat kepada mereka di hadapan Allah supaya mereka jangan diazab oleh-Nya.\qt@no{81}}%
\qt@newcmd\qurantrans@id@mmcccxxxii{%
(Sekali-kali tidak) tiada sesuatu pun yang dapat mencegah azab mereka. (Kelak mereka itu akan mengingkari) yakni tuhan-tuhan sembahan mereka itu (penyembahan mereka) artinya mereka akan mengingkari penyembahan orang-orang yang mempertuhankan mereka, sebagaimana dijelaskan pula oleh ayat lain, yaitu firman-Nya, ``Mereka sekali-kali tidak menyembah Kami..." (Q.S. Al-Qashash, 63). (dan tuhan-tuhan itu akan menjadi musuh bagi mereka) yakni berhala-berhala itu justru akan menjadi musuh orang-orang yang menyembahnya kelak di akhirat.\qt@no{82}}%
\qt@newcmd\qurantrans@id@mmcccxxxiii{%
(Tidakkah kamu lihat, bahwasanya Kami telah mengirim setan-setan itu) yakni pengaruh mereka (kepada orang-orang kafir untuk menghasut mereka) untuk menggerakkan mereka melakukan perbuatan-perbuatan maksiat (dengan sungguh-sungguh).\qt@no{83}}%
\qt@newcmd\qurantrans@id@mmcccxxxiv{%
(Maka janganlah kamu tergesa-gesa terhadap mereka) untuk mendatangkan azab buat mereka (karena sesungguhnya Kami hanya menghitung untuk mereka) hari-hari atau nafas-nafas mereka (dengan perhitungan yang teliti) hingga tiba saatnya azab mereka.\qt@no{84}}%
\qt@newcmd\qurantrans@id@mmcccxxxv{%
Ingatlah (hari ketika Kami mengumpulkan orang-orang yang takwa) berkat keimanan mereka (kepada Tuhan Yang Maha Pemurah sebagai perutusan yang terhormat). Lafal Wafdun adalah bentuk jamak dan lafal Waafidun, artinya delegasi.\qt@no{85}}%
\qt@newcmd\qurantrans@id@mmcccxxxvi{%
(Dan Kami akan menghalau orang-orang yang durhaka) karena kekafiran mereka (ke neraka Jahanam dalam keadaan dahaga). Lafal Wirdun adalah bentuk jamak dari lafal Waaridun artinya berjalan dalam keadaan dahaga.\qt@no{86}}%
\qt@newcmd\qurantrans@id@mmcccxxxvii{%
(Mereka tidak dapat memberi) manusia semuanya (syafaat kecuali orang yang telah mengadakan perjanjian di sisi Tuhan Yang Maha Pemurah) yakni kesaksian bahwa tiada Tuhan selain Allah dan tiada daya serta tiada kekuatan melainkan berkat pertolongan Allah.\qt@no{87}}%
\qt@newcmd\qurantrans@id@mmcccxxxviii{%
(Dan mereka berkata,) orang-orang Yahudi dan Nasrani dan orang-orang yang menyangka bahwa malaikat-malaikat itu adalah anak-anak perempuan Allah ("Tuhan Yang Maha Pemurah mempunyai anak") maka Allah menyanggah perkataan mereka itu melalui firman-Nya,\qt@no{88}}%
\qt@newcmd\qurantrans@id@mmcccxxxix{%
("Sesungguhnya kalian telah mendatangkan sesuatu perkara yang sangat mungkar) yaitu suatu perkara mungkar yang sangat besar.\qt@no{89}}%
\qt@newcmd\qurantrans@id@mmcccxl{%
(Hampir-hampir) dapat dibaca Takaadu dan Yakaadu (langit pecah) terbelah, dan menurut qiraat yang lain lafal Yatafaththarna dibaca Yanfathirna (karena ucapan itu dan bumi belah dan gunung-gunung runtuh) yakni terbalik menindih mereka disebabkan.\qt@no{90}}%
\qt@newcmd\qurantrans@id@mmcccxli{%
(mereka mendakwakan Allah Yang Maha Pemurah mempunyai anak"). Allah berfirman,\qt@no{91}}%
\qt@newcmd\qurantrans@id@mmcccxlii{%
("Dan tidak layak bagi Allah Yang Maha Pemurah mempunyai anak") yakni tidak patut bagi-Nya hal yang demikian itu.\qt@no{92}}%
\qt@newcmd\qurantrans@id@mmcccxliii{%
(Tidak ada) (seorang pun di langit dan di bumi melainkan akan datang kepada Tuhan Yang Maha Pemurah selaku seorang hamba) yang hina dan tunduk patuh kepada-Nya kelak di hari kiamat, termasuk Uzair dan Isa juga.\qt@no{93}}%
\qt@newcmd\qurantrans@id@mmcccxliv{%
(Sesungguhnya Allah telah menentukan jumlah mereka dan menghitung mereka dengan hitungan yang teliti) maka tidak samar bagi-Nya mengenai jumlah mereka secara keseluruhan atau pun secara rinci dan tiada seorang pun yang terlewat dari perhitungan-Nya.\qt@no{94}}%
\qt@newcmd\qurantrans@id@mmcccxlv{%
(Dan tiap-tiap mereka akan datang kepada Allah pada hari kiamat dengan sendiri-sendiri) tanpa harta dan tanpa pembantu yang dapat membelanya.\qt@no{95}}%
\qt@newcmd\qurantrans@id@mmcccxlvi{%
(Sesungguhnya orang-orang yang beriman dan beramal saleh, kelak Allah Yang Maha Pemurah akan menanamkan dalam hati mereka rasa kasih sayang) di antara sesama mereka; mereka saling kasih-mengasihi dan sayang-menyayangi dan Allah swt. mencintai mereka semuanya.\qt@no{96}}%
\qt@newcmd\qurantrans@id@mmcccxlvii{%
(Maka sesungguhnya telah Kami mudahkan dia) Alquran itu (dengan bahasamu) bahasa Arab (agar kamu dapat memberi kabar gembira dengan Alquran itu kepada orang-orang yang bertakwa) yaitu orang-orang yang beruntung memperoleh iman (dan agar kamu memberi peringatan) menakut-nakuti (dengannya kepada kaum yang membangkang). Lafal Luddan adalah bentuk jamak dari lafal Aladdun artinya banyak membantah dengan kebatilan, mereka adalah orang-orang kafir Mekah.\qt@no{97}}%
\qt@newcmd\qurantrans@id@mmcccxlviii{%
(Dan berapa banyak) banyak sekali (telah Kami binasakan umat-umat sebelum mereka) umat-umat di masa silam disebabkan kedustaan mereka terhadap Rasul (Adakah kamu melihat) menemukan (seorang pun dari mereka atau kamu dengar suara mereka yang samar-samar?) Tentu saja tidak. Sebagaimana Kami telah membinasakan umat-umat di masa silam maka niscaya pula Kami akan membinasakan mereka, disebabkan kekafiran mereka itu.\qt@no{98}}%
\qt@newcmd\qurantrans@id@mmcccxlix{%
\basmalahid (Tha Ha) hanya Allahlah yang mengetahui maksudnya\qt@no{1}}%
\qt@newcmd\qurantrans@id@mmcccl{%
(Kami tidak menurunkan Alquran ini kepadamu) hai Muhammad (agar kamu menjadi susah) supaya kamu letih dan payah disebabkan apa yang kamu kerjakan sesudah ia diturunkan, sehingga kamu harus berkepanjangan berdiri di dalam melakukan salat malam. Maksudnya berilah kesempatan istirahat bagi dirimu.\qt@no{2}}%
\qt@newcmd\qurantrans@id@mmcccli{%
(Tetapi) Kami turunkan Alquran ini (sebagai peringatan) melalui apa yang dikandungnya (bagi orang yang takut) kepada Allah.\qt@no{3}}%
\qt@newcmd\qurantrans@id@mmccclii{%
(Yaitu diturunkan) lafal Tanziilan ini menjadi Badal dari lafal Fi'il yang menashabkannya, yakni Nazzalahu Tanziilan (dari Allah yang menciptakan bumi dan langit yang tinggi). Lafal Al 'Ula merupakan bentuk jamak dari kata 'Ulyaa, keadaannya sama dengan lafal Kubraa dan Kubar.\qt@no{4}}%
\qt@newcmd\qurantrans@id@mmcccliii{%
Yaitu (Tuhan Yang Maha Pemurah, yang di atas Arasy) lafal Arasy ini menurut pengertian bahasa diartikan singgasana raja (berkuasa) yakni bersemayam sesuai dengan keagungan dan kebesaran-Nya.\qt@no{5}}%
\qt@newcmd\qurantrans@id@mmcccliv{%
(Kepunyaan-Nyalah semua yang ada di langit, semua yang ada di bumi, semua yang ada di antara keduanya) yakni makhluk-makhluk yang ada di antara keduanya (dan semua yang di bawah tanah) yaitu lapisan tanah yang masih basah, yang dimaksud adalah di bawah semua lapisan bumi yang tujuh, karena lapisan bumi yang berjumlah tujuh itu berada di bawah lapisan tanah yang basah.\qt@no{6}}%
\qt@newcmd\qurantrans@id@mmccclv{%
(Dan jika kamu mengeraskan ucapanmu) di dalam berzikir atau berdoa, maka sesungguhnya Allah tidak memerlukan suara keras engkau sewaktu melakukan hal tersebut (maka sesungguhnya Dia mengetahui rahasia dan yang lebih tersembunyi) daripada rahasia, maksudnya adalah semua apa yang ada dalam hati manusia yang tidak diungkapkannya, maka janganlah engkau memayahkan dirimu dengan mengeraskan suaramu.\qt@no{7}}%
\qt@newcmd\qurantrans@id@mmccclvi{%
(Dialah Allah, tidak ada Tuhan melainkan Dia, Dia mempunyai Asmaulhusna) jumlahnya sebanyak yang disebutkan di dalam hadis yaitu sembilan puluh sembilan nama-nama yang baik. Lafal Al Husna bentuk Muannats daripada lafal Al Ahsan.\qt@no{8}}%
\qt@newcmd\qurantrans@id@mmccclvii{%
(Apakah) telah (datang kepadamu kisah Musa?)\qt@no{9}}%
\qt@newcmd\qurantrans@id@mmccclviii{%
(Ketika ia melihat api, lalu berkatalah ia kepada keluarganya) yakni kepada istrinya, ("Tinggallah kamu) di sini, hal itu terjadi sewaktu ia berada dalam perjalanan dari Madyan menuju ke negeri Mesir (sesungguhnya aku melihat) menyaksikan (api, mudah-mudahan aku dapat membawa sedikit daripadanya untuk kalian) berupa obor yang dinyalakan pada sumbu atau kayu (atau aku akan mendapatkan petunjuk di tempat itu") yang dapat menunjukkan jalan; karena pada saat itu Nabi Musa kehilangan arah jalan disebabkan gelapnya malam. Nabi Musa mengungkapkan kata-katanya dengan memakai istilah La'alla yang artinya mudah-mudahan karena ia merasa kurang pasti dengan apa yang telah dijanjikannya itu.\qt@no{10}}%
\qt@newcmd\qurantrans@id@mmccclix{%
(Maka ketika ia datang ke tempat api itu) yaitu di pohon 'Ausaj (ia dipanggil, ``Hai Musa!)\qt@no{11}}%
\qt@newcmd\qurantrans@id@mmccclx{%
(Sesungguhnya Aku) dibaca Innii karena dengan menganggap lafal Nudiya bermakna Qiila. Dan bila dibaca Annii maka diperkirakan adanya huruf Ba sebelumnya (inilah) lafal Anaa di sini berfungsi mentaukidkan makna yang terkandung di dalam Ya Mutakallim (Rabbmu, maka tanggalkanlah kedua terompahmu; sesungguhnya kamu berada di lembah yang suci) lembah yang disucikan, atau lembah yang diberkati (Thuwa) menjadi Badal atau 'Athaf Bayan. Kalau dibaca Thuwan maka dianggap sebagai nama tempat saja dan jika dibaca Thuwa dalam bentuk lafal yang Muannats, maka dianggap sebagai nama daerah dan 'Alamiyah, sehingga tidak menerima harakat Tanwin.\qt@no{12}}%
\qt@newcmd\qurantrans@id@mmccclxi{%
(Dan Aku telah memilih kamu) dari kaummu (maka dengarkanlah apa yang akan diwahyukan kepadamu) dari-Ku.\qt@no{13}}%
\qt@newcmd\qurantrans@id@mmccclxii{%
(Sesungguhnya Aku ini adalah Allah, tiada Tuhan selain Aku, maka sembahlah Aku dan dirikanlah salat untuk mengingat Aku) di dalam salat itu.\qt@no{14}}%
\qt@newcmd\qurantrans@id@mmccclxiii{%
(Sesungguhnya hari kiamat itu akan datang Aku merahasiakan waktunya) dari manusia dan menampakkan kepada mereka hanya dekatnya hari kiamat melalui alamat-alamatnya supaya mendapatkan balasan) di hari itu (tiap-tiap diri itu dengan apa yang ia usahakan) apakah kebaikan ataukah keburukan.\qt@no{15}}%
\qt@newcmd\qurantrans@id@mmccclxiv{%
(Maka sekali-kali janganlah kamu dipalingkan) dibelokkan (daripadanya) dari iman kepada adanya hari kiamat (oleh orang yang tidak beriman kepadanya dan oleh orang yang mengikuti hawa nafsunya) untuk ingkar kepada adanya hari kiamat (yang menyebabkan kamu jadi binasa") sedangkan mereka pasti akan binasa.\qt@no{16}}%
\qt@newcmd\qurantrans@id@mmccclxv{%
(Apakah itu) yang berada (di tangan kananmu, hai Musa?) Kata tanya atau Istifham di sini mengandung makna Taqrir, maksudnya supaya Allah menurunkan mukjizat kepada Nabi Musa dengan melalui tongkatnya itu.\qt@no{17}}%
\qt@newcmd\qurantrans@id@mmccclxvi{%
(Berkata Musa, ``Ini adalah tongkatku, aku bertelekan) berpegangan (padanya) sewaktu aku melompat dan berjalan (dan aku pukul) aku memukul daun-daun pohon (dengannya) supaya daun-daun itu berjatuhan (untuk kambingku) lalu kambing-kambingku itu memakannya (dan bagiku ada lagi padanya keperluan). Lafal Ma'aarib adalah bentuk jamak dari lafal Ma'ribah atau Ma'rabah atau Ma'rubah, artinya keperluan-keperluan (yang lain") seperti untuk memikul bekal dan air minum, serta untuk mengusir binatang buas. Kemudian Allah menambahkan jawaban, sebagai penjelasan bahwa pada tongkat itu masih terdapat kegunaan lainnya, yaitu:\qt@no{18}}%
\qt@newcmd\qurantrans@id@mmccclxvii{%
(Allah berfirman, ``Lemparkanlah tongkat itu, hai Musa!")\qt@no{19}}%
\qt@newcmd\qurantrans@id@mmccclxviii{%
(Lalu dilemparkannyalah tongkat itu, maka tiba-tiba ia menjadi seekor ular) yang sangat besar (yang merayap) yakni berjalan cepat dengan perutnya seperti ular kecil, di dalam ayat lain disebutkan Al Jaan, bukan Hayyatun.\qt@no{20}}%
\qt@newcmd\qurantrans@id@mmccclxix{%
(Allah berfirman, ``Peganglah ia dan jangan takut) kepadanya (Kami akan mengembalikannya kepada keadaannya) lafal Siiratahaa dinashabkan dengan mencabut huruf Jarnya, maksudnya ke dalam bentuknya (yang semula) kemudian Nabi Musa memasukkan tangannya ke mulut ular besar itu, maka kembalilah kepada keadaan semula yaitu menjadi tongkat lagi. Jelaslah bahwa tempat untuk memasukkan tangannya adalah tempat pegangan tongkat, yaitu di antara kedua rahang ular tersebut. Allah swt. sengaja memperlihatkan hal itu kepada Nabi Musa, supaya ia jangan kaget bila tongkat itu berubah menjadi ular besar di hadapan raja Firaun nanti.\qt@no{21}}%
\qt@newcmd\qurantrans@id@mmccclxx{%
(Dan kepitkanlah tanganmu) yang sebelah kanan, yang dimaksud adalah telapak tangannya (ke ketiakmu) yakni dijepitkan pada tubuhmu yang sebelah kiri, yaitu pada tempat antara ketiak dan lenganmu, kemudian keluarkanlah ia (niscaya ia keluar) dalam keadaan berbeda dengan warna kulit yang sebelumnya, yaitu (menjadi putih cemerlang tanpa cacat) putih bersinar dengan cemerlang sebagaimana sinar matahari, dan sinarnya itu menyilaukan pandangan mata (sebagai mukjizat yang lain) tangan itu bisa menjadi putih bersinar; lafal Baidhaa'a dan lafal Aayatan Ukhraa keduanya menjadi Hal atau kata keterangan keadaan bagi Dhamir yang terkandung di dalam lafal Takhruj.\qt@no{22}}%
\qt@newcmd\qurantrans@id@mmccclxxi{%
(Untuk Kami perlihatkan kepadamu) Kami sengaja melakukan hal itu bilamana kamu sewaktu-waktu mau menggunakannya, untuk memperlihatkan kepadamu (sebagian tanda-tanda kekuasaan Kami) bukti kekuasaan Kami (yang sangat besar) bukti yang besar bagi kerasulanmu. Apabila Nabi Musa hendak mengembalikan tangannya seperti semula, maka ia mengepitkannya lagi pada ketiaknya seperti yang dilakukannya semula, kemudian mengeluarkannya kembali.\qt@no{23}}%
\qt@newcmd\qurantrans@id@mmccclxxii{%
(Pergilah) sebagai seorang Rasul (kepada Firaun) dan orang-orang yang mengikutinya (sesungguhnya ia telah melampaui batas)" sangat keterlaluan di dalam kekafirannya, hingga ia berani mengaku menjadi tuhan.\qt@no{24}}%
\qt@newcmd\qurantrans@id@mmccclxxiii{%
(Berkata Musa, ``Ya Rabbku! Lapangkanlah untukku dadaku,) maksudnya lapangkanlah dadaku supaya mampu mengemban risalah-Mu.\qt@no{25}}%
\qt@newcmd\qurantrans@id@mmccclxxiv{%
(Dan mudahkanlah) permudahlah (untukku urusanku) supaya aku dapat menyampaikannya.\qt@no{26}}%
\qt@newcmd\qurantrans@id@mmccclxxv{%
(Dan lepaskanlah kekakuan dari lidahku) keadaan ini terjadi sejak lidahnya terbakar bara api yang ia masukkan ke dalam mulutnya sewaktu masih kecil.\qt@no{27}}%
\qt@newcmd\qurantrans@id@mmccclxxvi{%
(Supaya mereka mengerti) yakni dapat memahami (perkataanku) di waktu aku menyampaikan risalah kepada mereka.\qt@no{28}}%
\qt@newcmd\qurantrans@id@mmccclxxvii{%
(Dan jadikanlah untukku seorang pembantu) orang yang membantuku di dalam menyampaikan risalah-Mu (dari keluargaku).\qt@no{29}}%
\qt@newcmd\qurantrans@id@mmccclxxviii{%
(Yaitu Harun) lafal Haaruna menjadi Maf'ul Tsani (saudaraku) lafal Akhii menjadi 'Athaf Rayan.\qt@no{30}}%
\qt@newcmd\qurantrans@id@mmccclxxix{%
(Teguhkanlah dengan dia kekuatanku) kemampuanku.\qt@no{31}}%
\qt@newcmd\qurantrans@id@mmccclxxx{%
(Dan jadikanlah ia sekutu dalam urusanku) yakni ikut mengemban risalah ini. Kedua Fi'il tadi yaitu Usydud dan Asyrik dapat pula dibaca sebagai Fi'il Mudhari' yang dijazamkan sehingga menjadi Asydud Bihi dan Usyrik-hu, keduanya merupakan Jawab dari Thalab atau permintaan.\qt@no{32}}%
\qt@newcmd\qurantrans@id@mmccclxxxi{%
(Supaya kami dapat bertasbih kepada-Mu) yakni melakukan tasbih (dengan banyak).\qt@no{33}}%
\qt@newcmd\qurantrans@id@mmccclxxxii{%
(Dan dapat mengingat-Mu) berzikir kepada-Mu (dengan banyak pula).\qt@no{34}}%
\qt@newcmd\qurantrans@id@mmccclxxxiii{%
(Sesungguhnya Engkau adalah Maha Mengetahui keadaan kami)" Maha Mengetahuinya, oleh sebab itu maka Engkau akan memberikan nikmat-Mu kepadaku dengan mengangkat Harun menjadi Rasul.\qt@no{35}}%
\qt@newcmd\qurantrans@id@mmccclxxxiv{%
(Allah berfirman, ``Sesungguhnya telah dikabulkan permintaanmu, hai Musa) sebagai anugerah Kami kepadamu.\qt@no{36}}%
\qt@newcmd\qurantrans@id@mmccclxxxv{%
(Dan sesungguhnya Kami telah memberi nikmat kepadamu pada kali yang lain).\qt@no{37}}%
\qt@newcmd\qurantrans@id@mmccclxxxvi{%
(Yaitu ketika) lafal Idz di sini mengandung makna Ta'lil (mengilhamkan kepada ibumu) di dalam mimpi, atau berupa inspirasi, yaitu sewaktu ibumu melahirkan dirimu, dan ia merasa khawatir Firaun akan membunuhmu bersama-sama dengan anak-anak lelaki lainnya yang baru dilahirkan saat itu (suatu yang diilhamkan") mengenai urusanmu. Selanjutnya dijelaskan ilham tersebut dalam firman selanjutnya:\qt@no{38}}%
\qt@newcmd\qurantrans@id@mmccclxxxvii{%
(Yaitu, ``Letakkanlah ia) tarohlah ia (di dalam sebuah peti, kemudian lemparkanlah ia) yakni peti itu (ke sungai) yakni sungai Nil (maka pasti sungai itu membawanya ke tepi) ke pinggirnya. Kata perintah di sini mengandung makna kalimat berita (supaya diambil oleh musuh-Ku dan musuhnya) yaitu raja Firaun. (Dan Aku telah melimpahkan) sesudah Firaun mengambil anakmu darimu (kepadamu kasih sayang yang datang daripada-Ku) supaya semua orang merasa kasih sayang kepadamu, lalu Firaun akan merasa sayang kepadamu, demikian pula setiap orang yang melihatmu (dan supaya kamu diasuh di bawah pengawasan-Ku) kamu dipelihara di bawah asuhan dan penjagaan-Ku.\qt@no{39}}%
\qt@newcmd\qurantrans@id@mmccclxxxviii{%
(Yaitu ketika) lafal Idz di sini bermakna Ta'lil (saudaramu yang perempuan berjalan) namanya Maryam untuk menyelidiki beritamu. Karena sesungguhnya Firaun dan keluarganya telah mendatangkan orang-orang perempuan yang menyusui, sedangkan kamu tidak mau menerima air susu seorang pun di antara mereka (lalu ia berkata, 'Bolehkah saya menunjukkan kepada kalian orang yang akan memeliharanya?') kemudian usulnya itu ternyata diperkenankan oleh keluarga Firaun, maka segera Maryam mendatangkan ibunya, lalu Nabi Musa mau menerima air susunya. (Maka Kami mengembalikanmu kepada ibumu, agar senang hatinya) karena bertemu kembali denganmu (dan tidak berduka cita) sejak saat itu. (Dan kamu pernah membunuh seorang manusia) yaitu seorang bangsa Qibti di Mesir. Maka kamu merasa susah dan khawatir setelah membunuh orang itu terhadap pembalasan raja Firaun (lalu Kami selamatkan kamu dari kesusahan dan Kami telah mencobamu dengan beberapa cobaan) Kami telah mengujimu dengan beberapa cobaan selain dari peristiwa itu, kemudian Kami selamatkan pula kamu daripadanya (maka kamu tinggal beberapa tahun) yakni selama sepuluh tahun (di antara penduduk Madyan) sesudah kamu datang ke tempat itu dari negeri Mesir, yaitu kamu tinggal di tempat Nabi Syuaib yang kemudian ia mengawinkanmu dengan putrinya (kemudian kamu datang menurut waktu yang ditetapkan) di dalam ilmu-Ku dengan membawa risalah, yaitu dalam usia empat puluh tahun (hai Musa!).\qt@no{40}}%
\qt@newcmd\qurantrans@id@mmccclxxxix{%
(Dan Aku telah memilihmu) telah menjadikanmu sebagai orang yang terpilih (untuk diri-Ku) untuk mengemban risalah.\qt@no{41}}%
\qt@newcmd\qurantrans@id@mmcccxc{%
(Pergilah kamu beserta saudaramu) kepada manusia (dengan membawa ayat-ayat-Ku) yang berjumlah sembilan ayat (dan janganlah kamu berdua lalai) melalaikan (dalam mengingat-Ku) yaitu dengan cara bertasbih dan cara-cara lainnya.\qt@no{42}}%
\qt@newcmd\qurantrans@id@mmcccxci{%
(Pergilah kamu berdua kepada Firaun, sesungguhnya dia telah melampaui batas) karena ia mengaku menjadi tuhan.\qt@no{43}}%
\qt@newcmd\qurantrans@id@mmcccxcii{%
(Maka berbicaralah kamu berdua kepadanya dengan kata-kata yang lemah lembut) untuk menyadarkannya supaya jangan mengaku menjadi tuhan (mudah-mudahan ia ingat) yakni sadar dan mau menerimanya (atau takut") kepada Allah lalu karenanya ia mau sadar. Ungkapan 'mudah-mudahan' berkaitan dengan pengetahuan Nabi Musa dan Nabi Harun. Adapun menurut pengetahuan Allah, maka Dia telah mengetahui bahwa Firaun tidak akan mau sadar dari perbuatannya.\qt@no{44}}%
\qt@newcmd\qurantrans@id@mmcccxciii{%
(Berkatalah mereka berdua, ``Ya Rabb kami! Sesungguhnya kami khawatir bahwa ia segera menyiksa kami) mengambil keputusan yang cepat untuk menyiksa kami (atau akan bertambah melampaui batas") terhadap kami, yakni bertambah takabbur.\qt@no{45}}%
\qt@newcmd\qurantrans@id@mmcccxciv{%
(Allah berfirman, ``Janganlah kamu berdua takut sesungguhnya Aku beserta kamu berdua) Aku akan membantu kamu berdua (Aku mendengar) apa yang dikatakannya (dan melihat) apa yang dikerjakannya.\qt@no{46}}%
\qt@newcmd\qurantrans@id@mmcccxcv{%
(Maka datanglah kamu berdua kepadanya dan katakanlah, `` Sesungguhnya kami berdua adalah utusan Rabbmu, maka lepaskanlah Bani Israel bersama kami) untuk berangkat ke negeri Syam (dan janganlah kamu menyiksa mereka) lepaskanlah mereka dari perbudakanmu yang telah kamu pekerjakan dengan kerja-kerja yang berat seperti menggali, membangun bangunan dan mengangkat barang-barang yang berat. (Sesungguhnya kami telah datang kepadamu dengan membawa bukti) yakni hujah (dari Rabbmu) yang membenarkan kerasulan kami. (Dan keselamatan itu dilimpahkan kepada orang yang mengikuti petunjuk) keselamatan dari azab bagi orang yang mengikutinya.\qt@no{47}}%
\qt@newcmd\qurantrans@id@mmcccxcvi{%
(Sesungguhnya telah diwahyukan kepada kami, bahwa siksa itu ditimpakan kepada orang-orang yang mendustakan) apa yang kami datangkan ini (dan berpaling") daripadanya. Kemudian Nabi Musa dan Nabi Harun mendatangi Firaun dan keduanya mengatakan semuanya itu kepadanya.\qt@no{48}}%
\qt@newcmd\qurantrans@id@mmcccxcvii{%
(Berkata Firaun, ``Maka siapakah Rabbmu berdua, hai Musa?") ungkapan ini ditujukan kepada Nabi Musa, karena dialah asal pembawa risalah Allah dan yang mendapatkan pemeliharaan dari-Nya.\qt@no{49}}%
\qt@newcmd\qurantrans@id@mmcccxcviii{%
(Musa berkata, ``Rabb kami ialah yang telah memberikan kepada tiap-tiap sesuatu) yakni tiap-tiap makhluk (bentuk kejadiannya) yang membedakannya daripada makhluk yang lain (kemudian memberinya petunjuk") sehingga mengetahui makanan, minuman dan cara mengembangkan keturunannya serta hal-hal lain yang menyangkut kehidupannya.\qt@no{50}}%
\qt@newcmd\qurantrans@id@mmcccxcix{%
(Berkatalah ia) yakni Firaun, ("Maka bagaimanakah) keadaan (umat-umat) yakni bangsa-bangsa (yang dahulu?") seperti kaum Nabi Nuh, kaum Nabi Hud, kaum Nabi Luth dan kaum Nabi Saleh, tentang penyembahan mereka kepada berhala-berhala.\qt@no{51}}%
\qt@newcmd\qurantrans@id@mmcd{%
(Ia berkata) yakni Nabi Musa, ("Pengetahuan tentang itu) pengetahuan mengenai keadaan mereka berada (di sisi Rabbku, di dalam sebuah kitab) yaitu Lohmahfuz; Dia akan membalas mereka kelak di hari kiamat. (Tidak akan salah) tidak akan lenyap (dari Rabbku) segala sesuatu (dan tidak pula lupa) akan sesuatu.\qt@no{52}}%
\qt@newcmd\qurantrans@id@mmcdi{%
Dia (yang telah menjadikan bagi kalian) di antara sekian banyak makhluk-Nya (bumi sebagai hamparan) tempat berpijak (dan Dia memudahkan) mempermudah (bagi kalian di bumi itu jalan-jalan) tempat-tempat untuk berjalan (dan Dia menurunkan dari langit air hujan) yakni merupakan hujan. Allah berfirman menggambarkan apa yang telah disebutkan-Nya itu sebagai nikmat dari-Nya, kepada Nabi Musa dan dianggap sebagai khithab untuk penduduk Mekah. (Maka Kami tumbuhkan dengan air hujan itu berjenis-jenis) bermacam-macam (tumbuh-tumbuhan yang beraneka ragam). Lafal Syattaa ini menjadi kata sifat daripada lafal Azwaajan, maksudnya, yang berbeda-beda warna dan rasa serta lain-lainnya. Lafal syattaa ini adalah bentuk jamak dari lafal Syatiitun, wazannya sama dengan lafal Mardhaa sebagai jamak dari lafal Mariidhun. Ia berasal dari kata kerja Syatta artinya Tafarraqa atau berbeda-beda.\qt@no{53}}%
\qt@newcmd\qurantrans@id@mmcdii{%
(Makanlah) daripadanya (dan gembalakanlah ternak kalian) di dalamnya. Lafal An'am adalah bentuk jamak dari lafal Ni'amun, yang artinya mencakup unta, sapi dan kambing. Dikatakan, Ru'tul An'aama atau aku menggembalakan ternak dan Ra'aituhaa atau aku telah menggembalakannya. Pengertian yang terkandung di dalam perintah ini menunjukkan makna ibahah atau boleh dan sekaligus sebagai pengingat akan nikmat-nikmat-Nya. Jumlah keseluruhan ayat ini menjadi kata keterangan keadaan daripada Dhamir yang terkandung di dalam lafal Akhrajnaa. Maksudnya, Kami memperbolehkan bagi kalian untuk memakannya dan mengembalakan ternak padanya. (sesungguhnya pada yang demikian itu) yakni pada hal-hal yang telah disebutkan dalam ayat ini (terdapat tanda-tanda) pelajaran-pelajaran (bagi orang-orang yang berakal) lafal Nuhaa adalah bentuk jamak dan lafal Nuhyah, wazannya sama dengan lafal Ghurfah yang jamaknya Ghuraf. Akal dinamakan dengan istilah ini, karena dapat mencegah pemiliknya dari melakukan perbuatan-perbuatan yang buruk.\qt@no{54}}%
\qt@newcmd\qurantrans@id@mmcdiii{%
(Dari bumi itulah) dari tanah (Kami menjadikan kalian) dengan menciptakan nenek moyang kalian Adam daripadanya (dan kepadanya Kami akan mengembalikan kalian) kalian akan dikuburkan di dalamnya sesudah mati (dan daripadanya Kami akan mengeluarkan kalian) pada hari berbangkit (pada kali) untuk kali (yang lain) sebagaimana Kami mengeluarkan kalian pada permulaan penciptaan kalian.\qt@no{55}}%
\qt@newcmd\qurantrans@id@mmcdiv{%
(Dan sesungguhnya telah Kami perlihatkan kepadanya) kepada Firaun (ayat-ayat Kami semuanya) yang berjumlah sembilan ayat itu (maka ia mendustakan) nya dan menuduh bahwa ayat-ayat itu adalah sihir (dan ia enggan) untuk mengesakan Allah swt.\qt@no{56}}%
\qt@newcmd\qurantrans@id@mmcdv{%
(Berkata Firaun, ``Adakah kamu datang kepada kami untuk mengusir kami dari negeri kami) yakni dari negeri Mesir, kemudian kamu menjadi raja padanya (dengan sihirmu, hai Musa?")\qt@no{57}}%
\qt@newcmd\qurantrans@id@mmcdvi{%
("Dan kami pun pasti akan mendatangkan pula kepadamu sihir semacam itu) yang akan melawannya (maka buatlah suatu waktu antara kami dan kamu) untuk pertemuan itu (yang kami tidak akan menyalahinya dan tidak pula kamu, di suatu tempat) lafal Makaanan ini dinashabkan dengan mencabut huruf Jarnya, maksudnya, di tempat (yang pertengahan") lafal Suwan dapat pula dibaca Siwan, artinya, tempat yang letaknya pertengahan, dari arah mana saja didatangi oleh kedua pihak jaraknya sama.\qt@no{58}}%
\qt@newcmd\qurantrans@id@mmcdvii{%
(Berkatalah ia) Nabi Musa, ("Waktu untuk pertemuan kami dengan kalian itu adalah hari raya) yakni hari raya Firaun dan kaumnya, yang pada hari itu mereka berhias diri dan berkumpul-kumpul (dan hendaklah dikumpulkan manusia) semua penduduk negeri Mesir dikumpulkan (pada waktu matahari naik sepenggalah") untuk menyaksikan apa yang akan terjadi.\qt@no{59}}%
\qt@newcmd\qurantrans@id@mmcdviii{%
(Maka Firaun meninggalkan) pergi meninggalkan tempat itu (lalu ia mengatur tipu muslihatnya) ia mulai mengumpulkan para ahli sihirnya (kemudian ia datang) bersama mereka pada waktu yang telah ditentukan itu.\qt@no{60}}%
\qt@newcmd\qurantrans@id@mmcdix{%
(Berkata Musa kepada mereka,) jumlah para ahli sihir Firaun ada tujuh puluh dua orang; setiap orang dari mereka memegang tali dan tongkat ("Celakalah kalian) maksudnya semoga Allah menimpakan kecelakaan kepada kalian (janganlah kalian mengada-adakan kedustaan terhadap Allah) dengan menyekutukan seseorang bersama-Nya (maka Dia membinasakan kalian) ia dapat dibaca Fayushitakum dan Fayashitakum, artinya Dia akan membinasakan kalian, karena perbuatan musyrik itu (dengan siksa") dari sisi-Nya. (Dan sesungguhnya telah kecewa) merugi (orang yang mengada-adakan kedustaan) terhadap Allah.\qt@no{61}}%
\qt@newcmd\qurantrans@id@mmcdx{%
(Maka mereka berbantah-bantahan di antara mereka tentang urusannya) yakni mengenai Nabi Musa dan saudaranya itu (dan mereka merahasiakan percakapan) mereka yang menyangkut Nabi Musa dan Nabi Harun.\qt@no{62}}%
\qt@newcmd\qurantrans@id@mmcdxi{%
(Mereka berkata) kepada diri mereka sendiri, ("Sesungguhnya dua orang ini) ungkapan Haadzaani dijadikan hujah atau alasan bagi sebagian ahli Nahwu yang menetapkan huruf Alif pada isim Tatsniyah dalam tiga keadaan. Akan tetapi menurut qiraat Abu 'Amr, lafal Haadzaani ini dibaca Haadzaini (adalah benar-benar ahli sihir yang hendak mengusir kalian, dari negeri kalian dengan sihirnya dan hendak melenyapkan kedudukan kalian yang utama") lafal Mutslaa adalah bentuk Muannats dari lafal Amtsal; maksudnya yang mulia. Artinya, keduanya akan melenyapkan kemuliaan kalian, bila mereka berdua dibiarkan menang, kemudian kalian cenderung kepada keduanya.\qt@no{63}}%
\qt@newcmd\qurantrans@id@mmcdxii{%
("Maka himpunkanlah segala daya upaya kalian) semua kekuatan dan keahlian sihir kalian. Kalau dibaca Fajma'uu berasal dari lafal Jama'a dan kalau dibaca Fa-ajmi'uu berasal dari lafal Ajma'a, artinya kerahkanlah (kemudian datanglah dengan berbaris). Lafal Shaffan adalah Hal atau kata keterangan keadaan, maksudnya dalam keadaan berbaris (dan sesungguhnya beruntunglah) yakni akan memperoleh keuntungan (orang yang menang pada hari ini") yakni yang dapat mengalahkan musuhnya.\qt@no{64}}%
\qt@newcmd\qurantrans@id@mmcdxiii{%
(Mereka berkata, ``Hai Musa!) Pilihlah (apakah kamu yang melemparkan dahulu) tongkatmu (atau kamikah orang yang mula-mula melemparkan?") tongkat.\qt@no{65}}%
\qt@newcmd\qurantrans@id@mmcdxiv{%
(Berkata Musa, ``Silakan kamu sekalian melemparkan") maka mereka melemparkannya. (Maka tiba-tiba tali-tali dan tongkat-tongkat mereka) asal kata 'Ishiyyun adalah 'Ushuwwun, kemudian kedua huruf Wawu ditukar menjadi Ya, selanjutnya harakat huruf 'Ain dan Shad dikasrahkan, maka menjadi 'Ishiyyun (terbayang kepada Musa seakan-akan karena pengaruh sihir mereka ia) merupakan ular-ular (yang berjalan) atau merayap pada perutnya.\qt@no{66}}%
\qt@newcmd\qurantrans@id@mmcdxv{%
(Maka timbullah perasaan) muncul perasaan (takut dalam hati Musa) dia merasa takut karena ternyata sihir mereka sejenis dengan mukjizatnya, sehingga akibatnya akan mengaburkan mana yang hak dan mana yang batil di mata orang banyak, yang nantinya mereka tidak mau beriman, disebabkan kejadian itu.\qt@no{67}}%
\qt@newcmd\qurantrans@id@mmcdxvi{%
(Kami berkata) kepada Musa, ("Janganlah kamu takut, sesungguhnya kamulah yang paling unggul) kamulah yang akan mengungguli mereka.\qt@no{68}}%
\qt@newcmd\qurantrans@id@mmcdxvii{%
(Dan lemparkanlah apa yang ada di tangan kananmu) yakni tongkat (niscaya ia akan menelan) yakni akan melahap (apa yang mereka perbuat. Sesungguhnya apa yang mereka perbuat itu adalah tipu daya tukang sihir) ulah tukang sihir belaka. (Dan tidak akan menang tukang sihir itu, dari mana saja ia datang") dengan sihirnya itu. Lalu Nabi Musa melemparkan tongkatnya, maka tongkat Nabi Musa itu menjadi ular yang besar dan menelan semua apa yang diperbuat oleh para ahli sihir.\qt@no{69}}%
\qt@newcmd\qurantrans@id@mmcdxviii{%
(Lalu tukang-tukang sihir itu tersungkur dengan bersujud) yakni mereka bersujud kepada Allah swt. (seraya berkata, ``Kami telah percaya kepada Rabb Harun dan Musa").\qt@no{70}}%
\qt@newcmd\qurantrans@id@mmcdxix{%
(Berkatalah) Firaun, ("Apakah kalian telah beriman) dapat dibaca A-amantum dan Aamantum (kepada Musa sebelum aku memberi izin) sebelum aku mengizinkan (kepadamu sekalian. Sesungguhnya ia adalah pemimpin kalian) guru kalian (yang mengajarkan sihir kepada kalian. Maka sesungguhnya aku akan memotong tangan dan kaki kamu sekalian dengan bersilang secara bertimbal balik) lafal Min Khilaafin berkedudukan menjadi Hal, artinya secara bersilang, yaitu tangan kanan dengan kaki kiri (dan sesungguhnya aku akan menyalib kalian pada pangkal pohon kurma) yakni pada pohon kurma (dan sesungguhnya kalian akan mengetahui siapa di antara kita) yakni diri Firaun sendiri dan Rabb Nabi Musa (yang lebih pedih dan lebih kekal siksaannya") bila ada orang yang melanggar kepadanya.\qt@no{71}}%
\qt@newcmd\qurantrans@id@mmcdxx{%
(Mereka berkata, ``Kami sekali-kali tidak akan mengutamakan kamu) kami tidak akan memilih kamu (daripada bukti-bukti yang nyata yang telah datang kepada kami) bukti-bukti yang menunjukkan kebenaran Nabi Musa (dan daripada Tuhan yang telah menciptakan kami) yakni Allah yang telah menjadikan kami. Kalimat ini dapat diartikan sebagai Qasam atau sumpah atau di'athafkan kepada lafal Ma (maka putuskanlah apa yang hendak kamu putuskan) artinya lakukanlah apa yang kamu ucapkan itu. (Sesungguhnya kamu hanya akan dapat memutuskan pada kehidupan di dunia saja) dinashabkannya lafal Al-Hayaatad Dun-yaa menunjukkan makna Ittisa', maksudnya peradilan di dunia dan kelak kamu akan mendapat balasan yang setimpal di akhirat akibat dari perbuatanmu itu.\qt@no{72}}%
\qt@newcmd\qurantrans@id@mmcdxxi{%
(Sesungguhnya kami telah beriman kepada Rabb kami, agar Dia mengampuni kesalahan-kesalahan kami) dari kemusyrikan dan dosa-dosa lainnya yang pernah kami lakukan (dan sihir yang telah kamu paksakan kepada kami melakukannya) mulai dari belajar sampai dengan mempraktekkannya untuk melawan Nabi Musa. (Dan Allah lebih baik) pahala-Nya daripada kamu, jika Dia ditaati (dan lebih kekal") azab-Nya daripada kamu, jika didurhakai.\qt@no{73}}%
\qt@newcmd\qurantrans@id@mmcdxxii{%
Allah berfirman (Sesungguhnya barang siapa yang datang kepada Rabbnya dalam keadaan berdosa) yakni dalam keadaan kafir, sebagaimana Firaun (maka sesungguhnya baginya neraka Jahanam. Ia tidak mati di dalamnya) sehingga ia dapat istirahat dari kepedihan azab (dan tidak pula hidup) dengan kehidupan yang layak dan bermanfaat bagi dirinya.\qt@no{74}}%
\qt@newcmd\qurantrans@id@mmcdxxiii{%
(Dan barang siapa yang datang kepada Rabbnya dalam keadaan beriman, lagi sungguh-sungguh telah beramal saleh) mengerjakan amal-amal fardu dan amal-amal sunah (maka mereka itulah orang-orang yang memperoleh kedudukan-kedudukan yang tinggi) lafal Al 'Ulaa adalah bentuk jamak daripada lafal Al 'Ulyaa muannats daripada lafal Al A'laa artinya yang paling tinggi.\qt@no{75}}%
\qt@newcmd\qurantrans@id@mmcdxxiv{%
(Yaitu surga Adn) sebagai tempat tinggalnya, lafal Jannaatu 'Adnin merupakan penjelasan daripada kedudukan tadi (yang mengalir sungai-sungai di bawahnya, mereka kekal di dalamnya. Dan itu adalah balasan bagi orang yang bersih) daripada dosa-dosa.\qt@no{76}}%
\qt@newcmd\qurantrans@id@mmcdxxv{%
(Dan sesungguhnya telah Kami wahyukan kepada Musa, ``Pergilah kalian dengan hamba-hamba-Ku di malam hari) jika dibaca Asri berasal dari Asraa dan jika dibaca Anisri dengan memakai Hamzah Washal, berasal dari kata Saraa, demikian menurut dua pendapat mengenainya, artinya: bawalah mereka pergi di malam hari dari negeri Mesir (maka buatlah untuk mereka) dengan tongkatmu itu (jalan yang kering di laut itu) artinya, jalan yang keadaannya telah kering. Nabi Musa mengerjakan apa yang telah diperintahkan kepadanya, lalu Allah mengeringkan jalan yang dilalui mereka, sehingga mereka dapat melaluinya (kamu tak usah khawatir akan tersusul) dapat terkejar oleh Firaun (dan tidak usah takut") tenggelam.\qt@no{77}}%
\qt@newcmd\qurantrans@id@mmcdxxvi{%
(Maka Firaun dengan bala tentaranya mengejar mereka) Firaun pun ikut bersama dengan bala tentaranya (lalu mereka ditutup oleh laut) yakni laut itu melanda mereka (yang menenggelamkan mereka) akhirnya Firaun bersama dengan balatentaranya tenggelam.\qt@no{78}}%
\qt@newcmd\qurantrans@id@mmcdxxvii{%
(Dan Firaun telah menyesatkan kaumnya) dengan menyeru mereka supaya menyembah dirinya (dan tidak memberi petunjuk) akan tetapi justru Firaun menjerumuskan mereka ke dalam kebinasaan, berbeda halnya dengan apa yang telah diungkapkannya, yang kemudian disitir oleh firman-Nya, yaitu: (Firaun berkata), ``Dan aku tiada menunjukkan kepada kalian melainkan jalan yang benar" (Q.S. Al-Mukmin 29).\qt@no{79}}%
\qt@newcmd\qurantrans@id@mmcdxxviii{%
(Hai Bani Israel! Sesungguhnya Kami telah menyelamatkan kamu sekalian dari musuh kalian) yakni Firaun dengan menenggelamkannya (dan Kami telah mengadakan perjanjian dengan kamu sekalian di sebelah kanan bukit Thur) kemudian Kami memberikan kitab Taurat kepada Musa untuk diamalkan (dan Kami telah menurunkan kepada kamu sekalian manna dan salwa) yaitu dinamakan pula Taranjabin dan burung Sammani. Sedangkan orang-orang yang diseru dalam ayat ini adalah orang-orang Yahudi yang hidup di masa Nabi saw. Allah swt. berbicara kepada mereka seraya mengingatkan akan nikmat-nikmat yang telah dilimpahkan-Nya kepada kakek moyang mereka di zaman Nabi Musa. Dimaksud sebagai pendahuluan terhadap apa yang akan diungkapkan oleh Allah pada firman selanjutnya, yaitu:\qt@no{80}}%
\qt@newcmd\qurantrans@id@mmcdxxix{%
(Makanlah di antara rezeki yang baik yang telah kami berikan kepada kalian) yakni nikmat yang telah dilimpahkan kepada kalian (dan janganlah melampaui batas padanya) seumpamanya kalian mengingkari nikmat-nikmat itu (yang menyebabkan kemurkaan-Ku menimpa kalian) bila dibaca Yahilla artinya wajib kemurkaan-Ku menimpa kalian. Dan jika dibaca Yahulla artinya, pasti kemurkaan-Ku menimpa kalian (Dan barang siapa ditimpa oleh kemurkaan-Ku) lafal Yahlil dapat pula dibaca Yahlul (maka sungguh binasalah ia) terjerumuslah ia ke dalam neraka.\qt@no{81}}%
\qt@newcmd\qurantrans@id@mmcdxxx{%
(Dan sesungguhnya Aku Maha Pengampun bagi orang yang bertobat) dari kemusyrikan (dan beriman) mentauhidkan Allah (dan beramal saleh) yakni mengamalkan fardu dan sunah (kemudian tetap di jalan yang benar) tetap mengamalkan apa yang telah disebutkan di atas hingga umurnya habis.\qt@no{82}}%
\qt@newcmd\qurantrans@id@mmcdxxxi{%
(Mengapa kamu datang lebih cepat daripada kaummu) lebih cepat dari janji yang telah ditentukan untuk mengambil kitab Taurat (hai Musa?)\qt@no{83}}%
\qt@newcmd\qurantrans@id@mmcdxxxii{%
(Berkata Musa, ``Itulah mereka) dekat denganku berdatangan (sedang menyusul aku dan aku bersegera kepada-Mu, Ya Rabbku, supaya Engkau rida") kepadaku, lebih daripada keridaan-Mu kepadaku sebelumnya. Sebelum menjawab pertanyaan Allah, Nabi Musa terlebih dahulu memohon maaf kepada-Nya, hal ini dia lakukan menurut dugaannya. Akan tetapi ternyata kenyataannya berbeda dengan apa yang diduga sebelumnya, yaitu ketika Allah berfirman pada ayat selanjutnya.\qt@no{84}}%
\qt@newcmd\qurantrans@id@mmcdxxxiii{%
(Berfirman Allah) subhaanahu wa taala, ("Maka sesungguhnya Kami telah menguji kaummu sesudah kamu tinggalkan) sesudah kamu berpisah meninggalkan mereka (dan mereka telah disesatkan oleh Samiri") yang menjerumuskan mereka sehingga mereka menyembah anak sapi.\qt@no{85}}%
\qt@newcmd\qurantrans@id@mmcdxxxiv{%
(Kemudian Musa kembali kepada kaumnya dengan marah) disebabkan tingkah laku kaumnya itu (dan bersedih hati) yakni dengan hati yang sangat sedih (Berkata Musa, ``Hai kaumku! Bukankah Rabb kalian telah menjanjikan kepada kalian suatu janji yang baik?) janji yang benar, bahwa Dia akan memberi kitab Taurat kepada kalian. (Maka apakah terasa lama masa yang berlalu itu bagi kalian) yakni masa perpisahanku dengan kalian (atau kalian menghendaki agar menimpa) (kalian kemurkaan dari Rabb kalian) disebabkan kalian menyembah anak sapi (dan kalian melanggar perjanjian kalian dengan aku?") padahal sebelumnya kalian telah berjanji akan datang sesudahku, tetapi ternyata kalian tidak mau datang.\qt@no{86}}%
\qt@newcmd\qurantrans@id@mmcdxxxv{%
(Mereka berkata, ``Kami sekali-kali tidak melanggar perjanjianmu dengan kemauan kami sendiri) lafal Bimalkinaa dapat pula dibaca Bimilkinaa atau Bimulkinaa, artinya dengan kehendak kami sendiri, atau dengan kemauan kami sendiri (tetapi kami disuruh membawa) dapat dibaca Hammalnaa atau Hummilnaa (beban-beban) yakni beban yang berat-berat (dari perhiasan kaum itu) yakni perhiasan milik kaum Firaun, yang mereka pinjam dahulu untuk keperluan pengantin, kini perhiasan itu masih berada di tangan mereka (maka kami telah melemparkannya) kami mencampakkannya ke dalam api atas perintah Samiri (dan demikian pula) sebagaimana kami melemparkannya (Samiri melemparkannya") yakni ia pun ikut melemparkan perhiasan kaum Firaun yang masih ada padanya dan ia melemparkan pula tanah Yang ia ambil dari bekas teracak kuda malaikat Jibril dengan cara seperti berikut ini.\qt@no{87}}%
\qt@newcmd\qurantrans@id@mmcdxxxvi{%
(Kemudian Samiri mengeluarkan untuk mereka anak lembu) yang berhasil ia cetak dari perhiasan itu (yang bertubuh) yakni ada daging dan darahnya (dan bersuara) suaranya dapat didengar. Anak lembu itu menjadi demikian disebabkan pengaruh tanah bekas teracak kuda malaikat Jibril, sehingga ia dapat hidup. Tanah itu diletakkan oleh Samiri ke dalam mulut lembu itu sesudah dicetak, lalu anak lembu itu menjadi hidup (maka mereka berkata) yakni Samiri dan para pengikutnya, ("Inilah Tuhan kalian dan Tuhan Musa, tetapi ia telah lupa") Musa telah lupa akan Tuhannya, bahwa Dia ada di sini, lalu pergi mencari-Nya. Maka Allah berfirman:\qt@no{88}}%
\qt@newcmd\qurantrans@id@mmcdxxxvii{%
(Maka apakah mereka tidak memperhatikan bahwa patung anak lembu itu) lafal Allaa merupakan gabungan daripada Ann yang ditakhfif dari Anna dan Laa, sedangkan isim Ann tidak disebutkan, asalnya Annahu Laa, artinya, bahwasanya anak lembu itu (tidak dapat memberi) tidak dapat memberikan (jawaban kepada mereka) yakni tidak dapat menyahuti perkataan mereka (dan tidak dapat memberi kemudaratan kepada mereka) maksudnya tidak dapat menolak kemudaratan yang menimpa mereka (dan tidak pula kemanfaatan?) tidak dapat mendatangkan kemanfaatan buat mereka. Maksudnya, mengapa mereka menjadikannya sebagai Tuhan?\qt@no{89}}%
\qt@newcmd\qurantrans@id@mmcdxxxviii{%
(Dan sesungguhnya Harun telah berkata kepada mereka sebelumnya) sebelum Nabi Musa kembali kepada mereka ("Hai kaumku! Sesungguhnya kalian hanya diberi cobaan dengan anak lembu itu dan sesungguhnya Rabb kalian ialah Yang Maha Pemurah, maka ikutilah aku) yakni menyembah kepada-Nya (dan taatilah perintahku") di dalam menyembah kepada-Nya.\qt@no{90}}%
\qt@newcmd\qurantrans@id@mmcdxxxix{%
(Mereka menjawab, ``Kami akan tetap) kami akan terus (menyembah patung anak lembu ini) (hingga Musa kembali kepada kami").\qt@no{91}}%
\qt@newcmd\qurantrans@id@mmcdxl{%
(Berkata Musa) setelah ia kembali kepada mereka, ("Hai Harun! Apa yang menghalangi kamu ketika kamu melihat mereka sesat,) ketika mereka menyembah patung anak lembu itu.\qt@no{92}}%
\qt@newcmd\qurantrans@id@mmcdxli{%
(Sehingga kamu tidak mengikuti aku?) huruf Laa di sini Zaidah. (Maka apakah kamu telah sengaja mendurhakai perintahku?") disebabkan kamu tinggal diam di antara orang-orang yang menyembah selain Allah swt.\qt@no{93}}%
\qt@newcmd\qurantrans@id@mmcdxlii{%
(Berkatalah) Harun ("Hai putra ibuku!) dapat dibaca Ummi dan Umma maksudnya ibuku, Nabi Harun sengaja menyebut nama ini untuk mengharapkan belas kasihan dari Nabi Musa (Janganlah kamu pegang janggutku) Nabi Musa memegang janggut Nabi Harun dengan tangan kirinya (dan jangan pula kepalaku) Nabi Musa memegang rambut kepala Nabi Harun dengan tangan kanannya sebagai pelampiasan kemarahannya (sesungguhnya aku khawatir) seandainya aku mengikutimu, maka pastilah akan mengikutiku pula segolongan orang-orang yang menyembah anak lembu itu (bahwa kamu akan berkata kepadaku, 'Kamu telah memecah belah antara Bani Israel) lalu kamu marah kepadaku (dan kamu tidak menunggu) (perintahku") di dalam mengambil sikap.\qt@no{94}}%
\qt@newcmd\qurantrans@id@mmcdxliii{%
Berkata Musa, ``Apakah yang mendorongmu) berbuat demikian (hai Samiri?")\qt@no{95}}%
\qt@newcmd\qurantrans@id@mmcdxliv{%
(Samiri menjawab, ``Aku mengetahui sesuatu yang mereka tidak mengetahuinya) dapat dibaca Yabshuruu dan Tabshuruu, artinya, aku mengetahui apa yang tidak mereka ketahui (maka aku ambil segenggam dari) tanah (bekas) jejak teracak kuda (rasul) yakni malaikat Jibril (lalu aku melemparkannya) yakni aku menaruhnya pada patung anak lembu yang telah dicetak (dan demikianlah telah menggoda) telah membujuk (aku hawa nafsuku") untuk menaruhnya ke dalam tubuhnya, yaitu setelah terlebih dahulu aku mengambil segenggam tanah bekas jejak teracak kuda malaikat Jibril. Lalu tanah itu aku taruh ke dalam patung yang tidak bernyawa, hingga patung itu menjadi hidup bagaikan ada rohnya. Kemudian aku melihat bahwa kaummu meminta kepadamu untuk menjadikan tuhan buat mereka. Lalu hatiku menggodaku untuk menjadikan patung anak lembu itu sebagai tuhan mereka.\qt@no{96}}%
\qt@newcmd\qurantrans@id@mmcdxlv{%
(Berkata Musa) kepada Samiri, ("Pergilah kamu) dari kalangan kami ini (maka sesungguhnya bagimu di dalam kehidupan di dunia ini) selama kamu hidup di dalamnya (hanya dapat mengatakan) kepada orang-orang yang kamu bertemu dengannya, ('Janganlah menyentuhku') janganlah kamu mendekat kepadaku. Dan disebutkan bahwa sejak saat itu Samiri mengembara tanpa tujuan dan jika ada seseorang menyentuhnya atau dia menyentuhnya, maka semuanya kena penyakit demam. (Dan sesungguhnya bagimu telah ada ketentuan waktu) bagi hukumanmu (yang kamu sekali-kali tidak dapat menghindarinya) jika dibaca Lan tukhlifahu artinya, kamu tidak dapat selamat dari azab itu. Dan jika dibaca Lan Tukhlafahu artinya, kamu dibangkitkan kelak di hari kiamat untuk diazab (dan lihatlah tuhanmu itu yang kamu tetap) lafal Zhalta asalnya dibaca Zhalilta, kemudian Lam yang pertama dibuang sehingga jadilah Zhalta artinya yang kamu selamanya (menyembah kepadanya) tetap menyembahnya. (Sesungguhnya kami akan membakarnya) dengan api (kemudian kami sungguh-sungguh akan menghambur-hamburkannya ke dalam laut) berupa abu yang berserakan terbawa oleh angin laut. Dan Nabi Musa mengerjakan apa yang telah dikatakannya itu setelah terlebih dahulu menyembelihnya.\qt@no{97}}%
\qt@newcmd\qurantrans@id@mmcdxlvi{%
(Sesungguhnya Tuhan kalian hanyalah Allah yang tidak ada Tuhan selain Dia, pengetahuan-Nya meliputi segala sesuatu) lafal 'Ilman adalah Tamyiz yang dipindahkan dari bentuk Fa'ilnya, artinya, pengetahuan-Nya meliputi segala sesuatu.\qt@no{98}}%
\qt@newcmd\qurantrans@id@mmcdxlvii{%
(Demikianlah) sebagaimana Kami telah mengisahkan cerita ini kepadamu, hai Muhammad (Kami kisahkan kepadamu sebagian kisah) berita (umat yang telah silam) yakni bangsa-bangsa di masa lampau (dan sesungguhnya telah Kami berikan kepadamu) yakni Kami telah memberimu (dari sisi Kami) yakni dari hadirat Kami (suatu peringatan) yakni Alquran.\qt@no{99}}%
\qt@newcmd\qurantrans@id@mmcdxlviii{%
(Barang siapa berpaling daripada Alquran) artinya ia tidak beriman kepada Alquran (maka sesungguhnya ia akan memikul dosa yang besar di hari kiamat) beban yang sangat berat berupa dosa-dosa.\qt@no{100}}%
\qt@newcmd\qurantrans@id@mmcdxlix{%
(Mereka kekal di dalamnya) menanggung azab dosanya untuk selamanya. (Dan amat buruklah dosa itu sebagai beban bagi mereka di hari kiamat) lafal Himlan merupakan Tamyiz yang menafsirkan makna Dhamir dalam lafal Saa'a, sedangkan subjek yang dicelanya dibuang yaitu lafal Wizrahum, artinya dosa mereka. Huruf Lam yang ada pada lafal Lahum berfungsi untuk menerangkan. Kemudian lafal Yaumal Qiyaamah dijelaskan oleh ayat berikutnya, yaitu:\qt@no{101}}%
\qt@newcmd\qurantrans@id@mmcdl{%
(Yaitu di hari yang di waktu itu ditiup sangkakala) untuk tiupan yang kedua kalinya (dan Kami akan mengumpulkan orang-orang yang berdosa) yaitu orang-orang kafir (pada hari itu dengan mata yang biru muram) yakni mata mereka tampak membiru dan muka mereka tampak hitam karena muram.\qt@no{102}}%
\qt@newcmd\qurantrans@id@mmcdli{%
(Mereka berbisik-bisik di antara mereka sendiri) yaitu berbicara dengan suara yang pelan-pelan ("Tidaklah) (kalian tinggal) di dunia (melainkan sepuluh) hari."\qt@no{103}}%
\qt@newcmd\qurantrans@id@mmcdlii{%
(Kami lebih mengetahui apa yang mereka katakan) dalam bisikan mereka itu. Maksudnya, keadaannya tidaklah seperti apa yang mereka katakan (ketika berkata orang yang paling tepat di antara mereka) yakni paling lurus (penilaiannya) sehubungan dengan hal ini, ("Kalian tidak berdiam di dunia melainkan hanya sehari saja") mereka menilai minim sekali masa tinggal mereka di dunia, hal ini disebabkan kengerian-kengerian yang mereka saksikan di alam akhirat.\qt@no{104}}%
\qt@newcmd\qurantrans@id@mmcdliii{%
(Dan mereka bertanya kepadamu tentang gunung-gunung,) bagaimana jadinya di hari kiamat nanti? (maka katakanlah) kepada mereka ("Rabbku akan menghancurkannya sehancur-hancurnya,) seumpamanya Dia meleburkannya menjadi debu yang lembut kemudian diterbangkan-Nya dengan angin.\qt@no{105}}%
\qt@newcmd\qurantrans@id@mmcdliv{%
(Maka Dia akan menjadikan bekas gunung-gunung itu datar) merata (dengan tanah) yakni rata sama sekali tiada bekasnya.\qt@no{106}}%
\qt@newcmd\qurantrans@id@mmcdlv{%
(Tidak ada sedikit pun kamu lihat padanya tempat yang melengkung) tempat yang rendah (dan tidak pula tempat yang tinggi) tempat yang tinggi-tinggi.\qt@no{107}}%
\qt@newcmd\qurantrans@id@mmcdlvi{%
(Pada hari itu) pada hari ketika gunung-gunung itu dihancurkan (manusia mengikuti) manusia semuanya mengikuti sesudah mereka dibangunkan dari kuburannya (penyeru) yang menggiring mereka dengan suaranya ke padang Mahsyar, dia adalah malaikat Israfil. Dia mengatakan, ``Kemarilah kamu sekalian ke hadapan Tuhan Yang Maha Pemurah" (dengan tidak berbelok-belok) sewaktu mereka menuruti panggilan suara itu. Atau dengan kata lain mereka tidak mempunyai kemampuan untuk tidak mengikuti anjuran suara itu (dan merendahlah) yakni menjadi tenanglah (semua suara kepada Tuhan Yang Maha Pemurah, maka kamu tidak mendengar melainkan hanya bisikan saja) suara telapak kaki mereka sewaktu berjalan menuju ke padang Mahsyar bagaikan suara teracak kaki unta bila berjalan.\qt@no{108}}%
\qt@newcmd\qurantrans@id@mmcdlvii{%
(Pada hari itu tidak berguna syafaat) seseorang (kecuali syafaat orang yang Allah Maha Pemurah telah memberi izin kepadanya) untuk memberi syafaat (dan Dia telah meridai perkataannya) seumpamanya orang yang diberi izin itu mengatakan, ``La Ilaaha Illallaah atau tidak ada Tuhan selain Allah."\qt@no{109}}%
\qt@newcmd\qurantrans@id@mmcdlviii{%
(Dia mengetahui apa yang ada di hadapan mereka) yaitu perkara-perkara akhirat (dan apa yang ada di belakang mereka) perkara-perkara dunia (sedangkan ilmu mereka tidak dapat meliputi ilmu-Nya") yakni mereka tidak mengetahui hal tersebut.\qt@no{110}}%
\qt@newcmd\qurantrans@id@mmcdlix{%
(Dan tunduklah semua muka) tunduk merendahkan diri (kepada Tuhan Yang Hidup Kekal lagi Maha Memelihara) yakni Allah swt. (Dan sesungguhnya telah merugilah) (orang yang melakukan kelaliman) yakni kemusyrikan.\qt@no{111}}%
\qt@newcmd\qurantrans@id@mmcdlx{%
(Dan barang siapa mengerjakan amal yang saleh) amal-amal ketaatan (dan ia dalam keadaan beriman, maka ia tidak khawatir akan diperlakukan tidak adil) dengan diberatkan dosanya (dan tidak pula akan pengurangan haknya) dikurangi pahala kebaikannya.\qt@no{112}}%
\qt@newcmd\qurantrans@id@mmcdlxi{%
(Dan demikianlah) lafal Kadzaalika dia'athafkan kepada Kadzaalika Naqushshu pada ayat sembilan puluh sembilan. Artinya: Demikianlah sebagaimana diturunkannya apa yang telah Kami ceritakan tadi (Kami menurunkannya) Alquran (dalam bahasa Arab dan Kami telah menerangkan dengan berulang-ulang) (di dalamnya sebagian dari ancaman, agar mereka bertakwa) takut kepada kemusyrikan (atau agar ia menimbulkan) Alquran ini (pengajaran bagi mereka) melalui kebinasaan yang telah dialami oleh umat-umat sebelumnya sehingga mereka mengambil pelajaran daripadanya.\qt@no{113}}%
\qt@newcmd\qurantrans@id@mmcdlxii{%
(Maka Maha Tinggi Allah Raja Yang sesungguhnya) daripada apa yang dikatakan oleh orang-orang musyrik (dan janganlah kamu tergesa-gesa terhadap Alquran) sewaktu kamu membacanya (sebelum disempurnakan mewahyukannya kepadamu) sebelum malaikat Jibril selesai menyampaikannya (dan katakanlah, ``Ya Rabbku! Tambahkanlah kepadaku ilmu pengetahuan") tentang Alquran, sehingga setiap kali diturunkan kepadanya Alquran, makin bertambah ilmu pengetahuannya.\qt@no{114}}%
\qt@newcmd\qurantrans@id@mmcdlxiii{%
(Dan sesungguhnya telah Kami perintahkan kepada Adam) Kami telah berwasiat kepadanya, janganlah ia memakan buah pohon terlarang ini (dahulu) sebelum ia memakannya (maka ia lupa) melupakan perintah kami itu (dan tidak Kami dapati padanya kemauan yang kuat) keteguhan dan kesabaran daripada apa yang Kami larang ia mengerjakannya.\qt@no{115}}%
\qt@newcmd\qurantrans@id@mmcdlxiv{%
(Dan) ingatlah (ketika Kami berkata kepada Malaikat, ``Sujudlah kalian kepada Adam!" Maka mereka sujud kecuali iblis) dia adalah bapaknya jin, dia dahulu berteman dengan para Malaikat dan ikut menyembah Allah bersama dengan para Malaikat (ia membangkang) tidak mau sujud kepada Nabi Adam; bahkan mengatakan sebagaimana yang telah disitir oleh firman-Nya; Iblis menjawab, ``Saya lebih baik daripadanya..." (Q.S. Al-A'raf, 12).\qt@no{116}}%
\qt@newcmd\qurantrans@id@mmcdlxv{%
(Maka Kami berkata, ``Hai Adam! Sesungguhnya iblis ini adalah musuh bagimu dan bagi istrimu) yakni Siti Hawa (maka sekali-kali janganlah sampai ia mengeluarkan kamu berdua dari surga, yang menyebabkan kamu menjadi sengsara) hidup sengsara disebabkan terlebih dahulu kamu harus mencangkul, menanam, menuai, menumbuk, membuat roti dan lain sebagainya. Ungkapan sengsara di sini ditujukan hanya kepada Nabi Adam, disebabkan secara fitrah suami itu mencari nafkah buat istrinya.\qt@no{117}}%
\qt@newcmd\qurantrans@id@mmcdlxvi{%
(Sesungguhnya kamu tidak akan kelaparan di dalamnya dan tidak akan telanjang). Lafal Allaa adalah gabungan daripada huruf An dan Laa.\qt@no{118}}%
\qt@newcmd\qurantrans@id@mmcdlxvii{%
(Dan sesungguhnya kamu) baik dibaca Annaka atau Innaka, diathafkan kepada isimnya Inna pada ayat sebelumnya dan jumlah kalimat kelanjutannya ialah (tidak akan merasa dahaga di dalamnya) yakni tidak akan merasa haus (dan tidak pula akan ditimpa panas matahari di dalamnya") yaitu sinar matahari di waktu dhuha tidak akan kamu alami lagi, karena di dalam surga tidak ada matahari.\qt@no{119}}%
\qt@newcmd\qurantrans@id@mmcdlxviii{%
(Kemudian setan membisikkan pikiran jahat kepadanya seraya berkata, ``Hai Adam! Maukah saya tunjukkan kepada kamu pohon keabadian) yaitu pohon yang barang siapa memakan buahnya akan hidup kekal (dan kerajaan yang tidak akan binasa?") yakni kerajaan yang kekal.\qt@no{120}}%
\qt@newcmd\qurantrans@id@mmcdlxix{%
(Maka keduanya memakan) yakni Adam dan Hawa (dari buah pohon itu, lalu tampaklah bagi keduanya aurat-auratnya) yakni keduanya dapat melihat kemaluan masing-masing. Kedua aurat itu dinamakan kemaluan disebabkan jika kelihatan maka orang yang memilikinya menjadi malu (dan mulailah keduanya menutupi) keduanya menempelkan kepada (aurat masing-masing dengan daun-daun yang ada di surga) untuk menutupi auratnya (dan durhakalah Adam kepada Rabbnya dan sesatlah ia) disebabkan memakan buah pohon yang terlarang itu.\qt@no{121}}%
\qt@newcmd\qurantrans@id@mmcdlxx{%
(Kemudian Rabbnya memilihnya) yakni mendekatkannya ke sisi-Nya (maka Dia menerima tobatnya) sebelum Nabi Adam bertobat (dan memberinya petunjuk) supaya terus-menerus bertobat.\qt@no{122}}%
\qt@newcmd\qurantrans@id@mmcdlxxi{%
(Allah berfirman, ``Turunlah kamu berdua) Adam dan Hawa berikut apa yang telah dikandung oleh kalian yaitu anak cucu kalian (daripadanya) dari surga (bersama-sama, sebagian kalian) sebagian keturunan kalian (menjadi musuh bagi sebagian yang lain) disebabkan sebagian dari mereka berbuat zalim terhadap sebagian yang lain. (Maka jika) lafal Imma ini asalnya terdiri dari In Syarthiyah yang diidgamkan kepada Ma Zaidah (jika datang kepada kalian petunjuk daripada-Ku maka barang siapa yang mengikuti petunjuk-Ku) yakni Alquran (maka ia tidak akan sesat) di dunia (dan tidak akan celaka) di akhirat nanti.\qt@no{123}}%
\qt@newcmd\qurantrans@id@mmcdlxxii{%
(Dan barang siapa berpaling dari peringatan-Ku) yakni Alquran, yaitu dia tidak beriman kepadanya (maka sesungguhnya baginya penghidupan yang sempit) lafal Dhankan ini merupakan Mashdar artinya sempit. Ditafsirkan oleh sebuah hadis, bahwa hal ini menunjukkan tentang diazabnya orang kafir di dalam kuburnya (dan Kami akan mengumpulkannya) orang yang berpaling dari Alquran (pada hari kiamat dalam keadaan buta") penglihatannya.\qt@no{124}}%
\qt@newcmd\qurantrans@id@mmcdlxxiii{%
(Berkatalah ia, ``Ya Rabbku! Mengapa Engkau menghimpun aku dalam keadaan buta, padahal dahulunya aku adalah orang yang melihat?") yakni di kala ia hidup di dunia melihat tetapi di kala ia dibangkitkan hidup kembali buta.\qt@no{125}}%
\qt@newcmd\qurantrans@id@mmcdlxxiv{%
(Allah berfirman,) perkaranya ("Demikianlah, telah datang kepadamu ayat-ayat Kami, maka kamu melupakannya) kamu meninggalkannya dan tidak mau beriman kepadanya (dan begitu pula) sebagaimana kamu lupa kepada ayat-ayat Kami (pada hari ini kamu pun dilupakan") dibiarkan tinggal di dalam neraka.\qt@no{126}}%
\qt@newcmd\qurantrans@id@mmcdlxxv{%
(Dan demikianlah) sebagaimana Kami membalas kepada orang yang berpaling daripada Alquran (Kami membalas orang yang melampaui batas) orang yang musyrik (dan tidak percaya kepada ayat-ayat Rabbnya. Dan sesungguhnya azab di akhirat itu lebih berat) daripada azab di dunia dan azab kubur (dan lebih kekal) lebih abadi.\qt@no{127}}%
\qt@newcmd\qurantrans@id@mmcdlxxvi{%
(Maka tidakkah menjadi petunjuk) yakni tidak jelas (bagi mereka) orang-orang kafir Mekah (berapa banyak) lafal Kam di sini adalah kalimat berita yang berkedudukan menjadi maf'ul (Kami membinasakan) sudah berapa banyak telah Kami binasakan (umat-umat sebelum mereka) umat-umat terdahulu disebabkan mereka mendustakan Rasul-rasul (padahal mereka berjalan) Lafal Yamsyuuna ini menjadi Hal daripada Dhamir Lahum (melewati peninggalan umat-umat itu?) sewaktu mereka berniaga ke negeri Syam dan negeri-negeri yang lain, seharusnya mereka mengambil pelajaran daripadanya. Disebutkan pengertian membinasakan, hal ini diambil dari Fi'il atau kata kerjanya tanpa memakai huruf Mashdar demi memelihara keselarasan makna, maka hal ini tidak dilarang. (Sesungguhnya pada yang demikian itu terdapat tanda-tanda) pelajaran-pelajaran (bagi orang-orang yang berakal) yakni bagi mereka yang berakal.\qt@no{128}}%
\qt@newcmd\qurantrans@id@mmcdlxxvii{%
(Dan sekiranya tidak ada suatu ketetapan dari Rabbmu yang telah terdahulu) untuk menangguhkan azab daripada mereka hingga hari kemudian (niscayalah) pembinasaan itu (pasti) menimpa mereka sejak di dunia (dan waktu yang telah ditentukan) waktu yang telah dipastikan bagi azab mereka. Kalimat ayat ini di'athafkan kepada Dhamir yang terkandung di dalam lafal Kaana dan menjadi pemisah di antara keduanya adalah Khabar Kaana yang berfungsi sebagai pengukuh makna. Maksudnya; dan di hari kemudian, azab akan menimpa mereka pula.\qt@no{129}}%
\qt@newcmd\qurantrans@id@mmcdlxxviii{%
(Maka sabarlah kamu atas apa yang mereka katakan) hanya saja ayat ini dimansukh oleh ayat berperang (dan bertasbihlah) salatlah (dengan memuji Rabbmu) lafal Bihamdi Rabbika merupakan Hal atau kata keterangan keadaan, maksudnya seraya memuji-Nya (sebelum terbit matahari) yaitu salat Subuh (dan sebelum terbenamnya) salat Asar (dan pada waktu-waktu di malam hari) saat-saat malam hari (bertasbih pulalah) yaitu salat Magrib dan salat Isyaklah kamu (dan pada waktu-waktu di siang hari) ia di'athafkan secara Mahal kepada lafal Ana yang dinashabkan. Maksudnya salat Zuhurlah kamu; karena waktu salat Zuhur itu mulai sejak bergeser matahari dari garis pertengahan langit; yaitu bergesernya matahari dari bagian pertengahan pertama menuju kepada bagian pertengahan kedua (supaya kamu merasa senang) dengan pahala yang akan diberikan kepadamu.\qt@no{130}}%
\qt@newcmd\qurantrans@id@mmcdlxxix{%
(Dan janganlah kamu tujukan kedua matamu kepada apa yang telah Kami berikan kepada golongan-golongan) yakni berbagai macam golongan (dari mereka, sebagai bunga kehidupan dunia) sebagai perhiasan dan kesemarakan kehidupan dunia (Kami cobai mereka dengannya) seumpamanya mereka makin kelewat batas karenanya. (Dan karunia Rabbmu) di surga (adalah lebih baik) daripada keduniaan yang diberikan kepada mereka (dan lebih kekal) yakni lebih abadi.\qt@no{131}}%
\qt@newcmd\qurantrans@id@mmcdlxxx{%
(Dan perintahkanlah kepada keluargamu mendirikan salat dan bersabarlah kamu) teguh dan sabarlah kamu (dalam mengerjakannya. Kami tidak meminta kepadamu) tidak membebankan kepadamu (rezeki) untuk dirimu dan tidak pula untuk orang lain (Kamilah yang memberi rezeki kepadamu. Dan akibat yang baik itu) yakni pahala surga (hanyalah bagi ketakwaan) bagi orang yang bertakwa.\qt@no{132}}%
\qt@newcmd\qurantrans@id@mmcdlxxxi{%
(Dan mereka berkata,) orang-orang musyrik ("Mengapa tidak) tidakkah (ia datang kepada kami) yakni Nabi Muhammad (dengan membawa bukti dari Rabbnya?") sesuai dengan apa yang diminta mereka. (Dan apakah belum datang kepada mereka) dapat dibaca Ta-tihim dan Ya-tihim (bukti yang nyata) yakni penjelasan (dari apa yang tersebut di dalam kitab-kitab yang terdahulu?) yang kesemuanya disebutkan oleh Alquran, yaitu mengenai berita umat-umat terdahulu yang telah dibinasakan disebabkan mereka mendustakan para Rasul.\qt@no{133}}%
\qt@newcmd\qurantrans@id@mmcdlxxxii{%
(Dan sekiranya Kami binasakan mereka dengan suatu azab sebelum ia diutus) sebelum Rasulullah diutus (tentulah mereka berkata) di hari kiamat nanti, ("Ya Rabb kami! Mengapa tidak) (Engkau utus seorang Rasul kepada kami, lalu kami mengikuti ayat-ayat Engkau) yang dibawa olehnya (sebelum kami menjadi hina) di hari kiamat (dan rendah?") dijebloskan ke dalam neraka Jahanam.\qt@no{134}}%
\qt@newcmd\qurantrans@id@mmcdlxxxiii{%
(Katakanlah:) kepada mereka, ("Masing-masing) di antara kami dan kalian (menanti) menunggu apa yang bakal terjadi padanya di hari kiamat itu (maka nantikanlah oleh kamu sekalian! Kelak kalian akan mengetahui) di hari kiamat itu (siapa yang menempuh jalan) yakni tuntunan (yang lurus) yang tidak menyimpang (dan siapa yang telah mendapat petunjuk") sehingga selamat dari kesesatan, kami ataukah kalian?\qt@no{135}}%
\qt@newcmd\qurantrans@id@mmcdlxxxiv{%
\basmalahid (Telah dekat kepada manusia) kepada penduduk Mekah yang ingkar terhadap adanya hari berbangkit (hari penghisaban mereka) yaitu hari kiamat (sedang mereka berada dalam kelalaian) daripadanya (lagi berpaling) tidak bersiap-siap untuk menghadapinya, yaitu dengan bekal iman.\qt@no{1}}%
\qt@newcmd\qurantrans@id@mmcdlxxxv{%
(Tidak datang kepada mereka suatu ayat Alquran pun yang baru diturunkan dari Rabb mereka) secara berangsur-angsur, yakni lafal Alquran (melainkan mereka mendengarnya, sedang mereka bermain-main) mereka memperolok-oloknya.\qt@no{2}}%
\qt@newcmd\qurantrans@id@mmcdlxxxvi{%
(Lagi dalam keadaan lalai) yakni kosong (hati mereka) untuk merenungkan makna-maknanya. (Dan mereka berbisik-bisik) mereka merahasiakan pembicaraan mereka (yakni orang-orang yang zalim itu) lafal ayat ini merupakan Badal daripada Dhamir Wawu yang terdapat di dalam lafal Wa Asarrun Najwa ("Orang ini tidak lain) yakni Nabi Muhammad (hanyalah seorang manusia seperti kalian) dan yang disampaikannya itu adalah sihir belaka (maka apakah kalian menerima sihir itu) yakni apakah kalian mau mengikutinya (padahal kalian menyaksikannya?") sedangkan kalian telah mengetahui, bahwa yang disampaikan itu adalah sihir.\qt@no{3}}%
\qt@newcmd\qurantrans@id@mmcdlxxxvii{%
(Berkatalah Muhammad) kepada mereka, ("Rabbku mengetahui semua perkataan) yang ada (di langit dan di bumi dan Dialah Yang Maha Mendengar) semua apa yang mereka rahasiakan di dalam pembicaraannya (lagi Maha Mengetahui") apa yang mereka rahasiakan.\qt@no{4}}%
\qt@newcmd\qurantrans@id@mmcdlxxxviii{%
(Bahkan) lafal Bal menunjukkan makna Intiqal atau memindahkan suatu pembicaraan kepada pembicaraan yang lain. Hal ini bersifat tetap di dalam ketiga tempat I'rab (mereka berkata pula:) dalam menanggapi Alquran yang diturunkan kepada Nabi Muhammad, bahwa Alquran itu adalah ("Mimpi-mimpi yang kalut) mimpi yang tidak menentu yang dilihat dalam tidurnya (malah diada-adakannya) dialah yang membuat-buatnya (bahkan dia sendiri seorang penyair) maka jelas yang disampaikannya itu adalah syair (maka hendaklah ia mendatangkan kepada kita suatu mukjizat, sebagaimana Rasul-rasul yang telah lalu diutus") yaitu semacam mukjizat unta Nabi Shaleh, tongkat dan tangan Nabi Musa, maka Allah swt. berfirman:\qt@no{5}}%
\qt@newcmd\qurantrans@id@mmcdlxxxix{%
(Tidak ada suatu negeri pun yang beriman sebelum mereka) yakni penduduknya (yang Kami telah binasakan) disebabkan kedustaan mereka terhadap mukjizat-mukjizat yang didatangkan oleh Rasulnya (maka apakah mereka akan beriman?) tentu saja tidak.\qt@no{6}}%
\qt@newcmd\qurantrans@id@mmcdxc{%
(Kami tiada mengutus rasul-rasul sebelum kamu melainkan beberapa orang laki-laki yang Kami beri wahyu) menurut qiraat yang lain lafal Nuuhii dibaca Yuuhaa (kepada mereka) mereka bukanlah malaikat (maka tanyakanlah olehmu kepada orang-orang yang berilmu) yakni ulama yang mengetahui kitab Taurat dan kitab Injil (jika kalian tidak mengetahui) hal tersebut, sesungguhnya mereka mengetahuinya, mengingat kepercayaan kalian kepada ulama kitab Taurat dan Injil lebih kuat daripada kepercayaan kaum Mukminin kepada Muhammad.\qt@no{7}}%
\qt@newcmd\qurantrans@id@mmcdxci{%
(Dan tidaklah Kami jadikan mereka) para rasul itu (tubuh-tubuh) lafal Jasadun sekalipun kata tunggal tetapi maknanya jamak (yang tiada memakan makanan) tetapi justru mereka memakannya (dan tidak pula mereka itu orang-orang yang kekal) hidup di dunia.\qt@no{8}}%
\qt@newcmd\qurantrans@id@mmcdxcii{%
(Kemudian Kami tepati janji kepada mereka) yaitu untuk menyelamatkan mereka (maka Kami selamatkan mereka dan orang-orang yang Kami kehendaki) yakni orang-orang yang beriman kepada para rasul itu (dan Kami binasakan orang-orang yang melampaui batas) yaitu orang-orang yang mendustakan para rasul.\qt@no{9}}%
\qt@newcmd\qurantrans@id@mmcdxciii{%
(Sesungguhnya telah Kami turunkan kepada kalian) hai orang-orang Quraisy (sebuah Kitab yang di dalamnya disebutkan diri kalian) disebabkan ia memakai bahasa kalian sendiri. (Maka apakah kalian tiada memahaminya?) lalu beriman kepadanya.\qt@no{10}}%
\qt@newcmd\qurantrans@id@mmcdxciv{%
(Dan berapa banyaknya Kami telah binasakan) kami hancurkan (beberapa negeri) yakni penduduk-penduduknya (yang penduduknya zalim) berbuat kekafiran (dan Kami adakan sesudah mereka itu kaum yang lain).\qt@no{11}}%
\qt@newcmd\qurantrans@id@mmcdxcv{%
(Maka tatkala mereka merasakan azab Kami) penduduk negeri-negeri tersebut merasakan kebinasaannya telah dekat (tiba-tiba mereka lari tergesa-gesa daripadanya) mereka berupaya melarikan diri secepatnya.\qt@no{12}}%
\qt@newcmd\qurantrans@id@mmcdxcvi{%
Kemudian berkatalah para Malaikat pembawa azab kepada mereka dengan nada mengejek, ("Janganlah kalian lari tergesa-gesa, kembalilah kalian kepada kemewahan yang telah kalian rasakan) kepada nikmat yang telah diberikan kepada kalian (dan kepada tempat-tempat kediaman kalian, supaya kalian ditanya") tentang sesuatu dari keduniaan milik kalian, sebagaimana biasanya.\qt@no{13}}%
\qt@newcmd\qurantrans@id@mmcdxcvii{%
(Mereka berkata, ``Aduhai) huruf Ya di sini menunjukkan makna penyesalan (celakalah kami) binasalah kami (sesungguhnya kami adalah orang-orang yang zalim") disebabkan kami kafir.\qt@no{14}}%
\qt@newcmd\qurantrans@id@mmcdxcviii{%
(Maka tetaplah demikian) kalimat-kalimat itu sebagai (keluhan mereka) yang mereka serukan dan mereka ulang-ulang (sehingga Kami jadikan mereka sebagai tanaman yang telah dituai) bagaikan tanaman yang dipanen dengan sabit; seumpamanya mereka dibunuh dengan memakai pedang (yang tidak dapat hidup lagi) mereka mati bagaikan padamnya nyala api bila dimatikan.\qt@no{15}}%
\qt@newcmd\qurantrans@id@mmcdxcix{%
(Dan tidaklah Kami ciptakan langit dan bumi dan segala yang ada di antara keduanya dengan bermain-main) tiada gunanya, tetapi justru hal ini menjadi bukti yang menunjukkan kekuasaan Kami dan sekaligus sebagai manfaat buat hamba-hamba Kami.\qt@no{16}}%
\qt@newcmd\qurantrans@id@mmd{%
(Sekiranya Kami hendak membuat sesuatu permainan) hal-hal yang dapat dijadikan hiburan seperti istri dan anak (tentulah Kami membuatnya dari sisi Kami) para bidadari dan para Malaikat. (Jika Kami menghendaki berbuat) demikian, tetapi Kami tidak akan memperbuatnya dan tidak menghendakinya.\qt@no{17}}%
\qt@newcmd\qurantrans@id@mmdi{%
(Sebenarnya Kami melontarkan) yakni melemparkan (yang hak) iman (kepada yang batil) yakni kekafiran (lalu yang hak itu menghancurkannya) yakni melenyapkan yang batil (maka dengan serta merta yang batil itu lenyap) hilang. Asal makna lafal Damaghahu adalah menimpakan pukulan pada otak, yaitu tempat yang mematikan. (Dan bagi kalian) hai orang-orang kafir Mekah (kecelakaan) azab yang keras (disebabkan apa yang kalian sifatkan itu) bahwa Allah mempunyai istri atau anak.\qt@no{18}}%
\qt@newcmd\qurantrans@id@mmdii{%
(Dan kepunyaan-Nyalah) kepunyaan Allahlah (segala yang di langit dan di bumi) sebagai milik-Nya (dan makhluk yang di sisi-Nya) yakni para malaikat. Jumlah kalimat ayat ini menjadi Mubtada, sedangkan Khabarnya ialah (mereka tiada mempunyai rasa angkuh untuk menyembah-Nya dan tiada pula merasa letih) tiada merasa payah dalam menyembah-Nya.\qt@no{19}}%
\qt@newcmd\qurantrans@id@mmdiii{%
(Mereka selalu bertasbih malam dan siang dengan tiada henti-hentinya) bertasbih bagi mereka bagaikan nafas dalam diri kita; tiada sesuatu pun yang mengganggunya.\qt@no{20}}%
\qt@newcmd\qurantrans@id@mmdiv{%
(Apakah) makna lafal Am di sini sama dengan lafal Bal, artinya akan tetapi. Sedangkan Hamzah Istifhamnya menunjukkan makna ingkar (mereka mengambil tuhan-tuhan) yang diadakan (dari bumi) seperti dari batu, emas dan perak (yang mereka) yakni tuhan-tuhan itu (dapat menghidupkan) orang-orang yang telah mati? Tentu saja tidak dapat; bukanlah Tuhan melainkan yang dapat menghidupkan orang-orang yang mati.\qt@no{21}}%
\qt@newcmd\qurantrans@id@mmdv{%
(Sekiranya ada pada keduanya) di langit dan di bumi (tuhan-tuhan selain Allah tentulah keduanya itu telah rusak binasa) maksudnya akan menyimpang daripada tatanan biasanya sebagaimana yang kita saksikan sekarang, hal itu disebabkan adanya persaingan di antara dua kekuasaan yang satu sama lain tiada bersesuaian, yang satu mempunyai ketentuan sendiri dan yang lainnya demikian pula. (Maka Maha Suci) yakni sucilah (Allah Rabb) Pencipta (Arasy) yakni singgasana atau Al Kursi (daripada apa yang mereka sifatkan) dari apa yang disifatkan oleh orang-orang kafir terhadap Allah swt. seperti mempunyai sekutu dan lain sebagainya.\qt@no{22}}%
\qt@newcmd\qurantrans@id@mmdvi{%
(Dia tidak ditanya tentang apa yang diperbuat-Nya dan merekalah yang akan ditanyai) tentang perbuatan-perbuatan mereka.\qt@no{23}}%
\qt@newcmd\qurantrans@id@mmdvii{%
(Apakah mereka mengambil selain daripada-Nya) selain dari Allah (sebagai tuhan-tuhan) kata tanya atau Istifham di sini mengandung makna ejekan (Katakanlah, ``Unjukkanlah bukti kalian!") yang menunjukkan kebenaran dugaan kalian itu. Dan sekali-kali kalian tidak akan dapat melakukannya. (Ini adalah peringatan bagi orang-orang yang bersamaku) yakni umatku; yang dimaksud ``ini" adalah Alquran, (dan peringatan bagi orang-orang yang sebelumku) umat-umat sebelumku, yang dimaksud adalah kitab Taurat, Injil dan kitab-kitab Allah yang lainnya: Tidak ada satu pun kitab-kitab itu yang mengatakan, bahwa ada Tuhan di samping Allah, sebagaimana yang dikatakan mereka; Maha Suci Allah dari hal tersebut. (Sebenarnya kebanyakan mereka tiada mengetahui yang hak) tidak mengetahui keesaan Allah (karena itu mereka berpaling) dari memikirkan hal-hal yang dapat mengantarkan mereka kepada ajaran tauhid.\qt@no{24}}%
\qt@newcmd\qurantrans@id@mmdviii{%
(Dan Kami tidak mengutus seorang rasul pun sebelum kamu, melainkan Kami wahyukan) dalam satu qiraat lafal Nuuhii dibaca Yuuhaa (kepadanya, ``Bahwasanya tidak ada Tuhan melainkan Aku, maka sembahlah Aku olehmu sekalian") artinya tauhidkanlah atau esakanlah Aku.\qt@no{25}}%
\qt@newcmd\qurantrans@id@mmdix{%
(Dan mereka berkata, ``Tuhan Yang Maha Pemurah telah mengambil anak") berupa Malaikat-malaikat (Maha Suci Allah. Sebenarnya) para malaikat itu (adalah hamba-hamba Allah yang dimuliakan) di sisi-Nya; dan pengertian kehambaan ini jelas bertentangan dengan pengertian keanakan.\qt@no{26}}%
\qt@newcmd\qurantrans@id@mmdx{%
(Mereka tidak mendahului-Nya dengan perkataan) mereka sama sekali tidak pernah berkata melainkan setelah ada firman-Nya (dan mereka mengerjakan perintah-perintah-Nya) yakni setelah diperintahkan oleh-Nya.\qt@no{27}}%
\qt@newcmd\qurantrans@id@mmdxi{%
(Allah mengetahui segala sesuatu yang di hadapan mereka dan yang di belakang mereka) apa yang telah mereka kerjakan dan yang sedang mereka kerjakan (dan mereka tiada memberi syafaat melainkan kepada orang yang diridai) oleh Allah swt. untuk mendapatkannya (dan mereka karena takut kepada-Nya) kepada Allah swt. (selalu berhati-hati) selalu takut kepada-Nya.\qt@no{28}}%
\qt@newcmd\qurantrans@id@mmdxii{%
(Dan barang siapa di antara mereka mengatakan, ``Sesungguhnya aku adalah tuhan selain daripada-Nya") selain daripada Allah swt., dia adalah iblis yang menganjurkan manusia untuk menyembah dan taat kepada perintahnya (maka orang itu Kami beri balasan dengan Jahanam, demikianlah) sebagaimana Kami memberikan balasan kepada iblis (Kami memberikan pembalasan kepada orang-orang yang zalim) yakni orang-orang yang musyrik.\qt@no{29}}%
\qt@newcmd\qurantrans@id@mmdxiii{%
(Apakah tidak) dapat dibaca Awalam atau Alam (melihat) mengetahui (orang-orang yang kafir itu, bahwasanya langit dan bumi itu keduanya dahulu merupakan suatu yang padu) bersatu (kemudian Kami pisahkan) Kami jadikan langit tujuh lapis dan bumi tujuh lapis pula. Kemudian langit itu dibuka sehingga dapat menurunkan hujan yang sebelumnya tidak dapat menurunkan hujan. Kami buka pula bumi itu sehingga dapat menumbuhkan tetumbuhan, yang sebelumnya tidak dapat menumbuhkannya. (Dan daripada air Kami jadikan) air yang turun dari langit dan yang keluar dari mata air di bumi (segala sesuatu yang hidup) tumbuh-tumbuhan dan lain-lainnya, maksudnya airlah penyebab bagi kehidupannya. (Maka mengapakah mereka tiada juga beriman?) kepada keesaan-Ku.\qt@no{30}}%
\qt@newcmd\qurantrans@id@mmdxiv{%
(Dan telah Kami jadikan di bumi ini berpatok-patok) yakni gunung-gunung yang kokoh (supaya) tidak (goncang ia) yakni, bumi (bersama mereka dan telah Kami jadikan pula padanya) di gunung-gunung itu (celah-celah) yang dapat ditempuh (sebagai jalan-jalan) lafal Subulan ini menjadi Badal dari lafal Fijaajan, artinya jalan-jalan yang luas dan dapat ditempuh (agar mereka mendapat petunjuk) untuk sampai pada tujuan-tujuan mereka dalam bepergian.\qt@no{31}}%
\qt@newcmd\qurantrans@id@mmdxv{%
(Dan Kami menjadikan langit itu sebagai atap) bagi bumi, sebagaimana atap yang menaungi rumah (yang terpelihara) tidak sampai ambruk (sedang mereka dari segala tanda-tanda yang ada padanya) berupa matahari, bulan dan bintang-bintang (berpaling) mereka yakni orang kafir tidak mau memikirkan hal itu hingga mereka mengetahui, bahwa pencipta kesemuanya itu tiada sekutu bagi-Nya.\qt@no{32}}%
\qt@newcmd\qurantrans@id@mmdxvi{%
(Dan Dialah yang telah menciptakan malam dan siang, matahari dan bulan. Masing-masing dari semua itu) lafal Kullun ini tanwinnya merupakan pergantian daripada Mudhaf ilaih, maksudnya masing-masing daripada matahari, bulan dan bintang-bintang lainnya (di dalam garis edarnya) pada garis edarnya yang bulat di angkasa bagaikan bundaran batu penggilingan gandum (beredar) maksudnya semua berjalan dengan cepat sebagaimana berenang di atas air. Disebabkan ungkapan ini memakai Tasybih, maka didatangkanlah Dhamir bagi orang-orang yang berakal; yakni keadaan semua yang beredar pada garis edarnya itu bagaikan orang-orang yang berenang di dalam air.\qt@no{33}}%
\qt@newcmd\qurantrans@id@mmdxvii{%
Ayat ini diturunkan ketika orang-orang kafir berkata, bahwa sesungguhnya Muhammad itu pasti akan mati (Kami tidak menjadikan hidup kekal bagi seorang manusia pun sebelum kamu) hidup abadi di dunia (maka jika kamu mati, apakah mereka akan kekal?) di dunia? Tentu saja tidak. Jumlah kalimat yang terakhir inilah yang mengandung pengertian ingkar.\qt@no{34}}%
\qt@newcmd\qurantrans@id@mmdxviii{%
(Tiap-tiap yang berjiwa itu akan merasakan mati) di dunia (dan Kami akan menguji kalian) mencoba kalian (dengan keburukan dan kebaikan) seperti miskin, kaya, sakit dan sehat (sebagai cobaan) kalimat ini menjadi Maf'ul Lah, maksudnya supaya Kami melihat, apakah mereka bersabar dan bersyukur ataukah tidak. (Dan hanya kepada Kamilah kalian dikembalikan) kemudian Kami akan membalas kalian.\qt@no{35}}%
\qt@newcmd\qurantrans@id@mmdxix{%
(Dan apabila orang-orang kafir itu melihat kamu tidaklah mereka menjadikanmu melainkan hanyalah sebagai bahan perolokan) yakni mereka memperolok-olok kamu seraya mengatakan, ("Apakah ini orang yang mencela tuhan-tuhan kalian?") orang yang mencaci maki tuhan-tuhan kalian. (Dan mereka adalah orang-orang yang bila disebutkan nama Tuhan Yang Maha Pemurah) kepada mereka (maka mereka) lafal ini berfungsi menjadi taukid (ingkar) kepada-Nya, karena mereka menjawab, ``Kami tidak mengetahui-Nya."\qt@no{36}}%
\qt@newcmd\qurantrans@id@mmdxx{%
Ayat ini diturunkan sewaktu mereka meminta disegerakan turunnya azab atas mereka. (Manusia telah dijadikan dari tergesa-gesa) disebabkan manusia itu bertabiat tergesa-gesa di dalam semua tindakannya, maka seolah-olah ia diciptakan daripadanya. (Kelak Aku akan perlihatkan kepada kalian tanda-tanda azab-Ku) yakni ketentuan waktu bagi azab-Ku (maka janganlah kalian minta kepada-Ku mendatangkannya dengan segera) kemudian Allah memperlihatkan kepada mereka turunnya azab itu, yaitu dengan dibunuhnya mereka dalam perang Badar.\qt@no{37}}%
\qt@newcmd\qurantrans@id@mmdxxi{%
(Mereka berkata, ``Kapankah janji itu akan datang) yang dimaksud kiamat itu (jika kamu sekalian adalah orang-orang yang benar?") tentang adanya janji itu.\qt@no{38}}%
\qt@newcmd\qurantrans@id@mmdxxii{%
Allah berfirman (Andaikata orang-orang kafir itu mengetahui waktu mereka tidak dapat mengelakkan) di waktu mereka tidak mampu menolak (api neraka dari muka mereka dan tidak pula dari punggung mereka sedangkan mereka tidak pula mendapat pertolongan) yang dapat mencegah diri mereka daripada api neraka itu, di hari kiamat nanti. Jawab dari pada lafal Lau tidak disebutkan, yaitu, niscaya mereka tidak akan mengeluarkan perkataan tersebut.\qt@no{39}}%
\qt@newcmd\qurantrans@id@mmdxxiii{%
(Sebenarnya akan mendatangi mereka) hari kiamat itu (dengan sekonyong-konyong lalu membuat mereka menjadi panik) menjadi bingung dan panik (maka mereka tidak sanggup menolaknya dan tidak pula mereka diberi tangguh) ditangguhkan untuk bertobat atau meminta ampunan.\qt@no{40}}%
\qt@newcmd\qurantrans@id@mmdxxiv{%
(Dan sungguh telah diperolok-olok beberapa orang rasul sebelum kamu) ayat ini mengandung hiburan yang ditujukan kepada Nabi saw. (maka turunlah) yakni menimpa (kepada orang-orang yang mencemoohkan rasul-rasul itu apa yang selalu mereka perolok-olokkan) yaitu berupa azab; demikian pula orang-orang yang memperolok-olokkan dirimu akan tertimpa azab yang sama seperti mereka.\qt@no{41}}%
\qt@newcmd\qurantrans@id@mmdxxv{%
(Katakanlah) kepada mereka, ("Siapakah yang dapat memelihara kalian) yang dapat menjaga diri kalian (di waktu malam dan siang hari daripada Tuhan Yang Maha Pemurah") daripada azab-Nya, jika azab itu turun kepada kalian. Maksudnya, tentu saja tidak ada seorang pun yang dapat melakukan hal itu. Orang-orang yang diajak bicara oleh ayat ini tidak merasa takut kepada azab Allah, disebabkan mereka ingkar kepada-Nya atau tidak percaya kepada adanya azab itu. (Sebenarnya mereka terhadap peringatan Rabb mereka) yakni Alquran (adalah orang-orang yang berpaling) tidak mau memikirkan tentangnya.\qt@no{42}}%
\qt@newcmd\qurantrans@id@mmdxxvi{%
(Atau) di dalam kalimat ini terkandung makna ingkar, maksudnya, apakah (mereka mempunyai tuhan-tuhan yang dapat memelihara diri mereka) dari apa-apa yang mencelakakan diri mereka (selain dari Kami) maksudnya apakah mereka mempunyai tuhan-tuhan selain Kami yang dapat mencegah diri mereka dari azab Allah? Tentu saja tidak (mereka pasti tidak akan sanggup) yakni tuhan-tuhan itu (menolong diri mereka sendiri) maka mereka tidak dapat menolongnya (dan tidak pula mereka) orang-orang kafir itu (dari Kami) yakni dari azab Kami (dilindungi) mendapat perlindungan. Asal katanya ialah dari kalimat Shahabakallaahu artinya mudah-mudahan Allah memelihara dan melindungimu.\qt@no{43}}%
\qt@newcmd\qurantrans@id@mmdxxvii{%
(Sebenarnya Kami telah memberi mereka dan bapak-bapak mereka kenikmatan) melalui yang Kami anugerahkan kepada mereka (sehingga panjanglah umur mereka) oleh karenanya mereka menjadi lupa daratan. (Maka apakah mereka tidak melihat bahwasanya Kami mendatangi negeri) mereka, yakni Kami menuju ke negeri orang-orang kafir (lalu Kami kurangi luasnya dari segala penjurunya) melalui penaklukkan yang dilakukan oleh Nabi saw. (Maka apakah mereka yang menang?) tentu saja tidak, tetapi Nabi dan sahabat-sahabatnyalah yang menang.\qt@no{44}}%
\qt@newcmd\qurantrans@id@mmdxxviii{%
(Katakanlah) kepada mereka, ("Sesungguhnya aku hanya memberi peringatan kepada kamu sekalian dengan wahyu) dari Allah swt. bukannya dari diriku sendiri (dan tiadalah orang-orang yang tuli mendengar seruan, apabila) dapat dibaca dengan menyatakan kedua Hamzahnya dan dengan meringankan bacaan Hamzah yang kedua, yaitu antara ucapan Hamzah dan Ya (mereka diberi peringatan") disebabkan mereka tidak mau mengamalkan apa yang telah mereka dengar dari peringatan-peringatan, sehingga mereka disamakan dengan orang-orang yang tuli.\qt@no{45}}%
\qt@newcmd\qurantrans@id@mmdxxix{%
(Dan sesungguhnya jika mereka ditimpa sedikit saja) barang sedikit (dari azab Rabbmu, pastilah mereka berkata, ``Aduhai) menunjukkan makna penyesalan (celakalah kami) binasalah kami (bahwasanya kami adalah orang yang menganiaya diri sendiri") disebabkan kami musyrik dan mendustakan Muhammad.\qt@no{46}}%
\qt@newcmd\qurantrans@id@mmdxxx{%
(Kami akan memasang timbangan yang tepat) timbangan yang adil (pada hari kiamat) pada hari itu (maka tiadalah dirugikan seseorang barang sedikit pun) dengan dikurangi pahala kebaikannya atau ditambahkan dosa keburukannya. (Dan jika) amalan itu (hanya seberat) sama beratnya dengan (biji sawi Kami mendatangkannya) yakni pahalanya. (Dan cukuplah Kami menjadi penghisab) segala sesuatu, yakni yang menghitungnya.\qt@no{47}}%
\qt@newcmd\qurantrans@id@mmdxxxi{%
(Dan sesungguhnya Kami telah berikan kepada Musa dan Harun kitab Taurat) kitab yang memisahkan antara perkara yang hak dan perkara yang batil dan antara perkara yang halal dan perkara yang haram (dan penerangan) sebagai penerang (serta pengajaran) sebagai pengajaran (bagi semua orang yang bertakwa).\qt@no{48}}%
\qt@newcmd\qurantrans@id@mmdxxxii{%
(Yaitu orang-orang yang takut kepada Rabb mereka sekalipun mereka menyendiri) jauh dari khalayak ramai, (dan mereka terhadap hari kiamat) yakni kengerian-kengeriannya (merasa takut) mereka merasa khawatir.\qt@no{49}}%
\qt@newcmd\qurantrans@id@mmdxxxiii{%
(Dan ini) yakni Alquran ini (adalah suatu kitab peringatan yang mempunyai berkah yang telah Kami turunkan. Maka mengapa kalian mengingkarinya?) Istifham atau kata tanya di sini mengandung pengertian mencemoohkan.\qt@no{50}}%
\qt@newcmd\qurantrans@id@mmdxxxiv{%
(Dan sesungguhnya telah Kami anugerahkan kepada Ibrahim hidayah kebenaran sebelumnya) sebelum ia mencapai umur balig (dan adalah Kami mengetahuinya) bahwa dia layak untuk menerima hal tersebut.\qt@no{51}}%
\qt@newcmd\qurantrans@id@mmdxxxv{%
(Yaitu ketika Ibrahim berkata kepada bapaknya dan kaumnya, ``Patung-patung apakah ini) maksudnya, apa kegunaan berhala-berhala ini (yang kalian tekun beribadah kepadanya?") kalian dengan tekun menyembahnya.\qt@no{52}}%
\qt@newcmd\qurantrans@id@mmdxxxvi{%
(Mereka menjawab, ``Kami mendapatkan bapak-bapak kami menyembahnya") maka kami mengikuti mereka.\qt@no{53}}%
\qt@newcmd\qurantrans@id@mmdxxxvii{%
(Ibrahim berkata) kepada mereka, ("Sesungguhnya kalian dan bapak-bapak kalian) disebabkan menyembah berhala-berhala itu (berada dalam kesesatan yang nyata") yakni jelas sesatnya.\qt@no{54}}%
\qt@newcmd\qurantrans@id@mmdxxxviii{%
(Mereka menjawab, ``Apakah kamu datang kepada kami dengan sungguh-sungguh) apakah perkataanmu yang demikian itu sungguh-sungguh (atau apakah kamu termasuk orang yang bermain-main?") di dalam perkataanmu itu.\qt@no{55}}%
\qt@newcmd\qurantrans@id@mmdxxxix{%
(Ibrahim berkata, ``Sebenarnya Rabb kalian) yang berhak untuk disembah (ialah Rabb) yang memiliki (langit dan bumi yang telah menciptakannya) tanpa contoh sebelumnya (dan aku atas yang demikian itu) yang telah aku katakan sekarang ini (termasuk orang-orang yang menyaksikan") nya.\qt@no{56}}%
\qt@newcmd\qurantrans@id@mmdxl{%
(Demi Allah, sesungguhnya aku akan melakukan tipu daya terhadap berhala-berhala kalian sesudah kalian pergi meninggalkannya).\qt@no{57}}%
\qt@newcmd\qurantrans@id@mmdxli{%
(Maka Ibrahim membuat berhala-berhala itu) sesudah mereka pergi meninggalkannya menuju ke tempat pertemuan di hari raya mereka (menjadi puing-puing) dapat dibaca Judzaadzan dan Jidzaadzan, artinya hancur terpotong-potong di kapak oleh Nabi Ibrahim (kecuali yang terbesar dari mereka) lalu Nabi Ibrahim menggantungkan kapaknya ke pundak berhala yang terbesar itu (agar mereka kepadanya) yakni kepada berhala yang terbesar itu (menanyakannya) maka mereka akan melihat apa yang ia perbuat terhadap berhala-berhala yang lain.\qt@no{58}}%
\qt@newcmd\qurantrans@id@mmdxlii{%
(Mereka berkata) setelah kembali dan melihat apa yang telah diperbuat terhadap berhala-berhala mereka, ("Siapakah yang melakukan perbuatan ini terhadap tuhan-tuhan kami, sesungguhnya dia termasuk orang-orang yang zalim") di dalam perbuatannya ini.\qt@no{59}}%
\qt@newcmd\qurantrans@id@mmdxliii{%
(Mereka berkata) sebagian dari mereka kepada yang lain, ("Kami dengar ada seorang pemuda yang menyebut-nyebut mereka) yakni yang mencaci maki berhala-berhala itu (yang bernama Ibrahim")\qt@no{60}}%
\qt@newcmd\qurantrans@id@mmdxliv{%
(Mereka berkata, ``Kalau demikian, bawalah dia ke hadapan orang banyak) perlihatkanlah dia kepada mereka (agar mereka menyaksikan") bahwasanya dialah yang telah melakukan semuanya ini.\qt@no{61}}%
\qt@newcmd\qurantrans@id@mmdxlv{%
(Mereka bertanya) setelah menghadirkan Ibrahim, ("Apakah kamu) dapat dibaca A'anta dan A-anta (yang melakukan perbuatan ini terhadap tuhan-tuhan kami, hai Ibrahim?")\qt@no{62}}%
\qt@newcmd\qurantrans@id@mmdxlvi{%
(Ibrahim menjawab) seraya menyembunyikan apa yang sebenarnya telah ia lakukan, ("Sebenarnya patung yang besar itulah yang melakukannya, maka tanyakanlah kepada berhala-berhala itu) siapakah pelakunya (jika mereka dapat berbicara") Jawab syarat dari kalimat ayat ini telah didahulukan dan kalimat yang sebelumnya merupakan sindiran bagi para penyembah berhala, bahwa berhala-berhala yang telah dimaklumi ketidakmampuannya untuk berbuat itu bukan tuhan.\qt@no{63}}%
\qt@newcmd\qurantrans@id@mmdxlvii{%
(Maka mereka telah kembali kepada kesadaran mereka) setelah berpikir (lalu berkata) kepada diri mereka sendiri, ("Sesungguhnya kalian adalah orang-orang yang berbuat aniaya") disebabkan kalian menyembah berhala yang tidak dapat berbicara.\qt@no{64}}%
\qt@newcmd\qurantrans@id@mmdxlviii{%
(Kemudian mereka menundukkan) karena malu kepada Allah (kepala mereka) karena kekafirannya telah dinyatakan, maka mereka berkata, ``Demi Allah! (Sesungguhnya kamu telah mengetahui, bahwa berhala-berhala itu tidak dapat berbicara") mengapa kamu menyuruh kami bertanya kepada mereka.\qt@no{65}}%
\qt@newcmd\qurantrans@id@mmdxlix{%
(Ibrahim berkata, ``Maka mengapakah kalian menyembah selain Allah) sebagai ganti dari-Nya untuk kalian sembah (sesuatu yang tidak dapat memberi manfaat sedikit pun kepada kalian) berupa rezeki dan lain-lainnya (dan tidak pula memberi mudarat kepada kalian?") barang sedikit pun, jika kalian tidak menyembahnya.\qt@no{66}}%
\qt@newcmd\qurantrans@id@mmdl{%
(Ah, alangkah buruknya) lafal Uffin atau Uffan ini bermakna Mashdar, artinya busuklah (kalian beserta apa yang kalian sembah selain Allah. Maka apakah kalian tidak memahami?) bahwa berhala-berhala itu tidak berhak untuk disembah dan tidak layak untuk dijadikan sesembahan, karena sesungguhnya yang berhak disembah itu hanyalah Allah semata.\qt@no{67}}%
\qt@newcmd\qurantrans@id@mmdli{%
(Mereka berkata, ``Bakarlah dia) yakni Nabi Ibrahim (dan bantulah tuhan-tuhan kalian) dengan membakar Ibrahim (jika kalian benar-benar hendak bertindak") untuk menolong tuhan-tuhan kalian. Mereka segera mengumpulkan kayu-kayu yang banyak sekali, lalu mereka menyalakannya. Mereka mengikat Nabi Ibrahim, kemudian menaruhnya pada Manjaniq atau alat pelontar yang besar, lalu Nabi Ibrahim dilemparkan ke dalam api yang besar itu. Allah berfirman:\qt@no{68}}%
\qt@newcmd\qurantrans@id@mmdlii{%
(Kami berfirman, ``Hai api! Menjadi dinginlah dan menjadi keselamatanlah bagi Ibrahim") maka api itu tidak membakarnya selain pada tali-tali pengikatnya saja dan lenyaplah panas api itu, yang tinggal hanyalah cahayanya saja, hal ini berkat perintah Allah, 'Salaaman' yakni menjadi keselamatan bagi Ibrahim, akhirnya Nabi Ibrahim selamat dari kematian karena api itu dingin.\qt@no{69}}%
\qt@newcmd\qurantrans@id@mmdliii{%
(Mereka hendak berbuat makar terhadap Ibrahim) yaitu dengan membakarnya (maka Kami menjadikan mereka itu orang-orang yang paling merugi) di dalam tujuan mereka.\qt@no{70}}%
\qt@newcmd\qurantrans@id@mmdliv{%
(Dan Kami selamatkan Ibrahim dan Luth) anak saudara Nabi Ibrahim yang bernama Haran yang tinggal di negeri Iraq (ke sebuah negeri yang Kami telah memberkahinya untuk sekalian manusia) dengan menjadikan sungai-sungai dan pohon-pohon yang banyak padanya, yaitu negeri Syam. Nabi Ibrahim tinggal di negeri Palestina sedangkan Nabi Luth di Mu'tafikah; jarak antara kedua negeri itu dapat ditempuh dalam sehari.\qt@no{71}}%
\qt@newcmd\qurantrans@id@mmdlv{%
(Dan Kami telah memberikan kepadanya) kepada Ibrahim, yang sebelumnya selalu mendambakan mempunyai seorang anak, sebagaimana yang disebutkan di dalam surah Ash-Shaffat (Ishak dan Yakub sebagai suatu anugerah) dari Kami, yaitu anugerah yang lebih daripada apa yang dimintanya. Atau yang dimaksud dengan Naafilah adalah cucu (Dan masing-masingnya) Nabi Ibrahim dan kedua anaknya itu (Kami jadikan orang-orang yang saleh) yakni menjadi nabi semuanya.\qt@no{72}}%
\qt@newcmd\qurantrans@id@mmdlvi{%
(Kami telah menjadikan mereka itu sebagian pemimpin-pemimpin) dapat dibaca A-immatan atau Ayimmatan, yakni pemimpin yang menjadi teladan dalam kebaikan (yang memberi petunjuk) kepada manusia (dengan perintah Kami) memberi petunjuk kepada mereka untuk memeluk agama Kami (dan telah Kami wahyukan kepada mereka mengerjakan kebajikan, mendirikan salat, menunaikan zakat) hendaknya mereka dan orang-orang yang mengikuti mereka mengerjakan semuanya itu. Huruf Ha dari lafal Iqaamah dibuang demi untuk meringankan bunyi, sehingga menjadi Iqaamash Shalaati bukan Iqaamatish Shalaati (dan hanya kepada Kamilah mereka selalu menyembah).\qt@no{73}}%
\qt@newcmd\qurantrans@id@mmdlvii{%
(Dan kepada Luth, Kami telah berikan hukum) yang memutuskan di antara orang-orang yang bersengketa (dan ilmu dan telah Kami selamatkan dia dari azab yang telah menimpa kota yang penduduknya mengerjakan) perbuatan-perbuatan (keji) yaitu seperti liwath atau homosex, main dadu, menebak nasib dengan burung dan lain sebagainya. (Sesungguhnya mereka adalah kaum yang jahat) lafal Sau-in adalah bentuk Mashdar dari lafal Saa-a lawan kata dari Sarra, artinya jahat atau buruk (lagi fasik).\qt@no{74}}%
\qt@newcmd\qurantrans@id@mmdlviii{%
(Dan Kami masukkan dia ke dalam rahmat Kami) yang antara lain dia Kami selamatkan dari kaumnya. (Karena sesungguhnya dia termasuk orang-orang yang saleh).\qt@no{75}}%
\qt@newcmd\qurantrans@id@mmdlix{%
(Dan) ingatlah kisah (Nuh) kalimat yang sesudahnya merupakan Badal atau kata ganti daripadanya (ketika dia berdoa) yakni berdoa bagi kebinasaan kaumnya, sebagaimana yang disitir oleh ayat lain, yaitu firman-Nya, ``Ya Rabbku! Janganlah Engkau biarkan seorang pun di antara orang-orang kafir itu tinggal di atas bumi." (Q.S. Nuh, 26). (sebelum itu) sebelum Nabi Ibrahim dan Nabi Luth (dan Kami memperkenankan doanya, lalu Kami selamatkan dia beserta keluarganya) beserta orang-orang yang ada di dalam bahteranya (dari bencana yang besar) dari bencana tenggelam dan permusuhan kaumnya yang mendustakannya.\qt@no{76}}%
\qt@newcmd\qurantrans@id@mmdlx{%
(Dan Kami telah menolongnya) Kami pelihara dia (dari kaum yang telah mendustakan ayat-ayat Kami) yang menunjukkan kerasulannya, hingga mereka tidak dapat menimpakan keburukan kepadanya (Sesungguhnya mereka adalah kaum yang jahat, maka Kami tenggelamkan mereka semuanya).\qt@no{77}}%
\qt@newcmd\qurantrans@id@mmdlxi{%
(Dan) ingatlah (Daud dan Sulaiman) yakni kisah keduanya, dijelaskan oleh ayat selanjutnya (di waktu keduanya memberikan keputusan mengenai tanaman) berupa ladang atau pohon anggur (karena tanaman itu dirusak oleh kambing-kambing kepunyaan kaumnya) kambing-kambing itu memakannya dan merusaknya di waktu malam hari tanpa ada penggembalanya, karena kambing-kambing itu lepas dengan sendirinya dari kandangnya. (Dan adalah Kami menyaksikan keputusan yang diberikan oleh mereka itu) Dhamir jamak dalam ayat ini menunjukkan makna untuk dua orang, yaitu Nabi Daud dan Nabi Sulaiman. Lalu Nabi Daud berkata, ``Pemilik ladang itu berhak untuk memiliki kambing-kambing yang telah merusak ladangnya". Akan tetapi Nabi Sulaiman memutuskan, ``Pemilik kebun hanya diperbolehkan memanfaatkan air susu, anak-anak dan bulu-bulunya, sampai tanaman ladang kembali seperti semula, diperbaiki oleh pemilik kambing, setelah itu ia diharuskan mengembalikan kambing-kambing itu kepada pemiliknya".\qt@no{78}}%
\qt@newcmd\qurantrans@id@mmdlxii{%
(Maka Kami telah memberikan pengertian tentang hukum) yakni keputusan yang adil dan tepat (kepada Sulaiman) keputusan yang dilakukan oleh keduanya itu berdasarkan ijtihad masing-masing, kemudian Nabi Daud mentarjihkan atau menguatkan keputusan yang diambil oleh Nabi Sulaiman. Menurut suatu pendapat dikatakan, bahwa keputusan keduanya itu berdasarkan wahyu dari Allah dan keputusan yang kedua yaitu yang telah diambil oleh Nabi Sulaiman berfungsi memansukh hukum yang pertama, yakni hukum Nabi Daud (dan kepada masing-masing) daripada keduanya (Kami berikan) kepadanya (hikmah) kenabian (dan ilmu) tentang masalah-masalah agama (dan telah Kami tundukkan gunung-gunung dan burung-burung, semua bertasbih bersama Daud) demikianlah gunung-gunung dan burung-burung itu ditundukkan untuk bertasbih bersama Nabi Daud. Nabi Daud memerintahkan gunung-gunung dan burung-burung untuk ikut bertasbih bersamanya bila ia mengalami kelesuan, hingga ia menjadi semangat lagi dalam bertasbih. (Dan Kamilah yang melakukannya) yakni Kamilah yang menundukkan keduanya dapat bertasbih bersama Daud, sekalipun hal ini menurut kalian merupakan hal yang ajaib dan aneh yaitu tunduk dan patuhnya gunung-gunung dan burung-burung kepada perintah Nabi Daud.\qt@no{79}}%
\qt@newcmd\qurantrans@id@mmdlxiii{%
(Dan Kami ajarkan kepada Daud membuat baju besi) yaitu baju yang terbuat dari besi, dialah orang pertama yang menciptakannya dan sebelumnya hanyalah berupa lempengan-lempengan besi saja (untuk kalian) yakni untuk segolongan manusia (guna melindungi diri kalian) jika dibaca Linuhshinakum, maka Dhamirnya kembali kepada Allah, maksudnya, supaya Kami melindungi kalian. Dan jika ia dibaca Lituhshinahum, maka Dhamirnya kembali kepada baju besi, maksudnya, supaya baju besi itu melindungi diri kalian. Jika dibaca Liyuhshinakum, maka Dhamirnya kembali kepada Nabi Daud, maksudnya, supaya dia melindungi kalian (dalam peperangan kalian) melawan musuh-musuh kalian. (Maka hendaklah kalian) hai penduduk Mekah (bersyukur) atas nikmat karunia-Ku itu, yaitu dengan percaya kepada Rasulullah. Maksudnya bersyukurlah kalian atas hal tersebut kepada-Ku.\qt@no{80}}%
\qt@newcmd\qurantrans@id@mmdlxiv{%
(Dan) telah Kami tundukkan (untuk Sulaiman angin yang sangat kencang tiupannya) dan pada ayat yang lain disebutkan Rukha-an, artinya angin yang sangat kencang dan pelan tiupannya, kesemuanya itu sesuai dengan kehendak Nabi Sulaiman (yang berhembus dengan perintahnya ke negeri yang kami telah memberkatinya) yakni negeri Syam. (Dan adalah Kami Maha Mengetahui segala sesuatu) antara lain ilmu Allah yang telah diberikan kepada Sulaiman itu akan mendorongnya tunduk patuh kepada Rabbnya. Allah melakukan hal itu sesuai dengan ilmu-Nya yang maha mengetahui segala sesuatu.\qt@no{81}}%
\qt@newcmd\qurantrans@id@mmdlxv{%
(Dan) telah Kami tundukkan pula kepadanya (segolongan setan-setan yang menyelam untuknya) mereka menyelam ke dalam laut, lalu mereka mengeluarkan batu-batu permata dari dalamnya untuk Nabi Sulaiman (dan mereka mengerjakan pekerjaan selain daripada itu) selain menyelam, yaitu seperti membangun bangunan dan pekerjaan-pekerjaan berat lainnya (dan adalah Kami memelihara mereka) supaya mereka jangan merusak lagi pekerjaan-pekerjaan yang telah mereka perbuat. Karena watak setan itu bilamana selesai dari suatu pekerjaan sebelum malam tiba, mereka merusaknya kembali, jika mereka tidak disuruh mengerjakan pekerjaan yang lain.\qt@no{82}}%
\qt@newcmd\qurantrans@id@mmdlxvi{%
(Dan) ingatlah kisah (Ayub,) kemudian dijelaskan oleh Badalnya, yaitu (ketika ia menyeru Rabbnya) pada saat itu dia mendapat cobaan dari-Nya; semua harta bendanya lenyap dan semua anak-anaknya mati serta badannya sendiri tercabik-cabik oleh penyakit, semua orang menjauhinya kecuali istrinya. Hal ini dialaminya selama tiga belas tahun, ada yang mengatakan tujuh belas tahun dan ada pula yang mengatakan delapan belas tahun. Selama itu penghidupan Nabi Ayub sangat sulit dan sengsara ("Sesungguhnya aku) asal kata Annii adalah Bi-ann (telah ditimpa kemudaratan) yakni hidup sengsara (dan Engkau adalah Yang Maha Penyayang di antara semua penyayang").\qt@no{83}}%
\qt@newcmd\qurantrans@id@mmdlxvii{%
(Maka Kami pun memperkenankan seruannya) doanya (lalu Kami lenyapkan penyakit yang ada padanya dan Kami kembalikan keluarganya kepadanya) yakni semua anak-anaknya baik yang laki-laki maupun yang perempuan, dengan cara menghidupkan mereka kembali. Jumlah anaknya ada tiga atau tujuh orang (dan Kami lipat gandakan bilangan mereka) bilangan anak-anaknya yang dilahirkan dari istrinya dan istrinya pun dimudakan-Nya. Nabi Ayub mempunyai dua buah lumbung; yang satu untuk tempat gandum dan yang satu lagi untuk tempat jewawut. Kemudian Allah mengirimkan dua kelompok awan; yang satu menurunkan hujan emas pada lumbung tempat gandum dan yang satunya lagi menurunkan hujan perak pada lumbung tempat jewawut, sehingga kedua lumbung itu penuh dengan emas dan perak (sebagai suatu rahmat) lafal Rahmatan ini menjadi Maf'ul Lah (dari sisi Kami) lafal Min 'Indinaa ini berkedudukan menjadi kata sifat (dan untuk menjadi peringatan bagi semua yang menyembah Allah) supaya mereka bersabar, yang karenanya mereka akan mendapatkan pahala.\qt@no{84}}%
\qt@newcmd\qurantrans@id@mmdlxviii{%
(Dan) ingatlah kisah (Ismail, Idris dan Zulkifli. Semua mereka termasuk orang-orang yang sabar) di dalam menjalankan ketaatan kepada Allah dan menjauhi kedurhakaan kepada-Nya.\qt@no{85}}%
\qt@newcmd\qurantrans@id@mmdlxix{%
(Kami telah memasukkan mereka ke dalam rahmat Kami) yakni kenabian. (Sesungguhnya mereka termasuk orang-orang yang saleh) orang-orang yang mensyukuri rahmat Kami. Dinamakan Zulkifli karena ia telah menyanggupi akan melakukan puasa di siang hari dan beribadah pada malam harinya, serta ia berjanji akan memutuskan peradilan di antara orang-orang dan tidak akan marah. Kemudian ternyata ia memenuhi apa yang telah dijanjikannya itu. Menurut suatu pendapat dikatakan bahwa ia bukan seorang nabi, akan tetapi hanya orang saleh atau wali Allah saja.\qt@no{86}}%
\qt@newcmd\qurantrans@id@mmdlxx{%
(Dan) ingatlah kisah (Dzun Nun) yaitu orang yang mempunyai ikan yang besar, dia adalah Nabi Yunus bin Mataa. Kemudian dijelaskan kalimat Dzun Nun ini oleh Badalnya pada ayat selanjutnya, yaitu (ketika ia pergi dalam keadaan marah) terhadap kaumnya, disebabkan perlakuan kaumnya yang menyakitkan dirinya, sedangkan Nabi Yunus belum mendapat izin dari Allah untuk pergi (lalu ia menyangka bahwa Kami tidak akan mampu untuk menjangkaunya) menghukumnya sesuai dengan apa yang telah Kami pastikan baginya, yaitu menahannya di dalam perut ikan paus, atau menyulitkan dirinya disebabkan hal tersebut (maka ia menyeru dalam tempat yang gelap gulita) gelapnya malam dan gelapnya laut serta gelapnya suasana dalam perut ikan paus ("bahwa) asal kata An adalah Bi-an, artinya, bahwasanya (tiada Tuhan selain Engkau, Maha Suci Engkau, sesungguhnya aku adalah termasuk orang-orang yang zalim") karena pergi dari kaumku tanpa seizin Allah.\qt@no{87}}%
\qt@newcmd\qurantrans@id@mmdlxxi{%
(Maka Kami telah memperkenankan doanya dan menyelamatkannya daripada kedukaan) disebabkan kalimat-kalimat tersebut. (Dan demikianlah) sebagaimana Kami menyelamatkan dia (Kami selamatkan orang-orang yang beriman) daripada malapetaka yang menimpa mereka, jika mereka meminta tolong kepada Kami seraya berdoa.\qt@no{88}}%
\qt@newcmd\qurantrans@id@mmdlxxii{%
(Dan) ingatlah kisah (Zakaria) kemudian dijelaskan oleh Badalnya pada ayat selanjutnya (tatkala ia menyeru Rabbnya) melalui doanya yang mengatakan, ("Ya Rabbku! Janganlah Engkau membiarkan aku hidup seorang diri) tanpa anak yang kelak akan mewarisiku (dan Engkaulah Waris Yang Paling Baik") yang tetap abadi sesudah semua makhluk-Mu musnah.\qt@no{89}}%
\qt@newcmd\qurantrans@id@mmdlxxiii{%
(Maka Kami memperkenankan doanya) yakni seruannya itu (dan Kami anugerahkan kepadanya Yahya) sebagai anaknya (dan Kami jadikan istrinya dapat mengandung) sehingga dapat melahirkan anak, padahal sebelumnya ia mandul. (Sesungguhnya mereka) para Nabi yang telah disebutkan tadi (adalah orang-orang yang selalu bersegera) mereka selalu bergegas-gegas (di dalam kebaikan-kebaikan) mengerjakan amal-amal ketaatan (dan mereka berdoa kepada Kami dengan mengharapkan) rahmat Kami (dan takut) kepada azab Kami. (Dan mereka adalah orang-orang yang khusyuk kepada Kami) yakni merendahkan diri dan patuh di dalam beribadah.\qt@no{90}}%
\qt@newcmd\qurantrans@id@mmdlxxiv{%
(Dan) ingatlah kisah Maryam (yang telah memelihara kehormatannya) ia memeliharanya supaya tidak dinodai (lalu Kami tiupkan ke dalam tubuhnya roh dari Kami) malaikat Jibril; dialah yang meniup ke dalam baju kurungnya, lalu Maryam mengandung Isa (dan Kami jadikan dia dan anaknya sebagai tanda yang besar bagi semesta alam) yakni manusia, jin dan malaikat, karena ia dapat mengandung tanpa lelaki.\qt@no{91}}%
\qt@newcmd\qurantrans@id@mmdlxxv{%
(Sesungguhnya ini) agama Islam atau agama tauhid ini (adalah agama kalian) hai orang-orang yang diajak berbicara. Maksudnya, kalian wajib memeluknya (agama yang satu) lafal ayat ini berkedudukan menjadi Hal yang bersifat tetap (dan Aku adalah Rabb kalian, maka sembahlah Aku) tauhidkan atau esakanlah Aku.\qt@no{92}}%
\qt@newcmd\qurantrans@id@mmdlxxvi{%
(Dan mereka telah memotong-motong) sebagian daripada orang-orang yang diajak bicara itu (urusan agama mereka di antara mereka) yakni mereka memecah belah perkara agama mereka; sebagian dari mereka bertentangan dengan sebagian yang lain di dalam masalah agama. Mereka adalah sekte-sekte dari agama Yahudi dan Nasrani. Lalu Allah berfirman, ("Kepada Kamilah masing-masing golongan itu akan kembali) kemudian Kami akan membalas amal perbuatan mereka.\qt@no{93}}%
\qt@newcmd\qurantrans@id@mmdlxxvii{%
(Maka barang siapa mengerjakan amal saleh, sedang ia beriman, maka tidak ada pengingkaran) tidak diingkari (terhadap amalannya dan sesungguhnya Kami menuliskan amalannya itu untuknya) Kami perintahkan Malaikat-malaikat penulis amal untuk menuliskannya, kemudian akan Kami balas amal perbuatan itu.\qt@no{94}}%
\qt@newcmd\qurantrans@id@mmdlxxviii{%
(Sungguh tidak mungkin atas suatu negeri yang telah Kami binasakan) yang dimaksud adalah penduduknya (bahwa mereka) huruf La di sini Zaidah yakni tidak ada maknanya (akan kembali) maksudnya mereka tidak mungkin akan dapat hidup kembali ke dunia.\qt@no{95}}%
\qt@newcmd\qurantrans@id@mmdlxxix{%
(Hingga) lafal Hattaa ini menunjukkan batas waktu bagi terlarangnya mereka untuk dapat hidup kembali (apabila dibukakan) dapat dibaca Futihat dan Futtihat (Yakjuj dan Makjuj) dapat dibaca Yakjuj wa Makjuj dan Yajuj wa Majuj, keduanya adalah nama bagi dua kabilah 'Ajam. Sebelum kalimat ini diperkirakan adanya Mudhaf, maksudnya tembok yang mengurung Yakjuj dan Makjuj; hal itu akan terjadi bila hari kiamat sudah dekat (dan mereka dari seluruh tempat-tempat yang tinggi) yakni dataran-dataran tinggi (turun dengan cepatnya) artinya, mereka turun dengan sangat cepat.\qt@no{96}}%
\qt@newcmd\qurantrans@id@mmdlxxx{%
(Dan telah dekatlah kedatangan janji yang benar) yakni hari kiamat (maka tiba-tiba) kisah kenyataannya (terbelalaklah mata orang-orang yang kafir) pada hari tersebut disebabkan sangat ngeri melihatnya, seraya mengatakan, ("Aduhai") ya di sini menunjukkan makna penyesalan (celakalah kami) binasalah kami (sesungguhnya kami) sewaktu hidup di dunia (adalah dalam kelalaian tentang ini) tentang hari kiamat (bahkan kami adalah orang-orang yang zalim) yakni menganiaya diri kami sendiri, disebabkan kami mendustakan para Rasul.\qt@no{97}}%
\qt@newcmd\qurantrans@id@mmdlxxxi{%
(Sesungguhnya kalian) hai penduduk Mekah (dan apa yang kalian sembah selain Allah) yaitu berhala-berhala (adalah makanan Jahanam) maksudnya sebagai bahan bakar (kalian pasti masuk ke dalamnya) pasti memasukinya.\qt@no{98}}%
\qt@newcmd\qurantrans@id@mmdlxxxii{%
(Andaikata mereka itu) yakni berhala-berhala itu (adalah tuhan-tuhan) sebagaimana sangkaan kalian (tentulah mereka tidak masuk neraka) mereka tidak akan memasukinya. (Dan semuanya) yakni orang-orang yang menyembah berhala bersama berhala-berhala sesembahan mereka (akal kekal di dalamnya).\qt@no{99}}%
\qt@newcmd\qurantrans@id@mmdlxxxiii{%
(Mereka) yakni keadaan para penyembah berhala itu (merintih di dalam api dan mereka di dalamnya tidak dapat mendengar) sesuatu pun karena gemuruhnya api Jahanam yang sangat kuat. Ayat ini diturunkan sewaktu Ibnu Zaba'ri mengatakan, bahwa penyembah Uzair, Al Masih dan para Malaikat, mereka semuanya dimasukkan ke dalam neraka, sebagaimana kisah yang telah disebutkan tadi.\qt@no{100}}%
\qt@newcmd\qurantrans@id@mmdlxxxiv{%
(Sesungguhnya orang-orang yang telah ada untuk mereka ketetapan dari Kami) yakni kedudukan (yang baik) antara lain adalah para nabi yang telah disebutkan tadi (mereka itu dijauhkan dari neraka Jahanam).\qt@no{101}}%
\qt@newcmd\qurantrans@id@mmdlxxxv{%
(Mereka tidak mendengar sedikit pun suaranya) yakni suara gemuruh api neraka itu (dan mereka dalam menikmati apa yang diingini oleh mereka) yakni berupa nikmat surga (hidup kekal).\qt@no{102}}%
\qt@newcmd\qurantrans@id@mmdlxxxvi{%
(Mereka tidak disusahkan oleh kedahsyatan yang besar) yaitu perintah yang menyuruh hamba Allah dimasukkan ke dalam neraka (dan mereka disambut) dijemput (oleh para Malaikat) sewaktu mereka keluar dari kuburannya masing-masing, seraya berkata kepada mereka, ("Inilah hari kalian yang telah dijanjikan kepada kalian") sewaktu kalian hidup di dunia.\qt@no{103}}%
\qt@newcmd\qurantrans@id@mmdlxxxvii{%
(Yaitu pada hari) ia dinashabkan oleh lafal Udzkur yang diperkirakan sebelumnya (Kami gulung langit seperti menggulungnya malaikat Sijil) lafal As Sijilli ini adalah nama malaikat pencatat amal perbuatan (terhadap kitab) catatan amal perbuatan anak Adam, sewaktu anak Adam yang bersangkutan mati. Huruf Lam pada lafal Lil Kutubi adalah Zaidah atau tambahan. Atau yang dimaksud dengan As Sijilli adalah lembaran-lembaran, sedangkan yang dimaksud Al Kitab adalah barang yang ditulis atau kertas dan huruf Lamnya bermakna 'Ala. Artinya: sebagaimana tergulungnya lembaran-lembaran kertas. Dan menurut qiraat yang lain lafal Lil Kitabi dibaca Lil Kutubi dalam bentuk jamak, yakni kitab-kitab atau kertas-kertas. (Sebagaimana Kami telah memulai penciptaan pertama) yakni mulai dari alam ketiadaan (begitulah Kami akan mengulanginya) yakni sesudah penciptaan itu ditiadakan. Huruf Kaf di sini berta'alluq kepada lafal Nu'iiduhu dan Dhamir Hu lafal Nu'iiduhu kembali kepada lafal Awwal dan huruf Ma pada lafal Kama adalah Mashdariyah (Itulah suatu janji yang pasti Kami tepati) Lafal Wa'dan dinashabkan oleh lafal Wa'dunaa yang keberadaannya diperkirakan pada sebelumnya, sedangkan lafal Wa'dan ini berfungsi mengukuhkan makna dari lafal yang diperkirakan sebelumnya (sesungguhnya Kamilah yang akan melaksanakannya) yaitu melaksanakan janji yang telah Kami tetapkan.\qt@no{104}}%
\qt@newcmd\qurantrans@id@mmdlxxxviii{%
(Dan sungguh telah Kami tulis di dalam Zabur) yakni kitab Zabur yang telah diturunkan oleh Allah (sesudah adanya peringatan) yang dimaksud adalah Ummul Kitab atau Alquran yang telah ada di sisi Allah, yakni di Lohmahfuz (bahwasanya bumi ini) yakni bumi surga (diwariskan kepada hamba-hamba-Ku yang saleh) yakni siapa saja di antara hamba-hamba-Ku yang saleh.\qt@no{105}}%
\qt@newcmd\qurantrans@id@mmdlxxxix{%
(Sesungguhnya apa yang disebutkan di dalam kitab ini) yakni Alquran (benar-benar menjadi bekal) yakni kecukupan untuk masuk surga (bagi kaum yang menyembah Allah) yakni bagi mereka yang mengamalkannya.\qt@no{106}}%
\qt@newcmd\qurantrans@id@mmdxc{%
(Dan tiadalah Kami mengutus kamu) hai Muhammad! (melainkan untuk menjadi rahmat) yakni merupakan rahmat (bagi semesta alam) manusia dan jin melalui kerasulanmu.\qt@no{107}}%
\qt@newcmd\qurantrans@id@mmdxci{%
(Katakanlah, ``Sesungguhnya yang diwahyukan kepadaku adalah bahwasanya Tuhan kalian adalah Tuhan Yang Maha Esa) tiada diwahyukan kepadaku sehubungan dengan perkara Tuhan, melainkan keesaan-Nya (maka hendaklah kalian berserah diri) taat kepada apa yang diwahyukan kepadaku, yaitu mentauhidkan Tuhan. Istifham di sini mengandung makna perintah.\qt@no{108}}%
\qt@newcmd\qurantrans@id@mmdxcii{%
(Jika mereka berpaling) dari hal tersebut (maka katakanlah, ``Aku telah menyerukan kepada kalian) maksudnya telah memberitahukan kepada kalian untuk berperang (dalam keadaan sama) lafal 'Alaa Sawaa-in ini menjadi Hal dari Fa'il dan Maf'ul. Maksudnya, antara kami dan kalian sama-sama mengetahui maklumat ini, aku tidak memaksakan kalian untuk berperang, tetapi kalian sendirilah yang mengajaknya, maka bersiap-siaplah kalian (dan tidaklah) yakni tiadalah (aku mengetahui, apakah yang diancamkan kepada kalian itu sudah dekat atau masih jauh") maksudnya azab atau kiamat yang juga di dalamnya mengandung azab, akan tetapi sesungguhnya yang mengetahui hal itu hanyalah Allah semata.\qt@no{109}}%
\qt@newcmd\qurantrans@id@mmdxciii{%
(Sesungguhnya Dia) Allah swt. (mengetahui perkataan yang terang-terangan) dan juga perbuatan kalian dan orang-orang selain kalian (dan Dia mengetahui apa yang kalian rahasiakan) yang dirahasiakan kalian dan selain kalian.\qt@no{110}}%
\qt@newcmd\qurantrans@id@mmdxciv{%
(Dan tidaklah) (aku mengetahui, barangkali hal itu) apa yang telah aku beritahukan kepada kalian dan belum diketahui saatnya (sebagai cobaan) ujian (bagi kalian) supaya dapat dilihat, apakah yang diperbuat oleh kalian dan kesenangan) yakni bersenang-senang (sampai kepada suatu waktu) maksudnya sampai habisnya umur kalian. Pengertian ayat ini hanya bersifat kebalikan daripada hal yang diharapkan dengan memakai ungkapan La'alla, akan tetapi bukan subjek daripada harapan tersebut.\qt@no{111}}%
\qt@newcmd\qurantrans@id@mmdxcv{%
(Muhammad berkata) qaala menurut suatu qiraat dibaca Qul, yakni katakanlah hai Muhammad, ("Ya Rabbku! Berilah keputusan) antara aku dan orang-orang yang mendustakan aku (dengan adil) yakni azab bagi mereka atau pertolongan-Mu di dalam menghadapi mereka. Maka akhirnya mereka diazab di dalam perang Badar, Uhud, Hunain, Ahzab dan Khandaq, Nabi saw. mendapat kemenangan atas mereka. (Dan Rabb kami ialah Tuhan Yang Maha Pemurah lagi Yang dimohonkan pertolongan-Nya terhadap apa yang kalian katakan itu") kedustaan perkataan kalian kepada Allah: kalian telah mengatakan-Nya, bahwa Allah mempunyai anak. Perkataan kalian kepadaku, bahwa aku ini adalah seorang penyihir. Perkataan kalian terhadap Alquran, bahwa ia adalah syair semata.\qt@no{112}}%
\qt@newcmd\qurantrans@id@mmdxcvi{%
\basmalahid (Hai manusia!) yakni penduduk Mekah dan selainnya (Bertakwalah kepada Rabb kalian) takutlah kalian akan azab-Nya, yaitu dengan taat kepada-Nya (sesungguhnya keguncangan hari kiamat itu) yakni saat gempa yang amat dahsyat menimpa bumi, lalu disusul dengan terbitnya matahari dari tempat terbenamnya, itulah pertanda kiamat telah di ambang pintu (adalah suatu kejadian yang sangat besar) sangat mengejutkan manusia hal ini merupakan semacam azab.\qt@no{1}}%
\qt@newcmd\qurantrans@id@mmdxcvii{%
(Pada hari kalian melihat keguncangan itu lalailah) disebabkannya (semua wanita yang menyusui anaknya) yang sebenarnya (dari anak yang disusukannya) ia melupakannya (dan gugurlah dari semua wanita yang sedang mengandung) yakni sedang hamil (kandungannya dan kamu lihat manusia dalam keadaan mabuk) disebabkan tercekam perasaan takut yang amat hebat (padahal sebenarnya mereka tidak mabuk) disebabkan minuman keras (akan tetapi azab Allah itu sangat keras) maka mereka takut kepada azab itu.\qt@no{2}}%
\qt@newcmd\qurantrans@id@mmdxcviii{%
Ayat berikut ini diturunkan berkenaan dengan Nadhr bin Harits dan para pengikutnya. (Di antara manusia ada orang yang membantah tentang Allah tanpa ilmu pengetahuan) mereka mengatakan, bahwa para Malaikat itu adalah anak-anak perempuan Allah. Alquran adalah dongengan orang-orang dahulu dan mereka mengingkari adanya hari berbangkit serta dihidupkan-Nya kembali manusia yang telah menjadi tanah (dan mengikuti) di dalam bantahannya itu (setiap setan yang sangat jahat) yaitu sangat membangkang.\qt@no{3}}%
\qt@newcmd\qurantrans@id@mmdxcix{%
(Yang telah ditetapkan terhadap setan itu) telah diputuskan terhadapnya (bahwa barang siapa yang berkawan dengan dia) mengikutinya (tentu dia akan menyesatkannya dan membawanya) menjerumuskannya (ke azab neraka) yang apinya berkobar-kobar.\qt@no{4}}%
\qt@newcmd\qurantrans@id@mmdc{%
(Hai manusia) yakni penduduk Mekah (jika kalian dalam keraguan) kalian meragukan (tentang hari berbangkit, sesungguhnya Kami telah menciptakan kalian) bapak moyang kalian, yaitu Adam (dari tanah, kemudian) Kami ciptakan anak cucunya (dari setetes nuthfah) air mani (kemudian dari segumpal darah) darah yang kental (kemudian dari segumpal daging) daging yang besarnya sekepal tangan (yang sempurna kejadiannya) telah diberi bentuk berupa makhluk yang sempurna (dan yang tidak sempurna) masih belum sempurna bentuknya (agar Kami jelaskan kepada kalian) kemahasempurnaan kekuasaan Kami, yaitu supaya kalian dapat mengambil kesimpulan daripadanya, bahwa Allah yang memulai penciptaan dapat mengembalikan ciptaan itu kepada asalnya. (Dan Kami tetapkan) kalimat ayat ini merupakan kalimat baru (di dalam rahim, apa yang Kami kehendaki sampai waktu yang sudah ditentukan) hingga ia keluar (kemudian Kami keluarkan kalian) dari perut ibu-ibu kalian (sebagai bayi) lafal Thiflan sekalipun berbentuk tunggal tetapi makna yang dimaksud adalah jamak (kemudian) Kami memberi kalian umur secara berangsur-angsur (hingga sampailah kalian kepada kedewasaan) dewasa dan kuat, yaitu di antara umur tiga puluh tahun sampai empat puluh tahun (dan di antara kalian ada yang diwafatkan) yakni mati sebelum mencapai usia dewasa (dan ada pula di antara kalian yang dipanjangkan umurnya sampai pikun) amat tua sehingga menjadi pikun (supaya dia tidak mengetahui lagi sesuatu pun yang dahulunya telah diketahuinya). Sehubungan dengan hal ini Ikrimah mengatakan, ``Barang siapa yang biasa membaca Alquran, niscaya ia tidak akan mengalami nasib yang demikian itu, yakni terlalu tua dan pikun." (Dan kalian lihat bumi ini kering) gersang (kemudian apabila telah Kami turunkan air atasnya, hiduplah bumi itu) menjadi hidup (dan suburlah ia) hidup dengan suburnya (serta dapat menumbuhkan) huruf Min adalah huruf Zaidah (berbagai macam tumbuh-tumbuhan) beraneka ragam tumbuhan (yang indah) yakni yang baik.\qt@no{5}}%
\qt@newcmd\qurantrans@id@mmdci{%
(Yang demikian itu) yakni hal-hal yang telah disebutkan itu mulai dari permulaan kejadian manusia hingga dihidupkannya bumi menjadi subur (karena sesungguhnya) disebabkan bahwa (Allah Dialah yang hak) Yang Tetap dan Abadi (dan sesungguhnya Dialah yang menghidupkan segala yang mati dan sesungguhnya Allah Maha Kuasa atas segala sesuatu).\qt@no{6}}%
\qt@newcmd\qurantrans@id@mmdcii{%
(Dan sesungguhnya hari kiamat itu pastilah datang, tak ada keraguan) tidak diragukan lagi (padanya; dan bahwasanya Allah membangkitkan semua orang di dalam kubur).\qt@no{7}}%
\qt@newcmd\qurantrans@id@mmdciii{%
Ayat berikut ini diturunkan berkenaan dengan Abu Jahal, yaitu: (Dan di antara manusia ada orang-orang yang membantah tentang Allah tanpa ilmu pengetahuan dan tanpa petunjuk) yang menjadi pegangannya (dan tanpa kitab yang bercahaya) kitab yang menjadi pegangannya dan yang dapat menunjukinya.\qt@no{8}}%
\qt@newcmd\qurantrans@id@mmdciv{%
(Dengan memalingkan lambungnya) Lafal ayat ini berkedudukan menjadi Hal atau keterangan keadaan, maksudnya orang yang membantah itu memalingkan lehernya dengan penuh kesombongan karena tidak mau beriman. Pengertian berpaling di sini adalah baik ke kanan maupun ke kiri sama saja (untuk menyesatkan) dapat dibaca Liyadhilla dan Liyudhilla, untuk menyesatkan manusia (dari jalan Allah) yakni dari agama-Nya. (Ia mendapat kehinaan di dunia) azab di dunia, akhirnya ia terbunuh dalam perang Badar (dan di hari kiamat Kami merasakan kepadanya azab neraka yang membakar) ia akan dibakar oleh api neraka, lalu dikatakan kepadanya,\qt@no{9}}%
\qt@newcmd\qurantrans@id@mmdcv{%
("Yang demikian itu, adalah disebabkan perbuatan yang dikerjakan oleh kedua tanganmu dahulu) yakni perbuatan kamu dahulu. Diungkapkan demikian mengingat, bahwa kebanyakan pekerjaan itu dilakukan oleh kedua tangan (dan sesungguhnya Allah sekali-kali bukanlah penganiaya) suka menganiaya (hamba-hamba-Nya") dengan mengazab mereka tanpa dosa.\qt@no{10}}%
\qt@newcmd\qurantrans@id@mmdcvi{%
(Dan di antara manusia ada orang yang menyembah Allah dengan berada di tepi) ia ragu di dalam ibadahnya itu. Keadaannya diserupakan dengan seseorang yang berada di tepi bukit, yakni ia tidak dapat berdiri dengan tetap dan mantap (maka jika ia memperoleh kebaikan) maksudnya kesehatan dan kesejahteraan pada diri dan harta bendanya (tetaplah ia dalam keadaan itu dan jika ia ditimpa oleh suatu bencana) cobaan pada hartanya dan penyakit pada dirinya (berbaliklah ia ke belakang) ia kembali menjadi kafir. (Rugilah ia di dunia) disebabkan terlepasnya semua apa yang ia harapkan dari dunia (dan di akhirat) disebabkan kekafirannya itu. (Yang demikian itu adalah kerugian yang nyata) jelas ruginya.\qt@no{11}}%
\qt@newcmd\qurantrans@id@mmdcvii{%
(Ia menyeru) menyembah (selain Allah) yakni berhala-berhala (sesuatu yang tidak dapat memberi mudarat kepada dirinya) jika ia tidak menyembahnya (dan pula tidak dapat memberi manfaat kepada dirinya) jika ia menyembahnya. (Yang demikian itu) penyembahan itu (adalah kesesatan yang jauh) sekali dari kebenaran.\qt@no{12}}%
\qt@newcmd\qurantrans@id@mmdcviii{%
(Ia menyeru sesuatu) huruf Lam adalah Zaidah (yang sebenarnya mudaratnya) jika ia menyembahnya (lebih dekat dari manfaatnya) jika menurut khayalannya ia dapat memberikan manfaat. (Sesungguhnya sejahat-jahat penolong) adalah sesembahan itu (dan sejahat-jahat kawan) adalah dia pula. Sesudah Allah swt. menyebutkan tentang orang-orang yang ragu dengan akibatnya yaitu kerugian, kemudian Allah mengiringinya dengan kisah mengenai orang-orang Mukmin dengan akibatnya, yaitu mendapatkan pahala dari-Nya. Untuk itu Allah swt. berfirman:\qt@no{13}}%
\qt@newcmd\qurantrans@id@mmdcix{%
(Sesungguhnya Allah memasukkan orang-orang yang beriman dan mengerjakan amal saleh) amal fardu dan sunah semuanya (ke dalam surga-surga yang di bawahnya mengalir sungai-sungai. Sesungguhnya Allah berbuat apa saja yang Dia kehendaki) termasuk memuliakan orang yang taat kepada-Nya dan menghinakan orang yang durhaka kepada-Nya.\qt@no{14}}%
\qt@newcmd\qurantrans@id@mmdcx{%
(Barang siapa yang menyangka bahwa Allah sekali-kali tiada menolongnya) menolong Nabi Muhammad saw. (di dunia dan akhirat, maka hendaklah ia merentangkan tali) tambang (ke langit) yang dimaksud adalah atap rumahnya, kemudian tali itu diikatkan ke atap rumah dan ke lehernya (kemudian hendaklah ia memutuskan tali itu) yakni mencekik dirinya dengan tali itu, maksudnya menggantung diri. Demikianlah sebagaimana yang disebutkan di dalam hadis-hadis sahih (kemudian hendaklah ia pikirkan, apakah tipu dayanya itu sungguh dapat melenyapkan) dalam hal tidak ditolongnya nabi (apa yang menyakitkan hatinya) apa yang membuat ia sakit hati. Maksudnya, hendaklah ia tercekik oleh kejengkelannya, karena sesungguhnya Allah pasti akan menolong nabi-Nya.\qt@no{15}}%
\qt@newcmd\qurantrans@id@mmdcxi{%
(Dan demikianlah) sebagaimana Kami turunkan ayat tadi (Kami telah menurunkan dia) ayat-ayat Alquran selanjutnya (yang merupakan ayat-ayat yang nyata) lafal Bayyinatin berkedudukan menjadi Hal, artinya ayat-ayat yang jelas (dan bahwasanya Allah memberikan petunjuk kepada siapa yang Dia kehendaki) untuk mendapatkan petunjuk-Nya; bagian ayat ini di'athafkan kepada dhamir Ha yang terdapat pada lafal Anzalnaahu.\qt@no{16}}%
\qt@newcmd\qurantrans@id@mmdcxii{%
(Sesungguhnya orang-orang yang beriman, orang-orang Yahudi) mereka adalah pemeluk agama Yahudi (orang-orang Shabi'in) salah satu sekte dari orang-orang Yahudi (orang-orang Nasrani, orang-orang Majusi dan orang-orang Musyrik, Allah akan memberi keputusan di antara mereka pada hari kiamat) yaitu dengan memasukkan orang-orang yang beriman ke dalam surga dan mencampakkan orang-orang selain mereka ke dalam neraka. (Sesungguhnya Allah terhadap segala sesuatu) yang diperbuat mereka (Maha Menyaksikan) mengetahuinya secara nyata.\qt@no{17}}%
\qt@newcmd\qurantrans@id@mmdcxiii{%
(Apakah kamu tiada melihat) tiada mengetahui (bahwa kepada Allah bersujud makhluk yang ada di langit dan makhluk yang ada di bumi dan matahari, bulan, bintang-bintang, gunung-gunung, pohon-pohon dan hewan-hewan yang melata) semuanya tunduk dan patuh menuruti apa yang dikehendaki-Nya (dan sebagian besar daripada manusia?) adalah orang-orang Mukmin, yaitu dengan bertambah perasaan rendah diri dalam sujud salat mereka. (Dan banyak di antara manusia yang telah ditetapkan azab atasnya) mereka adalah orang-orang kafir, karena mereka membangkang tidak mau bersujud, sedangkan sujud itu adalah pertanda iman. (Dan barang siapa yang dihinakan Allah) disengsarakan-Nya (maka tidak seorang pun yang memuliakannya) yang akan membahagiakannya. (Sesungguhnya Allah berbuat apa yang Dia kehendaki) seperti menghinakan dan memuliakan.\qt@no{18}}%
\qt@newcmd\qurantrans@id@mmdcxiv{%
(Inilah dua golongan yang bertengkar) yaitu golongan orang-orang Mukmin di satu pihak dan di pihak lain lima golongan orang-orang kafir yang disebutkan dalam ayat 17=Lafal Khashmun ini dapat diartikan untuk tunggal dan jamak (mereka saling bertengkar mengenai Rabb mereka) dalam urusan agama mereka. (Maka orang-orang kafir akan dibuatkan untuk mereka pakaian-pakaian dari api neraka) yang kemudian mereka pakai, maksudnya mereka diliputi oleh api neraka. (Disiramkan air yang sedang mendidih ke atas kepala mereka) yaitu air yang sangat panas.\qt@no{19}}%
\qt@newcmd\qurantrans@id@mmdcxv{%
(Dihancur leburkan) diluluhkan (dengan air itu apa yang ada dalam perut mereka) yakni lemak dan lain-lainnya (dan) terpangganglah disebabkan panasnya air itu (kulit) mereka.\qt@no{20}}%
\qt@newcmd\qurantrans@id@mmdcxvi{%
(Dan untuk mereka palu-palu dari besi) untuk memukul kepala mereka.\qt@no{21}}%
\qt@newcmd\qurantrans@id@mmdcxvii{%
(Setiap kali mereka hendak keluar dari neraka) tempat mereka diazab (lantaran kesengsaraan mereka) yang menekan diri mereka di dalam neraka (niscaya mereka dikembalikan ke dalamnya) mereka dipukuli dengan palu-palu besi supaya kembali lagi ke neraka. (Dan) dikatakan kepada mereka, ("Rasailah azab yang membakar ini") azab yang sangat membakar ini.\qt@no{22}}%
\qt@newcmd\qurantrans@id@mmdcxviii{%
Allah swt. berfirman kepada orang-orang Mukmin, ("Sesungguhnya Allah memasukkan orang-orang yang beriman dan mengerjakan amal saleh ke dalam surga-surga yang di bawahnya mengalir sungai-sungai. Di surga itu mereka diberi perhiasan dengan gelang-gelang dari emas dan mutiara) kalau dibaca Lu-luin maka artinya perhiasan itu terdiri dari emas dan mutiara, atau emas itu dihiasi dengan mutiara. Jika dibaca Lu-luan berarti ia di'athafkan secara Mahall kepada lafal Min Asaawira. (Dan pakaian mereka adalah sutera) yaitu pakaian yang diharamkan bagi kaum lelaki di dunia.\qt@no{23}}%
\qt@newcmd\qurantrans@id@mmdcxix{%
(Dan mereka diberi petunjuk) di dunia (kepada ucapan-ucapan yang baik) yaitu kalimat La Ilaaha Illallaah/ tidak ada Tuhan selain Allah (dan mereka ditunjuki pula kepada jalan yang terpuji) yakni jalan Allah yang terpuji dan agama-Nya.\qt@no{24}}%
\qt@newcmd\qurantrans@id@mmdcxx{%
(Sesungguhnya orang-orang yang kafir dan menghalangi manusia dari jalan Allah) dari ketaatan kepada-Nya (dan) dari (Masjidilharam yang telah Kami jadikan ia) sebagai manasik dan tempat beribadah (untuk semua manusia, baik yang bermukim) yang tinggal (di situ maupun di padang pasir) yakni pendatang (dan siapa yang bermaksud di dalamnya melakukan kejahatan) huruf Ba di sini adalah Zaidah (secara zalim) yang menyebabkan orang yang bersangkutan zalim, seumpamanya ia mengerjakan perbuatan yang terlarang, sekalipun dalam bentuk mencaci pelayan (niscaya akan Kami rasakan kepadanya sebagian siksa yang pedih)" yang menyakitkan. Berdasarkan pengertian ini maka Khabar Inna diambil daripadanya. Maksudnya, sesungguhnya orang-orang yang kafir dan menghalangi manusia dari jalan Allah dan dari Masjidilharam, niscaya Kami akan rasakan kepada mereka sebagian siksa yang pedih.\qt@no{25}}%
\qt@newcmd\qurantrans@id@mmdcxxi{%
(Dan) ingatlah (ketika Kami jelaskan) Kami terangkan (kepada Ibrahim tempat Baitullah) supaya ia membangunnya kembali karena Baitullah itu telah diangkat sejak zaman banjir besar yakni zamannya Nabi Nuh, kemudian Kami perintahkan kepada Ibrahim, ("Janganlah kamu menyekutukan Aku dengan sesuatu pun dan sucikanlah rumah-Ku ini) dari berhala-berhala (bagi orang-orang yang tawaf dan orang-orang yang bermukim) yakni orang-orang yang tinggal di sekitarnya (dan orang-orang yang rukuk dan sujud") Rukka'is-sujuud adalah bentuk jamak dari kata Raaki 'iin dan Saajidin, maksudnya adalah orang-orang yang salat.\qt@no{26}}%
\qt@newcmd\qurantrans@id@mmdcxxii{%
(Dan berserulah) serukanlah (kepada manusia untuk mengerjakan haji) kemudian Nabi Ibrahim naik ke puncak bukit Abu Qubais, lalu ia berseru, ``Hai manusia! Sesungguhnya Rabb kalian telah membangun Baitullah dan Dia telah mewajibkan kalian untuk melakukan haji, maka sambutlah seruan Rabb kalian ini". Lalu Nabi Ibrahim menolehkan wajahnya ke kanan dan ke kiri serta ke arah Timur dan ke arah Barat. Maka menjawablah semua orang yang telah ditentukan baginya dapat berhaji dari tulang-tulang sulbi kaum lelaki dan rahim-rahim kaum wanita, seraya mengatakan, ``Labbaik allaahumma Labbaika", artinya: Ya Allah, kami penuhi panggilan-Mu, Ya Allah, kami penuhi panggilan-Mu. Sedangkan Jawab dari Amar yang di muka tadi ialah (niscaya mereka akan datang kepadamu dengan berjalan kaki) lafal Rijaalan adalah bentuk jamak dari lafal Raajilun, wazannya sama dengan lafal Qaaimun yang bentuk jamaknya adalah Qiyaamun; artinya berjalan kaki (dan) dengan berkendaraan (dengan menaiki unta yang kurus) karena lamanya perjalanan; lafal Dhamirin dapat ditujukan kepada jenis jantan dan betina (mereka datang) yakni unta-unta kurus itu yang dimaksud adalah orang-orang yang mengendarainya (dari segenap penjuru yang jauh) dari daerah yang perjalanannya sangat jauh.\qt@no{27}}%
\qt@newcmd\qurantrans@id@mmdcxxiii{%
(Supaya mereka mempersaksikan) yakni mendatangi (berbagai manfaat untuk mereka) dalam urusan dunia mereka melalui berdagang, atau urusan akhirat atau untuk keduanya. Sehubungan dengan masalah ini ada berbagai pendapat mengenainya (dan supaya mereka menyebut nama Allah pada hari-hari yang telah ditentukan) yakni tanggal sepuluh Zulhijah, atau hari Arafah, atau hari berkurban hingga akhir hari-hari Tasyriq; mengenai masalah ini pun ada beberapa pendapat (atas rezeki yang telah Allah berikan kepada mereka berupa binatang ternak) unta, sapi dan kambing yang disembelih pada hari raya kurban dan ternak-ternak yang disembelih sesudahnya sebagai kurban. (Maka makanlah sebagian daripadanya) jika kalian menyukainya (dan berikanlah untuk dimakan orang-orang yang sengsara lagi fakir) yakni sangat miskin.\qt@no{28}}%
\qt@newcmd\qurantrans@id@mmdcxxiv{%
(Kemudian hendaklah mereka menghilangkan kotoran yang ada pada badan mereka) maksudnya hendaklah mereka merapihkan ketidakrapihan diri mereka seperti memotong rambut dan kuku yang panjang (dan hendaklah mereka menunaikan) dapat dibaca Walyuufuu dan Walyuwaffuu (nazar-nazar mereka) dengan menyembelih hewan ternak sebagai hewan kurban (dan hendaklah mereka melakukan tawaf) tawaf ifadah (sekeliling rumah yang tua itu) yakni rumah kuno, karena ia adalah rumah pertama yang dibuat untuk ibadah manusia.\qt@no{29}}%
\qt@newcmd\qurantrans@id@mmdcxxv{%
(Demikianlah) menjadi Khabar dari Mubtada yang keberadaannya diperkirakan sebelumnya, yakni perintah Allah itu sebagaimana yang telah disebutkan (dan barang siapa mengagungkan apa-apa yang terhormat di sisi Allah) yaitu hal-hal yang tidak boleh dirusak (maka itu adalah) mengagungkannya (lebih baik baginya di sisi Rabbnya) di akhirat kelak. (Dan telah dihalalkan bagi kamu sekalian binatang ternak) untuk memakannya sesudah disembelih terlebih dahulu (kecuali yang diterangkan kepada kalian) keharamannya di dalam firman yang lainnya yaitu, ``Diharamkan bagi kalian memakan bangkai..." (Q.S. Al-Maidah, 3). Dengan demikian berarti Istitsna di sini bersifat Munqathi'. Dan dapat pula dikatakan Muttashil, sedangkan barang yang diharamkan adalah ditujukan kepada hewan yang mati dengan sendirinya dan oleh penyebab-penyebab lainnya (maka jauhilah oleh kalian berhala-berhala yang najis itu) huruf Min di sini menunjukkan arti Bayan atau keterangan, maksudnya barang yang najis itu adalah berhala-berhala (dan jauhilah perkataan-perkataan dusta) perkataan yang mengandung kemusyrikan terhadap Allah di dalam bacaan Talbiyah kalian, atau yang dimaksud adalah kesaksian palsu.\qt@no{30}}%
\qt@newcmd\qurantrans@id@mmdcxxvi{%
(Dengan ikhlas kepada Allah) yakni berserah diri kepada-Nya serta berpaling dari semua agama selain dari agama-Nya (tidak mempersekutukan sesuatu dengan Dia) kalimat ayat ini mengukuhkan makna kalimat yang sebelumnya dan keduanya itu merupakan Hal atau kata keterangan dari dhamir Wawu. (Barang siapa mempersekutukan sesuatu dengan Allah, maka adalah ia seolah-olah terjungkal) yakni jatuh (dari langit lalu disambar oleh burung) diambil dengan cepat (atau diterbangkan oleh angin yang melemparkannya) yang menjatuhkannya (ke tempat yang jauh sekali) sangat jauh sehingga tidak dapat diharapkan lagi keselamatannya.\qt@no{31}}%
\qt@newcmd\qurantrans@id@mmdcxxvii{%
(Demikianlah) perintah itu (dan barang siapa mengagungkan syiar-syiar Allah, maka sesungguhnya hal itu) mengagungkan syiar-syiar Allah, yaitu menyembelih hewan kurban untuk tanah suci, seumpamanya hewan kurban itu dipilih yang baik dan digemukkan terlebih dahulu (timbul dari ketakwaan hati) dalam diri mereka. Hewan-hewan kurban itu dinamakan Sya'aair disebabkan kesyiarannya yakni kesemarakannya, disebabkan hewan-hewan tersebut telah diberi tanda yang menunjukkan, bahwa mereka untuk dikurbankan, yaitu seperti dicap dengan besi panas pada punggungnya, sehingga menambah semaraknya suasana hari raya.\qt@no{32}}%
\qt@newcmd\qurantrans@id@mmdcxxviii{%
(Bagi kalian pada binatang-binatang hadyu itu ada beberapa manfaat) seperti menjadikannya sebagai hewan kendaraan dan untuk mengangkut barang-barang selagi hal itu tidak membuatnya bahaya atau cacat (sampai pada waktu yang ditentukan) yaitu waktu disembelih sebagai hewan kurban (kemudian tempat wajib serta akhir masa penyembelihannya) tempat diperbolehkan menyembelihnya (ialah setelah sampai ke Baitul Atiq) yaitu maksudnya di semua tanah suci.\qt@no{33}}%
\qt@newcmd\qurantrans@id@mmdcxxix{%
(Dan bagi tiap-tiap umat) golongan orang-orang yang beriman yang telah mendahului kalian (telah Kami syariatkan penyembelihan kurban) kalau dibaca Mansakan adalah Mashdar dan kalau dibaca Minsakan berarti isim makan atau nama tempat. Maksudnya menyembelih kurban atau tempat penyembelihannya (supaya mereka menyebut nama Allah terhadap binatang ternak yang telah direzekikan Allah kepada mereka) sewaktu mereka menyembelihnya. (Maka Tuhan kalian adalah Tuhan Yang Maha Esa, karena itu berserah dirilah kalian kepada-Nya) taat dan patuhlah kalian kepada-Nya. (Dan berilah kabar gembira kepada orang-orang yang tunduk patuh kepada Allah) orang-orang yang taat dan merendahkan diri kepada-Nya.\qt@no{34}}%
\qt@newcmd\qurantrans@id@mmdcxxx{%
(Yaitu orang-orang yang apabila disebutkan nama Allah gemetarlah) yakni takutlah (hati mereka, orang-orang yang sabar terhadap apa yang menimpa mereka) berupa musibah dan malapetaka (orang-orang yang mendirikan salat) yang mengerjakan salat pada waktu-waktunya (dan orang-orang yang menafkahkan sebagian dari apa yang telah Kami rezekikan kepada mereka) mereka menyedekahkannya.\qt@no{35}}%
\qt@newcmd\qurantrans@id@mmdcxxxi{%
(Dan unta-unta itu) al Budna adalah bentuk jamak dari lafal Badanah, yaitu hewan unta (Kami jadikan untuk kalian sebagian syiar Allah) pertanda-pertanda bagi agama-Nya (kalian memperoleh kebaikan yang banyak padanya) kemanfaatan duniawi sebagaimana yang telah disebutkan tadi dan pahala di akhirat (maka sebutlah oleh kalian nama Allah ketika kalian menyembelihnya) sewaktu menyembelihnya (dalam keadaan berdiri) dengan kaki yang terikat. (Kemudian apabila telah roboh) sesudah disembelih, yaitu telah mati dan sudah waktunya untuk dapat dimakan (maka makanlah sebagiannya) jika kalian suka (dan beri makanlah orang yang rela dengan apa yang ada padanya) maksudnya orang-orang yang menerima dengan apa yang diberikan oleh Allah kepadanya dan ia tidak meminta-minta serta tidak pernah memamerkan dirinya miskin (dan orang yang meminta) yaitu orang yang meminta-minta dan orang yang menampakkan kemiskinannya. (Demikianlah) sebagaimana penundukan tadi (Kami telah menundukkan unta-unta itu kepada kalian) sehingga mereka dapat disembelih dan dapat dinaiki, jika tidak Kami tundukkan maka niscaya kalian tidak akan mampu terhadapnya (mudah-mudahan kalian bersyukur) atas nikmat-Ku kepada kalian.\qt@no{36}}%
\qt@newcmd\qurantrans@id@mmdcxxxii{%
(Daging-daging unta dan darahnya itu sekali-kali tidak dapat mencapai keridaan Allah) tidak dapat diterima di sisi-Nya (tetapi ketakwaan daripada kalianlah yang dapat mencapai keridaan-Nya) yaitu yang dapat sampai kepada-Nya hanyalah amal saleh yang ikhlas disertai iman. (Demikianlah Allah telah menundukkannya untuk kalian supaya kalian mengagungkan Allah terhadap hidayah-Nya) yakni atas petunjuk-Nya yang telah membimbing kalian sehingga dapat mengetahui pertanda-pertanda agama dan manasik-manasik haji-Nya. (Dan berilah kabar gembira kepada orang-orang yang berbuat baik) yaitu orang-orang yang mentauhidkan Allah.\qt@no{37}}%
\qt@newcmd\qurantrans@id@mmdcxxxiii{%
(Sesungguhnya Allah membela orang-orang yang telah beriman) daripada perbuatan-perbuatan kaum musyrikin. (Sesungguhnya Allah tidak menyukai tiap-tiap orang yang berkhianat) di dalam amanat yang dititipkan kepadanya (lagi mengingkari nikmat) ingkar terhadap nikmat-nikmat-Nya; mereka adalah orang-orang musyrik. Makna ayat ini ialah bahwa Allah akan mengazab mereka.\qt@no{38}}%
\qt@newcmd\qurantrans@id@mmdcxxxiv{%
(Telah diizinkan bagi orang-orang yang diperangi) yaitu orang-orang Mukmin untuk berperang. Ayat ini adalah ayat pertama yang diturunkan sehubungan dengan masalah jihad (karena sesungguhnya mereka) (telah dianiaya) oleh orang-orang kafir. (Dan sesungguhnya Allah benar-benar Maha Kuasa menolong mereka).\qt@no{39}}%
\qt@newcmd\qurantrans@id@mmdcxxxv{%
Mereka adalah (orang-orang yang telah diusir dari kampung halaman mereka tanpa alasan yang benar) di dalam pengusiran itu; mereka sekali-kali tidak diusir (melainkan karena mereka berkata) disebabkan perkataan yang mereka ucapkan yaitu, ("Rabb kami hanyalah Allah") semata. Perkataan ini adalah perkataan yang hak dan benar, maka mengusir hanya dengan alasan karena mengucapkan perkataan itu adalah tidak dibenarkan. (Dan sekiranya Allah tiada menolak keganasan sebagian manusia) lafal Ba'dhahum menjadi Badal Ba'dh lafal An-Naas (dengan sebagian yang lain, tentulah telah dirobohkan) dibaca Lahuddimat dengan memakai harakat Tasydid menunjukkan makna banyak, yakni telah banyak dirobohkan; sebagaimana dapat dibaca Takhfif yaitu Lahudimat (biara-biara) bagi para rahib (gereja-gereja) bagi orang-orang Nasrani (rumah-rumah ibadah) bagi orang-orang Yahudi; lafal shalawaat artinya tempat peribadatan menurut bahasa Ibrani (dan mesjid-mesjid) bagi kaum Muslimin (yang disebut di dalamnya) maksudnya di dalam tempat-tempat yang telah disebutkan tadi (nama Allah dengan banyak) sehingga ibadah menjadi terhenti karena robohnya tempat-tempat tersebut. (Sesungguhnya Allah pasti menolong orang yang menolong-Nya) menolong agama-Nya. (Sesungguhnya Allah benar-benar Maha Kuat) di atas semua makhluk-Nya (lagi Maha Perkasa) pengaruh dan kekuasaan-Nya maha perkasa.\qt@no{40}}%
\qt@newcmd\qurantrans@id@mmdcxxxvi{%
(Yaitu orang-orang yang jika Kami teguhkan kedudukan mereka di muka bumi) dengan memberikan pertolongan kepada mereka sehingga mereka dapat mengalahkan musuh-musuhnya (niscaya mereka mendirikan salat, menunaikan zakat, menyuruh berbuat yang makruf dan mencegah dari perbuatan yang mungkar) kalimat ayat ini menjadi Jawab Syarat; dan Syarat beserta Jawabnya menjadi Shilah dari Maushul, kemudian diperkirakan adanya lafal Hum sebelumnya sebagai Mubtada (dan kepada Allahlah kembali segala urusan) di akhirat, semua urusan itu kembali kepada-Nya.\qt@no{41}}%
\qt@newcmd\qurantrans@id@mmdcxxxvii{%
(Dan jika mereka mendustakan kamu) ayat ini mengandung makna yang menghibur hati Nabi saw. (maka sesungguhnya telah mendustakan juga sebelum mereka kaum Nuh) lafal Qaum dimuannatskan karena memandang dari segi maknanya (Ad) yakni kaum Nabi Hud (dan Tsamud) kaum Nabi Saleh.\qt@no{42}}%
\qt@newcmd\qurantrans@id@mmdcxxxviii{%
(Dan kaum Ibrahim, kaum Luth).\qt@no{43}}%
\qt@newcmd\qurantrans@id@mmdcxxxix{%
(Dan penduduk Madyan) kaum Nabi Syuaib (dan telah didustakan Musa) didustakan oleh bangsa Koptik bukan oleh kaumnya sendiri yaitu Bani Israel. Maksudnya mereka semuanya mendustakan rasul-rasul mereka, hal itu menjadi perumpamaan bagimu (lalu Aku tangguhkan untuk orang-orang kafir) memberikan tangguh dengan mengakhirkan azab mereka (kemudian Aku balas mereka) yaitu menimpakan azab kepada mereka (maka lihatlah bagaimana besarnya kebencian-Ku) kemurkaan-Ku kepada mereka disebabkan kedustaan mereka, maka Aku binasakan mereka. Istifham di sini mengandung makna Taqrir, maksudnya azab itu benar-benar ditimpakan kepada orang-orang yang berhak menerimanya.\qt@no{44}}%
\qt@newcmd\qurantrans@id@mmdcxl{%
(Berapa banyaknya) sudah berapa banyak (negeri yang Kami telah membinasakannya) menurut qiraat yang lain dibaca Ahlaktuhaa (yang penduduknya dalam keadaan zalim) para penghuninya berbuat aniaya, disebabkan kekafiran mereka (maka runtuhlah) roboh tembok-temboknya (menutupi atap-atapnya) atap-atap rumah mereka tertutup oleh reruntuhan tembok-temboknya (dan) berapa banyak pula (sumur yang terlantar) ditinggalkan begitu saja disebabkan para pemiliknya binasa (dan istana yang tinggi) lagi sepi disebabkan para pemiliknya telah mati binasa.\qt@no{45}}%
\qt@newcmd\qurantrans@id@mmdcxli{%
(Maka apakah mereka tidak berjalan) mereka orang-orang kafir Mekah itu (di muka bumi, lalu mereka mempunyai hati yang dengan itu mereka dapat memahami) apa yang telah menimpa orang-orang yang mendustakan sebelum mereka (atau mempunyai telinga yang dengan itu mereka dapat mendengar?) berita-berita tentang dibinasakannya mereka dan hancurnya negeri-negeri tempat tinggal mereka, oleh sebab itu mereka mengambil pelajaran darinya. (Karena sesungguhnya) kisah yang sesungguhnya (bukanlah mata itu yang buta, tetapi yang buta ialah hati yang di dalam dada) kalimat ayat ini berfungsi mengukuhkan makna sebelumnya.\qt@no{46}}%
\qt@newcmd\qurantrans@id@mmdcxlii{%
(Dan mereka meminta kepadamu agar azab itu disegerakan, padahal Allah sekali-kali tidak akan menyalahi janji-Nya) untuk menurunkan azab itu, maka Dia menurunkannya dalam perang Badar. (Sesungguhnya sehari di sisi Rabbmu) hari-hari di akhirat disebabkan pedihnya azab (adalah seperti seribu tahun dari tahun-tahun yang kalian hitung) dapat dibaca Ya'udduuna dan Ta'udduuna, yakni menurut perhitungan tahun-tahun di dunia.\qt@no{47}}%
\qt@newcmd\qurantrans@id@mmdcxliii{%
(Dan berapa banyaknya kota yang Kami tangguhkan azab-Ku kepadanya, yang penduduknya berbuat zalim, kemudian Aku azab mereka) yang dimaksud dengan kota di sini adalah para penduduknya (dan hanya kepada Akulah kembalinya segala sesuatu).\qt@no{48}}%
\qt@newcmd\qurantrans@id@mmdcxliv{%
(Katakanlah, ``Hai manusia!) yakni penduduk Mekah (Sesungguhnya aku adalah seorang pemberi peringatan yang nyata kepada kalian") dan jelas peringatannya, dan aku adalah pembawa berita gembira bagi orang-orang yang beriman.\qt@no{49}}%
\qt@newcmd\qurantrans@id@mmdcxlv{%
(Maka orang-orang yang beriman dan mengerjakan amal saleh, bagi mereka ampunan) dari dosa-dosa (dan rezeki yang mulia) yaitu surga.\qt@no{50}}%
\qt@newcmd\qurantrans@id@mmdcxlvi{%
(Dan orang-orang yang berusaha terhadap ayat-ayat Kami) Alquran dengan menentang dan membatalkannya (dengan melemahkan) orang-orang yang mengikuti Nabi saw., mereka menganggap lemah orang-orang yang mengikutinya, dan mereka berupaya menghambat kaum Muslimin untuk beriman kepadanya, atau mereka menganggap lemah Kami untuk dapat mengazab mereka. Dan menurut qiraat yang lain dibaca Mu'ajjiziina, yakni mereka dapat mendahului Kami, atau dengan kata lain mereka mengira, bahwa diri mereka yang ingkar terhadap adanya hari berbangkit dan hari pembalasan mereka mengira akan selamat dari azab Kami (mereka itu adalah penghuni-penghuni Jahim) yakni neraka.\qt@no{51}}%
\qt@newcmd\qurantrans@id@mmdcxlvii{%
(Dan Kami tidak mengutus sebelum kamu seorang rasul pun) rasul adalah seorang nabi yang diperintahkan untuk menyampaikan wahyu (dan tidak pula seorang nabi) yaitu orang yang diberi wahyu akan tetapi tidak diperintahkan untuk menyampaikannya (melainkan apabila ia membaca) membacakan Alquran (setan pun, memasukkan godaan-godaan terhadap bacaannya itu) membisikkan apa-apa yang bukan Alquran dan disukai oleh orang-orang yang ia diutus kepada mereka. Sehubungan dengan hal ini Nabi saw. pernah mengatakan setelah beliau membacakan surah An-Najm, yaitu sesudah firman-Nya, ``Maka apakah patut kalian (hai orang-orang musyrik) menganggap Lata, Uzza dan Manat yang ketiganya..." (Q.S. An-Najm, 19-2O) lalu beliau mengatakan, ``Bintang-bintang yang ada di langit yang tinggi itu, sesungguhnya manfaatnya dapat diharapkan". Orang-orang musyrik yang ada di hadapan Nabi saw. kala itu merasa gembira mendengarnya. Hal ini dilakukan oleh Nabi saw. di hadapan mereka, dan sewaktu Nabi saw. membacakan ayat di atas lalu setan meniupkan godaan kepada lisan Nabi saw. tanpa ia sadari, sehingga keluarlah perkataan itu dari lisannya. Maka malaikat Jibril memberitahukan kepadanya apa yang telah ditiupkan oleh setan terhadap lisannya itu, lalu Nabi saw. merasa berduka cita atas peristiwa itu. Hati Nabi saw. menjadi terhibur kembali setelah turunnya ayat berikut ini, ("Allah menghilangkan) membatalkan (apa yang ditiupkan oleh setan itu, dan Dia menguatkan ayat-ayat-Nya) memantapkannya. (Dan Allah Maha Mengetahui) apa yang telah dilancarkan oleh setan tadi (lagi Maha Bijaksana) di dalam memberikan kesempatan kepada setan untuk dapat meniupkan godaannya kepada Nabi saw. Dia berbuat apa saja yang dikehendaki-Nya.\qt@no{52}}%
\qt@newcmd\qurantrans@id@mmdcxlviii{%
(Agar Dia menjadikan apa yang ditiupkan oleh setan itu sebagai cobaan) yakni musibah (bagi orang-orang yang di dalam hatinya ada penyakit) perselisihan dan kemunafikan (dan yang kasar hatinya) orang-orang musyrik; hati mereka kasar dan keras tidak mau menerima barang yang hak. (Dan sesungguhnya orang-orang yang zalim itu) yakni orang-orang kafir (benar-benar dalam permusuhan yang sangat") mereka berada dalam perselisihan yang berkepanjangan dengan Nabi saw. dan orang-orang Mukmin, hal ini dapat diketahui sewaktu terlontar kata-kata dari lisan Nabi saw. yang menyebutkan tuhan-tuhan mereka dengan sebutan yang membuat mereka suka; hanya saja hal itu dibatalkan oleh firman Allah selanjutnya.\qt@no{53}}%
\qt@newcmd\qurantrans@id@mmdcxlix{%
(Dan agar orang-orang yang telah diberi ilmu meyakini) diberi ilmu tentang ketauhidan dan Alquran (bahwasanya Alquran) itulah (yang hak dari Rabbmu lalu mereka beriman kepadanya dan tenanglah) yakni mantaplah (hati mereka kepadanya, dan sesungguhnya Allah adalah Pemberi petunjuk bagi orang-orang yang beriman kepada jalan) tuntunan (yang lurus) yaitu agama Islam.\qt@no{54}}%
\qt@newcmd\qurantrans@id@mmdcl{%
(Dan senantiasalah orang-orang kafir itu berada dalam keragu-raguan) tidak percaya (terhadap Alquran) disebabkan apa-apa yang diembuskan oleh setan melalui lisan Nabi, kemudian hal itu dibatalkan (hingga datang kepada mereka saat ajalnya dengan tiba-tiba) saat kematian mereka, atau yang dimaksud adalah hari kiamat yang datang secara mendadak (atau datang kepada mereka azab hari kiamat) yaitu perang Badar, yang di dalam perang itu tiada kebaikan sedikit pun bagi orang-orang kafir; keadaan pada hari itu diserupakan bagaikan angin kering yang tidak membawa kebaikan sedikit pun. Atau makna yang dimaksud adalah azab hari kiamat, yaitu hari yang tidak ada malam hari lagi sesudahnya.\qt@no{55}}%
\qt@newcmd\qurantrans@id@mmdcli{%
(Kekuasaan di hari itu) yaitu hari kiamat (hanyalah bagi Allah) semata. Makna Istiqrar atau tetap yang terkandung sebelum lafal Yaumaidzin adalah 'Amil yang menashabkan Zharaf atau lafal Yaumaidzin. Maksudnya; kekuasaan pada hari kiamat itu hanyalah tetap bagi Allah semata (Dia memberi keputusan di antara mereka) antara kaum Mukminin dan orang-orang kafir, pengertian ini dijelaskan oleh firman selanjutnya, yaitu, (Maka orang-orang yang beriman dan beramal saleh adalah di dalam surga yang penuh kenikmatan) penuh dengan anugerah dari Allah.\qt@no{56}}%
\qt@newcmd\qurantrans@id@mmdclii{%
(Dan orang-orang yang kafir dan mendustakan ayat-ayat Kami, maka bagi mereka azab yang menghinakan) azab yang keras disebabkan kekafiran mereka.\qt@no{57}}%
\qt@newcmd\qurantrans@id@mmdcliii{%
(Dan orang-orang yang berhijrah di jalan Allah) jalan ketaatan kepada-Nya, yaitu berhijrah dari Mekah ke Madinah (kemudian mereka dibunuh atau mati, benar-benar Allah akan memberikan kepada mereka rezeki yang baik) yakni rezeki di surga. (Dan sesungguhnya Allah adalah sebaik-baik pemberi rezeki) Pemberi rezeki yang paling utama.\qt@no{58}}%
\qt@newcmd\qurantrans@id@mmdcliv{%
(Sesungguhnya Allah akan memasukkan mereka ke dalam suatu tempat) dapat dibaca Mudkhalan dan Madkhalan, artinya tempat masuk atau suatu tempat (yang mereka menyukainya) yaitu surga. (Dan sesungguhnya Allah Maha Mengetahui) tentang niat mereka (lagi Maha Penyantun) dari menghukum mereka.\qt@no{59}}%
\qt@newcmd\qurantrans@id@mmdclv{%
Perkaranya (demikianlah) apa yang telah Kami ceritakan kepadamu (dan barang siapa membalas) melakukan pembalasan, yang dimaksud adalah orang-orang Mukmin (seimbang dengan penganiayaan yang pernah ia derita) sesuai dengan penganiayaan yang dialaminya dari orang-orang musyrik yang berbuat aniaya terhadapnya. Atau dengan kata lain, ia memerangi mereka sebagaimana mereka memeranginya di bulan Muharam (kemudian ia dianiaya lagi) dan diusir dari kampung halamannya oleh mereka (pasti Allah akan menolongnya. Sesungguhnya Allah benar-benar Maha Pemaaf) terhadap orang-orang yang beriman (lagi Maha Pengampun) terhadap mereka yang memerangi orang-orang musyrik, sekalipun dalam bulan Muharam.\qt@no{60}}%
\qt@newcmd\qurantrans@id@mmdclvi{%
(Yang demikian itu) pertolongan atau kemenangan itu (adalah karena sesungguhnya Allah kuasa memasukkan malam ke dalam siang dan memasukkan siang ke dalam malam) Dia berkuasa untuk memasukkan masing-masing di antara keduanya kepada yang lainnya, yaitu dengan mengembalikan waktu pada salah satu di antaranya. Yang demikian itu merupakan pengaruh daripada kekuasaan Allah swt. yang dengan kekuasaan-Nya itu kaum Muslimin dapat kemenangan (dan bahwasanya Allah Maha Mendengar) terhadap doa-doa kaum Mukminin (lagi Maha Melihat) perihal orang-orang yang beriman, di mana Dia menjadikan iman dalam diri mereka, kemudian Dia memperkenankan doa mereka.\qt@no{61}}%
\qt@newcmd\qurantrans@id@mmdclvii{%
(Demikian itu) yakni kemenangan itu pun (adalah karena sesungguhnya Allah, Dialah Tuhan yang hak) yang semestinya (dan sesungguhnya apa saja yang mereka seru) dapat dibaca Yad'uuna dan Tad'uuna, maksudnya apa saja yang mereka sembah (selain dari Allah) yakni berhala-berhala (itulah yang batil) yakni yang akan lenyap (dan sesungguhnya Allah, Dialah Yang Maha Tinggi) atas segala sesuatu dengan kekuasaan-Nya (lagi Maha Besar) artinya segala sesuatu selain-Nya adalah kecil.\qt@no{62}}%
\qt@newcmd\qurantrans@id@mmdclviii{%
(Apakah kamu tiada melihat) tidak mengetahui (bahwasanya Allah menurunkan air dari langit) yakni hujan (lalu jadilah bumi itu hijau?) disebabkan adanya tumbuh-tumbuhan sesudah itu, hal ini merupakan bukti bagi kekuasaan Allah. (Sesungguhnya Allah benar-benar Maha Lembut) terhadap hamba-hamba-Nya, karena itu Dia menumbuhkan tumbuh-tumbuhan dengan air hujan itu (lagi Maha Waspada) terhadap apa yang ada dalam hati mereka, di kala hujan datang terlambat.\qt@no{63}}%
\qt@newcmd\qurantrans@id@mmdclix{%
(Kepunyaan-Nyalah segala yang ada di langit dan segala yang ada di bumi) sebagai milik-Nya. (Dan sesungguhnya Allah benar-benar Maha Kaya) tidak membutuhkan hamba-hamba-Nya (lagi Maha Terpuji) terhadap kekasih-kekasih-Nya.\qt@no{64}}%
\qt@newcmd\qurantrans@id@mmdclx{%
(Apakah kamu tiada melihat) tiada mengetahui (bahwasanya Allah menundukkan bagi kalian apa yang ada di bumi) berupa hewan-hewan ternak (dan bahtera) perahu, kapal (yang berlayar di laut) hingga dapat dinaiki dan dapat membawa muatan (dengan perintah-Nya) dengan seizin-Nya. (Dan Dia menahan benda-benda langit) (supaya tidak) supaya jangan (jatuh ke bumi melainkan dengan izin-Nya) oleh sebab itu mereka akan hancur binasa. (Sesungguhnya Allah benar-benar Maha Pengasih lagi Maha Penyayang kepada manusia) oleh karenanya Dia menundukkan kesemuanya itu, dan menahan langit supaya tidak jatuh menimpa mereka.\qt@no{65}}%
\qt@newcmd\qurantrans@id@mmdclxi{%
(Dan Dialah Allah yang telah menghidupkan kalian) menumbuhkan kalian (kemudian mematikan kalian) bilamana ajal atau batas umur kalian telah habis (kemudian menghidupkan kalian lagi) di waktu hari berbangkit (sesungguhnya manusia itu) yakni orang yang musyrik (benar-benar sangat mengingkari) kepada nikmat-nikmat Allah, disebabkan mereka tidak mau mengesakan-Nya.\qt@no{66}}%
\qt@newcmd\qurantrans@id@mmdclxii{%
(Bagi tiap-tiap umat telah Kami tetapkan manasik tertentu) dapat dibaca Mansakan dan Minsakan artinya syariat (yang mereka lakukan) yakni mereka amalkan (maka janganlah sekali-kali mereka membantah kamu) makna yang dimaksud adalah, janganlah kamu membantah mereka (dalam urusan ini) masalah penyembelihan, karena mereka mengatakan, bahwa apa yang dimatikan oleh Allah yakni bangkai lebih berhak untuk kalian makan daripada apa yang kalian sembelih (dan serulah manusia kepada Rabbmu) agama-Nya. (Sesungguhnya kamu benar-benar berada pada petunjuk) agama (yang lurus).\qt@no{67}}%
\qt@newcmd\qurantrans@id@mmdclxiii{%
(Dan jika mereka membantah kamu) dalam masalah agama (maka katakanlah! ``Allah lebih mengetahui tentang apa yang kalian kerjakan") maka Dia akan membalasnya kepada kalian. Ayat ini diturunkan sebelum ada perintah untuk berperang.\qt@no{68}}%
\qt@newcmd\qurantrans@id@mmdclxiv{%
(Allah akan mengadili di antara kalian) hai orang-orang Mukmin dan orang-orang kafir (pada hari kiamat tentang apa yang kalian dahulu selalu berselisih padanya) yaitu satu golongan dengan golongan lainnya berbeda pendapat.\qt@no{69}}%
\qt@newcmd\qurantrans@id@mmdclxv{%
(Apakah kamu tidak mengetahui) Istifham di sini bermakna Taqrir, maksudnya bukankah kamu telah mengetahui (bahwa sesungguhnya Allah mengetahui apa saja yang ada di langit dan di bumi; bahwasanya yang demikian itu) apa yang telah disebutkan tadi (terdapat dalam Kitab?) yang dimaksud adalah Lohmahfuz. (Sesungguhnya yang demikian itu) pengetahuan apa yang telah disebutkan tadi (amat mudah bagi Allah.)\qt@no{70}}%
\qt@newcmd\qurantrans@id@mmdclxvi{%
(Dan mereka menyembah) yakni orang-orang musyrik (selain daripada Allah, apa yang Allah tidak menurunkan tentang itu) yang dimaksud adalah berhala-berhala (suatu keterangan pun) hujah mengenainya (dan apa yang mereka sendiri tidak mempunyai pengetahuan terhadapnya) bahwasanya hal-hal itu adalah tuhan-tuhan. (Dan bagi orang-orang yang zalim sekali-kali tidak ada) zalim karena melakukan kemusyrikan (seorang penolong pun) yang dapat mencegah azab Allah dari diri mereka.\qt@no{71}}%
\qt@newcmd\qurantrans@id@mmdclxvii{%
(Dan apabila dibacakan di hadapan mereka ayat-ayat Kami) dari Alquran (yang terang) jelas keadaannya (niscaya kamu melihat tanda-tanda keingkaran pada muka orang-orang yang kafir itu) keingkaran mereka terhadap ayat-ayat Kami, yaitu sebagai pengaruh dari kebencian mereka terhadapnya, kelihatan muka mereka sangat masam. (Hampir-hampir mereka menyerang orang-orang yang membacakan ayat-ayat Kami di hadapan mereka) akan menimpakan kekerasan terhadap mereka. (Katakanlah! ``Apakah akan aku kabarkan kepada kalian yang lebih buruk daripada itu?) perkara yang lebih kalian tidak sukai daripada Alquran yang dibacakan kepada kalian ini (Yaitu neraka". Allah telah mengancamkannya kepada orang-orang yang kafir) bahwasanya tempat kembali mereka adalah neraka. (Dan seburuk-buruk tempat kembali) itu adalah neraka.\qt@no{72}}%
\qt@newcmd\qurantrans@id@mmdclxviii{%
(Hai manusia,) yakni penduduk Mekah (telah dibuatkan perumpamaan, maka dengarkanlah oleh kalian perumpamaan itu) yaitu, (Sesungguhnya segala yang kalian seru) kalian sembah (selain Allah) yaitu berhala-berhala (sekali-kali tidak dapat menciptakan seekor lalat pun) lafal Dzubaaban adalah isim jenis, yang artinya jamak, sedangkan bentuk tunggalnya adalah Dzubaabatun; lafal ini dapat dipakai untuk mudzakkar dan muanats (walaupun mereka bersatu untuk menciptakannya) untuk membuatnya. (Dan jika lalat itu merampas sesuatu dari mereka) apa yang ada pada mereka berupa wewangian dan minyak Za'faron yang dilumurkan kepada berhala-berhala mereka itu (tiadalah mereka dapat menyelamatkan sesuatu itu) dapat merampas kembali sesuatu itu (dari lalat itu) karena mereka tidak mampu, mengapa mereka menyembah selain Allah? Yaitu apa-apa yang mereka anggap sebagai sekutu-sekutu Allah. Ini adalah hal yang aneh sekali, diungkapkan oleh peribahasa dengan ungkapan seperti berikut ini, ("Alangkah lemahnya yang menyeru) yakni yang menyembah (dan alangkah lemahnya pula yang diseru) yakni yang disembah.\qt@no{73}}%
\qt@newcmd\qurantrans@id@mmdclxix{%
(Mereka tidak menganggap Allah) tidak mengagungkan-Nya (dengan sebenar-benarnya) dengan pengagungan yang sebenarnya, disebabkan mereka menyekutukan-Nya dengan apa-apa yang tidak dapat mencegah seekor lalat pun dan tidak dapat pula merebut apa yang telah diambilnya. (Sesungguhnya Allah benar-benar Maha Kuat lagi Maha Perkasa") yakni Maha Menang.\qt@no{74}}%
\qt@newcmd\qurantrans@id@mmdclxx{%
(Allah memilih utusan-utusan-Nya dari malaikat dan dari manusia) sebagai rasul-rasul-Nya. Ayat ini diturunkan ketika orang-orang musyrik mengatakan, sebagaimana yang telah disitir oleh firman-Nya, ``Mengapa Alquran itu diturunkan kepadanya di antara kita?" (Q.S. Shad, 8) (sesungguhnya Allah Maha Mendengar) ucapan-ucapan mereka (lagi Maha Melihat) utusan yang telah diangkat-Nya, seperti malaikat Jibril, malaikat Mikail, Nabi Ibrahim, Nabi Muhammad dan Rasul-rasul lainnya, semoga selawat dan salam Allah curahkan kepada mereka semuanya.\qt@no{75}}%
\qt@newcmd\qurantrans@id@mmdclxxi{%
(Allah mengetahui apa yang ada di hadapan mereka dan apa yang ada di belakang mereka) apa yang akan mereka lakukan dan apa yang telah mereka lakukan, dan apa yang sekarang sedang mereka lakukan. (Dan hanya kepada Allah dikembalikan semua urusan).\qt@no{76}}%
\qt@newcmd\qurantrans@id@mmdclxxii{%
(Hai orang-orang yang beriman! Rukuk dan sujudlah kalian) salatlah kalian (dan sembahlah Rabb kalian) tauhidkanlah Dia (dan perbuatlah kebaikan) seperti menghubungkan silaturahim dan melakukan akhlak-akhlak yang mulia (supaya kalian mendapat keberuntungan) kalian beruntung karena dapat hidup abadi di surga.\qt@no{77}}%
\qt@newcmd\qurantrans@id@mmdclxxiii{%
(Dan berjihadlah kalian pada jalan Allah) demi menegakkan agama-Nya (dengan jihad yang sebenar-benarnya) dengan mengerahkan segala kemampuan kalian di dalamnya. Lafal Haqqa dinashabkan disebabkan menjadi Mashdar. (Dia telah memilih kalian) untuk membela agama-Nya (dan Dia sekali-kali tidak menjadikan untuk kalian dalam agama suatu kesempitan) artinya hal-hal yang membuat kalian sulit untuk melakukannya, untuk itu Dia memberikan kemudahan kepada kalian dalam keadaan darurat, antara lain boleh mengkasar salat, bertayamum, memakan bangkai, dan berbuka puasa bagi orang yang sedang sakit dan bagi yang sedang melakukan perjalanan (sebagaimana agama orang tua kalian) kedudukan lafal Millata dinashabkan dengan cara mencabut huruf Jarrnya, yaitu huruf Kaf (Ibrahim) lafal ini menjadi athaf Bayan. (Dia) yakni Allah (telah menamai kalian orang-orang Muslim dari dahulu) sebelum diturunkannya Alquran (dan begitu pula dalam Kitab ini) yakni Alquran (supaya Rasul itu menjadi saksi atas diri kalian) kelak di hari kiamat, bahwasanya dia telah menyampaikan kepada kalian (dan kalian) semuanya (menjadi saksi atas segenap manusia) bahwasanya Rasul-rasul mereka telah menyampaikan risalah-Nya kepada mereka (maka dirikanlah salat) maksudnya laksanakanlah salat secara terus-menerus (tunaikanlah zakat dan berpeganglah kalian kepada Allah) percayalah kalian kepada-Nya (Dia adalah pelindung kalian) yang menolong kalian dan yang mengurus perkara-perkara kalian (maka sebaik-baik pelindung) adalah Dia (dan sebaik-baik penolong) kalian adalah Dia.\qt@no{78}}%
\qt@newcmd\qurantrans@id@mmdclxxiv{%
\basmalahid (Sesungguhnya) lafal Qad di sini menunjukkan makna Tahqiq, artinya sungguh telah pasti (beruntunglah) berbahagialah (orang-orang yang beriman).\qt@no{1}}%
\qt@newcmd\qurantrans@id@mmdclxxv{%
(Yaitu orang-orang yang khusyuk dalam salatnya) dengan merendahkan diri penuh perasaan kepada Allah.\qt@no{2}}%
\qt@newcmd\qurantrans@id@mmdclxxvi{%
(Dan orang-orang yang menjauhkan diri dari hal yang tiada berguna) berupa perkataan dan hal-hal lainnya.\qt@no{3}}%
\qt@newcmd\qurantrans@id@mmdclxxvii{%
(Dan orang-orang yang terhadap zakat mereka menunaikannya) membayarnya.\qt@no{4}}%
\qt@newcmd\qurantrans@id@mmdclxxviii{%
(Dan orang-orang yang terhadap kemaluannya mereka selalu memeliharanya) dari yang diharamkan.\qt@no{5}}%
\qt@newcmd\qurantrans@id@mmdclxxix{%
(Kecuali terhadap istri-istri mereka) (atau terhadap budak yang mereka miliki) yakni hamba sahaya wanita yang mereka tawan dari peperangan (maka sesungguhnya mereka dalam hal ini tiada tercela) bila mereka mendatanginya.\qt@no{6}}%
\qt@newcmd\qurantrans@id@mmdclxxx{%
(Barang siapa menginginkan yang selain itu) selain istri-istri sendiri dan sahaya wanita tawanan mereka untuk pelampiasan hajat biologisnya, seumpamanya melakukan masturbasi (maka mereka itulah orang-orang yang melampaui batas) yakni melampaui batas halal dan melakukan hal-hal yang diharamkan bagi mereka.\qt@no{7}}%
\qt@newcmd\qurantrans@id@mmdclxxxi{%
(Dan orang-orang yang terhadap amanat yang dipercayakan kepada mereka) dapat dibaca secara jamak dan mufrad, yakni Amaanaatihim dan Amaanatihim (dan janji mereka) yang mereka adakan di antara sesama mereka atau antara mereka dengan Allah, seperti salat dan lain-lainnya (mereka memeliharanya) benar-benar menjaganya.\qt@no{8}}%
\qt@newcmd\qurantrans@id@mmdclxxxii{%
(Dan orang-orang yang terhadap salat mereka) dapat dibaca dalam bentuk jamak dan mufrad, yakni Shalawaatihim dan shalaatihim (mereka memeliharanya) mereka mengerjakannya tepat pada waktu-waktunya.\qt@no{9}}%
\qt@newcmd\qurantrans@id@mmdclxxxiii{%
(Mereka itulah orang-orang yang akan mewarisi) bukan selain mereka.\qt@no{10}}%
\qt@newcmd\qurantrans@id@mmdclxxxiv{%
(Yakni yang akan mewarisi surga Firdaus) yaitu surga yang tempatnya paling tinggi. (Mereka kekal di dalamnya) di dalam ayat-ayat yang telah lalu terkandung isyarat yang menunjukkan tempat kembali di akhirat. Hal ini sangat relevan bila disebutkan hal-hal yang menyangkut masalah permulaan atau asal kejadian, sesudah pembahasan tadi.\qt@no{11}}%
\qt@newcmd\qurantrans@id@mmdclxxxv{%
(Dan) Allah telah berfirman, (Sesungguhnya Kami telah menciptakan manusia) yakni Adam (dari suatu sari pati) lafal Sulaalatin berasal dari perkataan Salaltusy Syai-a Minasy Syai-i, artinya aku telah memeras sesuatu daripadanya, yang dimaksud adalah inti sari dari sesuatu itu (berasal dari tanah) lafal Min Thiinin berta'alluq kepada lafal Sulaalatin.\qt@no{12}}%
\qt@newcmd\qurantrans@id@mmdclxxxvi{%
(Kemudian Kami jadikan ia) manusia atau keturunan Adam (dari nuthfah) yakni air mani (yang berada dalam tempat yang kokoh) yaitu rahim.\qt@no{13}}%
\qt@newcmd\qurantrans@id@mmdclxxxvii{%
(Kemudian air mani itu Kami jadikan segumpal darah) darah kental (lalu segumpal darah itu Kami jadikan segumpal daging) daging yang besarnya sekepal tangan (dan segumpal daging itu Kami jadikan tulang-belulang, lalu tulang-belulang itu Kami bungkus dengan daging) menurut qiraat yang lain lafal 'Izhaaman dalam dua tempat tadi dibaca 'Azhman, yakni dalam bentuk tunggal. Dan lafal Khalaqnaa yang artinya menciptakan, pada tiga tempat tadi bermakna Shayyarnaa, artinya Kami jadikan (kemudian Kami jadikan dia sebagai makhluk yang lain) yaitu dengan ditiupkan roh ke dalam tubuhnya. (Maka Maha Sucilah Allah, Pencipta Yang Paling Baik) sebaik-baik Yang Menciptakan. Sedangkan Mumayyiz dari lafal Ahsan tidak disebutkan, karena sudah dapat diketahui dengan sendirinya, yaitu lafal Khalqan.\qt@no{14}}%
\qt@newcmd\qurantrans@id@mmdclxxxviii{%
(Kemudian, sesudah itu sesungguhnya kamu sekalian benar-benar akan mati).\qt@no{15}}%
\qt@newcmd\qurantrans@id@mmdclxxxix{%
(Kemudian, sesungguhnya kamu sekalian akan dibangkitkan di hari kiamat) untuk menjalani hisab dan pembalasan.\qt@no{16}}%
\qt@newcmd\qurantrans@id@mmdcxc{%
(Dan sesungguhnya Kami telah menciptakan di atas kalian tujuh buah jalan) yakni tujuh langit; lafal Tharaaiq ini adalah bentuk jamak dari lafal Thariiqah, dikatakan demikian karena ia adalah jalan-jalan bagi para Malaikat (dan tidaklah Kami terhadap makhluk) yang berada di bawah tujuh langit itu (melupakannya) dengan membiarkan langit itu runtuh menimpa mereka, sehingga mereka binasa semuanya, akan tetapi Kami menahannya supaya jangan runtuh; sebagaimana yang telah disebutkan dalam firman-Nya yang lain, yaitu, ``Dan Dia menahan (benda-benda) langit jatuh ke bumi." (Q.S. Al-Hajj, 65).\qt@no{17}}%
\qt@newcmd\qurantrans@id@mmdcxci{%
(Dan Kami turunkan air dari langit menurut suatu ukuran) berdasarkan kecukupan mereka (lalu Kami jadikan air itu menetap di bumi, dan sesungguhnya Kami benar-benar berkuasa menghilangkannya) jika demikian mereka pasti akan mati bersama dengan hewan ternak mereka karena kehausan.\qt@no{18}}%
\qt@newcmd\qurantrans@id@mmdcxcii{%
(Lalu dengan air itu, Kami tumbuhkan untuk kalian kebun-kebun kurma dan anggur) kedua jenis buah-buahan ini kebanyakan terdapat di negeri Arab (di dalam kebun-kebun itu kalian peroleh buah-buahan yang banyak dan sebagian dari buah-buahan itu kalian makan) di waktu musim panas dan musim dingin.\qt@no{19}}%
\qt@newcmd\qurantrans@id@mmdcxciii{%
(Dan) Kami tumbuhkan pula (pohon kayu yang asal tumbuhnya dari Thursina) dapat dibaca Sina dan Saina dengan tidak menerima Tanwin karena menjadi 'Alamiyah, artinya nama sebuah bukit. Jika tidak menerima tanwin karena Illat Ta'nits, maka berarti nama suatu lembah (yang menghasilkan) dapat dibaca Tunbitu dan Tanbutu (minyak) bila menurut bacaan Tunbitu maka huruf Ba dianggap huruf Zaidah, bila menurut bacaan yang kedua yaitu Tanbutu maka huruf Ba dianggap sebagai huruf Ta'diyah yang menggandengkan Fi'il dengan Maf'ul; pohon yang dimaksud adalah pohon Zaitun (dan sebagai penyedap bagi orang-orang yang makan) lafal ini di'athafkan kepada lafal Bid Duhni, sehingga dibaca Wa Shibghin Lil Aakiliina. Artinya, sebagai penyedap suapan yang dicelupkan kepadanya kemudian dimakan, yang dimaksud adalah minyak Zaitun tersebut.\qt@no{20}}%
\qt@newcmd\qurantrans@id@mmdcxciv{%
(Dan sesungguhnya pada binatang-binatang ternak bagi kalian) yakni unta, sapi dan kambing (benar-benar terdapat pelajaran yang penting) bahan pelajaran yang kalian dapat mengambil manfaat besar daripadanya (Kami memberi minum kalian) dapat dibaca Nasqiikum dan Nusqiikum (dari apa yang ada di dalam perutnya) yakni air susu (dan juga pada hewan ternak itu terdapat faedah yang banyak bagi kalian) dari bulu domba, unta dan kambing serta manfaat-manfaat yang lainnya (dan sebagian daripadanya kalian makan).\qt@no{21}}%
\qt@newcmd\qurantrans@id@mmdcxcv{%
(Dan di atas punggung-punggung ternak itu) khususnya unta (dan juga di atas bahtera) yaitu perahu-perahu dan kapal-kapal (kalian diangkut).\qt@no{22}}%
\qt@newcmd\qurantrans@id@mmdcxcvi{%
(Dan sesungguhnya Kami telah mengutus Nuh kepada kaumnya, lalu ia berkata, ``Hai kaumku! Sembahlah oleh kamu sekalian Allah) taatilah dan esakanlah Allah (karena sekali-kali tidak ada Tuhan bagi kalian selain Dia) lafal Ghairuhu merupakan Isim dari Maa, sedangkan lafal sebelumnya menjadi Khabar dari Maa dan huruf Min adalah huruf Zaidah. (Maka mengapa kalian tidak bertakwa kepada-Nya?") tidak takut kepada azab-Nya, mengapa kalian menyembah selain-Nya?\qt@no{23}}%
\qt@newcmd\qurantrans@id@mmdcxcvii{%
(Maka pemuka-pemuka orang yang kafir di antara kaumnya berkata) kepada para pengikut mereka, ("Orang ini tidak lain hanyalah manusia seperti kalian, yang bermaksud hendak menjadi seorang yang lebih tinggi) lebih mulia dan berpengaruh (dari kalian) maksudnya ia ingin menjadi orang yang banyak pengikutnya, dan para pengikutnya adalah kalian sendiri. (Dan kalau Allah menghendaki) supaya tidak disembah selain daripada-Nya (tentu Dia mengutus beberapa Malaikat) untuk menyampaikan hal tersebut, tidak mengutus manusia. (Belum pernah kami mendengar seruan yang seperti ini) yang diserukan oleh Nabi Nuh, maksudnya ajaran tauhid (pada masa nenek moyang kami yang dahulu) yakni umat-umat terdahulu.\qt@no{24}}%
\qt@newcmd\qurantrans@id@mmdcxcviii{%
(Ia tiada lain) maksudnya Nuh ini tidak lain (hanyalah seorang laki-laki yang berpenyakit gila) dalam keadaan gila (maka tunggulah terhadapnya) tunggulah dia, atau biarkanlah dia (sampai suatu waktu") hingga saat kematiannya. Maksud mereka biarkanlah dia begitu, nanti juga mati sendiri.\qt@no{25}}%
\qt@newcmd\qurantrans@id@mmdcxcix{%
(Berdoalah) Nabi Nuh, ("Ya Rabbku! Tolonglah aku) atas mereka (karena mereka mendustakan aku") yakni mereka tidak mau percaya lagi kepadaku, maka binasakanlah mereka. Maka Allah berfirman memperkenankan doanya:\qt@no{26}}%
\qt@newcmd\qurantrans@id@mmdcc{%
(Lalu Kami wahyukan kepadanya, ``Buatlah bahtera) yakni perahu (di bawah pengawasan Kami) maksudnya di bawah penilikan dan pengawasan Kami (dan wahyu Kami) yaitu perintah Kami (maka apabila perintah Kami datang) yakni perintah untuk membinasakan mereka (dan tanur telah memancarkan air) dapur pembuat roti telah memancarkan air, sebagai pertanda bagi Nabi Nuh (maka masukkanlah ke dalam bahtera itu) naikkanlah ke dalamnya (dari tiap-tiap jenis) hewan (sepasang) jantan dan betina. Lafal Itsnaini adalah Maf'ul, sedangkan huruf Min berta'alluq kepada lafal Usluk. Menurut suatu kisah disebutkan, bahwa Allah swt. mengumpulkan bagi Nabi Nuh segala macam jenis binatang liar dan burung-burung, serta hewan-hewan lainnya. Kemudian Nabi Nuh memukulkan tangannya kepada tiap-tiap jenis, tangan kanannya mengenai jenis jantan dan tangan kirinya mengenai jenis betina, kemudian ia menaikkan semuanya ke dalam bahtera. Menurut Qiraat yang lain lafal kulli dibaca Kullin; berdasarkan qiraat ini lafal Zaujaini menjadi Maf'ul dan lafal Itsnaini berkedudukan mengukuhkan maknanya (dan juga keluargamu) istri dan anak-anakmu (kecuali orang yang telah lebih dahulu ketetapan azab atasnya di antara mereka) yaitu istri dan anaknya yang bernama Kan`an, lain halnya dengan anak-anaknya yang lain, yaitu Sam, Ham dan Yafits, Nabi Nuh mengangkut mereka bersama dengan istri-istri mereka ke dalam bahtera. Di dalam surah Hud telah disebutkan melalui firman-Nya, 'Dan muatkan pula orang-orang yang beriman. Dan tidak beriman bersama dengan Nuh itu kecuali sedikit.' (Q.S. Hud, 40). Menurut suatu pendapat dikatakan, bahwa jumlah mereka ada enam orang laki-laki berikut istri mereka. Menurut pendapat yang lain dikatakan, bahwa semua orang yang ada di dalam bahtera jumlahnya tujuh puluh delapan orang; separuh laki-laki dan yang separuh lagi perempuan. (Dan janganlah kamu bicarakan dengan Aku tentang orang-orang yang zalim) yaitu orang-orang yang kafir, biarkanlah mereka binasa (karena sesungguhnya mereka akan ditenggelamkan).\qt@no{27}}%
\qt@newcmd\qurantrans@id@mmdcci{%
(Apabila kamu telah lengkap) telah genap (yakni kamu dan orang-orang yang bersamamu berada di atas bahtera itu, maka ucapkanlah, 'Segala puji bagi Allah yang telah menyelamatkan kami dari orang-orang yang zalim') yakni orang-orang yang kafir dengan dibinasakannya mereka.\qt@no{28}}%
\qt@newcmd\qurantrans@id@mmdccii{%
(Dan berdoalah) di kala kamu turun dari bahtera, ('Ya Rabbku! Tempatkanlah aku pada tempat) kalau dibaca Munzalan berarti menjadi Mashdar dan Isim Makan/tempat sekaligus, apabila dibaca Manzilan berarti tempat berlabuh (yang diberkati) yakni tempat tersebut diberkati (dan Engkau adalah sebaik-baik yang memberi tempat'") maksudnya Engkau adalah pemberi tempat yang paling baik kepada semua yang telah disebutkan tadi.\qt@no{29}}%
\qt@newcmd\qurantrans@id@mmdcciii{%
(Sesungguhnya pada kejadian itu) kisah Nabi Nuh dan bahteranya serta dibinasakan-Nya orang-orang kafir (benar-benar terdapat beberapa tanda) yang menunjukkan kepada kekuasaan Allah swt. (dan sesungguhnya) huruf In di sini adalah bentuk Takhfif daripada Inna, sedangkan isimnya adalah Dhamir Sya'an, bentuk asalnya adalah Innahu yakni sesungguhnya hal itu (Kamilah yang mencoba mereka) menguji kaum Nuh dengan mengutus Nuh kepada mereka supaya Nuh memberi nasihat dan pelajaran kepada mereka.\qt@no{30}}%
\qt@newcmd\qurantrans@id@mmdcciv{%
(Kemudian, Kami jadikan sesudah mereka umat) kaum (yang lain) mereka adalah kaum Ad.\qt@no{31}}%
\qt@newcmd\qurantrans@id@mmdccv{%
(Lalu Kami utus kepada mereka, seorang rasul dari kalangan mereka sendiri) yaitu Nabi Hud ("Hendaklah) ia mengatakan kepada mereka (kalian menyembah Allah, sekali-kali tidak ada Tuhan selain daripada-Nya. Mengapa kalian tidak bertakwa) takut kepada azab-Nya karenanya kalian harus beriman kepada-Nya.\qt@no{32}}%
\qt@newcmd\qurantrans@id@mmdccvi{%
(Dan berkatalah pemuka-pemuka yang kafir di antara kaumnya dan yang mendustakan akan menemui hari akhirat) yakni tempat mereka kembali kelak (dan yang telah Kami mewahkan mereka) Kami berikan nikmat kepada mereka (dalam kehidupan di dunia, 'Orang ini tidak lain hanyalah manusia seperti kalian, dia makan dari apa yang kalian makan dan minum dari apa yang kalian minum').\qt@no{33}}%
\qt@newcmd\qurantrans@id@mmdccvii{%
(Dan) demi Allah (sesungguhnya jika kamu sekalian menaati manusia yang seperti kalian) di dalam ayat ini terkandung makna Qasam atau sumpah dan Syarat, sedangkan Jawab dari Syarat tersebut terkandung pada ayat selanjutnya (niscaya bila demikian, kalian benar-benar) yakni jika kalian menaatinya (menjadi orang-orang yang merugi") mendapat kerugian.\qt@no{34}}%
\qt@newcmd\qurantrans@id@mmdccviii{%
("Apakah ia menjanjikan kepada kalian, bahwa bila kalian telah mati dan telah menjadi tanah dan tulang-belulang, kalian sesungguhnya akan dikeluarkan dari kuburan kalian) lafal Mukhrajuuna merupakan Khabar dari Annakum yang pertama, sedangkan lafal Annakum yang kedua berfungsi mengukuhkan makna Annakum yang pertama tadi, disebutkan lagi karena panjangnya Fashl atau pemisah antara Khabar dan 'Amilnya.\qt@no{35}}%
\qt@newcmd\qurantrans@id@mmdccix{%
(Jauh, jauh sekali) lafal Haihaata Haihaata adalah Isim Fi'il Madhi yang bermakna Mashdar, artinya jauh, jauh sekali dari kebenaran (apa yang diancamkan kepada kalian itu) yaitu dihidupkannya kembali kalian dari kuburan. Huruf Lam pada lafal Limaa Tuu'aduna adalah Lam Zaidah yang mengandung makna Bayan atau penjelasan.\qt@no{36}}%
\qt@newcmd\qurantrans@id@mmdccx{%
(Tiada lain hal itu) yakni kehidupan yang sesungguhnya (hanyalah kehidupan kita di dunia ini, kita mati kemudian kita hidup) yaitu dengan hidupnya anak-anak kita (dan sekali-kali kita tidak akan dibangkitkan kembali).\qt@no{37}}%
\qt@newcmd\qurantrans@id@mmdccxi{%
(Ia tiada lain) Rasul itu (hanyalah seorang laki-laki yang mengada-adakan kebohongan terhadap Allah, dan kami sekali-kali tidak akan beriman kepadanya") tidak akan percaya dengan adanya berbangkit sesudah mati.\qt@no{38}}%
\qt@newcmd\qurantrans@id@mmdccxii{%
(Rasul itu berdoa, ``Ya Rabbku! Tolonglah aku karena mereka mendustakanku").\qt@no{39}}%
\qt@newcmd\qurantrans@id@mmdccxiii{%
(Allah berfirman, ``Dalam sedikit waktu lagi) sebentar lagi. Huruf Ma di sini adalah Zaidah (pasti mereka akan menjadi) akan menjadi orang-orang (yang menyesal") atas kekafiran dan kedustaan mereka.\qt@no{40}}%
\qt@newcmd\qurantrans@id@mmdccxiv{%
(Maka dimusnahkanlah mereka oleh suara yang mengguntur) suara yang menandakan turunnya azab dan binasanya makhluk (dengan hak) maka matilah mereka (dan Kami jadikan mereka bagaikan tumbuh-tumbuhan yang kering) Kami jadikan mereka seperti tanaman yang kering atau mati (maka alangkah jauhnya) dari rahmat (bagi orang-orang yang zalim itu) yakni orang-orang yang mendustakan Rasul itu.\qt@no{41}}%
\qt@newcmd\qurantrans@id@mmdccxv{%
(Kemudian Kami ciptakan sesudah mereka umat-umat) kaum-kaum (yang lain).\qt@no{42}}%
\qt@newcmd\qurantrans@id@mmdccxvi{%
(Tidak dapat sesuatu umat pun mendahului ajalnya) seumpamanya mereka mati sebelum ajal mereka (dan tidak dapat pula mereka terlambat) dari ajalnya itu. Lafal Yasta'khiruna dalam bentuk jamak dikaitkan kepada lafal Ummatin yang bentuknya muannats, hal ini memandang dari segi maknanya, karena ummatin berarti jamak.\qt@no{43}}%
\qt@newcmd\qurantrans@id@mmdccxvii{%
(Kemudian Kami utus rasul-rasul Kami berturut-turut) lafal Tatran dapat pula dibaca Tatraa tanpa memakai harakat Tanwin, artinya berturut-turut yang di antara kedua rasul terdapat pemisah jarak waktu yang cukup lama. (Manakala datang kepada suatu umat) lafal Jaa-a Ummatan dapat dibaca Jaa-a ummatan yakni dengan mentashhilkan huruf Hamzah yang kedua, sehingga ucapannya seolah-olah ada huruf Wau (Rasul, umat itu mendustakannya, maka Kami perikutkan sebagian mereka dengan sebagian yang lain) Kami samakan mereka dengan umat-umat terdahulu dalam hal terbinasa (dan Kami jadikan mereka buah tutur manusia maka kebinasaanlah bagi orang-orang yang tidak beriman).\qt@no{44}}%
\qt@newcmd\qurantrans@id@mmdccxviii{%
(Kemudian Kami utus Musa dan saudaranya Harun dengan membawa tanda-tanda kebesaran Kami, dan bukti yang nyata) hujah yang nyata, yaitu berupa tangan, tongkat dan mukjizat-mukjizat lainnya.\qt@no{45}}%
\qt@newcmd\qurantrans@id@mmdccxix{%
(Kepada Firaun dan pembesar-pembesar kaumnya, maka mereka ini takabur) sombong tidak mau beriman kepada ayat-ayat dan mukjizat-mukjizat, dan juga mereka tidak mau beriman kepada Allah (dan mereka adalah orang-orang yang sombong) yaitu menindas kaum Bani Israel secara lalim.\qt@no{46}}%
\qt@newcmd\qurantrans@id@mmdccxx{%
(Dan mereka berkata, ``Apakah pantas kita percaya kepada dua orang manusia seperti kita juga, padahal kaum mereka adalah orang-orang yang menghambakan diri kepada kita?") yakni kaum Bani Israel; mereka tunduk dan dianggap hina oleh Firaun.\qt@no{47}}%
\qt@newcmd\qurantrans@id@mmdccxxi{%
(Maka tetaplah mereka mendustakan keduanya, sebab itu mereka adalah termasuk orang-orang yang dibinasakan).\qt@no{48}}%
\qt@newcmd\qurantrans@id@mmdccxxii{%
(Dan sesungguhnya telah Kami berikan Kitab kepada Musa) kitab Taurat (agar mereka) kaumnya, yaitu bangsa Bani Israel (mendapat petunjuk) dengan adanya kitab Taurat itu dari kesesatan. Aku memberikannya sekali turun sesudah Firaun dan kaumnya binasa\qt@no{49}}%
\qt@newcmd\qurantrans@id@mmdccxxiii{%
(Dan telah Kami jadikan putra Maryam) yakni Nabi Isa (beserta ibunya suatu tanda) kekuasaan Kami. Dalam ayat ini tidak disebutkan dua tanda karena keduanya terlibat dalam satu tanda itu, yaitu Maryam dapat melahirkan Nabi Isa tanpa suami (dan Kami menempatkan keduanya di suatu tanah tinggi) yakni tempat di dataran tinggi, yaitu di Baitulmakdis, atau di Damaskus, atau di Palestina; sehubungan dengan hal ini banyak pendapat mengenainya (yang datar) rata tanahnya sehingga para penghuninya menetap dengan nyaman (dan mempunyai banyak sumber air) yang mengalir lagi jernih sebagai suatu kenyataan.\qt@no{50}}%
\qt@newcmd\qurantrans@id@mmdccxxiv{%
(Hai Rasul-rasul! Makanlah dari makanan yang baik-baik) makanan-makanan yang halal (dan kerjakanlah amal yang saleh) amal-amal yang fardu dan sunah. (Sesungguhnya Aku Maha Mengetahui apa yang kalian kerjakan) maka kelak Aku akan memperhitungkannya atas kalian.\qt@no{51}}%
\qt@newcmd\qurantrans@id@mmdccxxv{%
(Dan) ketahuilah (bahwasanya ini) yakni agama Islam (adalah agama kalian) hai orang-orang yang diajak bicara, maksudnya kalian harus memeluknya (agama yang satu) lafal Ummatan Waahidatan ini menjadi Hal yang bersifat Lazimah atau tetap. Menurut suatu qiraat yang lain lafal Anna haadzihi dibaca Takhfif sehingga menjadi An Haadzihi, sedangkan menurut qiraat yang lainnya lagi dibaca Inna Haadzihi, dan dianggap sebagai jumlah Isti'naf atau kalimat baru, sehingga artinya menjadi, sesungguhnya agama Islam ini (dan Aku adalah Rabb kalian, maka bertakwalah kalian kepada-Ku) artinya takutlah kalian kepada-Ku.\qt@no{52}}%
\qt@newcmd\qurantrans@id@mmdccxxvi{%
(Kemudian mereka memecah belah) para pengikut Rasul itu (perkara mereka) yakni agama mereka (menjadi beberapa pecahan di antara mereka) lafal Zuburan ini menjadi Hal dari Fa'ilnya lafal Taqaththa'uu, artinya, menjadi sekte-sekte yang bertentangan, seperti yang terjadi di kalangan orang-orang Yahudi dan orang-orang Nasrani serta lain-lainnya. (Tiap-tiap golongan terhadap apa yang ada pada sisi mereka) agama yang mereka pegang (merasa bangga) merasa puas dan gembira.\qt@no{53}}%
\qt@newcmd\qurantrans@id@mmdccxxvii{%
(Maka biarkanlah mereka) biarkanlah orang-orang kafir Mekah itu (dalam kesesatannya) (sampai suatu waktu) hingga saat kematian mereka.\qt@no{54}}%
\qt@newcmd\qurantrans@id@mmdccxxviii{%
(Apakah mereka mengira bahwa sesungguhnya apa-apa yang Kami berikan kepada mereka) artinya, Kami limpahkan kepada mereka (berupa harta benda dan anak-anak) di dunia ini.\qt@no{55}}%
\qt@newcmd\qurantrans@id@mmdccxxix{%
(Kami bersegera) menyegerakan (memberikan kebaikan-kebaikan kepada mereka) tidak, sesungguhnya tidak demikian (sebenarnya mereka tidak sadar) bahwasanya hal itu adalah pengluluh atau Istidraj buat mereka.\qt@no{56}}%
\qt@newcmd\qurantrans@id@mmdccxxx{%
(Sesungguhnya orang-orang yang karena perasaan khasyyah mereka kepada Rabb mereka) disebabkan mereka takut kepada-Nya (mereka merasa takut sekali) kepada azab-Nya.\qt@no{57}}%
\qt@newcmd\qurantrans@id@mmdccxxxi{%
(Dan orang-orang yang terhadap ayat-ayat Rabb mereka) Alquran (mereka beriman) sangat percaya kepadanya.\qt@no{58}}%
\qt@newcmd\qurantrans@id@mmdccxxxii{%
(Dan orang-orang yang tidak mempersekutukan dengan Rabb mereka) sesuatu apa pun.\qt@no{59}}%
\qt@newcmd\qurantrans@id@mmdccxxxiii{%
(Dan orang-orang yang memberikan) yang menginfakkan (apa yang telah mereka berikan) mereka infakkan berupa zakat dan amal-amal saleh (dengan hati yang takut) takut amalnya tidak diterima (karena mereka tahu bahwa sesungguhnya mereka) sebelum lafal Annahum ini diperkirakan adanya huruf Lam yang menjarkannya (akan dikembalikan kepada Rabb mereka).\qt@no{60}}%
\qt@newcmd\qurantrans@id@mmdccxxxiv{%
(Mereka itu bersegera untuk mendapatkan kebaikan-kebaikan, dan merekalah orang-orang yang segera memperolehnya) menurut ilmu Allah.\qt@no{61}}%
\qt@newcmd\qurantrans@id@mmdccxxxv{%
(Kami tiada membebani seseorang melainkan menurut kesanggupannya) yang sesuai dengan kemampuannya, oleh karenanya barang siapa tidak mampu melakukan salat sambil berdiri, maka ia boleh melakukannya sambil duduk, dan barang siapa tidak mampu melakukan puasa maka ia boleh berbuka (dan pada sisi Kami) di sisi Kami (ada suatu kitab yang membicarakan dengan benar) apa yang telah dilakukan oleh seseorang, yaitu Lohmahfuz; padanya ditulis semua amal-amal perbuatan (dan mereka) kita semua orang yang beramal (tidak dianiaya) barang sedikit pun dari amal-amalnya, oleh karenanya sedikit pun tidak dikurangi pahala amal kebaikannya, dan tidak pula ditambah dosa-dosanya.\qt@no{62}}%
\qt@newcmd\qurantrans@id@mmdccxxxvi{%
(Tetapi hati mereka) yakni orang-orang kafir itu (dalam kealpaan) artinya, kebodohan (mengenai hal ini) yaitu Alquran (dan mereka banyak mengerjakan perbuatan-perbuatan selain daripada itu) selain amal-amal kebaikan yang dilakukan oleh orang-orang yang beriman (mereka tetap mengerjakannya) oleh sebab itu mereka diazab.\qt@no{63}}%
\qt@newcmd\qurantrans@id@mmdccxxxvii{%
(Hingga) menunjukkan makna Ibtida (apabila Kami timpakan kepada orang-orang yang hidup mewah di antara mereka) yakni orang-orang kaya dan pemimpin-pemimpin mereka (azab) dengan pedang dalam perang Badar (dengan serta merta mereka memekik minta tolong) mereka ribut meminta tolong. Kemudian dikatakan kepada mereka,\qt@no{64}}%
\qt@newcmd\qurantrans@id@mmdccxxxviii{%
("Janganlah kalian memekik, minta tolong pada hari ini. Sesungguhnya kalian tidak akan mendapat pertolongan dari Kami) maksudnya tidak ada seorang pun yang dapat menolong kalian.\qt@no{65}}%
\qt@newcmd\qurantrans@id@mmdccxxxix{%
(Sesungguhnya ayat-ayat-Ku) dari Alquran (selalu dibacakan kepada kalian, tetapi kalian selalu berpaling ke belakang) mundur ke belakang maksudnya kalian tidak mau menerimanya.\qt@no{66}}%
\qt@newcmd\qurantrans@id@mmdccxl{%
(Dengan menyombongkan diri) tidak mau beriman (akan keakuan kalian) yakni membanggakan Kakbah atau tanah suci yang kalian tempati, maksudnya kalian beranggapan bahwa diri kalian adalah penduduknya, oleh karena itu kalian merasa dalam keadaan aman dari azab Allah, berbeda dengan kaum-kaum yang lain di tempat tinggal mereka selain dari tanah suci (dan seraya bergadang) lafal Samiran menjadi Hal, artinya mereka berkumpul membentuk suatu kelompok sambil berbincang-bincang di waktu malam hari; hal ini mereka lakukan di sekeliling Kakbah (kalian mengucapkan perkataan-perkataan yang keji terhadapnya") lafal Tahjuruuna ini jika berasal dari Fi'il Tsulatsi artinya tidak menganggap Alquran. Jika berasal dari Fi'il Ruba'i berarti mereka membuat-buat perkataan yang keji tanpa hak terhadap diri Nabi saw. dan Alquran. Selanjutnya Allah swt. berfirman,\qt@no{67}}%
\qt@newcmd\qurantrans@id@mmdccxli{%
(Maka apakah mereka tidak memperhatikan) asal lafal Yaddabbaruu adalah Yatadabbaruuna, kemudian huruf Ta dimasukkan ke dalam huruf Dal setelah terlebih dahulu diganti menjadi Dal, sehingga jadilah Yaddabbaruuna (perkataan ini) Alquran ini yang menunjukkan kebenaran Nabi saw. (atau apakah telah datang kepada mereka apa yang tidak pernah datang kepada nenek moyang mereka dahulu?)\qt@no{68}}%
\qt@newcmd\qurantrans@id@mmdccxlii{%
(Ataukah mereka tidak mengenal Rasul mereka, karena itu mereka memungkirinya?)\qt@no{69}}%
\qt@newcmd\qurantrans@id@mmdccxliii{%
(Atau apakah patut mereka berkata, ``Padanya ada penyakit gila") Istifham atau kata tanya di sini mengandung arti Taqrir atau menetapkan perkara yang hak, yaitu membenarkan Nabi dan membenarkan bahwa Rasul-rasul telah datang kepada umat-umat terdahulu, serta mereka mengetahui bahwa Rasul mereka adalah orang yang jujur dan dapat dipercaya, dan bahwasanya Rasul mereka itu tidak gila. (Sebenarnya) lafal Bal menunjukkan makna Intiqal (dia telah membawa kebenaran kepada mereka) yakni Alquran yang di dalamnya terkandung ajaran Tauhid dan hukum-hukum Islam (dan kebanyakan mereka benci kepada kebenaran itu).\qt@no{70}}%
\qt@newcmd\qurantrans@id@mmdccxliv{%
(Andaikata kebenaran itu menuruti) artinya Alquran itu menuruti (hawa nafsu mereka) seumpamanya Alquran itu datang dengan membawa hal-hal yang mereka sukai, seperti menisbatkan sekutu dan anak kepada Allah, padahal Allah Maha Suci dari hal tersebut (pasti binasalah langit dan bumi dan semua yang ada di dalamnya) yakni menyimpang dari tatanan yang sebenarnya dan tidak seperti apa yang disaksikan sekarang, hal itu disebabkan adanya dua pengaruh kekuasaan yang saling tarik-menarik. (Sebenarnya Kami telah mendatangkan kepada mereka kebanggaan mereka) yaitu Alquran yang di dalamnya terkandung sebutan dan kemuliaan mereka (tetapi mereka berpaling dari kebanggaan itu).\qt@no{71}}%
\qt@newcmd\qurantrans@id@mmdccxlv{%
(Atau kamu meminta upah kepada mereka) sebagai imbalan dari apa yang kamu datangkan buat mereka yaitu masalah keimanan (maka upah Rabbmu) adalah pahala, upah dan rezeki-Nya (adalah lebih baik) dan menurut qiraat yang lain dibaca Kharjan dalam dua tempat tadi; tetapi menurut qiraat yang lainnya lagi dibaca Kharaajan pada keduanya (dan Dia adalah Pemberi rezeki Yang Paling Baik) Pengupah Yang Paling Utama.\qt@no{72}}%
\qt@newcmd\qurantrans@id@mmdccxlvi{%
(Dan sesungguhnya kamu benar-benar menyeru mereka kepada jalan) tuntunan (yang lurus) yaitu agama Islam.\qt@no{73}}%
\qt@newcmd\qurantrans@id@mmdccxlvii{%
(Dan sesungguhnya orang-orang yang tidak beriman kepada adanya hari akhirat) adanya hari berbangkit dan pembalasan pahala serta azab (dari jalan yang lurus) dari tuntunan yang lurus (mereka benar-benar menyimpang) yakni membelok.\qt@no{74}}%
\qt@newcmd\qurantrans@id@mmdccxlviii{%
(Andaikata mereka Kami belas kasihani, dan Kami lenyapkan kemudaratan yang mereka alami) yakni kelaparan yang menimpa mereka di Mekah selama tujuh tahun itu (benar-benar mereka akan terus-menerus) masih tetap dan berkepanjangan (dalam keterlaluan mereka) dalam kesesatan mereka (mereka bergelimang) terombang-ambing.\qt@no{75}}%
\qt@newcmd\qurantrans@id@mmdccxlix{%
(Dan sesungguhnya Kami telah pernah menimpakan azab kepada mereka) kelaparan itu (tetapi mereka masih tidak tunduk) masih tidak mau merendahkan diri (kepada Rabb mereka, dan juga mereka tidak mau ber-tadharru' kepada-Nya) maksudnya mereka tidak mau juga meminta kepada Allah dengan berdoa kepada-Nya.\qt@no{76}}%
\qt@newcmd\qurantrans@id@mmdccl{%
(Hingga) lafal Hattaa menunjukkan makna Ibtida atau permulaan (apabila Kami bukakan untuk mereka suatu pintu yang di dalamnya ada) terdapat (azab yang keras) yaitu perang Badar tempat mereka terbunuh (tiba-tiba mereka menjadi berputus asa) putus harapan dari semua kebaikan.\qt@no{77}}%
\qt@newcmd\qurantrans@id@mmdccli{%
(Dan Dialah Yang menciptakan) yang menjadikan (bagi kamu sekalian pendengaran) lafal As Sam'u maknanya Al Asmaa', dalam bentuk jamak (penglihatan dan kalbu) hati. (Amat sedikitlah) lafal Maa mengukuhkan makna yang terkandung dalam lafal Qaliilan (kalian bersyukur).\qt@no{78}}%
\qt@newcmd\qurantrans@id@mmdcclii{%
(Dan Dialah yang mengembangbiakkan kalian) menciptakan kalian (di bumi ini, dan hanya kepada-Nyalah kalian akan dihimpunkan) akan dibangkitkan menjadi hidup kembali kemudian menghadap kepada-Nya.\qt@no{79}}%
\qt@newcmd\qurantrans@id@mmdccliii{%
(Dan Dialah yang menghidupkan) dengan meniupkan roh ke dalam Mudhghah atau janin (dan mematikan, dan Dialah yang mengatur pertukaran malam dan siang) malam gelap, dan siang menjadi terang, serta menambah panjang dan mengurangi waktu salah satu di antara keduanya. (Maka apakah kalian tidak memahaminya?) maksudnya memahami ciptaan Allah swt., kemudian kalian mengambil pelajaran daripadanya.\qt@no{80}}%
\qt@newcmd\qurantrans@id@mmdccliv{%
(Sebenarnya mereka mengucapkan perkataan yang serupa dengan perkataan yang diucapkan oleh orang-orang dahulu kala).\qt@no{81}}%
\qt@newcmd\qurantrans@id@mmdcclv{%
(Mereka berkata) orang-orang dahulu itu, ("Apakah betul, apabila kami telah mati dan kami telah menjadi tanah dan tulang-belulang, apakah sesungguhnya kami benar-benar akan dibangkitkan hidup kembali?) memang kalian akan dibangkitkan kembali oleh-Nya. Kedua huruf Hamzah pada dua tempat ini dapat dibaca Tahqiq, sehingga bacaannya menjadi A-innaa. Sebagaimana huruf Hamzah yang keduanya dapat pula dibaca Tas-hil, sehingga bacaannya menjadi Ayinnaa. Sehubungan dengan bacaan ini ada dua pendapat, yaitu men-tahqiq-kan kedua Hamzahnya dan men-tashil-kan Hamzah yang kedua.\qt@no{82}}%
\qt@newcmd\qurantrans@id@mmdcclvi{%
(Sesungguhnya kami dan bapak-bapak kami telah diberi ancaman dengan ini) yaitu dengan masalah akan dibangkitkan menjadi hidup kembali sesudah mati (dahulu, tiada lain) tidak lain (ia hanyalah dongengan-dongengan) kebohongan-kebohongan (orang-orang dahulu kala") wazan lafal Asaathiir sama dengan lafal Al Adhaahiik dan Al-A`aajiib, adalah bentuk jamak dari lafal Usthuurah artinya dongengan atau fiksi.\qt@no{83}}%
\qt@newcmd\qurantrans@id@mmdcclvii{%
(Katakanlah) kepada mereka, ("Kepunyaan siapakah bumi ini, dan semua yang ada padanya) yakni semua makhluk yang ada padanya (jika kalian mengetahui?") siapa pencipta dan pemiliknya.\qt@no{84}}%
\qt@newcmd\qurantrans@id@mmdcclviii{%
(Mereka akan menjawab, ``Kepunyaan Allah." Katakanlah) kepada mereka, ("Maka apakah kalian tidak memikirkannya?") asal Tadzakkaruuna adalah Tatadzakkaruuna kemudian huruf Ta yang kedua diidgamkan atau dimasukkan ke dalam huruf Dzal setelah terlebih dahulu diganti menjadi Dzal, sehingga jadilah Tadzakkaruuna, artinya mengambil pelajaran. Maksudnya, apakah kalian tidak mengambil pelajaran daripadanya, karena kalian mengetahui, bahwa Tuhan Yang Maha Kuasa yang telah menciptakan untuk pertama kali, Maha Kuasa pula untuk menghidupkannya kembali, sesudah ciptaan-Nya mati.\qt@no{85}}%
\qt@newcmd\qurantrans@id@mmdcclix{%
(Katakanlah! ``Siapakah Rabb langit yang tujuh dan Rabb Arasy yang besar") yakni Al Kursi.\qt@no{86}}%
\qt@newcmd\qurantrans@id@mmdcclx{%
(Mereka akan menjawab, ``Kepunyaan Allah". Katakanlah! ``Apakah kalian tidak bertakwa?") tidak takut bila kalian menyembah selain-Nya.\qt@no{87}}%
\qt@newcmd\qurantrans@id@mmdcclxi{%
(Katakanlah! ``Siapakah yang di tangan-Nya berada kekuasaan) yakni merajai (segala sesuatu) lafal Malakuut huruf Ta yang ada padanya menunjukkan makna Mubalaghah, yakni kekuasaan di atas segala kekuasaan (sedangkan Dia melindungi dan tidak membutuhkan perlindungan) Dia melindungi dan tidak memerlukan perlindungan (jika kalian mengetahui?")\qt@no{88}}%
\qt@newcmd\qurantrans@id@mmdcclxii{%
(Mereka akan menjawab, ``Kepunyaan Allah") menurut qiraat yang lain dibaca Allah, baik dalam ayat ini maupun dalam ayat sebelumnya. Demikian itu karena makna yang dimaksud adalah, kepunyaan siapakah hal-hal yang telah disebutkan itu (Katakanlah! ``Kalau demikian maka dari jalan manakah kalian merasa ditipu?") ditipu dan dikelabui dari perkara yang hak, yaitu menyembah Allah semata. Maksudnya, bagaimanakah bisa terbayangkan dalam benak kalian bahwasanya hal ini batil?\qt@no{89}}%
\qt@newcmd\qurantrans@id@mmdcclxiii{%
(Sebenarnya Kami telah membawa kebenaran kepada mereka) dengan sesungguhnya (dan sesungguhnya mereka benar-benar orang-orang yang berdusta) sewaktu mereka menentang kebenaran itu; kebenaran tersebut adalah,\qt@no{90}}%
\qt@newcmd\qurantrans@id@mmdcclxiv{%
(Allah sekali-kali tidak mempunyai anak, dan sekali-kali tidak ada tuhan yang lain beserta-Nya, kalau ada tuhan beserta-Nya) jika ada tuhan lain di samping Dia (masing-masing tuhan itu akan membawa makhluk yang diciptakannya) yang menguasai makhluknya sendiri dan mempertahankannya dari makhluk tuhan yang lain (dan sebagian dari tuhan-tuhan itu akan mengalahkan sebagian yang lain) sebagian di antara mereka berupaya untuk mengalahkan sebagian yang lain sebagaimana apa yang biasa dilakukan oleh raja-raja di dunia. (Maha Suci Allah) lafal Subhaanallaah ini berarti mensucikan Dia (dari apa yang mereka sifatkan) kepada-Nya, seperti apa yang telah disebutkan tadi.\qt@no{91}}%
\qt@newcmd\qurantrans@id@mmdcclxv{%
(Yang mengetahui semua yang gaib dan semua yang tampak) maksudnya semua yang tidak tampak dan semua yang tampak. Kalau dibaca 'Aalimil Ghaibi menjadi sifat, artinya yang mengetahui dan seterusnya. Jika dibaca 'Aalimul Ghaibi berarti menjadi Khabar dari Mubtada yang tidak disebutkan yaitu lafal Huwa, artinya Dia Mengetahui yang gaib (maka Maha Tinggi Dia) Maha Besar Dia (dari apa yang mereka persekutukan) kepada-Nya.\qt@no{92}}%
\qt@newcmd\qurantrans@id@mmdcclxvi{%
(Katakanlah! ``Ya Rabbku! Jika) lafal Imma pada asalnya terdiri daripada gabungan antara In Syarthiyyah dan Ma Zaidah (Engkau sungguh-sungguh hendak memperlihatkan kepadaku apa yang diancamkan kepada mereka) berupa azab, hal ini benar-benar terjadi dalam perang Badar, yaitu banyak dari kalangan orang-orang musyrik yang mati terbunuh.\qt@no{93}}%
\qt@newcmd\qurantrans@id@mmdcclxvii{%
(Ya Rabbku! Maka janganlah Engkau jadikan aku berada di antara orang-orang yang zalim.") karena aku pun nanti akan binasa pula bersama dengan mereka.\qt@no{94}}%
\qt@newcmd\qurantrans@id@mmdcclxviii{%
(Dan sesungguhnya Kami benar-benar kuasa untuk memperlihatkan kepadamu apa yang Kami ancamkan kepada mereka).\qt@no{95}}%
\qt@newcmd\qurantrans@id@mmdcclxix{%
(Tolaklah dengan menampilkan hal yang lebih baik) yaitu budi pekerti yang baik, bersikap lapang dada dan berpaling dari mereka yang kafir (hal yang buruk itu) perlakuan mereka yang menyakitkan terhadap dirimu. Ayat ini diturunkan sebelum ada perintah untuk berperang. (Kami lebih mengetahui apa yang mereka sifatkan) kedustaan dan buat-buatan mereka, maka kelak Kami akan membalasnya kepada mereka.\qt@no{96}}%
\qt@newcmd\qurantrans@id@mmdcclxx{%
(Dan katakanlah! ``Ya Rabbku! Aku berlindung kepada Engkau) aku meminta perlindungan (dari bisikan-bisikan setan) dari kecenderungan-kecenderungan setan yang selalu setan embus-embuskan itu.\qt@no{97}}%
\qt@newcmd\qurantrans@id@mmdcclxxi{%
(Dan aku berlindung pula kepada Engkau, ya Rabbku, dari kedatangan setan-setan itu kepadaku") dalam perkara-perkaraku, karena sesungguhnya mereka datang hanya dengan membawa keburukan belaka.\qt@no{98}}%
\qt@newcmd\qurantrans@id@mmdcclxxii{%
(Sehingga) lafal Hattaa menunjukkan makna Ibtida atau permulaan (apabila datang kematian kepada seseorang dari mereka) kemudian ia melihat kedudukannya di neraka dan di surga seandainya ia beriman (dia berkata, ``Ya Rabbku! Kembalikanlah aku) ke dunia. Ungkapan Jamak pada lafal Irji'uuni mengandung makna Ta'zhim atau mengagungkan.\qt@no{99}}%
\qt@newcmd\qurantrans@id@mmdcclxxiii{%
(Agar aku berbuat amal yang saleh) dengan mengatakan, 'Aku bersaksi tiada Tuhan selain Allah', hal ini akan menjadi penghapus (terhadap yang telah aku tinggalkan") aku sia-siakan umurku. Maksudnya, supaya hal itu menjadi penggantinya. Maka Allah berfirman, ("Sekali-kali tidak) tidak ada kembali lagi. (Sesungguhnya itu) permohonan untuk kembali ke dunia (adalah perkataan yang diucapkannya saja) tidak ada manfaat bagi pembicaranya. (Dan di hadapan mereka) (ada dinding) penghalang yang menahan mereka untuk dapat kembali lagi ke dunia (sampai hari mereka dibangkitkan") yang tiada kembali lagi sesudahnya.\qt@no{100}}%
\qt@newcmd\qurantrans@id@mmdcclxxiv{%
(Apabila sangkakala ditiup) tiupan malaikat Israfil yang pertama atau yang kedua (maka tidaklah ada lagi pertalian nasab di antara mereka pada hari itu) yang dapat mereka bangga-banggakan (dan tidak pula mereka saling bertanya) tentang nasab tersebut, berbeda dengan ketika mereka hidup di dunia. Hal tersebut disebabkan kengerian yang menyibukkan diri mereka pada hari kiamat itu, yakni melihat sebagian kengerian-kengerian yang ada padanya. Pada sebagian waktu dari hari kiamat mereka sadar pula, sebagaimana yang diungkapkan oleh ayat yang lain, yaitu, ``Dan sebagian dari mereka menghadap kepada sebagian yang lain berbantah-bantahan." (Q.S. Ash-Shaffat, 27).\qt@no{101}}%
\qt@newcmd\qurantrans@id@mmdcclxxv{%
(Barang siapa yang berat timbangannya) karena amal-amal kebaikan (maka mereka itulah orang-orang yang mendapat keberuntungan) yakni orang-orang yang beruntung.\qt@no{102}}%
\qt@newcmd\qurantrans@id@mmdcclxxvi{%
(Dan barang siapa yang ringan timbangannya) karena dosa-dosanya (maka mereka itulah orang-orang yang merugikan dirinya sendiri) maka mereka (kekal di dalam neraka Jahanam).\qt@no{103}}%
\qt@newcmd\qurantrans@id@mmdcclxxvii{%
(Muka mereka dibakar api neraka) api neraka membakarnya (dan mereka di dalam neraka itu dalam keadaan cacat) bibir mereka bagian atas dan bawah mengkerut memperlihatkan gigi-gigi mereka, kemudian dikatakan kepada mereka,\qt@no{104}}%
\qt@newcmd\qurantrans@id@mmdcclxxviii{%
(Bukankah ayat-ayat-Ku) dari Alquran (telah dibacakan kepada kamu sekalian) maksudnya kalian telah diperingatkan melaluinya (tetapi kalian selalu mendustakannya?)\qt@no{105}}%
\qt@newcmd\qurantrans@id@mmdcclxxix{%
(Mereka berkata, ``Ya Rabb kami! Kami telah dikuasai oleh kejahatan kami) menurut qiraat yang lain dibaca Syaqawatunaa, keduanya merupakan Mashdar dan bermakna sama, yaitu kejahatan kami (dan adalah kami orang-orang yang sesat) dari jalan petunjuk.\qt@no{106}}%
\qt@newcmd\qurantrans@id@mmdcclxxx{%
(Ya Rabb kami! Keluarkanlah kami daripadanya maka jika kami kembali) kepada pelanggaran lagi (maka sesungguhnya kami adalah orang-orang yang zalim").\qt@no{107}}%
\qt@newcmd\qurantrans@id@mmdcclxxxi{%
(Allah berfirman) kepada mereka melalui lisan malaikat Malik penjaga neraka, sesudah jangka waktu yang lamanya dua kali lipat umur dunia, ("Tinggallah dengan hina di dalamnya) makin menjauhlah kalian di dalam neraka dengan hina (dan janganlah kalian berbicara dengan Aku") untuk meminta supaya azab dihentikan dari diri kalian; dijawab demikian supaya mereka tidak mempunyai harapan lagi untuk dapat diangkat dari dalam neraka.\qt@no{108}}%
\qt@newcmd\qurantrans@id@mmdcclxxxii{%
(Sesungguhnya ada segolongan dari hamba-hamba-Ku) mereka adalah kaum Muhajirin (berdoa, ``Ya Rabb kami! Kami telah beriman, maka ampunilah kami dan berilah kami rahmat dan Engkau adalah Pemberi rahmat Yang Paling Baik").\qt@no{109}}%
\qt@newcmd\qurantrans@id@mmdcclxxxiii{%
(Lalu kalian menjadikan mereka buah ejekan) lafal Sikhriyyan dapat pula dibaca Sukhriyyan keduanya merupakan bentuk Mashdar, maknanya adalah ejekan. Di antara mereka yang menjadi bahan ejekan orang-orang musyrik adalah sahabat Bilal, sahabat Shuhaib, sahabat Ammar, sahabat Salman (sehingga menjadikan kalian lupa mengingat Aku) kalian melupakannya disebabkan kalian sibuk dengan memperolok-olokkan mereka. Mengingat mereka sering lupa, maka sifat pelupa dinisbatkan kepada mereka (dan adalah kalian selalu menertawakan mereka).\qt@no{110}}%
\qt@newcmd\qurantrans@id@mmdcclxxxiv{%
(Sesungguhnya Aku memberi balasan kepada mereka di hari ini) kenikmatan yang abadi (karena kesabaran mereka) dalam menghadapi ejekan kalian dan perlakuan yang menyakitkan dari kalian terhadap mereka (sesungguhnya mereka) bila dibaca Innahum berarti jumlah Isti'naf, artinya, sesungguhnya mereka. Jika dibaca Annahum berarti menjadi Maf'ul kedua dari lafal Jazaituhum, artinya, bahwasanya mereka (itulah orang-orang yang menang) memperoleh apa yang mereka dambakan.\qt@no{111}}%
\qt@newcmd\qurantrans@id@mmdcclxxxv{%
(Berfirmanlah) Allah swt. kepada mereka melalui lisan malaikat Malik. Menurut qiraat yang lain dibaca Qul, yakni katakanlah kepada mereka, ("Berapa lamakah kalian tinggal di bumi) di dunia dan di dalam kuburan kalian (yakni berapa tahunkah bilangannya?") lafal 'Adada Siniina berkedudukan menjadi Tamyiz.\qt@no{112}}%
\qt@newcmd\qurantrans@id@mmdcclxxxvi{%
(Mereka menjawab, ``Kami tinggal hanya sehari atau setengah hari) mereka ragu, dan menganggap pendek masa tinggal mereka disebabkan kengerian mereka melihat besarnya azab di hari itu (maka tanyakanlah kepada malaikat-malaikat yang menghitung") amal perbuatan makhluk.\qt@no{113}}%
\qt@newcmd\qurantrans@id@mmdcclxxxvii{%
(Berfirmanlah) Allah swt. melalui lisan malaikat Malik. Menurut qiraat yang lain lafal Qaala dibaca Qul, artinya katakanlah. ("Tiada lain) (kalian tinggal hanya sebentar saja, kalau kalian sesungguhnya mengetahui") lama masa tinggal kalian itu, sedikit sekali jika dibandingkan keabadian kalian di dalam neraka.\qt@no{114}}%
\qt@newcmd\qurantrans@id@mmdcclxxxviii{%
(Maka apakah kalian mengira, bahwa sesungguhnya Kami menciptakan kalian secara bermain-main) yakni tidak ada hikmah dan manfaatnya (dan bahwa kalian tidak akan dikembalikan kepada Kami?) kalau dibaca Laa Turja'uuna artinya, kalian tidak dikembalikan. Dan kalau dibaca Tarji'uuna artinya, kalian akan kembali. Tentu saja tidak, sebenarnya supaya kalian menjadi hamba-hamba-Ku untuk Kami perintah dan Kami larang, kemudian kalian kembali kepada Kami untuk menerima pembalasan amal perbuatan kalian. Hal ini sebagaimana yang diungkapkan oleh firman-Nya yang lain, yaitu, ``Dan Aku tidak menciptakan jin dan manusia melainkan supaya mereka menyembah Aku." (Q.S. Adz-Dzariyat, 56).\qt@no{115}}%
\qt@newcmd\qurantrans@id@mmdcclxxxix{%
(Maka Maha Tinggi Allah) dari main-main dan hal-hal lainnya yang tidak layak bagi kebesaran-Nya (Raja Yang Sebenarnya; tidak ada Tuhan selain Dia, Rabb Yang mempunyai Arasy yang mulia) yakni Al-Kursi atau singgasana bagi raja.\qt@no{116}}%
\qt@newcmd\qurantrans@id@mmdccxc{%
(Dan barang siapa menyembah tuhan yang lain di samping Allah, padahal tak ada suatu dalil pun baginya tentang itu) lafal Laa Burhaana ini menjadi sifat yang Kasyifah atau yang terbuka, akan tetapi tidak dimengerti, karena pada kenyataannya hal itu mustahil (maka sesungguhnya perhitungannya) yakni pembalasan perbuatannya itu (di sisi Rabbnya. Sesungguhnya orang-orang yang kafir itu tidak beruntung) yakni tidak berbahagia.\qt@no{117}}%
\qt@newcmd\qurantrans@id@mmdccxci{%
(Dan katakanlah! ``Ya Rabbku! Berilah ampun dan berilah rahmat) kepada orang-orang Mukmin dalam bentuk rahmat di samping ampunan itu (dan Engkau adalah pemberi rahmat yang paling baik") artinya Pemberi rahmat yang paling utama.\qt@no{118}}%
\qt@newcmd\qurantrans@id@mmdccxcii{%
\basmalahid Ini adalah (suatu surah yang Kami turunkan dan Kami wajibkan) dapat dibaca secara Takhfif, yaitu Faradhnaahaa, dapat pula dibaca secara Musyaddad, yaitu Farradhnaahaa. Dikatakan demikian karena banyaknya fardu-fardu atau kewajiban-kewajiban yang terkandung di dalamnya (dan Kami turunkan di dalamnya ayat-ayat yang jelas) yakni jelas dan gamblang maksud-maksudnya (agar kalian selalu mengingatnya) asal kata Tadzakkaruuna ialah Tatadzakkaruuna, kemudian huruf Ta yang kedua diidgamkan kepada huruf Zal, sehingga menjadi Tadzakkaruuna, artinya mengambil pelajaran daripadanya.\qt@no{1}}%
\qt@newcmd\qurantrans@id@mmdccxciii{%
(Perempuan yang berzina dan laki-laki yang berzina) kedua-duanya bukan muhshan atau orang yang terpelihara dari berzina disebabkan telah kawin. Hadd bagi pelaku zina muhshan adalah rajam, menurut keterangan dari Sunah. Huruf Al yang memasuki kedua lafal ini adalah Al Maushulah sekaligus sebagai Mubtada, mengingat kedudukan Mubtada di sini mirip dengan Syarat, maka Khabarnya kemasukan huruf Fa, sebagaimana yang disebutkan dalam ayat berikutnya, yaitu, (maka deralah tiap-tiap seorang dari keduanya seratus kali dera) yakni sebanyak seratus kali pukulan. Jika dikatakan Jaladahu artinya ia memukul kulit seseorang; makna yang dimaksud adalah mendera. Kemudian ditambahkan hukuman pelaku zina yang bukan muhshan ini menurut keterangan dari Sunah, yaitu harus diasingkan atau dibuang selama satu tahun penuh. Bagi hamba sahaya hanya dikenakan hukuman separuh dari hukuman orang yang merdeka tadi (dan janganlah belas kasihan kalian kepada keduanya mencegah kalian untuk menjalankan agama Allah) yakni hukum-Nya, seumpamanya kalian melalaikan sesuatu dari hudud yang harus diterima keduanya (jika kalian beriman kepada Allah dan hari akhirat) yaitu hari berbangkit. Dalam ungkapan ayat ini terkandung anjuran untuk melakukan pengertian yang terkandung sebelum syarat. Ungkapan sebelum syarat tadi, yaitu kalimat ``Dan janganlah belas kasihan kalian kepada keduanya, mencegah kalian untuk menjalankan hukum Allah", merupakan Jawab dari Syarat, atau menunjukkan kepada pengertian Jawab Syarat (dan hendaklah hukuman mereka berdua disaksikan) dalam pelaksanaan hukuman deranya (oleh sekumpulan dari orang-orang yang beriman) menurut suatu pendapat para saksi itu cukup tiga orang saja; sedangkan menurut pendapat yang lain, bahwa saksi-saksi itu jumlahnya harus sama dengan para saksi perbuatan zina, yaitu sebanyak empat orang saksi laki-laki.\qt@no{2}}%
\qt@newcmd\qurantrans@id@mmdccxciv{%
(Laki-laki yang berzina tidak menikahi) (melainkan perempuan yang berzina atau perempuan yang musyrik; dan perempuan yang berzina tidak dikawini melainkan oleh laki-laki yang berzina atau laki-laki yang musyrik) pasangan yang cocok buat masing-masingnya sebagaimana yang telah disebutkan tadi (dan yang demikian itu diharamkan) menikahi perempuan-perempuan yang berzina (atas orang-orang Mukmin) yang terpilih. Ayat ini diturunkan tatkala orang-orang miskin dari kalangan sahabat Muhajirin berniat untuk mengawini para pelacur orang-orang musyrik, karena mereka orang kaya-kaya. Kaum Muhajirin yang miskin menyangka kekayaan yang dimilikinya itu akan dapat menanggung nafkah mereka. Karena itu dikatakan, bahwa pengharaman ini khusus bagi para sahabat Muhajirin yang miskin tadi. Tetapi menurut pendapat yang lain mengatakan pengharaman ini bersifat umum dan menyeluruh, kemudian ayat ini dinasakh oleh firman-Nya yang lain, yaitu, ``Dan nikahkanlah orang-orang yang sendirian di antara kalian..." (Q.S. An Nur, 32).\qt@no{3}}%
\qt@newcmd\qurantrans@id@mmdccxcv{%
(Dan orang-orang yang menuduh wanita-wanita yang baik-baik) menuduh berzina wanita-wanita yang memelihara dirinya dari perbuatan zina (dan mereka tidak mendatangkan empat orang saksi) yang menyaksikan perbuatan zina mereka dengan mata kepala sendiri (maka deralah mereka) bagi masing-masing dari mereka (delapan puluh kali dera, dan janganlah kalian terima kesaksian mereka) dalam suatu perkara pun (buat selama-lamanya. Dan mereka itulah orang-orang yang fasik) karena mereka telah melakukan dosa besar.\qt@no{4}}%
\qt@newcmd\qurantrans@id@mmdccxcvi{%
(Kecuali orang-orang yang bertobat sesudah itu dan memperbaiki) amal perbuatan mereka (maka sesungguhnya Allah Maha Pengampun) terhadap dosa tuduhan mereka itu (lagi Maha Penyayang) kepada mereka, yaitu dengan memberikan inspirasi untuk bertobat kepada mereka, yang dengan tobat itu terhapuslah julukan fasik dari diri mereka, kemudian kesaksian mereka dapat diterima kembali. Akan tetapi menurut suatu pendapat bahwa kesaksian mereka tetap tidak dapat diterima. Pendapat ini beranggapan bahwa pengertian Istitsna atau pengecualian di sini hanya kembali kepada kalimat terakhir dari ayat sebelumnya tadi, yaitu, ``Dan mereka itulah orang-orang yang fasik". Maksudnya hanya status fasik saja yang dihapus dari mereka, sedangkan ketiadagunaan kesaksiannya masih tetap.\qt@no{5}}%
\qt@newcmd\qurantrans@id@mmdccxcvii{%
(Dan orang-orang yang menuduh istrinya) berbuat zina (padahal mereka tidak mempunyai saksi-saksi) atas perbuatan itu (selain diri mereka sendiri) kasus ini telah terjadi pada segolongan para Sahabat (maka persaksian orang itu) lafal ayat ini menjadi Mubtada (ialah empat kali bersumpah) lafal ayat ini dapat dinashabkan karena dianggap sebagai Mashdar (dengan nama Allah, sesungguhnya dia adalah termasuk orang-orang yang benar) dalam tuduhan yang ia lancarkan kepada istrinya itu, yakni tuduhan berbuat zina.\qt@no{6}}%
\qt@newcmd\qurantrans@id@mmdccxcviii{%
(Dan sumpah yang kelima, bahwa laknat Allah atasnya, jika ia termasuk orang-orang yang berdusta) dalam hal ini yang menjadi Khabar dari Mubtada pada ayat yang sebelumnya tadi ialah, Untuk menolak hukuman hudud menuduh berzina yang akan ditimpakan atas dirinya.\qt@no{7}}%
\qt@newcmd\qurantrans@id@mmdccxcix{%
(Istrinya itu dapat dihindarkan) dapat mempertahankan dirinya (dari hukuman) hudud berzina yang telah dikuatkan dengan kesaksian sumpah suaminya yaitu (oleh sumpahnya empat kali atas nama Allah, sesungguhnya suaminya itu benar-benar termasuk orang-orang yang dusta) dalam tuduhan yang ia lancarkan terhadap dirinya, yaitu tuduhan melakukan zina.\qt@no{8}}%
\qt@newcmd\qurantrans@id@mmdccc{%
(Dan yang kelima, bahwa laknat Allah atasnya jika suaminya itu termasuk orang-orang yang benar) dalam tuduhannya itu.\qt@no{9}}%
\qt@newcmd\qurantrans@id@mmdccci{%
(Dan andaikata tidak ada karunia Allah dan rahmat-Nya atas diri kalian) dengan menutupi hal tersebut (dan andaikata Allah bukan Penerima tobat) maksudnya, Allah menerima tobatnya yang disebabkan tuduhannya itu dan dosa-dosa yang lainnya (lagi Maha Bijaksana) dalam keputusan-Nya mengenai masalah ini dan hal-hal yang lain, niscaya Dia akan menjelaskan mana yang benar dalam masalah ini, dan niscaya pula Dia akan menyegerakan hukuman-Nya kepada orang-orang yang berhak menerimanya.\qt@no{10}}%
\qt@newcmd\qurantrans@id@mmdcccii{%
(Sesungguhnya orang-orang yang membawa berita bohong) kedustaan yang paling buruk yang dilancarkan terhadap Siti Aisyah r.a. Umulmukminin, ia dituduh melakukan zina (adalah dari golongan kalian juga) yakni segolongan dari kaum Mukmin. Siti Aisyah mengatakan, bahwa mereka adalah Hissan bin Tsabit, Abdullah bin Ubay, Misthah dan Hamnah binti Jahsy. (Janganlah kalian kira bahwa berita bohong itu) hai orang-orang Mukmin selain dari mereka yang melancarkan tuduhan itu (buruk bagi kalian, tetapi hal itu mengandung kebaikan bagi kalian) dan Allah akan memberikan pahalanya kepada kalian. Kemudian Allah swt. menampakkan kebersihan Siti Aisyah r.a. Dan orang yang telah menolongnya yaitu Shofwan. Sehubungan dengan peristiwa ini Siti Aisyah r.a. telah menceritakan, sebagai berikut, ``Aku ikut bersama Nabi saw. dalam suatu peperangan, yaitu sesudah diturunkannya ayat mengenai hijab bagi kaum wanita. Setelah Nabi saw. menunaikan tugasnya, lalu ia kembali dan kota Madinah sudah dekat. Pada suatu malam setelah istirahat Nabi saw. menyerukan supaya rombongan melanjutkan perjalanan kembali. Aku pergi dari rombongan untuk membuang hajat besarku. Setelah selesai, aku kembali ke rombongan yang sedang bersiap-siap untuk berangkat, akan tetapi ternyata kalungku putus/jatuh, lalu aku kembali lagi ke tempat buang hajat tadi untuk mencarinya. Mereka mengangkat sekedupku ke atas unta kendaraanku, karena mereka menduga bahwa aku telah berada di dalamnya. Karena kaum wanita pada saat itu beratnya ringan sekali, disebabkan mereka hanya makan sedikit. Aku menemukan kembali kalungku yang hilang itu, lalu aku datang ke tempat rombongan, ternyata mereka telah berlalu. Lalu aku duduk di tempat semula, dengan harapan bahwa rombongan akan merasa kehilangan aku, lalu mereka kembali ke tempatku. Mataku mengantuk sekali, sehingga aku tertidur; sedangkan Shofwan pada waktu itu berada jauh dari rombongan pasukan karena beristirahat sendirian. Kemudian dari tempat istirahatnya itu ia melanjutkan kembali perjalanannya menyusul pasukan. Ketika ia sampai ke tempat pasukan, ia melihat ada seseorang sedang tidur, lalu ia langsung mengenaliku, karena ia pernah melihatku sebelum ayat hijab diturunkan. Aku terbangun ketika dia mengucapkan Istirja', 'yaitu kalimat Innaa Lillaahi Wa Innaa Ilaihi RaaJi'uuna'. Aku segera menutup wajahku dengan kain jilbab. Demi Allah, sepatah kata pun ia tidak berbicara denganku, terkecuali hanya kalimat Istirja'nya sewaktu ia merundukkan hewan hendaraannya kemudian ia turun dengan berpijak kepada kaki depan untanya. Selanjutnya aku menaiki unta kendaraannya dan ia langsung menuntun kendaraannya yang kunaiki, hingga kami dapat menyusul rombongan pasukan, yaitu sesudah mereka beristirahat pada siang hari yang panasnya terik. Akhirnya tersiarlah berita bohong yang keji itu, semoga binasalah mereka yang membuat-buatnya. Sumber pertama yang menyiarkannya adalah Abdullah bin Ubay bin Salul." Hanya sampai di sinilah kisah siti Aisyah menurut riwayat yang dikemukakan oleh Imam Bukhari dan Imam Muslim. Selanjutnya Allah berfirman, ("Tiap-tiap seseorang dari mereka) akan dibalas kepadanya (dari dosa yang dikerjakannya) mengenai berita bohong ini. (Dan siapa di antara mereka yang mengambil bagian yang terbesar dalam penyiaran berita bohong itu) maksudnya orang yang menjadi biang keladi dan berperanan penting dalam penyiaran berita bohong ini, yang dimaksud adalah Abdullah bin Ubay (baginya azab yang besar") yakni neraka kelak di akhirat\qt@no{11}}%
\qt@newcmd\qurantrans@id@mmdccciii{%
(Mengapa tidak, sewaktu kalian mendengar berita bohong itu orang-orang Mukmin dan Mukminat berprasangka terhadap diri mereka sendiri) sebagian dari mereka mempunyai prasangka terhadap sebagian yang lain (dengan sangkaan yang baik, dan mengapa tidak berkata, ``Ini adalah suatu berita bohong yang nyata") dan jelas bohongnya. Di dalam ayat ini terkandung ungkapan Iltifat dari orang-orang yang diajak bicara. Maksudnya, mengapa kalian hai golongan orang-orang yang menuduh, mempunyai dugaan seperti itu dan berani mengatakan hal itu?\qt@no{12}}%
\qt@newcmd\qurantrans@id@mmdccciv{%
(Mengapa tidak) (mendatangkan) golongan yang menuduh itu (empat orang saksi atas berita bohong itu?) maksudnya orang-orang yang menyaksikan peristiwa itu. (Oleh karena mereka tidak mendatangkan saksi-saksi maka mereka itulah pada sisi Allah) menurut hukum-Nya (orang-orang yang dusta) dalam tuduhannya.\qt@no{13}}%
\qt@newcmd\qurantrans@id@mmdcccv{%
(Sekiranya tidak ada karunia Allah dan rahmat-Nya kepada kalian semua di dunia dan di akhirat, niscaya kalian ditimpa, karena pembicaraan kalian) hai golongan yang menuduh (tentang berita bohong itu, azab yang besar) di akhirat kelak.\qt@no{14}}%
\qt@newcmd\qurantrans@id@mmdcccvi{%
(Di waktu kalian menerima berita bohong itu dari mulut ke mulut) yaitu sebagian di antara kalian menceritakannya kepada sebagian yang lain. Lafal Talaqqaunahu berasal dari lafal Tatalaqqaunahu, kemudian salah satu dari huruf Ta dibuang sehingga jadilah Talaqqaunahu. Lafal Idz tadi dinashabkan oleh lafal Massakum atau oleh lafal Afadhtum (dan kalian katakan dengan mulut kalian apa yang tidak kalian ketahui sedikit jua, dan kalian menganggapnya suatu yang ringan saja) sebagai sesuatu hal yang tidak berdosa. (Padahal dia pada sisi Allah adalah besar) dosanya.\qt@no{15}}%
\qt@newcmd\qurantrans@id@mmdcccvii{%
(Dan mengapa tidak, sewaktu) ketika (kalian mendengar berita bohong itu, kalian tidak mengatakan, ``Sekali-kali tidaklah pantas) maksudnya tidak layak (bagi kita memperkatakan ini. Maha Suci Engkau) lafal Subhaanaka menunjukkan makna Ta'ajjub (ini adalah dusta) bohong (yang besar.")\qt@no{16}}%
\qt@newcmd\qurantrans@id@mmdcccviii{%
(Allah memperingatkan kalian) yakni melarang kalian (agar jangan kembali memperbuat yang seperti itu selama-lamanya, jika kalian orang-orang yang beriman) yang mau mengambil pelajaran dari hal tersebut.\qt@no{17}}%
\qt@newcmd\qurantrans@id@mmdcccix{%
(Dan Allah menerangkan ayat-ayat-Nya kepada kalian) mengenai perintah dan larangan. (Dan Allah Maha Mengetahui) tentang apa yang Dia perintahkan dan apa yang Dia larang (lagi Maha Bijaksana) dalam hal ini.\qt@no{18}}%
\qt@newcmd\qurantrans@id@mmdcccx{%
(Sesungguhnya orang-orang yang ingin agar berita perbuatan yang amat keji itu tersiar) dengan melalui mulut mereka (di kalangan orang-orang yang beriman) dengan menisbatkan perbuatan keji itu kepada mereka, yang dimaksud adalah segolongan dari kaum Mukmin (bagi mereka azab yang pedih di dunia) mendapat hukuman hudud menuduh berzina (dan di akhirat) oleh Allah dimasukkan ke dalam neraka. (Dan Allah Maha Mengetahui) ketiadaan perbuatan keji itu dari kalangan mereka (sedangkan kalian) hai golongan orang-orang yang melancarkan berita bohong, terhadap apa yang kalian katakan itu (tidak mengetahui) tentang adanya perbuatan keji di kalangan orang-orang yang beriman.\qt@no{19}}%
\qt@newcmd\qurantrans@id@mmdcccxi{%
(Dan sekiranya tidaklah karena karunia Allah kepada kalian) hai orang-orang yang menuduh (dan rahmat-Nya, dan Allah Maha Penyantun lagi Maha Penyayang) kepada kalian, niscaya Dia akan menyegerakan hukuman-Nya kepada kalian.\qt@no{20}}%
\qt@newcmd\qurantrans@id@mmdcccxii{%
(Hai orang-orang yang beriman! Janganlah kalian mengikuti langkah-langkah setan) mengikuti godaan-godaannya. (Barang siapa yang mengikuti langkah-langkah setan, sesungguhnya setan itu) yakni yang diikutinya itu (selalu menyuruh mengerjakan perbuatan yang keji) yakni perbuatan yang buruk (dan yang mungkar) menurut syariat, yaitu jika perbuatan itu diikuti (Sekiranya tidaklah karena karunia Allah dan rahmat-Nya kepada kamu sekalian, niscaya tidak seorang pun dari kalian bersih) hai orang-orang yang menuduh, disebabkan berita bohong yang kalian katakan itu (selama-lamanya) tidak akan menjadi baik dan tidak akan menjadi bersih dari dosa ini hanya dengan bertobat daripadanya (tetapi Allah membersihkan) menyucikan (siapa yang dikehendaki-Nya) dari dosa, yaitu dengan menerima tobatnya. (Dan Allah Maha Mendengar) tentang apa yang telah kalian katakan (lagi Maha Mengetahui) tentang apa yang kalian maksud.\qt@no{21}}%
\qt@newcmd\qurantrans@id@mmdcccxiii{%
(Dan janganlah bersumpah orang-orang yang mempunyai kelebihan) yaitu orang-orang kaya (dan kelapangan di antara kalian, bahwa mereka) tidak (akan memberi bantuan kepada kaum kerabatnya, orang-orang yang miskin dan orang-orang yang berhijrah pada jalan Allah) ayat ini diturunkan berkenaan dengan sahabat Abu Bakar r. a, ia bersumpah tidak akan memberikan nafkah lagi kepada Misthah saudara sepupunya yang miskin lagi seorang Muhajir, padahal Misthah adalah sahabat yang ikut dalam perang Badar. Misthah terlibat dalam peristiwa berita bohong ini; maka sahabat Abu Bakar menghentikan nafkah yang biasa ia berikan kepadanya. Para sahabat lainnya telah bersumpah pula, bahwa mereka juga tidak akan memberikan nafkah lagi kepada seorang yang terlibat membicarakan masalah berita bohong tersebut (dan hendaklah mereka memaafkan dan berlapang dada) terhadap mereka yang terlibat, dengan mengembalikan keadaan seperti semula. (Apakah kalian tidak ingin bahwa Allah mengampuni kalian? Dan Allah adalah Maha Pengampun lagi Maha Penyayang) terhadap orang-orang yang beriman. Sahabat Abu Bakar r.a. berkata sesudah turunnya ayat ini, ``Tentu saja, aku menginginkan supaya Allah mengampuni aku", lalu ia memberikan lagi bantuannya kepada Misthah sebagaimana biasanya.\qt@no{22}}%
\qt@newcmd\qurantrans@id@mmdcccxiv{%
(Sesungguhnya orang-orang yang menuduh) berzina (wanita-wanita yang baik-baik) terpelihara kehormatannya (yang lengah) dari perbuatan-perbuatan keji, seumpamanya dalam hati mereka tidak sedikit pun terbetik niat untuk melakukannya (lagi beriman) kepada Allah dan Rasul-Nya (mereka kena laknat di dunia dan akhirat, dan bagi mereka azab yang besar).\qt@no{23}}%
\qt@newcmd\qurantrans@id@mmdcccxv{%
(Pada hari) yauma dinashabkan oleh lafal Istaqarra yang berta'alluq kepadanya, maksudnya pada hari yang telah ditetapkan bagi mereka (memberi kesaksian) dapat dibaca Tasyhadu dan Yasyhadu (lidah, tangan dan kaki mereka atas mereka terhadap apa yang dahulu mereka kerjakan) berupa perbuatan dan perkataan yang telah mereka kerjakan, yaitu pada hari kiamat.\qt@no{24}}%
\qt@newcmd\qurantrans@id@mmdcccxvi{%
(Di hari itu, Allah akan memberi mereka balasan yang setimpal) Dia akan membalas mereka dengan pembalasan yang semestinya mereka terima (dan tahulah mereka bahwa Allahlah Yang Benar lagi Yang menjelaskan) karena Dia benar-benar membuktikan pembalasan-Nya yang selama ini mereka ragukan kebenarannya; di antara mereka yang mendapat pembalasan adalah Abdullah bin Ubay bin Salul. Yang dimaksud dengan wanita-wanita yang terpelihara kehormatannya adalah istri-istri Nabi saw. Adapun mengenai wanita-wanita yang disebutkan Qadzafnya dalam awal surah At-Taubah, yang dimaksud adalah wanita-wanita selain istri-istri Nabi.\qt@no{25}}%
\qt@newcmd\qurantrans@id@mmdcccxvii{%
(Wanita-wanita yang keji) baik perbuatannya maupun perkataannya (adalah untuk laki-laki yang keji) pula (dan laki-laki yang keji) di antara manusia (adalah buat wanita-wanita yang keji pula) sebagaimana yang sebelumnya tadi (dan wanita-wanita yang baik) baik perbuatan maupun perkataannya (adalah untuk laki-laki yang baik) di antara manusia (dan laki-laki yang baik) di antara mereka (adalah untuk wanita-wanita yang baik pula) baik perbuatan maupun perkataannya. Maksudnya, hal yang layak adalah orang yang keji berpasangan dengan orang yang keji, dan orang baik berpasangan dengan orang yang baik. (Mereka itu) yaitu kaum laki-laki yang baik dan kaum wanita yang baik, antara lain ialah Siti Aisyah dan Sofwan (bersih dari apa yang dituduhkan oleh mereka) yang keji dari kalangan kaum laki-laki dan wanita. (Bagi mereka) yakni laki-laki yang baik dan wanita yang baik itu (ampunan dan rezeki yang mulia) di surga. Siti Aisyah merasa puas dan bangga dengan beberapa hal yang ia peroleh, antara lain, ia diciptakan dalam keadaan baik, dan dijanjikan mendapat ampunan dari Allah, serta diberi rezeki yang mulia.\qt@no{26}}%
\qt@newcmd\qurantrans@id@mmdcccxviii{%
(Hai orang-orang yang beriman! Janganlah kalian memasuki rumah yang bukan rumah kalian sebelum meminta izin) maksudnya sebelum kalian meminta izin kepada empunya (dan memberi salam kepada penghuninya). Seseorang jika mau memasuki rumah orang lain hendaknya ia mengucapkan, ``Assalaamu Alaikum, bolehkah aku masuk?" demikianlah menurut tuntunan hadis. (Yang demikian itu lebih baik bagi kalian) daripada masuk tanpa izin (agar kalian selalu ingat) lafal Tadzakkaruuna dengan mengidgamkan huruf Ta kedua kepada huruf Dzal; maksudnya supaya kalian mengerti akan kebaikan meminta izin itu, kemudian kalian mengerjakannya.\qt@no{27}}%
\qt@newcmd\qurantrans@id@mmdcccxix{%
(Jika kalian tidak menemukan seorang pun di dalamnya) maksudnya orang yang mengizinkan kalian masuk (maka janganlah kalian masuk sebelum kalian mendapat izin. Dan jika dikatakan kepada kalian) sesudah kalian meminta izin ("Kembalilah" maka hendaklah kalian kembali. Itu) yakni kembali itu (lebih bersih) dan lebih baik (bagi kalian) daripada berdiam menunggu di pintu (dan Allah terhadap apa yang kalian kerjakan) yakni mengenai memasuki rumah orang lain dengan memakai izin atau tidak (Maha Mengetahui) Dia kelak akan membalasnya kepada kalian.\qt@no{28}}%
\qt@newcmd\qurantrans@id@mmdcccxx{%
(Tidak ada dosa atas kalian memasuki rumah yang tidak disediakan untuk didiami, yang di dalamnya ada keperluan) maksudnya, ada manfaat (bagi kalian) misalnya dijadikannya sebagai tempat tinggal sementara atau untuk keperluan yang lainnya, seperti rumah-rumah asrama dan lain sebagainya (dan Allah mengetahui apa yang kalian nyatakan) yakni semua apa yang kalian lahirkan (dan apa yang kalian sembunyikan) artinya yang kalian rahasiakan sewaktu kalian masuk ke dalam rumah yang bukan rumah kalian, termasuk maksud baik atau maksud-maksud lainnya. Pada pembahasan yang akan datang akan diceritakan, bahwa mereka para sahabat, jika mereka memasuki rumah mereka sendiri, mereka mengucapkan salam kepada diri mereka sendiri.\qt@no{29}}%
\qt@newcmd\qurantrans@id@mmdcccxxi{%
(Katakanlah kepada orang laki-laki yang beriman, ``Hendaklah mereka menahan pandangannya) dari apa-apa yang tidak dihalalkan bagi mereka melihatnya. Huruf Min di sini adalah Zaidah (dan memelihara kemaluannya) daripada hal-hal yang tidak dihalalkan untuknya (yang demikian itu adalah lebih suci) adalah lebih baik (bagi mereka, sesungguhnya Allah Maha Mengetahui apa yang mereka perbuat") melalui penglihatan dan kemaluan mereka, kelak Dia akan membalasnya kepada mereka.\qt@no{30}}%
\qt@newcmd\qurantrans@id@mmdcccxxii{%
(Dan katakanlah kepada wanita yang beriman, ``Hendaklah mereka menahan pandangannya) daripada hal-hal yang tidak dihalalkan bagi mereka melihatnya (dan memelihara kemaluannya) dari hal-hal yang tidak dihalalkan untuknya (dan janganlah mereka menampakkan) memperlihatkan (perhiasannya, kecuali yang biasa tampak daripadanya) yaitu wajah dan dua telapak tangannya, maka kedua perhiasannya itu boleh dilihat oleh lelaki lain, jika tidak dikhawatirkan adanya fitnah. Demikianlah menurut pendapat yang membolehkannya. Akan tetapi menurut pendapat yang lain hal itu diharamkan secara mutlak, sebab merupakan sumber terjadinya fitnah. Pendapat yang kedua ini lebih kuat demi untuk menutup pintu fitnah. (Dan hendaklah mereka menutupkan kain kerudung ke dadanya) hendaknya mereka menutupi kepala, leher dan dada mereka dengan kerudung atau jilbabnya (dan janganlah menampakkan perhiasannya) perhiasan yang tersembunyi, yaitu selain dari wajah dan dua telapak tangan (kecuali kepada suami mereka) bentuk jamak dari lafal Ba'lun artinya suami (atau ayah mereka, atau ayah suami mereka, atau putra-putra mereka, atau putra-putra suami mereka, atau saudara-saudara mereka, atau putra-putra saudara-saudara mereka, atau putra-putra saudara-saudara perempuan mereka, atau wanita-wanita Islam atau budak-budak yang mereka miliki) diperbolehkan bagi mereka melihatnya kecuali anggota tubuh antara pusar dan lututnya, anggota tersebut haram untuk dilihat oleh mereka selain dari suaminya sendiri. Dikecualikan dari lafal Nisaaihinna, yaitu perempuan-perempuan yang kafir, bagi wanita Muslimat tidak boleh membuka aurat di hadapan mereka. Termasuk pula ke dalam pengertian Maa Malakat Aymaanuhunna, yaitu hamba sahaya laki-laki miliknya (atau pelayan-pelayan laki-laki) yakni pembantu-pembantu laki-laki (yang tidak) kalau dibaca Ghairi berarti menjadi sifat dan kalau dibaca Ghaira berarti menjadi Istitsna (mempunyai keinginan) terhadap wanita (dari kalangan kaum laki-laki) seumpamanya penis masing-masing tidak dapat bereaksi (atau anak-anak) lafal Ath-Thifl bermakna jamak sekalipun bentuk lafalnya tunggal (yang masih belum mengerti) belum memahami (tentang aurat wanita) belum mengerti persetubuhan, maka kaum wanita boleh menampakkan aurat mereka terhadap orang-orang tersebut selain antara pusar dan lututnya. (Dan janganlah mereka memukulkan kaki mereka agar diketahui perhiasan yang mereka sembunyikan) yaitu berupa gelang kaki, sehingga menimbulkan suara gemerincing. (Dan bertobatlah kamu sekalian kepada Allah, hai orang-orang yang beriman) dari apa yang telah kalian kerjakan, yaitu sehubungan dengan pandangan yang dilarang ini dan hal-hal lainnya yang dilarang (supaya kalian beruntung") maksudnya selamat dari hal tersebut karena tobat kalian diterima. Pada ayat ini ungkapan Mudzakkar mendominasi atas Muannats.\qt@no{31}}%
\qt@newcmd\qurantrans@id@mmdcccxxiii{%
(Dan kawinkanlah orang-orang yang sendirian di antara kalian) lafal Ayaama adalah bentuk jamak dari lafal Ayyimun artinya wanita yang tidak mempunyai suami, baik perawan atau janda, dan laki-laki yang tidak mempunyai istri; hal ini berlaku untuk laki-laki dan perempuan yang merdeka (dan orang-orang yang layak kawin) yakni yang Mukmin (dari hamba-hamba sahaya kalian yang lelaki dan hamba-hamba sahaya kalian yang perempuan) lafal 'ibaadun adalah bentuk jamak dari lafal 'Abdun. (Jika mereka) yakni orang-orang yang merdeka itu (miskin Allah akan memampukan mereka) berkat adanya perkawinan itu (dengan karunia-Nya. Dan Allah Maha Luas) pemberian-Nya kepada makhluk-Nya (lagi Maha Mengetahui) mereka.\qt@no{32}}%
\qt@newcmd\qurantrans@id@mmdcccxxiv{%
(Dan orang-orang yang tidak mampu kawin hendaklah menjaga kesuciannya) maksudnya mereka yang tidak mempunyai mahar dan nafkah untuk kawin, hendaklah mereka memelihara kesuciannya dari perbuatan zina (sehingga Allah memampukan mereka) memberikan kemudahan kepada mereka (dengan karunia-Nya) hingga mereka mampu kawin. (Dan orang-orang yang menginginkan perjanjian) lafal Al Kitaaba bermakna Al Mukaatabah, yaitu perjanjian untuk memerdekakan diri (di antara budak-budak yang kalian miliki) baik hamba sahaya laki-laki maupun perempuan (maka hendaklah kalian buat perjanjian dengan mereka jika kalian mengetahui ada kebaikan pada mereka) artinya dapat dipercaya dan memiliki kemampuan untuk berusaha yang hasilnya kelak dapat membayar perjanjian kemerdekaan dirinya. Shighat atau teks perjanjian ini, misalnya seorang pemilik budak berkata kepada budaknya, ``Aku memukatabahkan kamu dengan imbalan dua ribu dirham, selama jangka waktu dua bulan. Jika kamu mampu membayarnya, berarti kamu menjadi orang yang merdeka." Kemudian budak yang bersangkutan menjawab, ``Saya menyanggupi dan mau menerimanya" (dan berikanlah kepada mereka) perintah di sini ditujukan kepada para pemilik budak (sebagian dari harta Allah yang dikaruniakan-Nya kepada kalian) berupa apa-apa yang dapat membantu mereka untuk menunaikan apa yang mereka harus bayarkan kepada kalian. Di dalam lafal Al-Iitaa terkandung pengertian meringankan sebagian dari apa yang harus mereka bayarkan kepada kalian, yaitu dengan menganggapnya lunas. (Dan janganlah kalian paksakan budak-budak wanita kalian) yaitu sahaya wanita milik kalian (untuk melakukan pelacuran) berbuat zina (sedangkan mereka sendiri menginginkan kesucian) memelihara kehormatannya dari perbuatan zina. Adanya keinginan untuk memelihara kehormatan inilah yang menyebabkan dilarang memaksa, sedangkan syarath di sini tidak berfungsi sebagaimana mestinya lagi (karena kalian hendak mencari) melalui paksaan itu (keuntungan duniawi) ayat ini diturunkan berkenaan dengan Abdullah bin Ubay, karena dia memaksakan hamba-hamba sahaya perempuannya untuk berpraktek sebagai pelacur demi mencari keuntungan bagi dirinya. (Dan barang siapa memaksa mereka, maka sesungguhnya Allah kepada mereka yang telah dipaksa itu adalah Maha Pengampun) (lagi Maha Penyayang).\qt@no{33}}%
\qt@newcmd\qurantrans@id@mmdcccxxv{%
(Dan sesungguhnya Kami telah menurunkan kepada kalian ayat-ayat yang memberi penerangan) dapat dibaca Mubayyanatin dan Mubayyinatin. Artinya, telah dijelaskan di dalamnya hal-hal yang telah disebutkan tadi (dan contoh-contoh) yakni berita yang aneh, yaitu berita tentang Siti Aisyah (dari orang-orang yang terdahulu sebelum kalian) maksudnya sama jenisnya dengan berita-berita mereka dalam hal keanehannya, seperti kisah mengenai Nabi Yusuf dan Siti Maryam (dan pelajaran bagi orang-orang yang bertakwa) yaitu dalam firman-Nya, ``Dan janganlah belas kasihan kalian kepada keduanya mencegah kalian untuk menjalankan agama (hukum) Allah." (Q.S. An-Nur, 2) dan firman-Nya, ``Mengapa di waktu kalian mendengar berita bohong itu orang-orang Mukmin dan Mukminat tidak berprasangka baik". (Q.S. An-Nur, 12). Dan firman-Nya, ``Dan mengapa kalian tidak berkata di waktu mendengar berita bohong itu..." (Q.S. An-Nur, 16). Dan firman-Nya, ``Allah memperingatkan kalian agar jangan kembali memperbuat yang seperti itu..." (Q.S. An-Nur, 17). Dalam ayat ini orang-orang yang bertakwa disebutkan secara khusus mengingat hanya merekalah yang dapat mengambil manfaat dari pelajaran yang terkandung di dalamnya.\qt@no{34}}%
\qt@newcmd\qurantrans@id@mmdcccxxvi{%
(Allah cahaya langit dan bumi) yakni pemberi cahaya langit dan bumi dengan matahari dan bulan. (Perumpamaan cahaya Allah) sifat cahaya Allah di dalam kalbu orang Mukmin (adalah seperti misykat yang di dalamnya ada pelita besar. Pelita itu di dalam kaca) yang dinamakan lampu lentera atau Qandil. Yang dimaksud Al Mishbah adalah lampu atau sumbu yang dinyalakan. Sedangkan Al Misykaat artinya sebuah lubang yang tidak tembus. Sedangkan pengertian pelita di dalam kaca, maksudnya lampu tersebut berada di dalamnya (kaca itu seakan-akan) cahaya yang terpancar darinya (bintang yang bercahaya seperti mutiara) kalau dibaca Diriyyun atau Duriyyun berarti berasal dari kata Ad Dar'u yang artinya menolak atau menyingkirkan, dikatakan demikian karena dapat mengusir kegelapan, maksudnya bercahaya. Jika dibaca Durriyyun dengan mentasydidkan huruf Ra, berarti mutiara, maksudnya cahayanya seperti mutiara (yang dinyalakan) kalau dibaca Tawaqqada dalam bentuk Fi'il Madhi, artinya lampu itu menyala. Menurut suatu qiraat dibaca dalam bentuk Fi'il Mudhari' yaitu Tuuqidu, menurut qiraat lainnya dibaca Yuuqadu, dan menurut qiraat yang lainnya lagi dapat dibaca Tuuqadu, artinya kaca itu seolah-olah dinyalakan (dengan) minyak (dari pohon yang banyak berkahnya, yaitu pohon zaitun yang tumbuh tidak di sebelah Timur dan pula tidak di sebelah Barat) akan tetapi tumbuh di antara keduanya, sehingga tidak terkena panas atau dingin yang dapat merusaknya (yang minyaknya saja hampir-hampir menerangi, walaupun tidak disentuh api) mengingat jernihnya minyak itu. (Cahaya) yang disebabkannya (di atas cahaya) api dari pelita itu. Makna yang dimaksud dengan cahaya Allah adalah petunjuk-Nya kepada orang Mukmin, maksudnya hal itu adalah cahaya di atas cahaya iman (Allah membimbing kepada cahaya-Nya) yaitu kepada agama Islam (siapa yang Dia kehendaki, dan Allah memperbuat) yakni menjelaskan (perumpamaan-perumpamaan bagi manusia) supaya dapat dicerna oleh pemahaman mereka, kemudian supaya mereka mengambil pelajaran daripadanya, sehingga mereka mau beriman (dan Allah Maha Mengetahui segala sesuatu) antara lain ialah membuat perumpamaan-perumpamaan ini.\qt@no{35}}%
\qt@newcmd\qurantrans@id@mmdcccxxvii{%
(Di rumah-rumah Allah) maksudnya mesjid-mesjid, lafal Fii Buyuutin berta'alluq kepada lafal Yusabbihu yang akan disebutkan nanti. (Yang Allah telah memerintahkan supaya dimuliakan) yakni diagungkan (dan disebut nama-Nya di dalamnya) dengan mentauhidkan-Nya (bertasbihlah) dapat dibaca Yusabbahu artinya dibacakan tasbih dalam salat. Dapat pula dibaca Yusabbihu, artinya membaca tasbih dalam salat (kepada Allah di dalamnya, pada waktu pagi) lafal Al-Ghuduwwi adalah Mashdar yang maknanya Al-Ghadwaati, artinya pagi hari (dan waktu petang) waktu sore sesudah matahari tergelincir.\qt@no{36}}%
\qt@newcmd\qurantrans@id@mmdcccxxviii{%
(Laki-laki) menjadi Fa'il atau subyek daripada Fi'il Yusabbihu, jika dibaca Yusabbahu berkedudukan menjadi Naibul Fa'il. Lafal Rijaalun adalah Fa'il dari Fi'il atau kata kerja yang diperkirakan keberadaannya sebagai jawab dari soal yang diperkirakan pula. Jadi seolah-olah dikatakan, siapakah yang melakukan tasbih kepada-Nya itu, jawabnya adalah laki-laki (yang tidak dilalaikan oleh perniagaan) perdagangan (dan tidak pula oleh jual beli dari mengingat Allah dan dari mendirikan salat) huruf Ha lafal Iqaamatish Shalaati dibuang demi untuk meringankan bacaan sehingga jadilah Iqaamish Shalaati (dan dari membayar zakat. Mereka takut kepada suatu hari yang di hari itu menjadi guncang) yakni panik (hati dan penglihatan) karena merasa khawatir, apakah dirinya selamat atau binasa, dan penglihatan jelalatan ke kanan dan ke kiri karena ngeri melihat pemandangan azab pada saat itu, yaitu hari kiamat.\qt@no{37}}%
\qt@newcmd\qurantrans@id@mmdcccxxix{%
(Dengan harapan supaya Allah memberi balasan kepada mereka dengan balasan yang lebih baik dari apa yang telah mereka kerjakan) maksudnya pahala yang baik, karena lafal Ahsan bermakna Hasan (dan supaya Allah menambah karunia-Nya kepada mereka. Dan Allah memberi rezeki kepada siapa yang dikehendaki-Nya tanpa batas) jika dikatakan, Fulaanun Yunfiqu Bighairi Hisabin, maka artinya, dia membelanjakan harta tanpa perhitungan lagi.\qt@no{38}}%
\qt@newcmd\qurantrans@id@mmdcccxxx{%
(Dan orang-orang yang kafir amal-amal mereka adalah laksana fatamorgana di tanah yang datar) lafal Qii'ah adalah bentuk jamak dari lafal Qaa'un, yakni padang sahara yang datar. Yang dimaksud dengan lafal Saraabun adalah pemandangan yang tampak di kala matahari sedang terik-teriknya yang rupanya mirip seperti air yang mengalir, atau lazim disebut fatamorgana (ia disangka) diduga (oleh orang yang kehausan) yaitu orang yang dahaga (air, tetapi bila didatanginya air itu dia tidak mendapatinya sesuatu apa pun) apa yang disangkanya itu, demikian pula halnya orang kafir, ia menduga bahwa amal kebaikannya seperti sedekah, yang ia sangka bermanfaat bagi dirinya, tetapi bila ia mati kemudian ia menghadap kepada Rabbnya, maka ia tidak mendapati amal kebaikannya itu. Atau dengan kata lain amalnya itu tidak memberi manfaat kepada dirinya. (Dan ia mendapatkan Allah di sisinya) yakni di sisi amalnya (lalu Allah memberikan kepadanya perhitungan amal-amal dengan cukup) Allah memberikan balasan amal perbuatannya itu hanya di dunia (dan Allah adalah sangat cepat perhitungan-Nya) di dalam memberikan balasan-Nya.\qt@no{39}}%
\qt@newcmd\qurantrans@id@mmdcccxxxi{%
(Atau) amal perbuatan orang-orang kafir yang buruk (seperti gelap-gulita di lautan yang dalam) yakni laut yang amat dalam (yang diliputi oleh ombak di atasnya) di atas ombak itu (ada ombak pula, di atasnya lagi) maksudnya di atas ombak yang kedua itu (awan) yang mendung dan gelap; ini adalah (gelap-gulita yang tindih-menindih) yakni gelapnya laut, gelapnya ombak yang pertama, gelapnya ombak yang kedua, dan gelapnya mendung (apabila dia mengeluarkan) yakni orang yang melihatnya (tangannya) di dalam gelap-gulita yang sangat ini (tiadalah dia dapat melihatnya) artinya hampir saja ia tidak dapat melihat tangannya sendiri (dan barang siapa yang tiada diberi cahaya oleh Allah tiadalah dia mempunyai cahaya sedikit pun) maksudnya barang siapa yang tidak diberi petunjuk oleh Allah, niscaya ia tidak akan mendapatkan petunjuk.\qt@no{40}}%
\qt@newcmd\qurantrans@id@mmdcccxxxii{%
(Tidakkah kamu melihat, bahwasanya Allah kepada-Nya bertasbih apa yang di langit dan di bumi) dan termasuk ke dalam pengertian bertasbih adalah salat (dan juga burung-burung) lafal Thair adalah bentuk jamak dari lafal Ath Thaair, yakni makhluk yang terbang antara bumi dan langit (dengan mengembangkan sayapnya) lafal Shaaffaatin adalah Hal atau kata keterangan keadaan dari burung-burung tadi, yaitu burung-burung itu membaca tasbih dengan mengembangkan sayapnya. (Masing-masingnya telah diketahui) oleh Allah (cara salat dan bertasbihnya, dan Allah Maha Mengetahui apa yang mereka kerjakan). Di dalam ungkapan ini, semuanya dianggap sebagai makhluk yang berakal.\qt@no{41}}%
\qt@newcmd\qurantrans@id@mmdcccxxxiii{%
(Dan kepunyaan Allahlah kerajaan langit dan bumi) maksudnya perbendaharaan-perbendaharaan hujan, rezeki dan tumbuh-tumbuhan (dan kepada Allahlah kembali) semua makhluk.\qt@no{42}}%
\qt@newcmd\qurantrans@id@mmdcccxxxiv{%
(Tidaklah kamu melihat bahwa Allah mengarak awan) menggiringnya secara lembut (kemudian mengumpulkan antara bagian-bagiannya) dengan menghimpun sebagiannya dengan sebagian yang lain, sehingga yang tadinya tersebar kini menjadi satu kumpulan (kemudian menjadikannya bertindih-tindih) yakni sebagiannya di atas sebagian yang lain (maka kelihatanlah olehmu air) hujan (keluar dari celah-celahnya) yakni melalui celah-celahnya (dan Allah juga menurunkan dari langit). Huruf Min yang kedua ini berfungsi menjadi Shilah atau kata penghubung (yakni dari gunung-gunung yang menjulang padanya) menjulang ke langit; Min Jibaalin menjadi Badal daripada lafal Minas Samaa-i dengan mengulangi huruf Jarrnya (berupa es) sebagiannya terdiri dari es (maka ditimpakannya es tersebut kepada siapa yang dikehendaki-Nya dan dipalingkan-Nya dari siapa yang dikehendaki-Nya. Hampir-hampir) hampir saja (kilauan kilat awan itu) yakni cahayanya yang berkilauan (menghilangkan penglihatan) mata yang memandangnya, karena silau olehnya.\qt@no{43}}%
\qt@newcmd\qurantrans@id@mmdcccxxxv{%
(Allah mempergantikan malam dan siang) mendatangkan masing-masingnya sebagai pengganti dari yang lain. (sesungguhnya pada yang demikian itu) yakni pergantian ini (terdapat pelajaran) yang menunjukkan kebesaran-Nya (bagi orang-orang yang mempunyai penglihatan) bagi mereka yang memiliki penglihatan memandang kekuasaan Allah swt.\qt@no{44}}%
\qt@newcmd\qurantrans@id@mmdcccxxxvi{%
(Dan Allah telah menciptakan semua jenis hewan) maksudnya makhluk hidup (dari air) yakni air mani (maka sebagian dari hewan itu ada yang berjalan di atas perutnya) seperti ulat dan binatang melata lainnya (dan sebagian berjalan dengan dua kaki) seperti manusia dan burung (sedangkan sebagian yang lain berjalan dengan empat kaki) seperti hewan liar dan hewan ternak. (Allah menciptakan apa yang dikehendaki-Nya, sesungguhnya Allah Maha Kuasa atas segala sesuatu).\qt@no{45}}%
\qt@newcmd\qurantrans@id@mmdcccxxxvii{%
(Sesungguhnya Kami telah menurunkan ayat-ayat yang menjelaskan) yaitu Alquran. (Dan Allah memimpin siapa yang dikehendaki-Nya kepada jalan) yakni tuntunan (yang lurus) yaitu agama Islam.\qt@no{46}}%
\qt@newcmd\qurantrans@id@mmdcccxxxviii{%
(Dan mereka berkata) maksudnya orang-orang munafik, ("Kami telah beriman) Kami telah percaya (kepada Allah) dengan mengesakan-Nya (dan Rasul) yaitu Nabi Muhammad (dan Kami menaati") apa yang telah ditetapkan oleh Allah dan Rasul-Nya. (Kemudian berpalinglah) memalingkan diri (sebagian dari mereka sesudah itu) dari apa yang telah ditetapkan oleh Allah dan Rasul-Nya (sekali-kali mereka itu bukanlah) orang-orang yang berpaling itu (orang-orang yang beriman) sejati, yang hati dan lisan mereka bersesuaian.\qt@no{47}}%
\qt@newcmd\qurantrans@id@mmdcccxxxix{%
(Dan apabila mereka dipanggil kepada Allah dan Rasul-Nya) yang menyampaikan kepada mereka (agar Rasul menghukum/mengadili di antara mereka, tiba-tiba sebagian dari mereka berpaling) menolak untuk datang memenuhi seruan Rasul.\qt@no{48}}%
\qt@newcmd\qurantrans@id@mmdcccxl{%
(Tetapi jika keputusan itu untuk kemaslahatan mereka, mereka mau datang kepada Rasul dengan patuh) dengan segera dan penuh ketaatan.\qt@no{49}}%
\qt@newcmd\qurantrans@id@mmdcccxli{%
(Apakah di dalam hati mereka ada penyakit) yakni kekafiran (atau karena mereka ragu-ragu) mereka meragukan kenabiannya (ataukah karena mereka takut kalau-kalau Allah dan Rasul-Nya berlaku zalim kepada mereka?) di dalam peradilan, yakni mereka diperlakukan secara aniaya di dalamnya. Tidak (sebenarnya, mereka itulah orang-orang yang zalim) karena mereka berpaling dari peradilan itu.\qt@no{50}}%
\qt@newcmd\qurantrans@id@mmdcccxlii{%
(Sesungguhnya jawaban orang-orang Mukmin, bila mereka dipanggil kepada Allah dan Rasul-Nya agar Rasul mengadili di antara mereka) maka jawaban yang pantas mereka katakan (ialah ucapan, ``Kami mendengar dan Kami patuh") yakni mengiakan secara spontan. (Dan mereka) sejak saat itu (adalah orang-orang yang beruntung) artinya orang-orang yang selamat di dunia dan akhirat.\qt@no{51}}%
\qt@newcmd\qurantrans@id@mmdcccxliii{%
(Dan barang siapa yang taat kepada Allah dan Rasul-Nya dan takut kepada Allah) merasa takut kepada-Nya (dan bertakwa kepada-Nya) dapat dibaca Wayattaqih dan Wayattaqhi, yakni dengan menaati-Nya (maka mereka adalah orang-orang yang mendapat kemenangan) yaitu mendapat surga.\qt@no{52}}%
\qt@newcmd\qurantrans@id@mmdcccxliv{%
(Dan mereka bersumpah dengan nama Allah sekuat-kuat sumpah) dengan sekuatnya (jika kalian suruh mereka) untuk pergi berjihad (pastilah mereka akan pergi. Katakanlah!) kepada mereka ("Janganlah kalian bersumpah, karena ketaatan yang diminta ialah ketaatan yang sebenarnya) maksudnya taat yang sebenarnya kepada Nabi adalah lebih baik daripada sumpah kalian yang tidak kalian tunaikan. (Sesungguhnya Allah Maha Mengetahui apa yang kalian kerjakan") berupa ketaatan kalian secara lisan, padahal kalian bertentangan dalam prakteknya.\qt@no{53}}%
\qt@newcmd\qurantrans@id@mmdcccxlv{%
(Katakanlah! ``Taatlah kepada Allah dan taatlah kepada Rasul dan jika kalian berpaling) dari taat kepadanya. Lafal Tawallau asalnya adalah Tatawallau; maksudnya pembicaraan ini ditujukan kepada mereka (maka sesungguhnya kewajiban Rasul itu adalah apa yang dibebankan kepadanya) yaitu menyampaikan risalah (dan kewajiban kamu sekalian adalah semata-mata apa yang dibebankan kepada kalian) yakni untuk taat kepadanya (dan jika kalian taat kepadanya, niscaya kalian mendapat petunjuk. Dan tidak lain kewajiban Rasul itu melainkan menyampaikan amanat Allah dengan terang") yaitu secara jelas dan gamblang.\qt@no{54}}%
\qt@newcmd\qurantrans@id@mmdcccxlvi{%
(Dan Allah telah menjanjikan kepada orang-orang yang beriman di antara kalian dan mengerjakan amal-amal yang saleh, bahwa Dia sungguh-sungguh akan menjadikan mereka berkuasa di bumi) sebagai ganti dari orang-orang kafir (sebagaimana Dia telah menjadikan berkuasa) dapat dibaca Kamastakhlafa dan Kamastukhlifa (orang-orang yang sebelum mereka) sebagaimana yang dialami oleh kaum Bani Israel sebagai pengganti dari orang-orang yang lalim dan angkara murka (dan sungguh Dia akan meneguhkan bagi mereka agama yang telah diridai-Nya untuk mereka) yaitu agama Islam; seumpamanya Dia akan memenangkannya di atas agama-agama yang lain, kemudian Dia meluaskan bagi mereka daerah-daerah mereka dan mereka menjadi para pemiliknya (dan Dia benar-benar akan menukar keadaan mereka) dapat dibaca Takhfif yaitu menjadi walayubdilannahum, dapat pula dibaca Tasydid yaitu menjadi Walayubaddilannahum (sesudah mereka berada dalam ketakutan) dari perlakuan orang-orang kafir (menjadi aman sentosa) dan Allah telah menunaikan janji-Nya kepada mereka, yaitu memberikan kepada mereka apa yang telah disebutkan tadi, kemudian Dia memuji mereka melalui firman-Nya, (Mereka tetap menyembah-Ku dengan tiada mempersekutukan sesuatu apa pun dengan Aku) ayat ini merupakan jumlah Isti'naf atau kalimat baru, akan tetapi statusnya disamakan sebagai Illat. (Dan barang siapa yang tetap kafir sesudah janji itu) sesudah pemberian nikmat kepada mereka, yaitu keamanan tadi (maka mereka itulah orang-orang yang fasik) dan orang-orang yang mula-mula kafir sesudah itu adalah para pembunuh Khalifah Usman r.a. kemudian mereka menjadi orang-orang yang saling membunuh padahal sebelumnya mereka berteman.\qt@no{55}}%
\qt@newcmd\qurantrans@id@mmdcccxlvii{%
(Dan dirikanlah salat, tunaikanlah zakat, dan taatlah kepada Rasul, supaya kalian diberi rahmat) mudah-mudahan kalian diberi rahmat.\qt@no{56}}%
\qt@newcmd\qurantrans@id@mmdcccxlviii{%
(Janganlah kamu kira) dapat dibaca Tahsabanna dan Yahsabanna, yang menjadi Fa'il atau subyeknya adalah Rasulullah (bahwa orang-orang yang kafir itu dapat melemahkan) Kami (di bumi ini) yakni selamat dari azab Kami (sedangkan tempat tinggal mereka) yaitu tempat mereka kembali (adalah neraka. Dan sungguh sejelek-jelek tempat kembali adalah neraka) maksudnya tempat kembali yang paling buruk.\qt@no{57}}%
\qt@newcmd\qurantrans@id@mmdcccxlix{%
(Hai orang-orang yang beriman, hendaklah meminta izin kepada kalian budak-budak yang kalian miliki) baik yang laki-laki maupun yang perempuan (dan orang-orang yang belum balig di antara kalian) maksudnya dari kalangan orang-orang yang merdeka dan belum mengetahui perihal kaum wanita (sebanyak tiga kali) yaitu dalam tiga waktu untuk seharinya (yaitu sebelum salat subuh dan ketika kalian menanggalkan pakaian luar kalian di tengah hari) yakni waktu salat Zuhur (dan sesudah salat Isyak. Itulah tiga aurat bagi kalian) kalau dibaca Rafa' menjadi Tsalaatsu 'Auraatin, berarti menjadi Khabar dari Mubtada yang diperkirakan keberadaannya, dan sebelum Khabar terdapat Mudhaf, kemudian kedudukan Mudhaf yang diperkirakan itu diganti oleh Mudhaf ilaih yaitu lafal Tsalaatsun itu sendiri. Makna selengkapnya ialah, Ketentuan tersebut adalah tiga waktu yang ketiga-tiganya merupakan aurat bagi kalian. Jika dibaca Nashab menjadi Tsalaatsa Auraatin Lakum, dengan memperkirakan adanya lafal Auraatin yang dinashabkan, juga karena menjadi Badal secara Mahal dari lafal sebelumnya, kemudian Mudhaf ilaih menggantikan kedudukannya. Dikatakan demikian karena pada saat-saat tersebut, yaitu ketiga waktu itu, orang-orang membuka pakaian luar mereka untuk istirahat sehingga auratnya kelihatan. (Tidak ada atas kalian dan tidak pula atas mereka) atas budak-budak yang kalian miliki dan anak-anak kecil (dosa) untuk masuk menemui kalian tanpa izin (selain dari tiga waktu itu) yakni sesudah ketiga waktu tadi, sedangkan mereka (melayani kalian) meladeni kalian (sebagian kalian) yakni pelayan itu mempunyai keperluan (kepada sebagian yang lain) kalimat ini berkedudukan mengukuhkan makna sebelumnya. (Demikianlah) sebagaimana apa yang telah disebutkan tadi (Allah menjelaskan ayat-ayat bagi kalian) yakni menjelaskan hukum-hukum-Nya. (Dan Allah Maha Mengetahui) tentang semua urusan makhluk-Nya (lagi Maha Bijaksana) di dalam mengatur kepentingan mereka. Ayat yang menyangkut masalah meminta izin ini menurut suatu pendapat telah dinasakh. Akan tetapi menurut pendapat yang lain tidak dinasakh, hanya saja orang-orang meremehkan masalah meminta izin ini, sehingga banyak dari mereka yang tidak memakainya lagi.\qt@no{58}}%
\qt@newcmd\qurantrans@id@mmdcccl{%
(Dan apabila anak-anak kalian telah sampai) hai orang-orang yang merdeka (kepada usia balig, maka hendaklah mereka meminta izin) dalam semua waktu (seperti orang-orang yang sebelum mereka meminta izin) yakni orang-orang dewasa yang merdeka. (Demikianlah Allah menjelaskan ayat-ayat-Nya bagi kalian. Dan Allah Maha mengetahui lagi Maha Bijaksana).\qt@no{59}}%
\qt@newcmd\qurantrans@id@mmdcccli{%
(Dan perempuan-perempuan tua yang telah terhenti) dari haid dan dari mempunyai anak disebabkan telah lanjut umurnya (yang tiada ingin kawin lagi) bagi yang demikian itu (tiadalah atas mereka dosa menanggalkan pakaian mereka) yakni jilbab mereka, atau selendang mereka, atau penutup yang ada di atas kerudung mereka (dengan tidak bermaksud menampakkan) yakni menonjolkan (perhiasan)-nya yang tersembunyi seperti kalung, gelang tangan dan gelang kaki (dan berlaku terhormat) tidak melepaskannya (adalah lebih baik bagi mereka. Dan Allah Maha Mendengar) perkataan kalian (lagi Maha Mengetahui) apa yang tersimpan di dalam kalbu kalian.\qt@no{60}}%
\qt@newcmd\qurantrans@id@mmdccclii{%
(Tidak ada dosa bagi orang buta, tidak pula bagi orang pincang, dan tidak pula bagi orang sakit) untuk makan bersama dengan orang-orang selain mereka (dan tidak pula) dosa (bagi diri kalian sendiri untuk makan bersama mereka di rumah kalian sendiri) yaitu di rumah anak-anak kalian (atau rumah bapak-bapak kalian, di rumah ibu-ibu kalian, di rumah saudara-saudara kalian yang laki-laki, di rumah saudara-saudara kalian yang perempuan, di rumah saudara-saudara bapak kalian yang laki-laki, di rumah saudara-saudara bapak kalian yang perempuan, di rumah saudara-saudara ibu kalian yang laki-laki, di rumah saudara-saudara ibu kalian yang perempuan, di rumah yang kalian miliki kuncinya) yang khusus kalian sediakan buat orang lain (atau - di rumah - kawan-kawan kalian) yang dimaksud dengan kawan adalah orang-orang yang benar-benar setia kepada kalian. Makna ayat ini ialah, bahwa kalian diperbolehkan makan dari rumah-rumah orang-orang yang telah disebutkan tadi, sekalipun para pemiliknya tidak hadir atau sedang tidak ada di rumah, jika memang kalian telah yakin akan kerelaan mereka terhadap sikap kalian itu (Tidak ada dosa bagi kalian makan bersama-sama mereka) yakni berbarengan dengan mereka (atau sendirian) tidak bersama-sama. Lafal Asytaatan ini adalah bentuk jamak dari kata Syatta, artinya sendiri-sendiri atau berpisah-pisah. Ayat ini diturunkan berkenaan dengan seseorang yang merasa berdosa jika ia makan sendirian. Jika ia tidak menemukan seseorang yang mau makan bersamanya, maka ia tidak mau memakan makanannya (maka apabila kalian memasuki rumah-rumah) milik kalian sendiri yang tidak ada penghuninya (hendaklah kalian memberi salam kepada diri kalian sendiri) katakanlah! ``Assalaamu 'Alainaa Wa Alaa `Ibaadillaahish Shaalihiin" yang artinya, ``Keselamatan semoga dilimpahkan kepada diri kami dan hamba-hamba Allah yang saleh". Karena sesungguhnya para Malaikatlah yang akan menjawab salam kalian itu. Jika ternyata di dalam rumah-rumah itu terdapat penghuninya, maka berilah salam kepada mereka (sebagai salam) lafal Tahiyyatan menjadi Mashdar artinya sebagai penghormatan (yang ditetapkan di sisi Allah, yang diberkati lagi baik) yakni diberi pahala bagi orang yang mengucapkannya. (Demikianlah Allah menjelaskan ayat-ayat-Nya bagi kalian) Dia merincikan tanda-tanda agama kalian (agar kalian memahaminya) supaya kalian mengerti hal tersebut.\qt@no{61}}%
\qt@newcmd\qurantrans@id@mmdcccliii{%
(Orang-orang Mukmin yang sesungguhnya itu tidak lain hanyalah orang-orang yang beriman kepada Allah dan Rasul-Nya, dan apabila mereka berada bersama-sama dengannya) dengan Rasulullah (dalam sesuatu urusan yang memerlukan pertemuan) seperti khutbah Jumat (mereka tidak meninggalkan) Rasulullah karena hal-hal mendadak yang dialami mereka, dalam hal ini mereka dimaafkan (sebelum meminta izin kepadanya. Sesungguhnya orang-orang yang meminta izin kepadamu, mereka itulah orang-orang yang beriman kepada Allah dan Rasul-Nya, maka apabila mereka meminta izin kepadamu karena sesuatu keperluan mereka) karena mereka mempunyai urusan penting (berilah izin kepada siapa yang kamu kehendaki di antara mereka) untuk pergi (dan mohonkanlah ampunan untuk mereka kepada Allah. Sesungguhnya Allah Maha Pengampun lagi Maha Penyayang).\qt@no{62}}%
\qt@newcmd\qurantrans@id@mmdcccliv{%
(Janganlah kalian jadikan panggilan Rasul di antara kalian seperti panggilan sebagian kalian kepada sebagian yang lain) umpamanya kalian mengatakan, ``Hai Muhammad!" Tetapi ucapkanlah, ``Hai Nabi Allah, hai Rasulullah!" Dengan suara yang lemah lembut dan penuh rendah diri. (Sesungguhnya Allah telah mengetahui orang-orang yang diam-diam pergi di antara kalian dengan sembunyi-sembunyi) mereka keluar dari mesjid pada waktu Nabi mengucapkan khutbahnya tanpa terlebih dahulu meminta izin kepadanya, secara diam-diam sambil menyembunyikan diri di balik sesuatu. Huruf Qad di sini menunjukkan makna Tahqiq yang artinya sesungguhnya (maka hendaklah orang-orang yang menyalahi perintah-Nya merasa takut) menyalahi perintah Allah dan Rasul-Nya (akan ditimpa cobaan) malapetaka (atau ditimpa azab yang pedih) di akhirat kelak.\qt@no{63}}%
\qt@newcmd\qurantrans@id@mmdccclv{%
(Ketahuilah, sesungguhnya kepunyaan Allahlah apa yang di langit dan di bumi) sebagai milik, makhluk dan hamba-Nya. (Sesungguhnya Dia mengetahui keadaan yang kalian) hai orang-orang Mukallaf (berada di dalamnya) apakah kalian beriman atau munafik. (Dan) Dia mengetahui pula (hari manusia dikembalikan kepada-Nya) di dalam ungkapan ini terdapat iltifat dari mukhatab ke ghaib. Maksudnya, bila hal itu akan terjadi (lalu diterangkan-Nya kepada mereka) pada hari itu (apa yang telah mereka kerjakan) yaitu perbuatan baik dan perbuatan buruk yang telah mereka perbuat (Dan Allah terhadap segala sesuatu) terhadap semua perbuatan kalian dan selainnya (Maha Mengetahui.)\qt@no{64}}%
\qt@newcmd\qurantrans@id@mmdccclvi{%
\basmalahid (Maha Suci) Allah swt. (yang telah menurunkan Alfurqan) yakni Alquran, ia dinamakan Alfurqan karena kandungannya membedakan antara perkara yang hak dan perkara yang batil (kepada hamba-Nya) yakni Nabi Muhammad (agar dia menyampaikannya kepada seluruh alam) yaitu kepada bangsa manusia dan bangsa jin, selain bangsa malaikat (sebagai pemberi peringatan) kepada mereka, dengan memperingatkan mereka akan azab Allah.\qt@no{1}}%
\qt@newcmd\qurantrans@id@mmdccclvii{%
(Yang kepunyaan-Nyalah kerajaan langit dan bumi, dan Dia tidak mempunyai anak, dan tidak ada sekutu bagi-Nya dalam kekuasaan-Nya, dan Dia telah menciptakan segala sesuatu) karena hanya Dialah yang mampu menciptakan kesemuanya itu (dan Dia menetapkan ukuran-ukurannya dengan serapi-rapinya) secara tepat dan sempurna.\qt@no{2}}%
\qt@newcmd\qurantrans@id@mmdccclviii{%
(Kemudian mereka mengambil) yang dimaksud adalah orang-orang kafir (selain daripada-Nya) selain Allah swt. (sebagai tuhan-tuhan) berupa berhala-berhala (yang mereka tidak menciptakan apa pun, bahkan mereka sendiri diciptakan dan tidak kuasa untuk menolak sesuatu kemudaratan dari dirinya) tidak akan mampu menolak bahaya yang mengancam dirinya (dan tidak pula untuk mengambil suatu manfaat pun) artinya tidak dapat menghasilkan manfaat bagi dirinya (dan juga tidak kuasa mematikan, menghidupkan) yakni tidak mampu mematikan seseorang dan tidak pula mampu menghidupkannya (dan tidak pula membangkitkan) tidak mampu membangkitkan orang-orang yang mati untuk dapat hidup kembali.\qt@no{3}}%
\qt@newcmd\qurantrans@id@mmdccclix{%
(Dan orang-orang kafir berkata, ``Sesungguhnya ini) Alquran ini (tidak lain hanyalah kebohongan-kebohongan) yakni kedustaan (yang diada-adakan olehnya) oleh Muhammad sendiri (dan dia dibantu oleh kaum yang lain) yakni oleh sebagian dari orang-orang ahli kitab. Allah berfirman: (Maka sesungguhnya mereka telah berbuat suatu kelaliman dan dusta yang besar") yakni kekafiran dan kedustaan.\qt@no{4}}%
\qt@newcmd\qurantrans@id@mmdccclx{%
(Dan mereka berkata,) pula bahwa Alquran itu ("Dongengan-dongengan orang-orang dahulu) yakni kedustaan-kedustaan mereka. Lafal Asaathiir adalah bentuk jamak dari lafal Usthuurah (dimintanya supaya dituliskan) telah menukilnya dari kaum tersebut melalui orang lain (maka dibacakanlah dongengan itu kepadanya) supaya ia hafal (setiap pagi dan petang.") Kemudian Allah berfirman menyanggah ucapan mereka:\qt@no{5}}%
\qt@newcmd\qurantrans@id@mmdccclxi{%
(Katakanlah! ``Alquran ini diturunkan oleh Allah yang mengetahui rahasia) hal-hal yang gaib (di langit dan di bumi. Sesungguhnya Dia adalah Maha Pengampun) kepada orang-orang yang beriman (lagi Maha Penyayang") kepada mereka.\qt@no{6}}%
\qt@newcmd\qurantrans@id@mmdccclxii{%
(Dan mereka berkata, ``Mengapa Rasul ini memakan makanan dan berjalan di pasar-pasar? Mengapa tidak) (diturunkan kepadanya Malaikat, agar Malaikat itu memberikan peringatan bersama dengan dia?) maksudnya yang membenarkan kerasulannya.\qt@no{7}}%
\qt@newcmd\qurantrans@id@mmdccclxiii{%
(Atau mengapa tidak diturunkan kepadanya perbendaharaan) dari langit yang kemudian ia membelanjakannya, sehingga ia tidak usah berjalan-jalan di pasar lagi untuk mencari penghidupan (atau mengapa tidak ada kebun baginya) yaitu ladang yang menjadi miliknya (yang dapat dia makan dari hasilnya") buah-buahannya, sehingga hal itu menjadi kecukupan baginya. Menurut qiraat yang lain dibaca Na'kulu Minhaa, artinya; yang kami dapat ikut makan dari kebunnya. Maksudnya, supaya memiliki kelebihan di atas kami. (Dan orang-orang yang zalim itu berkata:) orang-orang kafir itu kepada orang-orang Mukmin, ("Tidak lain kamu sekalian hanyalah mengikuti seorang lelaki yang kena sihir") orang yang akalnya tidak waras karena pengaruh sihir. Maka Allah berfirman pada ayat selanjutnya:\qt@no{8}}%
\qt@newcmd\qurantrans@id@mmdccclxiv{%
(Perhatikanlah, bagaimana mereka membuat perumpamaan-perumpamaan tentang kamu) dengan julukan sebagai orang yang kena pengaruh sihir, orang yang membutuhkan nafkah, orang yang harus ditemani oleh Malaikat yang bersama-sama menyampaikan tugasnya (lalu sesatlah mereka) dari petunjuk disebabkan ucapannya itu (mereka tidak sanggup mendapatkan jalan untuk menentang kerasulannya) maksudnya mereka tidak akan dapat menemukan jalan untuk menentangnya.\qt@no{9}}%
\qt@newcmd\qurantrans@id@mmdccclxv{%
(Maha Agung Allah) Maha Kaya akan kebaikan (yang jika Dia menghendaki, niscaya dijadikan-Nya bagimu yang lebih baik dari yang demikian) yakni lebih baik daripada perbendaharaan harta dan kebun yang mereka mintakan di dunia ini (yaitu surga-surga yang di bawahnya mengalir sungai-sungai) karena Dia telah menjanjikan akan memberikan kepadanya nanti di akhirat (dan dijadikan-Nya pula) lafal ayat ini dibaca Jazm (untukmu istana-istana) dan menurut qiraat yang lain, lafal Yaj'al dibaca Yaj'alu sehingga kedudukannya menjadi kalimat Isti'naf, atau kalimat baru.\qt@no{10}}%
\qt@newcmd\qurantrans@id@mmdccclxvi{%
(Bahkan mereka mendustakan hari kiamat) hari terakhir yang tiada hari lagi sesudahnya. (Dan Kami menyediakan neraka yang menyala-nyala bagi siapa yang mendustakan hari kiamat) neraka yang apinya menyala-nyala dengan nyala yang besar.\qt@no{11}}%
\qt@newcmd\qurantrans@id@mmdccclxvii{%
(Apabila neraka itu melihat mereka dari tempat yang jauh, mereka mendengar kegeramannya) yakni suara mendidihnya seperti halnya orang yang sedang marah (dan suara nyalanya) suara yang keras sekali dari nyala apinya. Atau makna yang dimaksud adalah jika orang-orang tersebut melihat neraka sekalipun dari tempat yang jauh, mereka akan mendengar suara gemuruh dan nyala apinya.\qt@no{12}}%
\qt@newcmd\qurantrans@id@mmdccclxviii{%
(Dan apabila mereka dicampakkan ke tempat yang sempit di neraka itu) dapat dibaca Dhayyiqan dengan memakai harakat Tasydid pada huruf Ya, dapat pula dibaca Takhfif atau tanpa Tasydid sehingga bacaannya menjadi Dhayqan, maksudnya neraka itu menghimpit mereka. Lafal Minhaa berkedudukan menjadi Hal dari lafal Makaanan, karena pada asalnya ia adalah kata sifat baginya (dengan dibelenggu) yakni tangan dan leher mereka dibelenggu menjadi satu; harakat Tasydid yang ada pada lafal Muqarraniina menunjukkan makna Taktsir atau banyak (mereka di sana mengharapkan kebinasaan) maksudnya mereka ingin mati saja karena pedihnya siksaan. Dikatakan oleh Allah swt. kepada mereka,\qt@no{13}}%
\qt@newcmd\qurantrans@id@mmdccclxix{%
("Janganlah kamu sekalian mengharapkan satu kebinasaan, melainkan harapkanlah kebinasaan yang banyak") sesuai dengan azab yang menimpa kalian ini.\qt@no{14}}%
\qt@newcmd\qurantrans@id@mmdccclxx{%
(Katakanlah! ``Apa yang demikian itukah) hal yang telah disebutkan itukah, yaitu ancaman dan gambaran tentang neraka (yang baik, atau surga yang kekal yang telah dijanjikan) (kepada orang-orang yang bertakwa?" Surga itu untuk mereka) menurut ilmu Allah (sebagai balasan) sebagai pahala (dan tempat kembali) tempat menetap yang abadi.\qt@no{15}}%
\qt@newcmd\qurantrans@id@mmdccclxxi{%
(Bagi mereka di dalam surga itu apa yang mereka kehendaki, sedangkan mereka kekal) lafal Khaalidiina menjadi Hal yang bersifat Lazimah atau harus (adalah) janji mereka seperti yang telah disebutkan tadi (janji dari Rabbmu yang patut dimohonkan kepada-Nya) artinya orang yang telah dijanjikan kepadanya hal itu patut untuk memohon kepada-Nya, sebagaimana yang diungkapkan oleh firman-Nya yang lain, yaitu, ``Ya Rabb kami! Berilah kami apa yang telah Engkau janjikan kepada kami dengan perantaraan rasul-rasul Engkau." (Q.S. Ali Imran, 194) atau hal itu dimintakan oleh para Malaikat buat mereka, sebagaimana yang diungkapkan oleh firman-Nya yang lain, yaitu, ``Ya Rabb kami! Masukkanlah mereka ke dalam surga Adn yang telah Engkau janjikan-kepada mereka." (Q.S. Al Mukmin, 8).\qt@no{16}}%
\qt@newcmd\qurantrans@id@mmdccclxxii{%
(Dan pada suatu hari ketika Allah menghimpunkan mereka) lafal Yahsyuruhum dapat pula dibaca Nahsyuruhum, sehingga artinya menjadi, Kami menghimpun mereka (beserta apa yang mereka sembah selain Allah) yakni seperti malaikat; Nabi Isa, dan Nabi Uzair, serta jin (lalu Allah berkata:) kepada mereka yang disembah untuk memantapkan hujah-Nya terhadap orang-orang yang menyembah mereka. Lafal Fayaquulu dapat pula dibaca Fanaquulu, artinya, Kami berkata, ("Apakah kalian) lafal A-antum dapat dibaca secara Tahqiq yaitu dengan menyatakan kedua Hamzahnya, dan dapat pula dibaca Tas-hil yaitu dengan menggantikan Hamzah yang kedua menjadi Alif sehingga bacaan Hamzahnya menjadi panjang, dapat pula dibaca pendek yakni tanpa memakai Alif (yang menyesatkan hamba-hamba-Ku itu) artinya apakah kalian telah menjerumuskan mereka ke dalam kesesatan dengan perintah kalian kepada mereka, supaya mereka menyembah kalian? (atau mereka sendirilah yang sesat dari jalan yang benar?") yakni atas kehendak mereka sendiri.\qt@no{17}}%
\qt@newcmd\qurantrans@id@mmdccclxxiii{%
(Mereka yang disembah itu menjawab, ``Maha Suci Engkau,) dari apa yang tidak layak bagi Engkau (tidaklah patut) tidaklah dibenarkan (bagi kami mengambil selain Engkau) (untuk jadi pelindung) lafal Min Auliyaa berkedudukan menjadi Maf'ul pertama, sedangkan huruf Min adalah Zaidah yang berfungsi mengukuhkan makna Nafi. Lafal sebelumnya berkedudukan menjadi Maf'ul kedua. Maksudnya, mana mungkin kami memerintahkan mereka untuk menyembah kami (akan tetapi Engkau telah memberi mereka dan bapak-bapak mereka kenikmatan hidup) sebelumnya yaitu di dunia, dengan umur yang panjang dan rezeki yang luas. (Sampai mereka lupa akan peringatan) yakni nasihat dan iman kepada Alquran (dan mereka adalah kaum yang binasa.") Allah berfirman:\qt@no{18}}%
\qt@newcmd\qurantrans@id@mmdccclxxiv{%
("Maka sesungguhnya mereka yang disembah itu telah mendustakan kalian) yang disembah itu berdusta kepada mereka yang menyembahnya (tentang apa yang kalian katakan) bahwasanya mereka adalah tuhan-tuhan (maka kalian tidak akan dapat) kalau dibaca yastathii'uuna artinya maka mereka tidak akan dapat; maksudnya baik mereka atau pun kalian (menolak) azab dari diri kalian (dan tidak pula menolong) mencegah azab yang menimpa diri kalian (dan barang siapa berbuat zalim) dengan memperbuat kemusyrikan (di antara kalian, niscaya Kami rasakan kepadanya azab yang besar) azab yang keras di akhirat.\qt@no{19}}%
\qt@newcmd\qurantrans@id@mmdccclxxv{%
(Dan Kami tidak mengutus rasul-rasul sebelum kamu, melainkan mereka sungguh memakan makanan dan berjalan di pasar-pasar) maka kamu adalah sama seperti mereka dalam hal ini. Maksudnya, telah dikatakan pula hal yang serupa terhadap mereka, sebagaimana apa yang dikatakan kepadamu sekarang ini. (Dan Kami jadikan sebagian kalian cobaan bagi sebagian yang lain) yakni orang yang kaya dicoba dengan adanya orang fakir dan orang yang sehat dicoba dengan adanya orang yang sakit, dan orang yang terhormat dicoba dengan adanya orang yang rendah. Maka golongan yang kedua dari orang-orang tadi mengatakan, 'Mengapa aku tidak seperti dia dalam segala hal?' (Maukah kalian bersabar?) di dalam menghadapi perkataan yang kalian dengar dari orang-orang yang kalian mendapat cobaan dari mereka. Istifham atau kata tanya di sini mengandung arti perintah, maksudnya bersabarlah kalian (dan adalah Rabbmu Maha Melihat") terhadap orang-orang yang sabar dan yang tidak sabar.\qt@no{20}}%
\qt@newcmd\qurantrans@id@mmdccclxxvi{%
(Berkatalah orang-orang yang tidak menanti-nanti pertemuannya dengan Kami,) yakni orang-orang yang tidak takut kepada adanya hari berbangkit dan hari pembalasan ("Mengapakah tidak) (diturunkan kepada kita malaikat) yang menjadi Rasul-rasul kepada kita (atau mengapa kita tidak melihat Rabb kita?") kemudian kita diberi tahu, bahwa Muhammad adalah Rasul-Nya. Lalu Allah berfirman, ("Sesungguhnya mereka memandang besar) merasa besar (tentang diri mereka dan mereka telah melampaui batas) berlaku sangat kurang ajar (dengan kelewat batas yang sangat besar) disebabkan mereka berani meminta melihat Allah swt. di dunia. Lafal 'Atauw dengan memakai huruf Wau sesuai dengan kata asalnya, berbeda dengan lafal 'Ataa yang huruf akhirnya telah diganti menjadi Ya, seperti dalam surah Maryam.\qt@no{21}}%
\qt@newcmd\qurantrans@id@mmdccclxxvii{%
(Pada hari mereka melihat Malaikat) di antara makhluk-makhluk Allah yang lainnya, yaitu pada hari kiamat. Lafal Yauma dinashabkan oleh lafal Udzkur, yang keberadaannya diperkirakan sebelumnya; maksudnya, ingatlah pada hari mereka melihat Malaikat (di hari itu tidak ada kabar gembira bagi orang-orang yang berdosa) yakni orang-orang kafir, berbeda keadaannya dengan orang-orang Mukmin, bagi mereka kabar gembira yaitu mendapatkan surga (dan mereka berkata: 'Hijran mahjuuran'") sebagaimana kebiasaan mereka di dunia apabila mereka tertimpa kesengsaraan, artinya: lindungilah kami di tempat perlindungan. Mereka pada hari itu meminta perlindungan kepada Malaikat. Kemudian Allah berfirman,\qt@no{22}}%
\qt@newcmd\qurantrans@id@mmdccclxxviii{%
("Dan Kami hadapi) kami hadapkan (segala amal yang mereka kerjakan) amal kebaikan seperti sedekah, menghubungkan silaturahmi, menjamu tamu dan menolong orang yang memerlukan pertolongan sewaktu di dunia (lalu Kami jadikan amal itu bagaikan debu yang beterbangan.") amal perbuatan mereka tidak bermanfaat sama sekali pada hari itu, tidak ada pahalanya sebab syaratnya tak terpenuhi, yaitu iman, akan tetapi mereka telah mendapatkan balasannya selagi mereka di dunia.\qt@no{23}}%
\qt@newcmd\qurantrans@id@mmdccclxxix{%
(Penghuni-penghuni surga pada hari itu) di hari kiamat (paling baik tempat tinggalnya) lebih baik daripada tempat tinggal orang-orang kafir sewaktu di dunia (dan paling indah tempat istirahatnya) lebih indah daripada tempat istirahat mereka sewaktu di dunia. Lafal Maqiila artinya tempat untuk beristirahat di tengah hari yang panas. Kemudian dari pengertian ini dapat diambil kesimpulan makna tentang selesainya masa perhitungan amal perbuatan, yaitu di waktu tengah hari, hanya memakan waktu setengah hari, seperti yang telah disebutkan di dalam hadis.\qt@no{24}}%
\qt@newcmd\qurantrans@id@mmdccclxxx{%
(Dan ingatlah di hari ketika langit pecah) yaitu semua langit (mengeluarkan kabut) seraya mengeluarkan kabut yang berwarna putih (dan diturunkan Malaikat) dari setiap lapisan langit (bergelombang-gelombang) pada hari kiamat itu. Dinashabkannya lafal Yauma karena pada sebelumnya diperkirakan ada lafal Udzkur. Menurut qiraat yang lain lafal Tasyaqqaqu dibaca Tasysyaqqaqu dengan ditasydidkannya huruf Syin yang diambil dari asal kata Tatasyaqqaqu. Kemudian huruf Ta yang kedua diganti menjadi Syin lalu diidgamkan kepada Syin yang kedua sehingga menjadi Tasysyaqqaqu. Sedangkan menurut qiraat yang lainnya lagi lafal Nuzzila dibaca Nunzilu dan lafal Al Malaaikatu dibaca Al Malaaikata, sehingga bacaan lengkapnya menurut qiraat ini menjadi Nunzilul Malaaikata, artinya, Kami menurunkan Malaikat-malaikat.\qt@no{25}}%
\qt@newcmd\qurantrans@id@mmdccclxxxi{%
(Kerajaan yang hak pada hari itu adalah kepunyaan Allah Yang Maha Pemurah) tiada seorang pun yang menyaingi-Nya dalam hal ini. (Dan adalah) hari itu (satu hari yang penuh kesukaran bagi orang-orang kafir) berbeda dengan keadaan orang-orang yang beriman.\qt@no{26}}%
\qt@newcmd\qurantrans@id@mmdccclxxxii{%
(Dan ingatlah hari ketika itu orang yang zalim) orang musyrik, yaitu Uqbah bin Mu'ith yang pernah membaca dua kalimat syahadat, kemudian ia menjadi murtad demi mengambil hati Ubay bin Khalaf (menggigit dua tangannya) karena menyesal dan kecewa, di hari kiamat (seraya berkata, ``Aduhai!) huruf Ya menunjukkan makna penyesalan (Kiranya dahulu aku mengambil bersama Rasul) yakni Nabi Muhammad (jalan) petunjuk.\qt@no{27}}%
\qt@newcmd\qurantrans@id@mmdccclxxxiii{%
(Kecelakaan besar bagiku) huruf Alif dari lafal Yaa Wailataa merupakan pergantian Ya Idhafah, asalnya adalah Yaa Wailatii maknanya alangkah binasanya aku (kiranya aku dahulu tidak menjadikan si Polan itu) yakni Ubay bin Khalaf yang dijilatnya tadi (teman akrab).\qt@no{28}}%
\qt@newcmd\qurantrans@id@mmdccclxxxiv{%
(Sesungguhnya dia telah menyesatkan aku dari peringatan) Alquran (sesudah peringatan itu datang kepadaku") karena dialah yang menjadikan aku murtad dan tidak beriman lagi kepada Alquran. Kemudian Allah berfirman, ("Dan adalah setan itu terhadap manusia) yang kafir (selalu membuat kecewa.") karena ia akan meninggalkannya begitu saja, cuci tangan bilamana manusia tertimpa malapetaka.\qt@no{29}}%
\qt@newcmd\qurantrans@id@mmdccclxxxv{%
(Berkatalah Rasul) Nabi Muhammad, ("Ya Rabbku! Sesungguhnya kaumku) kabilah Quraisy (menjadikan Alquran ini suatu yang diasingkan") ditinggal begitu saja. Maka Allah swt. berfirman,\qt@no{30}}%
\qt@newcmd\qurantrans@id@mmdccclxxxvi{%
("Dan seperti itulah) sebagaimana Kami telah menjadikan bagimu musuh dari kalangan orang-orang musyrik kaummu sendiri (Kami adakan bagi tiap-tiap Nabi) sebelum kamu (musuh dari orang-orang yang berdosa) yakni orang-orang musyrik maka bersabarlah sebagaimana mereka bersabar. (Dan cukuplah Rabbmu menjadi Pemberi petunjuk) bagimu (dan Penolong") yang menolong kamu terhadap musuh-musuhmu.\qt@no{31}}%
\qt@newcmd\qurantrans@id@mmdccclxxxvii{%
(Berkatalah orang-orang yang kafir, ``Mengapa tidak) (diturunkan kepadanya Alquran sekali turun saja?") sebagaimana kitab Taurat, kitab Injil dan kitab Zabur. Allah menjawab melalui firman-Nya, ``Kami sengaja menurunkannya (demikian) secara terpisah-pisah (supaya Kami perkuat hatimu dengannya) Kami menguatkan kalbumu dengan Alquran (dan Kami membacakannya kelompok demi kelompok") Kami menurunkannya tahap demi tahap secara perlahan dan tidak tergesa-gesa, supaya mudah dipahami dan dihafal.\qt@no{32}}%
\qt@newcmd\qurantrans@id@mmdccclxxxviii{%
(Tidaklah orang-orang kafir itu datang kepadamu membawa sesuatu yang ganjil) untuk membatalkan perkaramu (melainkan Kami datangkan kepadamu suatu yang benar) yang menolak dan membantahnya (dan yang paling baik penjelasannya) untuk menjelaskan perkara yang sebenarnya kepada mereka.\qt@no{33}}%
\qt@newcmd\qurantrans@id@mmdccclxxxix{%
Mereka adalah (orang-orang yang dihimpunkan dengan diseret atas muka-muka mereka) mereka digiring seraya diseret (ke neraka Jahanam, mereka itulah orang-orang yang paling buruk tempatnya) yaitu neraka Jahanam (dan paling sesat jalannya) paling keliru jalannya bila dibandingkan dengan selain mereka, sebab kekafirannya.\qt@no{34}}%
\qt@newcmd\qurantrans@id@mmdcccxc{%
(Dan sesungguhnya Kami telah memberikan kepada Musa kitab) Taurat (dan Kami telah menjadikan Harun saudaranya, menyertai dia sebagai wazir) yang membantunya di dalam menyampaikan tugas risalahnya.\qt@no{35}}%
\qt@newcmd\qurantrans@id@mmdcccxci{%
(Kemudian Kami berfirman kepada keduanya, ``Pergilah kamu berdua kepada kaum yang mendustakan ayat-ayat Kami") yakni bangsa Koptik, Firaun dan kaumnya, lalu keduanya berangkat ke negeri mereka, akan tetapi mereka mendustakannya. (Maka Kami membinasakan mereka sehancur-hancurnya) Kami menumpas mereka sampai binasa.\qt@no{36}}%
\qt@newcmd\qurantrans@id@mmdcccxcii{%
(Dan) ingatlah (kaum Nuh tatkala mereka mendustakan Rasul-rasul) mereka mendustakan Nabi Nuh, mengingat Nabi Nuh tinggal bersama mereka dalam kurun waktu yang lama sekali, maka diungkapkan dalam ayat ini seolah-olah Nabi Nuh menduduki tempat Rasul-rasul. Atau karena dengan mendustakan Nabi Nuh maka seolah-olah mereka mendustakan Rasul-rasul lainnya yang membawa risalah yang sama dengan apa yang dibawa oleh Nabi Nuh, yaitu ajaran Tauhid (Kami tenggelamkan mereka) lafal ayat ini menjadi jawab dari Lamma (dan Kami jadikan cerita mereka bagi manusia) sesudah mereka (sebagai tanda) pelajaran (dan Kami telah menyediakan) di akhirat (untuk orang-orang yang zalim) yakni orang-orang kafir (azab yang pedih) siksaan yang sangat menyakitkan di samping azab yang telah mereka rasakan sewaktu hidup di dunia.\qt@no{37}}%
\qt@newcmd\qurantrans@id@mmdcccxciii{%
(Dan) ingatlah (kaum Ad) yakni kaum Nabi Hud (dan Tsamud) kaum Nabi Saleh (dan penduduk Rass) nama sebuah sumur; Nabi mereka menurut suatu pendapat adalah Nabi Syuaib, tetapi menurut pendapat yang lain bukan Nabi Syuaib. Mereka tinggal di sekitar sumur itu, kemudian sumur itu amblas berikut orang-orang yang tinggal di sekitarnya dan rumah-rumah mereka pun ikut amblas (dan banyak lagi generasi-generasi) kaum-kaum (di antara kaum-kaum tersebut) yakni antara kaum Ad dan penduduk Rass.\qt@no{38}}%
\qt@newcmd\qurantrans@id@mmdcccxciv{%
(Dan Kami jadikan bagi masing-masing mereka tamsil) untuk menegakkan hujah terhadap mereka, oleh karenanya tidak sekali-kali Kami membinasakan mereka melainkan sesudah mereka Kami beri peringatan (dan masing-masing mereka itu benar-benar telah Kami binasakan dengan sehancur-hancurnya) yakni Kami tumpas mereka hingga binasa, disebabkan mereka telah mendustakan nabi-nabi mereka.\qt@no{39}}%
\qt@newcmd\qurantrans@id@mmdcccxcv{%
(Dan sesungguhnya mereka telah melalui) yakni orang-orang kafir Mekah itu sering melewati (sebuah negeri yang dihujani dengan hujan yang sejelek-jeleknya) lafal As Sau' adalah bentuk Mashdar dari lafal Saa-a. Maksudnya mereka telah dihujani dengan batu-batu; negeri tempat tinggal mereka adalah suatu kota yang paling besar bagi kaum Nabi Luth, kemudian Allah membinasakan mereka sebab mereka gemar melakukan perbuatan yang keji. (Maka apakah mereka tidak menyaksikan bekas-bekasnya) di dalam perjalanan mereka menuju ke negeri Syam, kemudian mereka mengambil pelajaran darinya? Istifham atau kata tanya pada ayat ini mengandung makna Taqrir, maksudnya, hendaklah mereka mengambil pelajaran dari bekas-bekas itu (bahkan adalah mereka itu tidak mengharapkan) mereka tidak takut sama sekali (akan kebangkitan) maksudnya hari mereka dihidupkan kembali, mereka sama sekali tidak beriman kepadanya.\qt@no{40}}%
\qt@newcmd\qurantrans@id@mmdcccxcvi{%
(Dan apabila mereka melihat kamu, maka tidak lain) (mereka menjadikan kamu sebagai ejekan) sasaran ejekan mereka, di dalam ejekannya itu mereka mengatakan, ("Inikah orangnya yang diutus oleh Allah sebagai Rasul?) menurut pengakuannya. Mereka mengatakan demikian dengan nada menghina dan menganggap remeh risalah yang dibawanya.\qt@no{41}}%
\qt@newcmd\qurantrans@id@mmdcccxcvii{%
(Sesungguhnya) lafal In adalah bentuk Takhfif dari lafal Inna, sedangkan isimnya tidak disebutkan, jadi bentuk lengkapnya adalah Innahuu, artinya, sesungguhnya ia (hampirlah ia menyesatkan kita) memalingkan diri kita (dari sesembahan-sesembahan kita, seandainya kita tidak sabar menyembahnya.") niscaya kita dapat dipalingkan dari sesembahan-sesembahan kita olehnya. Maka Allah berfirman, ("Dan mereka kelak akan mengetahui di saat mereka melihat azab) secara terang-terangan kelak di akhirat (siapa yang paling sesat jalannya") yang paling keliru tuntunannya, apakah mereka ataukah orang-orang yang beriman?\qt@no{42}}%
\qt@newcmd\qurantrans@id@mmdcccxcviii{%
(Terangkanlah kepadaku) ceritakanlah kepada-Ku (tentang orang yang menjadikan hawa nafsunya sebagai tuhannya) maksudnya orang-orang yang menurutkan hawa nafsunya; dalam ungkapan ayat ini Maf'ul kedua didahulukan mengingat kedudukannya yang penting, yaitu lafal Ilaahahu. Sedangkan jumlah Manittakhadza Hawaahu adalah Maf'ul Awwal dari lafal Ara-aita, dan Maf'ul yang kedua adalah lafal Ilaahahu yang didahulukan tadi. (Maka apakah kamu dapat menjadi pemeliharanya?) yang dapat memelihara dia untuk tidak mengikuti hawa nafsunya? Tentu saja tidak.\qt@no{43}}%
\qt@newcmd\qurantrans@id@mmdcccxcix{%
(Atau apakah kamu mengira bahwa kebanyakan mereka itu mendengar) dengan pendengaran yang dibarengi dengan pengertian (atau memahami) apa yang kamu katakan kepada mereka. (Tiada lain) (mereka itu hanyalah seperti binatang ternak, bahkan mereka lebih sesat lagi jalannya) daripada binatang ternak itu, karena binatang ternak mau menurut dan patuh kepada penggembalanya, sedangkan mereka tidak mau menaati Pemeliharanya, yaitu Allah, yang telah memberikan kenikmatan kepada mereka.\qt@no{44}}%
\qt@newcmd\qurantrans@id@mmcm{%
(Apakah kamu tidak memperhatikan) yakni tidak melihat (kepada) ciptaan (Rabbmu, bagaimana Dia memanjangkan bayang-bayang) mulai dari tenggelamnya matahari sampai dengan hendak terbitnya (dan kalau Dia menghendaki) yakni Rabbmu (niscaya Dia menjadikan bayang-bayang itu tetap) artinya tidak hilang sekalipun matahari terbit (kemudian Kami jadikan matahari atasnya) yakni bayang-bayang atau gelap itu (sebagai petunjuk) karena seandainya tidak ada matahari maka niscaya bayang-bayang atau gelap itu tidak akan dikenal.\qt@no{45}}%
\qt@newcmd\qurantrans@id@mmcmi{%
(Kemudian Kami menarik bayang-bayang itu) yakni bayang-bayang yang memanjang itu (kepada Kami dengan tarikan yang perlahan-lahan), yaitu dengan terbitnya matahari.\qt@no{46}}%
\qt@newcmd\qurantrans@id@mmcmii{%
(Dialah yang menjadikan untuk kalian malam sebagai pakaian) yakni yang menutupi bagaikan pakaian (dan tidur untuk istirahat) bagi tubuh setelah selesai dari bekerja (dan Dia menjadikan siang untuk bangun berusaha) kalian bangun di waktu itu untuk mencari rezeki dan melakukan pekerjaan-pekerjaan lainnya.\qt@no{47}}%
\qt@newcmd\qurantrans@id@mmcmiii{%
(Dialah yang meniupkan angin) menurut qiraat yang lain lafal Ar-Riih dibaca Ar-Riyah (pembawa kabar gembira dekat sebelum kedatangan rahmat-Nya) yakni dekat sebelum hujan. Lafal Nusyuran menurut suatu qiraat dibaca Nusyran, artinya secara terpisah-pisah yakni dibaca secara Takhfif supaya ringan bacaannya. Menurut qiraat yang lain dibaca Nasyran karena dianggap sebagai Mashdar. Menurut qiraat lainnya lagi dibaca Busyra, artinya sebagai pembawa kabar gembira. Bentuk tunggal bacaan pertama adalah Nusyurun, wazannya sama dengan lafal Rasulun yang bentuk jamaknya adalah Rusulun. Sedangkan bentuk tunggal dari bacaan yang kedua yaitu Busyran ialah Basyirun, artinya pembawa kabar gembira (dan Kami turunkan dan langit air yang amat bersih) yaitu air yang dapat dipakai untuk bersuci, atau air yang menyucikan.\qt@no{48}}%
\qt@newcmd\qurantrans@id@mmcmiv{%
(Agar Kami menghidupkan dengan air itu negeri atau tanah yang mati) lafal Maitan dibaca Takhfif bentuk Mudzakkar dan Muannatsnya sama saja. Disebutkan dengan maksud, bahwa yang mati itu adalah tanah negeri itu (dan agar Kami memberi minum dengannya) dengan air itu (sebagian besar dari makhluk Kami, binatang-binatang ternak) unta, sapi dan kambing (dan manusia yang banyak) lafal Anaasiyyu merupakan bentuk jamak dari lafal Insaanun, bentuk asalnya adalah Anaasiinu, kemudian huruf Nun diganti menjadi Ya, lalu huruf Ya yang pertama diidgamkan kepadanya sehingga jadilah Anaasiyyu. Atau lafal Anaasiyyu ini adalah bentuk jamak dari lafal Insiyyun.\qt@no{49}}%
\qt@newcmd\qurantrans@id@mmcmv{%
(Dan sesungguhnya Kami telah menggilirnya) yakni air hujan itu (di antara manusia supaya mereka mengambil pelajaran daripadanya) Yadzdzakkaruu asalnya Yatadzakkaruu, kemudian huruf Ta diidgamkan kepada huruf Dzal setelah terlebih dahulu diganti menjadi Dzal pula, sehingga jadilah Yadzdzakkaruu. Menurut suatu qiraat dibaca Liyadzkuruu, sehingga artinya menjadi: supaya mereka ingat akan nikmat Allah dengan adanya air tersebut (maka kebanyakan manusia itu tidak mau kecuali mengingkari) nikmat Allah, karena mereka mengatakan bahwa hujan kita ini disebabkan munculnya bintang anu.\qt@no{50}}%
\qt@newcmd\qurantrans@id@mmcmvi{%
(Dan andai kata Kami menghendaki, benar-benarlah Kami utus pada tiap-tiap negeri seorang yang memberi peringatan) untuk mengingatkan penduduknya, akan tetapi Kami mengutus kamu, hai Muhammad, kepada penduduk semua negeri sebagai pemberi peringatan kepada mereka semuanya, supaya pahalamu menjadi besar.\qt@no{51}}%
\qt@newcmd\qurantrans@id@mmcmvii{%
(Maka janganlah kamu mengikuti orang-orang kafir) memperturutkan hawa nafsu mereka (dan berjihadlah terhadap mereka dengannya) dengan Alquran (dengan jihad yang besar).\qt@no{52}}%
\qt@newcmd\qurantrans@id@mmcmviii{%
(Dan Dialah yang membiarkan dua laut mengalir) secara berdampingan (yang ini tawar lagi segar) sangat tawar lagi menyegarkan (dan yang lain asin lagi pahit) asin sekali sehingga rasanya pahit (dan Dia jadikan antara keduanya dinding) batas yang menyebabkan kedua air tersebut tidak membaur, antara yang satu dengan yang lainnya (dan batas yang menghalangi) yakni penghalang yang mencegah keduanya untuk bercampur.\qt@no{53}}%
\qt@newcmd\qurantrans@id@mmcmix{%
(Dan Dia pula yang menciptakan manusia dari air) yakni dari air mani; lafal Basyar adalah sinonim dari lafal Insaan (lalu Dia jadikan manusia itu punya keturunan) punya hubungan nasab (dan mushaharah) punya hubungan mushaharah, misalnya seorang lelaki atau perempuan melakukan perkawinan dengan pasangannya untuk memperoleh keturunan, maka hubungan kekeluargaan dari perkawinan ini dinamakan hubungan Mushaharah (dan adalah Rabbmu Maha Kuasa) untuk menciptakan apa yang dikehendaki-Nya.\qt@no{54}}%
\qt@newcmd\qurantrans@id@mmcmx{%
(Dan mereka menyembah) yakni orang-orang kafir (selain Allah apa yang tidak memberi manfaat kepada mereka) dengan menyembahnya (dan tidak pula memberi mudarat kepada mereka) jika tidak disembah, yang dimaksud adalah berhala-berhala. (Adalah orang kafir itu selalu menentang Rabbnya) selalu membantu setan dengan cara taat kepadanya dan menentang Rabbnya.\qt@no{55}}%
\qt@newcmd\qurantrans@id@mmcmxi{%
(Dan tidaklah Kami mengutus kamu melainkan hanya sebagai pembawa kabar gembira) (dan pemberi peringatan) yang memperingatkan manusia tentang neraka.\qt@no{56}}%
\qt@newcmd\qurantrans@id@mmcmxii{%
(Katakanlah! ``Aku tidak meminta kepada kalian dalam menyampaikan hal ini) yakni menyampaikan apa yang aku diutus untuk menyampaikannya (upah sedikit pun, melainkan) tetapi hanya mengharapkan kepatuhan (orang-orang yang mau mengambil jalan kepada Rabbnya) dengan cara menginfakkan harta bendanya ke jalan keridaan-Nya, maka untuk hal ini aku tidak mencegahnya.\qt@no{57}}%
\qt@newcmd\qurantrans@id@mmcmxiii{%
(Dan bertawakallah kepada Allah Yang Hidup Kekal Yang tidak mati, dan bertasbihlah) seraya (memuji kepada-Nya) yakni, katakanlah, 'Subhanallah Wal Hamdulillah' yang artinya; Maha Suci Allah dan segala puji bagi Allah. (Dan cukuplah Dia Maha Mengetahui dosa hamba-hamba-Nya) lafal Bihi berta'alluq kepada lafal Dzunubi.\qt@no{58}}%
\qt@newcmd\qurantrans@id@mmcmxiv{%
Dia adalah (Yang menciptakan langit dan bumi dan apa yang ada di antara keduanya dalam enam hari) dari hari-hari dunia menurut perkiraan; karena pada masa itu masih belum ada matahari. Akan tetapi jika Dia menghendaki niscaya Dia dapat menciptakan kesemuanya dalam waktu sekejap saja. Sengaja Dia memakai cara ini dengan maksud untuk mengajari makhluk-Nya supaya berlaku perlahan-lahan dan tidak tergesa-gesa dalam segala hal (kemudian Dia berkuasa di atas Arasy) arti kata Arasy menurut istilah bahasa adalah singgasana raja. (yakni Allah Yang Maha Penyayang) lafal Ar-Rahmaan ini berkedudukan menjadi Badal dari Dhamir yang terkandung di dalam lafal Istawaa Makna Istawaa ialah bersemayam, karena ungkapan inilah yang sesuai dengan keagungan dan kebesaran-Nya (maka tanyakanlah) hai manusia (tentang Dia) tentang Allah Yang Maha Pemurah (kepada orang yang mengetahui.") tentang-Nya, dia akan menceritakan kepada-Mu mengenai sifat-sifat-Nya.\qt@no{59}}%
\qt@newcmd\qurantrans@id@mmcmxv{%
(Dan apabila dikatakan kepada mereka) yaitu penduduk Mekah ("Sujudlah kamu sekalian kepada Yang Maha Pemurah", mereka menjawab, ``Siapakah Yang Maha Pemurah itu? Apakah kami akan sujud kepada Tuhan yang kamu perintahkan kami bersujud kepada-Nya?") lafal Ta`muruuna dapat dibaca Ya`muruuna dan yang memerintahkan kepada mereka untuk bersujud adalah Nabi Muhammad. Makna ayat; kami tidak mengetahui-Nya, maka kami tidak mau bersujud kepada-Nya (dan makin menambah mereka) perintah bersujud yang ditujukan kepada mereka itu menambah mereka (semakin jauh) dari iman. Maka Allah swt. berfirman,\qt@no{60}}%
\qt@newcmd\qurantrans@id@mmcmxvi{%
(Maha Suci) yakni Maha Agung (Allah yang telah menjadikan di langit gugusan-gugusan bintang) yang ada dua belas, yaitu: Aries, Taurus, Gemini, Cancer, Leo, Virgo, Libra, Scorpio, Sagitarius, Capricornus, Aquarius dan Pisces. Gugusan-gugusan tersebut merupakan garis edar dari tujuh planet yang beredar, yaitu planet Mars mempunyai Aries dan Scorpio, Gemini dan Virgo, planet Bulan mempunyai Cancer, planet Matahari mempunyai Leo, planet Yupiter mempunyai Sagitarius dan Pisces, planet Uranus mempunyai Capricornus dan Aquarius (dan Dia menjadikan padanya) juga (lampu) yakni matahari (dan bulan yang bercahaya) menurut suatu qiraat lafal Siraajan dibaca Suruujan dengan ungkapan jamak. Arti Muniiran adalah Nayyiraatin yakni yang bercahaya. Sengaja di sini hanya disebutkan bulan di antara planet-planet tersebut karena mengingat keutamaan yang dimilikinya.\qt@no{61}}%
\qt@newcmd\qurantrans@id@mmcmxvii{%
(Dan Dia pula yang menjadikan malam dan siang silih berganti) yakni satu sama lainnya saling silih berganti dengan yang lainnya (bagi orang yang ingin mengambil pelajaran) dapat dibaca Yadzdzakkara dan Yadzkura, yang pembahasannya sebagaimana pada ayat sebelumnya. Yakni, ia ingat akan kebaikan yang tidak dilakukan pada salah satu di antaranya, kemudian ia melakukan pada waktu yang lainnya, sebagai ganti dari apa yang tidak dilakukannya di waktu yang pertama tadi (atau orang yang ingin bersyukur) atas nikmat Rabb yang telah dilimpahkan kepadanya pada dua waktu itu.\qt@no{62}}%
\qt@newcmd\qurantrans@id@mmcmxviii{%
(Dan hamba-hamba Allah Yang Maha Pemurah itu) yakni hamba-hamba-Nya yang baik. Lafal ayat ini dan kalimat sesudahnya, berkedudukan menjadi Mubtada, yaitu sampai dengan firman-Nya, ``Ulaika Yujzauna" dan seterusnya, tanpa ada jumlah lain yang menyisipinya (yaitu orang-orang yang berjalan di atas bumi dengan rendah hati) dengan tenang dan rendah diri (dan apabila orang-orang jahil menyapa mereka) mengajak mereka berbicara mengenai hal-hal yang tidak disukainya (mereka mengucapkan kata-kata yang mengandung keselamatan) perkataan yang menghindarkan diri mereka dari dosa.\qt@no{63}}%
\qt@newcmd\qurantrans@id@mmcmxix{%
(Dan orang-orang yang melalui malam hari dengan bersujud kepada Rabb mereka) lafal Sujjadan merupakan bentuk jamak dari lafal Saajidun (dan berdiri) pada malam harinya mereka mengerjakan salat.\qt@no{64}}%
\qt@newcmd\qurantrans@id@mmcmxx{%
(Dan orang-orang yang berkata, ``Ya Rabb kami! Jauhkanlah azab Jahanam dari kami, sesungguhnya azabnya itu adalah kebinasaan yang kekal") yang abadi.\qt@no{65}}%
\qt@newcmd\qurantrans@id@mmcmxxi{%
(Sesungguhnya ia adalah seburuk-buruk) sejelek-jelek (tempat menetap dan tempat kediaman) yakni Jahanam adalah tempat menetap dan tempat tinggal yang paling buruk.\qt@no{66}}%
\qt@newcmd\qurantrans@id@mmcmxxii{%
(Dan orang-orang yang apabila membelanjakan) hartanya kepada anak-anak mereka (mereka tidak berlebih-lebihan dan tidak pula kikir) dapat dibaca Yaqturuu dan Yuqtiruu, artinya tidak mempersempit perbelanjaannya (dan adalah) nafkah mereka (di antara yang demikian itu) di antara berlebih-lebihan dan kikir (mengambil jalan pertengahan) yakni tengah-tengah.\qt@no{67}}%
\qt@newcmd\qurantrans@id@mmcmxxiii{%
(Dan orang-orang yang tidak menyembah tuhan yang lain beserta Allah dan tidak membunuh jiwa yang diharamkan Allah) membunuhnya (kecuali dengan alasan yang benar, dan tidak berzina, barang siapa yang melakukan demikian itu) yakni salah satu di antara ketiga perbuatan tadi (niscaya dia mendapat pembalasan dosanya) hukumannya.\qt@no{68}}%
\qt@newcmd\qurantrans@id@mmcmxxiv{%
(Yakni akan dilipatkan) menurut qiraat yang lain ia dibaca Yudha'afu dengan ditasydidkan huruf `Ainnya (azab untuknya pada hari kiamat dan dia akan kekal dalam azab itu) Fi'il tadi bila dibaca Jazm yakni Yudha'af dan Yakhlud maka kedudukannya menjadi Badal, jika keduanya dibaca Rafa' yakni Yudha'afu dan Yakhludu berarti keduanya merupakan jumlah Isti'naf (dalam keadaan terhina) lafal Muhaanan berkedudukan menjadi Hal atau keterangan keadaan.\qt@no{69}}%
\qt@newcmd\qurantrans@id@mmcmxxv{%
(Kecuali orang-orang yang bertobat dan mengerjakan amal saleh) dari kalangan mereka (maka kejahatan mereka itu diganti Allah) maksudnya dosa-dosa yang telah disebutkan tadi diganti oleh Allah (dengan kebaikan) di akhirat kelak. (Dan adalah Allah Maha Pengampun lagi Maha Penyayang) Dia tetap bersifat demikian.\qt@no{70}}%
\qt@newcmd\qurantrans@id@mmcmxxvi{%
(Dan orang yang bertobat) dari dosa-dosanya selain dari orang-orang yang telah disebutkan tadi (dan mengerjakan amal saleh, maka sesungguhnya dia bertobat kepada Allah dengan tobat yang sebenar-benarnya) dia kembali kepada-Nya dengan bertobat, maka Dia akan membalasnya dengan kebaikan.\qt@no{71}}%
\qt@newcmd\qurantrans@id@mmcmxxvii{%
(Dan orang-orang yang tidak memberikan persaksian palsu) yakni kesaksian yang dusta dan batil (dan apabila mereka bertemu dengan orang-orang yang mengerjakan perbuatan-perbuatan yang tidak berfaedah) seperti perkataan-perkataan yang buruk dan perbuatan-perbuatan yang lainnya (mereka lalui saja dengan menjaga kehormatan dirinya) mereka berpaling daripadanya.\qt@no{72}}%
\qt@newcmd\qurantrans@id@mmcmxxviii{%
(Dan orang-orang yang apabila diberi peringatan) diberi nasihat dan pelajaran (dengan ayat-ayat Rabb mereka) yakni Alquran (mereka tidak menghadapinya) mereka tidak menanggapinya (sebagai orang-orang yang tuli dan buta) tetapi mereka menghadapinya dengan cara mendengarkannya sepenuh hati dan memikirkan isinya serta mengambil manfaat daripadanya.\qt@no{73}}%
\qt@newcmd\qurantrans@id@mmcmxxix{%
(Dan orang-orang yang berkata, ``Ya Rabb kami! Anugerahkanlah kepada kami istri-istri kami dan keturunan kami) ia dapat dibaca secara jamak sehingga menjadi Dzurriyyaatinaa, dapat pula dibaca secara Mufrad, yakni Dzurriyyatinaa (sebagai penyenang hati kami) artinya kami melihat mereka selalu taat kepada-Mu (dan jadikanlah kami imam bagi orang-orang yang bertakwa.") yakni pemimpin dalam kebaikan.\qt@no{74}}%
\qt@newcmd\qurantrans@id@mmcmxxx{%
(Mereka itulah orang-orang yang dibalasi dengan martabat yang tinggi) di surga kelak (karena kesabaran mereka) di dalam menjalankan taat kepada Allah (dan mereka disambut) dapat dibaca Yulaqqauna dengan memakai Tasydid, sebagaimana dapat pula dibaca Yalqauna (di dalamnya) yakni di surga yang paling tinggi martabatnya itu (dengan penghormatan dan ucapan selamat) dari para Malaikat.\qt@no{75}}%
\qt@newcmd\qurantrans@id@mmcmxxxi{%
(Mereka kekal di dalamnya, surga itulah sebaik-baik tempat menetap dan tempat kediaman) yakni tempat kediaman buat mereka. Lafal Ulaaika dan sesudahnya menjadi Khabar dari lafal 'Ibaadur Rahmaan pada ayat 63 tadi.\qt@no{76}}%
\qt@newcmd\qurantrans@id@mmcmxxxii{%
(Katakanlah,) hai Muhammad kepada penduduk Mekah ("Tiada) lafal Maa bermakna Nafi (mengindahkan) menghiraukan (Rabbku akan kalian melainkan kalau ada ibadah kalian) kepada-Nya di waktu kalian tertimpa kesengsaraan dan musibah, kemudian Dia menghilangkannya dari kalian (padahal sesungguhnya) maksudnya mana mungkin Dia memperhatikan kalian, (sedangkan kalian telah mendustakan) Rasul dan Alquran (karena itu kelak akan ada) azab (yang pasti.") menimpa kalian di akhirat, selain daripada azab yang akan menimpa kalian di dunia. Akhirnya di antara mereka banyak yang terbunuh di dalam perang Badar; jumlah mereka yang terbunuh ada tujuh puluh orang. Sedangkan yang menjadi Jawab dari lafal Laulaa terkandung di dalam pengertian kalimat yang sebelumnya.\qt@no{77}}%
\qt@newcmd\qurantrans@id@mmcmxxxiii{%
\basmalahid (Thaa Siin Miim) hanya Allah saja yang mengetahui maksudnya.\qt@no{1}}%
\qt@newcmd\qurantrans@id@mmcmxxxiv{%
(Inilah) (ayat-ayat Al Kitab) yakni Alquran. Idhafah di sini mengandung makna Min, maksudnya sebagian daripada Alquran (yang menerangkan) perkara yang hak atas perkara yang batil.\qt@no{2}}%
\qt@newcmd\qurantrans@id@mmcmxxxv{%
(Boleh jadi kamu) hai Muhammad (akan membinasakan dirimu) bunuh diri karena sedih, disebabkan (karena mereka tidak) yaitu penduduk Mekah (beriman) lafal La'alla di sini bermakna Isyfaq atau menunjukkan makna rasa kasihan. Maksudnya, kasihanilah dirimu itu, ringankanlah dari kesedihannya.\qt@no{3}}%
\qt@newcmd\qurantrans@id@mmcmxxxvi{%
(Jika Kami kehendaki niscaya Kami menurunkan kepada mereka mukjizat dari langit, maka akan senantiasa) lafal Fazhallat dalam bentuknya yang Madhi ini bermakna Mudhari', artinya: maka akan terus-menerus (kuduk-kuduk mereka tunduk kepadanya) yakni mereka beriman kepadanya. Karena lafal Al A'naaq disifati dengan lafal Al Khudhu'. Sifat tersebut merupakan ciri khas makhluk yang berakal, maka sifat Al A'naaq dijamakkan ke dalam bentuk sebagaimana makhluk yang berakal.\qt@no{4}}%
\qt@newcmd\qurantrans@id@mmcmxxxvii{%
(Dan sekali-kali tidak datang kepada mereka suatu peringatan) yaitu Alquran (yang baru dari Tuhan Yang Maha Pemurah) yang membeberkan rahasia mereka (melainkan mereka selalu berpaling daripadanya).\qt@no{5}}%
\qt@newcmd\qurantrans@id@mmcmxxxviii{%
(Sungguh mereka telah mendustakan) Alquran (maka kelak akan datang kepada mereka kenyataan dari berita-berita) akibat dari apa (yang selalu mereka perolok-olokkan).\qt@no{6}}%
\qt@newcmd\qurantrans@id@mmcmxxxix{%
(Dan apakah mereka tidak memperhatikan) maksudnya tidak memikirkan tentang (bumi, berapakah banyaknya Kami tumbuhkan di bumi itu) alangkah banyaknya (dari bermacam-macam tumbuh-tumbuhan yang baik) jenisnya?\qt@no{7}}%
\qt@newcmd\qurantrans@id@mmcmxl{%
(Sesungguhnya pada yang demikian itu benar-benar terdapat suatu tanda) yang menunjukkan akan kesempurnaan kekuasaan Allah swt. (Dan kebanyakan mereka tidak beriman), menurut ilmu Allah. Imam Sibawaih berpendapat bahwa lafal Kaana di sini adalah Zaidah.\qt@no{8}}%
\qt@newcmd\qurantrans@id@mmcmxli{%
(Dan sesungguhnya Rabbmu benar-benar Dia-iah Yang Maha Perkasa) memiliki keperkasaan untuk membalas orang-orang kafir (lagi Maha Penyayang) terhadap orang-orang yang beriman.\qt@no{9}}%
\qt@newcmd\qurantrans@id@mmcmxlii{%
(Dan) ceritakanlah, hai Muhammad!, kepada kaummu (ketika Rabbmu menyeru Musa) melalui firman-Nya pada malam ketika ia melihat api dan pohon ("Bahwasanya) hendaknya (datangilah kaum yang zalim itu), datanglah kamu kepada mereka sebagai seorang Rasul.\qt@no{10}}%
\qt@newcmd\qurantrans@id@mmcmxliii{%
(Yaitu kaum Firaun) terutama Firaun sendiri, mereka telah berbuat aniaya terhadap diri mereka sendiri dengan kekafiran mereka kepada Allah dan penindasan mereka kepada kaum Bani Israel (mengapa mereka tidak) Istifham di sini bermakna sanggahan (bertakwa?") kepada Allah dengan menaati-Nya,\qt@no{11}}%
\qt@newcmd\qurantrans@id@mmcmxliv{%
(Berkata) Musa, ("Ya Rabbku! Sesungguhnya aku takut bahwa mereka akan mendustakan aku).\qt@no{12}}%
\qt@newcmd\qurantrans@id@mmcmxlv{%
(Dan akan terasa sempit dadaku) karena mereka mendustakan aku (sedangkan lidahku tidak lancar) untuk menyampaikan risalah yang dibebankan kepadaku, karena lisanku pelat (maka utuslah) saudaraku (Harun) bersamaku.\qt@no{13}}%
\qt@newcmd\qurantrans@id@mmcmxlvi{%
(Dan aku berdosa terhadap mereka) disebabkan aku telah membunuh seorang bangsa Kobtik (maka aku takut mereka akan membunuhku") disebabkan aku telah membunuh salah seorang dari mereka.\qt@no{14}}%
\qt@newcmd\qurantrans@id@mmcmxlvii{%
(Berfirman) Allah swt., ("Jangan takut!) mereka tidak akan dapat membunuhmu (Pergilah kamu berdua) yakni kamu dan saudaramu itu; ungkapan ayat ini lebih diprioritaskan kepada Mukhathab, karena pada kenyataannya Nabi Harun pada waktu itu sedang tidak bersamanya (dengan membawa ayat-ayat Kami, sesungguhnya Kami bersamamu mendengarkan.") apa yang kalian katakan dan apa yang dikatakan oleh mereka tentang kalian. Keduanya dianggap seakan-akan orang banyak (bentuk jamak).\qt@no{15}}%
\qt@newcmd\qurantrans@id@mmcmxlviii{%
(Maka datanglah kamu berdua kepada Firaun dan katakanlah olehmu, ``Sesungguhnya kami) yakni kamu berdua ini (adalah Rasul Rabb semesta alam) kepadamu.\qt@no{16}}%
\qt@newcmd\qurantrans@id@mmcmxlix{%
(Hendaklah) hendaknya (lepaskanlah untuk pergi bersama kami) ke negeri Syam (kaum Bani Israel") maka Nabi Musa dan Nabi Harun datang kepada Firaun lalu keduanya mengatakan apa yang telah disebutkan tadi.\qt@no{17}}%
\qt@newcmd\qurantrans@id@mmcml{%
(Berkatalah) Firaun kepada Nabi Musa, ("Bukankah kami telah mengasuhmu di dalam keluarga kami) yakni dalam rumah kami (waktu kamu masih kanak-kanak) semasa kecil, baru saja dilahirkan, tetapi sudah disapih (dan kamu tinggal bersama kami beberapa tahun dari umurmu), selama tiga puluh tahun, pada masa itu Musa berpakaian seperti Firaun dan berkendaraan sebagaimana Firaun, ia dikenal sebagai anak angkat Firaun.\qt@no{18}}%
\qt@newcmd\qurantrans@id@mmcmli{%
(Dan kamu telah berbuat suatu perbuatan yang telah kamu lakukan itu) yaitu membunuh seorang bangsa Kobtik (dan kamu termasuk orang-orang yang tidak tahu membalas budi") yakni termasuk orang-orang yang ingkar terhadap nikmat yang telah kuberikan kepadamu, yaitu dididik dan tidak dijadikan budak.\qt@no{19}}%
\qt@newcmd\qurantrans@id@mmcmlii{%
(Berkatalah) Musa, ("Aku telah melakukannya, sedangkan di waktu itu) pada masa itu (aku termasuk orang-orang yang khilaf) dari apa yang akan diberikan oleh Allah kepadaku sesudahnya, yaitu ilmu dan risalah.\qt@no{20}}%
\qt@newcmd\qurantrans@id@mmcmliii{%
(Lalu aku lari meninggalkan kalian ketika aku takut kepada kalian, kemudian Rabbku memberikan kepadaku hikmah) yakni ilmu (serta Dia menjadikanku salah seorang di antara Rasul-rasul).\qt@no{21}}%
\qt@newcmd\qurantrans@id@mmcmliv{%
(Budi yang kamu limpahkan kepadaku itu) asal lafal Tamunnuhaa adalah Tamunnu Bihaa, maksudnya, yang telah kamu limpahkan kepadaku itu (adalah disebabkan kamu telah memperbudak Bani Israel") kalimat ayat ini merupakan keterangan dari ayat yang sebelumnya, maksudnya, kamu telah menjadikan mereka sebagai budak-budak dan sebagai gantinya kamu tidak memperbudak aku, sesungguhnya kamu tidak memberikan nikmat apa pun dengan perlakuanmu yang demikian itu, karena kamu memperbudak mereka, hal ini adalah perbuatan aniaya. Sebagian Mufassirin ada yang memperkirakan adanya Hamzah Istifham bermakna sanggahan, pada awal perkataan Nabi Musa ini, sehingga lafal Fa'altuha asalnya Afa'altuha.\qt@no{22}}%
\qt@newcmd\qurantrans@id@mmcmlv{%
(Berkata Firaun) kepada Nabi Musa, ("Siapakah Rabb semesta alam itu?") sebagaimana yang telah kamu katakan itu, bahwa kamu adalah Rasul-Nya? Maksudnya, siapakah Dia itu? Karena mengingat bahwa tiada jalan bagi makhluk untuk mengetahui hakikat Allah swt. melainkan hanya melalui sifat-sifat-Nya. Nabi Musa a.s. mengemukakan jawabannya kepada Firaun dengan ungkapan berikut.\qt@no{23}}%
\qt@newcmd\qurantrans@id@mmcmlvi{%
(Musa menjawab, ``Rabb Pencipta langit dan bumi dan apa-apa yang ada di antara keduanya) yakni Dialah yang menciptakan kesemuanya itu (jika kamu sekalian orang-orang yang mempercayai.") bahwa Dia adalah yang menciptakan semuanya, maka berimanlah kalian kepada-Nya dan esakanlah Dia.\qt@no{24}}%
\qt@newcmd\qurantrans@id@mmcmlvii{%
(Berkata) Firaun (kepada orang-orang sekelilingnya,) dari kalangan orang-orang terpandang kaumnya ("Apakah kaian tidak mendengarkan?") jawabannya yang tidak sesuai dengan pertanyaannya itu.\qt@no{25}}%
\qt@newcmd\qurantrans@id@mmcmlviii{%
(Berkata pula) Musa, ("Rabb kalian dan Rabb nenek moyang kalian yang dahulu") jawaban Nabi Musa kali ini sekali pun isinya telah terkandung pada jawaban yang pertama tadi tetapi membuat Firaun naik pitam. Oleh sebab itu,\qt@no{26}}%
\qt@newcmd\qurantrans@id@mmcmlix{%
(Firaun berkata, ``Sesungguhnya Rasul kalian yang diutus kepada kamu sekalian benar-benar orang gila").\qt@no{27}}%
\qt@newcmd\qurantrans@id@mmcmlx{%
(Berkata) Musa, ("Rabb yang menguasai Timur dan Barat dan apa yang di antara keduanya -itulah Rabb kalian, jika kalian mempergunakan akal") maka berimanlah kepada-Nya, dan esakanlah Dia.\qt@no{28}}%
\qt@newcmd\qurantrans@id@mmcmlxi{%
(Berkatalah) Firaun kepada Nabi Musa, ("Sungguh jika kamu menyembah Tuhan selain aku, benar-benar aku akan menjadikan kamu salah seorang yang dipenjarakan") penjara di masa Firaun sangat mengerikan keadaannya, karena seseorang ditahan di suatu tempat di bawah tanah dalam keadaan menyendiri, sehingga tidak dapat melihat apa-apa dan tidak dapat mendengar suara seorang manusia pun.\qt@no{29}}%
\qt@newcmd\qurantrans@id@mmcmlxii{%
(Musa berkata) kepada Firaun, ("Dan apakah kamu akan melakukan itu kendati pun) maksudnya apakah sungguh kamu akan melakukannya sekalipun (aku datang kepadamu dengan membawa sesuatu keterangan yang nyata) berupa bukti yang jelas yang menunjukkan kerasulanku."\qt@no{30}}%
\qt@newcmd\qurantrans@id@mmcmlxiii{%
(Firaun berkata) kepada Nabi Musa, ("Datangkanlah sesuatu keterangan yang nyata itu, jika kamu termasuk orang-orang yang benar") di dalam pengakuanmu itu.\qt@no{31}}%
\qt@newcmd\qurantrans@id@mmcmlxiv{%
(Maka Musa melemparkan tongkatnya, lalu tiba-tiba tongkat itu menjadi ular yang nyata) ular raksasa.\qt@no{32}}%
\qt@newcmd\qurantrans@id@mmcmlxv{%
(Dan ia menarik tangannya) mengeluarkannya dari kantong bajunya (maka tiba-tiba tangan itu jadi putih) memancarkan sinar (bagi orang-orang yang melihatnya) berbeda dengan keadaan warna kulit tangan sebelumnya.\qt@no{33}}%
\qt@newcmd\qurantrans@id@mmcmlxvi{%
(Berkata) Firaun (kepada pembesar-pembesar yang ada di sekelilingnya, ``Sesungguhnya Musa ini benar-benar seorang ahli sihir yang pandai) yakni orang yang unggul di dalam ilmu sihir.\qt@no{34}}%
\qt@newcmd\qurantrans@id@mmcmlxvii{%
(Ia hendak mengusir kalian dari negeri kalian dengan sihirnya; maka karena itu apakah yang kalian anjurkan?").\qt@no{35}}%
\qt@newcmd\qurantrans@id@mmcmlxviii{%
(Mereka menjawab, ``Tundalah urusan dia dan saudaranya) tangguhkanlah urusan keduanya (dan kirimkanlah ke seluruh negeri orang-orang yang akan mengumpulkan) menghimpun para ahli sihir.\qt@no{36}}%
\qt@newcmd\qurantrans@id@mmcmlxix{%
(Niscaya mereka akan mendatangkan semua ahli sihir yang pandai kepadamu") yang kepandaiannya melebihi Musa dalam ilmu sihir.\qt@no{37}}%
\qt@newcmd\qurantrans@id@mmcmlxx{%
(Lalu dikumpulkanlah ahli-ahli sihir pada waktu yang ditetapkan di hari yang maklum) yaitu pada waktu matahari mencapai sepenggalah atau waktu dhuha di hari raya mereka.\qt@no{38}}%
\qt@newcmd\qurantrans@id@mmcmlxxi{%
(Dan dikatakan kepada orang banyak, ``Berkumpullah kamu sekalian).\qt@no{39}}%
\qt@newcmd\qurantrans@id@mmcmlxxii{%
(Semoga kita mengikuti ahli-ahli sihir jika mereka adalah orang-orang yang menang") Istifham pada ayat sebelumnya mengandung makna anjuran untuk berkumpul; sedangkan pengertian Tarajji atau harapan di sini bergantung kepada kemenangan para ahli sihir, dimaksud supaya mereka tetap menjalankan tradisi agama mereka dan tidak mengikuti ajaran Nabi Musa.\qt@no{40}}%
\qt@newcmd\qurantrans@id@mmcmlxxiii{%
(Maka tatkala ahIi-ahli sihir datang, mereka pun bertanya kepada Firaun, ``Apakah sungguh-sungguh) lafal A-inna dapat dibaca secara Tahqiq dan Tas-hil; kalau dibaca Tahqiq bacaannya menjadi A-inna dan kalau dibaca Tas-hil menjadi Ayinna (kami mendapat upah yang besar jika kami adalah orang-orang yang menang?").\qt@no{41}}%
\qt@newcmd\qurantrans@id@mmcmlxxiv{%
(Firaun menjawab, ``Ya, kalau demikian, sesungguhnya kamu sekalian) pada saat kalian menang (benar-benar akan menjadi orang yang didekatkan kepadaku").\qt@no{42}}%
\qt@newcmd\qurantrans@id@mmcmlxxv{%
(Berkatalah Musa kepada mereka) sesudah mereka berkata kepadanya, sebagaimana yang disitir oleh firman-Nya yang lain, yaitu, ``Kamukah yang akan melemparkan lebih dahulu, ataukah kami yang akan melemparkan?" (Q.S. 7 Al A'raf, 115). ("Jatuhkanlah apa yang hendak kalian jatuhkan") perintah ini merupakan izin dari Nabi Musa kepada mereka supaya mereka lebih dahulu melemparkan apa yang hendak mereka lemparkan, dimaksudkan supaya lebih menonjolkan perkara yang hak.\qt@no{43}}%
\qt@newcmd\qurantrans@id@mmcmlxxvi{%
(Lalu mereka menjatuhkan tali-temali dan tongkat-tongkat mereka, dan mengatakan, ``Demi kekuasaan Firaun, sesungguhnya kami benar-benar akan menang").\qt@no{44}}%
\qt@newcmd\qurantrans@id@mmcmlxxvii{%
(Kemudian Musa menjatuhkan tongkatnya, tiba-tiba ia menelan) lafal Talqafu ini bentuk asalnya adalah Taltaqafu, kemudian salah satu dari huruf Ta dibuang sehingga menjadi Talqafu, artinya menelan bulat-bulat (benda-benda palsu yang mereka ada-adakan itu) yang mereka sulap dengan ilmu sihir mereka, sehingga tampak seolah-olah tali-temali dan tongkat-tongkat mereka itu berupa ular-ular yang merayap.\qt@no{45}}%
\qt@newcmd\qurantrans@id@mmcmlxxviii{%
(Maka tersungkurlah ahli-ahli sihir sambil bersujud) kepada Allah.\qt@no{46}}%
\qt@newcmd\qurantrans@id@mmcmlxxix{%
(Mereka berkata, ``Kami beriman kepada Rabb semesta alam).\qt@no{47}}%
\qt@newcmd\qurantrans@id@mmcmlxxx{%
(Yaitu Rabb Musa dan Harun") karena mereka mengetahui, bahwa apa yang mereka saksikan dari tongkat Nabi Musa itu bukanlah sihir sebagaimana perbuatan mereka.\qt@no{48}}%
\qt@newcmd\qurantrans@id@mmcmlxxxi{%
(Berkata) Firaun, ("Apakah kamu sekalian beriman) lafal A-amantum dapat pula dibaca Tas-hil sehingga bacaannya menjadi Amantum (kepadanya) yakni kepada Nabi Musa (sebelum aku memberi izin) secara langsung dariku (kepada kalian? Sesungguhnya dia benar-benar pemimpin kalian yang mengajarkan sihir kepada kalian) berarti ilmu kalian itu adalah sebagian daripada ilmunya, dan ini berarti pertarungan dan kemenangan di antara sesama perguruan (maka kalian nanti pasti benar-benar mengetahui) akibat perbuatan kalian itu dariku. (Sesungguhnya aku akan memotong tangan kalian dan kaki kalian dengan bersilang) yaitu tangan kanan mereka akan dipotong berikut kaki kirinya (dan aku akan menyalib kalian semuanya").\qt@no{49}}%
\qt@newcmd\qurantrans@id@mmcmlxxxii{%
(Mereka berkata, ``Tidak ada kemudaratan) tidak mengapa bagi kami jika hal tersebut ditimpakan kepada kami (sesungguhnya kami kepada Rabb kami) sesudah kami mati dengan cara apa pun (akan kembali) yakni kembali kepada-Nya di akhirat nanti.\qt@no{50}}%
\qt@newcmd\qurantrans@id@mmcmlxxxiii{%
(Sesungguhnya kami sangat menginginkan) sangat mengharapkan (bahwa Rabb kami akan mengampuni kesalahan kami, karena kami adalah orang- orang yang pertama-tama beriman") di masa kami ini.\qt@no{51}}%
\qt@newcmd\qurantrans@id@mmcmlxxxiv{%
(Dan Kami wahyukan kepada Musa) sesudah beberapa tahun ia tinggal bersama dengan kaum Firaun, yang di masa-masa itu ia menyeru mereka kepada jalan yang benar dengan membawa ayat-ayat Allah, akan tetapi hal itu tidak menambah mereka melainkan hanya kesombongan belaka, ("Pergilah di malam hari dengan membawa hamba-hamba-Ku) yakni bangsa Bani Israel. Menurut suatu qiraat lafal An Asri dibaca An-isri. Asal katanya adalah berakar dari lafal Asra; maksudnya, pergilah dengan mereka menuju ke arah laut Merah di malam hari (karena sesungguhnya kamu sekalian akan dikejar") oleh Firaun dan bala tentaranya, maka mereka pun ikut masuk ke dalam laut di belakang kalian, lalu Aku menyelamatkan kalian dan menenggelamkan mereka.\qt@no{52}}%
\qt@newcmd\qurantrans@id@mmcmlxxxv{%
(Kemudian Firaun mengirimkan) sesudah ia mendengar berita tentang keberangkatan Nabi Musa dan kaum Bani Israel (orangnya ke kota-kota) menurut suatu kisah diceritakan bahwa Firaun memiliki seribu buah kota dan dua belas ribu kampung (mengumpulkan tentaranya) untuk mengumpulkan pasukan. Firaun menginstruksikan demikian seraya mengatakan,\qt@no{53}}%
\qt@newcmd\qurantrans@id@mmcmlxxxvi{%
("Sesungguhnya mereka itu benar-benar golongan) yang dimaksud adalah kaum Bani Israel (yang kecil) menurut suatu pendapat dikatakan, bahwa jumlah kaum Bani Israel yang dibawa Nabi Musa berjumlah enam ratus tujuh puluh ribu orang, sedangkan barisan terdepan dari Firaun berjumlah tujuh ratus ribu tentara, belum lagi yang ada di belakangnya, maka oleh karena itu Firaun menganggap kecil jumlah Bani Israel dibandingkan dengan jumlah tentaranya itu.\qt@no{54}}%
\qt@newcmd\qurantrans@id@mmcmlxxxvii{%
(Dan sesungguhnya mereka membuat hal-hal yang menimbulkan amarah kita,) yakni telah melakukan apa yang membuat kita murka.\qt@no{55}}%
\qt@newcmd\qurantrans@id@mmcmlxxxviii{%
(Dan sesungghnya kita benar-benar golongan yang selalu berjaga-jaga") Kaum yang selalu bersiap-siap. Menurut Suatu qiraat Haadziruuna dibaca Hadziruuna artinya selalu waspada.\qt@no{56}}%
\qt@newcmd\qurantrans@id@mmcmlxxxix{%
Allah berfirman, ("Maka Kami keluarkan mereka) Firaun dan kaumnya dari Mesir untuk mengejar Nabi Musa dan kaumnya (dari taman-taman) yakni kebun-kebun yang ada di sepanjang kedua tepi sungai Nil (mata air) yaitu kolam-kolam yang mengalir di rumah-rumah mereka yang bersumber dari sungai Nil.\qt@no{57}}%
\qt@newcmd\qurantrans@id@mmcmxc{%
(Dan dari perbendaharaan) harta yang berharga berupa emas dan perak; dinamakan Kunuz karena para pemiliknya tidak menunaikan hak Allah yang ada padanya (dan kedudukan yang mulia) yakni majelis-majelis yang indah bagi para penguasa dan para wazir, tempat mereka dikelilingi oleh para pengikutnya masing-masing.\qt@no{58}}%
\qt@newcmd\qurantrans@id@mmcmxci{%
(Demikianlah halnya) Kami telah mengeluarkan mereka sebagaimana yang telah disebutkan tadi (dan Kami anugerahkan semuanya itu kepada Bani Israel.") sesudah Firaun dan kaumnya ditenggelamkan.\qt@no{59}}%
\qt@newcmd\qurantrans@id@mmcmxcii{%
(Maka Firaun dan bala tentaranya mengejar mereka di waktu matahari terbit) yakni di waktu pagi.\qt@no{60}}%
\qt@newcmd\qurantrans@id@mmcmxciii{%
(Maka setelah kedua golongan itu saling melihat) masing-masing pihak telah melihat pihak yang lainnya (berkatalah pengikut-pengikut Musa, ``Sesungguhnya kita benar-benar akan terkejar") oleh pasukan Firaun, kita tidak akan mampu menghadapi mereka, karena kita tidak mempunyai kekuatan.\qt@no{61}}%
\qt@newcmd\qurantrans@id@mmcmxciv{%
(Berkatalah) Nabi Musa, ("Sekali-kali tidak akan tersusul) kita tidak akan tersusul oleh mereka (sesungguhnya Rabbku besertaku) pertolongan-Nya selalu menyertaiku (kelak Dia akan memberi petunjuk kepadaku") jalan yang menuju keselamatan.\qt@no{62}}%
\qt@newcmd\qurantrans@id@mmcmxcv{%
Allah berfirman, ("Lalu Kami wahyukan kepada Musa, 'Pukullah lautan itu dengan tongkatmu') maka Nabi Musa memukul laut itu dengan tongkatnya. (Maka terbelahlah lautan itu) membentuk dua belas jalan (tiap-tiap belahan adalah seperti gunung yang besar) di antara dua gunung terdapat jalan yang akan dilalui oleh mereka; sehingga disebutkan bahwa pelana hewan-hewan kendaraan mereka sedikit pun tidak terkena basah, dan tidak pula kecipratan air.\qt@no{63}}%
\qt@newcmd\qurantrans@id@mmcmxcvi{%
(Dan Kami dekatkan) Kami jadikan (di sana) di tempat itu (golongan yang lain) Firaun dan kaumnya, sehingga mereka melalui jalan yang dilalui oleh Nabi Musa dan kaumnya.\qt@no{64}}%
\qt@newcmd\qurantrans@id@mmcmxcvii{%
(Dan Kami selamatkan Musa dan semua orang-orang yang besertanya) dengan mengeluarkan mereka dari laut, sebagaimana gambaran yang telah disebutkan tadi.\qt@no{65}}%
\qt@newcmd\qurantrans@id@mmcmxcviii{%
(Dan Kami tenggelamkan golongan yang lain itu) yakni Firaun dan kaumnya, dengan menutup kembali lautan ketika mereka telah masuk ke dalamnya, sedangkan Bani Israel telah selamat keluar semuanya dari laut.\qt@no{66}}%
\qt@newcmd\qurantrans@id@mmcmxcix{%
(Sesungguhnya pada yang demikian itu) yaitu ditenggelamkannya Firaun dan kaumnya (benar-benar merupakan tanda) yaitu pelajaran bagi orang-orang yang sesudah mereka. (Akan tetapi kebanyakan mereka tidak beriman) kepada Allah. Yang beriman kepada Allah dari kalangan kaum Firaun hanyalah Asiah istri Firaun sendiri, Hezqil dari kalangan keluarga Firaun dan Maryam binti Namushi yang menunjukkan tempat kuburan Nabi Yusuf a.s.\qt@no{67}}%
\qt@newcmd\qurantrans@id@mmm{%
(Dan sesungguhnya Rabbmu benar-benar Dialah Yang Maha Perkasa) maka Dia membalas kelakuan orang-orang kafir itu dengan menenggelamkan mereka (lagi Maha Penyayang.") terhadap orang-orang Mukmin, Dia menyelamatkan mereka dari tenggelam.\qt@no{68}}%
\qt@newcmd\qurantrans@id@mmmi{%
(Dan bacakanlah kepada mereka) yakni orang-orang kafir Mekah (kisah) berita (Ibrahim) kemudian dijelaskan oleh Badalnya, yaitu:\qt@no{69}}%
\qt@newcmd\qurantrans@id@mmmii{%
(Ketika ia berkata kepada bapaknya dan kaumnya, ``Apakah yang kalian sembah?")\qt@no{70}}%
\qt@newcmd\qurantrans@id@mmmiii{%
(Mereka menjawab, ``Kami menyembah berhala-berhala) mereka menjelaskan perbuatannya secara terang-terangan supaya berhala-berhala itu disukai olehnya (dan kami senantiasa tekun menyembahnya") maksudnya kami selalu menyembahnya; sepanjang siang dengan tekun, mereka menambahkan jawabannya dengan maksud membanggakan diri mereka terhadap Nabi Ibrahim.\qt@no{71}}%
\qt@newcmd\qurantrans@id@mmmiv{%
(Berkata Ibrahim, ``Apakah berhala-berhala itu mendengar seruan kalian di waktu) ketika (kalian berdoa kepadanya?).\qt@no{72}}%
\qt@newcmd\qurantrans@id@mmmv{%
(Atau dapatkah mereka memberi manfaat ke pada kalian) jika kalian menyembahnya (atau memberi mudarat?") kepada diri kalian, jika kalian tidak menyembahnya.\qt@no{73}}%
\qt@newcmd\qurantrans@id@mmmvi{%
(Mereka menjawab, ``Sebenarnya kami mendapati nenek moyang kami berbuat demikian") yakni mereka melakukan sebagaimana apa yang kami lakukan sekarang ini.\qt@no{74}}%
\qt@newcmd\qurantrans@id@mmmvii{%
(Ibrahim berkata, ``Maka apakah kalian telah memperhatikan apa yang selalu kalian sembah).\qt@no{75}}%
\qt@newcmd\qurantrans@id@mmmviii{%
(Kalian dan nenek moyang kalian yang dahulu?)\qt@no{76}}%
\qt@newcmd\qurantrans@id@mmmix{%
(Karena sesungguhnya apa yang kalian sembah itu adalah musuhku) aku tidak menyembah mereka (melainkan) aku hanya menyembah (Rabb semesta alam).\qt@no{77}}%
\qt@newcmd\qurantrans@id@mmmx{%
(Yaitu Tuhan yang telah menciptakan aku, maka Dia-lah yang menunjuki aku) kepada agama yang benar.\qt@no{78}}%
\qt@newcmd\qurantrans@id@mmmxi{%
(Dan Tuhanku, yang memberi makan dan minum kepadaku).\qt@no{79}}%
\qt@newcmd\qurantrans@id@mmmxii{%
(Dan apabila aku sakit. Dialah yang menyembuhkan aku).\qt@no{80}}%
\qt@newcmd\qurantrans@id@mmmxiii{%
(Dan Yang akan mematikan aku, kemudian akan menghidupkan aku kembali).\qt@no{81}}%
\qt@newcmd\qurantrans@id@mmmxiv{%
(Dan Yang amat kuinginkan) amat kuharapkan (akan mengampuni kesalahanku pada hari kiamat") yaitu hari pembalasan.\qt@no{82}}%
\qt@newcmd\qurantrans@id@mmmxv{%
(Ya Rabbku! Berikanlah kepadaku hikmah) yakni ilmu (dan masukkanlah aku ke dalam golongan orang-orang yang saleh) golongan para nabi.\qt@no{83}}%
\qt@newcmd\qurantrans@id@mmmxvi{%
(Dan jadikanlah aku buah tutur yang baik) pujian yang baik (bagi orang-orang yang datang kemudian) maksudnya orang-orang yang datang sesudahku hingga hari kiamat.\qt@no{84}}%
\qt@newcmd\qurantrans@id@mmmxvii{%
(Dan jadikanlah aku termasuk orang-orang yang mewarisi surga yang penuh kenikmatan) yakni di antara orang-orang yang memperolehnya.\qt@no{85}}%
\qt@newcmd\qurantrans@id@mmmxviii{%
(Dan ampunilah bapakku, karena sesungguhnya ia adalah termasuk orang-orang yang sesat) umpamanya, Engkau memberikan jalan bertobat kepadanya, lalu Engkau mengampuninya. Doa ini diucapkan oleh Nabi Ibrahim sebelum jelas baginya, bahwa dia adalah musuh Allah, sebagaimana yang telah diterangkan dalam surah Al Bara'ah atau surah At Taubah.\qt@no{86}}%
\qt@newcmd\qurantrans@id@mmmxix{%
(Dan janganlah Engkau hinakan aku) janganlah Engkau jelek-jelekkan aku (pada hari mereka dibangkithan) di hari semua manusia dibangkitkan.\qt@no{87}}%
\qt@newcmd\qurantrans@id@mmmxx{%
Yang pada hari itu Allah berfirman, ("Di hari ini harta dan anak-anak laki-laki tidak berguna) bagi seorang pun.\qt@no{88}}%
\qt@newcmd\qurantrans@id@mmmxxi{%
(Kecuali) lain halnya dengan (orang-orang yang menghadap Allah dengan hati yang bersih") dari syirik dan munafik, yang dimaksud adalah hati orang Mukmin, maka sesungguhnya imannya itu dapat memberi manfaat kepada dirinya.\qt@no{89}}%
\qt@newcmd\qurantrans@id@mmmxxii{%
(Dan didekatkanlah surga) yakni dijadikan dekat- (kepada orang-orang yang bertakwa) hingga mereka dapat melihatnya dengan jelas.\qt@no{90}}%
\qt@newcmd\qurantrans@id@mmmxxiii{%
(Dan diperlihatkan dengan jelas neraka Jahim) yakni ditampakkan (kepada orang-orang yang Sesat) yakni orang-orang kafir.\qt@no{91}}%
\qt@newcmd\qurantrans@id@mmmxxiv{%
(Dan dikatakan kepada mereka, ``Di manakah berhala-berhala yang dahulu kalian menyembahnya).\qt@no{92}}%
\qt@newcmd\qurantrans@id@mmmxxv{%
(Selain dari Allah?) selain dari-Nya, yang dimaksud adalah berhala-berhala. (Dapatkah mereka menolong kalian) menolak azab yang akan menimpa diri kalian (atau menolong diri mereka sendiri?") yaitu menyelamatkan diri mereka sendiri dari azab?, tentu saja tidak bisa.\qt@no{93}}%
\qt@newcmd\qurantrans@id@mmmxxvi{%
(Maka sesembahan-sesembahan itu dijungkirkan) dicampakkan (ke dalam neraka bersama-sama orang-orang yang sesat).\qt@no{94}}%
\qt@newcmd\qurantrans@id@mmmxxvii{%
(Dan bala tentara iblis) yakni pengikut-pengikutnya dan orang-orang yang menaatinya dari jenis jin dan manusia (semuanya).\qt@no{95}}%
\qt@newcmd\qurantrans@id@mmmxxviii{%
(Mereka berkata,) orang-orang yang sesat itu (sedangkan mereka bertengkar di dalam neraka itu) bersama dengan sesembahan-sesembahan mereka.\qt@no{96}}%
\qt@newcmd\qurantrans@id@mmmxxix{%
("Demi Allah; sungguh) lafal In di sini merupakan bentuk takhfif daripada Inna, sedangkan isimnya tidak disebutkan, pada asalnya adalah Innahuu (kita dahulu dalam kesesatan yang nyata) yakni jelas sesatnya.\qt@no{97}}%
\qt@newcmd\qurantrans@id@mmmxxx{%
(Karena) sebab (kita mempersamakan kalian dengan Rabb semesta alam) dalam hal menyembah.\qt@no{98}}%
\qt@newcmd\qurantrans@id@mmmxxxi{%
(Dan tiadalah yang menyesatkan kita) dari petunjuk (kecuali orang-orang yang berdosa) yakni setan atau para pendahulu kita yang kita tiru perbuatan mereka.\qt@no{99}}%
\qt@newcmd\qurantrans@id@mmmxxxii{%
(Maka kami tidak mempunyai pemberi syafaat seorang pun) tidak sebagaimana orang-orang Mukmin; mereka memiliki para Malaikat, para Nabi dan orang-orang Mukmin lainnya yang dapat memberi syafaat kepada mereka.\qt@no{100}}%
\qt@newcmd\qurantrans@id@mmmxxxiii{%
(Dan tidak pula mempunyai teman yang akrab) yaitu teman yang memperhatikan perkara kita.\qt@no{101}}%
\qt@newcmd\qurantrans@id@mmmxxxiv{%
(Maka sekiranya kita dapat kembali sekali lagi) ke alam dunia (niscaya kami menjadi orang-orang yang beriman") makna Lau di sini menunjukkan arti Tamanni atau mengharapkan sesuatu yang mustahil dapat dicapai, dan lafal Nakuunu adalah Jawab dari Lau.\qt@no{102}}%
\qt@newcmd\qurantrans@id@mmmxxxv{%
(Sesungguhnya pada yang demikian itu) yaitu apa yang telah disebutkan tadi menyangkut kisah Nabi Ibrahim bersama dengan kaumnya (benar-benar terdapat tanda-tanda kekuasaan Allah, tetapi kebanyakan mereka tidak beriman).\qt@no{103}}%
\qt@newcmd\qurantrans@id@mmmxxxvi{%
(Dan sesungguhnya Rabbmu benar- benar Dia-lah Yang Maha Perkasa lagi Maha Penyayang).\qt@no{104}}%
\qt@newcmd\qurantrans@id@mmmxxxvii{%
(Kaum Nuh telah mendustakan para Rasul) disebabkan mereka mendustakan Nabi Nuh, maka mereka dikatakan telah mendustakan para Rasul yang lain; karena sesungguhnya semua ajaran yang dibawa para Rasul itu adalah sama, yaitu menyeru kepada ajaran tauhid. Atau makna yang dimaksud karena mengingat Nabi Nuh tinggal bersama kaumnya dalam kurun waktu yang sangat lama sehingga kedudukan Nabi Nuh sama saja dengan kedudukan Rasul-rasul yang banyak. Di-ta'nits-kannya dhamir yang kembali kepada lafal Qaum karena memandang dari segi makna lafal Qaum, sedangkan jika dhamir yang kembali kepadanya itu berbentuk mudzakkar, karena memandang dari segi lafalnya.\qt@no{105}}%
\qt@newcmd\qurantrans@id@mmmxxxviii{%
(Ketika Saudara mereka berkata kepada mereka,) yang dimaksud adalah Nabi Nuh sendiri, pengertian saudara di sini adalah dari segi nasab atau keturunan ("Mengapa kalian tidak bertakwa?") kepada Allah.\qt@no{106}}%
\qt@newcmd\qurantrans@id@mmmxxxix{%
(Sesungguhnya aku adalah seorang Rasul kepercayaan yang diutus kepada kalian) guna menyampaikan apa yang aku diutus untuk menyampaikannya.\qt@no{107}}%
\qt@newcmd\qurantrans@id@mmmxl{%
(Maka bertakwalah kepada Allah dan taatlah kepadaku) di dalam semua apa yang kuperintahkan kalian mengerjakannya, yaitu mentauhidkan Allah dan taat kepada-Nya.\qt@no{108}}%
\qt@newcmd\qurantrans@id@mmmxli{%
(Dan aku sekali-kali tidak meminta kepada kalian atas ajakan-ajakan itu) imbalan dari menyampaikannya (suatu upah pun, tidak lain) (upahku) pahalaku (hanyalah dari Rabb semesta alam).\qt@no{109}}%
\qt@newcmd\qurantrans@id@mmmxlii{%
(Maka bertakwalah kepada Allah dan taatlah kepadaku) Nabi Nuh mengulang-ulang kalimat ini untuk menegaskan perintahnya.\qt@no{110}}%
\qt@newcmd\qurantrans@id@mmmxliii{%
(Mereka berkata, ``Apakah kami akan beriman) percaya (kepadamu) dengan perkataan itu (padahal yang mengikuti kamu) menurut suatu qiraat dibaca Atbaa'uka, jamak dari lafal Taabi'un yang berkedudukan menjadi Mubtada (ialah orang-orang yang hina?") yakni orang-orang yang rendah.\qt@no{111}}%
\qt@newcmd\qurantrans@id@mmmxliv{%
(Nuh menjawab, ``Bagaimana aku mengetahui) mana mungkin aku mengetahui (apa yang telah mereka kerjakan?).\qt@no{112}}%
\qt@newcmd\qurantrans@id@mmmxlv{%
(Tidak lain) (perhitungan amal perbuatan mereka hanyalah kepada Rabbku) maka Dia akan membalasnya kepada mereka (kalau kalian menyadari) jika kalian mengetahui hal tersebut niscaya kalian tidak akan mencelanya.\qt@no{113}}%
\qt@newcmd\qurantrans@id@mmmxlvi{%
(Dan aku sekali-kali tidak akan mengusir orang-orang yang beriman.)\qt@no{114}}%
\qt@newcmd\qurantrans@id@mmmxlvii{%
(Tiada lain) (aku ini hanyalah pemberi peringatan yang jelas") jelas peringatannya.\qt@no{115}}%
\qt@newcmd\qurantrans@id@mmmxlviii{%
(Mereka berkata, ``Sungguh jika kamu tidak mau berhenti hai Nuh,) dari apa yang kamu katakan kepada kami itu (niscaya benar-benar kamu akan termasuk orang-orang yang dirajam") dengan batu atau dengan makian.\qt@no{116}}%
\qt@newcmd\qurantrans@id@mmmxlix{%
(Berkata) Nuh ("Ya Rabbku! Sesungguhnya kaumku telah mendustakan aku).\qt@no{117}}%
\qt@newcmd\qurantrans@id@mmml{%
(Karena itu adakanlah keputusan antaraku dan mereka) putuskanlah (dan selamatkanlah aku dan orang-orang yang mukmin besertaku").\qt@no{118}}%
\qt@newcmd\qurantrans@id@mmmli{%
Allah berfirman, ("Maka Kami selamatkan Nuh dan orang-orang yang besertanya di dalam kapal yang penuh muatan) yang penuh dengan manusia, hewan dan burung-burung.\qt@no{119}}%
\qt@newcmd\qurantrans@id@mmmlii{%
(Kemudian sesudah itu Kami tenggelamkan) sesudah Nabi Nuh dan orang-orang yang besertanya diselamatkan (orang-orang yang tertinggal) di antara kaumnya.\qt@no{120}}%
\qt@newcmd\qurantrans@id@mmmliii{%
(Sesungguhnya yang demikian itu benar-benar terdapat tanda -kekuasaan Allah- tetapi kebanyakan mereka tidak beriman).\qt@no{121}}%
\qt@newcmd\qurantrans@id@mmmliv{%
(Dan sesungguhnya Rabbmu, Dia-lah Yang Maha Perkasa lagi Maha Penyayang").\qt@no{122}}%
\qt@newcmd\qurantrans@id@mmmlv{%
(Kaum Ad telah mendustakan para Rasul).\qt@no{123}}%
\qt@newcmd\qurantrans@id@mmmlvi{%
(Ketika saudara mereka Hud berkata kepada mereka, ``Mengapa kalian tidak bertakwa?).\qt@no{124}}%
\qt@newcmd\qurantrans@id@mmmlvii{%
(Sesungguhnya aku adalah seorang Rasul kepercayaan yang diutus kepada kalian).\qt@no{125}}%
\qt@newcmd\qurantrans@id@mmmlviii{%
(Maka bertakwalah kalian kepada Allah dan taatlah kepadaku).\qt@no{126}}%
\qt@newcmd\qurantrans@id@mmmlix{%
(Dan sekali-kali aku tidak meminta upah kepada kalian atas ajakan itu, tiada lain upahku hanyalah dari Rabb semesta alam).\qt@no{127}}%
\qt@newcmd\qurantrans@id@mmmlx{%
(Apakah kalian mendirikan pada tiap-tiap tanah yang tinggi) tempat yang tinggi (bangunan) yang berfungsi sebagai pertanda bagi orang-orang yang lewat (untuk bermain-main) di tempat-tempat tersebut kalian memperolok-olok orang-orang yang melewatinya. Kalimat ini berkedudukan menjadi Hal atau kata keterangan keadaan bagi dhamir yang terkandung di dalam lafal Tabnuuna.\qt@no{128}}%
\qt@newcmd\qurantrans@id@mmmlxi{%
(Dan kalian membuat benteng-benteng) yakni penampungan-penampungan air di bawah tanah (dengan maksud supaya kalian) seolah-olah kalian akan (hidup kekal) di dunia ini dan tidak akan mati.\qt@no{129}}%
\qt@newcmd\qurantrans@id@mmmlxii{%
(Dan apabila kalian menyiksa) dengan pukulan atau membunuh (maka kalian menyiksa sebagai orang-orang yang kejam dan bengis) tanpa belas kasihan sedikit pun.\qt@no{130}}%
\qt@newcmd\qurantrans@id@mmmlxiii{%
(Maka bertakwalah kalian kepada Allah) dalam hal itu (dan taatlah kalian kepadaku) di dalam semua apa yang aku perintahkan kalian untuk melakukannya.\qt@no{131}}%
\qt@newcmd\qurantrans@id@mmmlxiv{%
(Dan bertakwalah kalian kepada Allah yang telah menganugerahkan kepada kalian) yakni yang telah melimpahkan nikmat kepada kalian (apa yang kalian ketahui).\qt@no{132}}%
\qt@newcmd\qurantrans@id@mmmlxv{%
(Dia telah menganugerahkan kepada kalian binatang-binatang ternak dan anak-anak).\qt@no{133}}%
\qt@newcmd\qurantrans@id@mmmlxvi{%
(Dan kebun-kebun) ladang-ladang (dan mata air) sungai-sungai.\qt@no{134}}%
\qt@newcmd\qurantrans@id@mmmlxvii{%
(Sesungguhnya aku takut kalian akan ditimpa azab hari yang besar") di dunia dan di akhirat jika kalian durhaka kepadaku.\qt@no{135}}%
\qt@newcmd\qurantrans@id@mmmlxviii{%
(Mereka menjawab, ``Adalah sama saja bagi kami apakah kamu memberi nasihat atau tidak memberi nasihat) pada prinsipnya sama saja, yaitu kami tidak akan mengindahkan lagi nasihatmu.\qt@no{136}}%
\qt@newcmd\qurantrans@id@mmmlxix{%
(Tiada lain) (hal ini) apa yang kamu takut-takuti kami dengannya (hanyalah adat kebiasaan dahulu,) kebiasaan dan kedustaan mereka. Menurut qiraat yang lain dibaca Khalqul Awwaliina; maksudnya: Tiada lain apa yang kami lakukan ini, yaitu ingkar kepada adanya hari berbangkit, melainkan kebiasaan dan tradisi orang-orang dahulu.\qt@no{137}}%
\qt@newcmd\qurantrans@id@mmmlxx{%
(Dan kami sekali-kali tidak akan diazab").\qt@no{138}}%
\qt@newcmd\qurantrans@id@mmmlxxi{%
(Maka mereka mendustakannya) mendustakan adanya azab itu (lalu Kami binasakan mereka) di dunia dengan angin. (Sesungguhnya pada yang demikian itu benar-benar terdapat tanda, kekuasaan Allah, tetapi kebanyakan mereka tidak beriman).\qt@no{139}}%
\qt@newcmd\qurantrans@id@mmmlxxii{%
(Dan sesungguhnya Rabbmu, Dialah Yang Maha Perkasa lagi Maha Penyayang).\qt@no{140}}%
\qt@newcmd\qurantrans@id@mmmlxxiii{%
(Kaum Tsamud telah mendustakan Rasul-Rasul).\qt@no{141}}%
\qt@newcmd\qurantrans@id@mmmlxxiv{%
(Ketika saudara mereka Saleh, berkata kepada mereka, ``Mengapa kalian tidak bertakwa?).\qt@no{142}}%
\qt@newcmd\qurantrans@id@mmmlxxv{%
(Sesungguhnya aku adalah seorang Rasu1 kepercayaan yang diutus kepada kalian).\qt@no{143}}%
\qt@newcmd\qurantrans@id@mmmlxxvi{%
(Maka bertakwalah kalian kepada Allah dan taatlah kalian kepadaku).\qt@no{144}}%
\qt@newcmd\qurantrans@id@mmmlxxvii{%
(Dan aku sekali-kali tidak meminta upah atas ajakan itu, tiada lain) (upahku hanyalah dari Rabb semesta alam).\qt@no{145}}%
\qt@newcmd\qurantrans@id@mmmlxxviii{%
(Adakah kalian akan dibiarkan tinggal di sini bergelimangan) dengan kebaikan-kebaikan (dengan aman).\qt@no{146}}%
\qt@newcmd\qurantrans@id@mmmlxxix{%
(Di dalam kebun-kebun serta mata air).\qt@no{147}}%
\qt@newcmd\qurantrans@id@mmmlxxx{%
(Dan tanaman-tanaman dan pohon-pohon kurma yang mayangnya lembut) yakni lemah lembut\qt@no{148}}%
\qt@newcmd\qurantrans@id@mmmlxxxi{%
(Dan kalian pahat sebagian dari gunung-gunung untuk dijadikan rumah-rumah dengan rajin) dengan penuh semangat; menurut suatu qiraat dibaca Farihina, artinya, dengan penuh keangkuhan.\qt@no{149}}%
\qt@newcmd\qurantrans@id@mmmlxxxii{%
(Maka bertakwalah kalian kepada Allah dan taatlah kepadaku) dengan mengerjakan apa yang telah kuperintahkan kepada kalian untuk melakukannya.\qt@no{150}}%
\qt@newcmd\qurantrans@id@mmmlxxxiii{%
(Dan janganlah kalian menaati perintah orang-orang yang melewati batas).\qt@no{151}}%
\qt@newcmd\qurantrans@id@mmmlxxxiv{%
(Yang membuat kerusakan di muka bumi) dengan melakukan perbuatan-perbuatan durhaka (dan tidak mengadakan perbaikan.") yakni menjalankan ketaatan kepada Allah.\qt@no{152}}%
\qt@newcmd\qurantrans@id@mmmlxxxv{%
(Mereka berkata, ``Sesungguhnya kamu adalah salah seorang dari orang-orang yang kena sihir) termasuk orang-orang yang banyak kena sihir, sehingga akalnya tidak waras lagi.\qt@no{153}}%
\qt@newcmd\qurantrans@id@mmmlxxxvi{%
(Kamu tidak lain hanyalah seorang manusia seperti kami, maka datangkanlah suatu mukjizat, jika kamu memang termasuk orang-orang yang benar") di dalam pengakuanmu sebagai seorang Rasul.\qt@no{154}}%
\qt@newcmd\qurantrans@id@mmmlxxxvii{%
(Saleh menjawab, ``Ini seekor unta betina, ia mempunyai giliran untuk mendapatkan air) maksudnya air minum (dan kalian mempunyai giliran pula untuk mendapatkan air di hari yang tertentu).\qt@no{155}}%
\qt@newcmd\qurantrans@id@mmmlxxxviii{%
(Dan janganlah kalian sentuh unta betina itu dengan sesuatu kejahatan, yang menyebabkan kalian akan ditimpa azab hari yang besar") yakni azab yang besar-besar.\qt@no{156}}%
\qt@newcmd\qurantrans@id@mmmlxxxix{%
(Kemudian mereka membunuhnya) yakni disembelih oleh sebagian dari mereka dengan persetujuan mereka semua (lalu mereka menjadi menyesal) karena telah membunuhnya.\qt@no{157}}%
\qt@newcmd\qurantrans@id@mmmxc{%
(Maka mereka ditimpa azab) yang telah diancamkan itu, sehingga binasalah mereka semuanya (Sesungguhnya pada yang demikian itu benar- benar terdapat bukti yang nyata. Dan adalah kebanyakan mereka tidak beriman)\qt@no{158}}%
\qt@newcmd\qurantrans@id@mmmxci{%
(Dan sesungguhnya Rabbmu benar-benar Dia-lah Yang Maha Perkasa lagi Maha Penyayang).\qt@no{159}}%
\qt@newcmd\qurantrans@id@mmmxcii{%
(Kaum Luth telah mendustakan Rasul-rasul).\qt@no{160}}%
\qt@newcmd\qurantrans@id@mmmxciii{%
(Ketika saudara mereka, Luth, berkata kepada mereka, ``Mengapa kalian tidak bertakwa?).\qt@no{161}}%
\qt@newcmd\qurantrans@id@mmmxciv{%
(Sesungguhnya aku adalah seorang Rasul kepercayaan yang diutus kepada kalian).\qt@no{162}}%
\qt@newcmd\qurantrans@id@mmmxcv{%
(Maka bertakwalah kepada Allah dan taatlah kepadaku).\qt@no{163}}%
\qt@newcmd\qurantrans@id@mmmxcvi{%
(Dan aku sekali-kali tidak minta upah kepada kalian atas ajakan itu, tidak lain) (upahku hanyalah dari Rabb semesta alam).\qt@no{164}}%
\qt@newcmd\qurantrans@id@mmmxcvii{%
(Mengapa kalian mendatangi jenis laki-laki di antara manusia?) melakukan homosex.\qt@no{165}}%
\qt@newcmd\qurantrans@id@mmmxcviii{%
(Dan kalian tinggalkan istri-istri yang dijadikan oleh Rabb kalian untuk kalian) yakni farji-farji mereka (bahkan kalian adalah orang-orang yang melampaui batas").\qt@no{166}}%
\qt@newcmd\qurantrans@id@mmmxcix{%
(Mereka menjawab, ``Hai Luth! Sesungguhnya jika kamu tidak berhenti) dari mengingkari perbuatan kami ini (benar-benar kamu termasuk orang-orang yang diusir") dari negeri kami ini.\qt@no{167}}%
\qt@newcmd\qurantrans@id@mmmc{%
(Berkata) Nabi Luth, ("Sesungguhnya aku sangat benci kepada perbuatan kalian) sangat membencinya.\qt@no{168}}%
\qt@newcmd\qurantrans@id@mmmci{%
(Ya Rabbku! Selamatkanlah aku beserta keluargaku dari akibat perbuatan yang mereka kerjakan") yakni dari azab yang akan menimpa mereka disebabkan perbuatan itu.\qt@no{169}}%
\qt@newcmd\qurantrans@id@mmmcii{%
(Lalu Kami selamatkan ia beserta keluarganya semua).\qt@no{170}}%
\qt@newcmd\qurantrans@id@mmmciii{%
(Kecuali seorang perempuan tua) yakni istri Nabi Luth sendiri (yang termasuk dalam golongan yang tinggal) orang-orang yang dibinasakan.\qt@no{171}}%
\qt@newcmd\qurantrans@id@mmmciv{%
(Kemudian Kami binasakan yang lain) yaitu mereka yang tinggal semuanya.\qt@no{172}}%
\qt@newcmd\qurantrans@id@mmmcv{%
(Dan Kami hujani mereka dengan hujan) batu sebagai alat untuk membinasakan mereka (maka amat jeleklah hujan yang menimpa orang-orang yang telah diberi peringatan itu) sejelek-jelek hujan adalah hujan yang menimpa mereka itu\qt@no{173}}%
\qt@newcmd\qurantrans@id@mmmcvi{%
(Sesungguhnya pada yang demikian itu benar-benar terdapat bukti-bukti yang nyata, kebanyakan manusia tidak beriman).\qt@no{174}}%
\qt@newcmd\qurantrans@id@mmmcvii{%
(Dan sesungguhnya Rabbmu, benar-benar Dia-lah Yang Maha Perkasa lagi Maha Penyayang).\qt@no{175}}%
\qt@newcmd\qurantrans@id@mmmcviii{%
(Penduduk Aikah telah mendustakan) dalam satu qiraat Aikati dibaca Laikata; adalah nama sebuah sumber air yang banyak pepohonan di sekitarnya di dekat kota Madyan (Rasul-rasul).\qt@no{176}}%
\qt@newcmd\qurantrans@id@mmmcix{%
(Ketika Syuaib berkata kepada mereka,) tidak dikatakan saudara mereka, karena Nabi Syuaib bukan berasal dari kalangan mereka ("Mengapa kalian tidak bertakwa?).\qt@no{177}}%
\qt@newcmd\qurantrans@id@mmmcx{%
(Sesungguhnya aku adalah seorang Rasul kepercayaan yang diutus kepada kalian).\qt@no{178}}%
\qt@newcmd\qurantrans@id@mmmcxi{%
(Maka bertakwalah kalian kepada Allah dan taatlah kalian kepadaku).\qt@no{179}}%
\qt@newcmd\qurantrans@id@mmmcxii{%
(Dan aku sekali-kali tidak meminta upah kepada kalian atas ajakan itu; tiada lain upahku hanyalah dari Rabb semesta alam).\qt@no{180}}%
\qt@newcmd\qurantrans@id@mmmcxiii{%
(Sempurnakanlah takaran) genapkanlah (dan janganlah kalian termasuk orang-orang yang merugikan) yakni mengurangi hak-hak orang lain.\qt@no{181}}%
\qt@newcmd\qurantrans@id@mmmcxiv{%
(Dan timbanglah dengan timbangan yang lurus) timbangan yang baik dan tidak berat sebelah.\qt@no{182}}%
\qt@newcmd\qurantrans@id@mmmcxv{%
(Dan janganlah kalian merugikan manusia pada hak-haknya) janganlah kalian mengurangi hak mereka barang sedikit pun (dan janganlah kalian merajalela di muka bumi dengan membuat kerusakan) melakukan pembunuhan dan kerusakan-kerusakan lainnya. Lafal Ta'tsau ini berasal dari 'Atsiya yang artinya membuat kerusakan; dan lafal Mufsidiina merupakan Hal atau kata keterangan keadaan daripada 'Amilnya, yaitu lafal Ta'tsau.\qt@no{183}}%
\qt@newcmd\qurantrans@id@mmmcxvi{%
(Dan bertakwalah kepada Allah yang telah menciptakan kalian dan makhluk) yakni umat-umat (yang dahulu").\qt@no{184}}%
\qt@newcmd\qurantrans@id@mmmcxvii{%
(Mereka berkata, ``Sesungguhnya kamu adalah salah seorang dari orang-orang yang kena sihir).\qt@no{185}}%
\qt@newcmd\qurantrans@id@mmmcxviii{%
(Dan kamu tidak lain hanyalah seorang manusia seperti kami, dan sesungguhnya) lafal In di sini adalah bentuk Takhfif daripada Inna, sedangkan isimnya tidak disebutkan, lengkapnya berasal dari Innahuu (kami yakin bahwa kamu benar-benar termasuk orang-orang yang berdusta).\qt@no{186}}%
\qt@newcmd\qurantrans@id@mmmcxix{%
(Maka jatuhkanlah atas kami gumpalan) dapat dibaca Kasafan dan Kisfan, artinya gumpalan-gumpalan (dari langit, jika kamu termasuk orang-orang yang benar") dalam pengakuan risalahmu itu.\qt@no{187}}%
\qt@newcmd\qurantrans@id@mmmcxx{%
(Syuaib berkata, ``Rabbku lebih mengetahui apa yang kalian kerjakan") maka Dia kelak akan membalasnya kepada kalian.\qt@no{188}}%
\qt@newcmd\qurantrans@id@mmmcxxi{%
(Kemudian mereka mendustakan Syuaib, lalu mereka ditimpa azab pada hari mereka dinaungi awan) yakni awan yang menaungi mereka sesudah hari yang panas sekali, kemudian awan itu menurunkan hujan api kepada mereka sehingga terbakarlah mereka semuanya (sesungguhnya azab itu adalah azab hari yang besar).\qt@no{189}}%
\qt@newcmd\qurantrans@id@mmmcxxii{%
(Sesungguhnya pada yang demikian itu benar-benar terdapat tanda kekuasaan Allah, tetapi kebanyakan mereka tidak beriman).\qt@no{190}}%
\qt@newcmd\qurantrans@id@mmmcxxiii{%
(Dan sesungguhnya Rabbmu benar-benar Dia-lah Yang Maha Perkasa lagi Maha Penyayang).\qt@no{191}}%
\qt@newcmd\qurantrans@id@mmmcxxiv{%
(Dan sesungguhnya ia) yakni Alquran ini (benar-benar diturunkan oleh Rabb semesta alam).\qt@no{192}}%
\qt@newcmd\qurantrans@id@mmmcxxv{%
(Dan dibawa turun oleh Ruhul Amin) yakni malaikat Jibril.\qt@no{193}}%
\qt@newcmd\qurantrans@id@mmmcxxvi{%
(Ke dalam kalbumu agar kamu menjadi salah seorang di antara orang-orang yang memberi peringatan).\qt@no{194}}%
\qt@newcmd\qurantrans@id@mmmcxxvii{%
(Dengan bahasa Arab yang jelas) yang terang. Dan menurut qiraat yang lain lafal Nazala dibaca Nazzala dan lafal Ar Ruuhu dibaca Ar Ruuha, sedangkan yang menjadi Fa'ilnya adalah Allah. Maksudnya, Alquran itu diturunkan oleh Allah melalui Ruhul Amin.\qt@no{195}}%
\qt@newcmd\qurantrans@id@mmmcxxviii{%
(Dan sesungguhnya) mengenai Alquran yang diturunkan kepada Muhammad itu (benar-benar tersebut dalam kitab-kitab) yakni kitab-kitab suci (orang-orang dahulu) seperti kitab Taurat dan kitab Injil.\qt@no{196}}%
\qt@newcmd\qurantrans@id@mmmcxxix{%
(Dan apakah tidak cukup bagi mereka) orang-orang kafir Mekah (sebagai suatu bukti) yang menunjukkan hal tersebut (bahwa para ulama Bani Israel mengetahuinya?) seperti Abdullah ibnu Salam dan pengikut-pengikutnya yang beriman kepada Muhammad, maka sesungguhnya mereka memberitakan hal tersebut. Kalau dibaca Yakun maka dibaca Ayatan; dan kalau dibaca Takun maka dibaca Ayatun.\qt@no{197}}%
\qt@newcmd\qurantrans@id@mmmcxxx{%
(Dan kalau Alquran itu Kami turunkan kepada salah seorang dari golongan bukan Arab) lafal A'jamiina adalah bentuk jamak dari lafal A'jam.\qt@no{198}}%
\qt@newcmd\qurantrans@id@mmmcxxxi{%
(Lalu ia membacakannya kepada mereka) yakni kepada orang-orang kafir Mekah (niscaya mereka tidak akan beriman kepadanya) karena enggan untuk mengikutinya.\qt@no{199}}%
\qt@newcmd\qurantrans@id@mmmcxxxii{%
(Demikianlah), sebagaimana Kami masukkan dusta ke dalam hati mereka jika Alquran diturunkan dengan bahasa Ajam (Kami masukkan Alquran) maksudnya, Kami masukkan dusta pula terhadap Alquran (ke dalam hati orang-orang yang durhaka) maksudnya orang-orang kafir Mekah tidak mempercayainya bila Nabi saw. membacakannya.\qt@no{200}}%
\qt@newcmd\qurantrans@id@mmmcxxxiii{%
(Mereka tidak beriman kepadanya, hingga mereka melihat azab yang pedih).\qt@no{201}}%
\qt@newcmd\qurantrans@id@mmmcxxxiv{%
(Maka datanglah azab kepada mereka dengan mendadak, sedangkan mereka tidak menyadarinya).\qt@no{202}}%
\qt@newcmd\qurantrans@id@mmmcxxxv{%
(Lalu mereka berkata, ``Apakah kami dapat diberi tangguh?") supaya kami mempunyai kesempatan untuk beriman. Maka dikatakan kepada mereka, ``Tidak". Mereka berkata: ``Kapankah datangnya azab itu?" Maka Allah swt. berfirman,\qt@no{203}}%
\qt@newcmd\qurantrans@id@mmmcxxxvi{%
("Maka apakah mereka meminta supaya disegerakan azab Kami?).\qt@no{204}}%
\qt@newcmd\qurantrans@id@mmmcxxxvii{%
(Maka bagaimana pendapatmu) bagaimana menurutmu (jika Kami berikan kepada mereka kenikmatan hidup bertahun-tahun).\qt@no{205}}%
\qt@newcmd\qurantrans@id@mmmcxxxviii{%
(Kemudian datang kepada mereka azab yang telah diancamkan kepada mereka).\qt@no{206}}%
\qt@newcmd\qurantrans@id@mmmcxxxix{%
(Apakah) huruf Maa di sini bermakna Istifham yakni kata tanya, maksudnya, apakah (dapat menjamin mereka apa yang mereka selalu menikmatinya?") untuk menolak azab dari diri mereka atau meringankannya; maksudnya tidak berguna.\qt@no{207}}%
\qt@newcmd\qurantrans@id@mmmcxl{%
(Dan Kami tidak membinasakan sesuatu negeri pun, melainkan sesudah ada baginya orang-orang yang memberi peringatan) yakni para Rasul yang memberi peringatan kepada para penduduknya.\qt@no{208}}%
\qt@newcmd\qurantrans@id@mmmcxli{%
(Peringatan-Ku) sebagai pelajaran untuk mereka. (Dan Kami sekali-kali tidak berlaku zalim) di dalam membinasakan mereka melainkan setelah terlebih dahulu mereka mendapat peringatan. Ayat ini diturunkan berkenaan dengan jawaban terhadap perkataan orang-orang musyrik, yaitu firman Allah berikut:\qt@no{209}}%
\qt@newcmd\qurantrans@id@mmmcxlii{%
(Dan dia itu tidak dibawa turun) yakni Alquran itu tidak dibawa turun oleh (setan-setan).\qt@no{210}}%
\qt@newcmd\qurantrans@id@mmmcxliii{%
(Dan tidaklah patut) tidak pantas (bagi setan-setan itu) untuk membawa turun Alquran (dan mereka pun tidak akan kuasa) melakukannya.\qt@no{211}}%
\qt@newcmd\qurantrans@id@mmmcxliv{%
(Sesungguhnya mereka dari pada mendengarkan) percakapan para Malaikat (benar-benar dijauhkan) dengan dilempar oleh batu-batu meteor.\qt@no{212}}%
\qt@newcmd\qurantrans@id@mmmcxlv{%
(Maka janganlah kamu menyeru tuhan yang lain di samping Allah, yang menyebabkan kalian termasuk orang-orang yang diazab) jika kamu melakukan hal tersebut, sebagaimana yang dimintakan oleh orang-orang musyrik itu.\qt@no{213}}%
\qt@newcmd\qurantrans@id@mmmcxlvi{%
(Dan berilah peringatan kepada kerabat-kerabatmu yang terdekat) mereka adalah Bani Hasyim dan Bani Mutalib, lalu Nabi saw. memberikan peringatan kepada mereka secara terang-terangan; demikianlah menurut keterangan hadis yang telah dikemukakan oleh Imam Bukhari dan Imam Muslim.\qt@no{214}}%
\qt@newcmd\qurantrans@id@mmmcxlvii{%
(Dan rendahkanlah dirimu) berlaku lemah lembutlah kamu (terhadap orang-orang yang mengikutimu, yaitu orang-orang yang beriman).\qt@no{215}}%
\qt@newcmd\qurantrans@id@mmmcxlviii{%
(Jika mereka mendurhakaimu) yakni kerabat-kerabat terdekatmu itu (maka katakanlah) kepada mereka; ("Sesungguhnya aku tidak bertanggung jawab terhadap apa yang kalian kerjakan") tentang penyembahan kalian kepada selain Allah itu.\qt@no{216}}%
\qt@newcmd\qurantrans@id@mmmcxlix{%
(Dan bertawakallah) dapat dibaca Watawakkal dan Fatawakkal, jika dibaca Fatawakkal artinya, maka bertawakallah (kepada Allah Yang Maha Perkasa lagi Maha Penyayang) maksudnya, serahkanlah semua perkaramu kepada-Nya.\qt@no{217}}%
\qt@newcmd\qurantrans@id@mmmcl{%
(Yang melihat kamu ketika kamu berdiri) untuk melakukan salat.\qt@no{218}}%
\qt@newcmd\qurantrans@id@mmmcli{%
(Dan melihat pula perubahan gerakmu) ketika kamu menjalankan rukun-rukun salat; mulai dari berdiri, duduk, rukuk dan sujud (di antara orang-orang yang sujud).\qt@no{219}}%
\qt@newcmd\qurantrans@id@mmmclii{%
(Sesungguhnya Dia adalah Yang Maha Mendengar lagi Maha Mengetahui).\qt@no{220}}%
\qt@newcmd\qurantrans@id@mmmcliii{%
(Apakah akan Aku beritakan kepada kalian) hai orang-orang kafir Mekah (kepada siapa setan-setan itu turun?) Tanazzalu pada asalnya dibaca Tatanazzalu kemudian salah satu huruf Ta dibuang sehingga menjadi Tanazzalu.\qt@no{221}}%
\qt@newcmd\qurantrans@id@mmmcliv{%
(Mereka turun kepada tiap-tiap pendusta) yakni orang yang banyak berdusta (lagi yang banyak dosa) durhaka, seperti Musailamah dan lain-lainnya dari kalangan orang-orang ahli peramal.\qt@no{222}}%
\qt@newcmd\qurantrans@id@mmmclv{%
(Mereka menghadapkan) yakni setan-setan itu (pendengaran) apa yang telah mereka curi dengar dari para malaikat, kemudian mereka menyampaikannya kepada para ahli ramal (dan kebanyakan mereka itu adalah orang-orang pendusta) mereka menambahi kedustaan kepada apa yang telah mereka dengar itu dengan kedustaan yang banyak; hal ini berlangsung sebelum setan-setan itu dihalangi untuk mencapai langit.\qt@no{223}}%
\qt@newcmd\qurantrans@id@mmmclvi{%
(Dan penyair-penyair itu diikuti oleh orang-orang yang sesat) di dalam syair-syair mereka, lalu mereka mengatakannya dan meriwayatkannya dari orang-orang yang sesat itu, maka mereka adalah orang-orang yang tercela.\qt@no{224}}%
\qt@newcmd\qurantrans@id@mmmclvii{%
Tidakkah kamu melihat) apakah kamu tidak memperhatikan (bahwasanya mereka di tiap-tiap lembah) yaitu di majelis-majelis pembicaraan dan sastra-sastranya, yakni majelis kesusasteraan (mengembara) yakni mereka mendatanginya, kemudian mereka melampaui batas di dalam pujian dan hinaan mereka melalui syair-syairnya.\qt@no{225}}%
\qt@newcmd\qurantrans@id@mmmclviii{%
(Dan bahwasanya mereka suka mengatakan) kami telah mengerjakan (apa yang mereka sendiri tidak mengerjakannya) artinya, mereka suka berdusta.\qt@no{226}}%
\qt@newcmd\qurantrans@id@mmmclix{%
(Kecuali orang-orang yang beriman dan beramal saleh) dari kalangan para penyair itu (dan banyak menyebut Allah) maksudnya syair tidaklah melupakan mereka untuk berzikir kepada Allah (dan mendapat kemenangan) melalui syairnya atas orang-orang kafir (sesudah menderita' kelaliman) artinya sesudah orang-orang kafir menghina mereka melalui syair-syairnya yang ditujukan kepada kaum Mukminin semuanya. Mereka tidak tercela dengan syair mereka itu, karena dalam firman yang lain Allah swt. telah berfirman, ``Allah tidak menyukai ucapan buruk yang diucapkan dengan terus terang kecuali orang-orang yang dianiaya." (Q.S. An Nisa 148). Allah telah berfirman pula dalam ayat yang lain, yaitu, ``Oleh karena itu barang siapa yang menyerang kalian, maka seranglah ia seimbang dengan serangannya terhadap kalian." (Q.S. 2 Al Baqarah, 194) ("Dan orang-orang yang zalim itu kelak akan mengetahui) yaitu mereka yang zalim dari kalangan para penyair dan lain-lainnya (ke tempat mana) yakni tempat kembali yang mana (mereka akan kembali") sesudah mereka mati nanti.\qt@no{227}}%
\qt@newcmd\qurantrans@id@mmmclx{%
\basmalahid (Tha Sin) hanya Allah saja yang mengetahui maksudnya (ini) yakni ayat-ayat ini (adalah ayat-ayat Alquran) sebagian daripada Alquran (dan ayat-ayat Kitab yang menjelaskan) yang memenangkan perkara yang hak di atas perkara yang batil. Lafal Kitabin di'athafkan kepada lafal yang sebelumnya dengan ditambahi sifat.\qt@no{1}}%
\qt@newcmd\qurantrans@id@mmmclxi{%
Ia adalah (petunjuk) yang memberi petunjuk agar tidak sesat (dan berita gembira untuk orang-orang yang beriman) yang percaya kepadanya, yaitu akan diberi surga.\qt@no{2}}%
\qt@newcmd\qurantrans@id@mmmclxii{%
(Yaitu orang-orang yang mendirikan salat) yakni menunaikannya sesuai dengan ketentuan-ketentuannya (dan menunaikan) memberikan (zakat dan mereka yakin akan adanya negeri akhirat) artinya mereka mengetahui melalui dalil-dalil Alquran. Hum diulang karena antara Hum yang pertama dengan Khabarnya ada pemisah.\qt@no{3}}%
\qt@newcmd\qurantrans@id@mmmclxiii{%
(Sesungguhnya orang-orang yang tidak beriman kepada negeri akhirat, Kami jadikan mereka memandang indah perbuatan-perbuatan mereka) yang buruk, yaitu dengan membarakan nafsu syahwat mereka, lalu hal itu mereka pandang baik (maka mereka bergelimang) merasa kebingungan di dalamnya, sebab hal itu dianggap buruk oleh kita.\qt@no{4}}%
\qt@newcmd\qurantrans@id@mmmclxiv{%
(Mereka itulah orang-orang yang mendapat azab yang buruk) yang keras di dunia, yaitu dengan dibunuh dan ditawan (dan mereka di akhirat adalah orang-orang yang paling merugi) karena tempat mereka adalah neraka, mereka kekal di dalamnya.\qt@no{5}}%
\qt@newcmd\qurantrans@id@mmmclxv{%
(Dan sesungguhnya kamu) khithab atau perintah ini ditujukan kepada Nabi saw. (benar-benar diberi Alquran) yakni diturunkan dengan sungguh-sungguh kepadamu (dari sisi) hadirat (Yang Maha Bijaksana lagi Maha Mengetahui) mengenai hal tersebut.\qt@no{6}}%
\qt@newcmd\qurantrans@id@mmmclxvi{%
Ingatlah (ketika Musa berkata kepada keluarganya) yaitu istrinya sewaktu ia berjalan dari Madyan menuju ke Mesir, ("Sesungguhnya aku melihat) dari jauh (api. Aku kelak akan membawa kepadamu kabar daripadanya) mengenai jalan yang harus kita tempuh, karena pada saat itu Nabi Musa tersesat (atau aku membawa kepadamu) dari api itu (suluh api). Jika dibaca Bisyihabi Qabasin, maka Idhafah di sini mengandung makna Bayan. Dapat pula dibaca Bisyihabin Qabasin, artinya obor api yang dinyalakan pada sumbu atau kayu (supaya kamu dapat berdiang") huruf Tha pada lafal Tashthaluna adalah pengganti dari huruf Ta asal, karena wazannya adalah Tafta'iluna, yaitu berasal dari Shaliya atau Shala yang artinya berdiang pada api untuk menghilangkan rasa dingin.\qt@no{7}}%
\qt@newcmd\qurantrans@id@mmmclxvii{%
(Maka tatkala ia tiba di tempat api itu, diserulah dia, ``Bahwa telah diberkati) yakni semoga Allah memberkati (orang yang berada di dekat api itu) yaitu Nabi Musa (dan orang-orang yang berada di sekitarnya) yang terdiri dari para Malaikat. Atau maknanya terbalik, yakni malaikat dahulu kemudian Nabi Musa. Lafal Baraka ini bermuta'addi dengan sendirinya sebagaimana dapat bermuta'addi dengan huruf. Kemudian setelah lafal Fi diperkirakan adanya lafal Makani, maksudnya Fi Makanin Nari, yaitu orang-orang yang ada di sekitar api. (Dan Maha Suci Allah, Rabb semesta alam) dari semua apa yang diserukan-Nya, maksudnya Maha Suci Allah dari keburukan.\qt@no{8}}%
\qt@newcmd\qurantrans@id@mmmclxviii{%
(Hai Musa! Sesungguhnya) keadaan yang sebenarnya (Akulah Allah Yang Maha Perkasa lagi Maha Bijaksana).\qt@no{9}}%
\qt@newcmd\qurantrans@id@mmmclxix{%
(Dan lemparkanlah tongkatmu") Musa melemparkannya. (Tatkala Musa melihat tongkatnya bergerak-gerak) bergerak ke sana dan ke mari (seperti seekor ular yang gesit) ular yang sangat besar tapi gesit gerakannya (larilah ia berbalik ke belakang tanpa menoleh) karena takut. Allah swt. berfirman, ("Hai Musa! Janganlah kamu takut) oleh ular itu. (Sesungguhnya tidak takut di hadapan-Ku) yakni di sisi-Ku (orang-orang yang dijadikan Rasul) mereka tidak takut oleh ular dan selainnya.\qt@no{10}}%
\qt@newcmd\qurantrans@id@mmmclxx{%
(Tetapi) (orang-orang yang berlaku zalim) berbuat aniaya terhadap dirinya sendiri (kemudian menggantinya dengan kebaikan) yang ia lakukan (sesudah keburukannya itu) bertobat daripadanya (maka sesungguhnya Aku Maha Pengampun lagi Maha Penyayang) menerima tobatnya dan mengampuninya\qt@no{11}}%
\qt@newcmd\qurantrans@id@mmmclxxi{%
(Dan masukkanlah tanganmu ke leher bajumu) yakni kerah bajumu (niscaya ia akan keluar) berbeda keadaannya dengan warna kulit tangan biasa (putih bukan karena penyakit) supak, dan memancarkan cahaya yang menyilaukan mata, hal itu sebagai mukjizat (termasuk sembilan buah mukjizat) yang kamu diutus untuk membawanya (yang akan dikemukakan kepada Firaun dan kaumnya. Sesungguhnya mereka adalah kaum yang fasik").\qt@no{12}}%
\qt@newcmd\qurantrans@id@mmmclxxii{%
(Maka tatkala mukjizat-mukjizat Kami yang jelas itu sampai kepada mereka) tampak dengan cemerlang lagi jelas (berkatalah mereka, ``Ini adalah sihir yang nyata") yakni jelas ilmu sihirnya.\qt@no{13}}%
\qt@newcmd\qurantrans@id@mmmclxxiii{%
(Dan mereka mengingkarinya) maksudnya mereka tidak mengakuinya sebagai mukjizat (padahal) sesungguhnya (hati mereka meyakininya) bahwa hal itu semuanya datang dari sisi Allah dan bukan ilmu sihir (tetapi kelaliman dan kesombonganlah) yang mencegah mereka dari beriman kepada apa yang dibawa oleh Nabi Musa itu, karenanya mereka ingkar. (Maka perhatikanlah) hai Muhammad (betapa kesudahan orang-orang yang berbuat kerusakan itu) sebagaimana yang kamu ketahui, yaitu mereka dibinasakan.\qt@no{14}}%
\qt@newcmd\qurantrans@id@mmmclxxiv{%
(Dan sesungguhnya Kami telah memberikan kepada Daud dan Sulaiman) yakni anak Daud (ilmu) tentang peradilan di antara manusia dan bahasa burung serta lain-lainnya (dan keduanya mengucapkan) sebagai tanda syukur mereka kepada Allah, ("Segala puji bagi Allah yang telah melebihkan kami) dengan kenabian dan ditundukkannya jin, manusia dan setan-setan (dari kebanyakan hamba-hamba-Nya yang beriman").\qt@no{15}}%
\qt@newcmd\qurantrans@id@mmmclxxv{%
(Dan Sulaiman telah mewarisi Daud) yakni kenabian dan ilmunya tidak kepada putra-putra Nabi Daud yang lainnya (dan dia berkata, ``Hai manusia! Kami telah diberi pengertian tentang ucapan burung) yakni ia memahami suara-suaranya dan apa yang dimaksudnya (dan kami diberi segala sesuatu) sebagaimana yang telah diberikan kepada para nabi dan para raja. (Sesungguhnya ini) semua yang diberikan ini (benar-benar satu karunia yang nyata").\qt@no{16}}%
\qt@newcmd\qurantrans@id@mmmclxxvi{%
(Dan dihimpunkan) dapat dikumpulkan (untuk Sulaiman bala tentaranya dari golongan jin, manusia dan burung-burung) di dalam perjalanan yang dilakukannya (lalu mereka diatur dengan tertib) yakni dikumpulkan, kemudian digerakkan dengan teratur dan tertib.\qt@no{17}}%
\qt@newcmd\qurantrans@id@mmmclxxvii{%
(Sehingga apabila mereka sampai di lembah semut) yaitu di kota Thaif atau di negeri Syam; yang dimaksud adalah semut-semut kecil dan semut-semut besar (berkatalah seekor semut) yaitu raja semut, sewaktu melihat bala tentara Nabi Sulaiman, ("Hai semut-semut! Masuklah ke dalam sarang-sarang kalian, agar kalian tidak diinjak) yakni tidak terinjak-injak (oleh Sulaiman dan bala tentaranya, sedangkan mereka tidak menyadari") semut dianggap sebagai makhluk yang dapat berbicara, mereka melakukan pembicaraan sesama mereka.\qt@no{18}}%
\qt@newcmd\qurantrans@id@mmmclxxviii{%
(Maka tersenyum) Nabi Sulaiman pada permulaannya (tertawa) pada akhirnya (karena mendengar perkataan semut itu) dia telah mendengarnya walaupun jaraknya masih jauh yakni tiga mil, kemudian suara itu dibawa oleh angin. Nabi Sulaiman menahan bala tentaranya sewaktu mereka hampir sampai ke lembah semut, sambil menunggu supaya semut-semut itu memasuki sarang-sarangnya terlebih dahulu. Bala tentara Nabi Sulaiman dalam perjalanan ini ada yang menaiki kendaraan dan ada pula yang berjalan kaki (dan dia berdoa, ``Ya Rabbku! Berilah aku) berilah aku ilham (untuk tetap mensyukuri nikmat-Mu yang telah Engkau anugerahkan) nikmat-nikmat itu (kepadaku dan kepada dua orang ibu bapakku dan untuk mengerjakan amal saleh yang Engkau ridai; dan masukkanlah aku dengan rahmat-Mu ke dalam golongan hamba-hamba-Mu yang Saleh") yakni para Nabi dan para Wali.\qt@no{19}}%
\qt@newcmd\qurantrans@id@mmmclxxix{%
(Dan dia memeriksa burung-burung) untuk mencari burung Hud-hud yang ditugaskan untuk meneliti adanya sumber air di bawah tanah, melalui paruhnya yang ia patuk-patukkan ke tanah yang dimaksud pada saat itu Nabi Sulaiman membutuhkan air untuk salat, ternyata dia tidak melihat burung Hud-hud itu (lalu ia berkata, ``Mengapa aku tidak melihat Hud-hud?) apakah gerangan yang menyebabkan hingga aku tidak melihatnya?, coba jelaskan kepadaku ke mana dia? (apakah dia termasuk yang tidak hadir?") Nabi Sulaiman tidak melihatnya karena tidak ada di tempat, setelah terbukti Hud-hud tidak ada.\qt@no{20}}%
\qt@newcmd\qurantrans@id@mmmclxxx{%
Nabi Sulaiman berkata, ("Sungguh aku benar-benar akan mengazabnya dengan azab) yakni hukuman (yang keras) yaitu akan dicabuti bulu-bulu sayap dan ekornya, kemudian akan dicampakkan di tempat yang amat panas, sehingga ia tidak dapat menghindarkan diri dari bahaya binatang melata dan serangga yang akan memakannya (atau aku benar-benar menyembelihnya) yaitu memotong lehernya (atau benar-benar dia datang kepadaku) dapat dibaca Laya'tiyanniy dan Laya'tiynaniy (dengan alasan yang terang") yang menjelaskan alasan ketidakhadirannya.\qt@no{21}}%
\qt@newcmd\qurantrans@id@mmmclxxxi{%
(Maka diamlah Nabi Sulaiman) dapat dibaca Famakutsa dan Famakatsa (dalam waktu yang tidak lama) tidak lama setelah itu datanglah burung Hud-hud ke hadapan Nabi Sulaiman seraya merendahkan diri, yakni dengan mengangkat kepalanya dan merendahkan kedua sayap dan ekornya. Akhirnya Nabi Sulaiman memaafkannya, lalu Nabi Sulaiman menanyakan kepadanya tentang apa yang ia jumpai selama ketidakhadirannya itu (Hud-hud berkata, ``Aku telah mengetahui sesuatu yang kamu belum mengetahuinya) yakni aku telah menyaksikan apa yang belum pernah kamu saksikan (dan kubawakan kepadamu dari negeri Saba) dapat dibaca Saba-in dan Saba-a nama suatu kabilah yang diam di negeri Yaman. Mereka dinamakan dengan nama kakek moyangnya. Berdasarkan ketentuan ini lafal Saba menerima Tanwin (suatu berita) yakni kabar (yang diyakini).\qt@no{22}}%
\qt@newcmd\qurantrans@id@mmmclxxxii{%
(Sesungguhnya aku menjumpai seorang wanita yang memerintah mereka) dia adalah ratu mereka bernama Balqis (dan dia dianugerahi segala sesuatu) yang diperlukan oleh seorang raja, seperti perlengkapan senjata dan peralatan lainnya (serta mempunyai singgasana) tempat duduk raja (yang besar) panjangnya kira-kira delapan puluh hasta dan lebarnya empat puluh hasta, sedangkan tingginya tiga puluh hasta, semuanya terbuat dari emas dan perak, kemudian bertahtakan mutiara, batu permata yaqut merah, batu zabarjad yang hijau dan tiang-tiangnya terbuat dari yaqut merah, zabarjad yang hijau dan zamrud. Kemudian singgasana itu memiliki tujuh pintu masuk yang selalu dijaga dengan ketat sekali.\qt@no{23}}%
\qt@newcmd\qurantrans@id@mmmclxxxiii{%
(Aku mendapati dia dan kaumnya menyembah matahari, selain Allah dan setan telah menjadikan mereka memandang baik perbuatan-perbuatan mereka, lalu menghalangi mereka dari jalan) yang benar (sehingga mereka tidak dapat petunjuk).\qt@no{24}}%
\qt@newcmd\qurantrans@id@mmmclxxxiv{%
(Agar mereka tidak menyembah Allah), ditambahkan An pada la yasjudu kemudian An di-idgamkan kepada la sehingga menjadi Alla Yasjudu perihalnya sama dengan lafal yang terdapat di dalam firman-Nya, 'Lialla Ya'lama Ahlul Kitabi.' Bentuk asalnya La Ya'lama lalu ditambah An dan sebelum itu lam Ta'lil. Kedudukan Alla Yasjudu menjadi Maf'ul secara Mahal dari lafal Yahtaduna, yaitu dengan menggugurkan huruf Ila (Yang mengeluarkan apa yang terpendam) lafal Al Khab-a adalah Mashdar, yang maknanya apa-apa yang terpendam di dalam hujan dan tumbuh-tumbuhan (di langit dan di bumi dan Yang mengetahui apa yang kalian sembunyikan) di dalam kalbu kalian (dan apa yang kalian nyatakan) melalui perkataan kalian.\qt@no{25}}%
\qt@newcmd\qurantrans@id@mmmclxxxv{%
(Allah, tiada Tuhan yang wajib disembah melainkan hanya Dia, Tuhan Yang mempunyai Arasy yang besar") ayat ini merupakan jumIah Isti'naf, dimaksud sebagai pujian yang menyangkut pula di dalamnya sebutan Arasy Tuhan Yang Maha Penyayang sebagai imbangan dari arasy ratu Balqis, sekalipun perbedaan antara keduanya jauh sekali.\qt@no{26}}%
\qt@newcmd\qurantrans@id@mmmclxxxvi{%
(Berkatalah) Nabi Sulaiman kepada burung Hud-hud ("Akan kami lihat, apakah kamu benar) di dalam berita yang kamu sampaikan kepada kami ini (ataukah kamu termasuk yang berdusta") yakni kamu termasuk satu di antara mereka. Ungkapan ini jauh lebih sopan daripada seandainya dikatakan, ``Ataukah kamu berdusta dalam hal ini". Kemudian burung Hud-hud menunjukkan sumber air itu kepada mereka lalu dikeluarkan airnya; mereka meminumnya sehingga menjadi segar kembali, mereka berwudu, lalu melakukan salat. Sesudah itu Nabi Sulaiman menulis surah kepada ratu Balqis yang bunyinya seperti berikut, ``Dari hamba Allah, Sulaiman ibnu Daud kepada ratu Balqis, ratu negeri Saba. Dengan nama Allah Yang Maha Pengasih lagi Maha Penyayang. Keselamatan atas orang yang mengikuti petunjuk. Amma Ba'du, Janganlah kamu sekalian berlaku sombong terhadapku dan datanglah kepadaku sebagai orang-orang yang berserah diri". Setelah itu Nabi Sulaiman menuliskannya dengan minyak kesturi lalu dicapnya dengan cincinnya. Maka berkatalah ia kepada burung Hud-hud,\qt@no{27}}%
\qt@newcmd\qurantrans@id@mmmclxxxvii{%
("Pergilah membawa surahku ini, lalu jatuhkan kepada mereka) kepada ratu Balqis dan kaumnya (kemudian berpalinglah) pergilah (dari mereka) dengan tidak terlalu jauh dari mereka (lalu perhatikanlah apa yang mereka bicarakan.") yakni, jawaban atau reaksi apakah yang bakal mereka lakukan. Kemudian burung Hud-hud membawa surah itu lalu mendatangi ratu Balqis yang pada waktu itu berada di tengah-tengah bala tentaranya. Kemudian burung Hud-hud menjatuhkan surah Nabi Sulaiman itu ke pangkuannya. Ketika ratu Balqis membaca surah tersebut, tubuhnya gemetar dan lemas karena takut, kemudian ia memikirkan isi surah tersebut.\qt@no{28}}%
\qt@newcmd\qurantrans@id@mmmclxxxviii{%
Selanjutnya (Ia berkata) yakni ratu Balqis kepada pemuka pemuka kaumnya, ("Hai pembesar-pembesar! Sesungguhnya aku) dapat dibaca Al Mala-u Inni dan Al Mala-u winni, yakni bacaan secara Tahqiq dan Tas-hil (telah dijatuhkan kepadaku sebuah surah yang mulia) yakni surah yang berstempel.\qt@no{29}}%
\qt@newcmd\qurantrans@id@mmmclxxxix{%
Sesungguhnya surah itu dari Sulaiman dan sesungguhnya isinya) kandungan isi surah itu, ('Dengan menyebut nama Allah Yang Maha Pemurah lagi Maha Penyayang).\qt@no{30}}%
\qt@newcmd\qurantrans@id@mmmcxc{%
(Janganlah kamu sekalian berlaku sombong terhadapku dan datanglah kepadaku, sebagai orang-orang yang berserah diri')".\qt@no{31}}%
\qt@newcmd\qurantrans@id@mmmcxci{%
(Berkata dia, ``Hai para pembesar! Berilah aku pertimbangan) dapat dibaca Al Mala-u Aftuni dan Al Mala-uwaftuni, maksudnya, kemukakanlah saran kamu sekalian kepadaku (dalam urusanku ini, aku tidak pernah memutuskan suatu persoalan) karena aku belum pernah memutuskannya (sebelum kalian berada dalam majelisku") sebelum kalian semua hadir di majelisku ini.\qt@no{32}}%
\qt@newcmd\qurantrans@id@mmmcxcii{%
(Mereka menjawab, ``Kita adalah orang-orang yang memiliki kekuatan dan juga memiliki keberanian yang sangat) dalam peperangan (dan keputusan berada di tanganmu, maka pertimbangkanlah apa yang akan kamu perintahkan") kami akan menaati perintahmu.\qt@no{33}}%
\qt@newcmd\qurantrans@id@mmmcxciii{%
(Dia berkata, ``Sesungguhnya raja-raja apabila memasuki suatu negeri, niscaya mereka membinasakannya) melakukan pengrusakan di dalamnya (dan menjadikan penduduknya yang mulia jadi hina, dan demikian pula yang akan mereka perbuat) yang akan dilakukan oleh para pengirim surah ini.\qt@no{34}}%
\qt@newcmd\qurantrans@id@mmmcxciv{%
(Dan sesungguhnya aku akan mengirim utusan kepada mereka dengan membawa hadiah, dan aku akan menunggu apa yang akan dibawa kembali oleh utusan-utusan itu") apakah mereka akan menerima hadiahku ini atau menolaknya. Jika ia seorang raja niscaya ia akan menerimanya, jika ia seorang Nabi niscaya ia akan menolaknya. Kemudian ratu Balqis mengirimkan para pelayan lelaki dan perempuan yang jumlahnya dua ribu orang; separuh laki-laki dan separuh lagi perempuan. Para utusan itu membawa lima ratus balok emas, sebuah mahkota yang bertatahkan permata, minyak kesturi, minyak anbar dan hadiah-hadiah lainnya beserta sebuah surah jawaban. Burung Hud-hud segera terbang menuju ke Nabi Sulaiman untuk memberitakan kepadanya semua apa yang ia dengar dan saksikan itu. Setelah Nabi Sulaiman mendapat berita dari burung Hud-hud, maka segera ia memerintahkan pasukannya untuk membuat batu bata dari emas dan perak, hendaknya dari tempat ia berkemah sampai dengan sembilan farsakh dihampari permadani, kemudian di sekelilingnya dibangun tembok yang terbuat dari batu bata emas dan perak, kemudian ia memerintahkan kepada anak-anak jin supaya mendatangkan hewan darat dan hewan laut yang paling indah untuk ditaruh di sebelah kanan dan kiri lapangan dekat istana yang dibangunnya itu.\qt@no{35}}%
\qt@newcmd\qurantrans@id@mmmcxcv{%
(Maka tatkala utusan itu sampai) utusan ratu Balqis yang membawa hadiah berikut dengan pengiring-pengiringnya (kepada Sulaiman. Sulaiman berkata, ``Apakah patut kalian menolong aku dengan harta?, apa yang diberikan Allah kepadaku) berupa kenabian dan kerajaan (lebih baik daripada apa yang diberikan-Nya kepada kalian) yakni keduniaan yang diberikan kepada kalian (tetapi kalian merasa bangga dengan hadiah kalian itu) karena kalian merasa bangga dengan harta keduniaan yang kalian miliki.\qt@no{36}}%
\qt@newcmd\qurantrans@id@mmmcxcvi{%
(Kembalilah kepada mereka) dengan hadiah yang kamu bawa itu (sungguh kami akan mendatangi mereka dengan bala tentara yang mereka tidak mempunyai kekuatan) tidak berdaya lagi (untuk melawannya, dan pasti kami akan mengusir mereka dari negeri itu) dari negeri tempat tinggal mereka, yaitu negeri Saba'. Negeri ini dinamai dengan nama kakek moyang mereka (dengan terhina dan mereka menjadi tawanan") jika mereka tidak mau datang kepadaku dengan berserah diri. Ketika utusan itu kembali kepada ratu Balqis berikut dengan hadiah yang mereka bawa sebelumnya, ratu Balqis menempatkan singgasananya di dalam keratonnya yang berpintu tujuh, sedangkan keraton ratu Balqis berada di dalam tujuh keraton yang besar-besar. Kemudian semua pintu-pintunya dikunci dengan rapat dan menugaskan sebagian bala tentaranya untuk menjaga keraton dan singgasananya. Setelah itu ia bersiap-siap untuk melakukan perjalanan menghadap Nabi Sulaiman, untuk melihat apa yang bakal diperintahkan oleh Nabi Sulaiman kepada dirinya. Berangkatlah ratu Balqis dengan membawa dua belas ribu pasukannya; menurut pendapat yang lain disebutkan bahwa jumlah tentara yang dibawanya pada saat itu sangat banyak, sehingga dari jarak satu farsakh dapat terdengar suara gemuruhnya.\qt@no{37}}%
\qt@newcmd\qurantrans@id@mmmcxcvii{%
(Berkata Sulaiman, ``Hai pembesar-pembesar! Siapakah di antara kamu sekalian) lafal ayat ini dapat dibaca secara Tahqiq dan dapat pula ia dibaca secara Tas-hil sebagaimana keterangan sebelumnya (yang sanggup membawa singgasananya kepadaku sebelum mereka datang kepadaku sebagai orang-orang yang berserah diri?") yakni taat dan tunduk kepadaku. Maka aku harus mengambil singgasananya itu sebelum mereka datang, bukan sesudahnya.\qt@no{38}}%
\qt@newcmd\qurantrans@id@mmmcxcviii{%
(Ifrit dari golongan jin berkata,) yakni jin yang paling kuat lagi keras ("Aku akan datang kepadamu dengan membawa singgasana itu sebelum kamu berdiri dari tempat dudukmu) dari majelis tempat ia melakukan peradilan di antara orang-orang, yaitu dari mulai pagi sampai tengah hari (dan sesungguhnya aku benar-benar kuat) untuk membawanya (lagi dapat dipercaya.") atas semua permata dan batu-batu berharga lainnya yang ada pada singgasananya itu. Maka Nabi Sulaiman berkata, ``Aku menginginkan yang lebih cepat dari itu".\qt@no{39}}%
\qt@newcmd\qurantrans@id@mmmcxcix{%
(Seorang yang mempunyai ilmu dari Al kitab) yang diturunkan (berkata,) ia bernama Ashif ibnu Barkhiya; dia terkenal sangat jujur dan mengetahui tentang asma Allah Yang Teragung, yaitu suatu asma apabila dipanjatkan doa niscaya doa itu dikabulkan ("Aku akan membawa singgasana itu kepadamu sebelum matamu berkedip") jika kamu tujukan pandanganmu itu kepada sesuatu. Maka Ashif berkata kepadanya, ``Coba lihat langit itu", maka Nabi Sulaiman pun menujukan pandangannya ke langit, setelah itu ia mengembalikan pandangannya ke arah semula sebagaimana biasanya, tiba-tiba ia menjumpai singgasana ratu Balqis itu telah ada di hadapannya. Ketika Nabi Sulaiman mengarahkan pandangannya ke langit, pada saat itulah Ashif berdoa dengan mengucapkan Ismul A'zham, seraya meminta kepada Allah supaya Dia mendatangkan singgasana tersebut, maka dikabulkan permintaan Ashif itu oleh Allah. Sehingga dengan seketika singgasana itu telah berada di hadapannya. Ibaratnya Allah meletakkan singgasana itu di bawah bumi, lalu dimunculkan-Nya di bawah singgasana Nabi Sulaiman. (Maka tatkala Sulaiman melihat singgasana itu terletak) telah berada (di hadapannya, ia pun berkata, ``Ini) yakni didatangkannya singgasana itu untukku (termasuk karunia Rabbku untuk mencoba aku) untuk menguji diriku (apakah aku bersyukur) mensyukuri nikmat, lafal ayat ini dapat dibaca Tahqiq dan Tas-hil (atau mengingkari) nikmat-Nya. (Dan barang siapa yang bersyukur maka sesungguhnya dia bersyukur untuk kebaikan dirinya) artinya pahalanya itu untuk dirinya sendiri (dan barang siapa yang ingkar) akan nikmat-Nya (maka sesungguhnya Rabbku Maha Kaya) tidak membutuhkan kesyukurannya (lagi Maha Mulia") yakni tetap memberikan kemurahan kepada orang-orang yang mengingkari nikmat-Nya.\qt@no{40}}%
\qt@newcmd\qurantrans@id@mmmcc{%
(Dia berkata, ``Ubahlah baginya singgasananya) yaitu bentuknya sehingga bila kelak ia melihatnya tidak yakin bahwa singgasana itu miliknya sendiri, (maka kita akan melihat apakah dia mengenal) yakni dapat mengetahuinya (ataukah dia termasuk orang-orang yang tidak mengenalnya") tidak mengetahuinya karena telah mengalami perubahan. Nabi Sulaiman sengaja melakukan hal ini untuk menguji kecerdasan akalnya, karena menurut kata orang-orang dia berakal cerdas. Maka mereka segera mengubah singgasana itu dengan cara menambahi dan mengurangi serta memoles bagian-bagiannya.\qt@no{41}}%
\qt@newcmd\qurantrans@id@mmmcci{%
(Dan ketika Balqis datang, ditanyakan) kepadanya, ("Serupa inikah singgasanamu?") apakah singgasanamu mirip seperti ini. (Dia menjawab, ``Seakan-akan singgasana ini singgasanaku") ternyata dia masih mengetahuinya dan di dalam jawabannya ini Balqis mengungkapkannya dengan memakai kata seakan-akan, sebagaimana apa yang telah mereka perbuat terhadap dirinya. Karena jika ditanyakan, ``Inikah singgasanamu?", maka niscaya dia akan menjawab. ``Ya". Maka Nabi Sulaiman berkata setelah mengetahui bahwa Balqis mempunyai makrifat dan ilmu ("Dan kami telah diberi pengetahuan sebelumnya dan kami adalah orang-orang yang berserah diri") kepada Allah swt.\qt@no{42}}%
\qt@newcmd\qurantrans@id@mmmccii{%
(Dan telah mencegahnya) dari menyembah Allah (apa yang selama ini ia sembah selain Allah) (karena sesungguhnya dia dahulunya termasuk orang-orang yang kafir).\qt@no{43}}%
\qt@newcmd\qurantrans@id@mmmcciii{%
(Dan dikatakan pula kepadanya, ``Masuklah ke dalam istana!") yang lantainya terbuat dari kaca yang bening sekali, kemudian di bawahnya ada air tawar yang mengalir yang ada ikannya. Nabi Sulaiman sengaja melakukan demikian sewaktu ia mendengar berita bahwa kedua betis ratu Balqis dan kedua telapak kakinya seperti keledai. (Maka tatkala dia melihat lantai istana itu dikiranya kolam air) yakni kolam yang penuh dengan air (dan disingkapkannya kedua betisnya) untuk menyeberangi yang ia duga sebagai kolam, sedangkan Nabi Sulaiman pada saat itu duduk di atas singgasananya di ujung lantai kaca itu, maka ternyata ia melihat kedua betis dan kedua telapak kakinya indah. (Sulaiman berkata) kepada Balqis, ("Sesungguhnya ia adalah istana licin) dan halus (yang terbuat dari kaca") kemudian Nabi Sulaiman mengajaknya untuk masuk Islam. (Balqis berkata, ``Ya Rabbku! Sesungguhnya aku telah berbuat zalim terhadap diriku sendiri) dengan menyembah selain Engkau (dan aku berserah diri) mulai saat ini (bersama Sulaiman kepada Allah, Rabb semesta alam.") kemudian Nabi Sulaiman berkehendak untuk mengawininya tetapi ia tidak menyukai rambut yang ada pada kedua betisnya. Maka setan-setan membuat cahaya untuk Nabi Sulaiman, dengan cahaya itu lenyaplah bulu-bulu betisnya. Nabi Sulaiman menikahinya serta mencintainya, kemudian Nabi Sulaiman mengakui kerajaannya. Tersebutlah, bahwa Nabi Sulaiman menggilirnya sekali setiap bulan, kemudian ia tinggal bersamanya selama tiga hari untuk setiap giliran. Disebutkan di dalam suatu riwayat, bahwa Nabi Sulaiman telah diangkat menjadi raja sejak ia berumur tiga belas tahun. Pada saat ia meninggal dunia umurnya mencapai lima puluh tiga tahun; Maha Suci Allah yang tiada habis bagi kerajaan-Nya.\qt@no{44}}%
\qt@newcmd\qurantrans@id@mmmcciv{%
(Dan sesungguhnya Kami telah mengutus kepada kaum Tsamud saudara mereka) yang satu kabilah (Saleh, yang berseru, ``Sembahlah Allah!") tauhidkanlah Dia. (Tetapi tiba-tiba mereka jadi dua golongan yang bermusuhan) dalam masalah agama; segolongan terdiri dari orang-orang yang beriman kepadanya sejak ia diutus kepada mereka dan golongan yang lain adalah orang-orang kafir.\qt@no{45}}%
\qt@newcmd\qurantrans@id@mmmccv{%
(Dia berkata) kepada orang-orang yang mendustakannya. ("Hai kaumku! Mengapa kalian minta disegerakan keburukan sebelum kamu minta kebaikan?) yakni meminta disegerakan turunnya azab sebelum rahmat, karena kalian telah mengatakan, 'Jika apa yang kamu datangkan kepada kami itu adalah benar, maka turunkanlah azab kepada kami', (Mengapa tidak) (kalian meminta ampun kepada Allah) dari kemusyrikan (agar kalian mendapat rahmat") karenanya kalian tidak akan diazab.\qt@no{46}}%
\qt@newcmd\qurantrans@id@mmmccvi{%
(Mereka menjawab, ``Kami mendapat kesialan) asalnya adalah Tathayyarna, kemudian huruf Ta diidgamkan kepada huruf Tha setelah diganti menjadi Tha, kemudian ditarik Hamzah Washal, sehingga menjadi Iththayyarna. Artinya, kami merasa sial (disebabkan kamu dan orang-orang yang besertamu") yakni orang-orang Mukmin yang besertamu. Mereka mengatakan demikian karena mereka tertimpa kemarau panjang dan paceklik. (Saleh berkata, ``Nasib kalian) yakni kesialan kalian (adapada sisi Allah) Dia-lah yang telah mendatangkannya kepada kalian, bukan kami (tetapi kalian kaum yang diuji") maksudnya sedang dicoba dengan kebaikan dan keburukan.\qt@no{47}}%
\qt@newcmd\qurantrans@id@mmmccvii{%
(Dan adalah di kota itu) yakni kota kaum Tsamud itu (sembilan orang laki-laki) dari kalangan kaum laki-laki (yang gemar membuat kerusakan di muka bumi) dengan melakukan perbuatan-perbuatan maksiat antara lain mereka merentenkan uang-uang Dirham (dan mereka tidak berbuat kebaikan) tidak pernah melakukan ketaatan.\qt@no{48}}%
\qt@newcmd\qurantrans@id@mmmccviii{%
(Mereka berkata) sebagian dari mereka berkata kepada sebagian yang lainnya, ("Bersumpahlah kalian) lakukanlah sumpah oleh kalian (dengan nama Allah bahwa kita sungguh-sungguh akan menyerangnya dengan tiba-tiba di malam hari) lafal Lanubayyitannahu ini dapat pula dibaca Latubayyitunnahu (beserta keluarganya) yakni orang-orang yang beriman kepadanya. Maksudnya, kami bunuh mereka di malam hari secara sekonyong-konyong (kemudian kita katakan) dapat dibaca Lanaqulanna dan Lataqulunna (kepada ahli warisnya) yakni kepada orang-orang yang memiliki darahnya (bahwa kita tidak menyaksikan) tidak terlibat (kematian keluarganya) dapat dibaca Mahlika dan Muhlika, maksudnya, kami tidak mengetahui siapakah yang telah membunuh mereka (dan sesungguhnya kita adalah orang-orang yang benar").\qt@no{49}}%
\qt@newcmd\qurantrans@id@mmmccix{%
(Dan mereka pun merencanakan makar) untuk membunuh Nabi Saleh dan para pengikutnya (dengan sungguh-sungguh dan Kami merencanakan makar pula) membalasnya dengan menyegerakan hukuman kepada mereka (sedangkan mereka tidak menyadari).\qt@no{50}}%
\qt@newcmd\qurantrans@id@mmmccx{%
(Maka perhatikanlah betapa sesungguhnya akibat makar mereka itu, bahwasanya Kami membinasakan mereka) sebagai balasannya (dan kaum mereka semuanya) dengan jeritan malaikat Jibril atau para Malaikat melempari mereka dengan batu-batu sedangkan mereka tidak melihat malaikat-malaikat itu tetapi para malaikat melihat mereka.\qt@no{51}}%
\qt@newcmd\qurantrans@id@mmmccxi{%
(Maka itulah rumah-rumah mereka dalam keadaan runtuh) yaitu kosong. Lafal Khawiyatan dinashabkan karena berkedudukan sebagai Hal, sedangkan 'Amil-nya atau yang mempengaruhinya adalah makna yang terkandung di dalam Isim Isyarat atau lafal Tilka (disebabkan kelaliman mereka) disebabkan kekafiran mereka. (Sesungguhnya yang demikian itu terdapat pelajaran) yaitu contoh yang dapat dijadikan sebagai pelajaran (bagi kaum yang mengetahui) kekuasaan Kami, karenanya mereka mengambil pelajaran darinya.\qt@no{52}}%
\qt@newcmd\qurantrans@id@mmmccxii{%
(Dan telah Kami selamatkan orang-orang yang beriman) kepada Nabi Saleh, yang jumlah mereka mencapai empat ribu orang (dan mereka itu selalu bertakwa) selalu memelihara diri dari perbuatan musyrik.\qt@no{53}}%
\qt@newcmd\qurantrans@id@mmmccxiii{%
(Dan ingatlah kisah Luth) lafal Luthan di-nashab-kan oleh lafal Udzkur yang keberadaannya diperkirakan sebelumnya, kemudian dijelaskan oleh Badalnya (yaitu ketika dia berkata kepada kaumnya, ``Mengapa kalian mengerjakan perbuatan fahisyah itu) yakni perbuatan sodomi atau homosex (sedangkan kalian mengetahuinya) sebagian di antara kalian melihat sebagian yang lain bergelimang di dalam melakukan perbuatan yang jelas kejinya itu.\qt@no{54}}%
\qt@newcmd\qurantrans@id@mmmccxiv{%
(Mengapa kalian) dapat dibaca secara Tahqiq dan Tashil (mendatangi laki-laki untuk melampiaskan nafsu syahwat kalian, bukan mendatangi wanita? Sebenarnya kalian adalah kaum yang tidak mengetahui.") akibat dari perbuatan kalian itu.\qt@no{55}}%
\qt@newcmd\qurantrans@id@mmmccxv{%
(Maka tidak lain jawaban kaumnya melainkan mengatakan ``Usirlah Luth beserta keluarganya) (dari negeri kalian, karena sesungguhnya mereka itu orang-orang yang mengklaim dirinya bersih") dari dubur kaum laki-laki, yakni tidak mau melakukan homosex.\qt@no{56}}%
\qt@newcmd\qurantrans@id@mmmccxvi{%
(Maka Kami selamatkan dia beserta keluarganya kecuali istrinya, Kami telah menakdirkan dia) telah memastikannya (termasuk orang-orang yang tertinggal) tetap terkena azab.\qt@no{57}}%
\qt@newcmd\qurantrans@id@mmmccxvii{%
(Dan Kami turunkan hujan atas mereka) berupa batu dari sijjil, maka binasalah mereka (maka amat buruklah) seburuk-buruk (hujan yang ditimpakan atas orang-orang yang diberi peringatan itu) yaitu hujan azab yang ditimpakan atas mereka.\qt@no{58}}%
\qt@newcmd\qurantrans@id@mmmccxviii{%
(Katakanlah) hai Muhammad!, ("Segala puji bagi Allah) atas binasanya orang-orang kafir dari umat-umat terdahulu (dan kesejahteraan atas hamba-hamba-Nya yang dipilih-Nya) yakni mereka yang dipilih-Nya (Apakah Allah) Allah dapat dibaca Tahqiq dan Tas-hil (yang lebih baik) bagi orang yang menyembah-Nya (ataukah apa yang mereka persekutukan dengan Dia) dapat dibaca, Yusyrikuna dan Tusyrikuna. Maksudnya apa yang dipersekutukan oleh para kuffar Mekah yaitu berhala-berhala. Apakah berhala-berhala itu lebih baik bagi para penyembahnya?\qt@no{59}}%
\qt@newcmd\qurantrans@id@mmmccxix{%
(Atau siapakah yang telah menciptakan langit dan bumi dan yang menurunkan air dari langit buat kalian, lalu Kami tumbuhkan) di dalam ungkapan ini terdapat Iltifat yakni sindiran dari Ghaibah kepada Mutakallim (dengan air itu kebun-kebun) lafal Hada-iq bentuk jamak dari lafal Hadiqatun artinya kebun yang dipagari (yang berpemandangan indah) tampak indah (yang kalian sekali-kali tidak mampu menumbuhkan pohon-pohonnya?) karena kalian tidak akan mempunyai kemampuan dan kekuasaan untuk itu. (Apakah ada tuhan) a-ilahun dapat dibaca Tahqiq dan Tas-hil (di samping Allah) yang membantu-Nya untuk melakukan hal-hal tersebut? Maksudnya tidak ada tuhan lain di samping Dia. (Bahkan sebenarnya mereka adalah orang-orang yang menyimpang) yakni menyekutukan Allah dengan selain-Nya.\qt@no{60}}%
\qt@newcmd\qurantrans@id@mmmccxx{%
(Atau siapakah yang telah menjadikan bumi sebagai tempat berdiam) sehingga ia tidak menggoncangkan penduduknya (dan yang menjadikan di cekah-celahnya) yakni di antara celah-celahnya (sungai-sungai dan yang menjadikan gunung-gunung untuk mengokohkannya) sebagai pengokoh Bumi (dan menjadikan suatu pemisah antara dua laut) antara air tawar dan air asin, satu sama lainnya tidak bercampur baur. (Apakah di samping Allah ada tuhan yang lain? Bahkan sebenarnya kebanyakan dari mereka tidak mengetahui) keesaaan-Nya\qt@no{61}}%
\qt@newcmd\qurantrans@id@mmmccxxi{%
(Atau siapakah yang memperkenankan doa orang yang dalam kesulitan) orang yang sengsara kemudian tertimpa kemudaratan (apabila ia berdoa kepada-Nya, dan yang menghilangkan kesusahan) dari dirinya dan dari diri orang selainnya (dan yang menjadikan kalian sebagai khalifah di bumi) Idhafah dalam lafal Khulafa-al Ardhi mengandung makna Fi. Maksudnya. setiap generasi menjadi pengganti generasi sebelumnya. (Apakah di samping Allah ada tuhan yang lain? Amat sedikitlah kalian mengingati-Nya) mengambil pelajaran dari hal ini. Lafal Tadzakkaruna dapat pula dibaca Yadzdzakkaruna; kemudian huruf Ta di-idgham-kan kepada huruf Dzal. Dan huruf Ma di sini untuk menunjukkan makna sedikit sekali. bintang sebagai pemandunya di waktu tengah malam, dan, dengan tanda-tanda yang ada di daratan di waktu siang hari\qt@no{62}}%
\qt@newcmd\qurantrans@id@mmmccxxii{%
(Atau siapakah yang memimpin kalian) yakni yang membimbing kalian kepada tujuan-tujuan kalian (dalam kegelapan di daratan dan lautan) dengan bintang-bintang sebagai pemandunya di waktu tengah malam dan dengan tanda-tanda yang ada di daratan di waktu siang hari (dan siapa pulakah yang mendatangkan angin sebagai kabar gembira sebelum kedatangan rahmat-Nya) sebelum hujan tiba (Apakah di samping Allah ada tuhan yang lain? Maha Tinggi Allah terhadap apa yang mereka persekutukan) dengan-Nya.\qt@no{63}}%
\qt@newcmd\qurantrans@id@mmmccxxiii{%
(Atau siapakah yang menciptakan manusia dari permulaannya) di dalam rahim, yakni dari air mani (kemudian mengulanginya lagi) menghidupkannya kembali sesudah mati, sekalipun kalian tidak mengakui adanya hari berbangkit itu, karena bukti-bukti yang menunjukkannya telah jelas (dan siapa pula yang memberikan rezeki dari langit) melalui hujan (dan bumi?) melalui tumbuh-tumbuhan. (Apakah di samping Allah ada tuhan yang lain?") maksudnya, tidak ada yang dapat melakukan sedikit pun dari hal-hal yang telah disebutkan tadi melainkan hanya Allah semata, dan tiada Tuhan selain-Nya. (Katakanlah) hai Muhammad!, ("Unjukkanlah bukti kebenaran kalian) argumentasi kalian (jika kalian memang orang-orang yang benar") bahwasanya di samping-Ku ada tuhan lain yang mampu berbuat sesuatu dari hal-hal yang telah disebutkan tadi. Kemudian orang-orang kafir itu bertanya kepada Nabi saw. tentang waktu kiamat, maka turunlah firman-Nya,\qt@no{64}}%
\qt@newcmd\qurantrans@id@mmmccxxiv{%
(Katakanlah!, ``Tidak ada seorang pun di langit dan di bumi yang mengetahui) baik dari kalangan para Malaikat maupun manusia (perkara yang gaib) dari mereka (kecuali) hanya (Allah saja) yang mengetahuinya (dan mereka tidak mengetahui) maksudnya orang-orang kafir Mekah sama pula dengan orang-orang selain mereka (bila) kapan waktunya (mereka dibangkitkan hidup kembali.")\qt@no{65}}%
\qt@newcmd\qurantrans@id@mmmccxxv{%
(Apakah) lafal Bal di sini bermakna Hal, yakni apakah (sampai ke sana) lafal Iddaraka pada asalnya adalah Tadaraka, kemudian huruf Ta diganti menjadi Dal kemudian di-idgam-kan kepada Dal, lalu ditariklah Hamzali Washal, artinya sama dengan lafal Balagha, Lahiqa, atau Tataba'a dan Talahaqa, yaitu, sampai ke sana. Menurut qiraat yang lain dibaca Adraka menurut wazan Akrama, sehingga artinya menjadi, Apakah telah sampai ke sana (pengetahuan mereka tentang akhirat?) yakni mengenai hari akhirat, sehingga mereka menanyakan tentang kedatangannya. Pada kenyataannya tidaklah demikian (sebenarnya mereka ragu-ragu tentang akhirat itu, bahkan mereka buta daripadanya) 'Amuna berasal dari kata Umyul Qalbi yang artinya buta hatinya; pengertian ungkapan ini lebih mengena daripada kalimat sebelumnya. Pada asalnya lafal 'Amuna adalah 'Amiyuna, oleh karena harakat Dhammah atas Ya dianggap berat untuk diucapkan, maka harakat Dhammah-nya dipindahkan kepada Mim, hal ini dilakukan sesudah terlebih dahulu harakat Kasrah-nya dibuang, sehingga jadilah 'Amuna.\qt@no{66}}%
\qt@newcmd\qurantrans@id@mmmccxxvi{%
Berkata pula orang-orang kafir) yang mengingkari adanya hari berbangkit ("Apakah setelah kita menjadi tanah dan begitu pula bapak-bapak kita; apakah sesungguhnya kita akan dikeluarkan kembali?) dari kuburan kita, maksudnya akan dihidupkan kembali.\qt@no{67}}%
\qt@newcmd\qurantrans@id@mmmccxxvii{%
(Sesungguhnya kami telah diberi ancaman dengan ini dan juga bapak-bapak kami dahulu, tiada lain) yakni tidak lain (ini hanyalah dongeng-dongengan orang dahulu kala") lafal Asathir bentuk jamak dari lafal Usthurah, artinya dongeng yang tidak ada kenyataannya, atau cerita dusta.\qt@no{68}}%
\qt@newcmd\qurantrans@id@mmmccxxviii{%
(Katakanlah!, ``Berjalanlah kalian di muka bumi, lalu perhatikanlah bagaimana akibat orang-orang yang berdosa) karena ingkar kepada adanya hari berbangkit, yaitu dibinasakan-Nya mereka oleh azab-Nya.\qt@no{69}}%
\qt@newcmd\qurantrans@id@mmmccxxix{%
(Dan janganlah kamu berduka cita terhadap mereka dan janganlah dadamu merasa sempit terhadap apa yang mereka tipu dayakan") ayat ini merupakan hiburan dan penenang hati Nabi saw. Maksudnya, janganlah kamu hiraukan makar mereka terhadap dirimu, karena sesungguhnya Kami akan menolong kamu dari mereka.\qt@no{70}}%
\qt@newcmd\qurantrans@id@mmmccxxx{%
(Dan mereka berkata, ``Bilakah datangnya ancaman itu) azab yang diancamkan itu (jika memang kamu orang-orang yang benar.") di dalam pengakuanmu itu.\qt@no{71}}%
\qt@newcmd\qurantrans@id@mmmccxxxi{%
(Katakanlah!, ``Mungkin telah hampir datang) artinya telah dekat (kepada kalian sebagian dari azab yang kalian minta supaya disegerakan itu.") maka terjadilah hal itu, yaitu dengan dibunuhnya mereka dalam perang Badar, sedangkan azab yang lainnya akan menimpa mereka sesudah mereka mati.\qt@no{72}}%
\qt@newcmd\qurantrans@id@mmmccxxxii{%
(Dan sesungguhnya Rabbmu, benar-benar mempunyai karunia yang besar yang diberikan-Nya kepada manusia) antara lain; penangguhan azab atas orang-orang kafir (tetapi kebanyakan mereka tidak mensyukurinya) orang-orang kafir tidak mensyukuri ditangguhkannya azab atas mereka, karena mereka tidak mempercayai akan adanya azab itu.\qt@no{73}}%
\qt@newcmd\qurantrans@id@mmmccxxxiii{%
(Dan sesungguhnya Rabbmu, benar-benar mengetahui apa yang disembunyikan hati mereka) maksudnya apa yang tersimpan di dalam hati mereka (dan apa yang mereka nyatakan) melalui lisan-lisan mereka.\qt@no{74}}%
\qt@newcmd\qurantrans@id@mmmccxxxiv{%
(Tiada sesuatu pun yang gaib di langit dan di bumi) huruf Ha pada lafal Ghaibah untuk menunjukkan makna Mubalaghah atau sangat, maksudnya sangat gaib di mata manusia (melainkan terdapat dalam kitab yang nyata) yakni Lohmahfuz dan rahasia ilmu Allah swt. antara lain diazabnya orang-orang kafir.\qt@no{75}}%
\qt@newcmd\qurantrans@id@mmmccxxxv{%
(Sesungguhnya Alquran ini menjelaskan kepada Bani Israel) yang ada di zaman Nabi saw. (sebagian besar dari perkara-perkara yang mereka berselisih tentangnya) dengan menjelaskan hal tersebut sesuai dengan kedudukannya, sehingga hilanglah semua perselisihan yang ada pada mereka, jika mereka mau mengambilnya dan masuk Islam.\qt@no{76}}%
\qt@newcmd\qurantrans@id@mmmccxxxvi{%
Dan sesungguhnya Alquran itu benar-benar menjadi petunjuk) dari kesesatan (dan rahmat bagi orang-orang yang beriman) yakni terhindar dari azab.\qt@no{77}}%
\qt@newcmd\qurantrans@id@mmmccxxxvii{%
(Sesungguhnya Rabbmu akan menyelesaikan perkara di antara mereka) sama dengan orang-orang selain mereka, kelak di hari kiamat (dengan keputusan-Nya) dengan keadilan-Nya. (Dan Dia-lah yang Maha Perkasa) Maha Menang (lagi Maha Mengetahui) tentang ketentuan yang akan diputuskan-Nya, tidak mungkin bagi seorang pun menentangnya, tidak sebagaimana di dunia di mana orang-orang kafir masih dapat menentang Nabi-nabi-Nya.\qt@no{78}}%
\qt@newcmd\qurantrans@id@mmmccxxxviii{%
(Sebab itu bertakwalah kepada Allah) percayakanlah kepada-Nya (sesungguhnya kamu berada di atas kebenaran yang nyata) yakni agama yang nyata, maka akibatnya kamulah yang akan mendapat kemenangan atas orang-orang kafir. Kemudian pada ayat selanjutnya Allah membuat perumpamaan tentang orang-orang kafir, sebagai orang-orang mati, tuli dan buta, untuk itu Allah swt. berfirman,\qt@no{79}}%
\qt@newcmd\qurantrans@id@mmmccxxxix{%
("Sesungguhnya kamu tidak dapat menjadikan orang-orang yang mati mendengar dan tidak pula menjadikan orang-orang yang tuli mendengar panggilan, apabila) dapat dibaca Tahqiq dan Tas-hil (mereka telah berpaling membelakang).\qt@no{80}}%
\qt@newcmd\qurantrans@id@mmmccxl{%
Dan kamu sekali-kali tidak dapat memimpin orang-orang buta dari kesesatan mereka, tidak lain kamu hanya dapat membuat mendengar) dengan pendengaran yang disertai pemahaman dan mau menerima apa yang didengarnya yaitu (orang-orang yang beriman kepada ayat-ayat Kami) kepada Alquran (lalu mereka berserah diri) mengikhlaskan diri mereka untuk mentauhidkan Allah.\qt@no{81}}%
\qt@newcmd\qurantrans@id@mmmccxli{%
(Dan apabila perkataan telah jatuh atas mereka) yakni azab telah pasti menimpa mereka termasuk orang-orang kafir lainnya. (Kami keluarkan sejenis binatang melata dari bumi yang akan mengatakan kepada mereka) yaitu akan berbicara kepada orang-orang yang ada dari kalangan mereka; sewaktu binatang melata itu keluar ia langsung berbicara kepada mereka dengan memakai bahasa Arab. Dan garis besar dari apa yang dikatakannya itu ialah (bahwa sesungguhnya manusia) orang-orang kafir Mekah. Lafal Anna menurut qiraat yang lain dibaca Inna; qiraat ini dapat dipakai pula bilamana diperkirakan adanya huruf Ba sesudah lafal Tukallimuhum (dahulu tidak yakin kepada ayat-ayat Kami.") mereka tidak beriman kepada Alquran yang di dalamnya disebutkan tentang adanya hari berbangkit, hari hisab amal perbuatan dan hari pembalasan. Dengan keluarnya binatang melata ini, maka terhentilah fungsi Amar Makruf dan Nahi Mungkar dan orang kafir yang beriman pada saat itu tidak dianggap lagi keimanannya, sebagaimana yang telah diwahyukan oleh Allah swt. kepada Nabi Nuh melalui firman-Nya, ``Bahwasanya sekali-kali, tidak akan beriman di antara kaummu, kecuali orang-orang yang telah beriman saja." (Q.S. 11 Hud, 36).\qt@no{82}}%
\qt@newcmd\qurantrans@id@mmmccxlii{%
(Dan) ingatlah (hari ketika Kami kumpulkan dari tiap-tiap umat segolongan) yakni sekumpulan (orang-orang yang mendustakan ayat-ayat Kami) mereka adalah pemimpin-pemimpin yang menjadi panutannya (lalu mereka dibagi-bagi) dikumpulkan dalam kelompok-kelompok kemudian mereka digiring.\qt@no{83}}%
\qt@newcmd\qurantrans@id@mmmccxliii{%
Sehingga apabila mereka datang) di tempat perhitungan amal perbuatan (Allah berfirman) kepada mereka, ("Apakah kalian telah mendustakan) nabi-nabi-Ku yang membawa (ayat-ayat-Ku, padahal tidak sampai ke sana) disebabkan kalian tidak mempercayainya (ilmu kalian, atau apakah) pada lafal Amma ini terdapat Ma Istifham yang diidgamkan kepada Am (yang) Dza di sini merupakan Isim Maushul, artinya apakah yang (telah kalian kerjakan?") dari apa yang telah diperintahkan kepada kalian untuk melakukannya.\qt@no{84}}%
\qt@newcmd\qurantrans@id@mmmccxliv{%
(Dan jatuhlah perkataan) yakni telah pasti azab (atas mereka disebabkan kelaliman mereka) disebabkan kemusyrikan mereka (maka mereka tidak dapat berkata apa-apa) karena mereka tidak mempunyai argumentasi.\qt@no{85}}%
\qt@newcmd\qurantrans@id@mmmccxlv{%
(Apakah mereka tidak memperhatikan, bahwa sesungguhnya Kami telah menjadikan) maksudnya telah menciptakan (malam supaya mereka beristirahat padanya) sama dengan orang-orang lain (dan siang yang menerangi?) supaya mereka dapat berusaha padanya. (Sesuugguhnya pada yang demikian itu terdapat tanda-tanda) yang menunjukkan kekuasaan Allah swt. (bagi orang-orang yang beriman) di sini hanya disebutkan mereka yang beriman, karena hanya mereka sajalah yang dapat mengambil manfaat dari hal ini untuk mempertebal keimanan mereka, berbeda halnya dengan orang-orang kafir.\qt@no{86}}%
\qt@newcmd\qurantrans@id@mmmccxlvi{%
(Dan hari ketika ditiup sangkakala) tiupan sangkakala malaikat Israfil yang pertama (maka terkejutlah segala yang di langit dan segala yang di bumi) mereka ketakutan, sehingga ketakutan itu mematikan mereka, sebagaimana yang diungkapkan oleh ayat lainnya, yaitu dengan ungkapan Sha'iqa, yakni terkejut yang mematikan. Dan ungkapan dalam ayat ini dipakai Fi'il Madhi untuk menggambarkan kepastian terjadinya hal ini (kecuali siapa yang dikehendaki Allah) yaitu malaikat Jibril, malaikat Mikail, malaikat Israfil dan malaikat Maut. Tetapi menurut suatu riwayat yang bersumber dari sahabat Ibnu Abbas disebutkan, bahwa mereka yang tidak terkejut adalah para Syuhada, karena mereka hidup di sisi Rabb mereka dengan diberi rezeki. (Dan semua mereka) lafal Kullun ini harakat Tanwinnya merupakan pergantian daripada Mudhaf Ilaih, artinya mereka semua sesudah dihidupkan kembali di hari kiamat (datang menghadap kepada-Nya) dapat dibaca Atauhu dan Atuhu (dengan merendahkan diri) artinya merasa rendah diri. Dan ungkapan lafal Atauhu dengan memakai Fi'il Madhi untuk menunjukkan, bahwa hal itu pasti terjadi.\qt@no{87}}%
\qt@newcmd\qurantrans@id@mmmccxlvii{%
(Dan kamu lihat gunung-gunung itu) yakni kamu saksikan gunung-gunung itu sewaktu terjadinya tiupan malaikat Israfil (kamu sangka dia) (tetap) diam di tempatnya karena besarnya (padahal ia berjalan sebagai jalannya awan) bagaikan hujan yang tertiup angin, maksudnya gunung-gunung itu tampak seolah-olah tetap, padahal berjalan lambat saking besarnya, kemudian jatuh ke bumi lalu hancur lebur kemudian menjadi abu bagaikan bulu-bulu yang beterbangan. (Begitulah perbuatan Allah) lafal Shun'a merupakan Mashdar yang mengukuhkan jumlah sebelumnya yang kemudian di-mudhaf-kan kepada Fa'il-nya Sesudah 'Amil-nya dibuang, bentuk asalnya ialah Shana'allahu Dzalika Shun'an. Selanjutnya hanya disebutkan lafal Shun'a yang kemudian dimudhaf-kan kepada Fa'il-nya yaitu lafal Allah, sehingga jadilah Shun'allahi; artinya begitulah perbuatan Allah (yang membuat dengan kokoh) rapih dan kokoh (tiap-tiap sesuatu) yang dibuat-Nya (sesungguhnya Allah Maha Mengetahui apa yang kalian kerjakan) lafal Taf'aluna dapat dibaca Yaf'aluna, yakni perbuatan maksiat yang dilakukan oleh musuh-musuh-Nya dan perbuatan taat yang dilakukan oleh kekasih-kekasih-Nya.\qt@no{88}}%
\qt@newcmd\qurantrans@id@mmmccxlviii{%
(Barang siapa yang membawa kebaikan) yakni membawa pengamalan kalimah ``La ilaha illallah" kelak di hari kiamat (maka ia memperoleh kebaikan) pahala (daripadanya) disebabkan, lafal Khairun di sini bukan mengandung arti Tafdhil, karena tiada suatu pekerjaan pun yang lebih baik daripadanya. Di dalam ayat lain disebutkan bahwa pahala itu ialah sepuluh kali lipat daripadanya (sedangkan mereka) orang-orang yang datang membawanya (daripada kejutan yang dahsyat pada hari itu) dapat dibaca Faza'i Yaumaidzin dan Faza'in Yaumaidzin (merasa aman tenteram).\qt@no{89}}%
\qt@newcmd\qurantrans@id@mmmccxlix{%
(Dan barang siapa yang membawa kejahatan) yakni kemusyrikan (maka disungkurkanlah muka mereka ke dalam neraka) disebabkan berpaling daripadanya. Di sini hanya disebutkan muka, karena merupakan anggota tubuh yang paling mulia, pengertiannya; semua anggota tubuhnya lebih disungkurkan lagi. Kemudian dikatakan kepada mereka dengan nada mencemoohkan. (Tiadalah kalian dibalasi melainkan) pembalasan yang setimpal (dengan apa yang dahulu kamu sekalian kerjakan) berupa kemusyrikan dan kemaksiatan. Katakanlah kepada mereka,\qt@no{90}}%
\qt@newcmd\qurantrans@id@mmmccl{%
("Aku hanya diperintahkan untuk menyembah Rabb negeri ini) yakni Mekah (yang telah menjadihannya kota suci) suci dan aman, tidak boleh dialirkan darah manusia di dalamnya, dan tidak boleh seseorang pun dianiaya, serta binatang buruannya tidak boleh diburu dan pepohonannya tidak boleh ditebang. Yang demikian itu merupakan nikmat-nikmat Allah yang dilimpahkan kepada kabilah Quraisy sebagai penduduknya, sehingga Allah tidak menurunkan azab atas negeri mereka dan selamat Pula dari fitnah-fitnah yang melanda kawasan negeri Arab lainnya (dan kepunyaan-Nya-lah) yakni kepunyaan Allah swt. (segala sesuatu) Dia adalah Rabb, pencipta dan pemilik semuanya (dan aku diperintahkan supaya aku termasuk orang-orang yang berserah diri) kepada Allah yaitu dengan mentauhidkan-Nya.\qt@no{91}}%
\qt@newcmd\qurantrans@id@mmmccli{%
(Dan supaya aku membacakan Alquran) kepada kalian dengan bacaan yang mengajak kalian untuk beriman (Maka barang siapa yang mendapat petunjuk) dari Alquran (maka sesungguhnya ia hanyalah mendapat petunjuk untuk kebaikan dirinya) karena dia sendirilah yang mendapat kan pahalanya (dan barang siapa yang sesat) dari jalan iman, dan sesat dari jalan petunjuk (maka katakanlah) kepadanya, ('Sesungguhnya aku ini tidak lain hanyalah salah seorang pemberi peringatan.'") yang menakut-nakuti kalian, maka tidak ada hak bagiku melainkan hanya menyampaikan saja. Ayat ini diturunkan sebelum ada perintah dari Allah untuk berperang.\qt@no{92}}%
\qt@newcmd\qurantrans@id@mmmcclii{%
(Dan katakanlah!, ``Segala puji bagi Allah, Dia akan memperlihatkan kepada kalian tanda-tanda kebesaran-Nya, maka kalian akan mengetahuinya) Allah memperlihatkannya kepada mereka dalam perang Badar, yaitu dengan dibunuhnya mereka dan sebagian lagi ada yang tertawan, serta para Malaikat memukuli muka dan belakang mereka, dan Allah menyegerakan mereka untuk masuk ke dalam neraka. (Dan Rabbmu tiada lalai dari apa yang kalian kerjakan.") lafal Taa'maluna dapat dibaca Ya'maluna. Dan sesungguhnya Allah menangguhkan mereka hanya sampai pada saatnya saja.\qt@no{93}}%
\qt@newcmd\qurantrans@id@mmmccliii{%
\basmalahid (Tha Sin Mim) hanya Allah-lah yang mengetahui maksudnya.\qt@no{1}}%
\qt@newcmd\qurantrans@id@mmmccliv{%
(Ini adalah) (ayat-ayat Kitab) sebagian dari Alquran (yang nyata) untuk membedakan antara perkara yang hak dengan perkara yang batil.\qt@no{2}}%
\qt@newcmd\qurantrans@id@mmmcclv{%
(Kami membacakan) Kami menceritakan (kepadamu sebagian dari kisah) yakni cerita (Musa dan Firaun dengan benar) dengan sebenarnya (untuk orang-orang yang beriman) untuk kepentingan mereka, karena hanya merekalah orang-orang yang dapat mengambil manfaat daripadanya.\qt@no{3}}%
\qt@newcmd\qurantrans@id@mmmcclvi{%
(Sesungguhnya Firaun telah berbuat sewenang-wenang) yaitu berbuat zalim (di muka bumi) di negeri Mesir (dan menjadikan penduduknya berpecah-belah) maksudnya terpecah-pecah, semuanya berkhidmat kepada dirinya (dengan menindas segolongan dari mereka) yakni kaum Bani Israel (menyembelih anak laki-laki mereka) yang baru dilahirkan (dan membiarkan hidup anak-anak perempuan mereka) karena juru peramal telah mengatakan kepada Firaun, bahwa akan ada seorang anak lelaki yang akan dilahirkan di Bani Israel, ia bakal menjadi penyebab hilangnya takhta kerajaan. (Sesungguhnya Firaun termasuk orang-orang yang berbuat kerusakan) yakni gemar membunuh dan melakukan perbuatan-perbuatan kejam lainnya\qt@no{4}}%
\qt@newcmd\qurantrans@id@mmmcclvii{%
(Dan Kami hendak memberi karunia kepada orang-orang yang tertindas di bumi Mesir itu dan hendak menjadikan mereka pemimpin) menjadi panutan dalam hal kebaikan; lafal A-immatan dapat dibaca Tahqiq dan Tas-hil (dan menjadikan mereka orang-orang yang mewarisi) kerajaan Firaun.\qt@no{5}}%
\qt@newcmd\qurantrans@id@mmmcclviii{%
(Dan akan Kami teguhkan kedudukan mereka di muka bumi) di negeri Mesir dan negeri Syam (Dan akan Kami perlihatkan kepada Firaun dan Haman beserta tentaranya) menurut qiraat yang lain dibaca Wa Yara Firaunu Wa Hamanu Wa Junuduhuma (apa yang selalu mereka khawatirkan dari mereka itu) tentang bayi yang akan lahir, yang kelak akan melenyapkan kerajaannya.\qt@no{6}}%
\qt@newcmd\qurantrans@id@mmmcclix{%
(Dan kami ilhamkan) wahyu berupa ilham atau ilham melalui mimpi (kepada ibu Musa) Musa adalah bayi yang dimaksud oleh peramal Firaun, dan tidak ada seorang pun mengetahui kelahirannya selain saudara perempuannya sendiri. ("Susukanlah dia! Apabila kamu khawatir terhadapnya maka hanyutkanlah dia ke dalam sungai) yakni sungai Nil (dan janganlah kamu khawatir) ia akan tenggelam (dan janganlah bersedih hati) karena berpisah dengan bayimu itu (karena sesungguhnya Kami akan mengembalikannya kepadamu, dan menjadikannya salah seorang dari para Rasul.") maka ibu Musa menyusukan Musa selama tiga bulan, selama itu Musa tidak pernah menangis. Akhirnya ibu Musa merasa khawatir akan keselamatan Musa, lalu ia menaruh Musa yang masih bayi itu ke dalam sebuah peti dilapisi dengan ter/aspal sebelah dalamnya, supaya air jangan masuk lalu dihanyutkan ke sungai Nil, di waktu malam hari.\qt@no{7}}%
\qt@newcmd\qurantrans@id@mmmcclx{%
(Maka ia dipungut) berikut petinya pada keesokan harinya (oleh keluarga) yakni pembantu-pembantu (Firaun) lalu peti itu diletakkan di hadapan Firaun dan Musa dikeluarkan dari dalam peti, di kala itu Musa sedang mengisap jempolnya dari jempol itu keluar air susu (yang akibatnya dia bagi mereka akan menjadi) pada akhirnya Musa akan menjadi (musuh) kelak akan membunuh kaum laki-laki mereka (dan kesedihan) karena akan menindas kaum wanita mereka. Lafal Hazanan di sini bermakna Isim Fa'il karena diambil dari lafal Hazinahu yang semakna dengan lafal Ahzanahu. (Sesungguhnya Firaun dan Haman) pembantu Firaun (beserta tentaranya adalah orang-orang yang bersalah). Lafal Khathi-ina berasal dari Al Khathi-ah, artinya orang-orang yang durhaka, maka mereka dihukum oleh perbuatannya sendiri.\qt@no{8}}%
\qt@newcmd\qurantrans@id@mmmcclxi{%
(Dan istri Firaun berkata) di kala Firaun beserta para pembantunya sudah bersiap-siap akan membunuh bayi itu, ``Ia adalah (biji mata bagiku dan bagimu, janganlah kalian membunuhnya, mudah-mudahan ia bermanfaat kepada kita atau kita ambil ia menjadi anak") akhirnya mereka menuruti kemauan istri Firaun itu (sedangkan mereka tiada menyadari) akibat dari perkara mereka dengan bayi itu.\qt@no{9}}%
\qt@newcmd\qurantrans@id@mmmcclxii{%
(Dan hati ibu Musa menjadi) setelah ia mengetahui bahwa bayinya telah diambil (kosong) tidak memikirkan selain daripada bayinya. (Sesungguhnya) lafal in di sini adalah bentuk Takhfif daripada Inna, sedangkan Isimnya dibuang, pada asalnya adalah Innaha, yakni sesungguhnya ibu Musa (hampir saja ia menyatakan rahasia tentang Musa) bahwa bayi itu adalah anaknya (seandainya tidak Kami teguhkan hatinya) dengan kesabaran, yakni Kami jadikan hatinya tenang (supaya ia termasuk orang-orang yang percaya) kepada janji Allah. Jawab dari lafal Laula dapat disimpulkan dari pengertian kalimat sebelumnya.\qt@no{10}}%
\qt@newcmd\qurantrans@id@mmmcclxiii{%
(Dan ibu Musa berkata kepada saudara perempuan Musa) bernama Maryam, ("Ikutilah dia") maksudnya ikutilah jejaknya sehingga kamu mengetahui bagaimana kesudahan beritanya. (Maka kelihatanlah olehnya Musa) dia mengawasinya (dari jauh) dari tempat yang jauh seraya menguntitnya (sedangkan mereka tidak mengetahui) bahwa dia adalah saudara perempuan dari bayi tersebut, dan bahwasanya keberadaannya itu adalah untuk mengikuti jejaknya.\qt@no{11}}%
\qt@newcmd\qurantrans@id@mmmcclxiv{%
(Dan Kami cegah Musa menyusu kepada perempuan-perempuan yang mau menyusukannya sebelum itu) maksudnya sebelum ia kembali berada di tangan ibunya. Yakni, Kami cegah dia untuk menerima air susu perempuan-perempuan yang mau menyusuinya selain dari air susu ibunya sendiri. Maka Nabi Musa menolak semua air susu perempuan-perempuan yang dihadirkan untuk menyusuinya (maka berkatalah ia) yakni saudara perempuan Musa, ("Maukah kalian aku tunjukkan kepada ahlul bait) ketika dia melihat mereka menaruh rasa belas kasihan kepada Musa (yang akan memeliharanya untuk kalian) yakni, yang akan menyusuinya dan mengurusnya (dan mereka dapat berlaku baik kepadanya?") menurut penafsiran lain Dhamir Lahu kembali kepada Raja Firaun, sebagai reaksi dari para pembantunya. Maksudnya setelah mereka mendengar usul saudara Musa, maka mereka menyetujui dan memperkuatnya dengan mengatakannya pula kepada Raja Firaun. Akhirnya permintaan Maryam dikabulkan, ia datang membawa ibu Musa, ternyata Musa mau menerima air susunya. Kemudian Maryam. memberikan pendapat kepada mereka, bahwa ibu Musa adalah seorang wanita yang harum baunya dan baik air susunya. Maka ibu Musa diizinkan untuk menyusuinya di rumahnya sendiri, akhirnya ibu Musa kembali membawa bayinya. Sebagaimana yang diungkapkan oleh firman-Nya,\qt@no{12}}%
\qt@newcmd\qurantrans@id@mmmcclxv{%
(Maka Kami kembalikan Musa kepada ibunya supaya senang hatinya) karena bertemu kembali dengannya (dan tidak berduka cita) setelah itu (dan supaya ia mengetahui bahwa janji Allah itu) yang akan mengembalikan Musa kepadanya (adalah benar, tetapi kebanyakan mereka) yakni manusia (tidak mengetahui) janji ini, dan mereka tidak pula mengetahui, bahwa Maryam adalah saudara Musa dan wanita yang dibawanya adalah ibunya sendiri. Kemudian Musa tinggal bersama ibunya sampai masa penyapihan; setiap hari ibu Musa menerima upah pekerjaan menyusuinya sebanyak satu Dinar. Ibu Musa mau menerimanya karena menganggap bahwa uang itu adalah harta perang. Setelah itu ia membawanya kembali kepada Firaun, sejak itu Musa dibesarkan di lingkungan istana Firaun, sebagaimana yang telah diungkapkan oleh firman-Nya sewaktu menceritakan tentang Musa dalam surah Asy Syu'ara, yaitu, ``Bukankah kami telah mengasuhmu di dalam (keluarga) kami waktu kamu masih kanak-kanak dan kamu tinggal bersama kami beberapa tahun dari umurmu." (Q.S. Asy Syu'ara, 18).\qt@no{13}}%
\qt@newcmd\qurantrans@id@mmmcclxvi{%
(Dan setelah Musa cukup umur) telah mencapai umur tiga puluh tahun atau tiga puluh tiga tahun (dan sempurna akalnya) yaitu telah mencapai umur empat puluh tahun (Kami berikan kepadanya hikmah) yakni kebijaksanaan (dan ilmu) yaitu pengetahuan tentang agama sebelum ia diutus menjadi Nabi. (Dan demikianlah) Kami memberikan balasan kepada Musa (Kami memberi balasan kepada orang-orang yang berbuat baik) untuk diri mereka sendiri.\qt@no{14}}%
\qt@newcmd\qurantrans@id@mmmcclxvii{%
(Dan masuklah) Musa (ke kota) yakni ke kota Firaun, yaitu kota Memphis, sesudah sekian lama ia meninggalkannya (ketika penduduknya sedang lengah) yaitu, pada saat orang-orang istirahat di siang hari (maka didapatinya di dalam kota itu dua orang laki-laki yang berkelahi; yang seorang dari bangsanya) dari kalangan Bani Israel (dan seorang lagi dari musuhnya) yakni, seorang bangsa Mesir. Pada mulanya orang Mesir itu menghina warga Bani Israel itu sewaktu orang Mesir itu menyuruhnya untuk membawa kayu bakar ke dapur raja Firaun. (Maka orang yang dari bangsanya meminta pertolongan kepadanya, untuk mengalahkan orang yang dari musuhnya) Musa berkata kepada orang Mesir itu, ``Lepaskanlah dia dan biarkan dia pergi!". Menurut suatu riwayat disebutkan, bahwa orang Mesir itu berkata kepada Musa, ``Sungguh aku berniat untuk menyeretnya ke hadapanmu" (lalu Musa meninjunya) memukulnya dengan kepalan tangannya. Musa sangat kuat lagi keras pukulannya (dan musuhnya itupun mati). Musa telah membunuhnya, padahal Musa tidak bermaksud untuk membunuh, lalu ia menguburnya di dalam pasir (Musa berkata, ``Ini adalah) membunuh orang ini (perbuatan setan) yang telah menggelorakan amarahku (sesungguhnya setan itu adalah musuh) bagi anak Adam (yang menyesatkan) dia (lagi nyata.") permusuhannya.\qt@no{15}}%
\qt@newcmd\qurantrans@id@mmmcclxviii{%
(Musa berkata,) seraya menyesal ("Ya Rabbku! Sesungguhnya aku telah menganiaya diriku sendiri) karena telah membunuh orang Mesir itu (karena itu ampunilah aku." Maka Allah mengampuninya, Sesungguhnya Dia adalah Yang Maha Pengampun lagi Maha Penyayang). Dia bersifat demikian sejak zaman Azali dan untuk selama-lamanya.\qt@no{16}}%
\qt@newcmd\qurantrans@id@mmmcclxix{%
(Musa berkata, ``Ya Rabbku! Demi nikmat yang telah Engkau limpahkan) (kepadaku) berupa ampunan, peliharalah diriku ini (aku sekali-kali tiada akan menjadi penolong) yakni menjadi pembantu (bagi orang-orang yang berdosa.") yaitu orang-orang kafir sesudah peristiwa ini, jika Engkau memelihara diriku.\qt@no{17}}%
\qt@newcmd\qurantrans@id@mmmcclxx{%
(Karena itu, jadilah Musa di kota itu merasa takut menunggu-nunggu dengan khawatir) apa yang bakal dilakukan oleh keluarga orang yang telah dibunuhnya itu terhadap dirinya (maka tiba-tiba orang yang meminta pertolongan kemarin berteriak-teriak meminta pertolongan kepadanya) maksudnya minta tolong lagi dari orang Mesir yang lain. (Musa berkata kepadanya, ``Sesungguhnya kamu benar-benar orang sesat yang nyata.") kesesatannya, karena apa yang telah kamu perbuat kemarin dan sekarang ini.\qt@no{18}}%
\qt@newcmd\qurantrans@id@mmmcclxxi{%
(Maka tatkala) huruf An di sini adalah Zaidah (Musa hendak memegang dengan keras orang yang menjadi musuh keduanya) yakni, musuh Musa dan orang Mesir yang mengejarnya (musuhnya berkata) yaitu warga Bani Israel musuh orang Mesir yang meminta tolong kepadanya itu, karena ia menduga bahwa Musa akan memukulnya ("Hai Musa! Apakah kamu bermaksud hendak membunuhku, sebagaimana kamu kemarin telah membunuh seorang manusia? Tiadalah) yakni tidaklah (kamu bermaksud melainkan hendak menjadi orang yang berbuat sewenang-wenang di negeri ini dan tiadalah kamu hendak menjadi salah seorang dari orang-orang yang mengadakan perdamaian"). Ketika orang yang meminta tolong kepadanya mengatakan demikian, orang Mesir yang mengerjarnya itu mendengar apa yang dikatakannya, sehingga orang Mesir itu kini mengetahui, bahwa yang membunuh orang kemarin adalah Musa sendiri. Lalu ia pergi kepada Firaun dan menceritakan hal itu kepadanya. Firaun memerintahkan kepada algojo-algojonya untuk menangkap dan membunuh Nabi Musa. Dengan segera para algojo itu berangkat mencari Musa.\qt@no{19}}%
\qt@newcmd\qurantrans@id@mmmcclxxii{%
(Dan datanglah seorang laki-laki) dia adalah seorang yang beriman dari kalangan keluarga Firaun (dari ujung kota) dari batas kota (bergegas-gegas) berjalan cepat dengan memotong jalan (seraya berkata, ``Hai Musa! Sesungguhnya pembesar negeri) dari kalangan kaum Firaun (sedang berunding tentang kamu) maksudnya, mereka sedang bermusyawarah tentang dirimu (untuk membunuhmu, sebab itu keluarlah) dari kota ini (sesungguhnya aku termasuk orang-orang yang memberi nasihat.") yakni, saranku ini -perintah agar kamu keluar- adalah nasihat.\qt@no{20}}%
\qt@newcmd\qurantrans@id@mmmcclxxiii{%
(Maka keluarlah Musa dari kota itu dengan rasa takut menunggu-nunggu dengan khawatir) apakah dirinya akan dapat dikejar oleh orang-orang yang mencarinya atau pertolongan Allah datang menyelamatkan dirinya? (dia berdoa, ``Ya Rabbku! Selamatkanlah aku dari orang-orang yang zalim itu") yaitu, kaum Firaun.\qt@no{21}}%
\qt@newcmd\qurantrans@id@mmmcclxxiv{%
(Dan tatkala ia menghadap) yakni menuju (ke jurusan negeri Madyan) ke arahnya. Madyan adalah nama kota tempat nabi Syuaib, yang jauhnya kira-kira delapan hari perjalanan dari kota Mesir. Kota tersebut dinamai dengan nama pendirinya yaitu Madyan ibnu Ibrahim, sedangkan Nabi Musa belum mengetahui jalan menuju ke arahnya (ia berdoa lagi, ``Mudah-mudahan Rabbku memimpinku ke jalan yang benar") maksudnya, jalan yang menuju ke arah negeri Madyan yang tidak terlalu jauh dan juga tidak terlalu dekat, yakni pertengahan. Allah mengutus malaikat yang membawa tongkat, lalu malaikat itu memimpin Nabi Musa menuju ke negeri Madyan.\qt@no{22}}%
\qt@newcmd\qurantrans@id@mmmcclxxv{%
(Dan tatkala ia sampai di sumber air negeri Madyan) yaitu, sebuah sumur yang ada di negeri Madyan, makna yang dimaksud ialah dia telah sampai ke negeri Madyan (ia menjumpai di tempat itu sekumpulan) sekelompok (orang-orang yang sedang memberi minum) ternaknya (dan ia menjumpai di belakang orang banyak itu) selain mereka (dua orang wanita yang sedang menahan ternaknya) maksudnya mencegah ternaknya supaya jangan merebut bagian air minum ternak orang lain. (Musa berkata) kepada kedua wanita itu, ("Apakah gerangan yang terjadi pada kalian berdua?") maksudnya, mengapa kalian berdua tidak meminumkan ternak kalian berdua? (Kedua wanita itu menjawab, ``Kami tidak dapat meminumkannya sebelum penggembala-penggembala itu memulangkan ternaknya). Lafal Ar Ri'a bentuk jamak dari Ra'in artinya penggembala. Maksudnya, sebelum mereka selesai dari meminumkan ternaknya, karena keduanya takut berdesak-desakan; setelah mereka bubar, baru meminumkan ternaknya. Menurut qiraat yang lain dibaca Yushdira yang berasal dari Fi'il Ruba'i yakni Ashdara, maknanya ialah, sebelum mereka membubarkan ternaknya dari sumur itu (sedangkan bapak kami adalah orang tua yang telah lanjut umurnya") maksudnya, tidak mampu lagi untuk meminumkan ternaknya.\qt@no{23}}%
\qt@newcmd\qurantrans@id@mmmcclxxvi{%
(Maka Musa memberi minum ternak itu untuk menolong keduanya) dari air sumur lain yang berada di dekat sumur itu, kemudian Nabi Musa mengangkat batu besar yang menutupinya, konon batu itu hanya dapat diangkat oleh sepuluh orang yang kuat (kemudian ia kembali) setelah itu Musa kembali lagi (ke tempat yang teduh) di bawah pohon Samurah, karena pada saat itu hari sangat panas dan ia dalam keadaan lapar (lalu berdoa, ``Ya Rabbku! Sesungguhnya aku terhadap kebaikan yang Engkau turunkan kepadaku) yang dimaksud adalah makanan (sangat memerlukan.") sangat membutuhkannya. Lalu kedua wanita itu kembali ke rumah bapak mereka, kejadian ini membuat bapaknya terkejut, karena mereka berdua kembali lebih cepat dari biasanya. Maka bapaknya menanyakan tentang hal tersebut. Lalu diceritakan kepadanya tentang seorang lelaki yang telah menolongnya memberi minum ternaknya. Bapak mereka bertanya kepada salah seorang dari keduanya, ``Coba panggillah dia untuk menghadap kepadaku". Lalu Allah berfirman,\qt@no{24}}%
\qt@newcmd\qurantrans@id@mmmcclxxvii{%
(Kemudian datanglah kepada Musa salah seorang dari kedua wanita itu berjalan kemalu-maluan) seraya menutupkan kain kerudung ke mukanya karena malu kepada Nabi Musa (ia berkata, ``Sesungguhnya bapakku memanggil kamu agar ia memberikan balasan terhadap kebaikanmu memberi minum ternak kami") Nabi Musa memenuhi panggilannya dan menolak dalam hatinya upah yang akan diberikan kepadanya, karena seolah-olah wanita itu bermaksud hendak memberi upah dan menganggap dirinya sebagai seorang upahan. Kemudian wanita itu berjalan di muka Nabi Musa tiba-tiba angin meniup kainnya, sehingga terlihat kedua betisnya. Lalu Nabi Musa berkata kepadanya, ``Berjalanlah engkau di belakangku dan tunjukkanlah jalan itu kepadaku". Wanita itu menuruti apa yang dikatakan oleh Nabi Musa, sehingga Nabi Musa sampai ke tempat bapak wanita itu, dia adalah Nabi Syuaib a.s. Ketika Nabi Musa sampai di hadapannya ternyata telah disiapkan makan malam, maka Nabi Syuaib berkata, ``Duduklah, kemudian makan malamlah". Nabi Musa menjawab, ``Aku khawatir jika makan malam ini sebagai imbalan karena aku telah memberi minum ternak keduanya, sedangkan aku berasal dari ahlul bait yang tidak pernah meminta imbalan dari suatu pekerjaan yang baik". Nabi Syuaib berkata, ``Tidak, ini merupakan tradisiku dan tradisi nenek moyangku. Kami biasa menjamu tamu kami, juga biasa memberi makan". Nabi Musa baru mau memakannya dan menceritakan kepadanya semua apa yang telah ia alami. Untuk itu maka Allah swt. berfirman, ("Maka tatkala Musa mendatangi bapak wanita itu dan menceritakan kepadanya kisah mengenai dirinya) lafal Al Qashash adalah Mashdar yang bermakna Isim Maf'ul; maksudnya Nabi Musa menceritakan kepadanya tentang pembunuhannya terhadap seorang bangsa Mesir dan niat bangsa Mesir untuk membunuhnya, serta kekhawatirannya terhadap Firaun (Syuaib berkata, 'Janganlah kamu takut! Kamu telah selamat dari orang-orang yang zalim'.") karena tidak ada kekuasaan bagi Firaun atas negeri Madyan.\qt@no{25}}%
\qt@newcmd\qurantrans@id@mmmcclxxviii{%
(Salah seorang dari kedua wanita itu berkata) yakni wanita yang disuruh menjemput Nabi Musa yaitu yang paling besar atau yang paling kecil ("Ya bapakku! Ambillah dia sebagai orang yang bekerja pada kita) sebagai pekerja kita, khusus untuk menggembalakan kambing milik kita, sebagai ganti kami (karena sesungguhnya orang yang paling baik yang kamu ambil untuk bekerja pada kita ialah orang yang kuat lagi dapat dipercaya") maksudnya, jadikanlah ia pekerja padanya, karena dia adalah orang yang kuat lagi dapat dipercaya. Lalu Nabi Syuaib bertanya kepada anaknya tentang Nabi Musa. Wanita itu menceritakan kepada bapaknya semua apa yang telah dilakukan oleh Nabi Musa, mulai dari mengangkat bata penutup sumur, juga tentang perkataannya, ``Berjalanlah di belakangku". Setelah Nabi Syuaib mengetahui melalui cerita putrinya bahwa ketika putrinya datang menjemput Nabi Musa, Nabi Musa menundukkan pandangan matanya, hal ini merupakan pertanda bahwa Nabi Musa jatuh cinta kepada putrinya, maka Nabi Syuaib bermaksud mengawinkan keduanya.\qt@no{26}}%
\qt@newcmd\qurantrans@id@mmmcclxxix{%
(Berkatalah dia, ``Sesungguhnya aku bermaksud menikahkan kamu dengan salah seorang dari kedua anakku ini) yaitu yang paling besar atau yang paling kecil (atas dasar kamu bekerja denganku) yakni, menggembalakan kambingku (delapan tahun) selama delapan tahun (dan jika kamu cukupkan sepuluh tahun) yakni, menggembalakan kambingku selama sepuluh tahun (maka itu adalah suatu kebaikan dari kamu) kegenapan itu (maka aku tidak hendak memberati kamu) dengan mensyaratkan sepuluh tahun. (Dan kamu Insya Allah akan mendapatiku) lafal Insya Allah di sini maksudnya untuk ber-tabarruk (termasuk orang-orang yang baik") yaitu orang-orang yang menepati janjinya.\qt@no{27}}%
\qt@newcmd\qurantrans@id@mmmcclxxx{%
Musa (Berkata, ``Itulah) yakni perjanjian yang telah kamu katakan itu (antara aku dan kamu. Mana saja dari kedua waktu yang ditentukan itu) delapan atau sepuluh tahun masa penggembalaan itu; huruf Ma pada lafal Ayyama adalah huruf Zaidah (aku sempurnakan) aku selesaikan (maka tidak ada tuntutan atas diriku) artinya tuntutan tambahan waktu lain. (Dan Allah atas apa yang kita ucapkan) tentang apa yang diucapkan oleh aku dan kamu (adalah sebagai saksi.") pemelihara atau saksi. Maka perjanjian itu dinyatakan oleh keduanya, dan Nabi Syuaib memerintahkan anak perempuannya supaya memberikan tongkatnya kepada Nabi Musa untuk mengusir binatang-binatang buas dari ternak yang digembalakannya nanti. Tongkat itu adalah milik para nabi secara turun-temurun sejak Nabi Adam dan kini berada di tangan Nabi Syuaib. Tongkat itu berasal dari kayu surga, tongkat itu beralih ke tangan nabi Musa dengan sepengetahuan Nabi Syuaib.\qt@no{28}}%
\qt@newcmd\qurantrans@id@mmmcclxxxi{%
(Maka tatkala Musa telah menyelesaikan waktu yang ditentukan) yakni masa penggembalaan itu, yaitu delapan atau sepuluh tahun. Masa sepuluh tahun inilah yang diduga kuat dilakukan oleh Nabi Musa (dan dia berangkat dengan keluarganya) dengan istrinya menuju ke negeri Mesir dengan seizin bapaknya (dilihatnyalah) yakni, Nabi Musa melihat dari jarak jauh (dari arah lereng gunung Thur) Thur adalah nama sebuah gunung (api, Ia berkata kepada keluarganya, ``Tunggulah) di sini (sesungguhnya aku melihat api, mudah-mudahan aku dapat membawa suatu berita kepadamu dari tempat api itu) tentang jalan yang sebenarnya, karena pada saat itu Nabi Musa tersesat (atau membawa sesuluh) dapat dibaca Jadzwatin, Judzwatin, dan Jidzwatin, yakni sebuah obor (api agar kamu dapat menghangatkan badan") maksudnya, berdiang dengan api itu. Huruf Tha yang ada pada lafal Tashthaluna merupakan pergantian dari huruf Ta wazan Ifti'al, karena berasal dari kata Shala bin nari atau Shaliya bin nari artinya berdiang dekat api untuk menghangatkan badan.\qt@no{29}}%
\qt@newcmd\qurantrans@id@mmmcclxxxii{%
(Maka tatkala Musa sampai ke tempat api itu, dia diseru dari arah pinggir) yakni sebelah (lembah yang kanan) yang berada di sebelah kanan Nabi Musa (pada tempat yang diberkahi) bagi Musa untuk mendengarkan Kalam Allah di tempat itu (dari sebatang pohon) lafal ayat ini menjadi Badal dari lafal Syathi' berikut pengulangan huruf Jar-nya, disebabkan pohon itu tumbuh di pinggir lembah; pohon itu adalah pohon anggur, atau pohon 'Ulaiq, atau pohon 'Ausaj (yaitu) huruf An adalah An Mufassarah bukan An Mukhaffafah ("Hai Musa! Sesungguhnya Aku adalah Allah, Rabb semesta alam).\qt@no{30}}%
\qt@newcmd\qurantrans@id@mmmcclxxxiii{%
(Dan lemparkanlah tongkatmu!") lalu Musa melemparkannya. (Tatkala Musa melihatnya bergerak-gerak) menjadi bergerak (seolah-olah dia seekor ular yang gesit) gerakannya sekalipun besar tubuhnya, dikatakan Jan artinya ular kecil padahal ular itu besar sekali, maksudnya gerakannya diserupakan dengan ular yang kecil dalam hal kegesitannya (larilah ia berbalik ke belakang) melarikan diri daripadanya (tanpa menoleh) tanpa menengok ke belakang lagi, lalu diserulah ia ("Hai Musa! Datanglah kepada-Ku dan janganlah kamu takut. Sesungguhnya kamu termasuk orang-orang yang aman!).\qt@no{31}}%
\qt@newcmd\qurantrans@id@mmmcclxxxiv{%
(Masukkanlah) sisipkanlah (tanganmu) yang sebelah kanan, yang dimaksud adalah telapak tangannya (ke leher bajumu) maksudnya, kerah baju gamismu, kemudian keluarkanlah kembali (niscaya ia keluar) berbeda keadaannya dengan tangan yang biasanya (putih tidak bercela) maksudnya bukan karena penyakit sopak. Nabi Musa memasukkan tangannya itu sesuai dengan perintah, kemudian ia mengeluarkannya kembali, tiba-tiba tampak bagaikan cahaya matahari yang menyilaukan pandangan mata (dan dekapkanlah tanganmu itu ke dadamu bila ketakutan) dapat dibaca Ar Rahbi dan Ar Rahbu yang artinya takut disebabkan sinar tangan tadi. Maksudnya jika kamu merasa takut maka masukkan kembali tanganmu itu ke dalam bajumu, niscaya kembali kepada keadaan semula. Pengertian tangan diungkapkan dengan istilah Janah yang artinya sayap, karena kedua tangan bagi manusia fungsinya sama dengan dua sayap bagi burung (maka yang demikian itu adalah dua) dapat dibaca Tasydid dan Takhfif, yakni Fadzanika dan Fadzannika, yang dimaksud adalah tongkat dan tangan itu; keduanya merupakan lafal Muannats dan Musyar ilaih dalam bentuk mudzakar karena khabarnya mudzakar (mukjizat) yang diturunkan (dari Rabbmu yang akan kamu hadapkan kepada Firaun dan pembesar-pembesar kaumnya. Sesungguhnya mereka adalah orang-orang yang fasik").\qt@no{32}}%
\qt@newcmd\qurantrans@id@mmmcclxxxv{%
(Musa berkata, ``Ya Rabbku! Sesungguhnya aku, telah membunuh seorang manusia dari golongan mereka) yaitu, orang Mesir yang telah dibunuhnya tadi (maka aku takut mereka akan membunuhku) disebabkan perbuatan itu.\qt@no{33}}%
\qt@newcmd\qurantrans@id@mmmcclxxxvi{%
(Dan saudaraku Harun dia lebih fasih lidahnya daripadaku) maksudnya jelas bicaranya (maka utuslah dia bersamaku sebagai pembantuku) yang kelak akan membantuku. Lafal Rid-an menurut qiraat yang lain dibaca Riddan (untuk membenarkan aku) lafal Yushaddiqni yang dibaca Jazm adalah menjadi Jawab dari Ad Du'a. Tetapi menurut qiraat yang lain dibaca Rafa, sehingga bacaannya menjadi Yushaddiquni sebagai sifat dari lafal Rid-an (sesungguhnya aku khawatir mereka akan mendustakan aku").\qt@no{34}}%
\qt@newcmd\qurantrans@id@mmmcclxxxvii{%
(Allah berfirman, ``Kami akan membantumu) memperkuatmu (dengan saudaramu, dan Kami berikan kepadamu berdua kekuasaan yang besar) berupa kemenangan yang besar (maka mereka tidak dapat mencapai kamu berdua) dengan maksud jahat mereka, maka pergilah kamu berdua (dengan membawa mukjizat Kami, kamu berdua dan orang yang mengikuti kamulah yang akan menang") atas mereka.\qt@no{35}}%
\qt@newcmd\qurantrans@id@mmmcclxxxviii{%
(Maka tatkala Musa datang kepada mereka dengan membawa mukjizat-mukjizat Kami yang nyata) yakni nyata keadaannya (mereka berkata, ``Ini tidak lain hanyalah sihir yang dibuat-buat) yakni sulapan ilmu sihir saja (dan kami belum pernah mendengar Seruan ini) yang telah ada (di) masa-masa (nenek moyang kami dahulu").\qt@no{36}}%
\qt@newcmd\qurantrans@id@mmmcclxxxix{%
(Berkatalah) dapat dibaca waqala dan Qala tanpa memakai Wawu (Musa, ``Rabbku lebih mengetahui) (orang yang patut membawa petunjuk dari sisi-Nya) Dhamir yang ada pada lafal 'Indahu kembali kepada Ar Rabb (dan siapa) di'athafkan kepada lafal Man sebelumnya (yang akan ada) dapat dibaca Takunu dan Yakunu (baginya kesudahan yang baik di negeri akhirat) yakni akibat yang terpuji di akhirat; maksudnya dia adalah aku sendiri, keduanya adalah aku sendiri yang berhak menyandangnya dan aku orang yang benar di dalam menyampaikan apa yang diturunkan kepadaku. (Sesungguhnya tidaklah akan mendapat kemenangan orang-orang yang zalim") yakni orang-orang yang kafir.\qt@no{37}}%
\qt@newcmd\qurantrans@id@mmmccxc{%
(Dan berkata Firaun, ``Hai pembesar kaumku! Aku tidak mengetahui tuhan bagi kalian selain aku sendiri. Maka bakarlah hai Haman, untukku tanah liat) maksudnya buatlah batu bata untukku (kemudian buatkanlah untukku bangunan yang tinggi) maksudnya gedung yang tinggi sekali (supaya aku dapat naik melihat Tuhan Musa) aku akan melihat-Nya dan berdiri di hadapan-Nya (dan sesungguhnya aku benar-benar yakin bahwa dia termasuk orang-orang yang pendusta") di dalam pengakuannya yang mengatakan ada Tuhan lain selain aku, bahwa ia seorang Rasul.\qt@no{38}}%
\qt@newcmd\qurantrans@id@mmmccxci{%
(Dan berlaku angkuhlah Firaun dan bala tentaranya di bumi Mesir) di negeri Mesir (tanpa alasan yang benar dan mereka menyangka bahwa mereka tidak akan dikembalikan kepada Kami) dapat dibaca La Yurja'una dan La Yarji'una.\qt@no{39}}%
\qt@newcmd\qurantrans@id@mmmccxcii{%
(Maka Kami hukum Firaun dan bala tentaranya, lalu Kami lemparkan mereka) Kami campakkan mereka (ke dalam laut) yang asin airnya, sehingga tenggelamlah mereka. (Maka lihatlah bagaimana akibat orang-orang yang zalim) sewaktu mereka menjadi binasa.\qt@no{40}}%
\qt@newcmd\qurantrans@id@mmmccxciii{%
(Dan Kami jadikan mereka) di dunia (pemimpin-pemimpin) A-immatan dapat dibaca Tahqiq dan Tas-hil, yakni pemimpin-pemimpin dalam kemusyrikan (yang menyeru ke neraka) disebabkan seruan mereka yang mengajak kepada kemusyrikan (dan pada hari kiamat mereka tidak akan ditolong) yaitu azab mereka tidak dapat ditolak lagi.\qt@no{41}}%
\qt@newcmd\qurantrans@id@mmmccxciv{%
(Dan Kami sertakan laknat kepada mereka di dunia ini) berupa kehinaan (dan pada hari kiamat mereka termasuk orang-orang yang dijauhkan) dari rahmat-Nya.\qt@no{42}}%
\qt@newcmd\qurantrans@id@mmmccxcv{%
(Dan sesungguhnya telah Kami berikan kepada Musa Alkitab) yaitu Taurat (sesudah Kami binasakan generasi-generasi yang terdahulu) yakni kaum Nabi Nuh, kaum 'Ad, kaum Tsamud dan lain-lainnya (untuk menjadi pelita bagi manusia) kedudukan lafal ayat ini menjadi Hal dari lafal Alkitab; itu adalah bentuk jamak dari lafal Bashirah yang artinya cahaya hati, maksudnya pelita hati bagi manusia (dan petunjuk) dari kesesatan bagi orang yang mengamalkannya (dan rahmat) bagi orang yang beriman kepadanya (agar mereka ingat) dapat mengambil pelajaran dari nasihat-nasihat yang terkandung di dalamnya.\qt@no{43}}%
\qt@newcmd\qurantrans@id@mmmccxcvi{%
(Dan tidaklah kamu) hai Muhammad (berada di sisi) bukit, atau lembah atau suatu tempat (yang sebelah barat) dari Musa ketika ia bermunajat (ketika Kami menyampaikan) mewahyukan (perintah ke pada Musa) supaya menyampaikannya kepada Firaun dan kaumnya (dan tiada pula kamu termasuk orang-orang yang menyaksikan) kejadian tersebut, lalu kamu mengetahuinya dan menceritakan tentangnya.\qt@no{44}}%
\qt@newcmd\qurantrans@id@mmmccxcvii{%
(Tetapi Kami telah mengadakan beberapa generasi) yakni umat-umat sesudah Nabi Musa (dan berlalulah atas mereka masa yang panjang) waktu yang berabad-abad sehingga mereka lupa akan perjanjian-perjanjian, dan ilmu-ilmu agama pun telah terhapus pula, serta wahyu terputus. Maka Kami datangkan kamu sebagai seorang Rasul dan Kami turunkan wahyu kepadamu mengenai berita Musa dan berita nabi-nabi lainnya (dan tiadalah kamu tinggal) bermukim (bersama-sama penduduk Madyan dengan membacakan ayat-ayat Kami kepada mereka) lafal Tatlu dan seterusnya merupakan Khabar yang kedua dari lafal Kunta, maksudnya, sehingga penduduk Madyan itu mengetahui kisah umat-umat terdahulu lalu mereka mengisahkannya (tetapi Kami telah mengangkat menjadi Rasul) kamu, dan Kami mengutus utusan-utusan Kami kepadamu dengan membawa berita orang-orang dahulu.\qt@no{45}}%
\qt@newcmd\qurantrans@id@mmmccxcviii{%
(Dan tiadalah kamu berada di dekat bukit Thur) nama sebuah bukit (ketika) sewaktu (Kami menyeru) Musa, ``Ambillah Alkitab ini dengan sepenuh kekuatanmu", yakni amalkanlah sekemampuanmu (tetapi) Kami utus kamu (sebagai rahmat dari Rabbmu, supaya kamu memberi peringatan kepada kaum yang sekali-kali belum datang kepada mereka pemberi peringatan sebelum kamu supaya mereka ingat) supaya mengambil pelajaran.\qt@no{46}}%
\qt@newcmd\qurantrans@id@mmmccxcix{%
(Dan agar mereka sewaktu ditimpa musibah) azab (disebabkan apa yang telah di kerjakan oleh tangan-tangan mereka) berupa kekafiran dan selainnya (mereka tidak akan mengatakan, ``Ya Rabb kami! Mengapa tidak) yakni kenapa tidak (Engkau utus seorang Rasul kepada kami, lalu kami mengikuti ayat-ayat Engkau) yang dibawa oleh Rasul Engkau (dan jadilah kami termasuk orang-orang yang beriman") Jawab dari lafal Laula dibuang, dan lafal yang sesudahnya merupakan Mubtada. Maksudnya, seandainya tidak karena azab yang menimpa mereka sebagai penyebab dari perkataannya. Atau maksudnya, seandainya tidak ada perkataan mereka yang menyebabkan turunnya azab, niscaya akan Kami segerakan kepada mereka azab itu, dan niscaya pula Kami tidak akan mengutusmu kepada mereka sebagai seorang Rasul.\qt@no{47}}%
\qt@newcmd\qurantrans@id@mmmccc{%
(Maka tatkala datang kepada mereka kebenaran) yang dibawa oleh Nabi Muhammad (dari sisi Kami, mereka berkata, ``Mengapa tidak) kenapa tidak (diberikan kepadanya seperti yang telah diberikan kepada Musa?") yaitu mukjizat-mukjizat seperti tangan yang bersinar menyilaukan, tongkat dan lain sebagainya, atau kitab yang diturunkan sekali turun. Allah swt. menjawab perkataan mereka melalui firman-Nya, ("Dan bukankah mereka itu telah ingkar juga kepada apa yang diberikan kepada Musa dahulu?) di mana (mereka telah mengatakan) sehubungan dengan perihal Nabi Musa dan juga tentang diri Nabi Muhammad ('Dua orang ahli sihir). Menurut qiraat yang lain dibaca Sahirani, subjek yang mereka maksud adalah Alquran dan kitab Taurat (yang saling bantu membantu'.") maksudnya mereka saling bahu membahu. (Dan mereka juga berkata, ``Sesungguhnya kami kepada masing-masing) dari kedua nabi, berikut kitab-kitabnya (tidak mempercayai").\qt@no{48}}%
\qt@newcmd\qurantrans@id@mmmccci{%
(Katakanlah) kepada mereka, ("Datangkanlah oleh kalian sebuah kitab dari sisi Allah yang kitab itu lebih dapat memberi petunjuk daripada keduanya) yang dimaksud adalah Alquran dan Taurat (niscaya aku akan mengikutinya, jika kalian sungguh orang-orang yang benar.") di dalam perkataannya.\qt@no{49}}%
\qt@newcmd\qurantrans@id@mmmcccii{%
(Maka jika mereka tidak menjawab kamu) maksudnya tantanganmu itu, yaitu supaya mereka mendatangkan Kitab dari sisi Allah (ketahuilah bahwa sesungguhnya mereka hanyalah mengikuti hawa nafsu mereka belaka) dalam kekafirannya itu (Dan siapakah yang lebih sesat daripada orang yang mengikuti hawa nafsunya dengan tidak mendapat petunjuk dari Allah sedikit pun?) maksudnya, tidak ada yang lebih sesat daripadanya. (Sesungguhnya Allah tidak memberi petunjuk kepada orang-orang yang zalim) yaitu orang-orang kafir.\qt@no{50}}%
\qt@newcmd\qurantrans@id@mmmccciii{%
(Dan sesungguhnya telah Kami jelaskan) telah Kami terangkan (perkataan ini kepada mereka) yaitu Alquran (agar mereka mendapat pelajaran) yakni mengambil pelajaran daripadanya, lalu mereka beriman.\qt@no{51}}%
\qt@newcmd\qurantrans@id@mmmccciv{%
(Orang-orang yang telah Kami datangkan kepada mereka Alkitab sebelumnya) sebelum Alquran (mereka beriman pula kepada Alquran itu). Ayat ini diturunkan berkenaan dengan segolongan orang-orang Yahudi yang masuk Islam; antara lain; Abdullah ibnu Salam. Ayat ini diturunkan pula berkenaan dengan segolongan orang-orang Anshar yang baru datang dari negeri Habsyah/Abesinia dan negeri Syam, kemudian mereka beriman kepada Nabi saw.\qt@no{52}}%
\qt@newcmd\qurantrans@id@mmmcccv{%
(Dan apabila dibacakan kepada mereka) Alquran (mereka berkata, ``Kami beriman kepadanya; sesungguhnya Alquran itu adalah suatu kebenaran dari Rabb kami, sesungguhnya kami adalah orang-orang yang beriman sebelumnya.") orang-orang yang mengesakan Allah.\qt@no{53}}%
\qt@newcmd\qurantrans@id@mmmcccvi{%
(Mereka itu diberi pahala dua kali) karena iman mereka kepada dua Kitab (disebabkan kesabaran mereka) di dalam mengamalkan kandungan kedua Kitab itu (dan mereka menolak) menutup (kejahatan dengan kebaikan) yaitu kejahatan yang mereka lakukan ditutup dengan kebaikan mereka (dan sebagian dari apa yang telah Kami rezekikan kepada mereka, mereka nafkahkan) mereka menyedekahkannya.\qt@no{54}}%
\qt@newcmd\qurantrans@id@mmmcccvii{%
(Dan apabila mereka mendengar perkataan yang tidak bermanfaat) berupa makian dan perlakuan yang menyakitkan dari pihak orang-orang kafir (mereka berpaling daripadanya dan berkata, ``Bagi kami amal-amal kami dan bagi kalian amal-amal kalian, kesejahteraan atas diri kalian), yaitu salam selamat tinggal, yang dimaksud adalah kalian selamat dari cacian kami dan hal-hal lain (kami tidak ingin bergaul dengan orang-orang jahil.") maksudnya tidak mau berteman dengan mereka.\qt@no{55}}%
\qt@newcmd\qurantrans@id@mmmcccviii{%
Ayat berikut ini diturunkan berkenaan dengan keinginan Nabi saw. akan keimanan pamannya yaitu Abu Thalib. (Sesungguhnya kamu tidak akan dapat memberi petunjuk kepada orang yang kamu kasihi) supaya ia mendapat hidayah (tetapi Allah memberi petunjuk kepada orang yang dikehendaki-Nya dan Allah lebih mengetahui) yakni mengetahui (orang-orang yang mau menerima petunjuk).\qt@no{56}}%
\qt@newcmd\qurantrans@id@mmmcccix{%
(Dan mereka berkata) yaitu kaumnya, ("Jika kami mengikuti petunjuk bersama kamu, niscaya kami akan diusir dari negeri kami") kami akan diusir dengan cepat daripadanya. Maka Allah swt. berfirman, (Dan apakah Kami tidak meneguhkan kedudukan mereka dalam daerah haram yang aman) maksudnya, mereka hidup dengan aman di dalamnya dari segala serangan dan pembunuhan, tidak sebagaimana yang terjadi di kalangan orang-orang Arab lainnya yang saling serang menyerang dan saling bunuh membunuh (yang didatangkan) dapat dibaca Tujba dan Yujba (ke tempat itu buah-buahan dari segala penjuru) dari berbagai penjuru (sebagai rezeki) bagi mereka (dari sisi Kami?) dari hadirat Kami (tetapi kebanyakan mereka tidak mengetahui) bahwa apa yang Kami katakan itu adalah benar.\qt@no{57}}%
\qt@newcmd\qurantrans@id@mmmcccx{%
(Dan berapa banyaknya negeri yang telah Kami binasakan yang sudah bersenang-senang dalam kehidupannya) yang dimaksud adalah penduduk negeri-negeri tersebut (maka itulah tempat kediaman mereka yang tidak didiami lagi sesudah mereka, kecuali sebagian kecil) untuk orang-orang yang lewat yang tinggal hanya sehari atau setengah hari. (Dan Kami adalah pewarisnya) dari mereka.\qt@no{58}}%
\qt@newcmd\qurantrans@id@mmmcccxi{%
(Dan tiadalah Rabbmu membinasakan kota-kota) disebabkan kelaliman yang dilakukan oleh para penduduknya (sebelum Dia mengutus di ibu kota itu) yakni pada kota terbesar negeri itu (seorang Rasul yang membacakan ayat-ayat Kami kepada mereka dan tidak pernah pula Kami membinasakan kota-kota kecuali penduduknya dalam keadaan melakukan kelaliman) yaitu mendustakan Rasul-rasul.\qt@no{59}}%
\qt@newcmd\qurantrans@id@mmmcccxii{%
(Dan apa saja yang diberikan kepada kalian, maka itu adalah kenikmatan hidup duniawi dan perhiasannya) kalian bersenang-senang dan menghias diri dengannya selama hidup kalian, kemudian semuanya akan lenyap (sedangkan apa yang di sisi Allah) yakni pahala-Nya (adalah lebih baik dan lebih kekal. Maka apakah kalian tidak memahaminya?) bahwa yang kekal itu lebih baik daripada yang lenyap. Dapat dibaca Ta'maluna dan Ya'maluna.\qt@no{60}}%
\qt@newcmd\qurantrans@id@mmmcccxiii{%
(Maka apakah orang yang Kami janjikan kepadanya suatu janji yang baik lalu ia memperolehnya) janji yang dimaksud adalah surga (sama dengan orang yang Kami berikan kepadanya kenikmatan hidup duniawi) yang dalam waktu dekat pasti akan lenyap (kemudian dia pada hari kiamat termasuk orang-orang yang diseret) ke dalam neraka. Orang yang dimaksud pada lafal pertama adalah orang Mukmin dan pada lafal kedua adalah orang kafir maksudnya tidak ada persamaan di antara keduanya.\qt@no{61}}%
\qt@newcmd\qurantrans@id@mmmcccxiv{%
(Dan) ingatlah (hari di waktu Dia menyeru mereka) yang dimaksud adalah Allah menyeru mereka (seraya berkata, ``Di manakah sekutu-sekutu-Ku yang dahulu kalian menduga") bahwa mereka adalah sekutu-sekutu-Ku.\qt@no{62}}%
\qt@newcmd\qurantrans@id@mmmcccxv{%
(Berkatalah orang-orang yang telah tetap hukuman atas mereka) yakni mereka harus masuk ke dalam neraka, mereka adalah para pemimpin kesesatan, ("Ya Rabb kami! Mereka inilah orang-orang yang kami sesatkan itu) lafal Haula-i adalah Mubtada dan Al Ladzina Aghwainahum adalah sifatnya (kami telah menyesatkan mereka) lafal ayat ini menjadi Khabarnya. Yaitu setelah kami sesatkan mereka, maka mereka pun tersesatlah (sebagaimana kami sendiri sesat) yakni, kami tidak memaksakan mereka untuk sesat (kami menyatakan berlepas diri kepada Engkau) dari mereka (mereka sekali-kali tidak menyembah kami") Ma di sini adalah Nafiyah, dan sengaja Maf'ulnya didahulukan demi untuk Fashilah, atau untuk memelihara keseragaman akhir ayat.\qt@no{63}}%
\qt@newcmd\qurantrans@id@mmmcccxvi{%
(Dikatakan kepada mereka ``Serulah oleh kalian sekutu-sekutu kalian!") yaitu berhala-berhala yang kalian yakini, bahwa mereka adalah sekutu-sekutu Allah (lalu mereka menyerunya, maka sekutu-sekutu itu tidak memperkenankan mereka) tidak menjawab seruan mereka (lalu mereka melihat) mereka yang diseru itu (azab) melihatnya dengan mata kepala mereka (kiranya mereka dahulu menerima petunjuk) sewaktu di dunia, mereka baru sadar setelah melihat azab di akhirat.\qt@no{64}}%
\qt@newcmd\qurantrans@id@mmmcccxvii{%
(Dan) ingatlah (hari di waktu Allah menyeru mereka, seraya berkata ``Apakah jawaban kalian kepada para Rasul?") yang diutus kepada kalian.\qt@no{65}}%
\qt@newcmd\qurantrans@id@mmmcccxviii{%
(Maka gelaplah bagi mereka segala alasan) maksudnya alasan yang dapat menyelamatkan diri mereka tidak dapat mereka kemukakan (di hari itu) mereka tidak dapat menemukan alasan agar dirinya dapat selamat dari azab (karena itu mereka tidak saling tanya menanya) mengenai hal ini, mereka hanya diam saja.\qt@no{66}}%
\qt@newcmd\qurantrans@id@mmmcccxix{%
(Adapun orang yang bertobat) dari kemusyrikan (dan beriman) percaya kepada keesaan Allah (serta mengerjakan amal yang saleh) yakni melaksanakan perbuatan-perbuatan yang difardukan (semoga dia termasuk orang-orang yang beruntung) yang selamat berkat adanya janji Allah.\qt@no{67}}%
\qt@newcmd\qurantrans@id@mmmcccxx{%
(Dan Rabbmu menciptakan apa saja yang dikehendaki-Nya dan memilih) apa yang dikehendaki-Nya. (Sekali-kali tidak ada bagi mereka) yakni bagi orang-orang musyrik (pilihan) maksudnya mereka tidak mempunyai pilihan apa-apa. (Maha Suci Allah dan Maha Tinggi dari apa yang mereka persekutukan) dari kemusyrikan mereka.\qt@no{68}}%
\qt@newcmd\qurantrans@id@mmmcccxxi{%
(Dan Rabbmu mengetahui apa yang disembunyikan dalam dada mereka) yakni yang dirahasiakan di dalam hati mereka berupa kekafiran dan dosa-dosa lainnya (dan apa yang mereka nyatakan) dengan lisan mereka dari hal-hal tersebut.\qt@no{69}}%
\qt@newcmd\qurantrans@id@mmmcccxxii{%
(Dan Dia-lah Allah, tidak ada Tuhan yang berhak disembah melainkan Dia, bagi-Nya-lah segala puji di dunia) (dan di akhirat) yaitu di surga (dan bagi-Nya-lah segala penentuan) yakni, keputusan yang terlaksana dalam segala sesuatu (dan hanya kepada-Nya-lah kalian dikembalikan) melalui hari berbangkit.\qt@no{70}}%
\qt@newcmd\qurantrans@id@mmmcccxxiii{%
(Katakanlah) kepada penduduk Mekah ("Terangkanlah kepadaku) ceritakanlah kepadaku (jika Allah menjadikan untuk kalian malam itu terus menerus) selama-lamanya (sampai hari kiamat, siapakah Tuhan selain Allah) menurut dugaan kalian (yang akan mendatangkan sinar terang kepada kalian?) siang hari kalian mencari penghidupan di dalamnya. (Maka apakah kalian tidak mendengar?") hal tersebut dengan pendengaran yang dibarengi dengan pemahaman, karenanya kalian tidak akan melakukan kemusyrikan lagi.\qt@no{71}}%
\qt@newcmd\qurantrans@id@mmmcccxxiv{%
(Katakanlah) kepada mereka, ("Terangkanlah kepadaku, jika Allah menjadikan untuk kalian siang itu terus menerus sampai hari kiamat, siapakah Tuhan selain Allah) menurut dugaan kalian (yang akan mendatangkan malam kepada kalian yang kalian berdiam diri) yakni beristirahat (padanya?) dari kelelahan dan kecapekan. (Maka apakah kalian tidak memperhatikan?") kesalahan yang kalian lakukan sekarang, yaitu berupa perbuatan musyrik; oleh karena itu kemudian kalian meninggalkannya.\qt@no{72}}%
\qt@newcmd\qurantrans@id@mmmcccxxv{%
(Dan karena rahmat-Nya) rahmat Allah swt. (Dia jadikan untuk kalian malam dan siang, supaya kalian beristirahat padanya) yakni pada malam harinya (dan supaya kalian mencari sebagian dari karunia-Nya) pada siang harinya, untuk mencari penghidupan (dan agar kalian bersyukur) dengan adanya nikmat Allah pada kedua waktu itu, yaitu malam hari dan siang hari.\qt@no{73}}%
\qt@newcmd\qurantrans@id@mmmcccxxvi{%
(Dan) ingatlah (hari di waktu Allah menyeru mereka, seraya berkata, ``Di manakah sekutu-sekutu-Ku yang dahulu kalian katakan?") ayat ini disebutkan kembali sebagai pendahuluan dari kisah selanjutnya, yang diungkapkan oleh ayat berikut ini, yaitu,\qt@no{74}}%
\qt@newcmd\qurantrans@id@mmmcccxxvii{%
(Dan kami datangkan) Kami hadirkan (dari tiap-tiap umat seorang saksi) seorang nabi yang menyaksikan apa yang telah mereka katakan (lalu Kami berkata) kepada mereka, ("Tunjukkanlah bukti kebenaran kalian") yang menunjukkan kebenaran dari kemusyrikan yang kalian lakukan itu (maka tahulah mereka bahwasanya yang hak) menyandang sifat Tuhan (kepunyaan Allah) tiada seorang pun yang berserikat dengan-Nya dalam hal ini (dan lenyaplah) yakni hilanglah (dari mereka apa yang dahulunya mereka ada-adakan) di dunia, yaitu dakwaan bahwa di samping Allah ada tuhan yang lain; Maha Tinggi Allah dari hal itu.\qt@no{75}}%
\qt@newcmd\qurantrans@id@mmmcccxxviii{%
(Sesungguhnya Karun adalah termasuk kaum Musa) dia adalah saudara sepupu Nabi Musa sendiri, yaitu anak saudara lelaki ayah Nabi Musa yang kawin dengan saudara perempuan ibu Nabi Musa, dan Karun beriman kepada Nabi Musa (maka ia berlaku aniaya terhadap mereka) yaitu bersifat takabur; sombong dan merasa paling banyak hartanya (dan Kami telah menganugerahkan kepadanya perbendaharaan harta yang kunci-kuncinya sungguh berat dipikul) terasa berat apabila dipikul (oleh sejumlah) segolongan (orang-orang yang mempunyai) yang memiliki (kekuatan) maksudnya, kunci-kunci itu sangat berat dirasakan oleh mereka. Huruf Ba yang ada pada lafal Bil 'ushbah berfungsi untuk Ta'diyah. Menurut suatu pendapat dikatakan, bahwa jumlah mereka ada tujuh puluh orang; dan menurut pendapat yang lain dikatakan bahwa jumlah mereka ada empat puluh orang, sedangkan menurut yang lainnya lagi berjumlah sepuluh orang, dan menurut yang lainnya lagi selain dari itu. Ingatlah (ketika kaumnya berkata kepadanya) yaitu orang-orang yang beriman dari kalangan kaum Bani Israel berkata kepada Karun ("Janganlah kamu bangga) dan sombong karena memiliki banyak harta, (sesungguhnya Allah tidak menyukai orang-orang yang terlalu membanggakan diri") dengan harta yang dimilikinya.\qt@no{76}}%
\qt@newcmd\qurantrans@id@mmmcccxxix{%
(Dan carilah) upayakanlah (pada apa yang telah dianugerahkan Allah kepada kalian) berupa harta benda (kebahagiaan negeri akhirat) seumpamanya kamu menafkahkannya di jalan ketaatan kepada Allah (dan janganlah kamu melupakan) jangan kamu lupa (bagianmu dari kenikmatan duniawi) yakni hendaknya kamu beramal dengannya untuk mencapai pahala di akhirat (dan berbuat baiklah) kepada orang-orang dengan bersedekah kepada mereka (sebagaimana Allah telah berbuat baik kepadamu, dan janganlah kamu berbuat) mengadakan (kerusakan di muka bumi) dengan mengerjakan perbuatan-perbuatan maksiat. (Sesungguhnya Allah tidak menyukai orang-orang yang berbuat kerusakan) maksudnya Allah pasti akan menghukum mereka.\qt@no{77}}%
\qt@newcmd\qurantrans@id@mmmcccxxx{%
(Karun berkata, ``Sesungguhnya aku hanya diberi harta itu) harta yang ada padanya itu (karena ilmu yang ada padaku") sebagai imbalan dari pengetahuan yang aku miliki; dia seorang yang paling ulung di kalangan Bani Israel mengenai kitab Taurat, sesudah Musa dan Harun. Allah berfirman, (Dan apakah ia tidak mengetahui bahwasanya Allah sungguh telah membinasakan umat-umat sebelumnya) yakni, bangsa-bangsa sebelumnya (yang lebih kuat daripadanya dan lebih banyak mengumpulkan harta?) maksudnya, Karun mengetahui kisah mereka, kemudian mereka dibinasakan oleh Allah. (Dan tidaklah perlu ditanyakan kepada orang-orang yang berdosa itu, tentang dosa-dosa mereka) karena Allah mengetahui hal tersebut, maka mereka dimasukkan ke neraka tanpa dihisab lagi.\qt@no{78}}%
\qt@newcmd\qurantrans@id@mmmcccxxxi{%
(Maka keluarlah) Karun (kepada kaumnya dalam kemegahannya) berikut para pengikutnya yang banyak jumlahnya; mereka semuanya menaiki kendaraan seraya memakai pakaian emas dan sutra. Kuda-kuda serta keledai-keledai yang mereka naiki pun dihiasnya. (Berkatalah orang-orang yang menghendaki kehidupan dunia, ``Aduhai!) huruf Ya di sini menunjukkan makna Tanbih (Kiranya kita mempunyai seperti apa yang telah diberikan kepada Karun) dalam masalah keduniawian (sesungguhnya ia benar-benar mempunyai keberuntungan) yakni bagian (yang besar.") yang sangat banyak keberuntungannya.\qt@no{79}}%
\qt@newcmd\qurantrans@id@mmmcccxxxii{%
(Berkatalah) kepada mereka (orang-orang yang dianugerahi ilmu) tentang apa yang telah dijanjikan oleh Allah kelak di akhirat, ("Kecelakaan yang besarlah bagi kalian) lafal Wailakum ini adalah kalimat hardikan (pahala Allah) di akhirat berupa surga (adalah lebih baik bagi orang-orang yang beriman dan beramal saleh) daripada apa yang diberikan oleh Allah kepada Karun di dunia (dan tidak diperoleh pahala itu) yakni surga (kecuali oleh orang-orang yang sabar") di dalam menjalankan ketaatan dan menjauhi maksiat.\qt@no{80}}%
\qt@newcmd\qurantrans@id@mmmcccxxxiii{%
(Maka Kami benamkan dia) Karun (beserta rumahnya ke dalam bumi. Maka tidak ada lagi baginya suatu golongan pun yang menolongnya terhadap azab Allah) seumpamanya penolong itu dapat mencegah kebinasaan dari diri Karun. (Dan tiadalah ia termasuk orang-orang yang dapat membela dirinya) dari azab Allah.\qt@no{81}}%
\qt@newcmd\qurantrans@id@mmmcccxxxiv{%
(Dan jadilah orang-orang yang kemarin mencita-citakan kedudukan Karun itu) dalam waktu yang singkat (mereka berkata, ``Aduhai! Benarlah Allah melapangkan) yakni meluaskan (rezeki bagi siapa yang Dia kehendaki dari hamba-hamba-Nya dan membatasinya) menyempitkannya bagi orang-orang yang dikehendaki-Nya. Lafal Way adalah Isim Fi'il yang artinya aku sangat kagum, dan huruf Kaf mempunyai makna huruf Lam. Maksudnya, aku sangat takjub karena sesungguhnya Allah melapangkan dan seterusnya (kalau Allah tidak melimpahkan harunia-Nya atas kita, benar-benar Dia telah membenamkan kita pula) dapat dibaca Lakhasafa dan Lakhusifa (Aduhai benarlah, tidak beruntung orang-orang yang mengingkari.") nikmat Allah seperti Karun tadi.\qt@no{82}}%
\qt@newcmd\qurantrans@id@mmmcccxxxv{%
(Negeri akhirat itu,) yakni surga (Kami jadikan untuk orang-orang yang tidak ingin menyombongkan diri di muka bumi) dengan melakukan kelaliman (dan tidak pula berbuat kerusakan) dengan melakukan perbuatan-perbuatan maksiat. (Dan kesudahan yang baik itu) yakni yang terpuji (adalah bagi orang orang yang bertakwa) maksudnya bagi orang-orang yang takut kepada azab Allah, yaitu dengan melakukan perbuatan-perbuatan ketaatan kepada-Nya.\qt@no{83}}%
\qt@newcmd\qurantrans@id@mmmcccxxxvi{%
(Barang siapa yang datang dengan membawa kebaikan, maka baginya pahala yang lebih baik daripada kebaikannya itu) sebagai imbalan daripada kebaikan yang dibawanya, yaitu sebanyak sepuluh kali lipat dari pahala kebaikannya (dan barang siapa yang datang dengan membawa kejahatan, maka tidaklah diberi pembalasan kepada orang-orang yang telah mengerjakan kejahatan itu melainkan) pembalasan yang seimbang (dengan apa yang dahulu mereka kerjakan) yakni dengan kejahatannya.\qt@no{84}}%
\qt@newcmd\qurantrans@id@mmmcccxxxvii{%
(Sesungguhnya yang mewajibkan atasmu Alquran) yakni yang menurunkannya (benar-benar akan mengembalikan kamu ke tempat kembali) ke Mekah, dan bahwa Nabi saw. telah rindu sekali kepada kota Mekah (katakanlah, ``Rabbku mengetahui) tentang (orang yang membawa petunjuk dan orang yang dalam kesesatan yang nyata"). Ayat ini diturunkan sebagai jawaban atas perkataan orang-orang kafir Mekah terhadap Nabi saw.; mereka menuduhnya bahwa ia sesat. Makna ayat ini, dia yakni Nabi saw. datang dengan membawa petunjuk sedangkan mereka adalah orang-orang yang berada dalam kesesatan. Dan lafal A'lam bermakna Alimun yakni mengetahui.\qt@no{85}}%
\qt@newcmd\qurantrans@id@mmmcccxxxviii{%
(Dan kamu tidak pernah mengharap agar diturunkan kepadamu Alkitab) yakni Alquran (tetapi) ia diturunkan kepadamu (karena suatu rahmat yang besar dari Rabbmu, sebab itu janganlah sekali-kali kamu menjadi penolong) pembantu (bagi orang-orang kafir) dalam agama mereka di mana mereka mengajak kamu untuk memasukinya.\qt@no{86}}%
\qt@newcmd\qurantrans@id@mmmcccxxxix{%
(Dan janganlah sekali-kali mereka dapat menghalangimu) asal kata Yashuddunnaka adalah Yashuddunaka, kemudian huruf Nun alamat Rafa'nya dibuang karena lafal dijazamkan, demikian pula huruf Wawu Fa'il tetapi bukan karena bertemu dengan huruf mati lainnya (dari menyampaikan ayat-ayat Allah, sesudah ayat-ayat itu diturunkan kepadamu) maksudnya, janganlah kamu memandang mereka dalam hal tersebut (dan serulah) manusia (kepada jalan Rabbmu) dengan menganjurkan mereka untuk mengesakan-Nya dan menyembah-Nya (dan janganlah sekali-kali kamu termasuk orang-orang musyrik) yaitu, dengan membantu mereka. 'Amil Jazm tidak berpengaruh terhadap Fi'il yaitu lafal Wa La Takunanna, karena Fi'il ini bersifat Mabni, sebagai akibat kemasukan Nun Taukid.\qt@no{87}}%
\qt@newcmd\qurantrans@id@mmmcccxl{%
(Janganlah kamu seru) janganlah kamu sembah (di samping Allah, tuhan apa pun yang lain. Tidak ada Tuhan yang berhak disembah melainkan Dia. Tiap-tiap sesuatu pasti binasa, kecuali Dia) kecuali Allah. (Bagi-Nya-lah segala penentuan) yakni, keputusan yang terlaksana (dan hanya kepada-Nya-lah kalian dikembalikan) setelah kalian dibangkitkan dari kubur masing-masing.\qt@no{88}}%
\qt@newcmd\qurantrans@id@mmmcccxli{%
\basmalahid (Alif Lam Mim) hanya Allah yang lebih mengetahui maksudnya.\qt@no{1}}%
\qt@newcmd\qurantrans@id@mmmcccxlii{%
(Apakah manusia itu mengira bahwa mereka dibiarkan saja mengatakan) mengenai ucapan mereka yang mengatakan, ("Kami telah beriman", sedangkan mereka tidak diuji lagi?) diuji lebih dulu dengan hal-hal yang akan menampakkan hakikat keimanan mereka. Ayat ini diturunkan berkenaan dengan orang-orang yang masuk Islam, kemudian mereka disiksa oleh orang-orang musyrik.\qt@no{2}}%
\qt@newcmd\qurantrans@id@mmmcccxliii{%
(Dan sesungguhnya Kami telah menguji orang-orang yang sebelum mereka. Sesungguhnya Allah mengetahui orang-orang yang benar) di dalam keimanan mereka dengan pengetahuan yang menyaksikan (dan sesungguhnya Dia mengetahui orang-orang yang dusta) di dalam keimanannya.\qt@no{3}}%
\qt@newcmd\qurantrans@id@mmmcccxliv{%
(Ataukah orang-orang yang mengerjakan kejahatan itu mengira) berupa perbuatan musyrik dan perbuatan maksiat (bahwa mereka akan luput dari Kami) maksudnya mereka dapat selamat sehingga Kami tidak membalas mereka (Amat buruklah) alangkah jeleknya (apa) yang (mereka putuskan) itu; seburuk-buruk keputusan adalah keputusan mereka.\qt@no{4}}%
\qt@newcmd\qurantrans@id@mmmcccxlv{%
(Barang siapa yang mengharap) merasa takut (bertemu dengan Allah, maka sesungguhnya waktu Allah itu) yang dijanjikan-Nya (pasti datang) maka hendaknya dia bersiap sedia untuk itu. (Dan Dialah Yang Maha Mendengar) perkataan hamba-hamba-Nya (lagi Maha Mengetahui) perbuatan-perbuatan mereka.\qt@no{5}}%
\qt@newcmd\qurantrans@id@mmmcccxlvi{%
(Dan barang siapa yang berjihad) maksudnya jihad fisik atau jihad nafsi (maka sesungghnya jihadnya itu adalah untuk dirinya sendiri) karena manfaat atau pahala dari jihadnya itu kembali kepada dirinya sendiri, bukan kepada Allah. (Sesungguhnya Allah benar-benar Maha Kaya dari semesta alam) yaitu dari manusia, jin dan Malaikat, dalam arti kata Dia tidak memerlukan sesuatu pun dari mereka, juga Dia tidak membutuhkan ibadah mereka kepada-Nya.\qt@no{6}}%
\qt@newcmd\qurantrans@id@mmmcccxlvii{%
(Orang-orang yang beriman dan beramal saleh, benar-benar akan Kami hapuskan dari mereka dosa-dosa mereka) melalui amal-amal saleh yang mereka lakukan (dan benar-benar akan Kami beri mereka balasan yang lebih baik) di-nashab-kannya lafal Ahsana karena huruf Jar-nya dibuang, makna yang dimaksud daripadanya ialah pahala yang baik (dari apa yang mereka kerjakan) yakni, dari amal-amal saleh mereka.\qt@no{7}}%
\qt@newcmd\qurantrans@id@mmmcccxlviii{%
(Dan Kami perintahkan manusia berbuat kebaikan kepada dua orang ibu-bapaknya) artinya perintah untuk berbuat baik, antara lain berbakti kepada kedua ibu-bapak. (Dan jika keduanya memaksamu untuk mempersekutukan Aku dengan sesuatu yang tentang hal itu kamu) yakni terhadap perbuatan musyrik itu (tidak mempunyai pengetahuan) untuk menyetujui dan menentangnya, dan hal itu tidak dapat dimengerti olehmu (maka janganlah kamu mengikuti keduanya) dalam kemusyrikannya. (Hanya kepada-Ku-lah kembali kalian lalu Aku kabarkan kepada kalian apa yang telah kalian kerjakan) maka Aku akan membalasnya kepada kalian.\qt@no{8}}%
\qt@newcmd\qurantrans@id@mmmcccxlix{%
(orang-orang yang beriman dan mengerjakan amal saleh, benar-benar Kami masukkan mereka ke dalam golongan orang-orang yang saleh) maksudnya para nabi dan kekasih-kekasih Allah, umpamanya Kami akan menghimpun mereka bersama-sama dengan para nabi dan para wali.\qt@no{9}}%
\qt@newcmd\qurantrans@id@mmmcccl{%
(Di antara manusia ada orang yang berkata, ``Kami beriman kepada Allah", maka apabila ia disakiti, -karena beriman- kepada Allah, ia menganggap fitnah manusia itu) yakni perlakuan mereka yang menyakitkan kepada dirinya (sebagai azab Allah) yaitu ketakutannya terhadap siksaan mereka disamakan seperti takut kepada azab Allah. Sehingga akhirnya dia mau menuruti kemauan mereka, lalu ia menjadi orang yang munafik. (Dan sungguh jika) huruf Lam pada lafal la in menunjukkan makna sumpah (datang pertolongan) kepada orang-orang Mukmin (dari Rabbmu) lalu orang-orang Mukmin memperoleh banyak ganimah (mereka pasti akan berkata) Lafal Layaqulunna dibuang daripadanya Nun alamat Rafa', karena jika dibiarkan, maka akan berturut-turutlah huruf Nun, sehingga jadilah Layaqulunna yang pada asalnya adalah Layaqulunanna, dan dibuang daripadanya Wawu Dhamir jamak bukan karena sebab bertemunya dua huruf yang disukunkan. ("Sesungguhnya kami adalah beserta kalian") dalam hal iman, karena itu maka ajaklah kami bersama-sama mendapat bagian ganimah itu. Maka Allah swt. berfirman (Bukankah Allah lebih mengetahui) yakni mengetahui (apa yang ada dalam dada semua manusia?) yakni apa yang ada di dalam hati mereka, apakah keimanan ataukah kemunafikan? Memang benar Allah lebih mengetahui.\qt@no{10}}%
\qt@newcmd\qurantrans@id@mmmcccli{%
(Dan sesungguhnya Allah benar-benar mengetahui orang-orang yang beriman) maksudnya mengenai hati mereka (dan sesungguhnya Dia mengetahui orang-orang yang munafik) maka kelak Dia akan membalas masing-masing golongan itu. Lam yang terdapat pada kedua Fi'il ayat ini menunjukkan makna Qasam.\qt@no{11}}%
\qt@newcmd\qurantrans@id@mmmccclii{%
(Dan berkatalah orang-orang kafir kepada orang-orang yang beriman, ``Ikutilah jalan kami) maksudnya cara mereka dalam beragama (dan nanti kami akan memikul dosa-dosa kalian") karena kalian menuruti kami jika memang kalian berdosa. Lafal Amar sekali pun sebagai kalimat Insya' akan tetapi menunjukkan makna Khabar atau kalimat berita. Maka Allah berfirman (dan mereka sendiri sedikit pun tidak sanggup memikul dosa-dosa mereka. Sesungguhnya mereka adalah benar-benar pendusta) dalam perkataannya itu.\qt@no{12}}%
\qt@newcmd\qurantrans@id@mmmcccliii{%
(Dan sesungguhnya mereka akan memikul beban mereka) dosa-dosa mereka (dan beban-beban dosa yang lain di samping beban-beban dasa mereka sendiri) disebabkan perkataan mereka kepada orang-orang yang beriman, sebagaimana yang diungkapkan oleh firman-Nya tadi, yaitu, ``Ikutilah jalan kami", dan juga disebabkan penyesatan yang mereka lakukan kepada orang-orang yang mengikuti mereka (dan sesungguhnya mereka akan ditanya pada hari kiamat tentang apa-apa yang selalu mereka ada-adakan) yakni kedustaan mereka terhadap Allah. Pertanyaan ini menunjukkan nada celaan, dan huruf Lam yang terdapat pada kedua Fi'il tadi menunjukkan makna Qasam, sedangkan Fa'il masing-masing yaitu berupa Wau Dhamir Jamak dibuang, dan demikian pula huruf Nun alamat Rafa'nya.\qt@no{13}}%
\qt@newcmd\qurantrans@id@mmmcccliv{%
(Dan sesungguhnya Kami telah mengutus Nuh kepada kaumnya) sewaktu Nabi Nuh diangkat menjadi Rasul ia berumur empat puluh tahun atau lebih dari itu (maka ia tinggal di antara mereka selama sembilan ratus lima puluh tahun) seraya menyeru mereka untuk mentauhidkan Allah, tetapi mereka yakni kaumnya, tetap mendustakannya. (Maka mereka ditimpa banjir besar) yaitu, air bah yang sangat tinggi sehingga tenggelamlah mereka semuanya (dan mereka adalah orang-orang yang zalim) maksudnya adalah orang-orang yang menyekutukan Allah.\qt@no{14}}%
\qt@newcmd\qurantrans@id@mmmccclv{%
(Maka Kami selamatkan dia) Nabi Nuh (dan penumpang-penumpang bahtera itu) yang bersama Nabi Nuh di dalam bahtera (dan Kami jadikan peristiwa itu tanda) pelajaran (bagi semua umat manusia) yang datang sesudah mereka, jika mereka berbuat durhaka kepada Rasul-rasul mereka. Setelah peristiwa banjir besar itu Nabi Nuh hidup selama enam puluh tahun atau lebih, sehingga jumlah manusia menjadi banyak.\qt@no{15}}%
\qt@newcmd\qurantrans@id@mmmccclvi{%
(Dan) ingatlah (Ibrahim ketika ia berkata kepada kaumnya, ``Sembahlah Allah dan bertakwalah kalian kepada-Nya!) takutlah kalian akan azab dan hukuman-Nya. (Demikian itu lebih baik bagi kalian) daripada apa yang sekarang kalian kerjakan yaitu menyembah berhala (jika kalian mengetahui) mana yang baik dan mana yang tidak baik.\qt@no{16}}%
\qt@newcmd\qurantrans@id@mmmccclvii{%
(Sesungguhnya apa yang kalian sembah selain Allah itu) (adalah berhala-berhala, dan kalian membuat dusta) kalian mengatakan kebohongan, bahwa berhala-berhala itu adalah sekutu-sekutu Allah. (Sesungguhnya yang kalian. sembah selain Allah itu tidak mampu memberikan rezeki kepada kalian) maksudnya mereka tidak akan mampu memberi rezeki kepada kalian (maka mintalah rezeki di sisi Allah) yakni mintalah rezeki itu kepada-Nya (dan sembahlah Dia dan bersyukurlah kepada-Nya. Hanya kepada-Nya-lah kalian akan dikembalikan).\qt@no{17}}%
\qt@newcmd\qurantrans@id@mmmccclviii{%
(Dan jika kalian mendustakan) aku, hai penduduk Mekah (maka umat sebelum kalian juga telah mendustakan) umat-umat sebelumku. (Dan kewajiban Rasul itu tidak lain hanyalah menyampaikan agama Allah dengan seterang-terangnya") dengan penyampaian yang sejelas-jelasnya. Pada kedua kisah ini terkandung makna yang dapat menghibur hati Nabi saw. dan Allah berfirman kepada kaumnya,\qt@no{18}}%
\qt@newcmd\qurantrans@id@mmmccclix{%
(Dan apakah mereka tidak memperhatikan) dapat dibaca Yarau dan Tarau, artinya memikirkan (bagaimana Allah menciptakan manusia dari permulaannya) lafal Yubdi-u menurut suatu qiraat dibaca Yabda-u berasal dari Bada-a, makna yang dimaksud bagaimana Allah menciptakan mereka dari permulaan (kemudian) Dia (mengulanginya kembali) maksudnya mengulangi penciptaan-Nya kembali sebagaimana permulaan Dia menciptakan mereka. (Sesungguhnya yang demikian itu) yaitu hal yang telah disebutkan mengenai penciptaan pertama dan penciptaan kedua (adalah mudah bagi Allah) dan kenapa mereka mengingkari adanya penciptaan yang kedua itu; yang dimaksud adalah hari berbangkit.\qt@no{19}}%
\qt@newcmd\qurantrans@id@mmmccclx{%
(Katakanlah, ``Berjalanlah kalian di muka bumi, maka perhatikanlah bagaimana Allah memulai penciptaan-Nya) yakni menciptakan orang-orang yang sebelum kalian, kemudian Dia mematikan mereka (lalu Allah menjadikannya sekali lagi) dapat dibaca An Nasy-atal akhirata dan An Nasy-atal ukhra. (Sesungguhnya Allah Maha Kuasa atas segala sesuatu) antara lain ialah memulai dan mengulanginya.\qt@no{20}}%
\qt@newcmd\qurantrans@id@mmmccclxi{%
(Allah mengazab siapa yang dikehendaki-Nya) menerima azab-Nya (dan memberi rahmat kepada siapa yang dikehendaki-Nya) untuk menerima rahmat-Nya (dan hanya kepada-Nya-lah kalian akan dikembalikan) yakni, hanya kepada-Nya-lah kalian kembali.\qt@no{21}}%
\qt@newcmd\qurantrans@id@mmmccclxii{%
(Dan kalian sekali-kali tidak dapat melepaskan diri) dari jangkauan kekuasaan Rabb kalian (di bumi dan tidak pula di langit) jika kalian berada padanya; makna yang dimaksud ialah bahwa kalian tidak akan dapat terlepas daripada-Nya di mana pun kalian berada (dan sekali-kali tiadalah bagi kalian seorang pelindung pun selain dari Allah) yang dapat mencegah azab-Nya atas kalian (dan tidak pula seorang penolong) yang dapat menolong kalian dari azab-Nya.\qt@no{22}}%
\qt@newcmd\qurantrans@id@mmmccclxiii{%
(Orang-orang yang kafir kepada ayat-ayat Allah dan pertemuan dengan Dia) tidak percaya pada Alquran dan adanya hari berbangkit (mereka putus asa dari rahmat-Ku) surga-Ku (dan mereka itu mendapat azab yang pedih) yakni azab yang menyakitkan.\qt@no{23}}%
\qt@newcmd\qurantrans@id@mmmccclxiv{%
Allah berfirman sehubungan dengan kisah Nabi Ibrahim a.s.: (Maka tiadalah jawaban kaumnya selain mengatakan, ``Bunuhlah atau bakarlah dia," lalu Allah menyelamatkannya dari api) mereka melemparkannya ke dalam api, sedangkan Allah menjadikan api itu dingin dan keselamatan bagi Ibrahim. (Sesungguhnya pada yang demikian itu) yakni diselamatkannya Nabi Ibrahim dari api (benar-benar terdapat tanda-tanda kebesaran Allah) yaitu tidak berpengaruhnya api terhadap diri Nabi Ibrahim, padahal api itu sangat besar nyalanya, kemudian dalam waktu yang sangat singkat Allah menjadikan bekas api itu sebuah taman (bagi orang-orang yang beriman) yakni bagi orang-orang yang percaya kepada keesaan Allah dan kekuasaan-Nya, karena hanya mereka saja yang dapat mengambil manfaat dari kisah ini.\qt@no{24}}%
\qt@newcmd\qurantrans@id@mmmccclxv{%
(Dan berkatalah dia) Nabi Ibrahim ("Sesungguhnya berhala-berhala yang kalian sembah selain Allah) huruf ma adalah mashdariyyah (adalah untuk menciptakan perasaan kasih sayang di antara kalian) lafal ayat ini adalah khabar dari inna. Tetapi menurut qiraat yang lain dibaca nashab sehingga menjadi mawaddatan sebagai maf`ul lah, sedangkan huruf maa tadi dianggap sebagai maa kaffah, yakni yang mencegah beramalnya inna. Maksudnya, kalian menjadikan penyembahan kepada berhala-berhala itu sebagai sarana untuk memelihara kasih sayang di antara kalian (dalam kehidupan dunia ini, kemudian di hari kiamat sebagian kalian mengingkari sebagian yang lain) yakni para pemimpin penyembah berhala itu cuci tangan dari apa yang dilakukan oleh para pengikutnya (dan sebagian kalian mengutuk sebagian yang lain) yakni para pengikut mengutuk para pemimpin mereka (dan tempat kembali kalian) semuanya (ialah neraka, dan sekali-kali tak ada bagi kalian para penolong pun.") yang dapat mencegah kalian dari masuk neraka.\qt@no{25}}%
\qt@newcmd\qurantrans@id@mmmccclxvi{%
(Maka berimanlah kepadanya) percayalah kepada Nabi Ibrahim (Luth) ia adalah anak saudara lelaki Nabi Ibrahim bernama Haran. (Dan berkatalah dia) Nabi Ibrahim: ("Sesungguhnya aku akan berpindah") dari kaumku (kepada Rabbku) yaitu akan berpindah ke tempat yang diperintahkan oleh Rabbku, kemudian Nabi Ibrahim meninggalkan kaumnya dari pedalaman negeri Irak menuju ke negeri Syam. (Sesungguhnya Dialah Yang Maha Perkasa) di dalam kerajaan-Nya (lagi Maha Bijaksana) dalam perbuatan-Nya.\qt@no{26}}%
\qt@newcmd\qurantrans@id@mmmccclxvii{%
(Dan Kami anugerahkan kepada Ibrahim) setelah berputra Ismail (Ishak dan Yakub) Yakub lahir sesudah Ishak (dan Kami jadikan pada keturunannya kenabian) semua nabi sesudah Nabi Ibrahim terdiri dari keturunannya (dan Alkitab) sekalipun lafal Alkitab bentuknya mufrad atau tunggal, tetapi makna yang dimaksud adalah jamak yaitu kitab Taurat, Injil, Zabur dan Alquran (dan Kami berikan kepadanya balasannya di dunia) yaitu dia menjadi buah tutur yang baik di kalangan para pemeluk setiap agama (dan sesungguhnya dia di akhirat benar-benar termasuk orang-orang yang saleh) yakni orang-orang yang mempunyai kedudukan yang tinggi di akhirat.\qt@no{27}}%
\qt@newcmd\qurantrans@id@mmmccclxviii{%
(Dan) ingatlah (ketika Luth berkata kepada kaumnya, ``Sesungguhnya kalian) inna dapat dibaca tahqiq dan tashil (benar-benar mengerjakan perbuatan yang amat keji) yakni mendatangi dubur laki-laki/homosex (yang belum pernah dikerjakan oleh seorang pun dari umat-umat sebelum kalian.") baik oleh manusia maupun jin.\qt@no{28}}%
\qt@newcmd\qurantrans@id@mmmccclxix{%
(Apakah sesungguhnya kalian patut mendatangi laki-laki, menyamun) orang-orang yang lewat di tempat kalian, kemudian kalian melakukan perbuatan keji terhadapnya di tempat kalian, sehingga orang-orang tidak mau lagi lewat di jalan kalian (dan kalian mengerjakan di tempat-tempat pertemuan kalian) yakni tempat kalian berkumpul (perbuatan kemungkaran) yakni sebagian kalian melakukan perbuatan keji dengan sebagian yang lain. (Maka jawaban kaumnya tidak lain hanya mengatakan, ``Datangkanlah kepada kami azab Allah, jika kamu termasuk orang-orang yang benar.") menganggap keji perbuatan ini, dan bahwasanya azab akan menimpa atas para pelakunya.\qt@no{29}}%
\qt@newcmd\qurantrans@id@mmmccclxx{%
(Luth berdoa, ``Ya Rabbku, tolonglah aku) dengan membuktikan apa yang telah aku katakan kepada mereka, yaitu menurunkan azab (atas kaum yang berbuat kerusakan itu.") Maksudnya mereka yang durhaka karena melakukan homosex, Allah memperkenankan doa Nabi Luth.\qt@no{30}}%
\qt@newcmd\qurantrans@id@mmmccclxxi{%
(Dan tatkala utusan Kami/para malaikat datang kepada Ibrahim membawa kabar gembira) mengenai akan lahirnya Ishak dan Yakub sesudahnya (mereka mengatakan, ``Sesungguhnya kami akan menghancurkan penduduk negeri ini) yang ditempati oleh kaum Nabi Luth (sesungguhnya penduduknya adalah orang-orang yang lalim.") yakni orang-orang yang kafir.\qt@no{31}}%
\qt@newcmd\qurantrans@id@mmmccclxxii{%
(Berkata dia) Ibrahim ("Sesungguhnya di kota itu ada Luth." Mereka berkata) para Malaikat itu berkata: ("Kami lebih mengetahui siapa yang ada di kota itu, Kami sungguh-sungguh akan menyelamatkan dia) lanunajjiyannahu dapat dibaca secara takhfif yaitu lanunjiyannahu, dapat pula dibaca tasydid, yaitu lanunajjiyannahu (beserta pengikut-pengikutnya kecuali istrinya. Dia adalah termasuk orang-orang yang tertinggal.") termasuk orang-orang yang dibinasakan.\qt@no{32}}%
\qt@newcmd\qurantrans@id@mmmccclxxiii{%
(Dan tatkala datang utusan-utusan Kami itu kepada Luth, dia merasa susah karena kedatangan mereka) dia merasa susah disebabkan adanya mereka (dan merasa tidak mempunyai kekuatan untuk melindungi mereka) karena mereka memiliki wajah-wajah tampan, mereka menyamar sebagai tamu Nabi Luth. Nabi Luth merasa takut kaumnya akan melakukan hal-hal yang tidak diinginkan terhadap tamu-tamunya, maka para utusan itu memberitahukan kepadanya, bahwa mereka adalah utusan dari Rabbnya (dan mereka berkata, ``Janganlah kamu takut dan jangan pula susah. Sesungguhnya kami akan menyelamatkan kamu) dapat dibaca munajjuuka dan munjuuka (dan pengikut-pengikutmu kecuali istrimu, dia adalah termasuk orang-orang yang tertinggal") dinashabkannya lafal ahlaka karena diathafkan secara mahal kepada huruf kaf yang ada pada lafal munajjuuka.\qt@no{33}}%
\qt@newcmd\qurantrans@id@mmmccclxxiv{%
(Sesungguhnya Kami akan menurunkan) dapat dibaca munziluuna dan munazziluuna (azab atas penduduk kota ini) yakni siksaan (dari langit karena) perbuatan (kefasikan yang mereka kerjakan) disebabkan kefasikan mereka.\qt@no{34}}%
\qt@newcmd\qurantrans@id@mmmccclxxv{%
(Dan sesungguhnya Kami tinggalkan daripadanya satu tanda yang nyata) yang jelas, yaitu berupa bekas-bekas kehancuran mereka (bagi orang-orang yang berakal) bagi mereka yang mau berpikir.\qt@no{35}}%
\qt@newcmd\qurantrans@id@mmmccclxxvi{%
(Dan) Kami utus (kepada penduduk Madyan saudara mereka Syuaib, maka ia berkata, ``Hai kaumku! Sembahlah oleh kalian Allah, harapkanlah pahala hari akhir) maksudnya takutlah kalian akan hari itu, yaitu hari kiamat (dan janganlah kalian berkeliaran di muka bumi berbuat kerusakan.") Lafal mufsidiina berkedudukan sebagai hal atau kata keterangan keadaan yang mengukuhkan makna 'amilnya. Lafal ta'tsau berasal dari lafal 'atsiya yang artinya membuat kerusakan.\qt@no{36}}%
\qt@newcmd\qurantrans@id@mmmccclxxvii{%
(Maka mereka mendustakan Syuaib, lalu mereka ditimpa gempa yang dahsyat) gempa yang sangat kuat goncangannya (dan jadilah mereka mayit-mayit yang bergelimpangan di rumah-rumah mereka) yakni mereka mati dalam keadaan terduduk di atas lutut mereka di tempat tinggal masing-masing.\qt@no{37}}%
\qt@newcmd\qurantrans@id@mmmccclxxviii{%
(Dan) Kami binasakan (kaum Ad dan Tsamud) lafal tsamuuda dapat pula dibaca tsamuudan dengan memakai harakat tanwin, maksudnya adalah nama kabilah (dan sungguh telah nyata bagi kalian) kebinasaan mereka (dari puing-puing tempat tinggal mereka) di daerah Al-Hijr dan negeri Yaman. (Dan setan menjadikan mereka memandang baik perbuatan-perbuatan mereka) seperti kekafiran dan kemaksiatan (lalu ia menghalangi mereka dari jalan) yang benar (sedangkan mereka adalah orang-orang yang berpandangan tajam) yakni memiliki pandangan tentang perkara hak itu tetapi mereka tidak mau mengikutinya.\qt@no{38}}%
\qt@newcmd\qurantrans@id@mmmccclxxix{%
(Dan) telah Kami binasakan pula (Qarun, Firaun dan Haman. Dan sesungguhnya telah datang kepada mereka) sebelumnya (Musa dengan membawa keterangan-keterangan yang nyata) hujah-hujah yang jelas dan gamblang. (Akan tetapi mereka berlaku sombong di muka bumi dan tiadalah mereka orang-orang yang luput) dari azab Kami.\qt@no{39}}%
\qt@newcmd\qurantrans@id@mmmccclxxx{%
(Maka masing-masing) dari orang-orang yang telah disebutkan di atas tadi (Kami siksa disebabkan dosanya, maka di antara mereka ada yang Kami timpakan kepadanya hujan batu kerikil) yaitu angin topan yang dibarengi dengan batu-batu kerikil, sebagaimana azab yang telah menimpa kaum Nabi Luth (dan di antara mereka ada yang ditimpa suara keras yang mengguntur) seperti azab yang menimpa kaum Tsamud (dan di antara mereka ada yang Kami benamkan ke dalam bumi) sebagaimana yang dialami oleh Qarun (dan di antara mereka ada yang Kami tenggelamkan) seperti yang menimpa kaum Nabi Nuh dan Firaun beserta kaumnya (dan Allah sekali-kali tidak hendak menganiaya mereka) maksudnya tidak akan mengazab mereka dengan tanpa dosa (akan tetapi merekalah yang menganiaya diri mereka sendiri) disebabkan mereka telah melakukan dosa.\qt@no{40}}%
\qt@newcmd\qurantrans@id@mmmccclxxxi{%
(Perumpamaan orang-orang yang mengambil pelindung-pelindung selain Allah) yakni berhala-berhala yang mereka harapkan dapat memberi manfaat kepada diri mereka (adalah seperti laba-laba yang membuat rumah) untuk tempat tinggalnya. (Dan sesungguhnya rumah yang paling lemah) yang paling rapuh (ialah rumah laba-laba) karena tidak dapat melindungi diri dari panas matahari dan dari dinginnya udara, demikian pula berhala-berhala itu, mereka tidak dapat memberikan manfaat apa pun kepada para penyembahnya (kalau mereka mengetahui) hal tersebut, tentu mereka tidak akan menyembahnya.\qt@no{41}}%
\qt@newcmd\qurantrans@id@mmmccclxxxii{%
(Sesungguhnya Allah mengetahui yang) arti huruf maa di sini bermakna alladzii, yakni apa yang (mereka seru) mereka sembah; lafal yad'uuna dapat pula dibaca tad'uuna (selain Allah) yakni selain daripada-Nya (yakni apa saja dan Dia Maha Perkasa) di dalam kerajaan-Nya (lagi Maha Bijaksana) di dalam perbuatan-Nya.\qt@no{42}}%
\qt@newcmd\qurantrans@id@mmmccclxxxiii{%
(Dan perumpamaan-perumpamaan ini) yang ada dalam Alquran (Kami buatkan) Kami jadikan (untuk manusia; dan tiada yang memahaminya) yang mengerti akan perumpamaan-perumpamaan ini (kecuali orang-orang yang berilmu) yakni, orang-orang yang berpikir.\qt@no{43}}%
\qt@newcmd\qurantrans@id@mmmccclxxxiv{%
(Allah menciptakan langit dan bumi dengan hak) dengan benar. (Sesungguhnya pada yang demikian itu terdapat tanda-tanda) yang menunjukkan akan kekuasaan Allah swt. (bagi orang-orang mukmin) orang-orang mukmin disebutkan secara khusus karena hanya mereka sajalah yang dapat mengambil manfaat dari hal tersebut untuk memperkuat keimanannya, berbeda dengan orang-orang kafir.\qt@no{44}}%
\qt@newcmd\qurantrans@id@mmmccclxxxv{%
(Bacalah apa yang telah diwahyukan kepadamu, yaitu Alkitab) kitab Alquran (dan dirikanlah salat. Sesungguhnya salat itu mencegah dari perbuatan-perbuatan keji dan mungkar) menurut syariat seharusnya salat menjadi benteng bagi seseorang dari perbuatan-perbuatan keji dan mungkar, selagi ia benar-benar mengerjakannya. (Dan sesungguhnya mengingat Allah adalah lebih besar keutamaannya) daripada ibadah-ibadah dan amal-amal ketaatan lainnya. (Dan Allah mengetahui apa yang kalian kerjakan) maka Dia membalasnya kepada kalian.\qt@no{45}}%
\qt@newcmd\qurantrans@id@mmmccclxxxvi{%
(Dan janganlah kalian berdebat dengan ahli kitab, melainkan dengan cara) dengan perdebatan yang (paling baik) seperti menyeru mereka kepada Allah dengan mengemukakan ayat-ayat-Nya dan mengingatkan mereka pada bukti-bukti-Nya (kecuali dengan orang-orang yang lalim di antara mereka) misalnya mereka memerangi kalian dan membangkang tidak mau membayar jizyah, maka debatlah mereka dengan pedang hingga mereka masuk Islam atau tetap pada agamanya dengan membayar jizyah (dan katakanlah) kepada orang-orang ahli kitab yang berikrar untuk membayar jizyah, yaitu bilamana mereka menceritakan kepada kalian tentang sesuatu hal yang terdapat di dalam kitab-kitab mereka: ("Kami telah beriman kepada kitab yang diturunkan kepada kami dan yang diturunkan kepada kalian) janganlah kalian mempercayai mereka dan jangan pula kalian mendustakannya dalam hal ini. (Tuhan kami dan Tuhan kalian adalah satu; dan kami hanya kepada-Nya berserah diri.") Yakni, hanya kepada-Nya kami taat.\qt@no{46}}%
\qt@newcmd\qurantrans@id@mmmccclxxxvii{%
(Dan demikian pulalah Kami turunkan kepadamu Alkitab) Alquran sebagaimana telah diturunkan kepada mereka kitab Taurat dan kitab-kitab lainnya. (Maka orang-orang yang telah Kami berikan kepada mereka Alkitab) yakni kitab Taurat, seperti Abdullah bin Salam dan lain-lainnya (mereka beriman kepadanya) kepada Alquran (dan di antara mereka) penduduk Mekah (ada yang beriman kepadanya. Dan tiadalah yang mengingkari ayat-ayat Kami) sesudah ayat-ayat itu jelas (selain orang-orang kafir) maksudnya adalah orang-orang Yahudi, telah jelas di mata mereka bahwa Alquran itu adalah hak, dan orang yang mendatangkannya pun adalah benar, akan tetapi mereka tetap mengingkarinya.\qt@no{47}}%
\qt@newcmd\qurantrans@id@mmmccclxxxviii{%
(Dan kamu tidak pernah membaca sebelumnya) yaitu sebelum diturunkannya Alquran kepadamu (sesuatu kitab pun dan kamu tidak pernah menulis suatu kitab dengan tangan kananmu; andaikata kamu pernah membaca dan menulis) maksudnya, seandainya kamu orang yang pandai membaca dan menulis (benar-benar ragulah) pasti akan merasa ragu (orang-orang yang mengingkarimu) yakni orang-orang Yahudi terhadap dirimu, lalu mereka pasti akan mengatakan bahwa nabi yang disebutkan dalam kitab Taurat adalah nabi yang ummi, tidak dapat membaca dan tidak pula dapat menulis.\qt@no{48}}%
\qt@newcmd\qurantrans@id@mmmccclxxxix{%
(Sebenarnya Alquran itu) Alquran yang kamu datang dengan membawanya (adalah ayat-ayat yang nyata di dalam dada orang-orang yang diberi ilmu) orang-orang mukmin yang menghafalnya. (Dan tidak ada yang mengingkari ayat-ayat Kami kecuali orang-orang lalim) yakni orang-orang Yahudi; mereka mengingkarinya, padahal Alquran telah jelas bagi mereka.\qt@no{49}}%
\qt@newcmd\qurantrans@id@mmmcccxc{%
(Dan mereka berkata) yaitu orang-orang kafir Mekah ("Mengapa tidak) kenapa tidak (diturunkan kepadanya) kepada Nabi Muhammad (mukjizat-mukjizat dari Rabbnya?") Dan menurut suatu qiraat aayaatun dibaca aayatun dalam bentuk tunggal, maksudnya mukjizat yang seperti unta Nabi Saleh, tongkat Nabi Musa dan hidangan Nabi Isa. (Katakanlah) kepada mereka: ("Sesungguhnya mukjizat-mukjizat itu terserah kepada Allah) Dialah yang menurunkannya dalam bentuk apa yang dikehendaki-Nya. (Dan sesungguhnya aku hanya seorang pemberi peringatan yang nyata.") Yakni sebagai orang yang menjelaskan peringatanku kepada orang-orang yang berbuat maksiat, bahwa mereka akan dimasukkan ke dalam neraka.\qt@no{50}}%
\qt@newcmd\qurantrans@id@mmmcccxci{%
(Dan apakah tidak cukup bagi mereka) apa yang mereka minta itu (bahwasanya Kami telah menurunkan kepadamu Alkitab) Alquran (sedangkan dia dibacakan kepada mereka?) Alquran adalah mukjizat yang terus-menerus dan tiada habis-habisnya, berbeda dengan mukjizat-mukjizat lainnya yang telah disebutkan tadi. (Sesungguhnya dalam hal ini) yakni Alquran (terdapat rahmat dan pelajaran) nasihat (bagi orang-orang yang beriman).\qt@no{51}}%
\qt@newcmd\qurantrans@id@mmmcccxcii{%
(Katakanlah, ``Cukuplah Allah menjadi saksi antaraku dan antara kalian) yang menyaksikan kebenaranku (Dia mengetahui apa yang di langit dan di bumi) antara lain Dia mengetahui tentang keadaanku dan keadaan kalian. (Dan orang-orang yang percaya kepada yang batil) yaitu yang menyembah kepada selain Allah (dan ingkar kepada Allah) sebagaimana yang kalian lakukan (mereka itulah orang-orang yang merugi.") dalam transaksi mereka, karena mereka telah membeli kekafiran dengan keimanan.\qt@no{52}}%
\qt@newcmd\qurantrans@id@mmmcccxciii{%
(Dan mereka meminta kepadamu supaya segera diturunkan azab. Kalau tidak karena waktu yang telah ditetapkan) bagi turunnya azab itu (benar-benar telah datang azab kepada mereka) dengan segera (dan azab itu benar-benar akan datang kepada mereka dengan tiba-tiba sedangkan mereka tidak menyadarinya) tentang waktu datangnya azab itu.\qt@no{53}}%
\qt@newcmd\qurantrans@id@mmmcccxciv{%
(Mereka meminta kepadamu supaya segera diturunkan azab) di dunia. (Dan sesungguhnya Jahanam benar-benar meliputi orang-orang kafir).\qt@no{54}}%
\qt@newcmd\qurantrans@id@mmmcccxcv{%
(Pada hari mereka ditutup oleh azab dari atas mereka dan dari bawah kaki mereka dan Allah berkata) dapat dibaca naquulu, artinya Kami berkata, yaquulu artinya berkatalah malaikat yang diserahi tugas mengazab: ("Rasakanlah apa yang telah kalian kerjakan.") Yakni pembalasan dari apa yang telah kalian kerjakan, kalian tidak akan dapat meloloskan diri daripadanya.\qt@no{55}}%
\qt@newcmd\qurantrans@id@mmmcccxcvi{%
(Hai hamba-hamba-Ku yang beriman, sesungguhnya bumi-Ku luas, maka sembahlah Aku saja) di mana saja kalian dapat melakukannya dengan mudah, umpamanya kalian berhijrah dari suatu tempat yang kalian mendapat kesukaran untuk melakukannya, ke tempat yang kalian akan mendapat kemudahan untuk melakukannya. Ayat ini diturunkan berkenaan dengan kaum Muslimin Mekah yang lemah, karena mereka mendapat tekanan dari orang-orang kafir Mekah yang tidak menghendaki Islam berkembang di negerinya.\qt@no{56}}%
\qt@newcmd\qurantrans@id@mmmcccxcvii{%
(Tiap-tiap yang berjiwa akan merasakan mati. Kemudian hanyalah kepada Kami kalian dikembalikan) sesudah kalian dibangkitkan, lafal turja'uuna dapat pula dibaca yurja'uuna.\qt@no{57}}%
\qt@newcmd\qurantrans@id@mmmcccxcviii{%
(Orang-orang yang beriman dan mengerjakan amal-amal yang saleh, sesungguhnya akan Kami tempatkan mereka) akan diberi tempat tinggal. Menurut qiraat yang lain lafal lanubawwiannahum dibaca lanutsawwiannahum dengan memakai huruf tsa sebagai ganti huruf ba, karena berasal dari kata ats-tsawa yang artinya tempat bermukim, yang menjadi maf`ulnya adalah lafal ghurafan dengan membuang huruf fi (pada tempat-tempat yang tinggi di dalam surga, yang mengalir sungai-sungai di bawahnya, mereka kekal) mereka ditakdirkan hidup kekal (di dalamnya. Itulah sebaik-baik pembalasan bagi orang-orang yang beramal) imbalan yang terbaik.\qt@no{58}}%
\qt@newcmd\qurantrans@id@mmmcccxcix{%
Mereka adalah (orang-orang yang bersabar) mengalami perlakuan yang menyakitkan dari pihak kaum musyrikin dan bersabar di dalam hijrah meninggalkan tanah kelahiran mereka demi membela agama (dan mereka bertawakal hanya kepada Rabbnya) karenanya Dia memberi rezeki kepada mereka dari jalan yang tidak mereka duga.\qt@no{59}}%
\qt@newcmd\qurantrans@id@mmmcd{%
(Dan berapa banyak) alangkah banyaknya (binatang yang tidak dapat membawa rezekinya sendiri) karena lemah. (Allahlah yang memberi rezeki kepadanya dan kepada kalian) hai orang-orang Muhajirin, sekalipun kalian tidak membawa bekal dan pula tidak membawa nafkah (dan Dia Maha Mendengar) perkataan-perkataan kalian (lagi Maha Mengetahui) apa yang terpendam di dalam hati kalian.\qt@no{60}}%
\qt@newcmd\qurantrans@id@mmmcdi{%
(Dan sesungguhnya jika) huruf lam menunjukkan makna qasam (kamu tanyakan kepada mereka) yakni kepada orang-orang kafir: ("Siapakah yang menciptakan langit dan bumi dan menundukkan matahari dan bulan?" Tentu mereka akan menjawab, ``Allah," maka betapakah mereka dapat dipalingkan dari jalan yang benar?) Maksudnya dipalingkan dari mentauhidkan Allah, padahal sebelumnya mereka telah mengakui hal tersebut.\qt@no{61}}%
\qt@newcmd\qurantrans@id@mmmcdii{%
(Allah melapangkan rezeki) meluaskannya (bagi siapa yang dikehendaki-Nya di antara hamba-hamba-Nya) sebagai ujian dari-Nya (dan Dia pula yang membatasinya) yakni, menyempitkan rezeki (baginya) sesudah rezeki itu dilapangkan bagi siapa yang dikehendaki-Nya sebagai cobaan dari-Nya. (Sesungguhnya Allah Maha Mengetahui segala sesuatu) antara lain melapangkan dan menyempitkan rezeki.\qt@no{62}}%
\qt@newcmd\qurantrans@id@mmmcdiii{%
(Dan sesungguhnya jika) huruf lam pada lafal la-in adalah bermakna qasam (kamu menanyakan kepada mereka, ``Siapakah yang menurunkan air dari langit, lalu menghidupkan dengan air itu bumi sesudah matinya?" Tentu mereka akan menjawab, ``Allah.") Maka kenapa mereka menyekutukan-Nya. (Katakanlah) kepada mereka: ("Segala puji bagi Allah) atas tetapnya hujah terhadap kalian (tetapi kebanyakan mereka tidak memahaminya.") artinya tidak memahami kontradiksi mereka dalam hal ini.\qt@no{63}}%
\qt@newcmd\qurantrans@id@mmmcdiv{%
(Dan tiadalah kehidupan dunia ini melainkan senda gurau dan main-main) sedangkan amal-amal takarrub termasuk perkara akhirat karena buahnya akan dipetik di akhirat nanti. (Dan sesungguhnya akhirat itulah yang sebenarnya kehidupan) lafal al-hayawan artinya kehidupan (kalau mereka mengetahui) hal tersebut, niscaya mereka tidak akan memilih perkara duniawi dan meninggalkan perkara akhirat.\qt@no{64}}%
\qt@newcmd\qurantrans@id@mmmcdv{%
(Maka apabila mereka naik kapal, mereka berdoa kepada Allah dengan memurnikan ketaatan kepada-Nya.) Yakni mereka tidak menyeru selain-Nya, karena mereka dalam keadaan kritis dan bahaya, tiada seorang pun yang dapat melenyapkannya melainkan hanya Dia (maka tatkala Allah menyelamatkan mereka sampai ke darat, tiba-tiba mereka kembali mempersekutukan) Allah.\qt@no{65}}%
\qt@newcmd\qurantrans@id@mmmcdvi{%
Agar mereka mengingkari apa yang telah Kami berikan kepada mereka) berupa nikmat-nikmat (dan agar mereka hidup bersenang-senang) dengan berkumpulnya mereka untuk menyembah berhala-berhala. Menurut qiraat yang lain dibaca walyatamatta'uu dalam bentuk kata perintah, yang dimaksud adalah makna tahdid/ancaman, yakni bersenang-senanglah mereka. (Kelak mereka akan mengetahui) akibat perbuatannya itu.\qt@no{66}}%
\qt@newcmd\qurantrans@id@mmmcdvii{%
Dan apakah mereka tidak memperhatikan) tidak mengetahui (bahwa sesungguhnya Kami telah menjadikan) negeri mereka yakni Mekah (tanah suci yang aman, sedangkan manusia sekitarnya rampok-merampok) saling bunuh-membunuh dan saling rampok-merampok di antara sesama mereka, berbeda halnya dengan penduduk Mekah. (Maka mengapa kepada yang batil) kepada berhala (mereka percaya dan ingkar kepada nikmat Allah?) Karena kemusyrikan mereka itu.\qt@no{67}}%
\qt@newcmd\qurantrans@id@mmmcdviii{%
(Dan siapakah) tiada seorang pun (yang lebih lalim daripada orang-orang yang mengada-adakan kedustaan terhadap Allah) dengan cara menyekutukan-Nya (atau mendustakan yang hak) maksudnya, Nabi saw. atau Alquran (tatkala yang hak itu datang kepadanya? Bukankah dalam neraka Jahanam itu ada tempat) tempat tinggal (bagi orang-orang yang kafir) maksudnya, di dalam neraka itu ada tempat tinggal bagi orang-orang kafir, dan orang yang mengada-adakan kedustaan terhadap Allah itu adalah satu di antara mereka yang kafir.\qt@no{68}}%
\qt@newcmd\qurantrans@id@mmmcdix{%
(Dan orang-orang yang berjihad untuk Kami) demi untuk mencari keridaan Kami (benar-benar akan Kami tunjukkan kepada mereka jalan Kami) jalan yang menuju kepada Kami. (Dan sesungguhnya Allah benar-benar beserta orang-orang yang berbuat baik) yakni orang-orang mukmin dengan memberikan pertolongan dan bantuan-Nya kepada mereka.\qt@no{69}}%
\qt@newcmd\qurantrans@id@mmmcdx{%
\basmalahid (Alif lam mim) hanya Allah yang mengetahui maksudnya.\qt@no{1}}%
\qt@newcmd\qurantrans@id@mmmcdxi{%
Telah dikalahkan bangsa Romawi) mereka adalah ahli kitab yang dikalahkan oleh kerajaan Persia yang bukan ahli kitab, bahkan orang-orang Persia itu penyembah berhala. Dengan adanya berita ini bergembiralah orang-orang kafir Mekah, kemudian mereka mengatakan kepada kaum Muslimin, ``Kami pasti akan mengalahkan kalian, sebagaimana kerajaan Persia telah mengalahkan kerajaan Romawi."\qt@no{2}}%
\qt@newcmd\qurantrans@id@mmmcdxii{%
(Di negeri yang terdekat) yakni di kawasan Romawi yang paling dekat dengan wilayah kerajaan Persia, yaitu di jazirah Arabia; kedua pasukan yang besar itu bertemu di tempat tersebut, pihak yang mulai menyerang adalah pihak Persia, lalu bangsa Romawi berbalik menyerang (dan mereka) yakni bangsa Romawi (sesudah dikalahkan itu) di sini mashdar dimudhafkan pada isim maf'ul, maksudnya sesudah orang-orang Persia mengalahkan mereka, akhirnya mereka (akan menang) atas orang-orang Persia.\qt@no{3}}%
\qt@newcmd\qurantrans@id@mmmcdxiii{%
(Dalam beberapa tahun lagi) pengertian lafal bidh'u siniina adalah mulai dari tiga tahun sampai dengan sembilan atau sepuluh tahun. Kedua pasukan itu bertemu kembali pada tahun yang ketujuh sesudah pertempuran yang pertama tadi. Akhirnya dalam pertempuran ini pasukan Romawi berhasil mengalahkan pasukan kerajaan Persia. (Bagi Allah-lah urusan sebelum dan sesudahnya) yakni sebelum bangsa Romawi menang dan sesudahnya. Maksudnya, pada permulaannya pasukan Persia dapat mengalahkan pasukan Romawi, kemudian pasukan Romawi menang atas mereka dengan kehendak Allah. (Dan di hari itu) yakni di hari kemenangan bangsa Romawi (bergembiralah orang-orang yang beriman).\qt@no{4}}%
\qt@newcmd\qurantrans@id@mmmcdxiv{%
(Karena pertolongan Allah) kepada mereka atas pasukan Persia; orang-orang Mukmin merasa gembira mendengar berita ini, dan mereka mengetahui berita ini melalui malaikat Jibril yang turun memberitahukannya ketika mereka sedang dalam perang Badar. Kegembiraan mereka menjadi bertambah setelah mereka mendapat kemenangan atas orang-orang musyrik di dalam perang Badar (Dia menolong siapa yang dikehendaki-Nya. Dan Dialah Yang Maha Perkasa) Maha Menang (lagi Maha Penyayang) kepada orang-orang Mukmin.\qt@no{5}}%
\qt@newcmd\qurantrans@id@mmmcdxv{%
(Sebagai janji yang sebenar-benarnya dari Allah) lafal ayat ini merupakan mashdar sebagai badal atau pengganti dari lafal berikut fi'ilnya; asalnya adalah wa'adahumullaahun-nashra; artinya Allah menjanjikan pertolongan kepada mereka (Allah tidak akan menyalahi janji-Nya) yakni pertolongan itu (tetapi kebanyakan manusia) orang-orang kafir Mekah (tidak mengetahui) janji-Nya yang akan menolong orang-orang beriman.\qt@no{6}}%
\qt@newcmd\qurantrans@id@mmmcdxvi{%
(Mereka hanya mengetahui yang lahir saja dari kehidupan dunia) maksudnya urusan penghidupan dunia seperti berdagang, bercocok tanam, membangun rumah, bertanam dan kesibukan-kesibukan duniawi lainnya. (Sedangkan mereka terhadap kehidupan akhirat adalah lalai) diulanginya lafal hum mengandung makna taukid atau untuk mengukuhkan makna kelalaian mereka.\qt@no{7}}%
\qt@newcmd\qurantrans@id@mmmcdxvii{%
(Dan mengapa mereka tidak memikirkan tentang diri mereka sendiri?) supaya mereka sadar dari kelalaiannya. (Allah tidak menjadikan langit dan bumi serta apa yang ada di antara keduanya melainkan dengan tujuan yang benar dan waktu yang ditentukan) artinya akan lenyap setelah waktunya habis, sesudah itu tibalah saatnya hari berbangkit. (Dan sesungguhnya kebanyakan di antara manusia) yaitu orang-orang kafir Mekah (benar-benar ingkar akan pertemuan dengan Rabbnya) yakni mereka tidak percaya kepada adanya hari berbangkit sesudah mati.\qt@no{8}}%
\qt@newcmd\qurantrans@id@mmmcdxviii{%
(Dan apakah mereka tidak mengadakan perjalanan di muka bumi dan memperhatikan bagaimana akibat orang-orang yang sebelum mereka?) maksudnya umat-umat sebelum mereka, mereka dibinasakan karena mendustakan rasul-rasulnya. (Orang-orang itu adalah lebih kuat dari mereka sendiri) seperti kaum Ad dan kaum Tsamud (dan telah mengolah bumi) mereka telah mencangkul dan membajaknya untuk lahan pertanian dan perkebunan (serta memakmurkannya lebih banyak dari apa yang telah mereka makmurkan) artinya lebih banyak dari apa yang telah dimakmurkan oleh orang-orang kafir Mekah (dan telah datang kepada mereka rasul-rasul mereka dengan membawa bukti-bukti yang nyata) hujah-hujah yang jelas. (Maka Allah sekali-kali tidak berlaku lalim kepada mereka) dengan membinasakan mereka tanpa dosa (akan tetapi merekalah yang berlaku lalim kepada diri sendiri) karena mereka mendustakan rasul-rasul mereka.\qt@no{9}}%
\qt@newcmd\qurantrans@id@mmmcdxix{%
(Kemudian akibat orang-orang yang mengerjakan kejahatan adalah azab yang lebih buruk) lafal as-suu-a adalah bentuk muannats dari lafal al-aswa' artinya yang paling buruk, berkedudukan sebagai khabar dari lafal kaana bila lafal 'aqibah dibaca rafa', tapi bila dibaca nashab berarti menjadi isim kaana. Makna yang dimaksud berupa azab neraka Jahanam dan mereka dijelek-jelekkan di dalamnya (disebabkan) (mereka mendustakan ayat-ayat Allah) yakni Alquran (dan mereka selalu memperolok-oloknya).\qt@no{10}}%
\qt@newcmd\qurantrans@id@mmmcdxx{%
(Allah menciptakan dari permulaan) Dia menciptakan manusia dari permulaan (kemudian mengembalikannya kembali) Dia menghidupkan mereka kembali sesudah mereka mati (kemudian kepada-Nyalah kalian dikembalikan) lafal ini dapat dibaca turja'uuna dan yurja'uuna.\qt@no{11}}%
\qt@newcmd\qurantrans@id@mmmcdxxi{%
(Dan pada hari terjadinya kiamat, orang-orang yang zalim terdiam berputus asa) orang-orang musyrik diam karena mereka sudah tidak mempunyai alasan lagi.\qt@no{12}}%
\qt@newcmd\qurantrans@id@mmmcdxxii{%
(Dan sekali-kali tidak ada) (bagi mereka dari sekutu-sekutu mereka) yang mereka sekutukan dengan Allah, yaitu berhala-berhala yang mereka harapkan untuk dapat memberi syafaat kepada mereka (yang memberi syafaat dan adalah mereka) yakni mereka bakal (mengingkari sekutu-sekutu mereka itu) berlepas diri daripada berhala-berhala mereka.\qt@no{13}}%
\qt@newcmd\qurantrans@id@mmmcdxxiii{%
(Dan pada hari terjadinya kiamat, di hari itu) lafal yaumaidzin berfungsi sebagai taukid atau mengukuhkan makna yauma (mereka bergolong-golongan) yakni golongan orang-orang Mukmin dan golongan orang-orang kafir.\qt@no{14}}%
\qt@newcmd\qurantrans@id@mmmcdxxiv{%
(Adapun orang-orang yang beriman mengerjakan amal saleh, maka mereka di dalam taman) surga (bergembira) merasa bahagia.\qt@no{15}}%
\qt@newcmd\qurantrans@id@mmmcdxxv{%
(Adapun orang-orang yang kafir dan mendustakan ayat-ayat Kami) yaitu Alquran (serta mendustakan menemui hari akhirat) yaitu hari berbangkit dan lain-lainnya (maka mereka tetap berada di dalam siksaan).\qt@no{16}}%
\qt@newcmd\qurantrans@id@mmmcdxxvi{%
(Maka bertasbihlah kepada Allah) maksudnya salatlah kalian (di waktu kalian berada di petang hari) di kala kalian memasuki petang hari; di dalam waktu ini terdapat dua salat, yaitu salat Magrib dan salat Isyak (dan di waktu kalian berada di waktu subuh) sewaktu kalian memasuki pagi hari di dalam waktu ini terdapat salat subuh.\qt@no{17}}%
\qt@newcmd\qurantrans@id@mmmcdxxvii{%
(Dan bagi-Nyalah segala puji di langit dan di bumi) kalimat ayat ini merupakan jumlah i'tiradh, maksudnya Dia dipuji oleh penduduk langit dan bumi (dan di waktu kalian berada pada petang hari) diathafkan kepada lafal hiina yang ada pada ayat sebelumnya; di dalam waktu ini terdapat salat Isyak (dan sewaktu kalian berada di waktu Zuhur) yakni di waktu kalian memasuki tengah hari, yang pada waktu itu terdapat salat Zuhur.\qt@no{18}}%
\qt@newcmd\qurantrans@id@mmmcdxxviii{%
(Dia mengeluarkan yang hidup dari yang mati) sebagaimana manusia, Dia menciptakan manusia dari air mani dan sebagaimana burung yang Dia ciptakan dari telur (dan mengeluarkan yang mati) yaitu air mani dan telur (dari yang hidup dan menghidupkan bumi) dengan menumbuhkan tumbuh-tumbuhan (sesudah matinya) sesudah kering. (Dan seperti itulah) dengan cara itulah (kalian akan dikeluarkan) dari kubur.\qt@no{19}}%
\qt@newcmd\qurantrans@id@mmmcdxxix{%
(Dan di antara tanda-tanda-Nya) yang menunjukkan akan kekuasaan-Nya (ialah Dia menciptakan kalian dari tanah) asal kalian yaitu Nabi Adam (kemudian tiba-tiba kalian menjadi manusia) yang terdiri dari darah dan daging (yang berkembang biak) di muka bumi.\qt@no{20}}%
\qt@newcmd\qurantrans@id@mmmcdxxx{%
(Dan di antara tanda-tanda kekuasaan-Nya ialah Dia menciptakan untuk kalian istri-istri dari jenis kalian sendiri) Siti Hawa tercipta dari tulang rusuk Nabi Adam sedangkan manusia yang lainnya tercipta dari air mani laki-laki dan perempuan (supaya kalian cenderung dan merasa tenteram kepadanya) supaya kalian merasa betah dengannya (dan dijadikan-Nya di antara kamu sekalian) semuanya (rasa kasih sayang. Sesungguhnya pada yang demikian itu) hal yang telah disebutkan itu (benar-benar terdapat tanda-tanda bagi kaum yang berpikir) yakni yang memikirkan tentang ciptaan Allah swt.\qt@no{21}}%
\qt@newcmd\qurantrans@id@mmmcdxxxi{%
(Dan di antara tanda-tanda kekuasaan-Nya ialah menciptakan langit dan bumi dan berlain-lainan bahasa kalian) maksudnya dengan bahasa yang berlainan, ada yang berbahasa Arab dan ada yang berbahasa Ajam serta berbagai bahasa lainnya (dan berlain-lainan pula warna kulit kalian) di antara kalian ada yang berkulit putih, ada yang hitam dan lain sebagainya, padahal kalian berasal dari seorang lelaki dan seorang perempuan, yaitu Nabi Adam dan Siti Hawa. (Sesungguhnya pada yang demikian itu benar-benar terdapat tanda-tanda) yang menunjukkan kekuasaan Allah swt. (bagi orang-orang yang mengetahui) yaitu bagi orang-orang yang berakal dan berilmu. Dapat dibaca lil'aalamiina dan lil'aalimiina.\qt@no{22}}%
\qt@newcmd\qurantrans@id@mmmcdxxxii{%
(Dan di antara tanda-tanda kekuasaan-Nya ialah tidur kalian di waktu malam dan siang hari) dengan kehendak-Nya sebagai waktu istirahat buat kalian (dan usaha kalian) di siang hari (mencari sebagian dari karunia-Nya) mencari rezeki dan penghidupan berkat kehendak-Nya. (Sesungguhnya pada yang demikian itu benar-benar terdapat tanda-tanda bagi kaum yang mendengarkan) dengan pendengaran yang dibarengi pemikiran dan mengambil pelajaran.\qt@no{23}}%
\qt@newcmd\qurantrans@id@mmmcdxxxiii{%
(Dan di antara tanda-tanda kekuasaan-Nya, Dia memperlihatkan kepada kalian) Dia mempersaksikan kepada kalian (kilat untuk menimbulkan ketakutan) bagi orang yang melakukan perjalanan karena takut disambar petir (dan harapan) bagi orang yang bermukim akan turunnya hujan (dan Dia menurunkan air hujan dari langit, lalu menghidupkan bumi dengan air itu sesudah matinya) Dia mengembangkannya dengan menumbuhkan tumbuh-tumbuhan padanya. (Sesungguhnya pada yang demikian itu) hal yang telah disebutkan tadi (benar-benar terdapat tanda-tanda bagi kaum yang mempergunakan akalnya) yaitu bagi mereka yang berpikir.\qt@no{24}}%
\qt@newcmd\qurantrans@id@mmmcdxxxiv{%
(Dan di antara tanda-tanda kekuasaan-Nya ialah berdirinya langit dan bumi dengan perintah-Nya) dengan kehendak-Nya tanpa tiang penyangga. (Kemudian apabila Dia memanggil kalian sekali panggil dari bumi) melalui tiupan sangkakala malaikat Israfil untuk membangunkan orang-orang yang telah mati dari kuburnya (seketika itu juga kalian keluar) dari kubur, kalian keluar dari dalam kubur melalui sekali seruan itu, merupakan tanda-tanda kekuasaan Allah swt.\qt@no{25}}%
\qt@newcmd\qurantrans@id@mmmcdxxxv{%
(Dan kepunyaan-Nyalah siapa saja yang ada di langit dan di bumi) sebagai miliknya, makhluk dan hamba-hamba-Nya. (Semuanya hanya kepada-Nya tunduk) yakni taat.\qt@no{26}}%
\qt@newcmd\qurantrans@id@mmmcdxxxvi{%
(Dan Dialah yang menciptakan dari permulaan) menciptakan manusia (kemudian mengembalikannya) menjadi hidup kembali setelah mereka mati (dan menghidupkan kembali itu adalah lebih mudah bagi-Nya) daripada memulai penciptaan; hal ini dikaitkan dengan realita yang berlaku di kalangan makhluk-Nya, yaitu bahwasanya mengulangi sesuatu itu lebih mudah daripada memulainya. Padahal kedua kondisi itu bagi Allah swt. sama saja mudahnya. (Dan bagi-Nyalah teladan yang maha tinggi di langit dan di bumi) yakni sifat yang maha tinggi, yaitu bahwa tiada Tuhan yang wajib disembah melainkan Allah (dan Dialah Yang Maha Perkasa) di dalam kerajaan-Nya (lagi Maha Bijaksana) di dalam ciptaan-Nya.\qt@no{27}}%
\qt@newcmd\qurantrans@id@mmmcdxxxvii{%
(Dia membuat) menjadikan (bagi kalian) hai orang-orang musyrik (perumpamaan) yang terdapat (di dalam diri kalian sendiri) yaitu (apakah ada di antara hamba-hamba sahaya yang dimiliki oleh tangan kanan kalian) semua hamba sahaya kalian (sekutu) bagi kalian (dalam memiliki rezeki yang telah Kami berikan kepada kalian) yaitu berupa harta benda dan lain-lainnya (maka kalian) dan mereka (sama dalam hak mempergunakan rezeki itu, kalian takut kepada mereka sebagaimana kalian takut kepada diri kalian sendiri?) yakni takut terhadap sesama orang-orang merdeka kalian. Kata istifham atau kata tanya mengandung arti nafi atau kata negatif. Makna yang dimaksud ialah, bukanlah hamba sahaya kalian itu adalah sekutu-sekutu bagi kalian di dalam memiliki rezeki dan harta benda yang ada pada sisi kalian, maka mengapa kalian menjadikan hamba-hamba Allah sebagai sekutu-sekutu-Nya? (Demikianlah Kami jelaskan ayat-ayat) Kami menerangkannya dengan cara penjelasan dan rincian seperti itu (bagi kaum yang berakal) bagi orang-orang yang menggunakan akal pikirannya.\qt@no{28}}%
\qt@newcmd\qurantrans@id@mmmcdxxxviii{%
(Tetapi orang-orang yang lalim, mengikuti) pengertian lalim di sini adalah menyekutukan Allah (hawa nafsunya tanpa ilmu pengetahuan; maka siapakah yang akan menunjuki orang yang telah disesatkan Allah?) maksudnya tidak ada seorang pun yang dapat menunjukinya. (Dan tiadalah bagi mereka seorang penolong pun) yang mencegah azab Allah atas mereka.\qt@no{29}}%
\qt@newcmd\qurantrans@id@mmmcdxxxix{%
(Maka hadapkanlah) hai Muhammad (wajahmu dengan lurus kepada agama Allah) maksudnya cenderungkanlah dirimu kepada agama Allah, yaitu dengan cara mengikhlaskan dirimu dan orang-orang yang mengikutimu di dalam menjalankan agama-Nya (fitrah Allah) ciptaan-Nya (yang telah menciptakan manusia menurut fitrah itu) yakni agama-Nya. Makna yang dimaksud ialah, tetaplah atas fitrah atau agama Allah. (Tidak ada perubahan pada fitrah Allah) pada agama-Nya. Maksudnya janganlah kalian menggantinya, misalnya menyekutukan-Nya. (Itulah agama yang lurus) agama tauhid itulah agama yang lurus (tetapi kebanyakan manusia) yakni orang-orang kafir Mekah (tidak mengetahui) ketauhidan atau keesaan Allah.\qt@no{30}}%
\qt@newcmd\qurantrans@id@mmmcdxl{%
(Dengan kembali) bertobat (kepada-Nya) kepada Allah swt., yaitu melaksanakan apa-apa yang diperintahkan oleh-Nya dan menjauhi hal-hal yang dilarang oleh-Nya. Lafal ayat ini merupakan hal atau kata keterangan keadaan bagi fa'il atau subjek yang terkandung di dalam lafal aqim beserta makna yang dimaksud daripadanya, yaitu hadapkanlah wajah kalian (dan bertakwalah kalian kepada-Nya) takutlah kalian kepada-Nya (serta dirikanlah salat dan janganlah kalian termasuk orang-orang yang mempersekutukan Allah).\qt@no{31}}%
\qt@newcmd\qurantrans@id@mmmcdxli{%
(Yaitu orang-orang) lafal ayat ini merupakan badal dari lafal minal musyrikiin berikut pengulangan huruf jarnya (yang memecah belah agamanya) disebabkan perselisihan mereka dalam apa yang mereka sembah (dan mereka menjadi beberapa golongan) menjadi bersekte-sekte dalam beragama. (Tiap-tiap golongan) dari kalangan mereka (dengan apa yang ada pada golongan mereka) maksudnya apa yang ada pada diri mereka (merasa bangga) yakni membanggakannya. Menurut qiraat yang lain lafal farraquu itu dibaca faraquu artinya mereka meninggalkan agama yang mereka diperintahkan untuk menjalankannya.\qt@no{32}}%
\qt@newcmd\qurantrans@id@mmmcdxlii{%
(Dan apabila manusia disentuh) orang-orang kafir Mekah (oleh suatu bahaya) oleh suatu marabahaya (mereka menyeru Tuhannya dengan kembali) yakni bertobat (kepada-Nya) bukan kepada selain-Nya (kemudian apabila Tuhan merasakan kepada mereka hanya sedikit saja rahmat) umpamanya dengan diturunkan hujan kepada mereka (tiba-tiba sebagian daripada mereka mempersekutukan Tuhannya).\qt@no{33}}%
\qt@newcmd\qurantrans@id@mmmcdxliii{%
(Sehingga mereka mengingkari akan rahmat yang telah Kami berikan kepada mereka) makna yang terkandung di dalam ayat ini adalah ancaman yang ditujukan kepada mereka yang ingkar itu. (Maka bersenang-senanglah kamu sekalian, kelak kalian akan mengetahui) akibat daripada bersenang-senang kalian itu; di dalam ungkapan ayat ini terkandung makna sindiran bagi orang-orang yang ketiga atau dhamir gaib.\qt@no{34}}%
\qt@newcmd\qurantrans@id@mmmcdxliv{%
(Atau pernahkah) lafal am menunjukkan arti yang sama dengan hamzah yang menunjukkan makna ingkar, yaitu bukankah (Kami menurunkan kepada mereka keterangan) yakni hujah dan Kitab (lalu keterangan itu menunjukkan) mengungkapkan dengan jelas (tentang apa yang mereka selalu mempersekutukannya dengan Tuhan?) Apakah kitab dan hujah tersebut memerintahkan mereka untuk berbuat musyrik, tentu saja tidak dan tidak akan ada.\qt@no{35}}%
\qt@newcmd\qurantrans@id@mmmcdxlv{%
(Dan apabila Kami rasakan kepada manusia) yakni orang-orang kafir Mekah dan orang-orang kafir lainnya (suatu rahmat) yakni suatu nikmat (niscaya mereka gembira dengan rahmat itu) mereka merasa bangga dengannya. (Dan apabila mereka ditimpa musibah) yaitu marabahaya (disebabkan kesalahan yang telah dikerjakan oleh tangan mereka sendiri, tiba-tiba mereka itu berputus asa) mereka putus harapan dari rahmat Allah. Orang beriman harus bersyukur bila diberi rahmat dan bila ditimpa marabahaya harus berdoa kepada Rabbnya.\qt@no{36}}%
\qt@newcmd\qurantrans@id@mmmcdxlvi{%
(Dan apakah mereka tidak memperhatikan) tidak mengetahui (bahwa sesungguhnya Allah melapangkan rezeki) meluaskannya (bagi siapa yang dikehendaki-Nya) sebagai ujian (dan Dia pula yang membatasinya) yang menyempitkannya kepada siapa yang dikehendaki-Nya sebagai cobaan buatnya. (Sesungguhnya pada yang demikian itu benar-benar terdapat tanda-tanda kekuasaan Allah bagi orang-orang yang percaya) pada tanda-tanda kekuasaan Allah itu.\qt@no{37}}%
\qt@newcmd\qurantrans@id@mmmcdxlvii{%
(Maka berikanlah kepada kerabat) kepada famili yang terdekat (akan haknya) yaitu dengan menyantuninya dan menghubungkan silaturahmi dengannya (demikian pula kepada fakir miskin dan ibnu sabil) orang yang sedang musafir, yaitu dengan memberikan sedekah kepada mereka, perintah ini ditujukan kepada Nabi saw. dan sebagai umatnya diharuskan mengikuti jejaknya. (Itulah yang lebih baik bagi orang-orang yang mencari keridaan Allah) yakni pahala-Nya sebagai imbalan dari apa yang telah mereka kerjakan (dan mereka itulah orang-orang yang beruntung) yaitu orang-orang yang memperoleh keberuntungan.\qt@no{38}}%
\qt@newcmd\qurantrans@id@mmmcdxlviii{%
(Dan sesuatu riba atau tambahan yang kalian berikan) umpamanya sesuatu yang diberikan atau dihadiahkan kepada orang lain supaya orang lain memberi kepadanya balasan yang lebih banyak dari apa yang telah ia berikan; pengertian sesuatu dalam ayat ini dinamakan tambahan yang dimaksud dalam masalah muamalah (agar dia menambah pada harta manusia) yakni orang-orang yang memberi itu, lafal yarbuu artinya bertambah banyak (maka riba itu tidak menambah) tidak menambah banyak (di sisi Allah) yakni tidak ada pahalanya bagi orang-orang yang memberikannya. (Dan apa yang kalian berikan berupa zakat) yakni sedekah (untuk mencapai) melalui sedekah itu (keridaan Allah, maka itulah orang-orang yang melipatgandakan) pahalanya sesuai dengan apa yang mereka kehendaki. Di dalam ungkapan ini terkandung makna sindiran bagi orang-orang yang diajak bicara atau mukhathabin.\qt@no{39}}%
\qt@newcmd\qurantrans@id@mmmcdxlix{%
(Allah-lah yang menciptakan kalian, kemudian memberi kalian rezeki, kemudian mematikan kalian, kemudian menghidupkan kalian kembali. Adakah di antara sekutu-sekutu kalian itu) yakni apa yang kalian sekutukan dengan Allah itu (yang dapat berbuat sesuatu dari yang demikian itu?) Tentu saja tidak ada. (Maha Sucilah Dia dan Maha Tinggi dari apa yang mereka persekutukan) dengan-Nya.\qt@no{40}}%
\qt@newcmd\qurantrans@id@mmmcdl{%
(Telah tampak kerusakan di darat) disebabkan terhentinya hujan dan menipisnya tumbuh-tumbuhan (dan di laut) maksudnya di negeri-negeri yang banyak sungainya menjadi kering (disebabkan perbuatan tangan manusia) berupa perbuatan-perbuatan maksiat (supaya Allah merasakan kepada mereka) dapat dibaca liyudziiqahum dan linudziiqahum; kalau dibaca linudziiqahum artinya supaya Kami merasakan kepada mereka (sebagian dari akibat perbuatan mereka) sebagai hukumannya (agar mereka kembali) supaya mereka bertobat dari perbuatan-perbuatan maksiat.\qt@no{41}}%
\qt@newcmd\qurantrans@id@mmmcdli{%
(Katakanlah) kepada orang-orang kafir Mekah: ("Adakanlah perjalanan di muka bumi dan perhatikanlah bagaimana kesudahan orang-orang yang dahulu. Kebanyakan dari mereka itu adalah orang-orang yang mempersekutukan Allah.") Yaitu mereka dibinasakan disebabkan kemusyrikan mereka, rumah-rumah dan tempat-tempat mereka kini kosong tak berpenghuni lagi karena penghuninya telah binasa.\qt@no{42}}%
\qt@newcmd\qurantrans@id@mmmcdlii{%
(Oleh karena itu maka hadapkanlah wajahmu kepada agama yang lurus) agama Islam (sebelum datang dari Allah suatu hari yang tak dapat ditolak kedatangannya) yaitu hari kiamat (pada hari itu mereka terpisah-pisah) pada asalnya lafal yashshadda'uuna adalah yatashadda'uuna kemudian huruf ta diganti menjadi shad yang selanjutnya diidghamkan atau dimasukkan kepada huruf shad lainnya sehingga jadilah yashshadda'uuna, yakni mereka berpisah-pisah sesudah mereka menjalani hisab; sebagian dari mereka ada yang masuk ke surga dan sebagian yang lainnya ada yang masuk ke neraka.\qt@no{43}}%
\qt@newcmd\qurantrans@id@mmmcdliii{%
(Barang siapa yang kafir maka dia sendirilah yang menanggung akibat kekafirannya) yaitu neraka sebagai imbalan dan akibat dari kekafirannya itu (dan barang siapa yang beramal saleh maka untuk diri mereka sendirilah mereka menyiapkan) menyiapkan tempat tinggal mereka di surga yang penuh dengan kesenangan itu.\qt@no{44}}%
\qt@newcmd\qurantrans@id@mmmcdliv{%
(Agar Allah memberi pahala) lafal ayat ini berta'alluq kepada lafal yashshadda'uuna pada ayat sebelumnya (kepada orang-orang yang beriman dan beramal saleh dari karunia-Nya) Dia memberi mereka pahala. (Sesungguhnya Dia tidak menyukai orang-orang yang kafir) Dia akan mengazab mereka.\qt@no{45}}%
\qt@newcmd\qurantrans@id@mmmcdlv{%
(Dan di antara tanda-tanda kekuasaan-Nya) yang menunjukkan akan kekuasaan Allah swt. (ialah bahwa Dia mengirimkan angin sebagai pembawa berita gembira) membawa berita gembira buat kalian mengenai akan turunnya hujan (dan untuk merasakan kepada kalian) melalui angin itu (sebagian dari rahmat-Nya) berupa hujan dan kesuburan sesudahnya (dan supaya kapal dapat berlayar) berkat adanya angin itu (dengan perintah-Nya) berdasarkan kehendak-Nya (dan juga supaya kalian dapat mencari) berupaya mencari (karunia-Nya) rezeki dari-Nya dengan cara berdagang melalui jalan laut (mudah-mudahan kalian bersyukur) atas adanya nikmat ini, hai penduduk Mekah, oleh karenanya kalian mengesakan-Nya.\qt@no{46}}%
\qt@newcmd\qurantrans@id@mmmcdlvi{%
(Dan sesungguhnya Kami telah mengutus sebelum kamu beberapa orang rasul kepada kaumnya, mereka datang kepadanya dengan membawa keterangan-keterangan yang jelas) hujah-hujah yang jelas yang membenarkan kerasulan mereka terhadap kaumnya, akan tetapi mereka mendustakannya (lalu Kami melakukan pembalasan terhadap orang-orang yang berdosa.) Kami binasakan orang-orang yang mendustakan para rasul-Nya. (Dan Kami selalu berkewajiban menolong orang-orang yang beriman) atas orang-orang kafir, yaitu dengan membinasakan orang-orang kafir dan menyelamatkan orang-orang yang beriman.\qt@no{47}}%
\qt@newcmd\qurantrans@id@mmmcdlvii{%
(Allah, Dialah yang mengirim angin, lalu angin itu menggerakkan awan) mengaraknya (dan Allah membentangkannya di langit menurut yang dikehendaki-Nya) makanya awan itu ada yang tipis dan ada yang tebal (dan menjadikannya bergumpal-gumpal) berkelompok-kelompok dan berpencar-pencar; dapat dibaca kisafan atau kisfan (lalu kamu lihat air) hujan (keluar dari celah-celahnya) dari celah-celah awan yang tebal itu (maka apabila hujan itu turun) (mengenai hamba-hamba-Nya yang dikehendaki-Nya tiba-tiba mereka menjadi gembira) mereka bergembira dengan turunnya hujan itu.\qt@no{48}}%
\qt@newcmd\qurantrans@id@mmmcdlviii{%
(Dan sesungguhnya) sungguh (sebelum hujan diturunkan kepada mereka) lafal min qablihi yang kedua ini berfungsi mengukuhkan makna lafal yang sama dengan sebelumnya (benar-benar telah berputus asa) putus harapan akan turunnya hujan.\qt@no{49}}%
\qt@newcmd\qurantrans@id@mmmcdlix{%
(Maka perhatikanlah bekas-bekas) menurut suatu qiraat dibaca dalam bentuk mufrad yakni atsari (rahmat Allah) nikmat yang dilimpahkan-Nya, yaitu berbentuk air hujan (bagaimana Allah menghidupkan bumi yang sudah mati) sesudah bumi itu kering dan tidak dapat menumbuhkan tetumbuhan lagi. (Sesungguhnya Dia yang berkuasa melakukan hal itu benar-benar berkuasa menghidupkan orang-orang yang telah mati. Dan Dia Maha Kuasa atas segala sesuatu).\qt@no{50}}%
\qt@newcmd\qurantrans@id@mmmcdlx{%
(Dan sungguh jika) lam menunjukkan makna qasam (Kami mengirimkan angin) yang membahayakan tumbuh-tumbuhan (lalu mereka melihat tumbuh-tumbuhan itu menjadi kuning/kering, benar-benar tetaplah mereka) benar-benar mereka menjadi; lafal ayat ini menjadi jawab dari qasam pada awal ayat tadi (sesudah itu) sesudah mengeringnya tumbuh-tumbuhan (orang-orang yang ingkar) mereka menjadi orang-orang yang mengingkari nikmat Allah, yaitu berupa hujan.\qt@no{51}}%
\qt@newcmd\qurantrans@id@mmmcdlxi{%
(Maka sesungguhnya kamu tidak akan sanggup menjadikan orang-orang yang mati itu dapat mendengar, dan menjadikan orang-orang yang tuli dapat mendengar seruan, apabila) lafal ad-du'aa idzaa dapat dibaca tahqiq dan tashil (mereka itu berpaling membelakangi).\qt@no{52}}%
\qt@newcmd\qurantrans@id@mmmcdlxii{%
(Dan kamu sekali-kali tidak akan dapat memberi petunjuk kepada orang-orang yang buta mata hatinya dari kesesatan, tidak lain) (kamu hanya dapat memperdengarkan) dengan pendengaran yang dibarengi dengan pemahaman dan mau menerima apa yang didengarnya (kepada orang-orang yang beriman dengan ayat-ayat Kami) yakni Alquran (mereka itulah orang-orang yang berserah diri) yaitu orang-orang yang ikhlas di dalam mentauhidkan Allah swt.\qt@no{53}}%
\qt@newcmd\qurantrans@id@mmmcdlxiii{%
(Allah, Dialah yang menciptakan kalian dari keadaan lemah) yaitu dari air mani yang hina lagi lemah itu (kemudian Dia menjadikan kalian sesudah keadaan lemah) yang lain yaitu masa kanak-kanak (menjadi kuat) masa muda yang penuh dengan semangat dan kekuatan (kemudian Dia menjadikan kalian sesudah kuat itu lemah kembali dan beruban) lemah karena sudah tua dan rambut pun sudah putih. Lafal dha'fan pada ketiga tempat tadi dapat dibaca dhu'fan. (Dia menciptakan apa yang dikehendaki-Nya) ada yang lemah, yang kuat, yang muda, dan yang tua (dan Dialah Yang Maha Mengetahui) mengatur makhluk-Nya (lagi Maha Kuasa) atas semua yang dikehendaki-Nya.\qt@no{54}}%
\qt@newcmd\qurantrans@id@mmmcdlxiv{%
(Dan pada hari terjadinya kiamat bersumpahlah) mengatakan sumpah (orang-orang yang berdosa) orang-orang kafir (mereka tidak berdiam) mereka tidak tinggal di dalam kubur (melainkan sesaat saja) maka Allah berfirman: (Seperti demikianlah mereka selalu dipalingkan) dari kebenaran atau dari perkara yang hak, yang dimaksud adalah tentang hari berbangkit. Maksudnya sebagaimana mereka dipalingkan dari kebenaran maka mereka pun dipalingkan pula dari masa yang sebenarnya mereka tinggal di dalam kubur.\qt@no{55}}%
\qt@newcmd\qurantrans@id@mmmcdlxv{%
(Dan berkata orang-orang yang diberi ilmu pengetahuan dan keimanan) para malaikat dan lain-lainnya: ("Sesungguhnya kalian telah berdiam menurut ketetapan Allah) sesuai dengan apa yang telah dipastikan oleh-Nya menurut ilmu Allah yang terdahulu (sampai hari berbangkit; maka inilah hari berbangkit itu) yang kalian ingkari itu (akan tetapi kalian selalu tidak meyakini") kejadiannya.\qt@no{56}}%
\qt@newcmd\qurantrans@id@mmmcdlxvi{%
(Maka pada hari itu tidak bermanfaat lagi) lafal yanfa'u dapat dibaca tanfa'u (bagi orang-orang yang lalim permintaan uzur mereka) alasan ingkar mereka kepada adanya hari berbangkit (dan tidak pula mereka diberi kesempatan bertobat) mereka tidak diperintahkan lagi untuk kembali bertobat kepada Allah swt. dengan melakukan perbuatan-perbuatan yang diridai-Nya.\qt@no{57}}%
\qt@newcmd\qurantrans@id@mmmcdlxvii{%
(Dan sesungguhnya telah Kami buatkan) telah Kami jadikan (di dalam Alquran ini segala macam perumpamaan untuk manusia) sebagai peringatan buat mereka. (Dan sesungguhnya jika) lam di sini bermakna qasam (kamu mendatangi mereka) hai Muhammad (dengan membawa suatu ayat) mukjizat seperti tongkat dan tangan Nabi Musa (pastilah akan berkata) dari lafal layaqulunna terbuang nun rafa', alasannya, karena berturut-turutnya beberapa nun, sedangkan wau-nya ikut dibuang pula, yaitu wau dhamir jamak, dengan alasan bukan karena bertemu dua huruf yang disukunkan (orang-orang yang kafir itu) sebagian dari mereka pasti mengatakan: ("Tidak lain) (kalian) yakni Nabi Muhammad dan para sahabatnya (hanyalah orang-orang yang membuat kepalsuan belaka") orang-orang yang mendatangkan kebatilan-kebatilan.\qt@no{58}}%
\qt@newcmd\qurantrans@id@mmmcdlxviii{%
(Demikianlah Allah mengunci mati hati orang-orang yang tidak mau memahami) ketauhidan, sebagaimana Dia mengunci mati hati orang-orang itu, maka Dia pun mengunci mati hati mereka yang mengatakan hal demikian terhadap Nabi Muhammad dan para sahabatnya.\qt@no{59}}%
\qt@newcmd\qurantrans@id@mmmcdlxix{%
(Maka bersabarlah kamu, sesungguhnya janji Allah) yang akan menolongmu atas mereka (adalah benar dan sekali-kali janganlah orang-orang yang tidak meyakini itu membuat kamu gelisah) yakni orang-orang yang tidak meyakini adanya hari berbangkit. Janganlah kamu menjadi gelisah dan membabi buta melihat tingkah mereka itu, tetaplah pada kesabaranmu, jangan hiraukan mereka.\qt@no{60}}%
\qt@newcmd\qurantrans@id@mmmcdlxx{%
\basmalahid (Alif lam mim) hanya Allah saja yang mengetahui arti dan maksud ayat ini.\qt@no{1}}%
\qt@newcmd\qurantrans@id@mmmcdlxxi{%
(Inilah) yakni ayat-ayat ini (ayat-ayat Alkitab) yakni Alquran (yang mengandung hikmah) idhafah lafal aayatu kepada lafal al-kitaabi mengandung makna min, maksudnya sebagian dari Alquran.\qt@no{2}}%
\qt@newcmd\qurantrans@id@mmmcdlxxii{%
Dia, yakni Alquran (menjadi petunjuk dan rahmat) lafal rahmatun dibaca rafa' (bagi orang-orang yang berbuat kebaikan) pada umumnya qiraat lafal rahmatun dibaca nashab sehingga bacaannya menjadi hudan wa rahmatan. Kedudukannya menjadi hal atau kata keterangan keadaan dari lafal aayatul kitaabi dan 'amilnya adalah makna isyarat yang terkandung dalam lafal tilka. Maksudnya, ayat-ayat Alquran ini sebagai petunjuk dan rahmat bagi orang-orang yang berbuat kebaikan.\qt@no{3}}%
\qt@newcmd\qurantrans@id@mmmcdlxxiii{%
(Yaitu orang-orang yang mendirikan salat) lafal ayat ini berkedudukan menjadi bayan atau penjelasan bagi lafal muhsiniin, maksudnya orang-orang yang berbuat kebaikan itu adalah orang-orang yang mendirikan salat (menunaikan zakat dan mereka yakin akan adanya hari akhirat) lafal hum yang kedua merupakan pengukuh makna bagi lafal hum yang pertama.\qt@no{4}}%
\qt@newcmd\qurantrans@id@mmmcdlxxiv{%
(Mereka itulah orang-orang yang tetap mendapat petunjuk dari Rabbnya dan mereka itulah orang-orang yang beruntung) yakni orang-orang yang memperoleh keberuntungan.\qt@no{5}}%
\qt@newcmd\qurantrans@id@mmmcdlxxv{%
(Dan di antara manusia ada orang yang mempergunakan perkataan yang tidak berguna) maksudnya (untuk menyesatkan) manusia; lafal ayat ini dapat dibaca liyadhilla dan liyudhilla (dari jalan Allah) dari jalan Islam (tanpa pengetahuan dan menjadikan jalan Allah itu) kalau dibaca nashab yaitu wa yattakhidzahaa berarti diathafkan kepada lafal yudhilla, dan jika dibaca rafa' yaitu wa yattakhidzuhaa, berarti diathafkan kepada lafal yasytarii (olok-olokan) menjadi objek ejekan dan olokan mereka. (Mereka itu akan memperoleh azab yang menghinakan) azab yang hina sekali.\qt@no{6}}%
\qt@newcmd\qurantrans@id@mmmcdlxxvi{%
(Dan apabila dibacakan kepadanya ayat-ayat Kami) ayat-ayat Alquran (dia berpaling dengan menyombongkan diri) dengan rasa sombong (seolah-olah dia belum mendengarnya, seakan-akan ada sumbatan di kedua telinganya) artinya kedua telinganya tersumbat; dan kedua jumlah tasybih menjadi hal atau kata keterangan keadaan dari dhamir yang terkandung di dalam lafal walla, atau tasybih yang kedua menjadi bayan atau penjelasan bagi tasybih yang pertama (maka beri kabar gembiralah dia) beritahukanlah kepadanya (dengan azab yang pedih) azab yang menyakitkan. Disebutkannya lafal al-bisyaarah dimaksudkan sebagai tahakkum atau ejekan, dan orang yang dimaksud adalah Nadhr bin Harits. Dia datang ke negeri Al-Hairah dengan tujuan berniaga, lalu ia membeli kitab-kitab cerita orang-orang Ajam. Setelah itu ia menceritakan isinya kepada penduduk Mekah seraya mengatakan, ``Sesungguhnya Muhammad telah menceritakan kepada kalian kisah-kisah kaum Ad dan kaum Tsamud, dan sekarang saya akan menceritakan kepada kalian kisah-kisah tentang kerajaan Romawi dan kerajaan Persia." Ternyata mereka menyenangi kisah Nadhr itu, karenanya mereka meninggalkan Alquran serta tidak mau mendengarkannya lagi.\qt@no{7}}%
\qt@newcmd\qurantrans@id@mmmcdlxxvii{%
(Sesungguhnya orang-orang yang beriman dan mengerjakan amal-amal saleh, bagi mereka surga-surga yang penuh kenikmatan).\qt@no{8}}%
\qt@newcmd\qurantrans@id@mmmcdlxxviii{%
(Kekal mereka di dalamnya) lafal ayat ini menjadi hal atau kata keterangan keadaan bagi lafal muqaddarah. Maksudnya telah dipastikan mereka kekal di dalamnya bila mereka memasukinya (sebagai janji Allah yang benar) Allah swt. telah menjanjikan hal tersebut kepada mereka dengan janji yang sebenar-benarnya. (Dan Dialah Yang Maha Perkasa) yang tidak ada sesuatu pun dapat mengalahkan-Nya sehingga Dia tidak akan menunaikan janji dan ancaman-Nya (lagi Maha Bijaksana) yang tiada meletakkan sesuatu melainkan pada tempatnya.\qt@no{9}}%
\qt@newcmd\qurantrans@id@mmmcdlxxix{%
(Dia menciptakan langit tanpa tiang yang kalian melihatnya) lafal 'amadin adalah bentuk jamak dari lafal 'imaadun yaitu pilar penyangga, dan memang langit itu tidak ada pilar yang menyangganya sejak diciptakannya (dan Dia meletakkan gunung-gunung di permukaan bumi) yakni gunung-gunung yang tinggi dan besar-besar supaya (jangan) tidak (menggoyangkan) tidak bergerak-gerak sehingga mengguncang (kalian dan mengembangbiakkan padanya segala macam jenis binatang. Dan Kami turunkan) di dalam ungkapan ayat ini terkandung iltifat dari ghaibah, seharusnya wa anzala (air hujan dari langit, lalu Kami tumbuhkan padanya segala macam tumbuh-tumbuhan yang baik) dari jenis tumbuh-tumbuhan yang baik.\qt@no{10}}%
\qt@newcmd\qurantrans@id@mmmcdlxxx{%
(Inilah ciptaan Allah) yakni makhluk-Nya (maka perlihatkanlah oleh kalian kepadaku) ceritakanlah kepadaku, hai penduduk Mekah (apa yang telah diciptakan oleh sesembahan-sesembahan kalian selain Allah) yang telah diciptakan oleh selain-Nya, yang dimaksud adalah sesembahan-sesembahan kalian, sehingga kalian menyekutukannya dengan Allah swt. Kata tanya maa menunjukkan makna ingkar, berkedudukan sebagai mubtada, sedangkan lafal dzaa yang berarti sama dengan lafal al-ladzii berikut dengan shilahnya menjadi khabar. Lafal aruuni tidak diberlakukan pengamalannya, sedangkan lafal-lafal yang sesudahnya menempati kedudukan sebagai kedua maf`ulnya. (Sebenarnya) akan tetapi (orang-orang yang lalim itu berada di dalam kesesatan yang nyata) disebabkan mereka menyekutukan Allah dan kalian adalah sebagian dari mereka.\qt@no{11}}%
\qt@newcmd\qurantrans@id@mmmcdlxxxi{%
(Dan sesungguhnya telah Kami berikan kepada Luqman hikmah) antara lain ilmu, agama dan tepat pembicaraannya, dan kata-kata mutiara yang diucapkannya cukup banyak serta diriwayatkan secara turun-temurun. Sebelum Nabi Daud diangkat menjadi rasul dia selalu memberikan fatwa, dan dia sempat mengalami zaman kenabian Nabi Daud, lalu ia meninggalkan fatwa dan belajar menimba ilmu dari Nabi Daud. Sehubungan dengan hal ini Luqman pernah mengatakan, ``Aku tidak pernah merasa cukup apabila aku telah dicukupkan." Pada suatu hari pernah ditanyakan oleh orang kepadanya, ``Siapakah manusia yang paling buruk itu?" Luqman menjawab, ``Dia adalah orang yang tidak mempedulikan orang lain yang melihatnya sewaktu dia mengerjakan kejahatan." (Yaitu) dan Kami katakan kepadanya, hendaklah (bersyukurlah kamu kepada Allah) atas hikmah yang telah dilimpahkan-Nya kepadamu. (Dan barang siapa yang bersyukur kepada Allah, maka sesungguhnya ia bersyukur untuk dirinya sendiri) karena pahala bersyukurnya itu kembali kepada dirinya sendiri (dan barang siapa yang tidak bersyukur) atas nikmat yang telah dilimpahkan-Nya kepadanya (maka sesungguhnya Allah Maha Kaya) tidak membutuhkan makhluk-Nya (lagi Maha Terpuji) Maha Terpuji di dalam ciptaan-Nya.\qt@no{12}}%
\qt@newcmd\qurantrans@id@mmmcdlxxxii{%
(Dan) ingatlah (ketika Luqman berkata kepada anaknya, di waktu ia menasihatinya, ``Hai anakku) lafal bunayya adalah bentuk tashghir yang dimaksud adalah memanggil anak dengan nama kesayangannya (janganlah kamu mempersekutukan Allah, sesungguhnya mempersekutukan) Allah itu (adalah benar-benar kelaliman yang besar.") Maka anaknya itu bertobat kepada Allah dan masuk Islam.\qt@no{13}}%
\qt@newcmd\qurantrans@id@mmmcdlxxxiii{%
(Dan Kami wasiatkan kepada manusia terhadap kedua orang ibu bapaknya) maksudnya Kami perintahkan manusia untuk berbakti kepada kedua orang ibu bapaknya (ibunya telah mengandungnya) dengan susah payah (dalam keadaan lemah yang bertambah-tambah) ia lemah karena mengandung, lemah sewaktu mengeluarkan bayinya, dan lemah sewaktu mengurus anaknya di kala bayi (dan menyapihnya) tidak menyusuinya lagi (dalam dua tahun. Hendaknya) Kami katakan kepadanya (bersyukurlah kepada-Ku dan kepada kedua orang ibu bapakmu, hanya kepada Akulah kembalimu) yakni kamu akan kembali.\qt@no{14}}%
\qt@newcmd\qurantrans@id@mmmcdlxxxiv{%
(Dan jika keduanya memaksamu untuk mempersekutukan dengan Aku sesuatu yang tidak ada pengetahuanmu tentang itu) yakni pengetahuan yang sesuai dengan kenyataannya (maka janganlah kamu mengikuti keduanya, dan pergaulilah keduanya di dunia dengan cara yang makruf) yaitu dengan berbakti kepada keduanya dan menghubungkan silaturahmi dengan keduanya (dan ikutilah jalan) tuntunan (orang yang kembali) orang yang bertobat (kepada-Ku) dengan melakukan ketaatan (kemudian hanya kepada Akulah kembali kalian, maka Kuberitakan kepada kalian apa yang telah kalian kerjakan) Aku akan membalasnya kepada kalian. Jumlah kalimat mulai dari ayat 14 sampai dengan akhir ayat 15 yaitu mulai dari lafal wa washshainal insaana dan seterusnya merupakan jumlah i'tiradh, atau kalimat sisipan.\qt@no{15}}%
\qt@newcmd\qurantrans@id@mmmcdlxxxv{%
("Hai anakku, sesungguhnya) perbuatan yang buruk-buruk itu (jika ada sekalipun hanya sebesar biji sawi, dan berada dalam batu atau di langit atau di bumi) atau di suatu tempat yang paling tersembunyi pada tempat-tempat tersebut (niscaya Allah akan mendatangkannya) maksudnya Dia kelak akan menghisabnya. (Sesungguhnya Allah Maha Halus) untuk mengeluarkannya (lagi Maha Waspada) tentang tempatnya.\qt@no{16}}%
\qt@newcmd\qurantrans@id@mmmcdlxxxvi{%
(Hai anakku, dirikanlah salat dan suruhlah manusia mengerjakan yang baik dan cegahlah mereka dari perbuatan mungkar serta bersabarlah terhadap apa yang menimpa kamu) disebabkan amar makruf dan nahi mungkarmu itu. (Sesungguhnya yang demikian itu) hal yang telah disebutkan itu (termasuk hal-hal yang ditekankan untuk diamalkan) karena mengingat hal-hal tersebut merupakan hal-hal yang wajib.\qt@no{17}}%
\qt@newcmd\qurantrans@id@mmmcdlxxxvii{%
(Dan janganlah kamu memalingkan) menurut qiraat yang lain dibaca wa laa tushaa`ir (mukamu dari manusia) janganlah kamu memalingkannya dari mereka dengan rasa takabur (dan janganlah kamu berjalan di muka bumi dengan angkuh) dengan rasa sombong. (Sesungguhnya Allah tidak menyukai orang-orang yang sombong) yakni orang-orang yang sombong di dalam berjalan (lagi membanggakan diri) atas manusia.\qt@no{18}}%
\qt@newcmd\qurantrans@id@mmmcdlxxxviii{%
(Dan sederhanalah kamu dalam berjalan) ambillah sikap pertengahan dalam berjalan, yaitu antara pelan-pelan dan berjalan cepat, kamu harus tenang dan anggun (dan lunakkanlah) rendahkanlah (suaramu. Sesungguhnya seburuk-buruk suara) suara yang paling jelek itu (ialah suara keledai.") Yakni pada permulaannya adalah ringkikan kemudian disusul oleh lengkingan-lengkingan yang sangat tidak enak didengar.\qt@no{19}}%
\qt@newcmd\qurantrans@id@mmmcdlxxxix{%
(Tidaklah kalian perhatikan) hai orang-orang yang diajak bicara, tidakkah kalian ketahui (bahwa Allah telah menundukkan untuk kepentingan kalian apa yang di langit) yaitu matahari, bulan dan bintang-bintang supaya kalian mengambil manfaat daripadanya (dan apa yang di bumi) berupa buah-buahan, sungai-sungai dan binatang-binatang (dan menyempurnakan) artinya meluaskan dan menyempurnakan (untuk kalian nikmat-Nya lahir) yaitu diberi bentuk yang baik, anggota yang paling sempurna dan lain sebagainya (dan batin) berupa pengetahuan dan lain sebagainya. (Dan di antara manusia) yakni penduduk Mekah (ada yang membantah tentang keesaan Allah tanpa ilmu pengetahuan atau petunjuk) dari Rasul (dan tanpa Kitab yang memberi penerangan) yang telah diturunkan oleh Allah, melainkan dia melakukan hal itu hanya secara taklid atau mengikut saja.\qt@no{20}}%
\qt@newcmd\qurantrans@id@mmmcdxc{%
(Dan apabila dikatakan kepada mereka, ``Ikutilah apa yang diturunkan Allah." Mereka menjawab, ``Tidak, tapi kami hanya mengikuti apa yang kami dapati bapak-bapak kami mengerjakannya.") Maka Allah berfirman, `` (Apakah) mereka mengikuti bapak-bapak mereka (walaupun setan itu menyeru mereka ke dalam siksa api yang menyala nyala?") yakni kepada hal-hal yang menjerumuskan mereka ke dalamnya, tentu saja tidak bukan?\qt@no{21}}%
\qt@newcmd\qurantrans@id@mmmcdxci{%
(Dan barang siapa yang menyerahkan dirinya kepada Allah) yakni mau menaati-Nya (sedangkan dia orang yang berbuat kebaikan) mengesakan-Nya (maka sesungguhnya ia telah berpegang kepada buhul tali yang kokoh) yakni bagian dari tali yang paling kuat sehingga tidak dikhawatirkan akan putus. (Dan hanya kepada Allah lah kesudahan segala urusan) maksudnya segala urusan itu akan kembali kepada-Nya.\qt@no{22}}%
\qt@newcmd\qurantrans@id@mmmcdxcii{%
(Dan barang siapa yang kafir maka janganlah membuatmu sedih) hai Muhammad (kekafirannya itu) janganlah kamu menghiraukannya. (Hanya kepada Kami lah mereka kembali, lalu Kami beritakan kepada mereka apa yang telah mereka kerjakan. Sesungguhnya Allah Maha Mengetahui segala isi hati) yakni apa yang terkandung di dalamnya, maka Dia akan membalasnya kelak.\qt@no{23}}%
\qt@newcmd\qurantrans@id@mmmcdxciii{%
(Kami berikan mereka bersenang-senang) di dunia (sebentar) hanya selama mereka hidup di dalamnya (kemudian Kami paksa mereka) di akhirat (masuk ke dalam siksa yang keras) yaitu siksaan neraka yang mereka tidak menemui jalan keselamatan darinya.\qt@no{24}}%
\qt@newcmd\qurantrans@id@mmmcdxciv{%
(Dan sesungguhnya jika) huruf lam menunjukkan makna qasam (kamu tanyakan kepada mereka, ``Siapakah yang menciptakan langit dan bumi?" Tentu mereka akan menjawab, ``Allah.") Dari lafal layaqulunanna terbuang daripadanya nun alamat rafa' karena berturut-turutnya nun, dan terbuang pula daripadanya wawu dhamir jamak bukan karena 'illat bertemunya dua huruf yang disukunkan. (Katakanlah, ``Segala puji bagi Allah") atas menangnya hujah tauhid atas mereka. (Tetapi kebanyakan mereka tidak mengetahui) apa yang seharusnya mereka lakukan, yaitu mentauhidkan-Nya.\qt@no{25}}%
\qt@newcmd\qurantrans@id@mmmcdxcv{%
(Kepunyaan Allah lah apa yang di langit dan yang di bumi) sebagai milik, makhluk dan hamba-hamba-Nya, maka tidak ada yang patut disembah di langit dan di bumi selain-Nya. (Sesungguhnya Allah Dialah Yang Maha Kaya) tidak membutuhkan makhluk-Nya (lagi Maha Terpuji) yakni terpuji di dalam ciptaan-Nya.\qt@no{26}}%
\qt@newcmd\qurantrans@id@mmmcdxcvi{%
(Dan seandainya pohon-pohon di bumi menjadi pena dan laut) lafal al-bahru diathafkan kepada isimnya anna (ditambahkan kepadanya tujuh laut sesudahnya) sebagai tambahannya sesudah keringnya laut (niscaya tidak akan habis-habisnya kalimat Allah) yang mengungkapkan tentang pengetahuan-pengetahuan-Nya dengan menuliskannya dengan memakai pena-pena itu dan berikut tambahan tujuh laut sebagai tintanya, serta tidak pula dengan tambahan yang lebih banyak dari itu, karena pengetahuan Allah tiada batasnya. (Sesungguhnya Allah Maha Perkasa) tidak ada sesuatu pun yang dapat menghalang-halangi-Nya (lagi Maha Bijaksana) tidak ada sesuatu pun yang terlepas dari pengetahuan dan kebijaksanaan-Nya.\qt@no{27}}%
\qt@newcmd\qurantrans@id@mmmcdxcvii{%
(Tidaklah Allah menciptakan dan membangkitkan kalian dari dalam kubur itu melainkan hanya seperti menciptakan dan membangkitkan satu jiwa saja) artinya sebagaimana menciptakan dan membangkitkan satu jiwa, karena kesemuanya itu akan ada hanya dengan kalimat kun fayakuun. (Sesungguhnya Allah Maha Mendengar) mendengar semua apa yang dapat didengar (lagi Maha Melihat) mengetahui semua apa yang dapat dilihat, dan tiada sesuatu pun yang menyibukkan-Nya dari yang lain.\qt@no{28}}%
\qt@newcmd\qurantrans@id@mmmcdxcviii{%
(Tidakkah kamu memperhatikan) artinya melihat, hai orang yang diajak bicara (bahwa sesungguhnya Allah memasukkan) mempergantikan (malam ke dalam siang dan memasukkan siang) mempergantikannya (ke dalam malam) maka Dia menambahkan pada masing-masing apa yang dikurangi dari yang lainnya (dan Dia tundukkan matahari dan bulan masing-masing) dari matahari dan bulan itu (berjalan) beredar pada garis edarnya (sampai kepada waktu yang ditentukan) yaitu hari kiamat (dan sesungguhnya Allah Maha Mengetahui apa yang kalian kerjakan).\qt@no{29}}%
\qt@newcmd\qurantrans@id@mmmcdxcix{%
(Demikianlah) hal yang telah disebutkan itu (karena sesungguhnya Allah Dialah yang hak) yang tetap. (Dan sesungguhnya apa saja yang mereka seru) yang mereka sembah; lafal ayat ini dapat dibaca ya'buduuna dan ta'buduuna (selain dari Allah, itulah yang batil) yang lenyap (dan sesungguhnya Allah Dialah Yang Maha Tinggi) atas semua makhluk-Nya dengan keperkasaan-Nya yang mengalahkan mereka semua (lagi Maha Besar) yakni Maha Agung.\qt@no{30}}%
\qt@newcmd\qurantrans@id@mmmd{%
(Tidakkah kamu memperhatikan bahwa sesungguhnya bahtera itu) kapal itu (berlayar di laut dengan nikmat Allah, supaya diperlihatkan-Nya kepada Kamu sekalian) hai orang-orang yang diajak bicara dalam hal ini (sebagian dari tanda-tanda kekuasaan-Nya. Sesungguhnya pada yang demikian itu benar-benar terdapat tanda-tanda) yaitu pelajaran-pelajaran (bagi semua orang yang sangat bersabar) di dalam menahan diri dari perbuatan-perbuatan maksiat yang dilarang oleh Allah (lagi banyak bersyukur) atas nikmat-nikmat-Nya.\qt@no{31}}%
\qt@newcmd\qurantrans@id@mmmdi{%
(Dan apabila mereka tertutup) yakni orang-orang kafir itu oleh (ombak yang besar seperti gunung) bagaikan bukit besarnya, hingga menutupi apa yang ada di bawahnya (mereka menyeru Allah dengan memurnikan ketaatan kepada-Nya) mereka berdoa hanya kepada-Nya, semoga Dia menyelamatkan mereka dari amukan gelombang itu. (Maka tatkala Allah menyelamatkan mereka sampai di daratan, lalu sebagian mereka tetap menempuh jalan pertengahan) yakni pertengahan antara ingkar dan iman, dan sebagian di antara mereka ada yang masih tetap pada kekafirannya. (Dan tidak ada yang mengingkari ayat-ayat Kami) yang antara lain ialah diselamatkannya mereka dari amukan gelombang (selain orang-orang yang tidak setia) yaitu pengkhianat (lagi ingkar) kepada nikmat-nikmat Allah swt.\qt@no{32}}%
\qt@newcmd\qurantrans@id@mmmdii{%
(Hai manusia) penduduk Mekah (bertakwalah kalian kepada Rabb kalian dan takutilah suatu hari yang pada hari itu tidak dapat mencukupi) tidak dapat menolong (seorang bapak terhadap anaknya) barang sedikit pun (dan seorang anak tidak dapat pula menolong bapaknya) pada hari itu (barang sedikit pun. Sesungguhnya janji Allah adalah benar) adanya hari berbangkit itu (maka janganlah sekali-kali kehidupan dunia memperdayakan kalian) hingga kalian meninggalkan Islam (dan jangan pula kalian diperdayakan terhadap Allah) yakni terhadap penyantunan-Nya dan penangguhan azab-Nya (oleh godaan yang membujuk) kalian, yaitu godaan setan.\qt@no{33}}%
\qt@newcmd\qurantrans@id@mmmdiii{%
(Sesungguhnya Allah, hanya pada sisi-Nya sajalah pengetahuan tentang hari kiamat) yakni kapan kiamat itu akan terjadi (dan Dialah yang menurunkan) dapat dibaca wa yunzilu dan wa yunazzilu (hujan) dalam waktu-waktu yang Dia ketahui (dan mengetahui apa yang ada di dalam rahim) apakah laki-laki atau perempuan; tidak ada seorang pun yang mengetahui salah satu dari tiga perkara itu melainkan hanya Allah swt. (Dan tiada seorang pun yang dapat mengetahui dengan pasti apa yang akan diusahakannya besok) apakah kebaikan ataukah keburukan, tetapi Allah swt. mengetahuinya. (Dan tiada seorang pun yang dapat mengetahui di bumi mana dia akan mati) hanya Allah swt. sajalah yang mengetahui hal ini. (Sesungguhnya Allah Maha Mengetahui) segala sesuatu (lagi Maha Mengenal) pada yang tersembunyi sebagaimana mengenal-Nya pada yang tampak. Imam Bukhari telah meriwayatkan sebuah hadis melalui sahabat Ibnu Umar r.a. bahwasanya kunci-kunci kegaiban itu ada lima perkara, antara lain sesungguhnya Allah hanya pada sisi-Nya sajalah pengetahuan tentang hari kiamat, dan seterusnya.\qt@no{34}}%
\qt@newcmd\qurantrans@id@mmmdiv{%
\basmalahid (Alif lam mim) hanya Allah sajalah yang mengetahui arti dan maksud ayat ini.\qt@no{1}}%
\qt@newcmd\qurantrans@id@mmmdv{%
(Turunnya Alkitab) yakni Alquran; Alkitab sebagai mubtada (yang tidak ada keraguan) tidak ada hal yang diragukan (padanya) fiihi sebagai khabar pertama (adalah dari Rabb semesta alam) rabbil'aalamiin sebagai khabar kedua.\qt@no{2}}%
\qt@newcmd\qurantrans@id@mmmdvi{%
(Tetapi mengapa) (mereka mengatakan, ``Dia mengada-adakannya") yakni Muhammad? Tidak (sebenarnya Alquran itu adalah kebenaran yang datang dari Rabbmu, agar kamu memberi peringatan) dengan Alquran itu (kepada kaum yang belum) huruf maa bermakna nafi atau negatif (datang kepada mereka orang yang memberi peringatan sebelum kamu; mudah-mudahan mereka mendapat petunjuk) dengan peringatanmu itu.\qt@no{3}}%
\qt@newcmd\qurantrans@id@mmmdvii{%
(Allahlah yang menciptakan langit dan bumi dan apa yang ada di antara keduanya dalam enam hari) dimulai dari hari Ahad dan selesai pada hari Jumat (kemudian Dia berkuasa di atas Arasy) kata Arasy menurut terminologi bahasa artinya singgasana seorang raja, maksudnya kekuasaan yang layak bagi kebesaran dan keagungan-Nya. (Tidak ada bagi kalian) hai orang-orang kafir Mekah (selain daripada-Nya) yakni selain-Nya (seorang penolong pun) lafal min waliyyin adalah isim daripada maa zaidah hanya ditambahi dengan huruf min pada permulaannya. Makna yang dimaksud ialah tiada seorang penolong pun (dan tidak pula seorang pemberi manfaat) yang dapat menolak azab Allah dari diri kalian. (Maka apakah kalian tidak memperhatikan) hal ini, yang oleh karenanya kalian mau beriman?\qt@no{4}}%
\qt@newcmd\qurantrans@id@mmmdviii{%
(Dia mengatur urusan dari langit ke bumi) selama dunia masih ada (kemudian naiklah) urusan dan pengaturan itu (kepada-Nya dalam suatu hari yang lamanya adalah seribu tahun menurut perhitungan kalian) di dunia. Dan di dalam surah Al-Ma'arij ayat 4 disebutkan bahwa kadar masa itu adalah lima puluh ribu tahun. Makna yang dimaksud ialah bahwa saat hari kiamat bagi orang-orang kafir terasa begitu lama sekali karena sangat ngerinya. Berbeda halnya dengan orang yang beriman, ia merasa seolah-olah hanya sebentar saja bahkan waktunya terasa lebih pendek daripada satu salat fardu yang dilakukannya di dunia. Demikianlah menurut keterangan yang dijelaskan di dalam hadis.\qt@no{5}}%
\qt@newcmd\qurantrans@id@mmmdix{%
(Yang demikian itu) yakni Yang Maha Pencipta dan Yang Maha Mengatur itu (ialah Tuhan Yang Mengetahui yang gaib dan yang nyata) yaitu apa yang gaib di mata makhluk-Nya dan apa yang nyata bagi makhluk-Nya (Yang Maha Perkasa) Maha Kuat di dalam kerajaan-Nya (lagi Maha Penyayang) kepada orang-orang yang taat kepada-Nya.\qt@no{6}}%
\qt@newcmd\qurantrans@id@mmmdx{%
(Yang membuat segala sesuatu yang Dia ciptakan sebaik-baiknya) kalau dibaca khalaqahu berarti fi'il madhi yang berkedudukan sebagai sifat. Apabila dibaca khalqahu berarti sebagai badal isytimal (dan yang memulai penciptaan manusia) yakni Nabi Adam (dari tanah).\qt@no{7}}%
\qt@newcmd\qurantrans@id@mmmdxi{%
(Kemudian Dia menjadikan keturunannya) anak cucunya (dari sulalah) dari darah kental (yang berasal dari air yang lemah) yaitu air mani.\qt@no{8}}%
\qt@newcmd\qurantrans@id@mmmdxii{%
(Kemudian Dia menyempurnakannya) menyempurnakan penciptaan Adam (dan meniupkan ke dalam tubuhnya sebagian dari roh-Nya) yakni Dia menjadikannya hidup dapat merasa atau mempunyai perasaan, yang sebelumnya ia adalah benda mati (dan Dia menjadikan bagi kalian) yaitu anak cucunya (pendengaran) lafal as-sam'a bermakna jamak sekalipun bentuknya mufrad (dan penglihatan serta hati) (tetapi kalian sedikit sekali bersyukur) huruf maa adalah huruf zaidah yang berfungsi mengukuhkan makna lafal qaliilan, yakni sedikit sekali.\qt@no{9}}%
\qt@newcmd\qurantrans@id@mmmdxiii{%
(Dan mereka berkata) orang-orang yang ingkar akan adanya hari berbangkit: ("Apakah bila kami telah lenyap di dalam tanah) yakni kami telah hancur di dalamnya, misalnya kami telah menjadi debu yang bercampur dengan tanah asli (kami benar-benar akan berada dalam ciptaan yang baru?") kata tanya di sini mengandung makna ingkar; lafal ayat ini boleh dibaca tahqiq dan boleh pula dibaca tashil. Maka Allah swt. berfirman: (Bahkan mereka terhadap hari pertemuan dengan Rabbnya) yaitu hari berbangkit (adalah orang-orang yang ingkar.)\qt@no{10}}%
\qt@newcmd\qurantrans@id@mmmdxiv{%
(Katakanlah) kepada mereka: ("Malaikat maut yang diserahi tugas untuk mencabut nyawa kalian akan mematikan kalian) yakni akan mencabut nyawa kalian (kemudian hanya kepada Rabb kalianlah, kamu sekalian akan dikembalikan") dalam keadaan hidup, maka kelak Dia akan membalas amal perbuatan kalian.\qt@no{11}}%
\qt@newcmd\qurantrans@id@mmmdxv{%
(Dan jika sekiranya kamu melihat orang-orang yang berdosa itu) yakni orang-orang kafir (menundukkan kepalanya di hadapan Rabbnya) karena merasa malu kepada-Nya, seraya mengatakan: ("Ya Rabb kami! Kami telah melihat) apa yang telah kami ingkari sebelumnya, yaitu hari berbangkit (dan mendengar) dari-Mu kebenaran rasul-rasul yang telah kami dustakan mereka dahulu (maka kembalikanlah kami) ke dunia (kami akan mengerjakan amal saleh) di dunia (sesungguhnya kami adalah orang-orang yang yakin") mulai sekarang, akan tetapi hal itu sama sekali tidak bermanfaat bagi mereka, dan mereka tidak akan dikembalikan lagi ke dunia. Sebagai jawab dari lafal lau ialah niscaya kamu melihat hal yang sangat mengerikan. Kemudian Allah berfirman pada ayat selanjutnya:\qt@no{12}}%
\qt@newcmd\qurantrans@id@mmmdxvi{%
(Dan kalau Kami menghendaki niscaya Kami akan berikan kepada tiap-tiap jiwa petunjuk baginya) sehingga ia memperoleh petunjuk untuk beriman dan mengerjakan ketaatan atas kemauan sendiri (akan tetapi telah tetaplah perkataan daripada-Ku) yaitu, ("Sesungguhnya akan Aku penuhi neraka Jahanam itu dengan jin) maksudnya bangsa jin (dan manusia semuanya) malaikat penjaga neraka mengatakan kepada mereka jika mereka dimasukkan ke dalamnya.\qt@no{13}}%
\qt@newcmd\qurantrans@id@mmmdxvii{%
(Maka rasakanlah oleh kalian) azab ini (disebabkan kalian melupakan pertemuan dengan hari kalian ini) karena kalian tidak mau beriman kepadanya (sesungguhnya Kami telah melupakan kalian pula) maksudnya Kami tinggalkan kalian di dalam azab (dan rasakanlah siksa yang kekal) azab yang abadi (disebabkan apa yang selalu kalian kerjakan") akibat dari kekafiran dan kedustaan yang telah kalian kerjakan.\qt@no{14}}%
\qt@newcmd\qurantrans@id@mmmdxviii{%
(Sesungguhnya orang-orang yang beriman kepada ayat-ayat Kami) yakni Alquran (adalah orang-orang yang apabila diperingatkan) dinasihati (dengan ayat-ayat Kami mereka menyungkur sujud dan bertasbih) seraya (memuji Rabbnya) dengan mengucapkan kalimat, ``Subhaanallaah wa bihamdihi" (sedangkan mereka tidak menyombongkan diri) lantaran beriman dan berlaku taat itu.\qt@no{15}}%
\qt@newcmd\qurantrans@id@mmmdxix{%
(Lambung mereka jauh) diri mereka jauh (dari tempat tidurnya) dari tempat pembaringannya disebabkan mereka selalu melakukan salat tahajud di malam hari (sedangkan mereka berdoa kepada Rabbnya dengan rasa takut) akan azab-Nya (dan penuh harap) akan rahmat-Nya (dan mereka menafkahkan sebagian dari rezeki yang Kami berikan kepada mereka) yaitu menyedekahkannya.\qt@no{16}}%
\qt@newcmd\qurantrans@id@mmmdxx{%
(Seorang pun tidak mengetahui apa yang disembunyikan) apa yang tersembunyi (bagi mereka yaitu berupa bermacam-macam nikmat yang menyedapkan pandangan mata) yakni nikmat-nikmat surga yang menyenangkan hati mereka. Menurut suatu qiraat lafal ukhfiya dibaca ukhfii, artinya apa yang Aku sembunyikan (sebagai balasan terhadap apa yang telah mereka kerjakan).\qt@no{17}}%
\qt@newcmd\qurantrans@id@mmmdxxi{%
(Maka apakah orang-orang yang beriman sama seperti orang yang fasik? Mereka tidak sama) maksudnya orang-orang mukmin dan orang-orang fasik atau kafir itu tidak sama.\qt@no{18}}%
\qt@newcmd\qurantrans@id@mmmdxxii{%
(Adapun orang-orang yang beriman dan mengerjakan amal-amal saleh, maka bagi mereka surga tempat kediaman) arti kata nuzulan asalnya adalah tempat yang disediakan untuk para tamu (sebagai pahala terhadap apa yang telah mereka kerjakan.)\qt@no{19}}%
\qt@newcmd\qurantrans@id@mmmdxxiii{%
(Adapun orang-orang yang fasik) disebabkan kekafiran mereka dan kedustaan yang mereka lakukan (maka tempat mereka adalah neraka. Setiap kali mereka hendak keluar daripadanya, mereka dikembalikan lagi ke dalamnya dan dikatakan kepada mereka, ``Rasakanlah siksa neraka yang dahulu kalian mendustakannya.")\qt@no{20}}%
\qt@newcmd\qurantrans@id@mmmdxxiv{%
(Dan sesungguhnya Kami merasakan kepada mereka sebagian azab yang dekat) yakni azab di dunia, seperti dibunuh, ditawan, ditimpa kekeringan dan paceklik serta dilanda wabah penyakit (selain) yakni sebelum (azab yang lebih besar) yaitu azab di akhirat (mudah-mudahan mereka) yaitu sebagian dari mereka yang masih ada (kembali) ke jalan yang benar, yaitu beriman.\qt@no{21}}%
\qt@newcmd\qurantrans@id@mmmdxxv{%
(Dan siapakah yang lebih lalim daripada orang yang telah diperingatkan dengan ayat-ayat Rabbnya) yakni Alquran (kemudian ia berpaling daripadanya?) Yaitu tidak ada seorang pun yang lebih aniaya daripadanya. (Sesungguhnya Kami terhadap orang-orang yang berdosa) orang-orang musyrik (akan mengadakan pembalasan.)\qt@no{22}}%
\qt@newcmd\qurantrans@id@mmmdxxvi{%
(Dan sesungguhnya telah Kami berikan kepada Musa Alkitab) yaitu kitab Taurat (maka janganlah kamu ragu-ragu) meragukan (untuk bertemu dengan Musa) dan keduanya telah berjumpa pada malam Rasulullah saw. diisrakan (dan Kami jadikan ia) Musa atau kitab Taurat (sebagai petunjuk) yaitu pemberi petunjuk (buat Bani Israel.)\qt@no{23}}%
\qt@newcmd\qurantrans@id@mmmdxxvii{%
(Dan Kami jadikan di antara mereka itu pemimpin-pemimpin) lafal ayat ini boleh dibaca tahqiq dan tashil (yang memberi petunjuk) kepada manusia (dengan perintah Kami ketika mereka sabar) di dalam memegang agama mereka dan sewaktu mereka menghadapi berbagai cobaan dari musuh-musuh mereka. Menurut qiraat yang lain dibaca limaa shabaruu. (Dan adalah mereka terhadap ayat-ayat Kami) yang menunjukkan kekuasaan dan keesaan Kami (orang-orang yang meyakini.)\qt@no{24}}%
\qt@newcmd\qurantrans@id@mmmdxxviii{%
(Sesungguhnya Rabbmu Dialah yang memberikan keputusan di antara mereka pada hari kiamat tentang apa yang selalu mereka perselisihkan padanya) yakni perkara agama.\qt@no{25}}%
\qt@newcmd\qurantrans@id@mmmdxxix{%
(Dan apakah tidak menjadi petunjuk bagi mereka, berapa banyak umat-umat sebelum mereka yang telah Kami binasakan) maksudnya apakah tidak jelas bagi orang-orang kafir Mekah, bahwasanya Kami telah banyak membinasakan umat-umat sebelum mereka disebabkan kekafirannya (sedangkan mereka sendiri berjalan) lafal ayat ini berkedudukan sebagai hal atau kata keterangan keadaan bagi dhamir lahum (di tempat-tempat kediaman mereka itu) sewaktu mereka mengadakan perjalanan ke negeri Syam dan negeri-negeri lainnya, yakni apakah mereka tidak mengambil pelajaran daripadanya. (Sesungguhnya yang demikian itu terdapat tanda-tanda) yang menunjukkan akan kekuasaan Kami. (Maka apakah mereka tidak mendengarkan) dengan pendengaran yang penuh perhatian dan mau menerima apa yang didengarnya?\qt@no{26}}%
\qt@newcmd\qurantrans@id@mmmdxxx{%
(Dan apakah mereka tidak memperhatikan, bahwasanya Kami menghalau awan yang mengandung air ke bumi yang tandus) yakni bumi yang tidak ada tumbuh-tumbuhan padanya (lalu Kami tumbuhkan dengan air hujan itu tanam-tanaman yang daripadanya dapat makan binatang-binatang ternak mereka dan mereka sendiri. Maka apakah mereka tidak memperhatikan?) hal tersebut sehingga menuntun mereka untuk mengetahui, bahwa Kami mampu untuk mengembalikan mereka hidup kembali sesudah mereka mati nanti.\qt@no{27}}%
\qt@newcmd\qurantrans@id@mmmdxxxi{%
(Dan mereka bertanya) kepada orang-orang yang beriman ("Bilakah kemenangan itu) datang bagi kalian atas kami (jika kalian memang orang-orang yang benar?")\qt@no{28}}%
\qt@newcmd\qurantrans@id@mmmdxxxii{%
(Katakanlah, ``Pada hari kemenangan itu) yaitu pada hari turunnya azab atas mereka (tidak berguna bagi orang-orang kafir iman mereka dan tidak pula mereka diberi tangguh") ditangguhkan supaya mereka dapat bertobat atau meminta maaf.\qt@no{29}}%
\qt@newcmd\qurantrans@id@mmmdxxxiii{%
(Maka berpalinglah kamu dari mereka dan tunggulah) saat turunnya azab atas mereka (sesungguhnya mereka juga menunggu)mu, kapan kamu mati atau terbunuh, sehingga mereka bebas darimu. Ayat ini diturunkan sebelum ada perintah Allah swt. untuk memerangi mereka.\qt@no{30}}%
\qt@newcmd\qurantrans@id@mmmdxxxiv{%
\basmalahid (Hai Nabi! Bertakwalah kepada Allah) teguhkanlah dirimu dalam bertakwa kepada Allah (dan janganlah kamu menuruti keinginan orang-orang kafir dan orang-orang munafik) dalam hal-hal yang bertentangan dengan syariatmu. (Sesungguhnya Allah Maha Mengetahui) apa yang akan terjadi sebelumnya (lagi Maha Bijaksana) di dalam mengatur urusan makhluk-Nya.\qt@no{1}}%
\qt@newcmd\qurantrans@id@mmmdxxxv{%
(Dan ikutilah apa yang diwahyukan Rabbmu kepadamu) yaitu Alquran. (Sesungguhnya Allah adalah Maha Mengetahui apa yang kalian kerjakan) menurut suatu qiraat lafal ta'maluuna dibaca ya'maluuna.\qt@no{2}}%
\qt@newcmd\qurantrans@id@mmmdxxxvi{%
(Dan bertawakallah kepada Allah) di dalam urusanmu. (Dan cukuplah Allah sebagai pemelihara) dirimu; sehubungan dengan hal ini, umat Nabi saw. mengikut kepadanya.\qt@no{3}}%
\qt@newcmd\qurantrans@id@mmmdxxxvii{%
(Allah sekali-kali tidak menjadikan bagi seseorang dua buah hati dalam rongganya) firman ini sebagai sanggahan terhadap sebagian orang-orang kafir yang mengatakan, bahwa dia memiliki dua hati; yang masing-masingnya mempunyai kesadaran yang lebih utama daripada kesadaran yang dimiliki oleh Muhammad (dan Dia tidak menjadikan istri-istri kalian yang) lafal allaa-iy dapat pula dibaca allaa-i (kalian zihari) dapat dibaca tuzhhiruuna dan tuzhaahiruuna (mereka itu) misalnya seseorang berkata kepada istrinya, ``Menurutku kamu bagaikan punggung ibuku," (sebagai ibu kalian) yakni mereka diharamkan oleh kalian seperti terhadap ibu kalian sendiri, hal ini di zaman jahiliah dianggap sebagai talak. Zihar hanya mewajibkan membayar kifarat dengan persyaratannya yang akan disebutkan di dalam surah Al-Mujadilah (dan Dia tidak menjadikan anak-anak angkat kalian) lafal ad'iyaa adalah bentuk jamak dari lafal da'iyyun, artinya adalah anak angkat (sebagai anak kandung kalian sendiri) yakni anak yang sesungguhnya bagi kalian. (Yang demikian itu hanyalah perkataan kalian di mulut kalian saja.) Sewaktu Nabi saw. menikahi Zainab binti Jahsy yang dahulunya adalah bekas istri Zaid bin Haritsah, anak angkat Nabi saw., orang-orang Yahudi dan munafik mengatakan, ``Muhammad telah mengawini bekas istri anaknya sendiri." Maka Allah swt. mendustakan mereka. (Dan Allah mengatakan yang sebenarnya) (dan Dia menunjukkan jalan) yang benar.\qt@no{4}}%
\qt@newcmd\qurantrans@id@mmmdxxxviii{%
Tetapi (panggillah mereka dengan memakai nama bapak-bapak mereka, itulah yang lebih pertengahan) lebih adil (pada sisi Allah, dan jika kalian tidak mengetahui bapak-bapak mereka, maka saudara-saudara kalian seagama dan maula-maula kalian) yaitu anak-anak paman kalian. (Dan tidak ada dosa atas kalian terhadap apa yang kalian khilaf padanya) dalam hal tersebut (tetapi) yang berdosa itu ialah (apa yang disengaja oleh hati kalian) sesudah adanya larangan. (Dan adalah Allah Maha Pengampun) atas apa yang terlanjur kalian katakan sebelum adanya larangan (lagi Maha Penyayang) kepada kalian.\qt@no{5}}%
\qt@newcmd\qurantrans@id@mmmdxxxix{%
(Nabi itu lebih utama bagi orang-orang mukminin dari diri mereka sendiri) maksudnya apa yang diserukan oleh Nabi saw. agar mereka melakukannya, dan apa yang diserukan oleh hawa nafsu mereka agar mereka melanggarnya, maka seruan Nabilah yang harus lebih diutamakan daripada kehendak diri mereka sendiri (dan istri-istrinya adalah ibu-ibu mereka) haram untuk dinikahi oleh mereka. (Dan orang-orang yang mempunyai hubungan darah) yakni kaum kerabat (satu sama lain lebih berhak) waris-mewarisi (di dalam Kitab Allah daripada orang-orang mukmin dan orang-orang Muhajirin) daripada waris-mewarisi berdasarkan saudara seiman dan berhijrah yang berlangsung pada permulaan Islam, kemudian dimansukh oleh ayat ini (kecuali) tetapi (kalau kalian mau berbuat baik kepada saudara-saudara kalian seagama) melalui wasiat, masih tetap diperbolehkan. (Adalah yang demikian itu) yaitu dihapusnya hukum waris-mewarisi karena seiman dan hijrah dengan hubungan kekerabatan (telah tertulis di dalam Alkitab) Alkitab yang dimaksud di dalam dua tempat pada ayat ini adalah Lohmahfuz.\qt@no{6}}%
\qt@newcmd\qurantrans@id@mmmdxl{%
(Dan) ingatlah (ketika Kami mengambil dari nabi-nabi perjanjian mereka) ketika mereka dikeluarkan dari tulang sulbi Adam sebagaimana benda yang paling kecil layaknya. Lafal adz-dzurri bentuk jamak dari lafal dzurrah artinya semut yang paling kecil (dan dari kamu sendiri, dari Nuh, Ibrahim, Musa dan Isa putra Maryam) hendaknya mereka menyembah Allah dan menyeru supaya beribadah kepada-Nya. Disebutkannya kelima nabi ini termasuk mengathafkan sesuatu kepada bagiannya (dan Kami telah mengambil dari mereka perjanjian yang teguh) janji yang sangat berat untuk melaksanakan apa-apa yang harus mereka pikul, yakni bersumpah atas nama Allah, kemudian perjanjian itu diambil oleh-Nya.\qt@no{7}}%
\qt@newcmd\qurantrans@id@mmmdxli{%
(Agar Dia menanyakan) yakni Allah (kepada orang-orang yang benar tentang kebenaran mereka) di dalam menyampaikan risalahnya; hal ini dimaksudkan sebagai celaan terhadap orang-orang yang kafir kepada para nabi (dan Dia menyediakan) yakni Allah swt. (bagi orang-orang kafir) terhadap para nabi (siksa yang pedih) yang menyakitkan. Lafal wa a'adda diathafkan pada lafal akhadznaa.\qt@no{8}}%
\qt@newcmd\qurantrans@id@mmmdxlii{%
(Hai orang-orang yang beriman, ingatlah akan nikmat Allah yang telah dikaruniakan kepada kalian ketika datang kepada kalian tentara-tentara) orang-orang kafir yang bersekutu sewaktu perang Khandaq (lalu Kami kirimkan kepada mereka angin topan dan tentara yang kalian tidak dapat melihatnya) yakni bala tentara malaikat. (Dan adalah Allah terhadap apa yang kalian kerjakan) kalau dibaca ta'maluuna yang dimaksud adalah bekerja menggali parit, dan kalau dibaca ya'maluuna yang dimaksud adalah mereka yang bersekutu yaitu kaum musyrikin (Maha Melihat.)\qt@no{9}}%
\qt@newcmd\qurantrans@id@mmmdxliii{%
(Yaitu ketika mereka datang kepada kalian dari atas dan dari bawah kalian) dari lembah bagian atas dan bawah, datang dari arah timur dan barat (dan ketika tidak tetap lagi penglihatan) perhatiannya hanya tertuju kepada musuh saja yang datang dari berbagai penjuru (dan hati kalian naik menyesak sampai tenggorokan) lafal hanaajir bentuk jamak dari lafal hanjarah, artinya adalah tenggorokan, diungkapkan demikian karena takut yang amat sangat (dan kalian menyangka terhadap Allah dengan bermacam-macam sangkaan) dengan berbagai macam prasangka, apakah mendapat pertolongan ataukah tidak, sehingga putus harapan dari pertolongan-Nya.\qt@no{10}}%
\qt@newcmd\qurantrans@id@mmmdxliv{%
(Di situlah diuji orang-orang Mukmin) mereka mendapat cobaan supaya menjadi jelas, siapakah orang Mukmin yang benar-benar dan siapakah yang gadungan (dan hati mereka diguncang) berdegup-degup (dengan guncangan yang sangat) disebabkan ketakutan yang sangat mencekam mereka.\qt@no{11}}%
\qt@newcmd\qurantrans@id@mmmdxlv{%
(Dan) ingatlah (ketika orang-orang munafik dan orang-orang yang berpenyakit dalam hatinya berkata) yakni penyakit lemah keyakinannya: ("Allah dan rasul-Nya tidak menjanjikan kepada kami) akan mendapat pertolongan Allah (melainkan tipu daya.") kedustaan belaka.\qt@no{12}}%
\qt@newcmd\qurantrans@id@mmmdxlvi{%
(Dan ketika berkata segolongan di antara mereka) yakni orang-orang munafik ("Hai penduduk Yatsrib!) Yatsrib adalah nama kedua kota Madinah; tidak menerima tanwin karena 'illat 'alamiyah dan wazan fi'il (Tidak ada tempat bagi kalian) dapat dibaca muqaama dan maqaama, artinya tidak ada tempat tinggal bagi kalian (maka kembalilah kalian") ke tempat-tempat tinggal kalian di Madinah, yang pada waktu itu kaum Muslimin telah berangkat keluar bersama dengan Nabi saw. ke salah satu lereng bukit di luar kota Madinah untuk menyambut kedatangan musuh. (Dan sebagian dari mereka minta izin kepada nabi) untuk kembali pulang (seraya berkata, ``Sesungguhnya rumah-rumah kami terbuka.") Tidak ada penjaganya sehingga keadaannya sangat mengkhawatirkan. Maka Allah swt. berfirman: (Dan rumah-rumah itu sekali-kali tidak terbuka, tidak lain) (mereka hanya hendak lari) dari medan perang.\qt@no{13}}%
\qt@newcmd\qurantrans@id@mmmdxlvii{%
(Kalau diserang) kota Madinah (dari segala penjuru) dari segala arahnya (kemudian diminta kepada mereka) yakni mereka diminta oleh orang-orang yang menyerang mereka (supaya murtad) supaya musyrik (niscaya mereka mengerjakannya) niscaya mereka menuruti kemauannya; lafal ayat ini huruf hamzahnya dapat dibaca panjang sehingga bacaannya menjadi la-aatauhaa dan dapat dibaca pendek sehingga bacaannya menjadi la-atauhaa (dan mereka tidak akan bertangguh untuk murtad itu melainkan dalam waktu yang singkat).\qt@no{14}}%
\qt@newcmd\qurantrans@id@mmmdxlviii{%
(Dan sesungguhnya mereka sebelum itu telah berjanji kepada Allah dahulu, mereka tidak akan berbalik ke belakang/mundur. Dan adalah perjanjian dengan Allah akan diminta pertanggungjawabannya) tentang pelaksanaannya.\qt@no{15}}%
\qt@newcmd\qurantrans@id@mmmdxlix{%
(Katakanlah, ``Lari itu sekali-kali tidaklah berguna bagi kalian, jika kalian melarikan diri dari kematian atau pembunuhan, dan jika kalian) melarikan diri (kalian tidak dapat bersenang-senang) di dunia ini sesudah kalian melarikan diri (melainkan hanya sebentar.") Yakni hanyalah sebatas sisa umur kalian.\qt@no{16}}%
\qt@newcmd\qurantrans@id@mmmdl{%
(Katakanlah! ``Siapakah yang dapat melindungi kalian) yang dapat menyelamatkan kalian (dari takdir Allah jika Dia menghendaki bencana atas kalian) kebinasaan dan kekalahan (atau) siapakah yang dapat menimpakan keburukan kepada kalian jika (telah menghendaki) Allah (atas diri kalian rahmat) yakni kebaikan. (Dan orang-orang munafik itu tidak memperoleh bagi mereka selain Allah) (pelindung) yang bermanfaat bagi diri mereka (dan tidak pula penolong.") yang dapat menolak marabahaya dari diri mereka.\qt@no{17}}%
\qt@newcmd\qurantrans@id@mmmdli{%
(Sesungguhnya Allah mengetahui orang-orang yang menghalang-halangi) yang menghambat (di antara kalian dan orang-orang yang berkata kepada saudara-saudaranya, ``Marilah) kemarilah (kepada kami." Dan mereka tidak mendatangi peperangan) pertempuran (melainkan hanya sebentar) hanya ingin pamer dan cari muka.\qt@no{18}}%
\qt@newcmd\qurantrans@id@mmmdlii{%
(Mereka bakhil terhadap kalian) maksudnya sangat perhitungan dalam menolong dan membantu kalian. Lafal asyihhatan bentuk jamak dari lafal syahiihun; berkedudukan menjadi hal atau kata keterangan keadaan dari dhamir yang terkandung di dalam lafal ya'tuuna (apabila datang ketakutan, kamu lihat mereka itu memandang kepadamu dengan mata yang terbalik-balik seperti) penglihatan atau seperti terbeliaknya (orang yang pingsan karena akan mati) yaitu orang yang sedang sekarat maut (dan apabila ketakutan telah hilang) harta-harta rampasan telah diperoleh kaum Muslimin (mereka mencaci kalian) menyakiti kalian atau memukul kalian (dengan lidah yang tajam, sedangkan mereka bakhil untuk berbuat kebaikan) atas harta rampasan yang telah diperolehnya. (Mereka itu tidak beriman) sesungguhnya (maka Allah menghapus pahala amal mereka. Dan yang demikian itu) penghapusan pahala amal perbuatan itu (adalah mudah bagi Allah) dengan kehendak-Nya.\qt@no{19}}%
\qt@newcmd\qurantrans@id@mmmdliii{%
(Mereka mengira golongan-golongan yang bersekutu itu) yaitu orang-orang kafir (belum pergi) maksudnya belum kembali ke Mekah disebabkan perasaan takut mereka terhadapnya (dan jika golongan-golongan yang bersekutu itu datang kembali) mengadakan serangan ulang (niscaya mereka ingin) mengharapkan (berada di dusun-dusun bersama orang-orang Arab badui) berada di tengah-tengah mereka di perkampungan (sambil menanya-nanya tentang berita-berita kalian) yakni kabar kalian beserta orang-orang kafir yang menyerang kalian. (Dan sekiranya mereka berada bersama kalian) di dalam serangan kali ini (mereka tidak akan berperang melainkan sebentar saja) hanya karena pamer dan takut dicela sebab tidak ikut berperang.\qt@no{20}}%
\qt@newcmd\qurantrans@id@mmmdliv{%
(Sesungguhnya telah ada pada diri Rasulullah itu suri teladan bagi kalian) dapat dibaca iswatun dan uswatun (yang baik) untuk diikuti dalam hal berperang dan keteguhan serta kesabarannya, yang masing-masing diterapkan pada tempat-tempatnya (bagi orang) lafal ayat ini berkedudukan menjadi badal dari lafal lakum (yang mengharap rahmat Allah) yakni takut kepada-Nya (dan hari kiamat dan dia banyak menyebut Allah) berbeda halnya dengan orang-orang yang selain mereka.\qt@no{21}}%
\qt@newcmd\qurantrans@id@mmmdlv{%
(Dan tatkala orang-orang Mukmin melihat golongan-golongan yang bersekutu itu) yang terdiri dari orang-orang kafir (mereka berkata, ``Inilah yang dijanjikan Allah dan Rasul-Nya kepada kita.") Yakni cobaan dan pertolongan dari Allah. (Dan benarlah Allah dan Rasul-Nya) tentang yang dijanjikannya. (Dan yang demikian itu tidaklah menambah kepada mereka) (kecuali iman) percaya mereka akan janji Allah (dan ketundukan) kepada perintah-Nya.\qt@no{22}}%
\qt@newcmd\qurantrans@id@mmmdlvi{%
(Di antara orang-orang Mukmin itu ada orang-orang yang menepati apa-apa yang telah mereka janjikan kepada Allah) yaitu gigih bertahan bersama dengan Nabi saw. (maka di antara mereka ada yang gugur) mati atau terbunuh di jalan Allah (dan di antara mereka ada pula yang menunggu-nunggu) hal tersebut (dan mereka sedikit pun tidak mengubah) janjinya, berbeda halnya dengan orang-orang munafik.\qt@no{23}}%
\qt@newcmd\qurantrans@id@mmmdlvii{%
(Supaya Allah memberikan balasan kepada orang-orang yang benar itu karena kebenarannya, dan menyiksa orang-orang munafik jika dikehendaki-Nya) seumpamanya Dia mematikan mereka dalam kemunafikannya (atau menerima tobat mereka. Sesungguhnya Allah adalah Maha Pengampun) (lagi Maha Penyayang) kepada orang yang bertobat kepada-Nya.\qt@no{24}}%
\qt@newcmd\qurantrans@id@mmmdlviii{%
(Dan Allah menghalau orang-orang yang kafir itu) yakni golongan-golongan yang bersekutu itu (yang keadaan mereka penuh kejengkelan, lagi mereka tidak memperoleh keuntungan apa pun) maksudnya tidak memperoleh kemenangan atas orang-orang Mukmin. (Dan Allah menghindarkan orang-orang Mukmin dari peperangan) dengan mengirimkan angin besar dan para malaikat kepada golongan-golongan yang bersekutu. (Dan adalah Allah Maha Kuat) untuk mewujudkan apa yang dikehendaki-Nya (lagi Maha Perkasa) Maha Menang atas semua perkara-Nya.\qt@no{25}}%
\qt@newcmd\qurantrans@id@mmmdlix{%
(Dan Dia menurunkan orang-orang ahli kitab yang membantu golongan-golongan yang bersekutu) yang dimaksud adalah Bani Quraizhah (dari benteng-benteng mereka) lafal shayaashi bentuk jamak dari lafal shaishatun, artinya adalah benteng tempat berlindung (dan Dia memasukkan rasa takut ke dalam hati mereka) yaitu rasa ngeri (sebagian mereka kalian bunuh) sebagian dari mereka terbunuh oleh kalian, yaitu mereka yang berperang (dan sebagian yang lain kalian tawan) yaitu kaum wanita dan anak-anaknya.\qt@no{26}}%
\qt@newcmd\qurantrans@id@mmmdlx{%
(Dan Dia mewariskan kepada kalian tanah-tanah, rumah-rumah dan harta benda mereka dan demikian pula tanah yang belum kalian injak) sebelumnya, yaitu tanah Khaibar, yang direbut sesudah Quraizhah. (Dan adalah Allah Maha Kuasa terhadap segala sesuatu.)\qt@no{27}}%
\qt@newcmd\qurantrans@id@mmmdlxi{%
(Hai Nabi! Katakanlah kepada istri-istrimu) yang pada saat itu jumlah mereka ada sembilan orang; mereka meminta kepada Nabi saw. perhiasan duniawi yang tidak dipunyai oleh beliau: ("Jika kamu sekalian mengingini kehidupan dunia dan perhiasannya, maka marilah supaya diberikan kepada kalian mut`ah) yakni mut`ah talak (dan aku ceraikan kalian dengan cara yang baik) aku ceraikan kalian tanpa menimbulkan kemudaratan.\qt@no{28}}%
\qt@newcmd\qurantrans@id@mmmdlxii{%
(Dan jika kamu sekalian menghendaki keridaan Allah dan Rasul-Nya serta kesenangan di negeri akhirat) yakni surga (maka sesungguhnya Allah menyediakan bagi siapa yang berbuat baik di antara kalian) yang menghendaki pahala di akhirat (pahala yang besar.") yaitu surga. Maka mereka memilih pahala di akhirat daripada pahala di dunia.\qt@no{29}}%
\qt@newcmd\qurantrans@id@mmmdlxiii{%
(Hai istri-istri nabi, siapa-siapa di antara kalian yang mengerjakan perbuatan keji yang nyata) Mubayyanatin dapat dibaca Mubayyinatin, artinya yang terang atau jelas (niscaya akan dilipat gandakan) menurut suatu qiraat dibaca Yudha'-'af dan menurut qiraat lainnya dibaca Nudhaa'af kemudian lafal Al 'Adzaabu dibaca Nashab sehingga menjadi Al 'Adzaaba (siksaan kepadanya dua kali lipat) dua kali lipat siksaan yang diterima oleh orang-orang selain kalian. (Dan adalah yang demikian itu mudah bagi Allah.)\qt@no{30}}%
\qt@newcmd\qurantrans@id@mmmdlxiv{%
(Dan barang siapa yang tetap taat) tetap setia (di antara kalian kepada Allah dan Rasul-Nya dan mengerjakan amal yang saleh, niscaya Kami berikan kepadanya pahala dua kali lipat) dua kali lipat pahala yang diterima oleh wanita-wanita yang taat selain kalian. Dan menurut suatu qiraat lafal Ta'malu dan Nu'tihaa dibaca Ya'malu dan Yu'tihaa (dan Kami sediakan baginya rezeki yang mulia) di surga sebagai tambahan pahalanya.\qt@no{31}}%
\qt@newcmd\qurantrans@id@mmmdlxv{%
(Hai istri-istri Nabi! Kamu sekalian tidaklah seperti seseorang) yakni segolongan (di antara wanita yang lain, jika kalian bertakwa) kepada Allah, karena sesungguhnya kalian adalah wanita-wanita yang agung. (Maka janganlah kalian tunduk dalam berbicara) dengan kaum laki-laki (sehingga berkeinginan orang yang ada penyakit dalam hatinya) yakni perasaan nifaq (dan ucapkanlah perkataan yang baik) dengan tanpa tunduk.\qt@no{32}}%
\qt@newcmd\qurantrans@id@mmmdlxvi{%
(Dan hendaklah kalian tetap) dapat dibaca Qirna dan Qarna (di rumah kalian) lafal Qarna pada asalnya adalah Aqrarna atau Aqrirna, yang diambil dari kata Qararta atau Qarirta. Kemudian harakat Ra dipindahkan kepada Qaf, selanjutnya huruf Ra dan hamzah Washalnya dibuang sehingga jadilah, Qarna atau Qirna (dan janganlah kalian berhias) asalnya berbunyi Tatabarrajna kemudian salah satu huruf Ta dibuang sehingga jadilah Tabarrajna (sebagaimana orang-orang jahiliah yang dahulu) sebagaimana berhiasnya orang-orang sebelum Islam, yaitu kaum wanita selalu menampakkan kecantikan mereka kepada kaum lelaki. Adapun yang diperbolehkan oleh Islam adalah sebagaimana yang disebutkan di dalam firman-Nya, ``.. dan janganlah mereka menampakkan perhiasannya, kecuali yang biasa tampak daripadanya." (Q.S. An-Nur, 31). (dan dirikanlah salat, tunaikanlah zakat dan taatilah Allah dan Rasul-Nya. Sesungguhnya Allah bermaksud hendak menghilangkan dosa dari kalian) yakni dosa-dosa, hai (ahlul bait) yakni istri-istri Nabi saw. (dan membersihkan kalian) daripada dosa-dosa itu (sebersih-bersihnya.)\qt@no{33}}%
\qt@newcmd\qurantrans@id@mmmdlxvii{%
(Dan ingatlah apa yang dibacakan di rumah kalian dari ayat-ayat Allah) Alquran (dan hikmah) sunah Nabi. (Sesungguhnya Allah adalah Maha Lembut) terhadap kekasih-kekasih-Nya (lagi Maha Mengetahui) terhadap semua makhluk-Nya.\qt@no{34}}%
\qt@newcmd\qurantrans@id@mmmdlxviii{%
(Sesungguhnya laki-laki dan perempuan yang muslim, laki-laki dan perempuan yang mukmin, laki-laki dan perempuan yang tetap dalam ketaatannya) (laki-laki dan perempuan yang benar) dalam keimanannya (laki-laki dan perempuan yang sabar) di dalam menjalankan ketaatan (laki-laki yang khusyuk) yang merendahkan diri (dan perempuan yang khusyuk, laki-laki dan perempuan yang bersedekah, laki-laki dan perempuan yang berpuasa, laki-laki dan perempuan yang memelihara kehormatannya) dari hal-hal yang diharamkan (laki-laki dan perempuan yang banyak menyebut nama Allah, Allah telah menyediakan untuk mereka ampunan) dari perbuatan-perbuatan maksiat yang pernah mereka lakukan (dan pahala yang besar) bagi amal ketaatan mereka.\qt@no{35}}%
\qt@newcmd\qurantrans@id@mmmdlxix{%
(Dan tidaklah patut bagi laki-laki yang Mukmin dan tidak pula bagi perempuan yang Mukmin, apabila Allah dan Rasul-Nya telah menetapkan suatu ketetapan akan ada) Yakuuna dapat dibaca Takuuna (bagi mereka pilihan yang lain) (tentang urusan mereka) yang berbeda dengan apa yang telah ditetapkan oleh Allah dan Rasul-Nya. Ayat ini diturunkan berkenaan dengan Abdullah bin Jahsy beserta saudara perempuannya yang bernama Zainab; Nabi saw. melamarnya untuk dikawinkan kepada Zaid bin Haritsah, lalu keduanya tidak menyukai hal tersebut ketika keduanya mengetahui bahwa Nabi melamar saudara perempuannya bukanlah untuk dirinya sendiri, melainkan untuk anak angkatnya yaitu Zaid bin Haritsah. Akan tetapi setelah turun ayat ini keduanya menjadi rela. (Dan barang siapa mendurhakai Allah dan Rasul-Nya maka sungguh dia telah sesat, sesat yang nyata) nyata sesatnya. Kemudian Nabi mengawinkan Zainab binti Jahsy dengan Zaid. Akan tetapi sesudah beberapa waktu dalam diri Zaid timbul rasa tidak senang terhadap istrinya itu, lalu ia berkata kepada Nabi saw. bahwa ia bermaksud untuk menalaknya. Maka Nabi saw. menjawab, ``Peganglah istrimu itu di dalam pemeliharaanmu" sebagaimana yang disitir oleh firman selanjutnya.\qt@no{36}}%
\qt@newcmd\qurantrans@id@mmmdlxx{%
(Dan ketika) ingatlah ketika (kamu berkata kepada orang yang Allah telah melimpahkan nikmat kepadanya) yakni nikmat Islam (dan kamu juga telah memberi nikmat kepadanya,) dengan memerdekakannya, yang dimaksud adalah Zaid bin Haritsah, dahulu pada zaman jahiliah dia adalah tawanan kemudian ia dibeli oleh Rasulullah, lalu dimerdekakan dan diangkat menjadi anak angkatnya sendiri ("Tahanlah terus istrimu dan bertakwalah kepada Allah") dalam hal menalaknya (sedangkan kamu menyembunyikan di dalam hatimu apa yang Allah akan menyatakannya) akan membeberkannya, yaitu perasaan cinta kepada Zainab binti Jahsy, dan kamu berharap seandainya Zaid menalaknya, maka kamu akan menikahinya (dan kamu takut kepada manusia) bila mereka mengatakan bahwa dia telah menikahi bekas istri anaknya (sedangkan Allahlah yang lebih berhak untuk kamu takuti) dalam segala hal dan dalam masalah menikahinya, dan janganlah kamu takuti perkataan manusia. Kemudian Zaid menalak istrinya dan setelah idahnya habis, Allah swt. berfirman, ("Maka tatkala Zaid telah mengakhiri keperluan terhadap istrinya) yakni kebutuhannya (Kami kawinkan kamu dengan dia) maka Nabi saw. langsung mengawininya tanpa meminta persetujuannya dulu, kemudian beliau membuat walimah buat kaum Muslimin dengan hidangan roti dan daging yang mengenyangkan mereka (supaya tidak ada keberatan bagi orang Mukmin untuk mengawini istri-istri anak-anak angkat mereka, apabila anak-anak angkat itu telah menyelesaikan keperluannya daripada istrinya. Dan adalah ketetapan Allah itu) apa yang telah dipastikan oleh-Nya (pasti terjadi.")\qt@no{37}}%
\qt@newcmd\qurantrans@id@mmmdlxxi{%
(Tidak ada suatu keberatan pun atas Nabi tentang apa yang telah ditetapkan) yang telah dihalalkan (Allah baginya, sebagai sunah Allah) lafal Sunatallah dinashabkan setelah huruf Jarnya dicabut (pada orang-orang yang telah berlalu dahulu) dari kalangan para nabi, yaitu bahwasanya tidak ada dosa bagi mereka dalam hal tersebut sebagai kemurahan bagi mereka dalam masalah nikah. (Dan adalah ketetapan Allah itu) yakni keputusan-Nya (suatu ketetapan yang pasti berlaku) pasti terlaksana.\qt@no{38}}%
\qt@newcmd\qurantrans@id@mmmdlxxii{%
(Yaitu orang-orang) lafal Al Ladziina menjadi Na'at atau sifat dari lafal Al Ladziina yang sebelumnya (yang menyampaikan risalah-risalah Allah, mereka takut kepada-Nya, dan mereka tiada merasa takut kepada seorang pun selain kepada Allah) mereka tidak takut kepada perkataan manusia dalam hal melaksanakan apa yang telah dihalalkan oleh Allah buat mereka. (Dan cukuplah Allah sebagai pembuat perhitungan) yakni yang memelihara amal-amal makhluk-Nya dan yang menghisab mereka.\qt@no{39}}%
\qt@newcmd\qurantrans@id@mmmdlxxiii{%
(Muhammad itu sekali-kali bukanlah bapak dari seorang laki-laki di antara kalian) dia bukan bapak Zaid, Zaid bukanlah anaknya, maka tidak diharamkan baginya untuk mengawini bekas istri anak angkatnya yaitu Zainab (tetapi dia) adalah (Rasulullah dan penutup nabi-nabi) artinya tidak akan lahir lagi nabi sesudahnya. Dan menurut suatu qiraat dibaca Khataman Nabiyyiina, sama dengan alat untuk mencap atau cincin, yang maksudnya sesudah dia para nabi dilak atau ditutup. (Dan adalah Allah Maha Mengetahui segala sesuatu) antara lain Dia mengetahui bahwa tidak akan ada nabi lagi sesudah Nabi Muhammad saw. seumpama Nabi Isa turun nanti, maka ia akan memerintah dengan memakai syariat Nabi Muhammad.\qt@no{40}}%
\qt@newcmd\qurantrans@id@mmmdlxxiv{%
(Hai orang-orang yang beriman! Berzikirlah dengan menyebut nama Allah, zikir yang sebanyak-banyaknya.)\qt@no{41}}%
\qt@newcmd\qurantrans@id@mmmdlxxv{%
(Dan bertasbihlah kepada-Nya di waktu pagi dan petang) yakni pada permulaan siang dan akhir siang.\qt@no{42}}%
\qt@newcmd\qurantrans@id@mmmdlxxvi{%
(Dialah Yang memberi rahmat kepada kalian) yang membelaskasihani kalian (dan malaikat-Nya) memohonkan ampunan buat kalian (supaya Dia mengeluarkan kalian) supaya Dia terus menerus mengeluarkan kalian (dari kegelapan) yakni kekafiran (kepada cahaya) yaitu keimanan. (Dan adalah Dia Maha Penyayang kepada orang-orang yang beriman).\qt@no{43}}%
\qt@newcmd\qurantrans@id@mmmdlxxvii{%
(Salam penghormatan kepada mereka) dari Allah swt. (pada hari mereka menemui-Nya ialah ``Salaam") melalui lisan Malaikat (dan Dia menyediakan pahala yang mulia bagi mereka) yaitu surga.\qt@no{44}}%
\qt@newcmd\qurantrans@id@mmmdlxxviii{%
(Hai Nabi, sesungguhnya Kami mengutusmu untuk jadi saksi) atas orang-orang yang kamu diutus kepada mereka (dan pembawa kabar gembira) bagi orang yang percaya kepadamu, yaitu diberi surga (dan pemberi peringatan) kepada orang yang mendustakanmu, yaitu akan dimasukkan ke dalam neraka.\qt@no{45}}%
\qt@newcmd\qurantrans@id@mmmdlxxix{%
(Dan untuk jadi penyeru kepada Allah) untuk taat kepada-Nya (dengan izin-Nya) dengan perintah-Nya (dan untuk jadi pelita yang menerangi) sebagaimana pelita yang memberi petunjuk ke jalan agama Allah.\qt@no{46}}%
\qt@newcmd\qurantrans@id@mmmdlxxx{%
(Dan sampaikanlah berita gembira kepada orang-orang Mukmin, bahwa sesungguhnya bagi mereka karunia yang besar dari Allah) yaitu surga.\qt@no{47}}%
\qt@newcmd\qurantrans@id@mmmdlxxxi{%
(Dan janganlah kamu menuruti orang-orang yang kafir dan orang-orang munafik itu) dalam hal-hal yang bertentangan dengan syariatmu (dan janganlah kamu hiraukan) artinya biarkanlah (gangguan mereka) janganlah kamu mengadakan pembalasan terhadap mereka, sampai dengan adanya perintah tentang apa yang harus kamu lakukan terhadap mereka (dan bertawakallah kepada Allah) Dialah Yang mencukupimu. (Dan cukuplah Allah sebagai Pelindung) maksudnya, serahkanlah semua urusanmu kepada-Nya.\qt@no{48}}%
\qt@newcmd\qurantrans@id@mmmdlxxxii{%
(Hai orang-orang yang beriman! Apabila kalian menikahi perempuan-perempuan yang beriman, kemudian kalian ceraikan mereka sebelum kalian mencampurinya) menurut suatu qiraat lafal Tamassuuhunna dibaca Tumaassuuhunna, artinya sebelum kalian menyetubuhi mereka (maka sekali-kali tidak wajib atas mereka idah bagi kalian yang kalian minta menyempurnakannya) yaitu yang kalian hitung dengan quru' atau bilangan yang lainnya. (Maka berilah mereka mutah) artinya berilah mereka uang mutah sebagai pesangon dengan jumlah yang secukupnya. Demikian itu apabila pihak lelaki belum mengucapkan jumlah maharnya kepada mereka, apabila ternyata ia telah mengucapkan jumlahnya, maka uang mutah itu adalah separuh dari mahar yang telah diucapkannya. Demikianlah menurut pendapat Ibnu Abbas kemudian pendapatnya itu dijadikan pegangan oleh Imam Syafii (dan lepaskanlah mereka itu dengan cara yang sebaik-baiknya) yaitu dengan tanpa menimbulkan kemudaratan pada dirinya.\qt@no{49}}%
\qt@newcmd\qurantrans@id@mmmdlxxxiii{%
(Hai Nabi! Sesungguhnya Kami telah menghalalkan bagi kamu istri-istrimu yang telah kamu berikan maskawinnya) yakni maharnya (dan hamba sahaya yang kamu miliki yang termasuk apa yang dikaruniakan oleh Allah kepadamu) dari orang-orang kafir melalui peperangan, yaitu sebagai tawananmu, seperti Shofiah dan Juwairiah (dan demikian pula anak-anak perempuan dari saudara laki-laki bapakmu, anak-anak perempuan dari saudara perempuan bapakmu, anak-anak perempuan dari saudara laki-laki ibumu, dan anak-anak perempuan dari saudara perempuan ibumu yang turut hijrah bersama kamu) berbeda halnya dengan perempuan-perempuan dari kalangan mereka yang tidak ikut berhijrah (dan perempuan Mukmin yang menyerahkan dirinya kepada Nabi kalau Nabi mau mengawininya) bermaksud untuk menikahinya tanpa memakai maskawin (sebagai pengkhususan bagimu, bukan untuk semua orang Mukmin) dalam pengertian nikah yang memakai lafal Hibah tanpa maskawin, (Sesungguhnya Kami telah mengetahui apa yang Kami wajibkan kepada mereka) kepada orang-orang Mukmin (tentang istri-istri mereka) berupa hukum-hukum dan ketentuan-ketentuan, yaitu hendaknya mereka mempunyai istri tidak lebih dari empat orang wanita dan hendaknya mereka tidak melakukan perkawinan melainkan harus dengan adanya seorang wali dan saksi-saksi serta maskawin (dan) di dalam (hamba sahaya yang mereka miliki) hamba sahaya perempuan yang dimilikinya melalui jalan pembelian dan jalan yang lainnya, seumpamanya, hamba sahaya perempuan itu termasuk orang yang dihalalkan bagi pemiliknya, karena ia adalah wanita ahli kitab, berbeda halnya dengan sahaya wanita yang beragama majusi atau watsani, dan hendaknya sahaya wanita itu melakukan istibra' atau menyucikan rahimnya terlebih dahulu sebelum digauli oleh tuannya (supaya tidak) lafal ayat ini berta'alluq pada kalimat sebelumnya (menjadi kesempitan bagimu) dalam masalah pernikahan. (Dan adalah Allah Maha Pengampun) dalam hal-hal yang memang sulit untuk dapat dihindari (lagi Maha Penyayang) dengan memberikan keleluasaan dan kemurahan dalam hal ini.\qt@no{50}}%
\qt@newcmd\qurantrans@id@mmmdlxxxiv{%
(Kamu boleh menangguhkan) dapat dibaca Turji-u dengan memakai huruf Hamzah pada akhirnya, juga dapat dibaca Turjiy dengan memakai huruf Ya pada akhirnya sebagai ganti dari Hamzah, artinya menangguhkan (siapa yang kamu kehendaki di antara mereka) yakni istri-istrimu itu dari gilirannya (dan boleh pula kamu menggilir) yaitu mengumpulkan gilirannya (siapa yang kamu kehendaki) di antara mereka kemudian kamu mendatanginya. (Dan siapa-siapa yang kamu ingini) kamu sukai untuk menggaulinya kembali (dari perempuan yang telah kamu pisahkan) dari gilirannya (maka tidak ada dosa bagimu) di dalam memintanya dan menggaulinya untukmu. Hal ini disuruh dipilih oleh Nabi sesudah ditentukan bahwa gilir itu wajib baginya. (Yang demikian itu) yakni boleh memilih itu (lebih dekat) kepada ketenangan hati mereka dan mereka tidak merasa sedih, dan semuanya rela dengan apa yang telah kamu berikan kepada mereka) yaitu tentang hal-hal yang telah disebutkan tadi menyangkut masalah boleh memilih di dalam menggilir (tanpa kecuali) lafal ayat ini mengukuhkan makna Fa'il yang terkandung di dalam lafal Yardhaina. (Dan Allah mengetahui apa yang tersimpan dalam hati kalian) mengenai masalah wanita atau istri dan kecenderungan hatimu kepada sebagian dari mereka. Dan sesungguhnya Kami menyuruh kamu memilih hanyalah untuk mempermudah kamu di dalam melakukan apa yang kamu kehendaki. (Dan adalah Allah Maha Mengetahui) tentang makhluk-Nya (lagi Maha Penyantun) mengenai menghukum mereka.\qt@no{51}}%
\qt@newcmd\qurantrans@id@mmmdlxxxv{%
(Tidak halal) dapat dibaca Tahillu atau Yahillu (bagimu mengawini perempuan-perempuan sesudah itu) sesudah sembilan orang istri yang telah Aku pilih buatmu (dan tidak boleh pula mengganti) lafal Tabaddala asalnya adalah Tatabaddala, kemudian salah satu huruf Ta dibuang sehingga jadilah Tabaddala, (mereka dengan istri-istri yang lain) misalnya kamu menalak mereka atau sebagian dari mereka, kemudian kamu menggantikannya dengan istri yang lain (meskipun kecantikannya menarik hatimu kecuali perempuan-perempuan hamba sahaya yang kamu miliki) yakni wanita sahaya yang kamu miliki, ia halal bagimu. Dan Nabi saw. sesudah sembilan orang istri itu memiliki Siti Mariah, yang daripadanya lahir Ibrahim, akan tetapi Ibrahim meninggal dunia semasa Nabi saw. masih hidup. (Dan adalah Allah Maha Mengawasi segala sesuatu) Maha Memelihara segala sesuatu.\qt@no{52}}%
\qt@newcmd\qurantrans@id@mmmdlxxxvi{%
(Hai orang-orang yang beriman! Janganlah kalian memasuki rumah-rumah Nabi kecuali bila kalian diizinkan) memasukinya karena mendapat undangan (untuk makan) kemudian kalian boleh memasukinya (dengan tidak menunggu-nunggu) tanpa menunggu lagi (waktu masak makanannya) yakni sampai makanan masak terlebih dahulu; Inaa berakar dari kata Anaa Ya-niy (tetapi jika kalian diundang maka masuklah dan bila kalian selesai makan, keluarlah kalian tanpa) berdiam lagi (asyik memperpanjang percakapan) sebagian dari kalian kepada sebagian yang lain. (Sesungguhnya yang demikian itu) yakni berdiamnya kalian sesudah makan (akan mengganggu nabi lalu nabi malu kepada kalian) untuk menyuruh kalian keluar (dan Allah tidak malu menerangkan yang hak) yakni menerangkan supaya kalian keluar; atau dengan kata lain Dia tidak akan mengabaikan penjelasannya. Menurut qiraat yang lain lafal Yastahyi dibaca dengan hanya memakai satu huruf Ya sehingga bacaannya menjadi Yastahiy. (Apabila kalian meminta sesuatu kepada mereka) kepada istri-istri Nabi saw. (yakni suatu keperluan, maka mintalah dari belakang tabir) dari belakang hijab. (Cara yang demikian itu lebih suci bagi hati kalian dan hati mereka) dari perasaan-perasaan yang mencurigakan. (Dan tidak boleh kalian menyakiti hati Rasulullah) dengan sesuatu perbuatan apa pun (dan tidak pula mengawini istri-istrinya sesudah ia wafat selama-lamanya. Sesungguhnya perbuatan itu di sisi Allah) dosanya (besar).\qt@no{53}}%
\qt@newcmd\qurantrans@id@mmmdlxxxvii{%
(Jika kalian melahirkan sesuatu atau menyembunyikannya) keinginan untuk menikahi mereka sesudah Nabi saw. wafat (maka sesungguhnya Allah adalah Maha Mengetahui segala sesuatu) Dia kelak akan membalasnya kepada kalian.\qt@no{54}}%
\qt@newcmd\qurantrans@id@mmmdlxxxviii{%
(Tidak ada dosa atas istri-istri Nabi terhadap bapak-bapak mereka, anak-anak laki-laki mereka, saudara laki-laki mereka, anak laki-laki dari saudara laki-laki mereka, anak laki-laki dari saudara mereka yang perempuan, perempuan-perempuan) yang beriman (dan hamba sahaya yang mereka miliki) yakni hamba sahaya laki-laki dan perempuan, untuk melihat dan bercakap dengan mereka tanpa memakai hijab (dan bertakwalah kalian kepada Allah) dalam hal-hal yang diperintahkan-Nya kepada kalian. (Sesungguhnya Allah Maha Menyaksikan segala sesuatu) tidak ada sesuatu pun yang samar dari pengetahuan-Nya.\qt@no{55}}%
\qt@newcmd\qurantrans@id@mmmdlxxxix{%
(Sesungguhnya Allah dan malaikat-malaikat-Nya bersalawat untuk Nabi) untuk Nabi Muhammad saw. (Hai orang-orang yang beriman! Bersalawatlah kalian untuk Nabi dan ucapkanlah salam penghormatan kepadanya) yaitu katakanlah oleh kalian, ``Allaahumma Shalli 'Alaa Sayyidinaa Muhammad Wa Sallim", artinya, ``Ya Allah! Limpahkanlah salawat dan Salam-Mu kepada junjungan kami Nabi Muhammad."\qt@no{56}}%
\qt@newcmd\qurantrans@id@mmmdxc{%
(Sesungguhnya orang-orang yang menyakiti Allah dan Rasul-Nya) mereka adalah orang-orang kafir, mereka mensifati Allah dengan sifat-sifat yang Dia Maha Suci daripadanya, yaitu mempunyai anak dan mempunyai sekutu, kemudian mereka mendustakan rasul-Nya. (Allah akan melaknatinya di dunia dan di akhirat) yakni menjauhkannya dari rahmat-Nya (dan menyediakan baginya siksa yang menghinakan) siksaan yang menghinakan yaitu neraka.\qt@no{57}}%
\qt@newcmd\qurantrans@id@mmmdxci{%
(Dan orang-orang yang menyakiti orang-orang Mukmin dan Mukminat tanpa kesalahan yang mereka perbuat) yaitu menuduh mereka mengerjakan hal-hal yang tidak mereka lakukan (maka sesungguhnya mereka telah memikul kebohongan) melancarkan tuduhan bohong (dan dosa yang nyata) yakni perbuatan yang nyata dosanya.\qt@no{58}}%
\qt@newcmd\qurantrans@id@mmmdxcii{%
(Hai Nabi! Katakanlah kepada istri-istrimu, anak-anak perempuanmu dan istri-istri orang Mukmin, ``Hendaklah mereka mengulurkan jilbabnya ke seluruh tubuh mereka") lafal Jalaabiib adalah bentuk jamak dari lafal Jilbaab, yaitu kain yang dipakai oleh seorang wanita untuk menutupi seluruh tubuhnya. Maksudnya hendaknya mereka mengulurkan sebagian daripada kain jilbabnya itu untuk menutupi muka mereka, jika mereka hendak keluar karena suatu keperluan, kecuali hanya bagian yang cukup untuk satu mata. (Yang demikian itu supaya mereka lebih mudah) lebih gampang (untuk dikenal) bahwasanya mereka adalah wanita-wanita yang merdeka (karena itu mereka tidak diganggu) maksudnya tidak ada orang yang berani mengganggunya, berbeda halnya dengan hamba sahaya wanita, mereka tidak diperintahkan untuk menutupi mukanya, sehingga orang-orang munafik selalu mengganggu mereka. (Dan adalah Allah Maha Pengampun) terhadap hal-hal yang telah lalu pada kaum wanita Mukmin yang merdeka, yaitu tidak menutupi wajah mereka (lagi Maha Penyayang) kepada mereka jika mereka mau menutupinya.\qt@no{59}}%
\qt@newcmd\qurantrans@id@mmmdxciii{%
(Sesungguhnya jika) huruf Lam bermaksud Qasam/sumpah (tidak berhenti orang-orang munafik) dari kemunafikan mereka (orang-orang yang berpenyakit dalam hati mereka) disebabkan telah melakukan perbuatan zina (dan orang-orang yang menyebarkan kabar bohong di Madinah) terhadap orang-orang Mukmin melalui perkataan mereka, bahwa musuh telah siap menyerang kalian berikut pasukan kalian; apakah mereka akan menang atau kalah kami tidak mengetahui (niscaya Kami gerakkan kamu untuk memerangi mereka) maksudnya Kami membuatmu berkuasa atas mereka (kemudian mereka tidak menjadi tetanggamu) tidak hidup berdampingan lagi denganmu (di Madinah melainkan dalam waktu sebentar) setelah itu mereka diusir daripadanya.\qt@no{60}}%
\qt@newcmd\qurantrans@id@mmmdxciv{%
(dalam keadaan terlaknat) dalam keadaan dijauhkan dari rahmat Allah. (Di mana saja mereka dijumpai) ditemui (mereka ditangkap dan dibunuh dengan sehebat-hebatnya) yakni keputusan tentang nasib mereka ini berdasarkan perintah dari-Nya.\qt@no{61}}%
\qt@newcmd\qurantrans@id@mmmdxcv{%
(Sebagai sunah Allah) yakni Allah telah menetapkan hal tersebut sebagai sunah-Nya (yang berlaku atas orang-orang yang telah terdahulu) atas umat-umat yang dahulu, yaitu atas orang-orang munafik yang selalu menyebarkan rasa takut ke dalam hati orang-orang yang beriman (dan kamu sekali-kali tiada akan mendapati perubahan pada sunah Allah) sebagai pengganti dari-Nya.\qt@no{62}}%
\qt@newcmd\qurantrans@id@mmmdxcvi{%
(Manusia bertanya kepadamu) yakni penduduk Mekah (tentang hari kiamat) kapankah akan terjadi. (Katakanlah! ``Sesungguhnya pengetahuan tentang hari kiamat itu hanya di sisi Allah". Dan tahukah kamu) maksudnya kamu tiada mengetahui kapan ia akan terjadi (boleh jadi hari kiamat itu waktunya) yakni terjadinya (sudah dekat).\qt@no{63}}%
\qt@newcmd\qurantrans@id@mmmdxcvii{%
(Sesungguhnya Allah melaknati orang-orang kafir) yakni menjauhkan mereka dari rahmat-Nya (dan menyediakan bagi mereka api yang menyala-nyala) yaitu neraka yang keras apinya tempat mereka dimasukkan.\qt@no{64}}%
\qt@newcmd\qurantrans@id@mmmdxcviii{%
(Mereka kekal) dipastikan kekekalan mereka (di dalamnya selama-lamanya, mereka tidak memperoleh seorang pelindung pun) yang memelihara mereka dari neraka (dan tidak pula seorang penolong) yang dapat mencegah neraka daripada mereka.\qt@no{65}}%
\qt@newcmd\qurantrans@id@mmmdxcix{%
(Pada hari ketika muka mereka dibolak-balikkan dalam neraka, mereka berkata, ``Aduhai!) lafal Yaa menunjukkan makna Tanbih atau memohon perhatian (andai kata kami taat kepada Allah dan taat pula kepada Rasul.")\qt@no{66}}%
\qt@newcmd\qurantrans@id@mmmdc{%
(Dan mereka berkata) yakni para pengikut dari kalangan mereka, ("Ya Rabb kami! Sesungguhnya kami telah menaati pemimpin-pemimpin kami) menurut suatu qiraat dibaca Saadatanaa, dalam bentuk Jam'ul Jam'i (dan pembesar-pembesar kami, lalu mereka menyesatkan kami dari jalan petunjuk) dari jalan hidayah.\qt@no{67}}%
\qt@newcmd\qurantrans@id@mmmdci{%
(Ya Rabb kami! Timpakanlah kepada mereka azab dua kali lipat) daripada azab yang kami terima (dan kutuklah mereka) azablah mereka terus (dengan kutukan yang banyak.") bilangannya; dan menurut Qiraat lain lafal Kabiiran dibaca Katsiiran yang artinya kutukan yang besar.\qt@no{68}}%
\qt@newcmd\qurantrans@id@mmmdcii{%
(Hai orang-orang yang beriman! Janganlah kalian menjadi) bersama Nabi kalian (seperti orang-orang yang menyakiti Musa) seperti perkataan mereka kepada Nabi Musa, ``Sesungguhnya tidak ada yang mencegahnya untuk mandi bersama kita melainkan karena pelirnya burut (maka Allah membersihkannya dari tuduhan-tuduhan yang mereka katakan) yaitu pada suatu hari Nabi Musa ketika hendak mandi meletakkan pakaiannya pada sebuah batu, kemudian batu itu membawa lari pakaiannya, dan berhenti di tengah-tengah segolongan kaum Bani Israel. Lalu Nabi Musa mengejarnya dan dapat menyusulnya, segera ia mengambil pakaiannya untuk menutupi dirinya. Pada saat itu orang-orang melihatnya dalam keadaan telanjang, ternyata pelir Nabi Musa tidak burut. (Dan adalah dia seorang yang mempunyai kedudukan terhormat di sisi Allah."). Di antara perlakuan yang menyakitkan Nabi saw. ialah pada suatu hari ia membagi-bagi ganimah, kemudian ada seorang lelaki berkata, ``Ini adalah pembagian yang tidak berdasarkan keridaan Allah swt." Maka pada saat itu wajah Nabi saw. merah padam mendengar perkataan itu, lalu beliau segera bersabda, ``Semoga Allah melimpahkan rahmat-Nya kepada Musa, sesungguhnya dia telah disakiti lebih dari ini tetapi dia tetap bersabar." Demikianlah menurut hadis yang diriwayatkan oleh Imam Bukhari.\qt@no{69}}%
\qt@newcmd\qurantrans@id@mmmdciii{%
(Hai orang-orang yang beriman! Bertakwalah kamu sekalian kepada Allah dan katakanlah perkataan yang benar) yakni perkataan yang tidak menyalahi.\qt@no{70}}%
\qt@newcmd\qurantrans@id@mmmdciv{%
(Niscaya Allah memperbaiki bagi kalian amal-amal kalian) yakni Dia menerimanya (dan mengampuni bagi kalian dosa-dosa kalian. Siapa yang menaati Allah dan Rasul-Nya, maka sesungguhnya ia telah mendapatkan kemenangan yang besar) yaitu dia telah memperoleh apa yang paling didambakannya.\qt@no{71}}%
\qt@newcmd\qurantrans@id@mmmdcv{%
(Sesungguhnya Kami telah mengemukakan amanat) yaitu ibadah salat dan ibadah-ibadah lainnya, apabila dikerjakan, pelakunya akan mendapat pahala, dan apabila ditinggalkan, pelakunya akan disiksa (pada langit, bumi dan gunung-gunung) seumpamanya Allah menciptakan pada masing-masing pemahaman dan dapat berbicara (maka semuanya enggan untuk memikul amanat itu dan mereka khawatir) yakni merasa takut (akan mengkhianatinya lalu dipikullah amanat itu oleh manusia) oleh Nabi Adam, sesudah terlebih dahulu ditawarkan kepadanya. (Sesungguhnya manusia itu amat zalim) terhadap dirinya sendiri, disebabkan apa yang telah dipikulnya itu (lagi amat bodoh) tidak mengerti tentang apa yang dipikulnya itu.\qt@no{72}}%
\qt@newcmd\qurantrans@id@mmmdcvi{%
(Sehingga Allah mengazab) huruf Lam berta'alluq kepada lafal 'Aradhnaa, sebagai akibat dari apa yang telah dipikul oleh Nabi Adam (orang-orang munafik laki-laki dan perempuan dan orang-orang musyrik laki-laki dan perempuan) yakni orang-orang yang menyia-nyiakan amanat itu (dan sehingga Allah menerima tobat orang-orang Mukmin laki-laki dan perempuan) yaitu orang-orang yang menunaikan amanahnya. (Dan adalah Allah Maha Pengampun) kepada orang-orang Mukmin (lagi Maha Penyayang) kepada mereka.\qt@no{73}}%
\qt@newcmd\qurantrans@id@mmmdcvii{%
\basmalahid (Segala puji bagi Allah) Allah swt. memuji diri-Nya dengan kalimat ini, maksudnya ialah pujian berikut apa yang terkandung di dalamnya yaitu pujian yang bersifat tetap. Memuji Allah artinya menyanjung-Nya dengan sebutan-sebutan yang baik (yang memiliki apa yang di langit dan apa yang di bumi) sebagai milik dan makhluk-Nya (dan bagi-Nya pula segala puji di akhirat) sebagaimana di dunia, yaitu Dia dipuji oleh kekasih-kekasih-Nya bilamana mereka telah berada di dalam surga. (Dan Dialah Yang Maha Bijaksana) di dalam perbuatan-Nya (lagi Maha Mengetahui) tentang makhluk-Nya.\qt@no{1}}%
\qt@newcmd\qurantrans@id@mmmdcviii{%
(Dia mengetahui apa yang masuk) yang meresap (ke dalam bumi) seperti air dan lain-lainnya (dan apa yang keluar daripadanya) seperti tumbuh-tumbuhan dan lain-lainnya (dan apa yang turun dari langit) berupa rezeki atau hujan dan lain-lainnya (dan apa yang naik) yakni yang terangkat (kepadanya) berupa amal perbuatan dan lain-lainnya. (Dan Dialah Yang Maha Penyayang) kepada kekasih-kekasih-Nya (lagi Maha Pengampun) kepada mereka.\qt@no{2}}%
\qt@newcmd\qurantrans@id@mmmdcix{%
(Dan orang-orang yang kafir berkata, ``Hari terakhir itu tidak akan datang kepada kami") yakni hari kiamat. (Katakanlah) kepada mereka, ("Pasti datang, demi Rabbku Yang mengetahui yang gaib, sesungguhnya kiamat itu pasti akan datang kepada kalian) kalau dibaca 'Aalimil Ghaibi berarti menjadi sifat dari lafal Rabbii. Kalau dibaca 'Aalimul Ghaibi berarti menjadi Khabar dari Mubtada, sehingga artinya menjadi seperti berikut, Ya, pasti datang, demi Rabbku, hari kiamat itu pasti akan datang kepada kalian; Dia mengetahui yang gaib. Bacaan yang kedua ini lebih sesuai dengan kalimat yang sesudahnya, yaitu, (tidak ada yang tersembunyi) tiada yang tidak tampak (bagi-Nya seberat) sebesar (zarah pun) zarah artinya semut yang paling kecil (yang ada di langit dan yang ada di bumi, dan tidak ada pula yang lebih kecil dari itu dan yang lebih besar, melainkan semuanya tercatat dalam Kitab yang nyata.) Kitab yang jelas, yang dimaksud adalah Lohmahfuz.\qt@no{3}}%
\qt@newcmd\qurantrans@id@mmmdcx{%
(Supaya Allah memberi balasan) pada hari kiamat itu (kepada orang-orang yang beriman dan mengerjakan amal yang saleh. Mereka itu adalah orang-orang yang baginya ampunan dan rezeki yang mulia.") rezeki yang baik di surga.\qt@no{4}}%
\qt@newcmd\qurantrans@id@mmmdcxi{%
(Dan orang-orang yang berusaha untuk) menentang atau membatalkan (ayat-ayat Kami) yaitu Alquran (dengan anggapan mereka dapat melepaskan diri dari Kami) dan menurut qiraat yang lain, lafal Mu'aajiziina pada ayat ini dan pada ayat yang lainnya nanti dibaca Mu'jiziina. Maksudnya menganggap Kami tidak mampu mengazab mereka, atau mereka beranggapan dapat melepaskan diri dari azab Kami, karena mereka mempunyai dugaan, bahwa tidak ada hari berbangkit dan tidak ada azab (mereka itu memperoleh buruknya azab) azab yang paling buruk (yang pedih) yang menyakitkan, kalau dibaca Aliimin berarti menjadi sifat daripada lafal Rijzin dan kalau dibaca Aliimun berarti menjadi sifat daripada lafal 'Adzaabun.\qt@no{5}}%
\qt@newcmd\qurantrans@id@mmmdcxii{%
(Dan berpendapat) yakni telah mengetahui (orang-orang yang diberi ilmu) yang dimaksud adalah orang-orang yang beriman dari kalangan ahli kitab, seperti Abdullah bin Salam dan teman-temannya (bahwa wahyu yang diturunkan kepadamu dari Rabbmu) yakni Alquran (itulah) keputusan (yang benar dan menunjuki manusia kepada jalan) tuntunan (Tuhan Yang Maha Perkasa lagi Maha Terpuji) Allah yang memiliki keperkasaan lagi terpuji.\qt@no{6}}%
\qt@newcmd\qurantrans@id@mmmdcxiii{%
(Dan orang-orang kafir berkata) sebagian dari mereka berkata kepada sebagian yang lain dengan nada yang penuh keheranan, ("Maukah kalian kami tunjukkan kepada kalian seorang laki-laki) yang mereka maksud adalah Nabi Muhammad (yang memberitakan kepada kalian) yang membawa berita kepada kalian, bahwasanya (apabila badan kalian telah hancur) telah berantakan (sehancur-hancurnya) menjadi berkeping-keping (sesungguhnya kalian akan dibangkitkan kembali dalam ciptaan yang baru?")\qt@no{7}}%
\qt@newcmd\qurantrans@id@mmmdcxiv{%
(Apakah dia mengada-adakan) lafal Aftaraa pada asalnya adalah A-iftaraa, kemudian Hamzah Washalnya tidak dibutuhkan lagi karena Hamzah Istifham sudah difathahkan, sehingga menjadi Aftaraa (kebohongan terhadap Allah) dalam hal tersebut (ataukah ada padanya penyakit gila?) yakni gangguan pada otaknya hingga ia mengkhayal yang bukan-bukan. Maka, Allah berfirman menyanggah mereka, ("Tidak, tetapi orang-orang yang tidak beriman kepada negeri akhirat) yang di dalamnya terdapat hari berbangkit dan azab pembalasan (berada dalam siksaan) di akhirat nanti (dan kesesatan yang jauh.) dari kebenaran dalam kehidupan dunia.\qt@no{8}}%
\qt@newcmd\qurantrans@id@mmmdcxv{%
(Maka, apakah mereka tidak melihat) tidak memperhatikan (kepada apa yang ada di hadapan mereka dan apa yang ada di belakang mereka) maksudnya apa yang ada di atas dan di bawah mereka (yaitu langit dan bumi? Jika Kami menghendaki, niscaya Kami benamkan mereka di bumi atau Kami jatuhkan kepada mereka gumpalan) dapat dibaca Kisfan atau Kisafan artinya gumpalan-gumpalan (dari langit) menurut qiraat yang lain lafal Nasya', Nakhsif, dan Nusqith dibaca Yasya', Yakhsif dan Yusqith. (Sesungguhnya pada yang demikian itu) hal-hal yang terlihat itu (benar-benar terdapat tanda bagi setiap hamba yang kembali.") kepada Rabbnya, yaitu tanda yang menunjukkan akan kekuasaan Allah yang mampu membangkitkan hidup kembali dan menciptakan apa yang dikehendaki-Nya.\qt@no{9}}%
\qt@newcmd\qurantrans@id@mmmdcxvi{%
(Dan sesungguhnya telah Kami berikan kepada Daud karunia dari Kami) berupa kenabian dan Kitab Zabur. Dan Kami berfirman, ("Hai gunung-gunung! Lakukanlah berulang-ulang) yakni ulang-ulanglah (bersama Daud) melakukan tasbih; maksudnya bertasbihlah berulang-ulang bersamanya (dan burung-burung") dibaca Nashab karena di'athafkan secara Mahall pada lafal Al Jibaalu maksudnya Kami menyeru mereka supaya bertasbih bersamanya (dan Kami telah melunakkan besi untuknya) sehingga besi di tangan Nabi Daud bagaikan adonan roti lunaknya.\qt@no{10}}%
\qt@newcmd\qurantrans@id@mmmdcxvii{%
Dan kami berfirman pula, ("Buatlah) dari besi itu (baju besi yang besar-besar) yang menutupi tubuh pemakainya, sehingga terseret ke tanah karena besarnya (dan ukurlah anyamannya) anyamlah baju besi itu, oleh karenanya pembuat baju besi dinamakan Sarrad. Maksudnya jadikanlah baju besi itu sehingga sesuai dengan ukuran pemakainya (dan kerjakanlah oleh kalian) oleh keluarga Daud bersama-sama Daud sendiri (amalan yang saleh. Sesungguhnya Aku melihat apa yang kalian kerjakan.") maka, Aku akan membalasnya kepada kalian.\qt@no{11}}%
\qt@newcmd\qurantrans@id@mmmdcxviii{%
(Dan) Kami tundukkan (bagi Sulaiman angin) menurut qiraat yang lain lafal Ar Riiha dibaca Ar Riihu yaitu dengan memperkirakan keberadaan lafal Taskhiirun (yang perjalanannya di waktu pagi) perjalanannya mulai dari pagi hingga waktu tergelincir matahari (sama dengan perjalanan sebulan, dan perjalanannya di waktu sore hari) yaitu mulai dari tergelincir matahari sampai terbenam (sama dengan perjalanan sebulan) maksudnya sama dengan perjalanan selama itu (dan Kami alirkan) Kami leburkan (cairan tembaga baginya) sehingga tembaga itu menjadi lebur selama tiga hari tiga malam, sebagaimana air mengalir dan umat manusia sampai sekarang dapat mengeksploitasinya berkat ilmu yang telah diberikan oleh Allah kepada Nabi Sulaiman. (Dan sebagian dari jin ada yang bekerja di bawah kekuasaannya dengan izin) yakni berdasarkan perintah (Rabbnya. Dan siapa yang menyimpang) menyeleweng (di antara mereka dari perintah Kami) yang menyuruhnya untuk taat kepada Nabi Sulaiman (Kami rasakan kepadanya azab neraka yang apinya menyala-nyala) di akhirat nanti. Menurut suatu pendapat azab tersebut terjadi di dunia, yaitu malaikat memukulnya dengan cambuk api, yang setiap pukulan dapat membakar dan menghanguskannya.\qt@no{12}}%
\qt@newcmd\qurantrans@id@mmmdcxix{%
(Para jin itu membuat untuk Sulaiman apa yang dikehendakinya dari gedung-gedung yang tinggi) bangunan-bangunan tinggi yang memakai tangga untuk orang yang mau memasukinya (dan patung-patung) lafal Tamaatsiil adalah bentuk jamak dari lafal Timtsaalun, yaitu segala sesuatu yang dibuat menurut gambaran objek yang dipahatnya. Maksudnya adalah patung-patung yang terbuat dari tembaga, ada pula yang terbuat dari kaca serta batu pualam. Perlu diketahui bahwa membuat patung atau gambar tidak diharamkan menurut syariat Nabi Sulaiman (dan piring-piring besar) lafal Jifaanin bentuk jamak dari lafal Jafnah (yang besarnya seperti kolam) lafal Jawaabii bentuk jamak dari lafal Jaabiyah artinya kolam yang besar; piring besar itu dapat dipakai untuk makan seribu orang (dan periuk yang tetap) berada di atas tungkunya serta tidak bergerak dari tempatnya karena saking besarnya. Periuk tersebut terbuat dari bukit negeri Yaman dan bagi orang yang memasak harus menaiki tangga, demikian pula bagi orang yang mau mengambil makanan daripadanya. Dan Kami berfirman, ("Bekerjalah kalian) hai (keluarga Daud) untuk taat kepada Allah (sebagai tanda syukur) kepada-Nya atas apa yang telah Dia limpahkan kepada kalian berupa nikmat-nikmat. (Dan sedikit sekali dari hamba-hamba-Ku yang berterima kasih.") yang mau bekerja untuk taat kepada-Ku sebagai ungkapan rasa syukurnya kepada-Ku atas nikmat-nikmat yang telah Kuberikan kepadanya.\qt@no{13}}%
\qt@newcmd\qurantrans@id@mmmdcxx{%
(Maka tatkala Kami telah menetapkan terhadapnya) terhadap Sulaiman (kematian) ia mati dalam keadaan diam berdiri bertopang pada tongkatnya selama setahun penuh. Para jin masih tetap melakukan pekerjaan-pekerjaan yang berat sebagaimana biasanya, karena mereka tidak menduga bahwa Nabi Sulaiman telah mati. Ketika rayap menggerogoti tongkatnya lalu tongkat itu patah, kemudian Nabi Sulaiman jatuh terjungkal maka menjadi nyatalah kematiannya di mata para jin itu (tidak ada yang menunjukkan kepada mereka kematiannya itu kecuali rayap) lafal Al Ardhu adalah bentuk Mashdar dari lafal Uridhatul Khasyabatu, artinya kayu itu digerogoti oleh rayap (yang memakan tongkatnya) lafal Minsa-atahuu dapat pula dibaca Minsaatahuu, yakni tongkatnya, dinamakan demikian karena tongkat itu dipakai untuk mengusir dan menghardik. (Maka, tatkala ia telah tersungkur) dalam keadaan telah mati (tahulah jin itu) yakni jelaslah bagi mereka (bahwa) ``an" berasal dari Anna yang kemudian ditakhfifkan, asalnya Annahum (kalau sekiranya mereka mengetahui yang gaib) antara lain ialah apa yang gaib di mata mereka tentang kematian Nabi Sulaiman (tentulah mereka tidak akan tetap dalam siksa yang menghinakan) kerja berat yang selama ini mereka lakukan, karena mereka menduga bahwa Nabi Sulaiman masih tetap hidup, berbeda halnya jika mereka mengetahui ilmu gaib. Mereka baru mengetahui kematiannya setelah satu tahun berdasarkan perhitungan masa yang diperkirakan jika sebuah tongkat dimakan rayap, sejak sehari semalam sesudah kematiannya.\qt@no{14}}%
\qt@newcmd\qurantrans@id@mmmdcxxi{%
(Sesungguhnya bagi kaum Saba) lafal Saba dapat dibaca dengan memakai harakat Tanwin pada akhirnya atau bisa juga tidak. Saba adalah nama suatu kabilah bangsa Arab yang diambil dari nenek moyang mereka (di tempat kediaman mereka) di negeri Yaman (ada tanda) yang menunjukkan akan kekuasaan Allah swt. (yaitu dua buah kebun) lafal Jannataani ini menjadi Badal dari lafal Aayatun (di sebelah kanan dan di sebelah kiri) lembah tempat mereka tinggal. Dan dikatakan kepada mereka, ("Makanlah oleh kalian dari rezeki Rabb kalian dan bersyukurlah kalian kepada-Nya.") atas apa yang telah dikaruniakan-Nya kepada kalian berupa nikmat-nikmat yang ada di negeri Saba. (Negeri kalian, adalah negeri yang baik) tidak ada tanah yang tandus, tidak ada nyamuk, tidak ada lalat, tidak ada lalat pengisap darah, tidak ada kalajengking dan tidak ada ular. Seandainya ada orang asing lewat ke negeri itu dan pada bajunya terdapat kutu, maka kutu itu otomatis akan mati karena harum dan bersihnya udara negeri Saba. (Dan) Allah (Rabb Yang Maha Pengampun.)\qt@no{15}}%
\qt@newcmd\qurantrans@id@mmmdcxxii{%
(Tetapi mereka berpaling) tidak mau bersyukur kepada-Nya dan bahkan mereka kafir kepada-Nya (maka Kami datangkan kepada mereka banjir yang besar) lafal Al 'Arim adalah bentuk jamak dari lafal 'Urmah yang artinya adalah bendungan yang menampung air sampai waktu yang dibutuhkan. Maksudnya dam yang membendung kebutuhan air mereka pecah sehingga menenggelamkan kebun-kebun dan harta benda mereka (dan Kami ganti kedua kebun mereka dengan dua kebun yang ditumbuhi) lafal Dzawaatai merupakan bentuk Tatsniyah dari lafal Dzawaatun yang Mufrad (pohon-pohon yang berbuah pahit) yang sangat pahit buahnya lagi tidak enak rasanya; dapat dibaca Ukuli Khamthin yaitu dengan di-mudhaf-kan, lafal Ukulin ini bermakna Maakuulin yaitu yang dimakan sebagaimana dapat pula dibaca Ukulin Khamthin, lalu dibaca Ukulin Wa Khamtin (pohon Atsl dan sedikit pohon Sidr).\qt@no{16}}%
\qt@newcmd\qurantrans@id@mmmdcxxiii{%
(Demikianlah) penggantian itu (Kami memberi balasan kepada mereka karena kekafiran mereka) sebab kekafiran mereka. (Dan Kami tidak menjatuhkan pembalasan melainkan hanya kepada orang-orang yang sangat kafir) lafal Nujaazii dapat pula dibaca Yujaazii, artinya tidaklah diberi balasan azab melainkan hanya orang-orang yang sangat ingkar.\qt@no{17}}%
\qt@newcmd\qurantrans@id@mmmdcxxiv{%
(Dan Kami jadikan antara mereka) yakni penduduk negeri Saba yang berada di Yaman (dan antara negeri-negeri yang Kami limpahkan berkat kepadanya) dengan melimpahnya air dan banyaknya pohon-pohonan, yang dimaksud adalah kampung-kampung negeri Syam tempat lalu mereka untuk tujuan berdagang (beberapa negeri yang berdekatan) mulai dari Yaman sampai ke Syam (dan Kami tetapkan antara negeri-negeri itu jarak-jarak perjalanan) hingga mereka dapat beristirahat pada suatu tempat, kemudian menginap pada tempat lainnya sampai pada akhir perjalanan mereka. Di dalam perjalanan, mereka tak perlu lagi membawa bekal dan air. Kami katakan, ("Berjalanlah kalian di kota-kota itu pada malam dan siang hari dengan aman") tanpa merasa takut lagi, baik kalian melakukan perjalanan pada malam hari maupun pada siang hari.\qt@no{18}}%
\qt@newcmd\qurantrans@id@mmmdcxxv{%
(Mereka berkata, ``Ya Rabb kami! Jauhkanlah) menurut suatu qiraat huruf 'Ain-nya di-tasydid-kan (jarak perjalanan kami") ke negeri Syam, maksudnya jadikanlah tempat-tempat yang dilalui itu menjadi padang sahara, supaya jarak perjalanan itu dianggap sangat jauh bagi orang-orang yang miskin, yaitu karena membutuhkan bekal-bekal yang banyak dan persediaan air yang cukup. Maka mereka mengingkari nikmat tersebut (dan mereka menganiaya diri mereka sendiri) dengan melakukan kekafiran (maka Kami jadikan mereka buah mulut) bagi orang-orang yang sesudah mereka dalam hal itu (dan Kami hancurkan mereka sehancur-hancurnya) Kami cerai-beraikan mereka dari negeri tempat tinggal mereka. (Sesungguhnya pada yang demikian itu) pada yang telah disebutkan itu (benar-benar terdapat tanda-tanda) yakni pelajaran (bagi setiap orang yang sabar) menahan diri dari perbuatan-perbuatan maksiat (lagi bersyukur) atas nikmat-nikmat-Nya.\qt@no{19}}%
\qt@newcmd\qurantrans@id@mmmdcxxvi{%
(Dan sesungguhnya telah membuktikan kebenaran) dapat dibaca Shadaqa atau Shaddaqa (terhadap mereka) terhadap orang-orang kafir, antara lain adalah penduduk negeri Saba (iblis akan kebenaran sangkaannya) bahwasanya apabila ia menggoda mereka, maka niscaya mereka akan mengikutinya (lalu mereka mengikutinya) maka benarlah dugaan iblis itu atau nyata benarlah apa yang diduga oleh iblis itu (kecuali) tetapi (sebagian dari orang-orang yang beriman) yang benar-benar beriman, tidak mau mengikuti iblis.\qt@no{20}}%
\qt@newcmd\qurantrans@id@mmmdcxxvii{%
(Dan tidak ada kekuasaan iblis terhadap mereka) maksudnya iblis tidak mempunyai kekuasaan apa-apa terhadap mereka (melainkan hanyalah agar Kami dapat mengetahui) yakni menyatakan (siapa yang beriman kepada adanya kehidupan akhirat dan siapa yang ragu-ragu tentang itu) maka kelak Kami akan membalasnya kepada masing-masing. (Dan Rabbmu Maha Memelihara segala sesuatu) yakni Maha Mengawasi.\qt@no{21}}%
\qt@newcmd\qurantrans@id@mmmdcxxviii{%
(Katakanlah) hai Muhammad kepada orang-orang kafir Mekah, ("Serulah mereka yang kalian anggap) sebagai tuhan-tuhan (selain Allah) untuk memberi manfaat kepada diri kalian sesuai dengan dugaan dan sangkaan kalian. Maka Allah berfirman mengenai yang dipertuhankan mereka itu (mereka tidak memiliki seberat) walau hanya seberat (zarah) kebaikan atau keburukan (di langit dan di bumi, dan mereka tidak mempunyai suatu saham pun dalam penciptaan langit dan bumi) tidak ikut andil (dan tidak ada bagi-Nya) yakni bagi Allah swt. (dari mereka) yang dianggap sebagai tuhan-tuhan itu (seorang pembantu pun") yaitu yang membantu-Nya.\qt@no{22}}%
\qt@newcmd\qurantrans@id@mmmdcxxix{%
(Dan tiadalah berguna syafaat di sisi Allah) Maha Tinggi Allah, ayat ini merupakan sanggahan terhadap perkataan mereka, bahwa sesungguhnya tuhan-tuhan sesembahan mereka akan dapat memberikan syafaat kepada mereka di sisi-Nya (melainkan bagi orang yang telah diizinkan) dapat dibaca Adzina atau Udzina (baginya) untuk memberi syafaat itu (sehingga apabila telah dihilangkan ketakutan) dapat dibaca Fazza'a atau Fuzzi'a (dari hati mereka) karena ada orang yang diizinkan untuk memberi syafaat (mereka berkata) sebagian dari mereka berkata kepada sebagian yang lain karena mendapat berita gembira itu, ("Apakah yang telah difirmankan oleh Rabb kalian?") mengenai syafaat itu. (Mereka menjawab) ``Perkataan (yang benar") yakni Dia telah memberi izin kepadanya untuk memberi syafaat (dan Dialah Yang Maha Tinggi) di atas semua makhluk-Nya dengan mengalahkan mereka semuanya (lagi Maha Besar) yakni Maha Agung.\qt@no{23}}%
\qt@newcmd\qurantrans@id@mmmdcxxx{%
(Katakanlah! ``Siapakah yang memberi rezeki kepada kalian dari langit) melalui hujan (dan dari bumi?") melalui tumbuh-tumbuhan (Katakanlah! ``Allah") jika mereka tidak mengatakan demikian, maka tidak akan ada jawaban lain yang benar (dan sesungguhnya kami atau kalian) yakni salah satu di antara kedua golongan (pasti berada dalam petunjuk atau dalam kesesatan yang nyata) nyata sesatnya, apakah kami atau kalian orang-orang kafir. Dikatakan dengan ungkapan yang samar demi untuk melunakkan hati orang yang kafir, dengan maksud menyeru mereka kepada iman, yaitu apabila mereka sesuai dengan Nabi saw.\qt@no{24}}%
\qt@newcmd\qurantrans@id@mmmdcxxxi{%
(Katakanlah! ``Kalian tidak akan ditanya tentang dosa yang kami perbuat) tentang dosa-dosa kami (dan kami tidak akan ditanya pula tentang apa yang kalian perbuat") karena sesungguhnya kami berlepas diri dari kalian.\qt@no{25}}%
\qt@newcmd\qurantrans@id@mmmdcxxxii{%
(Katakanlah! ``Rabb kita akan mengumpulkan kita semua) kelak di hari kiamat (kemudian Dia memberi keputusan) memutuskan (antara kita dengan benar) maka orang-orang yang benar akan dimasukkan-Nya ke dalam surga, dan orang-orang yang salah akan dimasukkan-Nya ke dalam neraka. (Dan Dialah Maha Pemberi keputusan) Yang menghukumi (lagi Maha Mengetahui") tentang keputusan hukum yang diambil-Nya.\qt@no{26}}%
\qt@newcmd\qurantrans@id@mmmdcxxxiii{%
(Katakanlah! ``Perlihatkanlah kepadaku) maksudnya beritahukanlah kepadaku (sesembahan-sesembahan yang kalian hubungkan dengan Dia sebagai sekutu-sekutu-Nya) untuk kalian sembah (sekali-kali tidak mungkin! Dialah Allah Yang Maha Perkasa) yakni Maha Menang atas semua perkara-Nya (lagi Maha Bijaksana") di dalam mengatur makhluk-Nya, maka tiadalah bagi-Nya sekutu dalam kerajaan-Nya.\qt@no{27}}%
\qt@newcmd\qurantrans@id@mmmdcxxxiv{%
(Dan Kami tidak mengutus kamu, melainkan untuk semua) lafal Kaaffatan berkedudukan menjadi Hal atau kata keterangan keadaan dari lafal An Naas yang sesudahnya, didahulukan mengingat kedudukannya yang sangat penting (manusia sebagai pembawa berita gembira) kepada orang-orang yang beriman, bahwa mereka akan masuk surga (dan sebagai pemberi peringatan) kepada orang-orang kafir bahwa mereka akan dimasukkan ke dalam neraka (tetapi kebanyakan manusia) yakni orang-orang kafir Mekah (tidak mengetahui hal ini).\qt@no{28}}%
\qt@newcmd\qurantrans@id@mmmdcxxxv{%
(Dan mereka berkata, ``Kapankah datangnya janji ini) yakni azab yang kamu janjikan itu (jika kamu adalah orang-orang yang benar?") dalam janjimu itu.\qt@no{29}}%
\qt@newcmd\qurantrans@id@mmmdcxxxvi{%
(Katakanlah! ``Bagi kalian ada hari yang telah dijanjikan yang tiada dapat kalian minta mundur daripadanya barang sesaat pun dan tidak pula kalian dapat meminta supaya diajukan") daripadanya, hari yang dimaksud adalah hari kiamat.\qt@no{30}}%
\qt@newcmd\qurantrans@id@mmmdcxxxvii{%
(Dan orang-orang kafir berkata) yakni sebagian dari penduduk Mekah ("Kami sekali-kali tidak akan beriman kepada Alquran ini dan tidak pula kepada kitab sebelumnya") kitab-kitab yang telah mendahuluinya, seperti kitab Taurat dan Injil yang di dalam kedua kitab tersebut disebutkan tentang adanya hari berbangkit, demikian itu karena mereka ingkar kepada Alquran. Lalu Allah berfirman mengenai mereka itu, ("Dan kalau kamu lihat) hai Muhammad ketika orang-orang yang lalim itu) yakni orang-orang yang kafir (dihadapkan kepada Rabbnya, sebagian dari mereka menghadapkan perkataan kepada sebagian yang lain. Orang-orang yang dianggap lemah berkata) yaitu para pengikut dari mereka (kepada orang-orang yang menyombongkan diri) yakni para pemimpinnya, ('Kalau tidak karena kalian) maksudnya seandainya kalian tidak menghalang-halangi kami untuk beriman (tentulah kami menjadi orang-orang yang beriman') kepada Nabi saw.\qt@no{31}}%
\qt@newcmd\qurantrans@id@mmmdcxxxviii{%
(Orang-orang yang menyombongkan diri berkata kepada orang-orang yang dianggap lemah, 'Kamikah yang telah menghalang-halangi kalian dari petunjuk sesudah petunjuk itu datang kepada kalian?) Tidak, (sebenarnya kalian sendirilah orang-orang yang berdosa') terhadap diri kalian sendiri.\qt@no{32}}%
\qt@newcmd\qurantrans@id@mmmdcxxxix{%
(Dan orang-orang yang dianggap lemah berkata kepada orang-orang yang menyombongkan diri, 'Sebenarnya tipu daya di waktu malam hari dan siang hari) yaitu tipu daya kalian terhadap kami yang kalian lakukan malam dan siang hari (ketika kalian menyeru kami supaya kami kafir kepada Allah dan menjadikan sekutu-sekutu bagi-Nya.') (Mereka menyembunyikan) kedua golongan itu, yaitu mereka yang menjadi pengikut kesesatan dan yang menjadi pemimpin kesesatan (penyesalannya) karena tidak mau beriman kepada Nabi saw. (tatkala mereka melihat azab.") masing-masing golongan menyembunyikan penyesalannya karena takut dicela. (Dan Kami pasang belenggu di leher orang-orang yang kafir) di dalam neraka. (Tiadalah) (mereka dibalas melainkan) dengan pembalasan (apa yang telah mereka kerjakan) di dunia.\qt@no{33}}%
\qt@newcmd\qurantrans@id@mmmdcxl{%
(Dan Kami tidak mengutus kepada suatu negeri seorang pemberi peringatan pun, melainkan orang-orang yang hidup mewah di negeri itu berkata) yakni para pemimpinnya hidup bergelimang dengan kemewahan, ("Sesungguhnya kami mengingkari apa yang kamu diutus untuk menyampaikannya.")\qt@no{34}}%
\qt@newcmd\qurantrans@id@mmmdcxli{%
(Dan mereka berkata, ``Kami lebih banyak mempunyai harta dan anak-anak) daripada orang-orang yang beriman (dan kami sekali-kali tidak akan diazab.")\qt@no{35}}%
\qt@newcmd\qurantrans@id@mmmdcxlii{%
(Katakanlah! ``Sesungguhnya Rabbku melapangkan rezeki) meluaskannya (bagi siapa yang dikehendaki-Nya) sebagai ujian (dan membatasinya) menyempitkannya bagi siapa yang dikehendakinya sebagai cobaan baginya (akan tetapi kebanyakan manusia) orang-orang kafir Mekah (tidak mengetahui") hal tersebut.\qt@no{36}}%
\qt@newcmd\qurantrans@id@mmmdcxliii{%
(Dan sekali-kali bukanlah harta dan bukan pula anak-anak kalian yang mendekatkan kalian kepada Kami sedikit pun) yang dapat mendekatkan diri kalian kepada Kami (tetapi) (orang-orang yang beriman dan mengerjakan amal-amal saleh, mereka itulah yang memperoleh balasan yang berlipat ganda disebabkan apa yang telah mereka kerjakan;) yakni sebagai balasan amalnya, yaitu satu amal kebaikan akan dibalas sepuluh kali lipat dan lebih banyak lagi dari itu (dan mereka di tempat-tempat yang tinggi) di dalam surga (hidup aman sentosa) tidak akan mati dan tidak akan tertimpa penyakit dan lain sebagainya. Menurut qiraat yang lain lafal Ghurufaati dibaca Ghurfah dalam bentuk Mufrad tetapi maknanya jamak.\qt@no{37}}%
\qt@newcmd\qurantrans@id@mmmdcxliv{%
(Dan orang-orang yang berusaha menentang ayat-ayat Kami) yakni membatalkan Alquran (dengan anggapan untuk dapat melepaskan diri dari azab Kami) yakni mereka menganggap Kami tidak mampu mengazab mereka dan mereka dapat meloloskan diri dari azab Kami (mereka itu dimasukkan ke dalam azab.)\qt@no{38}}%
\qt@newcmd\qurantrans@id@mmmdcxlv{%
(Katakanlah! ``Sesungguhnya Rabbku melapangkan rezeki) meluaskannya (bagi siapa yang dikehendaki-Nya di antara hamba-hamba-Nya) sebagai ujian buatnya (dan membatasinya) menyempitkannya (baginya) sesudah Dia melapangkannya, atau Dia menyempitkannya bagi siapa yang dikehendaki-Nya sebagai cobaan buatnya. (Dan barang apa saja yang kalian nafkahkan) dalam hal kebaikan (maka Allah akan menggantinya dan Dialah Pemberi rezeki yang sebaik-baiknya.") dikatakan, setiap orang memberi rezeki kepada keluarganya, yakni dari rezeki Allah swt.\qt@no{39}}%
\qt@newcmd\qurantrans@id@mmmdcxlvi{%
(Dan) ingatlah (hari, yang di waktu itu, Allah mengumpulkan mereka semuanya) yakni orang-orang musyrik (kemudian Allah berfirman kepada malaikat, ``Apakah mereka ini) dapat dibaca Tahqiq dan Tas-hil (dahulu menyembah kalian?")\qt@no{40}}%
\qt@newcmd\qurantrans@id@mmmdcxlvii{%
(Malaikat-malaikat itu menjawab, ``Maha Suci Engkau) dari semua sekutu (Engkaulah Pelindung kami, bukan mereka") maksudnya tidak ada saling lindung-melindungi antara kami dan mereka dari pihak kami (bahkan) lafal Bal di sini menunjukkan makna Intiqal, yakni sebenarnya (mereka telah menyembah jin) setan-setan, yaitu mereka menaati setan-setan yang menyuruh mereka untuk menyembah kami (kebanyakan mereka beriman kepada jin) yakni mereka selalu mempercayai apa yang dikatakan oleh jin kepada mereka.\qt@no{41}}%
\qt@newcmd\qurantrans@id@mmmdcxlviii{%
Allah swt. berfirman, ("Maka pada hari ini sebagian kalian terhadap sebagian yang lain tidak memiliki) yakni orang-orang yang disembah terhadap orang-orang yang menyembahnya tidak memiliki (kemanfaatan) yaitu syafaat (dan tidak pula kemudaratan") yaitu hak mengazab. (Dan Kami katakan kepada orang-orang yang zalim) yakni kepada orang-orang kafir, ("Rasakanlah oleh kalian azab neraka yang dahulunya kalian dustakan.")\qt@no{42}}%
\qt@newcmd\qurantrans@id@mmmdcxlix{%
(Dan apabila dibacakan kepada mereka ayat-ayat Kami) yakni Alquran (yang terang) yang jelas melalui lisan nabi Kami, yaitu Muhammad saw. (mereka berkata, ``Orang ini tiada lain hanyalah seorang laki-laki yang ingin menghalangi kalian dari apa yang disembah oleh bapak-bapak kalian") yaitu berupa berhala-berhala (dan mereka berkata, ``Tidak lain ini) yakni Alquran ini (hanyalah kebohongan) (yang diada-adakan saja") atas nama Allah. (Dan orang-orang kafir berkata terhadap kebenaran) yakni Alquran (tatkala kebenaran itu datang kepada mereka, ``Tidak lain) (ini hanyalah sihir yang nyata") sihir yang jelas.\qt@no{43}}%
\qt@newcmd\qurantrans@id@mmmdcl{%
(Dan Kami tidak pernah memberikan kepada mereka Kitab-kitab yang mereka baca dan sekali-kali tidak pernah pula mengutus kepada mereka sebelum kamu seorang pemberi peringatan pun) maka berdasarkan alasan apakah mereka mendustakanmu?\qt@no{44}}%
\qt@newcmd\qurantrans@id@mmmdcli{%
(Dan orang-orang yang sebelum mereka telah mendustakan sedangkan orang-orang kafir itu belum sampai menerima) yakni orang-orang kafir Mekah (sepersepuluh dari apa yang telah Kami berikan kepada orang-orang dahulu itu) yaitu berupa kekuatan, usia yang panjang dan banyaknya harta (lalu mereka mendustakan rasul-rasul-Ku) yang Aku utus kepada mereka. (Maka alangkah hebatnya akibat kemurkaan-Ku) yaitu hukuman dan pembinasaan-Ku terhadap mereka, kemurkaan-Ku itu benar-benar pada tempatnya.\qt@no{45}}%
\qt@newcmd\qurantrans@id@mmmdclii{%
(Katakanlah! ``Sesungguhnya aku hendak memperingatkan kepada kalian suatu hal saja) yaitu (supaya kalian menghadap Allah) dengan ikhlas hanya karena-Nya (dua-dua) yakni berduaan (atau sendiri-sendiri) satu persatu (kemudian kalian pikirkan tentang -Muhammad-) sehingga kalian mengetahui (tidak ada pada diri kawan kalian ini) yakni Nabi Muhammad (penyakit gila sedikit pun) yakni kegilaan (tidak lain dia hanyalah pemberi peringatan bagi kalian sebelum) kalian menghadapi (azab yang keras.") di akhirat nanti jika kalian mendurhakainya.\qt@no{46}}%
\qt@newcmd\qurantrans@id@mmmdcliii{%
(Katakanlah) kepada mereka! ("Upah apa pun yang aku minta kepada kalian) atas menyampaikan peringatan dan menyampaikan risalah Rabbku (maka upah itu untuk kalian) maksudnya aku tidak meminta upah apa pun atas hal ini. (Upahku tiada lain) tidak lain upahku (hanyalah dari Allah, dan Dia Maha Mengetahui segala sesuatu") Maha Menyaksikan dan Maha Mengetahui tentang kebenaranku.\qt@no{47}}%
\qt@newcmd\qurantrans@id@mmmdcliv{%
(Katakanlah! ``Sesungguhnya Rabbku mewahyukan kebenaran) yakni menyampaikannya kepada nabi-nabi-Nya (Dia Maha Mengetahui segala yang gaib") semua apa yang gaib dari makhluk-Nya baik yang di langit maupun yang di bumi.\qt@no{48}}%
\qt@newcmd\qurantrans@id@mmmdclv{%
(Katakanlah, ``Kebenaran telah datang) yakni agama Islam (dan yang batil itu tidak akan memulai) kekafiran itu tidak akan memulai (dan tidak pula akan mengulangi") tidak akan ada bekasnya lagi.\qt@no{49}}%
\qt@newcmd\qurantrans@id@mmmdclvi{%
(Katakanlah! ``Jika aku sesat) dari kebenaran (maka sesungguhnya aku sesat atas kemudaratan diriku sendiri) yakni dosa kesesatanku ditanggung oleh diriku (dan jika aku mendapat petunjuk maka itu adalah disebabkan apa yang diwahyukan Rabbku kepadaku) berupa Alquran dan Hadis Hikmah. (Sesungguhnya Dia Maha Mendengar) Maha mengabulkan doa (lagi Maha Dekat.")\qt@no{50}}%
\qt@newcmd\qurantrans@id@mmmdclvii{%
(Dan jika kamu melihat) hai Muhammad (ketika mereka terperanjat ketakutan) sewaktu mereka dibangkitkan, niscaya kamu akan melihat perkara yang hebat (maka mereka tidak dapat melepaskan diri) dari kekuasaan Kami yang dimaksud adalah dari azab Kami (dan mereka ditangkap dari tempat yang dekat) yaitu dari kubur mereka secara langsung.\qt@no{51}}%
\qt@newcmd\qurantrans@id@mmmdclviii{%
(Dan di waktu itu mereka berkata, ``Kami beriman kepada-Nya) yakni kepada Nabi Muhammad, atau kepada Alquran (bagaimanakah mereka dapat mencapai) meraih keimanan; dapat dibaca Tanaawusy atau huruf Wau diganti menjadi Hamzah, sehingga bacaannya menjadi Tanaa-usy maksudnya amat mustahillah mereka dapat mencapai keimanan (dari tempat yang jauh itu") dari tempatnya yang sekarang, karena mereka sekarang berada di alam akhirat dan tempat keimanan itu ada di dunia.\qt@no{52}}%
\qt@newcmd\qurantrans@id@mmmdclix{%
(Dan sesungguhnya mereka telah mengingkari Allah sebelum itu) sewaktu mereka hidup di dunia (dan mereka menduga-duga) meramal-ramal (tentang yang gaib dari tempat yang jauh) yaitu terhadap hal-hal yang tidak dapat dijangkau oleh pengetahuan mereka, karena mereka sewaktu di dunia mengatakan terhadap Nabi, bahwa Dia adalah penyihir, tukang syair dan tukang ramal. Mereka mengatakan tentang Alquran, bahwa itu adalah sihir, syair, dan ramalan.\qt@no{53}}%
\qt@newcmd\qurantrans@id@mmmdclx{%
(Dan dihalangi antara mereka dengan apa yang mereka ingini) yakni ingin beriman, maksudnya iman mereka tidak diterima lagi, karena waktunya sudah habis (sebagaimana dilakukan terhadap orang-orang yang serupa dengan mereka) yakni golongan-golongan mereka dalam hal kekafiran (pada masa dahulu) sebelum mereka. (Sesungguhnya mereka dahulu di dunia dalam keraguan yang mendalam) tentang hal-hal yang sekarang mereka imani; disebabkan sewaktu di dunia mereka tidak mau menganggap dalil-dalil yang menunjuk ke arahnya.\qt@no{54}}%
\qt@newcmd\qurantrans@id@mmmdclxi{%
\basmalahid (Segala puji bagi Allah) Allah memuji diri-Nya dengan kalimat tersebut, sebagaimana keterangan yang telah disebutkan dalam awal surah As-Saba (Pencipta langit dan bumi) yang menciptakan keduanya tanpa konsep terlebih dahulu (Yang menjadikan malaikat sebagai utusan-utusan) kepada para nabi (yang mempunyai sayap, masing-masing ada yang dua, tiga dan empat. Allah menambahkan pada ciptaan-Nya) yakni menciptakan malaikat dan lain-lainnya (apa yang Dia kehendaki. Sesungguhnya Allah Maha Kuasa atas segala sesuatu.)\qt@no{1}}%
\qt@newcmd\qurantrans@id@mmmdclxii{%
(Apa saja yang Allah anugerahkan kepada manusia berupa rahmat) seperti rezeki dan hujan (maka tidak ada seorang pun yang dapat menahannya; dan apa saja yang ditahan oleh Allah) dari hal-hal tersebut (maka tidak seorang pun yang sanggup untuk melepaskannya sesudah itu) sesudah Allah menahannya. (Dan Dialah Yang Maha Perkasa) Maha Menang atas perkara-Nya (lagi Maha Bijaksana) dalam perbuatan-Nya.\qt@no{2}}%
\qt@newcmd\qurantrans@id@mmmdclxiii{%
(Hai manusia!) penduduk Mekah (Ingatlah akan nikmat Allah kepada kalian) yang telah menempatkan kalian di tanah suci dan yang mencegah serangan-serangan dari luar terhadap kalian. (Adakah sesuatu pencipta) huruf Min di sini adalah Zaidah atau tambahan, lafal Khaaliqin sebagai Mubtada (selain Allah) kalau dibaca Ghairu berarti menjadi Na'at atau sifat secara Mahall dari lafal Khaaliqin, kalau dibaca Ghairi berarti di'athafkan kepada lafal Khaaliqin secara Lafzhan, dan Khabar Mubtadanya adalah (yang dapat memberikan rezeki kepada kalian dari langit) yakni berupa hujan (dan) dari (bumi?) berupa tumbuh-tumbuhan. Istifham atau kata tanya di sini mengandung makna Taqrir, yakni tidak ada pencipta dan tidak ada pemberi rezeki selain Allah. (Tidak ada Tuhan selain Dia; maka mengapakah kalian berpaling) dari mentauhidkan-Nya? Padahal kalian telah mengakui, bahwa Dia adalah Yang Maha Pencipta dan Maha Pemberi rezeki.\qt@no{3}}%
\qt@newcmd\qurantrans@id@mmmdclxiv{%
(Dan jika mereka mendustakan kamu) hai Muhammad, tentang ajaran tauhid yang engkau bawa dan berita adanya hari kebangkitan yang kamu sampaikan serta adanya hari penghisaban dan pembalasan amal perbuatan (maka sungguh telah didustakan pula rasul-rasul sebelum kamu) dalam hal tersebut maka bersabarlah kamu sebagaimana mereka bersabar. (Dan hanya kepada Allahlah dikembalikan segala urusan) di akhirat. Dia kelak akan mengazab orang-orang yang mendustakan dan menolong orang-orang yang berserah diri atau orang-orang muslim.\qt@no{4}}%
\qt@newcmd\qurantrans@id@mmmdclxv{%
(Hai manusia! Sesungguhnya janji Allah) tentang adanya hari berbangkit dan lain-lainnya (adalah benar, maka sekali-kali janganlah kehidupan dunia memperdayakan kalian) sehingga kalian tidak mau beriman kepada adanya hari berbangkit dan lain-lainnya (dan sekali-kali janganlah memperdayakan kalian tentang Allah) tentang sifat dan Penyantun-Nya dan sifat Sabar-Nya yang menangguhkan kalian tidak diazab (orang yang pandai menipu) yakni setan.\qt@no{5}}%
\qt@newcmd\qurantrans@id@mmmdclxvi{%
(Sesungguhnya setan itu adalah musuh bagi kalian, maka anggaplah ia musuh) dengan cara taat kepada Allah dan tidak menaati setan (karena sesungguhnya setan-setan itu hanya mengajak golongannya) yakni pengikut-pengikutnya yang sama-sama kafir dengannya (supaya menjadi penghuni neraka yang menyala-nyala) yakni neraka yang keras siksaannya.\qt@no{6}}%
\qt@newcmd\qurantrans@id@mmmdclxvii{%
(Orang-orang yang kafir bagi mereka azab yang keras. Dan orang-orang yang beriman serta mengerjakan amal saleh bagi mereka ampunan dan pahala yang besar) ini penjelasan tentang nasib orang-orang yang menuruti kemauan setan dan orang-orang yang menentangnya, kelak di akhirat.\qt@no{7}}%
\qt@newcmd\qurantrans@id@mmmdclxviii{%
Ayat ini diturunkan berkenaan dengan Abu Jahal dan orang-orang sepertinya. (Maka apakah orang yang dihiasi pekerjaannya yang buruk) karena setan telah menyulapnya (lalu ia menganggapnya baik?) lafal Man adalah Mubtada, sedangkan Khabarnya ialah, sebagaimana orang yang mendapat petunjuk dari Allah. Tentu saja tidak sama. Khabar ini disimpulkan dari ayat selanjutnya, yaitu, (Maka sesungguhnya Allah menyesatkan siapa yang dikehendaki-Nya dan menunjuki siapa yang dikehendaki-Nya; maka janganlah dirimu binasa sebab ulah mereka itu) yaitu atas orang-orang yang menganggap baik perbuatannya yang buruk itu (karena kesedihan) yaitu kamu merasa sedih karena mereka tidak mau beriman (Sesungguhnya Allah Maha Mengetahui apa yang mereka perbuat) kelak Dia akan membalasnya kepada mereka.\qt@no{8}}%
\qt@newcmd\qurantrans@id@mmmdclxix{%
(Dan Allah, Dialah Yang mengirimkan angin) menurut qiraat yang lain dibaca Ar Riih dalam bentuk Mufrad (lalu angin itu menggerakkan awan) lafal Mudhari' di sini untuk menceritakan keadaan di masa lalu, maksudnya angin itu menggerakkannya (lalu Kami halau awan itu) di dalam ungkapan ayat ini terkandung Iltifat dari dhamir Gaib (ke suatu negeri yang mati) tanah yang tandus yang tidak ada tumbuh-tumbuhannya. Dapat dibaca Mayyitin atau Mayitin (lalu Kami hidupkan dengan hujan itu bumi) yang dikenainya (setelah matinya) setelah ia mengalami kekeringan, yaitu Kami tumbuhkan padanya tumbuh-tumbuhan dan rumput-rumputan. (Demikianlah kebangkitan itu) cara membangkitkan yang mati menjadi hidup kembali.\qt@no{9}}%
\qt@newcmd\qurantrans@id@mmmdclxx{%
(Barang siapa yang menghendaki kemuliaan, maka bagi Allahlah kemuliaan itu semuanya) di dunia dan di akhirat, maka kemuliaan itu tidak akan dapat diraih melainkan dengan jalan taat kepada-Nya, oleh karenanya taatlah kepada-Nya. (Kepada-Nyalah naik perkataan-perkataan yang baik) yang telah dipermaklumkan oleh-Nya, yaitu kalimat ``Laa Ilaaha Illallaah", artinya, ``Tidak ada Tuhan selain Allah", dan kalimat-kalimat yang baik lainnya (dan amal saleh dinaikkan-Nya) diterima oleh-Nya. (Dan orang-orang yang merencanakan) membuat rencana makar (kejahatan) terhadap diri Nabi di Darun Nadwah, yaitu untuk mengikatnya, atau membunuhnya atau mengusirnya, sebagaimana keterangan yang telah disebutkan dalam surah Al-Anfal (bagi mereka azab yang keras. Dan rencana jahat mereka akan hancur) yakni akan berantakan.\qt@no{10}}%
\qt@newcmd\qurantrans@id@mmmdclxxi{%
(Dan Allah menciptakan kalian dari tanah) yaitu menciptakan Adam dari tanah liat (kemudian dari air mani) lalu Dia menciptakan anak cucunya dari air mani (kemudian Dia menjadikan kalian berpasang-pasang) terdiri dari kaum pria dan wanita. (Dan tidak ada seorang perempuan pun mengandung dan tidak pula melahirkan melainkan dengan sepengetahuan-Nya) lafal Bi'ilmihi berkedudukan menjadi Hal atau kata keterangan keadaan, yakni telah diketahui oleh-Nya. (Dan sekali-kali tidak dipanjangkan umur seorang yang berumur panjang) tidak diperpanjang (dan tidak pula dikurangi umurnya) yakni orang yang diberi umur panjang itu (melainkan tercatat dalam Kitab) di Lohmahfuz (Sesungguhnya yang demikian itu bagi Allah adalah mudah) amat gampang.\qt@no{11}}%
\qt@newcmd\qurantrans@id@mmmdclxxii{%
(Dan tiada sama -antara- dua laut; yang ini tawar, segar) sangat tawar (sedap diminum) sedap rasanya (dan yang lain asin lagi pahit) karena terlalu asin. (Dan dari masing-masing) kedua laut itu (kalian dapat memakan daging yang segar) yaitu ikan (dan kalian dapat mengeluarkan) dari laut yang asin, menurut pendapat yang lain dari laut yang tawar juga (perhiasan yang dapat kalian memakainya) yaitu berupa mutiara dan batu Marjan (dan kamu lihat) kamu dapat menyaksikan (bahtera) perahu (padanya) yakni pada masing-masing dari keduanya (dapat berlayar) dapat membelah airnya karena dapat melaju di atasnya; baik maju atau pun mundur hanya dengan satu arah angin (supaya kalian dapat mencari) berupaya mencari (karunia-Nya) karunia Allah swt. melalui berniaga dengan memakai jalan laut (dan supaya kalian bersyukur) kepada Allah atas hal tersebut.\qt@no{12}}%
\qt@newcmd\qurantrans@id@mmmdclxxiii{%
(Dia memasukkan) Allah memasukkan (malam ke dalam siang) sehingga bertambah panjanglah siang (dan memasukkan siang) (ke dalam malam) sehingga waktu malam bertambah panjang (dan menundukkan matahari dan bulan, masing-masing) dari matahari dan bulan itu (berjalan) beredar pada garis edarnya (menurut waktu yang ditentukan) yakni sampai hari kiamat. (Yang -berbuat- demikian itulah Allah Rabb kalian, kepunyaan-Nyalah kerajaan. Dan orang-orang yang kalian seru) yang kalian sembah (selain-Nya) yang dimaksud adalah berhala-berhala (tiada mempunyai apa-apa walaupun setipis kulit ari) yakni kulit yang melapisi biji.\qt@no{13}}%
\qt@newcmd\qurantrans@id@mmmdclxxiv{%
(Jika kalian menyeru mereka, tiada mendengar seruanmu, dan kalau mereka mendengar) seumpamanya (mereka tidak dapat memperkenankan permintaan kalian) mereka tidak dapat memenuhi permintaan kalian. (Dan di hari kiamat mereka akan mengingkari kemusyrikan kalian) disebabkan kalian menyekutukan Allah bersama mereka. Maksudnya, mereka tidak bertanggung jawab terhadap penyembahan kalian kepada mereka (dan tidak ada yang dapat memberikan keterangan kepada kalian) tentang keadaan dua negeri yaitu dunia dan akhirat (sebagaimana yang diberikan oleh Yang Maha Mengetahui) yaitu Allah swt. sendiri.\qt@no{14}}%
\qt@newcmd\qurantrans@id@mmmdclxxv{%
(Hai manusia! Kalianlah yang berkehendak kepada Allah) dalam keadaan bagaimana pun (dan Allah, Dialah Yang Maha Kaya) tidak membutuhkan makhluk-Nya (lagi Maha Terpuji) atas perbuatan-Nya terhadap mereka.\qt@no{15}}%
\qt@newcmd\qurantrans@id@mmmdclxxvi{%
(Jika Dia menghendaki, niscaya Dia memusnahkan kalian dan mendatangkan makhluk yang baru) sebagai ganti daripada kalian.\qt@no{16}}%
\qt@newcmd\qurantrans@id@mmmdclxxvii{%
(Dan yang demikian itu sekali-kali tidak sulit bagi Allah) tidak sukar bagi-Nya.\qt@no{17}}%
\qt@newcmd\qurantrans@id@mmmdclxxviii{%
(Dan tidaklah menanggung) setiap diri (Yang telah berbuat dosa) yakni ia tidak akan menanggung (dosa) diri (orang lain. Dan jika memanggil) seseorang yang (diberati) oleh dosanya (untuk memikul dosa itu) yaitu memanggil orang lain untuk ikut memikul sebagian dari dosanya (tiadalah akan dipikul untuknya sedikit pun) orang yang dipanggil itu tidak akan mau memikulnya walau sedikit pun (meskipun -yang dipanggil itu- kaum kerabatnya) seperti ayah dan anaknya; tidak adanya penanggungan dosa dari kedua belah pihak ini berdasarkan keputusan dari Allah. (Sesungguhnya yang dapat kamu beri peringatan hanya orang-orang yang takut kepada azab Rabbnya -sekalipun mereka tidak melihat-Nya) mereka tetap takut kepada-Nya sekalipun mereka tidak melihat-Nya, sebab hanya merekalah orang-orang yang dapat mengambil manfaat dari adanya peringatan itu (dan mereka mendirikan salat) mereka melestarikannya (Dan barang siapa yang menyucikan dirinya) dari kemusyrikan dan dosa-dosa lainnya (sesungguhnya ia menyucikan diri untuk kebaikan dirinya) karena kemaslahatannya akan kembali kepada dirinya sendiri. (Dan kepada Allahlah kembali kalian) kelak di alam akhirat Dia akan membalas amal perbuatan kalian.\qt@no{18}}%
\qt@newcmd\qurantrans@id@mmmdclxxix{%
(Dan tidaklah sama orang yang buta dengan orang yang melihat) orang kafir dan orang mukmin.\qt@no{19}}%
\qt@newcmd\qurantrans@id@mmmdclxxx{%
(Dan tidak pula sama gelap gulita) yaitu kekafiran (dengan cahaya) yakni keimanan.\qt@no{20}}%
\qt@newcmd\qurantrans@id@mmmdclxxxi{%
(Dan tidak pula sama yang teduh dengan yang panas) yakni surga dan neraka.\qt@no{21}}%
\qt@newcmd\qurantrans@id@mmmdclxxxii{%
(Dan tidak pula sama orang-orang yang hidup dan orang-orang yang mati) orang-orang beriman dengan orang-orang kafir; ditambahkannya lafal Laa pada ketiga ayat di atas untuk mengukuhkan makna tidak sama. (Sesungguhnya Allah memberikan pendengaran kepada siapa yang dikehendaki-Nya) untuk mendapat hidayah, karena itu tidak beriman (dan kamu sekali-kali tiada sanggup menjadikan orang yang di dalam kubur dapat mendengar) yakni orang-orang kafir; mereka diserupakan dengan orang-orang yang telah mati, maksudnya kamu tidak akan sanggup menjadikan mereka mendengar, kemudian mereka mau menerima seruanmu.\qt@no{22}}%
\qt@newcmd\qurantrans@id@mmmdclxxxiii{%
(Tiada lain) (kamu hanyalah seorang pemberi peringatan) terhadap mereka.\qt@no{23}}%
\qt@newcmd\qurantrans@id@mmmdclxxxiv{%
(Sesungguhnya Kami mengutus kamu dengan membawa kebenaran) yakni petunjuk (sebagai pembawa berita gembira) bagi orang yang mau menerima kebenaran itu (dan sebagai pemberi peringatan) kepada orang yang tidak mau menerimanya. (Dan tidak ada) (suatu umat pun melainkan telah ada) telah lewat (padanya seorang pemberi peringatan) nabi yang memberi peringatan kepada mereka.\qt@no{24}}%
\qt@newcmd\qurantrans@id@mmmdclxxxv{%
(Dan jika mereka mendustakan kamu) yakni penduduk Mekah (maka sesungguhnya orang-orang yang sebelum mereka telah mendustakan -rasul-rasul-Nya-; kepada mereka telah datang rasul-rasul-Nya dengan membawa bukti-bukti yang nyata) yakni mukjizat-mukjizat (zubur) seperti shuhuf Nabi Ibrahim (dan Kitab yang memberi penjelasan yang sempurna) yaitu kitab Taurat dan Injil, oleh karenanya bersabarlah kamu sebagaimana mereka bersabar.\qt@no{25}}%
\qt@newcmd\qurantrans@id@mmmdclxxxvi{%
(Kemudian Aku azab orang-orang yang kafir) disebabkan kedustaan mereka (maka -lihatlah- bagaimana hebatnya akibat kemurkaan-Ku) keingkaran-Ku terhadap mereka, yaitu hukuman dan kebinasaan yang menimpa mereka, hal itu benar-benar pada tempatnya.\qt@no{26}}%
\qt@newcmd\qurantrans@id@mmmdclxxxvii{%
(Tidakkah kamu melihat) mengetahui (bahwasanya Allah menurunkan hujan dari langit lalu Kami hasilkan) di dalam ungkapan ayat ini terkandung Iltifat dari dhamir Gaib (dengan hujan itu buah-buahan yang beraneka ragam jenisnya) ada yang berwarna hijau, merah dan kuning dan warna-warna lainnya. (Dan di antara gunung-gunung itu ada garis-garis) Judadun adalah bentuk jamak dari lafal Juddatun, artinya jalan yang terdapat di gunung dan lainnya (putih, merah) dan kuning (yang beraneka macam warnanya) ada yang tua dan ada yang muda (dan ada -pula yang hitam pekat) di'athafkan kepada lafal Judadun, artinya ialah batu-batu yang besar yang hitam pekat warnanya. Dikatakan Aswadu Gharbiibu, hitam pekat; tetapi sangat sedikit dikatakan Gharabiibu Aswadu.\qt@no{27}}%
\qt@newcmd\qurantrans@id@mmmdclxxxviii{%
(Dan demikian pula di antara manusia, binatang-binatang melata dan binatang-binatang ternak ada yang bermacam-macam warnanya) sebagaimana beraneka ragamnya buah-buahan dan gunung-gunung. (Sesungguhnya yang takut kepada Allah di antara hamba-hamba-Nya, hanyalah ulama) berbeda halnya dengan orang-orang yang jahil seperti orang-orang kafir Mekah. (Sesungguhnya Allah Maha Perkasa) di dalam kerajaan-Nya (lagi Maha Pengampun) terhadap dosa hamba-hamba-Nya yang mukmin.\qt@no{28}}%
\qt@newcmd\qurantrans@id@mmmdclxxxix{%
(Sesungguhnya orang-orang yang selalu membaca) selalu mempelajari (kitab Allah dan mendirikan salat) yakni mereka melaksanakannya secara rutin dan memeliharanya (dan menafkahkan sebagian dari rezeki yang Kami anugerahkan kepada mereka dengan diam-diam dan terang-terangan) berupa zakat dan lain-lainnya (mereka itu mengharapkan perniagaan yang tidak akan merugi) tidak bangkrut.\qt@no{29}}%
\qt@newcmd\qurantrans@id@mmmdcxc{%
(Agar Allah menyempurnakan kepada mereka pahala mereka) pahala amal-amal mereka yang telah disebutkan itu (dan menambah kepada mereka dari karunia-Nya. Sesungguhnya Allah Maha Pengampun) terhadap dosa-dosa mereka (lagi Maha Mensyukuri) ketaatan mereka.\qt@no{30}}%
\qt@newcmd\qurantrans@id@mmmdcxci{%
(Dan apa yang telah Kami wahyukan kepadamu yaitu Alkitab) yakni Alquran (itulah yang benar, membenarkan kitab-kitab yang sebelumnya) yang diturunkan sebelumnya. (Sesungguhnya Allah benar-benar Maha Mengetahui lagi Maha Melihat -keadaan- hamba-hamba-Nya) Dia mengetahui apa yang tersimpan di dalam kalbu mereka dan apa yang mereka lahirkan.\qt@no{31}}%
\qt@newcmd\qurantrans@id@mmmdcxcii{%
(Kemudian Kami wariskan) Kami berikan (Kitab itu) yakni Alquran (kepada orang-orang yang Kami pilih di antara hamba-hamba Kami) mereka adalah umatmu (lalu di antara mereka ada yang menganiaya diri mereka sendiri) karena sembrono di dalam mengamalkannya (dan di antara mereka ada yang pertengahan) dalam mengamalkannya (dan di antara mereka ada -pula- yang lebih cepat berbuat kebaikan) di samping mengamalkan Alquran, juga mempelajarinya, mengajarkannya dan membimbing orang lain untuk mengamalkannya (dengan izin Allah) dengan kehendak-Nya. (Yang demikian itu) yakni diwariskannya Alquran kepada mereka (adalah karunia yang amat besar.)\qt@no{32}}%
\qt@newcmd\qurantrans@id@mmmdcxciii{%
(Bagi mereka surga Adn) sebagai tempat tinggalnya (mereka masuk ke dalamnya) yakni ketiga golongan tersebut; lafal ayat ini dapat dibaca Yadkhuluunahaa atau Yudkhaluunahaa, berkedudukan menjadi Khabar dari Mubtada yaitu lafal Jannaatu 'Adnin (mereka diberi perhiasan) kalimat ayat ini menjadi Khabar yang kedua (di dalamnya dengan) lafal Min di sini menunjukkan makna Ba'dh atau sebagian (gelang-gelang dari emas dan dengan mutiara) yang berbingkai emas (dan pakaian mereka di dalamnya adalah sutera.)\qt@no{33}}%
\qt@newcmd\qurantrans@id@mmmdcxciv{%
(Dan mereka berkata, ``Segala puji bagi Allah yang telah menghilangkan duka cita dari kami.) yakni semua duka cita. (Sesungguhnya Rabb kami benar-benar Maha Pengampun) terhadap dosa-dosa kami (lagi Maha Mensyukuri) ketaatan kami.\qt@no{34}}%
\qt@newcmd\qurantrans@id@mmmdcxcv{%
(Yang menempatkan kami dalam tempat yang kekal) sebagai tempat tinggal kami (dari karunia-Nya; di dalamnya kami tidak merasa lelah) yakni tiada merasa payah (dan tiada pula merasa lesu") karena kecapekan, sebab di dalam surga tidak ada lagi yang namanya taklif. Disebutkannya lafal yang kedua padahal maknanya sama dengan yang pertama, dimaksud untuk lebih menegaskan kenafiannya atau ketiadaannya.\qt@no{35}}%
\qt@newcmd\qurantrans@id@mmmdcxcvi{%
(Dan orang-orang kafir bagi mereka neraka Jahanam; mereka tidak dibinasakan) dengan dimatikan (sehingga mereka mati) yakni terbebas dari rasa sakit (dan tidak -pula- diringankan dari mereka azabnya) walau barang sekejap pun. (Demikianlah) sebagaimana Kami berikan balasan azab kepada mereka. (Kami membalas setiap orang yang sangat kafir) lafal Najziy dapat pula dibaca Yajziy; arti lafal Kafuur adalah orang kafir.\qt@no{36}}%
\qt@newcmd\qurantrans@id@mmmdcxcvii{%
(Dan mereka berteriak di dalam neraka itu) meminta tolong dengan suara yang sangat keras dan jeritan-jeritan kesakitan, seraya mengatakan, ("Ya Rabb kami! Keluarkanlah kami) dari dalam neraka (niscaya kami akan mengerjakan amal yang saleh berlainan dengan yang telah kami kerjakan") lalu dikatakan kepada mereka, ("Dan apakah Kami tidak memanjangkan umur kalian dalam masa) waktu (yang cukup untuk berpikir bagi orang yang mau berpikir dan apakah tidak datang kepada kalian pemberi peringatan?") yakni rasul tetapi kalian tidak memenuhi seruannya (maka rasakanlah -azab Kami- dan tidak ada bagi orang yang lalim) orang kafir (seorang penolong pun) yang dapat menolak azab dari diri mereka.\qt@no{37}}%
\qt@newcmd\qurantrans@id@mmmdcxcviii{%
(Sesungguhnya Allah mengetahui yang tersembunyi di langit dan di bumi. Sesungguhnya Dia Maha Mengetahui segala isi hati) yang tersimpan di dalam kalbu, ini berarti bahwa pengetahuan Allah tentang hal ikhwal manusia yang lahir lebih mengetahui.\qt@no{38}}%
\qt@newcmd\qurantrans@id@mmmdcxcix{%
(Dialah yang menjadikan kalian khalifah-khalifah di muka bumi) lafal Khalaa-if adalah bentuk jamak dari Khaliifah, yakni Dia mengganti sebagian di antara kalian dengan sebagian yang lain, yaitu generasi demi generasi. (Barang siapa yang kafir) di antara kalian (maka kekafirannya menimpa dirinya sendiri.) (Dan kekafiran orang-orang yang kafir itu tidak lain hanyalah akan menambah kemurkaan pada sisi Rabbnya) Dia akan bertambah murka kepadanya (dan kekafiran orang-orang yang kafir itu tidak lain hanyalah akan menambah kerugian mereka belaka) di akhirat kelak.\qt@no{39}}%
\qt@newcmd\qurantrans@id@mmmdcc{%
(Katakanlah! ``Terangkanlah kepadaku tentang sekutu-sekutu kalian yang kalian seru) yang kalian sembah (selain Allah) mereka adalah berhala-berhala yang diduga oleh para pengabdinya, bahwa mereka adalah sekutu-sekutu Allah swt. (Perlihatkanlah kepadaku) terangkanlah kepadaku (bagian manakah dari bumi ini yang telah mereka ciptakan ataukah mereka mempunyai saham) yakni andil bersama Allah (di dalam) menciptakan (langit atau adakah Kami memberi kepada mereka sebuah kitab sehingga mereka mendapatkan keterangan-keterangan yang jelas) yakni hujah-hujah yang jelas (daripadanya) seumpamanya disebutkan di dalamnya, bahwa mereka adalah sekutu-sekutu-Ku yang ikut andil bersama-Ku? Tentu saja tidak. (Sebenarnya tidaklah) (orang-orang yang lalim itu menjanjikan) yakni orang-orang yang kafir (sebagian dari mereka kepada sebagian yang lain, melainkan tipuan belaka.") kebatilan belaka, melalui perkataan mereka, bahwa berhala-berhala itu dapat memberikan syafaat kepada mereka.\qt@no{40}}%
\qt@newcmd\qurantrans@id@mmmdcci{%
(Sesungguhnya Allah menahan langit dan bumi supaya jangan lenyap) mencegah keduanya agar tidak lenyap (dan sungguh jika) huruf Lam di sini bermakna Qasam (keduanya akan lenyap tidak ada yang dapat menahan keduanya seorang pun selain Allah. Sesungguhnya Dia adalah Maha Penyantun lagi Maha Pengampun) oleh karenanya Dia menangguhkan azab-Nya atas orang-orang kafir.\qt@no{41}}%
\qt@newcmd\qurantrans@id@mmmdccii{%
(Dan mereka bersumpah) yakni orang-orang kafir Mekah (dengan nama Allah dengan sekuat-kuat sumpah) sumpah yang sungguh-sungguh (sesungguhnya jika datang kepada mereka seorang pemberi peringatan) yakni seorang rasul (niscaya mereka akan lebih mendapat petunjuk dari salah satu umat-umat yang lain) yaitu umat Yahudi, Nasrani dan umat-umat beragama lainnya. Maksudnya mereka lebih mendapat petunjuk daripada umat mana pun, karena mereka melihat adanya perselisihan di antara mereka, yaitu sebagian dari mereka mendustakan sebagian yang lain. Karena orang-orang Yahudi mengatakan, ``Orang-orang Nasrani itu tidak mempunyai suatu pegangan." Demikian pula orang-orang Nasrani mengatakan, ``Orang-orang Yahudi tidak mempunyai suatu pegangan." (Tatkala datang kepada mereka pemberi peringatan) yaitu Nabi Muhammad saw. (maka tidaklah menambah kepada mereka) kedatangan pemberi peringatan itu (melainkan jauhnya mereka dari petunjuk) mereka makin bertambah jauh dari petunjuk.\qt@no{42}}%
\qt@newcmd\qurantrans@id@mmmdcciii{%
(Karena kesombongan -mereka- di muka bumi) terhadap keimanan, mereka tidak mau beriman karena sombong. Lafal ayat ini menjadi Maf'ul Lah (dan karena rencana) pekerjaan mereka (yang jahat) berupa kemusyrikan dan lain-lainnya. (Dan tidaklah menimpa) tidak menggilas (rencana jahat itu selain orang yang merencanakannya sendiri) yaitu orang yang mengadakan makar itu sendiri. Lafal Al Makru diberi sifat As Sayyi-u adalah bentuk asal tetapi di-mudhaf-kan-nya lafal Al Makru kepada lafal As Sayyi-u, menurut suatu pendapat merupakan cara pemakaian yang lain tetapi dengan memperkirakan adanya Mudhaf yang lain supaya jangan langsung di-mudhaf-kan kepada sifat. (Tiadalah yang mereka nanti-nantikan) (melainkan, berlakunya, sunah, Allah yang telah berlaku, kepada orang-orang yang dahulu) yaitu diturunkannya azab atas mereka sebab mereka mendustakan rasul-rasul-Nya. (Maka sekali-kali kamu tidak akan menemui perubahan bagi sunah Allah dan sekali-kali tidak pula akan menemui penyimpangan bagi sunah Allah itu) azab itu tidak dapat diganti dengan yang lain dan tidak ditimpakan kepada orang-orang yang tidak berhak menerimanya.\qt@no{43}}%
\qt@newcmd\qurantrans@id@mmmdcciv{%
(Dan apakah mereka tidak berjalan di muka bumi, lalu melihat bagaimana kesudahan orang-orang yang sebelum mereka, sedangkan orang-orang itu adalah lebih besar kekuatannya dari mereka?) maka Allah tetap membinasakan mereka karena mereka telah mendustakan rasul-rasul mereka. (Dan tiada sesuatu pun yang dapat melemahkan Allah) yang dapat mendahului-Nya dan dapat meloloskan diri dari azab-Nya (baik di langit maupun di bumi. Sesungguhnya Allah Maha Mengetahui) segala sesuatu (lagi Maha Kuasa) atas semuanya.\qt@no{44}}%
\qt@newcmd\qurantrans@id@mmmdccv{%
(Dan kalau sekiranya Allah swt. menyiksa manusia disebabkan usahanya) karena maksiat-maksiat yang telah dikerjakannya (niscaya Dia tidak akan meninggalkan di atas permukaan bumi (suatu makhluk pun) yang hidup merayap di atasnya (akan tetapi Allah menangguhkan penyiksaan mereka, sampai waktu yang tertentu) yakni hari kiamat (maka apabila datang ajal mereka, maka sesungguhnya Allah adalah Maha Melihat keadaan hamba-hamba-Nya) Dia kelak akan membalas amal perbuatan mereka, yaitu dengan memberi pahala kepada orang-orang yang beriman dan menghukum orang-orang yang kafir.\qt@no{45}}%
\qt@newcmd\qurantrans@id@mmmdccvi{%
\basmalahid (Yaa siin) hanya Allahlah yang mengetahui maksudnya.\qt@no{1}}%
\qt@newcmd\qurantrans@id@mmmdccvii{%
(Demi Alquran yang penuh hikmah) yang padat dengan hikmah-hikmah, susunan kata-katanya amat mengagumkan dan makna-maknanya sangat indah lagi memukau.\qt@no{2}}%
\qt@newcmd\qurantrans@id@mmmdccviii{%
(Sesungguhnya kamu) hai Muhammad (salah seorang dari rasul-rasul.)\qt@no{3}}%
\qt@newcmd\qurantrans@id@mmmdccix{%
(Yang berada di atas) berta'alluq kepada ayat sebelumnya (jalan yang lurus) jalannya para nabi sebelum kamu, yaitu jalan tauhid dan hidayah. Ungkapan yang memakai kata pengukuh sumpah dan pengukuh lainnya, dimaksud sebagai sanggahan terhadap perkataan orang-orang kafir yang ditujukan kepada Nabi Muhammad, yaitu sebagaimana yang disitir oleh firman-Nya, ``Kamu bukan seorang yang dijadikan rasul." (Q.S. Ar-Ra'd 43.)\qt@no{4}}%
\qt@newcmd\qurantrans@id@mmmdccx{%
(Sebagai wahyu yang diturunkan oleh Yang Maha Perkasa) di dalam kerajaan-Nya (lagi Maha Penyayang) kepada makhluk-Nya. Khabar dari Mubtada diperkirakan keberadaannya, yaitu lafal Alquran. Maksudnya, Alquran ini sebagai wahyu yang diturunkan.\qt@no{5}}%
\qt@newcmd\qurantrans@id@mmmdccxi{%
(Agar kamu memberi peringatan) dengan Alquran itu (kepada kaum) lafal Litundzira berta'alluq kepada lafal Tanziilun (yang bapak-bapak mereka belum pernah diberi peringatan) mereka belum pernah diberi peringatan karena hidup di zaman fatrah atau zaman kekosongan nabi dan rasul (karena itu mereka) yakni kaum itu (dalam keadaan lalai) lalai dari iman dan petunjuk.\qt@no{6}}%
\qt@newcmd\qurantrans@id@mmmdccxii{%
(Sesungguhnya telah pasti berlaku perkataan) yakni ketentuan Allah telah pasti (terhadap kebanyakan mereka) yakni azab-Nya telah pasti atas mereka (karena mereka tidak beriman) kebanyakan dari mereka tidak beriman.\qt@no{7}}%
\qt@newcmd\qurantrans@id@mmmdccxiii{%
(Sesungguhnya Kami telah memasang belenggu di leher mereka) tangan mereka disatukan dengan leher mereka dalam satu belenggu, karena pengertian lafal Al-Ghillu ialah mengikatkan kedua tangan ke leher (lalu tangan mereka) yaitu tangan-tangan mereka diangkat dan disatukan (ke dagu) mereka, lafal Adzqaan bentuk jamak dari lafal Dzaqanun yaitu tempat tumbuh janggut (maka karena itu mereka tertengadah) kepala mereka terangkat dan tidak dapat ditundukkan. Ini merupakan tamtsil, yang dimaksud ialah mereka tidak mau taat untuk beriman, dan mereka sama sekali tidak mau menundukkan kepalanya dalam arti kata tidak mau beriman.\qt@no{8}}%
\qt@newcmd\qurantrans@id@mmmdccxiv{%
(Dan Kami adakan di hadapan mereka dinding dan di belakang mereka dinding) lafal Saddan dalam dua tempat tadi boleh dibaca Suddan (dan Kami tutup -mata- mereka sehingga mereka tidak dapat melihat.) Ini merupakan tamtsil yang menggambarkan tertutupnya jalan iman bagi mereka.\qt@no{9}}%
\qt@newcmd\qurantrans@id@mmmdccxv{%
(Sama saja bagi mereka apakah kamu memberi peringatan kepada mereka) dapat dibaca Tahqiq dan dapat pula dibaca Tas-hil (ataukah kamu tidak memberi peringatan kepada mereka, mereka tidak akan beriman.)\qt@no{10}}%
\qt@newcmd\qurantrans@id@mmmdccxvi{%
(Sesungguhnya Kamu hanya dapat memperingati) yakni akan dapat mengambil manfaat dari peringatanmu (orang yang mau mengikuti peringatan) petunjuk Alquran (dan yang takut kepada Tuhan Yang Maha Pemurah walaupun Dia tidak melihat-Nya) yakni ia tetap takut kepada-Nya sekalipun ia tidak melihat-Nya. (Maka berilah ia kabar gembira dengan ampunan dan pahala yang mulia) yaitu mendapat surga.\qt@no{11}}%
\qt@newcmd\qurantrans@id@mmmdccxvii{%
(Sesungguhnya Kami menghidupkan orang-orang mati) yakni menghidupkannya kembali (dan Kami menuliskan) di Lohmahfuz (apa yang telah mereka kerjakan) selama hidup di dunia berupa kebaikan dan keburukan, lalu Kami membalasnya kepada mereka (dan bekas-bekas yang mereka tinggalkan) hal-hal yang dijadikan panutan dari perbuatan mereka sesudah mereka tiada (serta segala sesuatu) dinashabkannya lafal Kulla oleh pengaruh Fiil atau kata kerja yang menjelaskannya, yaitu kalimat berikutnya (Kami catat) Kami kumpulkan satu persatu secara mendetail (di dalam kitab induk yang nyata) yaitu di Lohmahfuz.\qt@no{12}}%
\qt@newcmd\qurantrans@id@mmmdccxviii{%
(Dan buatlah) adakanlah (buat mereka suatu perumpamaan) lafal Matsalan adalah Maf'ul Awal (yaitu penduduk) lafal Ashhaaba ini menjadi Maf'ul yang kedua (suatu negeri) yaitu kota Inthakiah (ketika datang kepada mereka) lafal ayat ini sampai akhir ayat berkedudukan menjadi Badal Isytimal dari lafal Ashhaabal Qaryah (utusan-utusan) utusan-utusan Nabi Isa.\qt@no{13}}%
\qt@newcmd\qurantrans@id@mmmdccxix{%
(Yaitu ketika Kami mengutus kepada mereka dua orang utusan, lalu mereka mendustakan keduanya) ayat ini seluruhnya berkedudukan sebagai Badal dari lafal Idz yang pertama (kemudian Kami kuatkan) kedua utusan itu; lafal ayat ini dapat dibaca Takhfif sehingga bunyinya menjadi Fa'azaznaa dapat pula dibaca Tasydid, sehingga bunyinya menjadi Fa'azzaznaa (dengan -utusan- yang ketiga, maka ketiga utusan itu berkata, ``Sesungguhnya kami adalah orang-orang yang diutus kepada kalian.")\qt@no{14}}%
\qt@newcmd\qurantrans@id@mmmdccxx{%
(Mereka menjawab, ``Kalian tidak lain hanyalah manusia seperti kami dan Allah Yang Maha Pemurah tidak menurunkan sesuatu pun. Tidak lain) (kalian hanyalah pendusta belaka.")\qt@no{15}}%
\qt@newcmd\qurantrans@id@mmmdccxxi{%
(Mereka berkata, ``Rabb kami mengetahui) kalimat ayat ini mengandung makna qasam, kemudian pengukuhannya ditambah dengan adanya huruf Lam pada lafal Lamursaluuna, sebagai sanggahan terhadap perkataan mereka (bahwa sesungguhnya kami adalah orang-orang yang diutus kepada kalian.)\qt@no{16}}%
\qt@newcmd\qurantrans@id@mmmdccxxii{%
(Dan kewajiban kami tidak lain hanyalah menyampaikan -perintah Allah- dengan jelas") menyampaikan yang jelas dan gamblang melalui mukjizat-mukjizat yang terang, yaitu dapat menyembuhkan orang buta, yang berpenyakit supak, dan dapat menghidupkan orang mati.\qt@no{17}}%
\qt@newcmd\qurantrans@id@mmmdccxxiii{%
(Mereka menjawab, ``Sesungguhnya kami bernasib malang) mengalami kesialan (karena kalian) kami mengalami kekeringan dan tidak pernah turun hujan sebab ada kalian (sesungguhnya jika) huruf Lam di sini bermakna qasam (kalian tidak berhenti -menyeru kami-, niscaya kami akan merajam kalian) dengan batu-batu (dan kalian pasti akan mendapat siksa yang pedih dari kami.") siksa yang menyakitkan.\qt@no{18}}%
\qt@newcmd\qurantrans@id@mmmdccxxiv{%
(Utusan-utusan itu berkata, ``Kemalangan kalian) yakni kesialan kalian itu (adalah karena kalian sendiri") disebabkan ulah kalian sendiri karena kafir. (Apakah jika) Hamzah Istifham digabungkan dengan In Syarthiyah, keduanya dapat dibaca Tahqiq, dan dapat pula dibaca Tas-hil (kalian diberi peringatan) yakni diberi nasihat dan peringatan; jawab Syarath tidak disebutkan. Lengkapnya ialah apakah jika kalian diberi peringatan lalu kalian bernasib sial karenanya lalu kalian kafir? Pengertian terakhir inilah objek daripada Istifham atau kata tanya. Makna yang dimaksud adalah sebagai cemoohan terhadap mereka. (Sebenarnya kalian adalah kaum yang melampaui batas) karena kemusyrikan kalian.\qt@no{19}}%
\qt@newcmd\qurantrans@id@mmmdccxxv{%
(Dan datanglah dari ujung kota seorang laki-laki) Habib An Najjar atau Habib si tukang kayu; dia telah beriman kepada utusan-utusan Nabi Isa, dan tempat tinggalnya berada di ujung kota Inthakiyah (dengan bergegas-gegas) lari dengan cepat, tatkala ia mendengar berita bahwa kaumnya mendustakan utusan-utusan itu (ia berkata, ``Hai kaumku! Ikutilah utusan-utusan itu.)\qt@no{20}}%
\qt@newcmd\qurantrans@id@mmmdccxxvi{%
(Ikutilah) lafal ayat ini mengukuhkan makna lafal yang sama pada ayat sebelumnya (orang yang tiada minta balasan kepada kalian) atas misi risalah yang disampaikannya itu (dan mereka adalah orang-orang yang mendapat petunjuk) lalu dikatakan kepadanya, ``Kamu seagama dengan mereka."\qt@no{21}}%
\qt@newcmd\qurantrans@id@mmmdccxxvii{%
Lalu laki-laki itu berkata, ("Mengapa aku tidak menyembah -Tuhan- yang telah menciptakan aku) yang telah menjadikan aku. Maksudnya, tidak ada yang mencegahku untuk menyembah-Nya, karena ada bukti-buktinya yang jelas, seharusnya kalian menyembah Dia (dan hanya kepada-Nya kalian semua akan dikembalikan?) sesudah mati, kemudian Dia akan membalas kekafiran kalian itu.\qt@no{22}}%
\qt@newcmd\qurantrans@id@mmmdccxxviii{%
(Mengapa aku akan menjadikan) Istifham atau kata tanya di sini mengandung arti kalimat negatif; dan lafal ayat ini sama dengan lafal A-andzartahum tadi, yaitu dapat dibaca Tahqiq dan Tashil (selain Allah) yakni selain-Nya (sebagai tuhan-tuhan -yang disembah-) maksudnya berhala-berhala (jika Allah Yang Maha Pemurah menghendaki kemudaratan terhadapku, niscaya syafaat mereka tidak memberi manfaat sedikit pun bagi diriku) seperti yang kalian dugakan itu (dan mereka tidak -pula- dapat menyelamatkanku) lafal ayat ini menjadi sifat bagi lafal Aalihatan.\qt@no{23}}%
\qt@newcmd\qurantrans@id@mmmdccxxix{%
(Sesungguhnya aku kalau begitu) seandainya aku menyembah selain Allah (berada dalam kesesatan yang nyata) benar-benar sesat.\qt@no{24}}%
\qt@newcmd\qurantrans@id@mmmdccxxx{%
(Sesungguhnya aku telah beriman kepada Rabb kalian, maka dengarkanlah pengakuan keimananku.") dengarkanlah perkataanku ini. Lalu mereka merajamnya hingga mati.\qt@no{25}}%
\qt@newcmd\qurantrans@id@mmmdccxxxi{%
(Dikatakan) kepadanya sesudah ia mati, ("Masuklah ke surga") menurut suatu pendapat dikatakan, bahwa Habib An Najjar itu masuk ke dalam surga dalam keadaan hidup. (Ia berkata, ``Aduhai!) huruf Ya di sini menunjukkan makna tanbih atau penyesalan (sekiranya kaumku mengetahui.)\qt@no{26}}%
\qt@newcmd\qurantrans@id@mmmdccxxxii{%
(Apa yang menyebabkan Rabbku memberi ampun kepadaku) yakni penyebab Allah memberikan ampunan kepadanya (dan menjadikan aku termasuk orang-orang yang dimuliakan.")\qt@no{27}}%
\qt@newcmd\qurantrans@id@mmmdccxxxiii{%
(Dan tiadalah) Maa bermakna Nafi (Kami turunkan kepada kaumnya) kaum Habib An Najjar (setelah dia meninggal) sesudah Habib mati karena dirajam oleh mereka (suatu pasukan pun dari langit) yaitu malaikat-malaikat untuk membinasakan mereka (dan tidak layak Kami menurunkannya) menurunkan Malaikat untuk membinasakan seseorang.\qt@no{28}}%
\qt@newcmd\qurantrans@id@mmmdccxxxiv{%
(Tidak ada siksaan) yakni hukuman atas mereka (melainkan satu teriakan saja) malaikat Jibril berteriak keras kepada mereka (maka tiba-tiba mereka semuanya mati) tak bergerak lagi, mati semuanya.\qt@no{29}}%
\qt@newcmd\qurantrans@id@mmmdccxxxv{%
(Alangkah besarnya penyesalan terhadap hamba-hamba itu) terhadap mereka dan orang-orang yang seperti mereka, yaitu orang-orang yang mendustakan rasul-rasul, karena akhirnya mereka dibinasakan. Yang dimaksud dengan penyesalan di sini adalah perasaan sakit yang amat sangat akibat suara malaikat Jibril. Kata Nida atau kata seru pada lafal Yaa hasratan hanyalah merupakan kata kiasan, maknanya sudah saatnya bagimu, maka menghadaplah kamu (tiada datang seorang rasul pun kepada mereka melainkan mereka selalu memperolok-olokkannya) ungkapan-ungkapan ini untuk menjelaskan penyebab dari penyesalan tadi. Di dalamnya terkandung pengertian ejekan mereka yang menyebabkan diri mereka binasa, setelah itu mereka menyesal karenanya.\qt@no{30}}%
\qt@newcmd\qurantrans@id@mmmdccxxxvi{%
(Tidakkah mereka mengetahui) yakni penduduk Mekah yang mengatakan kepada Nabi saw. sebagaimana yang disitir oleh firman-Nya, ``Kamu bukan seorang yang dijadikan rasul." (Q.S. Ar-Ra'd, 43.) Istifham atau kata tanya pada ayat ini mengandung makna Taqrir yakni ketahuilah oleh kalian (berapa banyak) lafal Kam mengandung makna kalimat berita, yakni banyak sekali; maknanya, sesungguhnya Kami (telah Kami binasakan sebelum mereka) amatlah banyak (umat-umat) bangsa-bangsa. (Bahwasanya mereka itu) orang-orang yang telah Kami binasakan (kepada mereka) yaitu orang-orang yang mendustakan Nabi saw. (tiada kembali) apakah mereka tidak mengambil pelajaran darinya. Lafal Annahum dan seterusnya berkedudukan menjadi Badal dari kalimat sebelumnya, dengan memelihara makna yang telah disebutkan.\qt@no{31}}%
\qt@newcmd\qurantrans@id@mmmdccxxxvii{%
(Dan tiadalah) bila dianggap sebagai In Nafiyah. Sesungguhnya, bila dianggap sebagai In Mukhaffafah dari Inna (masing-masing) dari semua makhluk, Kullun berkedudukan menjadi Mubtada (melainkan) apabila dibaca Tasydid artinya sama dengan lafal illa. Jika dibaca Takhfif yaitu menjadi Lamaa, maka huruf Lamnya adalah Lam Fariqah dan huruf Ma-nya adalah Zaidah (dikumpulkan) menjadi Khabar dari Mubtada, yakni dihimpunkan (kepada Kami kembali) untuk menjalani penghisaban; lafal ayat ini menjadi Khabar kedua\qt@no{32}}%
\qt@newcmd\qurantrans@id@mmmdccxxxviii{%
(Dan suatu tanda bagi mereka) yang menunjukkan bahwa mereka akan dibangkitkan kembali, lafal ayat ini berkedudukan menjadi Khabar Muqaddam (adalah bumi yang mati) dapat dibaca Al Maytati atau Al Mayyitati (Kami hidupkan bumi itu) dengan air, menjadi Mubtada Muakhkhar (dan Kami keluarkan daripadanya biji-bijian) seperti gandum (maka daripadanya mereka makan.)\qt@no{33}}%
\qt@newcmd\qurantrans@id@mmmdccxxxix{%
(Dan Kami jadikan padanya kebun-kebun) ladang-ladang (kurma dan anggur dan Kami pancarkan padanya beberapa mata air) dari sebagian kebun-kebun itu.\qt@no{34}}%
\qt@newcmd\qurantrans@id@mmmdccxl{%
(Supaya mereka dapat makan dari buahnya) dapat dibaca Tsamarihi atau Tsumurihi, yakni buah pohon yang telah disebutkan tadi, yaitu buah kurma dan buah-buah lainnya (dan dari apa yang diusahakan oleh tangan mereka) bukan dari hasil buah-buahan. (Maka mengapakah mereka tidak bersyukur?) atas nikmat-nikmat Allah yang telah dilimpahkan kepada mereka.\qt@no{35}}%
\qt@newcmd\qurantrans@id@mmmdccxli{%
(Maha Suci Allah yang telah menciptakan pasangan-pasangan) yang berjenis-jenis (semuanya, baik dari apa yang ditumbuhkan oleh bumi) berupa biji-bijian dan lain-lainnya (dan dari diri mereka) yaitu jenis pria dan wanita (maupun dari apa yang tidak mereka ketahui) yaitu makhluk-makhluk yang ajaib dan aneh.\qt@no{36}}%
\qt@newcmd\qurantrans@id@mmmdccxlii{%
(Dan suatu tanda bagi mereka) yang menunjukkan kekuasaan Allah yang besar (adalah malam; Kami tanggalkan) Kami pisahkan (siang dari malam itu, maka dengan serta merta mereka berada dalam kegelapan) mereka memasuki kegelapan malam hari.\qt@no{37}}%
\qt@newcmd\qurantrans@id@mmmdccxliii{%
(Dan matahari berjalan) ayat ini dan seterusnya merupakan bagian daripada ayat Wa-aayatul Lahum, atau merupakan ayat yang menyendiri, yakni tidak terikat oleh ayat sebelumnya demikian pula ayat Wal Qamara, pada ayat selanjutnya (di tempat peredarannya) tidak akan menyimpang dari garis edarnya. (Demikianlah) beredarnya matahari itu (ketetapan Yang Maha Perkasa) di dalam kerajaan-Nya (lagi Maha Mengetahui) tentang makhluk-Nya.\qt@no{38}}%
\qt@newcmd\qurantrans@id@mmmdccxliv{%
(Dan bagi bulan) dapat dibaca Wal Qamaru atau Wal Qamara, bila dibaca nashab yaitu Wal Qamara berarti dinashabkan oleh Fiil sesudahnya yang berfungsi menafsirkannya yaitu (telah Kami tetapkan) bagi peredarannya (manzilah-manzilah) sebanyak dua puluh delapan manzilah selama dua puluh delapan malam untuk setiap bulannya. Kemudian bersembunyi selama dua malam, jika bilangan satu bulan tiga puluh hari, dan satu malam jika bilangan satu bulan dua puluh sembilan hari (sehingga kembalilah ia) setelah sampai ke manzilah yang terakhir, menurut pandangan mata (sebagai bentuk tandan yang tua) bila sudah lanjut masanya bagaikan ketandan, lalu menipis, berbentuk sabit dan berwarna kuning.\qt@no{39}}%
\qt@newcmd\qurantrans@id@mmmdccxlv{%
(Tidaklah mungkin bagi matahari) tidak akan terjadi (mendapatkan bulan) yaitu matahari dan bulan bersatu di malam hari (dan malam pun tidak dapat mendahului siang) malam hari tidak akan datang sebelum habis waktu siang hari. (Dan masing-masing) matahari, bulan dan bintang-bintang. Tanwin lafal Kullun ini merupakan pergantian dari Mudhaf Ilaih (pada garis edarnya) yang membundar (beredar) pada garis edarnya masing-masing. Di dalam ungkapan ini benda-benda langit diserupakan sebagai makhluk yang berakal, karenanya mereka diungkapkan dengan lafal Yasbahuuna.\qt@no{40}}%
\qt@newcmd\qurantrans@id@mmmdccxlvi{%
(Dan suatu tanda bagi mereka) yang menunjukkan kekuasaan Kami (adalah bahwa Kami angkut keturunan mereka) menurut qiraat yang lain lafal Dzurriyyatahum dibaca dalam bentuk jamak sehingga bacaannya menjadi Dzurriyyaatihim, maksudnya ialah kakek moyang mereka (dalam bahtera) yakni perahu Nabi Nuh (yang penuh muatan) dipadati penumpang.\qt@no{41}}%
\qt@newcmd\qurantrans@id@mmmdccxlvii{%
(Dan Kami ciptakan untuk mereka seperti bahtera itu) seperti perahu Nabi Nuh, perahu kecil dan besar yang dibuat oleh mereka sesudahnya, bentuknya sama dengan perahu Nabi Nuh. Ini berkat apa yang telah Allah swt. ajarkan kepada Nabi Nuh (yang akan mereka kendarai) mereka berlayar dengannya.\qt@no{42}}%
\qt@newcmd\qurantrans@id@mmmdccxlviii{%
(Dan jika Kami menghendaki niscaya Kami tenggelamkan mereka) sekalipun memakai perahu (maka tiadalah penolong) yakni penyelamat (bagi mereka dan tidak -pula- mereka diselamatkan) ditolong sehingga selamat.\qt@no{43}}%
\qt@newcmd\qurantrans@id@mmmdccxlix{%
(Tetapi -Kami selamatkan mereka- karena rahmat yang besar dari Kami dan untuk memberikan kesenangan hidup sampai kepada suatu ketika) tiada yang menyelamatkan mereka melainkan rahmat Kami kepada mereka; dan karena Kami hendak memberikan kesenangan hidup kepada mereka sampai batas ajal mereka.\qt@no{44}}%
\qt@newcmd\qurantrans@id@mmmdccl{%
(Dan apabila dikatakan kepada mereka, ``Takutlah kalian akan siksa yang di hadapan kalian) berupa azab di dunia sebagaimana apa yang telah menimpa orang-orang selain mereka (dan siksa yang akan datang) yaitu azab di akhirat (supaya kalian mendapat rahmat") tetapi mereka tetap berpaling.\qt@no{45}}%
\qt@newcmd\qurantrans@id@mmmdccli{%
(Dan sekali-kali tiada datang kepada mereka suatu tanda dari tanda-tanda kekuasaan Rabb mereka melainkan mereka selalu berpaling daripadanya.)\qt@no{46}}%
\qt@newcmd\qurantrans@id@mmmdcclii{%
(Dan apabila dikatakan) berkata sahabat-sahabat yang miskin (kepada mereka, ``Nafkahkanlah) sedekahkanlah kepada kami (sebagian dari rezeki yang diberikan Allah kepada kalian") berupa harta benda (maka orang-orang yang kafir itu berkata kepada orang-orang yang beriman,) dengan nada yang sinis sebagai ejekan yang ditujukan kepada mereka, ("Apakah kami akan memberi makanan kepada orang-orang yang jika Allah menghendaki tentulah Dia akan memberinya makan) sesuai dengan keyakinan kalian itu. (Tiada lain kalian) yaitu apa yang kalian katakan kepada kami, padahal kalian mempunyai keyakinan bahwa Allah pasti memberi makan kalian (melainkan dalam kesesatan yang nyata") yakni jelas sesatnya. Ditegaskannya lafal Al Ladziina Kafaruu mengandung arti yang mendalam.\qt@no{47}}%
\qt@newcmd\qurantrans@id@mmmdccliii{%
(Dan mereka berkata, ``Bilakah terjadinya janji ini?) yakni hari berbangkit (jika kalian orang-orang yang benar?") mengenai apa yang kalian katakan.\qt@no{48}}%
\qt@newcmd\qurantrans@id@mmmdccliv{%
Allah berfirman, ("Mereka tidak menunggu) menanti-nanti (melainkan satu teriakan saja), yaitu tiupan malaikat Israfil yang pertama (yang akan membinasakan mereka ketika mereka sedang bertengkar") lafal Yakhishshimuuna pada asalnya adalah Yakhtashimuuna, kemudian harakat Ta dipindahkan kepada Kha, lalu Ta diidgamkan kepada Shad. Maksudnya, mereka dalam keadaan lalai dari kedatangan hari kiamat, disebabkan mereka sibuk dalam pertengkaran mereka, jual beli yang mereka lakukan, makan, dan minum serta kesibukan-kesibukan lainnya. Menurut qiraat yang lain lafal Yakhishshimuuna mempunyai Wazan sama dengan lafal Yadhribuuna, artinya sebagian dari mereka bertengkar dengan sebagian yang lain.\qt@no{49}}%
\qt@newcmd\qurantrans@id@mmmdcclv{%
(Lalu mereka tidak kuasa membuat suatu wasiat pun) tidak dapat berwasiat (dan tidak pula dapat kembali kepada keluarganya) dari pasar dan dari tempat-tempat kesibukan mereka, semuanya mati di tempatnya masing-masing.\qt@no{50}}%
\qt@newcmd\qurantrans@id@mmmdcclvi{%
(Dan ditiuplah sangkakala) yaitu tiupan yang kedua untuk membangkitkan makhluk supaya hidup kembali; jarak antara dua tiupan, yakni tiupan pertama dengan tiupan kedua lamanya empat puluh tahun (maka tiba-tiba mereka) orang-orang yang telah terkubur itu (dari kuburnya) dari tempat mereka dikubur (Keluar dengan segera menuju kepada Rabb mereka) mereka keluar dengan cepat lalu menuju kepada-Nya.\qt@no{51}}%
\qt@newcmd\qurantrans@id@mmmdcclvii{%
(Mereka berkata) orang-orang kafir di antara manusia, ("Aduhai!) Ya di sini menunjukkan makna Tanbih (celakalah kami) binasalah kami lafal Wailun adalah Mashdar yang tidak mempunyai Fi'il dari lafalnya. (Siapakah yang membangkitkan kami dari tempat tidur kami -kubur-?") karena mereka seolah-olah dalam keadaan tidur di antara kedua tiupan itu, maksudnya mereka tidak diazab. (Inilah) kebangkitan ini (yang) telah (dijanjikan yang Maha Pemurah dan benarlah) mengenainya (Rasul-rasul-Nya) mereka mengakui atas kebenaran yang telah dikatakan oleh para rasul, tetapi pengakuan mereka tidak bermanfaat lagi. Menurut pendapat yang lain, bahwa kalimat tersebut dikatakan kepada mereka.\qt@no{52}}%
\qt@newcmd\qurantrans@id@mmmdcclviii{%
(Tiadalah teriakan itu selain sekali teriakan saja, tiba-tiba mereka semua kepada Kami) di hadapan Kami (dikumpulkan.)\qt@no{53}}%
\qt@newcmd\qurantrans@id@mmmdcclix{%
(Pada hari itu seseorang tidak akan dirugikan sedikit pun dan kalian tidak dibalasi, kecuali) dengan balasan (apa yang telah kalian kerjakan.)\qt@no{54}}%
\qt@newcmd\qurantrans@id@mmmdcclx{%
(Sesungguhnya penghuni surga pada hari itu dalam kesibukan) mereka tidak menghiraukan lagi apa yang dialami oleh ahli neraka, karena mereka sibuk dengan kenikmatan-kenikmatan yang sedang mereka rasakan, seperti memecahkan selaput dara bidadari-bidadari; mereka tidak mempunyai kesibukan yang membuat mereka lelah atau payah, karena di dalam surga tidak ada kelelahan. Lafal Syughulin dapat pula dibaca Syughlin (bersenang-senang) yakni bergelimangan di dalam kenikmatan. Lafal Faakihuuna menjadi Khabar kedua dari Inna, sedangkan Khabar yang pertama adalah Fii Syughulin.\qt@no{55}}%
\qt@newcmd\qurantrans@id@mmmdcclxi{%
(Mereka) lafal Hum menjadi Mubtada (dan istri-istri mereka berada dalam tempat yang teduh) lafal Zhilaalun ini adalah bentuk jamak dari lafal Zhillun atau Zhillatun; menjadi Khabar Mubtada; arti Zhillun adalah tidak terkena panas matahari maksudnya teduh. (Di atas dipan-dipan) lafal Araa-iki adalah bentuk jamak dari lafal Ariikah, adalah ranjang atau permadani yang tebal (mereka bersandaran) bertelekan di atas dipan-dipan; lafal ayat ini menjadi Khabar kedua dan menjadi tempat berta'alluqnya Alal Araaa-iki.\qt@no{56}}%
\qt@newcmd\qurantrans@id@mmmdcclxii{%
(Di surga itu mereka memperoleh buah-buahan dan mereka memperoleh pula) di dalamnya (apa yang mereka minta) apa yang mereka dambakan.\qt@no{57}}%
\qt@newcmd\qurantrans@id@mmmdcclxiii{%
(Kepada mereka dikatakan, ``Salaam") kedudukan kalimat ini menjadi Mubtada (sebagai ucapan selamat) yang menjadi Khabarnya ialah (dari Rabb Yang Maha Penyayang) kepada mereka, yakni Dia mengucapkan kepada mereka, ``Kesejahteraan atas kalian."\qt@no{58}}%
\qt@newcmd\qurantrans@id@mmmdcclxiv{%
(Dan) Dia berfirman pula, ("Berpisahlah kalian dan orang-orang mukmin pada hari ini hai orang-orang yang berbuat jahat) mereka diperintahkan supaya berpisah di kala mereka bercampur dengan orang-orang mukmin.\qt@no{59}}%
\qt@newcmd\qurantrans@id@mmmdcclxv{%
(Bukankah Aku telah memerintahkan kepada kalian hai Bani Adam) melalui lisan Rasul-rasul-Ku (supaya kalian tidak menyembah setan) jangan menaatinya. (Sesungguhnya setan itu adalah musuh yang nyata bagi kalian") yakni jelas permusuhannya.\qt@no{60}}%
\qt@newcmd\qurantrans@id@mmmdcclxvi{%
(Dan hendaklah kalian menyembah-Ku) yakni esakanlah Aku dan taatilah Aku. (Inilah jalan) maksudnya tuntunan (yang lurus.)\qt@no{61}}%
\qt@newcmd\qurantrans@id@mmmdcclxvii{%
(Sesungguhnya setan itu telah menyesatkan sebagian besar di antara kalian) lafal Jibillan adalah bentuk jamak dari Jabiilun seperti wazan Qadiimun, artinya makhluk. Menurut qiraat yang lain dibaca Jibullan dengan harakat Dhammah pada huruf Ba. (Maka apakah kalian tidak memikirkan?) tentang permusuhan setan dan penyesatannya; atau azab yang bakal menimpa mereka, yang karenanya mereka lalu mau beriman. Dikatakan kepada mereka di akhirat nanti:\qt@no{62}}%
\qt@newcmd\qurantrans@id@mmmdcclxviii{%
(Inilah Jahanam yang kalian dahulu diancam) dengannya.\qt@no{63}}%
\qt@newcmd\qurantrans@id@mmmdcclxix{%
(Masuklah ke dalamnya pada hari ini disebabkan kalian dahulu mengingkarinya.)\qt@no{64}}%
\qt@newcmd\qurantrans@id@mmmdcclxx{%
(Pada hari ini Kami tutup mulut mereka) mulut orang-orang kafir, karena mereka mengatakan, yaitu sebagaimana yang disitir oleh firman-Nya, ``Demi Allah, Rabb kami, tiadalah kami mempersekutukan Allah." (Q.S. 6 Al An'am, 23) (Dan berkatalah kepada Kami tangan mereka dan kaki mereka memberi kesaksian) juga anggota-anggota mereka lainnya (terhadap apa yang dahulu mereka kerjakan) setiap anggota tubuh mengucapkan apa yang telah diperbuatnya.\qt@no{65}}%
\qt@newcmd\qurantrans@id@mmmdcclxxi{%
(Dan jika Kami menghendaki pastilah Kami hapuskan penglihatan mereka) Kami jadikan penglihatan mereka buta sama sekali (lalu mereka berlomba-lomba) bersegera (-mencari- jalan) untuk pergi sebagaimana kebiasaan mereka. (Maka betapakah) bagaimanakah (mereka dapat melihat) jalan itu, jika mereka dalam keadaan buta? Yakni mereka pasti tidak akan dapat melihat jalan itu.\qt@no{66}}%
\qt@newcmd\qurantrans@id@mmmdcclxxii{%
(Dan jika Kami menghendaki pastilah Kami ubah mereka) diubah menjadi kera, babi atau batu (di tempat mereka berada) menurut qiraat yang lain lafal Makanatihim dibaca dalam bentuk jamak, yaitu Makaanaatihim, yaitu di tempat-tempat mereka (maka mereka tidak sanggup berjalan dan tidak pula sanggup kembali) yakni mereka tidak dapat pergi dan tidak dapat pulang kembali.\qt@no{67}}%
\qt@newcmd\qurantrans@id@mmmdcclxxiii{%
(Dan barang siapa yang Kami panjangkan umurnya) yaitu diperpanjang ajalnya (niscaya dia Kami kembalikan) menurut qiraat yang lain tidak dibaca Nunakkis-hu melainkan Nunkis-hu yang berasal dari Mashdar At-Tankiis, yakni mengembalikannya (kepada kejadiannya) sehingga setelah ia kuat dan muda lalu menjadi tua dan lemah kembali. (Maka apakah mereka tidak memikirkan?) bahwasanya Dzat Yang Maha Kuasa memperbuat demikian, berkuasa pula untuk membangkitkan hidup kembali, oleh karenanya mereka lalu mau beriman kepada-Nya. Menurut qiraat yang lain lafal Ya'qiluuna dibaca Ta'qiluuna dengan memakai huruf Ta.\qt@no{68}}%
\qt@newcmd\qurantrans@id@mmmdcclxxiv{%
(Dan Kami tidak mengajarkan kepadanya) yakni kepada Nabi saw. (tentang syair) ayat ini diturunkan sebagai sanggahan terhadap perkataan orang-orang kafir, karena mereka telah mengatakan, bahwa sesungguhnya Alquran yang didatangkan olehnya adalah syair (dan bersyair itu tidak layak) tidak mudah (baginya.) (Alquran itu tiada lain) apa yang diturunkan kepadanya, tiada lain (hanyalah pelajaran) nasihat (dan Kitab yang memberi penerangan) yang menjelaskan tentang hukum-hukum dan lain-lainnya.\qt@no{69}}%
\qt@newcmd\qurantrans@id@mmmdcclxxv{%
(Supaya dia memberi peringatan) dengan Alquran itu; lafal Liyundzira dapat pula dibaca Litundzira artinya supaya kamu memberi peringatan dengan Alquran itu (kepada orang-orang yang hidup) hatinya, maksudnya tanggap terhadap apa-apa yang dinasihatkan kepada mereka; mereka adalah orang-orang mukmin (dan supaya pastilah ketetapan) azab (terhadap orang-orang kafir) mereka diserupakan orang mati, karena mereka tidak tanggap terhadap apa-apa yang dinasihatkan kepada mereka.\qt@no{70}}%
\qt@newcmd\qurantrans@id@mmmdcclxxvi{%
(Dan apakah mereka tidak melihat) tidak memperhatikan, Istifham di sini mengandung makna Taqrir dan huruf Wau yang masuk kepadanya merupakan huruf 'Athaf (bahwa Kami telah menciptakan untuk mereka) ini ditujukan kepada segolongan manusia (dari apa yang telah Kami ciptakan dengan kekuasaan Kami) dari hasil ciptaan Kami tanpa sekutu dan tanpa pembantu (yaitu berupa binatang ternak) unta, sapi, dan kambing lalu mereka menguasainya?) dapat memeliharanya.\qt@no{71}}%
\qt@newcmd\qurantrans@id@mmmdcclxxvii{%
(Dan Kami tundukkan binatang-binatang itu) Kami jadikan mereka tunduk (untuk mereka; maka sebagiannya menjadi tunggangan mereka) menjadi kendaraan mereka (dan sebagiannya mereka makan.)\qt@no{72}}%
\qt@newcmd\qurantrans@id@mmmdcclxxviii{%
(Dan mereka memperoleh padanya manfaat-manfaat) yakni dari bulu unta, kambing, dan dombanya (dan minuman) dari air susunya, lafal Masyaarib adalah bentuk jamak dari lafal Masyrab yang bermakna Asy-Syurb atau minuman, makna yang dimaksud adalah tempat minum. (Maka mengapakah mereka tidak bersyukur?) kepada Allah Yang telah melimpahkan nikmat-nikmat itu kepada mereka, lalu karenanya mereka mau beriman. Makna yang dimaksud ialah mereka tidak mensyukurinya.\qt@no{73}}%
\qt@newcmd\qurantrans@id@mmmdcclxxix{%
(Mereka mengambil selain Allah) selain-Nya (sebagai sesembahan-sesembahan) berhala-berhala yang mereka sembah (agar mereka mendapat pertolongan) terhindar dari azab Allah, karena mendapat syafaat dari tuhan-tuhan sesembahan mereka itu, ini menurut dugaan mereka sendiri.\qt@no{74}}%
\qt@newcmd\qurantrans@id@mmmdcclxxx{%
(Berhala-berhala itu tidak akan dapat) yakni sesembahan-sesembahan mereka itu tidak dapat menolong. Ungkapan kata berhala memakai jamak untuk orang yang berakal hanyalah sebagai kata kiasan saja, yakni mereka dianggap sebagai makhluk yang berakal (menolong mereka padahal berhala-berhala itu) sesembahan-sesembahan mereka itu (menjadi tentara mereka) menurut dugaan mereka, yaitu tentara yang siap menolong mereka (yang disiapkan) di dalam neraka bersama mereka.\qt@no{75}}%
\qt@newcmd\qurantrans@id@mmmdcclxxxi{%
(Maka janganlah ucapan mereka menyedihkan kamu) seperti ucapan, bahwa kamu bukanlah seseorang yang diutus oleh Allah dan ucapan-ucapan lainnya. (Sesungguhnya Kami mengetahui apa yang mereka rahasiakan dan apa yang mereka nyatakan) dari perkataan-perkataan semacam itu dan yang lainnya, kelak Kami akan membalasnya kepada mereka.\qt@no{76}}%
\qt@newcmd\qurantrans@id@mmmdcclxxxii{%
(Apakah manusia tidak memperhatikan) apakah ia tidak mengetahui, orang yang dimaksud adalah Ashi bin Wail (bahwa Kami menciptakannya dari setitik air) yakni air mani, hingga Kami jadikan ia besar dan kuat (maka tiba-tiba ia menjadi penentang) yakni sangat memusuhi Kami (yang nyata) jelas menentangnya, tidak mau percaya kepada adanya hari berbangkit.\qt@no{77}}%
\qt@newcmd\qurantrans@id@mmmdcclxxxiii{%
(Dia membuat perumpamaan bagi Kami) mengenai hal tersebut (dan dia lupa kepada kejadiannya) berasal dari air mani, dan terlebih lagi ia lupa kepada hal-hal yang selain itu (ia berkata, ``Siapakah yang dapat menghidupkan tulang-belulang yang telah hancur luluh?") hancur berantakan, di dalam ungkapan ini tidak dikatakan Ramiimatun, karena isim bukan sifat. Menurut suatu riwayat dikisahkan bahwa Ashi bin Wail mengambil sebuah tulang yang telah hancur, kemudian ia cerai-beraikan tulang itu di hadapan Nabi saw. seraya berkata, ``Apakah kamu berpendapat, bahwa Allah nanti akan menghidupkan kembali tulang ini sesudah hancur luluh dan berantakan ini?" Maka Nabi saw. menjawab, ``Ya, Dia akan memasukkanmu ke neraka."\qt@no{78}}%
\qt@newcmd\qurantrans@id@mmmdcclxxxiv{%
(Katakanlah! ``Ia akan dihidupkan oleh Tuhan yang menciptakannya yang pertama kali. Dan Dia tentang segala makhluk) semua yang diciptakan-Nya (Maha Mengetahui) secara global dan rinci, baik sebelum mereka diciptakan maupun sesudahnya.\qt@no{79}}%
\qt@newcmd\qurantrans@id@mmmdcclxxxv{%
(Yaitu Tuhan yang menjadikan untuk kalian) yakni segolongan umat manusia (dari kayu yang hijau) yakni kayu pohon Marakh dan Affar atau semua jenis pohon selain pohon anggur (api, maka tiba-tiba kalian nyalakan -api- dari kayu itu.") kalian membuat api daripadanya. Hal ini menunjukkan kekuasaan Allah swt. yang mampu untuk menghidupkan kembali manusia yang mati. Karena sesungguhnya di dalam kayu yang hijau itu terhimpun antara air, api, dan kayu; maka air tidak dapat memadamkan api, dan pula api tidak dapat membakar kayu.\qt@no{80}}%
\qt@newcmd\qurantrans@id@mmmdcclxxxvi{%
(Dan tidakkah Tuhan yang menciptakan langit dan bumi itu) padahal langit dan bumi itu sangat besar (berkuasa menciptakan yang serupa dengan itu) yaitu manusia yang kecil bentuknya itu. (Benar) Dia berkuasa untuk menciptakannya, di sini Allah swt. menjawab diri-Nya sendiri. (Dan Dialah Maha Pencipta) banyak ciptaan-Nya (lagi Maha Mengetahui) segala sesuatu.\qt@no{81}}%
\qt@newcmd\qurantrans@id@mmmdcclxxxvii{%
(Sesungguhnya perkara-Nya) keadaan-Nya (apabila Dia menghendaki sesuatu) yakni berkehendak menciptakan sesuatu (hanyalah berkata kepadanya, ``Jadilah," maka terjadilah ia) berujudlah sesuatu itu. Menurut qiraat yang lain lafal Fayakuunu dibaca Fayakuna karena diathafkan kepada lafal Yaquula.\qt@no{82}}%
\qt@newcmd\qurantrans@id@mmmdcclxxxviii{%
(Maka Maha Suci Allah Yang dalam genggaman-Nya kekuasaan) lafal Malakuutu pada asalnya adalah Mulki kemudian ditambahkan huruf Wawu dan Ta untuk menunjukkan makna mubalaghah, artinya kekuasaan atas (segala sesuatu dan kepada-Nyalah kalian dikembalikan) kelak di akhirat.\qt@no{83}}%
\qt@newcmd\qurantrans@id@mmmdcclxxxix{%
\basmalahid (Demi yang bersaf-saf dengan sebenar-benarnya) yaitu para malaikat yang berbaris membentuk saf-saf dalam menyembah Allah, atau para malaikat yang sayap-sayapnya bersaf-saf membentuk barisan di udara sambil menunggu apa yang diperintahkan kepada mereka.\qt@no{1}}%
\qt@newcmd\qurantrans@id@mmmdccxc{%
(Dan demi rombongan yang menggiring dengan sebenar-benarnya) demi para malaikat yang menggiring atau mengarak awan.\qt@no{2}}%
\qt@newcmd\qurantrans@id@mmmdccxci{%
(Dan demi rombongan yang membacakan) maksudnya para pembaca Alquran yang sedang membacakannya sebagai (peringatan) lafal Dzikran menjadi Mashdar dari makna Fi'il At-Taaliyaat. Maksudnya, demi para qari yang membacakan peringatan atau Alquran.\qt@no{3}}%
\qt@newcmd\qurantrans@id@mmmdccxcii{%
(Sesungguhnya Tuhan kalian) hai penduduk Mekah (benar-benar Esa.)\qt@no{4}}%
\qt@newcmd\qurantrans@id@mmmdccxciii{%
(Tuhan langit dan bumi dan apa yang berada di antara keduanya dan Tuhan tempat-tempat terbit matahari) dan tempat-tempat terbenamnya pada setiap harinya, yaitu arah Timur dan arah Barat.\qt@no{5}}%
\qt@newcmd\qurantrans@id@mmmdccxciv{%
(Sesungguhnya Kami telah menghias langit yang terdekat dengan hiasan, yaitu bintang-bintang) dengan cahayanya, atau hiasan itu berupa bintang-bintang itu sendiri. Pengertian Idhafah di sini mengandung makna bayan atau menjelaskan, perihalnya sama dengan makna qiraat yang menanwinkannya.\qt@no{6}}%
\qt@newcmd\qurantrans@id@mmmdccxcv{%
(Dan sebagai pemelihara) lafal Hifzhan dinashabkan oleh Fi'il yang diperkirakan keberadaannya pada sebelumnya, yakni Kami memelihara langit dengan bintang-bintang atau meteor-meteor (dari setiap) lafal ayat ini berta'alluq kepada Fi'il yang diperkirakan keberadaannya (setan yang durhaka) setan yang membangkang atau tidak mau taat.\qt@no{7}}%
\qt@newcmd\qurantrans@id@mmmdccxcvi{%
(Mereka tidak dapat mendengar-dengarkan) maksudnya setan-setan itu tidak dapat mendengar-dengarkan apa yang telah dipelihara oleh-Nya. Lafal ayat ini merupakan jumlah Isti'naf (pembicaraan para malaikat) yang berada di langit. Lafal Yasma'uuna dimuta'addikan dengan huruf Ilaa karena pengertiannya mengandung makna seperti apa yang terdapat di dalam lafal Al-Ishghaa. Menurut suatu qiraat dibaca La Yassamma'uuna dengan memakai Tasydid pada huruf Mim dan Sin-nya, berasal dari lafal Yatasamma'uuna, kemudian huruf Ta diidgamkan kepada huruf Sin, sehingga jadilah Yassamma'uuna (Dan mereka dilempari) yakni setan-setan itu dengan meteor-meteor (dari segala penjuru) langit.\qt@no{8}}%
\qt@newcmd\qurantrans@id@mmmdccxcvii{%
(Untuk mengusir mereka) lafal Duhuuran bentuk Mashdar dari lafal Daharahu, artinya dia mengusir mereka dan menjauhkan mereka, juga menjadi Maf'ul Lah (dan bagi mereka) di akhirat kelak (azab yang kekal) yang abadi.\qt@no{9}}%
\qt@newcmd\qurantrans@id@mmmdccxcviii{%
(Terkecuali setan yang mencuri-curi -pembicaraan malaikat- dengan sekali curi) lafal Al-Khathfah adalah Mashdar Marrah dan yang diistitsnakan atau yang dikecualikan adalah dhamir yang terkandung di dalam lafal Laa Yasma'uuna. Maksudnya, tiada yang dapat mendengarkan pembicaraan para malaikat kecuali hanya setan yang dapat mencuri-curinya dengan cepat (maka ia dikejar oleh meteor) yakni bintang yang bercahaya (yang melubanginya) yang menembus tubuh setan-setan itu, atau membakarnya, atau membuatnya cacat.\qt@no{10}}%
\qt@newcmd\qurantrans@id@mmmdccxcix{%
(Maka tanyakanlah kepada mereka) kepada orang-orang kafir Mekah, kalimat ayat ini mengandung makna Taqrir atau Taubikh, yakni mengandung nada menetapkan atau celaan, ("Apakah mereka yang lebih kukuh kejadiannya ataukah yang telah Kami ciptakan itu?") yakni para malaikat, langit, bumi dan semua apa yang ada di antara keduanya. Didatangkannya lafal Man mengandung pengertian memprioritaskan makhluk yang berakal. (Sesungguhnya Kami telah menciptakan mereka) asal mereka, yaitu Nabi Adam (dan tanah liat) tanah yang melekat di tangan bilamana dipegang. Maksudnya, kejadian mereka adalah dari sesuatu yang lemah, karena itu janganlah mereka bersikap takabur dan sombong, yakni mengingkari Nabi saw. dan Alquran, yang hal ini dengan mudah dapat mengakibatkan mereka terjerumus ke dalam jurang kebinasaan.\qt@no{11}}%
\qt@newcmd\qurantrans@id@mmmdccc{%
(Bahkan) lafal Bal di sini menunjukkan arti Intiqal, yakni perpindahan dari suatu topik pembicaraan kepada pembicaraan yang lain, yaitu pembahasan mengenai keadaan Nabi Muhammad dan orang-orang kafir Mekah (kamu heran) pembicaraan ayat ini ditujukan kepada Nabi saw. yakni kamu heran akan keingkaran mereka terhadapmu (dan) mereka (menghinakan kamu) karena keherananmu itu.\qt@no{12}}%
\qt@newcmd\qurantrans@id@mmmdccci{%
(Dan apabila mereka diberi pelajaran) maksudnya, dinasihati dengan ayat-ayat Alquran (mereka tiada mengingatinya) mereka tidak menjadikannya sebagai pelajaran.\qt@no{13}}%
\qt@newcmd\qurantrans@id@mmmdcccii{%
(Dan apabila mereka melihat sesuatu tanda kebesaran Allah) seperti terbelahnya bulan (mereka sangat menghinakan) mereka menghina dan mengejeknya.\qt@no{14}}%
\qt@newcmd\qurantrans@id@mmmdccciii{%
(Dan mereka berkata) sehubungan dengan adanya tanda kebesaran Allah itu, ("Tiada lain) tidak lain (ini hanyalah sihir yang nyata") jelas sihirnya. Kemudian mereka berkata seraya mengingkari adanya hari berbangkit:\qt@no{15}}%
\qt@newcmd\qurantrans@id@mmmdccciv{%
(Apakah apabila kami telah mati dan telah menjadi tanah serta menjadi tulang-belulang, apakah benar-benar kami akan dibangkitkan?) lafal A-idzaa dan A-innaa dapat pula dibaca Tas-hil, sehingga bacaannya menjadi Ayidzaa dan Ayinnaa.\qt@no{16}}%
\qt@newcmd\qurantrans@id@mmmdcccv{%
(Dan apakah bapak-bapak kami yang telah dahulu) kalau dibaca Au berarti huruf 'Athaf, jika dibaca Awa, berarti huruf Istifham, Wawu-nya adalah huruf 'Athaf, sedangkan Ma'thuf 'Alaihnya adalah Inna dan Isimnya secara Mahall, atau di'athafkan kepada Dhamir yang terkandung di dalam lafal Lamab'uutsuuna, Hamzah Istifham sebagai pemisahnya. Maksudnya, apakah bapak-bapak kami yang telah dahulu akan dibangkitkan pula?\qt@no{17}}%
\qt@newcmd\qurantrans@id@mmmdcccvi{%
(Katakanlah kepada mereka, ``Ya) mereka pasti dibangkitkan hidup kembali (dan kalian akan terhina") kalian akan menjadi orang-orang yang terhina karenanya.\qt@no{18}}%
\qt@newcmd\qurantrans@id@mmmdcccvii{%
(Maka sesungguhnya kebangkitan itu hanyalah dengan) dhamir pada ayat ini bersifat Mubham, kurang jelas, lalu ditafsirkan oleh ayat selanjutnya (suatu teriakan) atau satu hardikan saja (maka tiba-tiba mereka) yakni makhluk semuanya, menjadi hidup kembali seraya (melihat) apa yang dilakukan terhadap diri mereka.\qt@no{19}}%
\qt@newcmd\qurantrans@id@mmmdcccviii{%
(Dan mereka berkata) yakni orang-orang kafir, ("Aduhai!) lafal Ya di sini menunjukkan makna Tanbih (celakalah kita") binasalah kita. Lafal Al-Wail merupakan bentuk Mashdar yang tidak mempunyai kata kerja dari lafalnya sendiri. Kemudian para malaikat berkata kepada orang-orang kafir itu. (Inilah hari pembalasan) hari penghisaban amal perbuatan dan pembalasannya.\qt@no{20}}%
\qt@newcmd\qurantrans@id@mmmdcccix{%
(Inilah hari keputusan) di antara para makhluk semuanya (yang kalian selalu mendustakannya.)\qt@no{21}}%
\qt@newcmd\qurantrans@id@mmmdcccx{%
Kemudian diperintahkan kepada para malaikat itu, ("Kumpulkanlah orang-rang yang zalim) yaitu orang-orang yang berbuat aniaya terhadap diri mereka sendiri karena mereka telah berbuat kemusyrikan (beserta teman sejawat mereka) teman-teman karib mereka, yaitu setan-setan (dan sesembahan-sesembahan yang selalu mereka sembah.)\qt@no{22}}%
\qt@newcmd\qurantrans@id@mmmdcccxi{%
(Selain Allah) yaitu berhala-berhala (maka tunjukkanlah kepada mereka) dan giringlah mereka (ke jalan jahim) atau jalan ke neraka.\qt@no{23}}%
\qt@newcmd\qurantrans@id@mmmdcccxii{%
(Dan tahanlah mereka) di tempat perhentian atau Ash-Shirat (karena sesungguhnya mereka akan ditanya") mengenai semua perkataan dan perbuatan mereka.\qt@no{24}}%
\qt@newcmd\qurantrans@id@mmmdcccxiii{%
Dikatakan kepada mereka dengan nada yang mengandung penghinaan dan cemoohan, ("Kenapa kalian tidak tolong-menolong") maksudnya mengapa sebagian di antara kalian tidak menolong kepada sebagian yang lain sebagaimana keadaan kalian waktu di dunia? Dan dikatakan pula kepada mereka:\qt@no{25}}%
\qt@newcmd\qurantrans@id@mmmdcccxiv{%
("Bahkan mereka pada hari itu menyerah diri) atau mereka itu tunduk dalam keadaan penuh kehinaan.\qt@no{26}}%
\qt@newcmd\qurantrans@id@mmmdcccxv{%
(Sebagian dari mereka menghadap kepada sebagian yang lain berbantah-bantahan") saling cela-mencela dan saling bantah-membantah.\qt@no{27}}%
\qt@newcmd\qurantrans@id@mmmdcccxvi{%
(Mereka berkata) yaitu sebagian dari pengikut-pengikut mereka berkata kepada para pemimpin mereka, ("Sesungguhnya kalianlah yang datang kepada kami dari kanan") maksudnya, dari segi yang kami merasa percaya kepada kalian karena kalian telah bersumpah kepada kami, bahwa kalian adalah orang-orang yang benar, karenanya kami percaya kepada kalian, dan kami mengikuti kalian. Maksudnya sesungguhnya kalian telah menyesatkan kami.\qt@no{28}}%
\qt@newcmd\qurantrans@id@mmmdcccxvii{%
(Mereka berkata) yakni pemimpin-pemimpin yang diikuti oleh mereka ("Sebenarnya kalianlah yang tidak beriman") dan sesungguhnya tidak akan percaya penyesatan yang kami lakukan seandainya kalian adalah orang-orang yang beriman, niscaya kalian akan ingkar terhadap kami.\qt@no{29}}%
\qt@newcmd\qurantrans@id@mmmdcccxviii{%
(Dan sekali-kali kami tidak berkuasa terhadap kalian) kami tidak mempunyai kemampuan untuk memaksa kalian mengikuti kami (bahkan kalianlah kaum yang melampaui batas) maksudnya, orang-orang yang sesat seperti kami.\qt@no{30}}%
\qt@newcmd\qurantrans@id@mmmdcccxix{%
(Maka pastilah) atau tetaplah (atas kita) semua (putusan Rabb kita) yakni azab-Nya, yaitu sebagaimana yang telah diungkapkan-Nya pada ayat yang lain, ``Sesungguhnya Aku akan penuhi neraka Jahanam dengan jin dan manusia bersama-sama." (Q.S. As-Sajdah, 13). (sesungguhnya kita) semua (akan merasakan) azab dengan adanya keputusan itu, yang akhirnya membuat mereka berkata:\qt@no{31}}%
\qt@newcmd\qurantrans@id@mmmdcccxx{%
(Maka kami telah menyesatkan kalian) sebagai penjelasan dari perkataan mereka yang disitir oleh firman-Nya (sesungguhnya kami adalah orang-orang yang sesat.)\qt@no{32}}%
\qt@newcmd\qurantrans@id@mmmdcccxxi{%
Allah swt. berfirman, (Maka sesungguhnya mereka pada hari itu) pada hari kiamat (bersama-sama dalam azab) karena mereka bersekutu dalam kesesatan.\qt@no{33}}%
\qt@newcmd\qurantrans@id@mmmdcccxxii{%
(Sesungguhnya demikianlah) artinya, sebagaimana Kami memperlakukan mereka (Kami berbuat terhadap orang-orang yang jahat) selain mereka. Yakni Kami pasti akan mengazab orang yang sesat beserta pengikut-pengikutnya.\qt@no{34}}%
\qt@newcmd\qurantrans@id@mmmdcccxxiii{%
(Sesungguhnya mereka) yaitu orang-orang tersebut; dialamatkan kepada mereka karena berdasarkan penjelasan selanjutnya yaitu (dahulu apabila dikatakan kepada mereka, ``Laa Ilaaha Illallaah") Tiada Tuhan melainkan Allah, (mereka menyombongkan diri.)\qt@no{35}}%
\qt@newcmd\qurantrans@id@mmmdcccxxiv{%
(Dan mereka berkata, ``Apakah sesungguhnya kami) lafal A-innaa dapat pula dibaca Ayinnaa (harus meninggalkan sesembahan-sesembahan kami karena seorang penyair gila?") yakni demi karena Muhammad.\qt@no{36}}%
\qt@newcmd\qurantrans@id@mmmdcccxxv{%
Allah swt. berfirman: (Sebenarnya dia Muhammad telah datang membawa kebenaran dan membenarkan rasul-rasul) yang juga datang membawa kebenaran, yaitu kalimat Laa Ilaaha Illallaah/tidak ada Tuhan selain Allah.\qt@no{37}}%
\qt@newcmd\qurantrans@id@mmmdcccxxvi{%
(Sesungguhnya kalian) di dalam ungkapan ini terkandung Iltifat karena seharusnya Innahum (pasti akan merasakan azab yang pedih.)\qt@no{38}}%
\qt@newcmd\qurantrans@id@mmmdcccxxvii{%
(Dan kalian tidak diberi pembalasan melainkan) pembalasan (apa yang telah kalian kerjakan.)\qt@no{39}}%
\qt@newcmd\qurantrans@id@mmmdcccxxviii{%
(Tetapi hamba-hamba Allah yang dibersihkan) yakni hamba-hamba Allah yang beriman, Istitsna di sini bersifat Munqathi', dan pembalasannya disebutkan pada firman selanjutnya, yaitu:\qt@no{40}}%
\qt@newcmd\qurantrans@id@mmmdcccxxix{%
(Mereka itu memperoleh) di dalam surga (rezeki yang tertentu) setiap pagi dan sorenya.\qt@no{41}}%
\qt@newcmd\qurantrans@id@mmmdcccxxx{%
(Yaitu buah-buahan) menjadi Badal atau 'Athaf Bayan dari lafal Rizqun; yaitu bermacam-macam rezeki yang dimakan hanya untuk dinikmati, bukan untuk memelihara kesehatan, karena penduduk surga tidak perlu lagi memelihara kesehatan sebab mereka telah diciptakan untuk hidup abadi dan sehat selama-lamanya. (Dan mereka adalah orang-orang yang dimuliakan) dengan pahala yang berlimpah dari Allah swt.\qt@no{42}}%
\qt@newcmd\qurantrans@id@mmmdcccxxxi{%
(Di dalam surga-surga yang penuh nikmat.)\qt@no{43}}%
\qt@newcmd\qurantrans@id@mmmdcccxxxii{%
(Di atas takhta-takhta kebesaran berhadap-hadapan) artinya, sebagian dari mereka duduk menghadap kepada sebagian yang lain, sehingga sebagian dari mereka tidak melihat tengkuk sebagian yang lainnya.\qt@no{44}}%
\qt@newcmd\qurantrans@id@mmmdcccxxxiii{%
(Diedarkan kepada mereka) maksudnya, kepada masing-masing di antara mereka diedarkan (gelas) yaitu tempat untuk minum berikut minumannya (yang berisikan khamar dari sungai khamar) yang mengalir bagaikan sungai di bumi.\qt@no{45}}%
\qt@newcmd\qurantrans@id@mmmdcccxxxiv{%
(Warnanya putih) lebih putih daripada air susu (sedap rasanya) sangat lezat rasanya (bagi orang-orang yang minum) berbeda dengan khamar di dunia yang apabila diminum rasanya tidak enak.\qt@no{46}}%
\qt@newcmd\qurantrans@id@mmmdcccxxxv{%
(Tidak ada di dalam khamar itu alkohol) yakni zat yang membuat akal mereka mabuk (dan mereka tiada mabuk karenanya) dapat dibaca Yunzafuuna atau yanzifuuna, yang berasal dari kalimat, Nazafasy Syaaribu, dan Anzafa, artinya memabukkan; maksudnya khamar surga itu tidak memabukkan berbeda halnya dengan khamar di dunia.\qt@no{47}}%
\qt@newcmd\qurantrans@id@mmmdcccxxxvi{%
(Di sisi mereka ada bidadari-bidadari yang tidak liar pandangannya) yaitu bidadari-bidadari yang selalu menundukkan pandangan matanya, atau dengan kata lain mereka hanya memandang suami-suami mereka saja dan tidak memandang orang lain, karena menurut mereka suami-suami mereka adalah orang-orang yang paling cakap (dan jelita matanya) artinya mata bidadari-bidadari itu sangat jelita.\qt@no{48}}%
\qt@newcmd\qurantrans@id@mmmdcccxxxvii{%
(Seakan-akan mereka) yakni warna kulit mereka (adalah telur) burung unta (yang tersimpan dengan baik) bagaikan telur burung unta yang terlindungi oleh bulu induknya, sehingga tidak ada suatu debu pun yang menempel padanya, demikian pula warnanya, putih kekuning-kuningan, warna kulit seperti itu adalah warna kulit wanita yang paling cantik.\qt@no{49}}%
\qt@newcmd\qurantrans@id@mmmdcccxxxviii{%
(Lalu sebagian mereka menghadap) yakni sebagian penduduk surga (kepada sebagian yang lain sambil bercakap-cakap) mengenai apa yang telah mereka lakukan di dunia.\qt@no{50}}%
\qt@newcmd\qurantrans@id@mmmdcccxxxix{%
(Berkatalah salah seorang di antara mereka, ``Sesungguhnya aku dahulu di dunia mempunyai seorang teman) yakni teman yang ingkar kepada adanya hari berbangkit.\qt@no{51}}%
\qt@newcmd\qurantrans@id@mmmdcccxl{%
(Yang berkata,) kepadaku dengan nada yang mengejek, ('Apakah kamu sungguh-sungguh termasuk orang-orang yang membenarkan) adanya hari berbangkit?\qt@no{52}}%
\qt@newcmd\qurantrans@id@mmmdcccxli{%
(Apakah apabila kita telah mati dan kita telah menjadi tanah dan tulang-belulang, apakah sesungguhnya kita) kedua huruf Hamzah pada ketiga tempat yang disebutkan di atas, yaitu A-innaka, A-idzaa dan A-innaa boleh dibaca Tahqiq dan boleh pula dibaca Tas-hil (benar-benar akan dibangkitkan untuk diberi pembalasan?') maksudnya akan dibalas dan dihisab? Ia ternyata ingkar kepada hal tersebut.\qt@no{53}}%
\qt@newcmd\qurantrans@id@mmmdcccxlii{%
(Berkata pulalah ia) yaitu penghuni surga yang mengatakan demikian kepada temannya ('Maukah kamu melihat keadaan temanku itu?'") maksudnya bersama-sama untuk melihat apa yang dialami temannya di dalam neraka? Temannya menjawab, ``Tidak mau."\qt@no{54}}%
\qt@newcmd\qurantrans@id@mmmdcccxliii{%
(Maka ia meninjaunya) yakni orang yang mengatakan demikian itu dari sebagian jendela surga (lalu ia melihat temannya itu) yaitu temannya yang ingkar kepada adanya hari berbangkit itu (di tengah-tengah neraka menyala-nyala) berada di tengah-tengah neraka Jahim.\qt@no{55}}%
\qt@newcmd\qurantrans@id@mmmdcccxliv{%
(Ia berkata pula) dengan nada mengejek, ("Demi Allah, sesungguhnya) lafal In di sini adalah bentuk Takhfif dari Inna (kamu benar-benar hampir) kamu hampir saja (mencelakakanku) membinasakan aku melalui penyesatanmu itu.\qt@no{56}}%
\qt@newcmd\qurantrans@id@mmmdcccxlv{%
(Jika tidak karena nikmat Rabbku) atas diriku yaitu berupa iman (pastilah aku termasuk orang-orang yang diseret) bersamamu ke dalam neraka. Dan penduduk surga berkata,\qt@no{57}}%
\qt@newcmd\qurantrans@id@mmmdcccxlvi{%
(Maka apakah kita tidak akan mati.)\qt@no{58}}%
\qt@newcmd\qurantrans@id@mmmdcccxlvii{%
(Melainkan hanya kematian kita yang pertama) yakni kematian kita di dunia (dan kita tidak akan disiksa di akhirat ini?") Istifham atau kata tanya di sini mengandung makna menetapkan kenikmatan yang mereka rasakan dan sebagai ungkapan rasa syukur mereka atas nikmat yang telah dilimpahkan Allah kepada diri mereka, yaitu mereka dijadikan hidup abadi dengan penuh kenikmatan dan tidak disiksa untuk selama-lamanya.\qt@no{59}}%
\qt@newcmd\qurantrans@id@mmmdcccxlviii{%
(Sesungguhnya ini) yakni apa yang Aku jelaskan mengenai keadaan penduduk surga (benar-benar kemenangan yang besar.)\qt@no{60}}%
\qt@newcmd\qurantrans@id@mmmdcccxlix{%
(Untuk kemenangan serupa ini hendaklah berusaha orang-orang yang beramal) menurut suatu pendapat, bahwa perkataan ini ditujukan kepada mereka. Dan menurut pendapat yang lain disebutkan, bahwa merekalah yang mengatakan demikian.\qt@no{61}}%
\qt@newcmd\qurantrans@id@mmmdcccl{%
(Apakah yang demikian itu) hal-hal yang telah disebutkan bagi ahli surga itu (merupakan hidangan yang lebih baik) suguhan atau hidangan yang diperuntukkan menjamu tamu atau orang yang menginap (ataukah pohon zaqqum) yang disediakan buat ahli neraka; pohon zaqqum adalah pohon yang paling buruk dan sangat pahit rasanya, tempat asalnya adalah Tihamah. Allah menumbuhkan pohon itu di dalam neraka Jahim, sebagaimana yang akan diterangkan nanti.\qt@no{62}}%
\qt@newcmd\qurantrans@id@mmmdcccli{%
(Sesungguhnya Kami menjadikan pohon zaqqum itu) artinya ditumbuhkannya pohon tersebut di dalam neraka (sebagai fitnah bagi orang-orang yang lalim) yakni orang-orang kafir Mekah, karena mereka telah mengatakan, bahwa api itu membakar pohon, mana mungkin di dalam neraka dapat ditumbuhkan pohon.\qt@no{63}}%
\qt@newcmd\qurantrans@id@mmmdccclii{%
(Sesungguhnya dia adalah sebatang pohon yang keluar dari dasar neraka yang menyala) yakni dari dasar neraka Jahanam, dan ranting-rantingnya mencuat sampai ke relung-relungnya.\qt@no{64}}%
\qt@newcmd\qurantrans@id@mmmdcccliii{%
(Mayangnya) diserupakan dengan mayang pohon kurma (seperti kepala setan-setan) maksudnya, seperti ular-ular yang sangat buruk dan menjijikkan tampangnya.\qt@no{65}}%
\qt@newcmd\qurantrans@id@mmmdcccliv{%
(Maka sesungguhnya mereka) yakni orang-orang kafir (benar-benar memakan sebagian dari pohon itu) sekalipun rasanya sangat memuakkan, karena mereka dalam keadaan sangat lapar (maka mereka memenuhi perutnya dengan buah zaqqum itu.)\qt@no{66}}%
\qt@newcmd\qurantrans@id@mmmdccclv{%
(Kemudian sesudah makan buah pohon zaqqum itu pasti mereka mendapat minuman yang bercampur dengan air yang sangat panas) yang mereka minum, hingga bercampur di dalam perut mereka apa yang mereka makan dan apa yang mereka minum itu.\qt@no{67}}%
\qt@newcmd\qurantrans@id@mmmdccclvi{%
(Kemudian sesungguhnya tempat kembali mereka benar-benar ke neraka Jahim) ayat ini memberikan pengertian, bahwa mereka keluar dahulu dari dalam neraka untuk meminum air hamim atau air yang sangat panas itu, dan bahwasanya air yang sangat panas itu adanya di luar neraka.\qt@no{68}}%
\qt@newcmd\qurantrans@id@mmmdccclvii{%
(Karena sesungguhnya mereka mendapati) menemukan (bapak-bapak mereka dalam keadaan sesat.)\qt@no{69}}%
\qt@newcmd\qurantrans@id@mmmdccclviii{%
(Lalu mereka sangat tergesa-gesa mengikuti jejak orang-orang tua mereka itu) atau terburu-buru mengikutinya, oleh karenanya mereka tergesa-gesa mengikuti kesesatan bapak-bapak mereka, tanpa berpikir lebih jauh lagi.\qt@no{70}}%
\qt@newcmd\qurantrans@id@mmmdccclix{%
(Dan sesungguhnya telah sesat sebelum mereka sebagian besar dari orang-orang yang dahulu) umat-umat yang terdahulu.\qt@no{71}}%
\qt@newcmd\qurantrans@id@mmmdccclx{%
(Dan sesungguhnya telah Kami utus pemberi-pemberi peringatan di kalangan mereka) yakni rasul-rasul yang memberi peringatan kepada mereka.\qt@no{72}}%
\qt@newcmd\qurantrans@id@mmmdccclxi{%
(Maka perhatikanlah bagaimana kesudahan orang-orang yang diberi peringatan itu) yakni orang-orang kafir itu, kesudahan mereka mendapat azab.\qt@no{73}}%
\qt@newcmd\qurantrans@id@mmmdccclxii{%
(Kecuali hamba-hamba Allah yang dibersihkan -dari dosa-dosa-) yakni kaum mukminin, sesungguhnya mereka selamat dari azab, karena keikhlasan mereka dalam beribadah kepada Allah. Atau karena Allah telah membersihkan mereka dari dosa-dosanya, makna ini berdasar qiraat yang membacanya Mukhlashiina.\qt@no{74}}%
\qt@newcmd\qurantrans@id@mmmdccclxiii{%
(Sesungguhnya Nuh telah menyeru Kami) melalui doanya, sebagaimana yang disitir oleh ayat lain, yaitu firman-Nya, ``Sesungguhnya aku ini adalah orang yang dikalahkan, oleh sebab itu menangkanlah (aku)." (Q.S. Al-Qamar, 10). (maka sesungguhnya sebaik-baik yang memperkenankan) doanya adalah Kami. Maksudnya, Nuh berdoa kepada Allah untuk dimenangkan atas kaumnya, lalu Allah binasakan mereka melalui banjir besar hingga mereka tenggelam semuanya.\qt@no{75}}%
\qt@newcmd\qurantrans@id@mmmdccclxiv{%
(Dan Kami telah menyelamatkannya beserta keluarganya dari bencana yang besar) yakni dari banjir yang besar itu.\qt@no{76}}%
\qt@newcmd\qurantrans@id@mmmdccclxv{%
(Dan Kami jadikan anak cucunya orang-orang yang melanjutkan keturunan) dengan demikian maka manusia semuanya adalah anak cucu dari Nabi Nuh a.s. Nabi Nuh mempunyai tiga orang anak, yaitu Sam adalah bapak moyang bangsa Arab, bangsa Persia dan bangsa Romawi; Ham adalah bapak moyang bangsa yang berkulit hitam; Yafits adalah bapak moyang bangsa Turki, bangsa Khazr, Ya'juj dan Ma'juj dan lain-lainnya.\qt@no{77}}%
\qt@newcmd\qurantrans@id@mmmdccclxvi{%
(Dan Kami abadikan) Kami lestarikan (untuk Nuh itu) pujian yang baik (di kalangan orang-orang yang datang kemudian) yakni para nabi dan semua umat manusia hingga hari kiamat.\qt@no{78}}%
\qt@newcmd\qurantrans@id@mmmdccclxvii{%
(Kesejahteraan) dari Kami dilimpahkan atas Nuh di seluruh alam.)\qt@no{79}}%
\qt@newcmd\qurantrans@id@mmmdccclxviii{%
(Sesungguhnya demikianlah Kami,) artinya sebagaimana Kami memberikan balasan kepada mereka (Kami memberi balasan kepada orang-orang yang berbuat baik.)\qt@no{80}}%
\qt@newcmd\qurantrans@id@mmmdccclxix{%
(Sesungguhnya dia termasuk di antara hamba-hamba Kami yang beriman.)\qt@no{81}}%
\qt@newcmd\qurantrans@id@mmmdccclxx{%
(Kemudian Kami tenggelamkan orang-orang yang lain) yakni orang-orang kafir dari kaum Nabi Nuh.\qt@no{82}}%
\qt@newcmd\qurantrans@id@mmmdccclxxi{%
(Dan sesungguhnya di antara golongan Nuh) yang mengikutinya dalam masalah pokok agama, yaitu masalah tauhid (adalah Ibrahim) sekalipun jarak zaman di antara keduanya sangat jauh, yaitu dua ribu enam ratus empat puluh tahun; dan adalah di antara keduanya terdapat Nabi Hud dan Nabi Saleh.\qt@no{83}}%
\qt@newcmd\qurantrans@id@mmmdccclxxii{%
(Ingatlah ketika ia datang kepada Rabbnya) maksudnya, ia mengikuti-Nya sewaktu datang kepada kaumnya (dengan hati yang suci) dari keraguan dan hal-hal lainnya.\qt@no{84}}%
\qt@newcmd\qurantrans@id@mmmdccclxxiii{%
(Ingatlah ketika ia berkata) sedangkan ia dalam keadaan demikian, yakni bersih dari keraguan terhadap Rabbnya (kepada bapaknya dan kaumnya) dengan nada yang mencela. ("Apakah) yang (kalian sembah itu?)\qt@no{85}}%
\qt@newcmd\qurantrans@id@mmmdccclxxiv{%
(Apakah dengan jalan berbohong) kedua huruf Hamzah pada ayat ini dapat dibaca Tahqiq atau Tas-hil (kalian menghendaki sesembahan-sesembahan selain Allah?) lafal Ifkan adalah Maf'ul Lah, dan lafal Aalihah adalah Maf'ul Bih bagi lafal Turiduuna. Al-Ifku artinya dusta yang paling buruk; makna yang dimaksud adalah, apakah kalian menyembah selain Allah?\qt@no{86}}%
\qt@newcmd\qurantrans@id@mmmdccclxxv{%
(Maka apakah anggapanmu terhadap Rabb semesta alam?") jika kalian menyembah selain-Nya; apakah kalian menganggap bahwa Dia akan membiarkan kalian tanpa mengazab kalian? Tentu saja tidak, Dia pasti mengazab kalian. Mereka adalah orang-orang ahli perbintangan. Lalu mereka keluar pada hari raya mereka dan meletakkan makanan mereka di depan latar berhala-berhala mereka, mereka menduga bahwa hal itu dapat membawa berkah pada makanan mereka. Apabila mereka kembali, maka mereka memakan makanan tersebut. Mereka mengatakan kepada Nabi Ibrahim, ``Marilah kita keluar."\qt@no{87}}%
\qt@newcmd\qurantrans@id@mmmdccclxxvi{%
(Lalu ia memandang sekali pandang ke bintang-bintang) untuk mengelabui mereka, bahwasanya dia percaya kepada bintang-bintang itu, supaya mereka tidak menaruh rasa curiga terhadap dirinya.\qt@no{88}}%
\qt@newcmd\qurantrans@id@mmmdccclxxvii{%
(Kemudian ia berkata, ``Sesungguhnya aku sakit") maksudnya, aku akan mengalami sakit.\qt@no{89}}%
\qt@newcmd\qurantrans@id@mmmdccclxxviii{%
(Lalu mereka berpaling daripadanya) menuju ke tempat perayaan mereka (dengan membelakangi)\qt@no{90}}%
\qt@newcmd\qurantrans@id@mmmdccclxxix{%
(Kemudian ia pergi dengan diam-diam) atau Nabi Ibrahim berangkat dengan diam-diam menuju (kepada berhala-berhala mereka) yang pada saat itu di hadapannya terdapat banyak hidangan makanan (lalu ia berkata) dengan nada yang sinis ditujukan kepada berhala-berhala mereka itu, ("Apakah kalian tidak makan?") tetapi berhala-berhala itu diam saja.\qt@no{91}}%
\qt@newcmd\qurantrans@id@mmmdccclxxx{%
Maka Ibrahim berkata, ("Kenapa kalian tidak menjawab?") ternyata berhala-berhala itu tidak juga menjawab.\qt@no{92}}%
\qt@newcmd\qurantrans@id@mmmdccclxxxi{%
(Lalu dihadapinya berhala-berhala itu sambil memukulnya dengan tangan kanannya) artinya, dengan sekuat-kuatnya hingga berhala-berhala itu pecah berantakan. Berita penghancuran berhala-berhala itu sampai kepada kaumnya melalui orang-orang yang melihat Nabi Ibrahim sedang menghancurkannya.\qt@no{93}}%
\qt@newcmd\qurantrans@id@mmmdccclxxxii{%
(Kemudian kaumnya datang kepadanya dengan bergegas) mereka berjalan dengan terburu-buru, lalu mereka berkata kepada Nabi Ibrahim, ``Kami menyembahnya sedangkan kamu memecahkannya."\qt@no{94}}%
\qt@newcmd\qurantrans@id@mmmdccclxxxiii{%
(Ibrahim berkata) kepada mereka dengan nada sinis, ("Apakah kalian menyembah patung-patung yang kalian pahat itu?) dari batu dan dari bahan-bahan lainnya sebagai berhala-berhala yang kalian sembah.\qt@no{95}}%
\qt@newcmd\qurantrans@id@mmmdccclxxxiv{%
(Padahal Allahlah yang telah menciptakan kalian dan apa yang kalian perbuat itu") yakni tentang apa yang kalian pahat dan hasil pahatan kalian itu, karenanya sembahlah Dia dan esakanlah Dia. Huruf Maa di sini menurut suatu pendapat adalah Maa Mashdariyah, menurut pendapat lainnya adalah Maa Maushulah, dan menurut pendapat lainnya lagi adalah Maa Maushufah.\qt@no{96}}%
\qt@newcmd\qurantrans@id@mmmdccclxxxv{%
(Mereka berkata) di antara sesama mereka ("Dirikanlah suatu bangunan untuknya) lalu kumpulkanlah kayu-kayu bakar di bawahnya, dan nyalakanlah api padanya, maka apabila ia telah menyala (lemparkanlah dia ke dalam api yang menyala-nyala itu") yakni ke dalam api yang telah membesar nyalanya itu.\qt@no{97}}%
\qt@newcmd\qurantrans@id@mmmdccclxxxvi{%
(Mereka hendak melakukan tipu muslihat kepadanya) dengan melemparkannya ke dalam api yang menyala-nyala untuk membinasakannya (maka Kami jadikan mereka orang-orang yang hina) orang-orang yang dikalahkan; karena ternyata Nabi Ibrahim keluar dari dalam api itu dalam keadaan selamat tidak apa-apa.\qt@no{98}}%
\qt@newcmd\qurantrans@id@mmmdccclxxxvii{%
(Dan Ibrahim berkata, ``Sesungguhnya aku pergi menghadap kepada Rabbku) artinya berhijrah demi karena-Nya meninggalkan negeri orang-orang kafir (dan Dia akan memberi petunjuk kepadaku) ke tempat yang aku diperintahkan-Nya berangkat ke sana, yaitu negeri Syam. Tatkala ia sampai di tanah suci yaitu Baitulmakdis, berkatalah ia dalam doanya,\qt@no{99}}%
\qt@newcmd\qurantrans@id@mmmdccclxxxviii{%
('Ya Rabbku! Anugerahkanlah kepadaku) seorang anak (yang termasuk orang-orang yang saleh.')\qt@no{100}}%
\qt@newcmd\qurantrans@id@mmmdccclxxxix{%
(Maka Kami beri dia kabar gembira dengan seorang anak yang amat sabar) yakni yang banyak memiliki kesabaran.\qt@no{101}}%
\qt@newcmd\qurantrans@id@mmmdcccxc{%
(Maka tatkala anak itu sampai pada umur sanggup berusaha bersama-sama Ibrahim) yaitu telah mencapai usia sehingga dapat membantunya bekerja; menurut suatu pendapat bahwa umur anak itu telah mencapai tujuh tahun. Menurut pendapat yang lain bahwa pada saat itu anak Nabi Ibrahim berusia tiga belas tahun (Ibrahim berkata, ``Hai anakku! Sesungguhnya aku melihat) maksudnya, telah melihat (dalam mimpi bahwa aku menyembelihmu!) mimpi para nabi adalah mimpi yang benar, dan semua pekerjaan mereka berdasarkan perintah dari Allah swt. (maka pikirkanlah apa pendapatmu!") tentang impianku itu; Nabi Ibrahim bermusyawarah dengannya supaya ia menurut, mau disembelih, dan taat kepada perintah-Nya. (Ia menjawab, ``Hai bapakku) huruf Ta pada lafal Abati ini merupakan pergantian dari Ya Idhafah (kerjakanlah apa yang diperintahkan kepadamu) untuk melakukannya (Insya Allah engkau akan mendapatiku termasuk orang-orang yang sabar") menghadapi hal tersebut.\qt@no{102}}%
\qt@newcmd\qurantrans@id@mmmdcccxci{%
(Tatkala keduanya telah berserah diri) artinya, tunduk dan patuh kepada perintah Allah swt. (dan Ibrahim membaringkan anaknya atas pelipisnya) Nabi Ismail dibaringkan pada salah satu pelipisnya; setiap manusia memiliki dua pelipis dan di antara keduanya terdapat jidat. Kejadian ini di Mina; kemudian Nabi Ibrahim menggorokkan pisau besarnya ke leher Nabi Ismail, akan tetapi berkat kekuasaan Allah pisau itu tidak mempan sedikit pun.\qt@no{103}}%
\qt@newcmd\qurantrans@id@mmmdcccxcii{%
(Dan Kami panggil dia, ``Hai Ibrahim!)\qt@no{104}}%
\qt@newcmd\qurantrans@id@mmmdcccxciii{%
(Sesungguhnya kamu telah membenarkan mimpimu itu") melalui apa yang telah kamu kerjakan, yaitu melaksanakan penyembelihan yang diperintahkan itu atau dengan kata lain, cukuplah bagimu hal itu. Jumlah kalimat Naadainaahu merupakan jawab dari lafal Lammaa, hanya ditambahi Wau (sesungguhnya demikianlah) maksudnya, sebagaimana Kami memberikan pahala kepadamu (Kami memberi balasan kepada orang-orang yang berbuat baik) terhadap diri mereka sendiri dengan melaksanakan apa yang diperintahkan kepada mereka, yaitu Kami akan melepaskan mereka dari kesulitan.\qt@no{105}}%
\qt@newcmd\qurantrans@id@mmmdcccxciv{%
(Sesungguhnya ini) penyembelihan yang diperintahkan ini (benar-benar suatu ujian yang nyata) atau cobaan yang jelas.\qt@no{106}}%
\qt@newcmd\qurantrans@id@mmmdcccxcv{%
(Dan Kami tebus anak itu) maksudnya, anak yang diperintahkan untuk disembelih (Nabi Ismail). Menurut suatu pendapat bahwa anak yang disembelih itu adalah Nabi Ishak (dengan seekor sembelihan) yakni dengan domba (yang besar) dari surga, yaitu domba yang sama dengan domba yang dijadikan kurban oleh Habil. Domba itu dibawa oleh malaikat Jibril, lalu Nabi Ibrahim menyembelihnya seraya membaca takbir.\qt@no{107}}%
\qt@newcmd\qurantrans@id@mmmdcccxcvi{%
(Kami abadikan) Kami lestarikan (untuk Ibrahim itu di kalangan orang-orang yang datang kemudian) pujian yang baik.\qt@no{108}}%
\qt@newcmd\qurantrans@id@mmmdcccxcvii{%
("Kesejahteraan) dari Kami (dilimpahkan atas Ibrahim.")\qt@no{109}}%
\qt@newcmd\qurantrans@id@mmmdcccxcviii{%
(Demikianlah) sebagaimana Kami memberikan imbalan pahala kepada Ibrahim (kami memberi balasan kepada orang-orang yang berbuat baik) terhadap diri mereka sendiri.\qt@no{110}}%
\qt@newcmd\qurantrans@id@mmmdcccxcix{%
(Sesungguhnya ia termasuk hamba-hamba Kami yang beriman.)\qt@no{111}}%
\qt@newcmd\qurantrans@id@mmmcm{%
(Dan Kami beri dia kabar gembira dengan kelahiran Ishak) dengan adanya ayat ini dapat disimpulkan, bahwa anak yang disembelih itu bukanlah Nabi Ishak tetapi anak Nabi Ibrahim yang lainnya, yaitu Nabi Ismail (seorang nabi) menjadi Hal dari lafal yang diperkirakan keberadaannya, artinya kelak ia akan menjadi seorang nabi (yang termasuk orang-orang yang saleh.)\qt@no{112}}%
\qt@newcmd\qurantrans@id@mmmcmi{%
(Kami limpahkan keberkatan atasnya) dengan diperbanyak anak cucunya (dan atas Ishak) anak Nabi Ibrahim, yaitu Kami menjadikan kebanyakan para nabi dari keturunannya. (Dan di antara anak cucunya ada yang berbuat baik) maksudnya, yang beriman (dan ada pula yang lalim terhadap dirinya sendiri) yang kafir (dengan nyata) nyata kekafirannya.\qt@no{113}}%
\qt@newcmd\qurantrans@id@mmmcmii{%
(Dan sesungguhnya Kami telah melimpahkan nikmat atas Musa dan Harun) yakni nikmat kenabian.\qt@no{114}}%
\qt@newcmd\qurantrans@id@mmmcmiii{%
(Dan Kami selamatkan keduanya dan kaumnya) yaitu kaum Bani Israel (dari bencana yang besar) dari perbudakan Firaun atas mereka.\qt@no{115}}%
\qt@newcmd\qurantrans@id@mmmcmiv{%
(Dan Kami tolong mereka) dari cengkeraman bangsa Koptik (maka jadilah mereka orang-orang yang menang.)\qt@no{116}}%
\qt@newcmd\qurantrans@id@mmmcmv{%
(Dan Kami berikan kepada keduanya kitab yang sangat jelas) yang di dalamnya terkandung hukum-hukum dan batasan-batasan serta hal-hal lainnya, yang kesemuanya itu diterangkan dengan jelas dan gamblang di dalamnya; Kitab yang dimaksud adalah Kitab Taurat.\qt@no{117}}%
\qt@newcmd\qurantrans@id@mmmcmvi{%
(Dan kami tunjuki keduanya ke jalan) yakni kepada tuntunan (yang lurus.)\qt@no{118}}%
\qt@newcmd\qurantrans@id@mmmcmvii{%
(Dan Kami abadikan) Kami lestarikan (untuk keduanya di kalangan orang-orang yang datang kemudian) pujian yang baik.\qt@no{119}}%
\qt@newcmd\qurantrans@id@mmmcmviii{%
(Yaitu ``Kesejahteraan) dari Kami (dilimpahkan atas Musa dan Harun".')\qt@no{120}}%
\qt@newcmd\qurantrans@id@mmmcmix{%
(Sesungguhnya demikianlah) maksudnya, sebagaimana Kami memberikan balasan pahala kepada keduanya (Kami memberi balasan kepada orang-orang yang berbuat baik.)\qt@no{121}}%
\qt@newcmd\qurantrans@id@mmmcmx{%
(Sesungguhnya keduanya termasuk hamba-hamba Kami yang beriman.)\qt@no{122}}%
\qt@newcmd\qurantrans@id@mmmcmxi{%
(Dan sesungguhnya Ilyas) dapat dibaca Ilyaas atau Alyaas (benar-benar termasuk salah seorang rasul-rasul) menurut suatu pendapat bahwa Nabi Ilyas itu adalah anak saudara lelaki Nabi Harun dan Nabi Musa. Menurut pendapat yang lain bukan; ia diutus oleh Allah kepada kaum yang tinggal di kota Ba'albak dan sekitarnya.\qt@no{123}}%
\qt@newcmd\qurantrans@id@mmmcmxii{%
(Ingatlah ketika) lafal Idz di sini dinashabkan oleh lafal Udzkur yang diperkirakan keberadaannya (ia berkata kepada kaumnya, ``Mengapa kalian tidak bertakwa) kepada Allah?\qt@no{124}}%
\qt@newcmd\qurantrans@id@mmmcmxiii{%
(Patutkah kalian menyembah Ba'l) Ba'l adalah nama berhala yang terbuat dari emas, dan dengan nama berhala itu pula negeri mereka diberi nama, lalu dimudhafkan kepada lafal Bik, sehingga jadilah Ba'alabak. Maksud ayat ini ialah mengapa kalian menyembahnya (dan kalian tinggalkan) artinya kalian tidak menyembah (sebaik-baik pencipta) yakni Allah; maksudnya mengapa kalian tidak menyembah Allah?\qt@no{125}}%
\qt@newcmd\qurantrans@id@mmmcmxiv{%
(Yaitu Allah Rabb kalian dan Rabb bapak-bapak kalian yang terdahulu?") kalau dibaca Allaahu Rabbukum Warabbu Aabaa-ikum, berarti sebelumnya diperkirakan adanya lafal Huwa. Kalau dibaca Allaaha Rabbakum warabba Aabaa-ikum berarti menjadi Badal dari lafal Ahsanal Khaaliqiina.\qt@no{126}}%
\qt@newcmd\qurantrans@id@mmmcmxv{%
(Maka mereka mendustakannya, karena itu mereka akan diseret) ke dalam neraka.\qt@no{127}}%
\qt@newcmd\qurantrans@id@mmmcmxvi{%
(Kecuali hamba-hamba Allah yang dibersihkan dari dosa) yaitu hamba-hamba Allah yang beriman, mereka diselamatkan dari neraka.\qt@no{128}}%
\qt@newcmd\qurantrans@id@mmmcmxvii{%
(Dan Kami abadikan untuk Ilyas di kalangan orang-orang yang datang kemudian) pujian yang baik.\qt@no{129}}%
\qt@newcmd\qurantrans@id@mmmcmxviii{%
(Yaitu ``Kesejahteraan) dari Kami (dilimpahkan atas Ilyasin) yang dimaksud adalah Nabi Ilyas yang tadi, ia dinamakan demikian secara Taghlib, perihalnya sama dengan ucapan orang-orang Arab jika menamakan Muhallab dan kaumnya, mereka menamakannya Al-Muhallabuun. Dan menurut qiraat yang membacakannya menjadi Aali Yasiina dengan dipanjangkan harakat Hamzahnya, berarti keluarga Nabi Ilyas, dan makna yang dimaksud adalah Nabi Ilyas pula.\qt@no{130}}%
\qt@newcmd\qurantrans@id@mmmcmxix{%
(Sesungguhnya demikianlah) sebagaimana Kami memberikan balasan pahala kepadanya (Kami memberikan balasan kepada orang-orang yang berbuat baik.)\qt@no{131}}%
\qt@newcmd\qurantrans@id@mmmcmxx{%
(Sesungguhnya dia termasuk hamba-hamba Kami yang beriman.)\qt@no{132}}%
\qt@newcmd\qurantrans@id@mmmcmxxi{%
(Dan sesungguhnya Luth benar-benar adalah seorang rasul.)\qt@no{133}}%
\qt@newcmd\qurantrans@id@mmmcmxxii{%
(Ingatlah ketika Kami selamatkan dia dan keluarganya pengikut-pengikutnya semua.)\qt@no{134}}%
\qt@newcmd\qurantrans@id@mmmcmxxiii{%
(Kecuali seorang perempuan tua istrinya yang berada bersama-sama orang yang ditinggal) orang-orang yang ditinggal tertimpa azab.\qt@no{135}}%
\qt@newcmd\qurantrans@id@mmmcmxxiv{%
(Kemudian Kami binasakan) Kami hancurkan (orang-orang yang lain) yaitu orang-orang yang kafir dari kaumnya.\qt@no{136}}%
\qt@newcmd\qurantrans@id@mmmcmxxv{%
(Dan sesungguhnya kalian hai penduduk Mekah benar-benar akan melalui mereka) melalui bekas-bekas dan tempat-tempat tinggal mereka bila kalian mengadakan perjalanan (di waktu pagi) maksudnya di waktu siang hari.\qt@no{137}}%
\qt@newcmd\qurantrans@id@mmmcmxxvi{%
(Dan di waktu malam hari. Maka apakah kalian tidak memikirkan?) hai penduduk Mekah, mengenai apa yang telah menimpa mereka berupa azab, oleh karena kalian lalu mengambil pelajaran darinya.\qt@no{138}}%
\qt@newcmd\qurantrans@id@mmmcmxxvii{%
(Sesungguhnya Yunus benar-benar salah seorang rasul.)\qt@no{139}}%
\qt@newcmd\qurantrans@id@mmmcmxxviii{%
(Ingatlah ketika ia lari) maksudnya, minggat (ke kapal yang penuh muatan) hal ini terjadi sewaktu ia bersitegang dengan kaumnya, karena ternyata azab yang diancamkan olehnya kepada kaumnya tidak turun-turun juga, akhirnya ia melarikan diri naik kapal. Dan kapal yang dinaikinya itu berhenti di tengah laut yang besar ombaknya. Juru mudi kapal mengatakan, bahwa di dalam kapal ini terdapat seorang hamba yang melarikan diri dari tuannya, hal ini akan tampak jelas melalui undian.\qt@no{140}}%
\qt@newcmd\qurantrans@id@mmmcmxxix{%
(Kemudian ia ikut berundi) para penumpang kapal itu semuanya diundi (lalu dia termasuk orang-orang yang kalah dalam undian itu) akibatnya ia dilemparkan ke laut.\qt@no{141}}%
\qt@newcmd\qurantrans@id@mmmcmxxx{%
(Maka ia ditelan oleh ikan besar) ditelan bulat-bulat (dalam keadaan tercela) karena ia melakukan perbuatan yang tercela, yaitu pergi dengan memakai jalan laut kemudian naik kapal meninggalkan kaumnya, tanpa izin terlebih dahulu dari Rabbnya.\qt@no{142}}%
\qt@newcmd\qurantrans@id@mmmcmxxxi{%
(Maka kalau sekiranya dia tidak termasuk orang-orang yang bertasbih) yakni selalu ingat kepada Allah, melalui zikirnya di dalam perut ikan seraya mengatakan, ``Laa Ilaaha Illaa Anta Subhaanaka Innii Kuntu Minazh Zhaalimiina", artinya, ``Tidak ada Tuhan selain Engkau, Maha Suci Engkau, sesungguhnya aku termasuk orang-orang yang aniaya."\qt@no{143}}%
\qt@newcmd\qurantrans@id@mmmcmxxxii{%
(Niscaya ia akan tetap tinggal di perut ikan itu sampai hari berbangkit) artinya, niscaya perut ikan besar itu akan menjadi kuburnya hingga hari kiamat nanti.\qt@no{144}}%
\qt@newcmd\qurantrans@id@mmmcmxxxiii{%
(Kemudian Kami lemparkan dia) Kami campakkan dia dari dalam perut ikan besar itu (ke daerah yang tandus) di permukaan bumi yang tandus, yakni ke tepi pantai pada hari itu juga, setelah tiga hari, tujuh hari, dua puluh hari atau setelah empat puluh hari sejak ia ditelan ikan besar itu (sedangkan ia dalam keadaan sakit) yakni kurus kering dan sakit bagaikan anak ayam yang terserang penyakit kok.\qt@no{145}}%
\qt@newcmd\qurantrans@id@mmmcmxxxiv{%
(Dan Kami tumbuhkan untuk dia sebatang pohon dari jenis labu) pohon itu dapat menaunginya dengan batangnya, berbeda keadaannya dengan pohon labu yang biasanya. Hal ini merupakan suatu mukjizat baginya, setiap pagi dan petang datang kepadanya kambing hutan, ia meminum air susu dari teteknya hingga ia kuat kembali.\qt@no{146}}%
\qt@newcmd\qurantrans@id@mmmcmxxxv{%
(Dan Kami utus dia) sesudah itu, sebagaimana status sebelumnya, kepada kaum Bunainawiy yang tinggal di daerah Maushul (kepada seratus ribu orang atau) bahkan (lebih dari itu) yakni lebih dua puluh atau tiga puluh atau tujuh puluh ribu orang.\qt@no{147}}%
\qt@newcmd\qurantrans@id@mmmcmxxxvi{%
(Lalu mereka beriman) sewaktu mereka menyaksikan azab yang telah dijanjikan kepada mereka (karena itu Kami anugerahkan kenikmatan hidup kepada mereka) artinya, kami biarkan mereka menikmati harta yang ada pada mereka (hingga waktu yang tertentu) hingga ajal mereka datang.\qt@no{148}}%
\qt@newcmd\qurantrans@id@mmmcmxxxvii{%
(Tanyakanlah kepada mereka) kepada orang-orang kafir Mekah; ungkapan ini dimaksud sebagai ejekan terhadap mereka, ("Apakah untuk Rabb kamu anak-anak perempuan) sesuai dengan dugaan mereka bahwa para malaikat itu adalah anak-anak perempuan Allah (dan untuk mereka anak laki-laki) mereka memilih yang lebih kuat dan yang lebih baik.\qt@no{149}}%
\qt@newcmd\qurantrans@id@mmmcmxxxviii{%
(Atau apakah Kami menciptakan malaikat-malaikat berupa perempuan dan mereka menyaksikannya") yakni mereka menyaksikan penciptaan Kami itu, yang karenanya mereka mengatakan demikian?\qt@no{150}}%
\qt@newcmd\qurantrans@id@mmmcmxxxix{%
(Ketahuilah bahwa sesungguhnya mereka dengan kebohongannya) dengan kedustaan mereka itu (benar-benar mengatakan,)\qt@no{151}}%
\qt@newcmd\qurantrans@id@mmmcmxl{%
("Allah beranak") melalui perkataan mereka yang menyatakan bahwa malaikat-malaikat itu adalah anak-anak perempuan Allah. (Dan sesungguhnya mereka benar-benar orang yang berdusta) dalam hal ini.\qt@no{152}}%
\qt@newcmd\qurantrans@id@mmmcmxli{%
(Apakah Tuhan memilih) lafal Ashthafaa Hamzahnya adalah Hamzah Istifham yang berharakat Fatah, oleh karenanya Hamzah Washal tidak dibutuhkan lagi, sebab itu dibuang. Yakni apakah Allah mengutamakan (anak-anak perempuan daripada anak laki-laki?)\qt@no{153}}%
\qt@newcmd\qurantrans@id@mmmcmxlii{%
(Apakah yang terjadi pada kalian? Bagaimanakah caranya kalian menetapkan?) kesimpulan yang rusak ini.\qt@no{154}}%
\qt@newcmd\qurantrans@id@mmmcmxliii{%
(Maka apakah kalian tidak memikirkan?) bahwasanya Allah swt. itu Maha Tinggi lagi Maha Suci dari mempunyai anak?\qt@no{155}}%
\qt@newcmd\qurantrans@id@mmmcmxliv{%
(Atau apakah kalian mempunyai bukti yang nyata?) artinya hujah yang jelas menyatakan bahwa Allah mempunyai anak.\qt@no{156}}%
\qt@newcmd\qurantrans@id@mmmcmxlv{%
(Maka bawalah kitab kalian) kitab Taurat kalian, kemudian perlihatkanlah kepadaku mengenai hal itu di dalamnya (jika kalian memang orang-orang yang benar) di dalam perkataan dan dugaan kalian itu.\qt@no{157}}%
\qt@newcmd\qurantrans@id@mmmcmxlvi{%
(Dan mereka adakan) orang-orang musyrik itu (antara Dia) yakni Allah swt. (dan antara jin) yakni malaikat dinamakan Al-Jinnah karena mereka tidak dapat dilihat oleh mata (hubungan nasab) melalui perkataan mereka yang menyatakan bahwasanya malaikat-malaikat itu adalah anak-anak perempuan Allah. (Dan sesungguhnya jin mengetahui bahwa mereka) yakni orang-orang yang mengatakan demikian (benar-benar akan diseret) ke dalam neraka dan mereka akan diazab di dalamnya.\qt@no{158}}%
\qt@newcmd\qurantrans@id@mmmcmxlvii{%
(Maha Suci Allah) kalimat ini memahasucikan Dia (dari apa yang mereka sifatkan) yaitu bahwasanya Allah mempunyai anak.\qt@no{159}}%
\qt@newcmd\qurantrans@id@mmmcmxlviii{%
(Kecuali hamba-hamba Allah yang dibersihkan dari dosa) yakni kecuali orang-orang yang beriman. Istitsna di sini adalah bersifat Munqathi'. Maksudnya bahwa mereka yang beriman itu memahasucikan Allah swt. dari apa yang telah disifatkan oleh mereka kepada-Nya.\qt@no{160}}%
\qt@newcmd\qurantrans@id@mmmcmxlix{%
(Maka sesungguhnya kalian dan apa-apa yang kalian sembah itu) yakni berhala-berhala sesembahan-sesembahan kalian itu.\qt@no{161}}%
\qt@newcmd\qurantrans@id@mmmcml{%
(Sekali-kali kalian dengannya tidak akan dapat) dengan melalui sesembahan kalian itu; lafal 'Alaihi berta'alluq kepada firman selanjutnya, yaitu (menyesatkan) seorang pun.\qt@no{162}}%
\qt@newcmd\qurantrans@id@mmmcmli{%
(Kecuali orang-orang yang akan masuk neraka yang menyala-nyala) menurut ilmu Allah swt.\qt@no{163}}%
\qt@newcmd\qurantrans@id@mmmcmlii{%
Malaikat Jibril berkata kepada Nabi saw., ("Tiada seorang pun di antara kami) para malaikat (melainkan mempunyai kedudukan yang tertentu) di langit, di tempat itu ia beribadah kepada Allah dan tidak melampaui tempat atau kedudukan yang lain.\qt@no{164}}%
\qt@newcmd\qurantrans@id@mmmcmliii{%
(Dan sesungguhnya kami benar-benar bersaf-saf) artinya meluruskan telapak kaki kami dalam salat.\qt@no{165}}%
\qt@newcmd\qurantrans@id@mmmcmliv{%
(Dan sesungguhnya kami benar-benar bertasbih.") menyucikan Allah dari hal-hal yang tidak layak bagi-Nya.\qt@no{166}}%
\qt@newcmd\qurantrans@id@mmmcmlv{%
(Sesungguhnya) lafal In di sini adalah bentuk Takhfif dari lafal Inna (mereka) yakni orang-orang kafir Mekah (akan berkata,)\qt@no{167}}%
\qt@newcmd\qurantrans@id@mmmcmlvi{%
("Kalau sekiranya di sisi kami ada sebuah peringatan) maksudnya, sebuah kitab (dari orang-orang yang dahulu) yakni dari kitab-kitab yang diturunkan kepada orang-orang yang dahulu.\qt@no{168}}%
\qt@newcmd\qurantrans@id@mmmcmlvii{%
(Benar-benar kami akan jadi hamba Allah yang mukhlis") maksudnya beribadah kepada-Nya semata.\qt@no{169}}%
\qt@newcmd\qurantrans@id@mmmcmlviii{%
Allah berfirman, ("Tetapi mereka mengingkarinya) mengingkari Kitab yang diturunkan kepada mereka, yaitu Alquran kitab yang lebih mulia daripada kitab-kitab yang diturunkan sebelumnya (kelak mereka akan mengetahui) akibat dari kekafiran dan keingkaran mereka itu.\qt@no{170}}%
\qt@newcmd\qurantrans@id@mmmcmlix{%
(Dan sesungguhnya telah tetap janji Kami) pertolongan Kami (kepada hamba-hamba Kami yang menjadi rasul) yaitu sebagaimana yang telah diungkapkan oleh firman-Nya yang lain, ``Aku dan rasul-rasul-Ku pasti menang." (Q.S. Al-Mujadilah, 21).\qt@no{171}}%
\qt@newcmd\qurantrans@id@mmmcmlx{%
Atau janji tersebut sebagaimana yang diungkapkan-Nya pada ayat berikut ini, yaitu, (yaitu, 'Sesungguhnya mereka itulah yang pasti mendapat pertolongan.')\qt@no{172}}%
\qt@newcmd\qurantrans@id@mmmcmlxi{%
(Dan sesungguhnya tentara Kami) yakni orang-orang mukmin (itulah yang pasti menang) atas orang-orang kafir melalui hujah, dan mendapat kemenangan atas mereka di dunia ini. Dan jika sebagian dari orang-orang yang beriman itu tidak mendapat kemenangan atas orang-orang kafir di dunia ini, maka mereka pasti mendapat kemenangan di akhirat nanti.\qt@no{173}}%
\qt@newcmd\qurantrans@id@mmmcmlxii{%
(Maka berpalinglah kamu dari mereka) yaitu dari orang-orang kafir Mekah (sampai suatu ketika") sampai Dia memerintahkannya untuk memerangi mereka.\qt@no{174}}%
\qt@newcmd\qurantrans@id@mmmcmlxiii{%
(Dan terangkanlah kepada mereka) apabila azab turun kepada mereka (maka kelak mereka akan mengetahui) akibat dari kekafiran mereka.\qt@no{175}}%
\qt@newcmd\qurantrans@id@mmmcmlxiv{%
Maka mereka mengatakan dengan nada yang mengejek, ``Kapankah turunnya azab itu?" Lalu Allah berfirman mengancam mereka yang mengatakan demikian: (Maka apakah mereka meminta supaya siksa Kami disegerakan.)\qt@no{176}}%
\qt@newcmd\qurantrans@id@mmmcmlxv{%
(Maka apabila siksaan itu turun di halaman mereka) maksudnya, di tengah-tengah mereka. Sehubungan dengan makna lafal As-Saahah ini Imam Al-Farra mengatakan, bahwa orang-orang Arab bila menyebutkan suatu kaum cukup hanya dengan menyebutkan halaman tempat mereka tinggal (maka amat buruklah) yakni seburuk-buruk pagi hari adalah (pagi hari yang dialami oleh orang-orang yang diperingatkan itu) di dalam ungkapan ayat ini terdapat Isim Zahir yang menduduki tempatnya Isim Mudhmar.\qt@no{177}}%
\qt@newcmd\qurantrans@id@mmmcmlxvi{%
(Dan berpalinglah kamu dari mereka hingga suatu ketika.)\qt@no{178}}%
\qt@newcmd\qurantrans@id@mmmcmlxvii{%
(Dan lihatlah, karena mereka juga akan melihat) ayat ini diulangi penyebutannya dengan maksud untuk mengukuhkan ancaman yang ditujukan kepada mereka, dan sekaligus sebagai penenang hati bagi Nabi saw.\qt@no{179}}%
\qt@newcmd\qurantrans@id@mmmcmlxviii{%
(Maha Suci Rabbmu Yang mempunyai keperkasaan) yakni kemenangan (dari apa yang mereka katakan) yaitu, bahwa Dia memiliki anak.\qt@no{180}}%
\qt@newcmd\qurantrans@id@mmmcmlxix{%
(Dan kesejahteraan dilimpahkan atas para rasul) yang menyampaikan ajaran tauhid dan syariat-syariat dari Allah swt.\qt@no{181}}%
\qt@newcmd\qurantrans@id@mmmcmlxx{%
(Dan segala puji bagi Allah Tuhan seru sekalian alam) Yang menolong mereka dan yang membinasakan orang-orang yang kafir.\qt@no{182}}%
\qt@newcmd\qurantrans@id@mmmcmlxxi{%
\basmalahid (Shaad) hanya Allahlah yang mengetahui artinya (demi Alquran yang mempunyai keagungan) yakni penjelasan atau kemuliaan. Jawab dari qasamnya tidak disebutkan, yaitu, bahwa perkaranya tidak seperti apa yang dikatakan oleh orang-orang kafir Mekah, tuhan itu bermacam-macam.\qt@no{1}}%
\qt@newcmd\qurantrans@id@mmmcmlxxii{%
(Sebenarnya orang-orang kafir itu) yakni penduduk Mekah yang kafir (berada dalam kesombongan) hamiyyah dan takabbur tidak mau beriman (dan permusuhan yang sengit) selalu menentang dan memusuhi Nabi saw.\qt@no{2}}%
\qt@newcmd\qurantrans@id@mmmcmlxxiii{%
(Berapa banyak) sudah berapa banyak (umat sebelum mereka yang telah Kami binasakan) yaitu dari kalangan umat-umat yang terdahulu, (lalu mereka meminta tolong) sewaktu azab menimpa mereka (padahal waktu itu bukanlah saat untuk lari melepaskan diri) artinya, untuk melarikan diri dari azab, karena segalanya sudah terlambat. Huruf Ta pada lafal Laata merupakan huruf Zaidah, dan jumlah kalimat ayat ini berkedudukan menjadi Hal atau kata keterangan keadaan dari Fa'ilnya lafal Naadau. Maksudnya, mereka meminta tolong padahal sudah tidak ada lagi jalan untuk melarikan diri, dan pula tidak ada lagi jalan untuk selamat dari azab. Akan tetapi penduduk Mekah yang kafir tidaklah mengambil pelajaran dari mereka yang telah dibinasakan itu.\qt@no{3}}%
\qt@newcmd\qurantrans@id@mmmcmlxxiv{%
(Dan mereka heran karena mereka kedatangan seorang pemberi peringatan dari kalangan mereka sendiri) yakni seorang Rasul dari kalangan mereka yang memberi peringatan dan mempertakuti mereka dengan azab neraka sesudah dibangkitkan nanti. Orang yang dimaksud adalah Nabi saw. (dan orang-orang kafir berkata,) di dalam ungkapan ini Isim Zhahir menduduki tempat Isim Mudhmar ("Ini adalah seorang ahli sihir yang banyak berdusta.)\qt@no{4}}%
\qt@newcmd\qurantrans@id@mmmcmlxxv{%
(Mengapa ia menjadikan tuhan-tuhan itu Tuhan yang satu saja?") demikian itu karena Nabi saw. pernah bersabda kepada mereka, ``Katakanlah, 'Laa Ilaaha Illallaah', artinya tiada Tuhan selain Allah. Mereka menjawab, 'Mana mungkin makhluk yang sedemikian banyak itu, semuanya dapat ditangani oleh Tuhan Yang Satu itu.' (Sesungguhnya itu benar-benar suatu hal yang sangat mengherankan") sangat aneh.\qt@no{5}}%
\qt@newcmd\qurantrans@id@mmmcmlxxvi{%
(Dan pergilah pemimpin-pemimpin mereka) dari majelis tempat mereka berkumpul, yaitu tempat Abu Thalib; di tempat itulah mereka mendengar dari Nabi saw. yang mengatakan, ``Katakanlah oleh kalian, 'Laa Ilaaha Illallaah', artinya tiada Tuhan selain Allah (seraya mengatakan, 'Pergilah kalian') maksudnya, sebagian dari mereka berkata kepada sebagian yang lain 'pergilah kalian' (dan tetaplah menyembah tuhan-tuhan kalian) artinya bertahanlah kalian di dalam menyembah tuhan-tuhan kalian itu (sesungguhnya ini) ajaran tauhid yang disampaikan Nabi itu (benar-benar suatu hal yang dikehendaki") olehnya supaya kita melakukannya.\qt@no{6}}%
\qt@newcmd\qurantrans@id@mmmcmlxxvii{%
(Kami tidak pernah mendengar hal ini dalam agama yang terakhir) maksudnya, agama Nabi Isa. (Tiada lain) tidak lain (ini hanyalah dusta yang diada-adakan) hal yang dibuat-buat saja.\qt@no{7}}%
\qt@newcmd\qurantrans@id@mmmcmlxxviii{%
(Mengapa telah diturunkan) dapat dibaca Tahqiq dapat pula dibaca Tas-hil (kepadanya) kepada Muhammad (peringatan) yakni kitab Alquran (di antara kita?) bukan diturunkan kepada orang yang tertua di antara kita atau orang yang paling terhormat di antara kita. Maksudnya, mengapa Alquran itu tidak diturunkan kepada orang yang paling tua atau orang yang paling terhormat di antara mereka. Lalu Allah berfirman, ("Sebenarnya mereka ragu terhadap Alquran-Ku) atau ragu terhadap wahyu-Ku, yaitu Alquran, karena mereka mendustakan rasul yang mendatangkannya (dan sebenarnya belumlah) artinya, belum lagi (mereka merasakan azab-Ku") seandainya mereka telah merasakannya niscaya mereka mau beriman kepada Nabi saw. tentang apa yang disampaikan olehnya dari sisi-Ku. Akan tetapi pada saat itu, yakni saat mereka merasakan azab-Ku, tidak ada gunanya lagi iman.\qt@no{8}}%
\qt@newcmd\qurantrans@id@mmmcmlxxix{%
(Atau apakah mereka itu mempunyai perbendaharaan rahmat Rabbmu Yang Maha Perkasa) yakni Maha Menang (lagi Maha Pemberi?) termasuk derajat kenabian dan hal-hal lainnya, karenanya mereka dapat memberikannya kepada siapa yang mereka kehendaki.\qt@no{9}}%
\qt@newcmd\qurantrans@id@mmmcmlxxx{%
(Atau apakah bagi mereka kerajaan langit dan bumi dan yang ada di antara keduanya?) jika mereka menduga hal tersebut (maka hendaklah mereka menaiki tangga-tangga) yang dapat mengantarkan mereka ke langit, lalu mereka mengambil wahyu dan mendatangkannya, kemudian mereka memberikannya secara khusus kepada orang-orang yang mereka kehendaki. Istifham atau kata tanya pada kedua tempat itu mengandung makna ingkar.\qt@no{10}}%
\qt@newcmd\qurantrans@id@mmmcmlxxxi{%
(Suatu tentara) maksudnya, suatu pasukan yang hina (di sana) yang telah mendustakanmu (pasti dikalahkan) menjadi sifat bagi lafal Jundun, sekalipun mereka terdiri (dari golongan-golongan yang bersekutu) lafal ayat ini menjadi sifat pula bagi lafal Jundun. Yakni suatu pasukan yang sama dengan pasukan-pasukan yang berserikat sebelum kamu yang memerangi para nabi. Pasukan-pasukan dahulu itu dapat dikalahkan dan dibinasakan, maka demikian pula mereka yang bersekutu untuk menghancurkanmu akan Kami binasakan pula.\qt@no{11}}%
\qt@newcmd\qurantrans@id@mmmcmlxxxii{%
(Telah mendustakan pula sebelum mereka itu kaum Nuh) lafal Qaum dianggap sebagai muannats karena ditinjau dari segi maknanya (Ad dan Firaun yang mempunyai patok yang banyak) disebutkan bahwa Firaun selalu mematok atau memasung setiap orang yang menentangnya, lalu kedua kaki dan tangan orang yang menentangnya itu diikatkan pada empat patok, kemudian disiksa. Oleh karenanya ia dijuluki sebagai Dzul Autaad.\qt@no{12}}%
\qt@newcmd\qurantrans@id@mmmcmlxxxiii{%
(Dan Tsamud, kaum Luth dan penduduk Aikah) yakni penduduk kota Al-Ghidhah, mereka adalah kaum Nabi Syuaib a.s. (Mereka itulah golongan-golongan yang bersekutu menentang rasul-rasul).\qt@no{13}}%
\qt@newcmd\qurantrans@id@mmmcmlxxxiv{%
(Tidak lain) tiada lain (semuanya) artinya masing-masing dari golongan-golongan yang bersekutu itu (hanyalah mendustakan rasul-rasul) karena mereka telah mendustakan salah seorang dari rasul-rasul itu, ini berarti sama saja dengan mendustakan semua rasul-rasul, karena sesungguhnya seruan dan ajaran mereka satu, yaitu menyeru kepada ajaran tauhid (maka pastilah) wajiblah bagi mereka (azab-Ku).\qt@no{14}}%
\qt@newcmd\qurantrans@id@mmmcmlxxxv{%
(Tiadalah yang ditunggu-tunggu) yang dinantikan (oleh mereka) oleh orang-orang kafir Mekah. (melainkan hanya satu teriakan) yaitu tiupan sangkakala untuk kiamat yang saat itu mereka ditimpa oleh azab (yang tidak ada bagi mereka saat berselang) maksudnya, sesudah itu tidak akan ada saat hidup kembali seperti di dunia. Lafal Fawaaqin dapat pula dibaca Fuwaaqin.\qt@no{15}}%
\qt@newcmd\qurantrans@id@mmmcmlxxxvi{%
(Dan mereka berkata) sewaktu Allah menurunkan firman-Nya, ``Adapun orang-orang yang diberikan kepadanya kitabnya dari sebelah kanannya..." (Q.S. Al-Haqqah, 19) ("Ya Rabb kami! Segerakanlah untuk kami catatan amal kami) yakni kitab catatan amal kami (sebelum hari berhisab") mereka mengatakan hal ini dengan nada yang sinis dan mengejek.\qt@no{16}}%
\qt@newcmd\qurantrans@id@mmmcmlxxxvii{%
Allah swt. berfirman, ("Bersabarlah atas segala apa yang mereka katakan; ingatlah hamba Kami Daud yang mempunyai kekuatan) dalam beribadah; tersebutlah bahwa dia sepanjang tahun selalu berpuasa sehari dan berbuka sehari; bangun pada tengah malam untuk melakukan salat, kemudian tidur selama sepertiga malam dan seperenam malam harinya lagi ia gunakan untuk salat (sesungguhnya dia amat taat) yakni selalu mengerjakan hal-hal yang menjadi keridaan Allah swt.\qt@no{17}}%
\qt@newcmd\qurantrans@id@mmmcmlxxxviii{%
(Sesungguhnya Kami menundukkan gunung-gunung untuk bertasbih bersama dia di waktu petang) di waktu salat Isyak (dan pagi) di waktu salat Duha, yaitu di waktu matahari mencapai sepenggalah.\qt@no{18}}%
\qt@newcmd\qurantrans@id@mmmcmlxxxix{%
(Dan) Kami tundukkan pula (burung-burung dalam keadaan berkumpul) berkumpul untuk bertasbih bersama dengan dia. (Masing-masing) dari gunung-gunung dan burung-burung itu (amat taat kepada-Nya) taat bertasbih kepada-Nya.\qt@no{19}}%
\qt@newcmd\qurantrans@id@mmmcmxc{%
(Dan Kami kuatkan kerajaannya) Kami kuatkan kerajaannya itu dengan para penjaga dan bala tentara; dan setiap malam mihrab Nabi Daud selalu dijaga oleh tiga puluh ribu pasukan (dan Kami berikan, kepadanya hikmah) yakni, kenabian dan ketepatan dalam berbagai perkara (dan kebijaksanaan dalam menyelesaikan perselisihan") yaitu penjelasan yang memuaskan dalam semua urusan.\qt@no{20}}%
\qt@newcmd\qurantrans@id@mmmcmxci{%
(Dan adakah) Istifham atau kata tanya di sini mengandung makna Ta'ajjub dan Tasywiq, atau dengan kata lain mengandung makna yang mendorong dan merangsang pendengar untuk mendengarkan kalimat-kalimat selanjutnya (sampai kepadamu) hai Muhammad (berita orang-orang yang berperkara ketika mereka memanjat pagar mihrab?) yaitu mihrab Nabi Daud, yang dimaksud adalah mesjidnya; demikian itu terjadi karena mereka dilarang masuk, sebab Nabi Daud sedang beribadah. Akhirnya mereka masuk dengan memanjat pagar mihrabnya. Makna ayat ialah apakah kamu telah mendengar berita dan kisah mereka?\qt@no{21}}%
\qt@newcmd\qurantrans@id@mmmcmxcii{%
(Ketika mereka masuk menemui Daud lalu ia terkejut karena kedatangan mereka. Mereka berkata, ``Janganlah kamu merasa takut) kami (adalah dua orang yang bersengketa) menurut suatu pendapat dikatakan, bahwa yang bersengketa itu adalah dua golongan, demikian itu supaya sesuai dengan dhamir jamak yang sebelumnya. Menurut pendapat yang lain disebutkan bahwa orang yang bersengketa itu dua orang, sedangkan dhamir jamak diartikan dengannya. Lafal Al-Khashmu dapat diartikan untuk satu orang atau lebih. Kedua orang itu adalah dua malaikat yang menjelma menjadi dua orang yang sedang bersengketa. Persengketaan yang terjadi di antara keduanya hanyalah sebagai perumpamaan, dimaksud untuk mengingatkan Nabi Daud a.s. atas apa yang telah dilakukannya. Karena ia mempunyai istri sebanyak sembilan puluh sembilan orang wanita. Tetapi sekalipun demikian ia melamar istri orang lain yang hanya mempunyai seorang istri kemudian ia mengawininya dan menggaulinya (salah seorang dari kami berbuat zalim kepada yang lain, maka berilah keputusan antara kami dengan adil dan janganlah kamu menyimpang dari kebenaran) janganlah kamu berlaku berat sebelah (dan tunjukilah kami) bimbinglah kami (ke jalan yang lurus) yakni keputusan yang pertengahan dan adil.\qt@no{22}}%
\qt@newcmd\qurantrans@id@mmmcmxciii{%
(Sesungguhnya saudaraku ini) maksudnya, saudara seagamaku ini (mempunyai sembilan puluh sembilan ekor kambing) ini sebagai kata kiasan dari istri (dan aku mempunyai seekor saja. Maka dia berkata, 'Serahkanlah kambing itu kepadaku) yakni jadikanlah aku sebagai suaminya (dan dia mengalahkan aku) atau dia menang atas diriku (dalam perdebatan'") yakni dalam sengketa ini, dan lawannya pun mengalah.\qt@no{23}}%
\qt@newcmd\qurantrans@id@mmmcmxciv{%
(Daud berkata, ``Sesungguhnya dia telah berbuat lalim kepadamu dengan meminta kambingmu itu) dengan maksud untuk menggabungkannya (untuk ditambahkan kepada kambingnya. Sesungguhnya kebanyakan dari orang-orang yang berserikat itu) yakni orang-orang yang terlibat dalam satu perserikatan (sebagian mereka berbuat lalim kepada sebagian yang lain, kecuali orang-orang yang beriman dan mengerjakan amal yang saleh; dan amat sedikitlah mereka ini") huruf Ma di sini untuk mengukuhkan makna sedikit. Lalu kedua malaikat itu naik ke langit dalam keadaan berubah menjadi ujud aslinya seraya berkata, ``Lelaki ini telah memutuskan perkara terhadap dirinya sendiri." Sehingga sadarlah Nabi Daud atas kekeliruannya itu. Lalu Allah berfirman, (Dan Daud yakin) yakni merasa yakin (bahwa Kami mengujinya) Kami menimpakan ujian kepadanya, berupa cobaan dalam bentuk cinta kepada perempuan itu (maka ia meminta ampun kepada Rabbnya lalu menyungkur rukuk) maksudnya bersujud (dan bertobat.)\qt@no{24}}%
\qt@newcmd\qurantrans@id@mmmcmxcv{%
(Maka Kami ampuni baginya kesalahannya itu. Dan sesungguhnya dia mempunyai kedudukan dekat pada sisi Kami) yakni dengan ditambahkan kebaikan baginya di dunia (dan tempat kembali yang baik) kelak di akhirat.\qt@no{25}}%
\qt@newcmd\qurantrans@id@mmmcmxcvi{%
(Hai Daud, sesungguhnya Kami menjadikan kamu khalifah penguasa di muka bumi) yaitu sebagai penguasa yang mengatur perkara manusia (maka berilah keputusan perkara di antara manusia dengan adil dan janganlah kamu mengikuti hawa nafsu) kemauan hawa nafsu (karena ia akan menyesatkan kamu dari jalan Allah) dari bukti-bukti yang menunjukkan keesaan-Nya. (Sesungguhnya orang-orang yang sesat dari jalan Allah) dari iman kepada Allah (mereka akan mendapat siksa yang berat karena mereka melupakan) artinya, disebabkan mereka lupa akan (hari perhitungan) hal ini ditunjukkan oleh sikap mereka yang tidak mau beriman, seandainya mereka beriman dengan adanya hari perhitungan itu, niscaya mereka akan beriman kepada Allah sewaktu mereka di dunia.\qt@no{26}}%
\qt@newcmd\qurantrans@id@mmmcmxcvii{%
(Dan Kami tidak menciptakan langit dan bumi dan apa yang ada di antara keduanya dengan batil) dengan main-main. (Yang demikian itu) yakni penciptaan hal tersebut tanpa hikmah (adalah anggapan orang-orang kafir) dari penduduk Mekah (maka neraka Waillah) Wail adalah nama sebuah lembah di neraka (bagi orang-orang yang kafir karena mereka akan masuk neraka.)\qt@no{27}}%
\qt@newcmd\qurantrans@id@mmmcmxcviii{%
(Patutkah Kami menganggap orang-orang yang beriman dan mengerjakan amal yang saleh sama dengan orang-orang yang berbuat kerusakan di muka bumi? Patutkah pula Kami menganggap orang-orang yang bertakwa sama dengan orang-orang yang berbuat maksiat?) Ayat ini diturunkan sewaktu orang-orang kafir Mekah berkata kepada orang-orang yang beriman, ``Sesungguhnya kami kelak di hari kemudian akan diberi seperti apa yang diberikan kepada kalian." Lafal Am di sini untuk menunjukkan makna sanggahan, yakni jelas tidak sama.\qt@no{28}}%
\qt@newcmd\qurantrans@id@mmmcmxcix{%
(Ini adalah sebuah Kitab) menjadi Khabar dari Mubtada yang tidak disebutkan, yakni, Ini adalah Kitab (yang Kami turunkan kepadamu penuh dengan berkah supaya mereka memperhatikan) asal lafal Yaddabbaruu adalah Yatadabbaruu, kemudian huruf Ta diidghamkan kepada huruf Dal sehingga jadilah Yaddabbaruu (ayat-ayatnya) maksudnya supaya mereka memperhatikan makna-makna yang terkandung di dalamnya, lalu mereka beriman karenanya (dan supaya mendapat pelajaran) mendapat nasihat (orang-orang yang mempunyai pikiran) yaitu yang berakal.\qt@no{29}}%
\qt@newcmd\qurantrans@id@mmmm{%
(Dan Kami karuniakan kepada Daud, Sulaiman) sebagai anaknya (dia adalah sebaik-baik hamba) maksudnya Sulaiman adalah sebaik-baik hamba. (Sesungguhnya dia amat taat) kepada Rabbnya, selalu bertasbih dan berzikir pada semua waktunya.\qt@no{30}}%
\qt@newcmd\qurantrans@id@mmmmi{%
(Ingatlah ketika dipertunjukkan kepadanya di waktu sore) yakni sesudah matahari tergelincir (kuda-kuda yang tenang di waktu berhenti) lafal Ash-Shaafinaat adalah bentuk jamak dari lafal Shaafinah, artinya kuda yang kalau berhenti berdiri pada tiga kaki, sedangkan kaki yang keempatnya berdiri pada ujung teracaknya atau berjinjit. Lafal ini berasal dari kata Shafana Yashfinu Shufuunan (dan cepat pada waktu berlari) lafal Al-Jiyaad adalah bentuk jamak dari lafal Jawaadun, artinya kuda balap. Maksud ayat, bahwa kuda-kuda itu bila berhenti tenang, dan bila berlari sangat cepat. Tersebutlah bahwa Nabi Sulaiman memiliki seribu ekor kuda, kuda-kuda itu ditampilkan di hadapannya setelah ia selesai melakukan salat Zuhur, karena ia bermaksud untuk berjihad dengan memakai kuda sebagai kendaraannya untuk melawan musuh. Sewaktu penampilan kuda baru sampai sembilan ratus ekor ternyata waktu Magrib telah tiba, sedangkan ia belum melakukan salat asar. Hal ini membuatnya berduka cita.\qt@no{31}}%
\qt@newcmd\qurantrans@id@mmmmii{%
(Maka ia berkata, ``Sesungguhnya aku menyukai) artinya, mempunyai maksud (bersenang-senang terhadap barang yang baik) yakni kuda (hingga aku lupa untuk berzikir kepada Rabbku) lupa melakukan salat asar (sehingga tertutuplah) matahari (dari pandangan mata.") artinya sehingga matahari itu tenggelam dan tidak kelihatan lagi.\qt@no{32}}%
\qt@newcmd\qurantrans@id@mmmmiii{%
(Ia berkata, ``Bawalah kuda-kuda itu kembali kepadaku") yaitu kuda-kuda yang ditampilkan tadi kemudian mereka membawanya kepada Nabi Sulaiman (lalu ia membabat kuda-kuda itu) dengan pedangnya (pada kaki-kakinya) lafal As-Suuq ini adalah bentuk jamak dari lafal Saaqun (dan pada lehernya) artinya Nabi Sulaiman menyembelih semua kuda-kuda itu kemudian memotong kakinya sebagai kurban untuk mendekatkan diri kepada Allah swt. Karena kuda-kuda itu ternyata membuatnya lalai dari salat; kemudian ia menyedekahkan daging-dagingnya. Akhirnya Allah menggantikan kudanya dengan kendaraan yang jauh lebih baik dan lebih cepat larinya, yaitu kendaraan angin; angin dapat diperintah untuk bertiup dengan membawanya ke mana saja yang ia kehendaki.\qt@no{33}}%
\qt@newcmd\qurantrans@id@mmmmiv{%
(Dan sesungguhnya Kami telah menguji Sulaiman) Kami telah mencobanya dengan suatu ujian, yaitu kerajaannya dirampas oleh orang lain. Demikian itu, karena ia pernah menikahi seorang perempuan yang ia sukai, hanya perempuan itu termasuk orang yang menyembah berhala, tanpa sepengetahuan Nabi Sulaiman. Dan tersebutlah bahwa kebesarannya itu terletak pada cincinnya kemudian pada suatu hari ketika ia bermaksud untuk pergi ke kamar mandi, ia melepaskan cincinnya itu. Lalu ia menitipkannya kepada salah seorang dari istrinya yang bernama Aminah, sebagaimana biasanya. Setelah ia pergi tiba-tiba datanglah makhluk jin yang menyerupai Nabi Sulaiman, kemudian jin itu mengambil cincin itu dari Aminah dan langsung memakainya (dan Kami dudukkan pada singgasananya sesosok jasad) yaitu jin tersebut, yang bernama Shakhr atau jin lainnya, kemudian jin itu menduduki singgasana Nabi Sulaiman. Ketika itu juga ia dikelilingi burung-burung dan lain-lainnya. Lalu muncullah Nabi Sulaiman dalam bentuk yang tidak seperti biasanya, yakni tanpa pakaian kebesaran, ia melihat bahwa di singgasananya telah duduk seseorang. Kemudian ia berkata kepada orang-orang yang ada di situ, ``Aku adalah Sulaiman." Akan tetapi orang-orang mengingkarinya (kemudian ia kembali) yakni kembali dapat merebut kebesarannya setelah selang beberapa hari; yaitu setelah ia berhasil merebut cincin kebesarannya, lalu memakainya dan duduk di atas singgasananya kembali.\qt@no{34}}%
\qt@newcmd\qurantrans@id@mmmmv{%
(Ia berkata, ``Ya Rabbku! Ampunilah aku dan anugerahkanlah kepadaku kerajaan yang tidak patut dimiliki) maksudnya, belum pernah dimiliki (oleh seorang jua pun sesudahku) artinya, yang tidak layak dimiliki oleh orang selainku. Pengertian ungkapan ini sama dengan makna yang terkandung di dalam firman-Nya yang lain, yaitu, 'Maka siapakah yang akan memberinya petunjuk sesudah Allah?' (Q.S. Al-Jatsiyah, 23) yakni selain Allah (sesungguhnya Engkaulah Yang Maha Pemberi.")\qt@no{35}}%
\qt@newcmd\qurantrans@id@mmmmvi{%
(Kemudian Kami tundukkan kepadanya angin yang berembus dengan baik menurut perintahnya) yakni berembus dengan lembut (ke mana saja yang ia kehendaki) sesuai dengan keinginan Nabi Sulaiman.\qt@no{36}}%
\qt@newcmd\qurantrans@id@mmmmvii{%
(Dan Kami tundukkan pula kepadanya setan-setan, semuanya ahli bangunan) yakni pandai membuat bangunan-bangunan yang menakjubkan dan aneh (dan penyelam) ahli menyelam di dalam laut untuk mengambil mutiara-mutiara yang terkandung di dalamnya.\qt@no{37}}%
\qt@newcmd\qurantrans@id@mmmmviii{%
(Dan setan yang lain) setan-setan yang lainnya (yang terikat) dirantai (dalam belenggu) yaitu, tangan mereka masing-masing diikatkan ke kepalanya dengan memakai belenggu.\qt@no{38}}%
\qt@newcmd\qurantrans@id@mmmmix{%
Dan Kami berfirman kepada Sulaiman (Inilah anugerah Kami; maka berikanlah) maksudnya, berikanlah sebagian daripadanya kepada orang yang kamu sukai (atau tahanlah) maksudnya, tidak memberikannya (dengan tiada pertanggungjawaban) tanpa ada hisab bagimu dalam hal ini.\qt@no{39}}%
\qt@newcmd\qurantrans@id@mmmmx{%
(Dan sesungguhnya dia mempunyai kedudukan yang dekat pada sisi Kami dan tempat kembali yang baik) penafsiran ayat ini sebagaimana yang telah lalu.\qt@no{40}}%
\qt@newcmd\qurantrans@id@mmmmxi{%
(Dan ingatlah akan hamba Kami Ayub ketika ia menyeru Rabbnya, ``Sesungguhnya aku) bahwasanya aku (diganggu oleh setan dengan kepayahan) kemudaratan (dan siksaan") yakni rasa sakit. Nabi Ayub menisbatkan atau mengaitkan hal tersebut kepada setan, sekalipun pada kenyataannya segala sesuatu itu berasal dari Allah swt. Dimaksud sebagai sopan santun Nabi Ayub terhadap Allah.\qt@no{41}}%
\qt@newcmd\qurantrans@id@mmmmxii{%
Dikatakan kepada Ayub ("Hantamkanlah) maksudnya hentakkanlah (kakimu) ke bumi, lalu ia menghantamkannya, setelah itu tiba-tiba mengalirlah mata air dari bekas hentakan kakinya. Kemudian dikatakan pula kepadanya (inilah air untuk mandi) artinya, mandilah kamu dengan air ini (yang dingin, dan untuk minum") minumlah kamu daripadanya. Segeralah Nabi Ayub mandi dan minum dan hilanglah semua penyakit yang ada di dalam dan di luar tubuhnya.\qt@no{42}}%
\qt@newcmd\qurantrans@id@mmmmxiii{%
(Dan Kami anugerahi dia dengan mengumpulkan kembali keluarganya dan Kami tambahkan kepada mereka sebanyak mereka) maksudnya, Allah menghidupkan kembali anak-anaknya yang telah mati itu, dan menambah pula kepadanya anak lain sejumlah anak yang telah mati itu (sebagai rahmat) sebagai nikmat dan karunia (dari Kami dan pelajaran) nasihat (bagi orang-orang yang mempunyai pikiran) yaitu bagi orang-orang yang berakal.\qt@no{43}}%
\qt@newcmd\qurantrans@id@mmmmxiv{%
(Dan ambillah dengan tanganmu seikat rumput) yakni seikat rumput lalang atau seikat ranting-ranting (maka pukullah dengan itu) istrimu, karena Nabi Ayub pernah bersumpah, bahwa ia sungguh akan memukul istrinya sebanyak seratus kali deraan, karena pada suatu hari ia pernah tidak menuruti perintahnya (dan janganlah kamu melanggar sumpah) dengan tidak memukulnya, lalu Nabi Ayub mengambil seratus tangkai kayu Idzkhir atau kayu lainnya, lalu ia memukulkannya sekali pukul kepada istrinya. (Sesungguhnya Kami dapati dia seorang yang sabar. Dialah sebaik-baik hamba) adalah Nabi Ayub. (Sesungguhnya dia amat taat) kepada Allah swt.\qt@no{44}}%
\qt@newcmd\qurantrans@id@mmmmxv{%
(Dan ingatlah hamba-hamba Kami; Ibrahim, Ishak dan Yakub yang mempunyai kekuatan) dalam hal beribadah (dan pandangan) yang tajam dalam masalah agama. Menurut suatu qiraat lafal 'Ibaadanaa dibaca 'Abdanaa dalam bentuk Mufrad, sedangkan lafal Ibrahiim merupakan Athaf Bayan baginya, dan lafal-lafal yang sesudahnya diathafkan kepada lafal 'Abdanaa.\qt@no{45}}%
\qt@newcmd\qurantrans@id@mmmmxvi{%
(Sesungguhnya Kami telah menyucikan mereka dengan menganugerahkan kepada mereka akhlak yang tinggi) yaitu (selalu mengingatkan manusia kepada negeri akhirat) atau alam akhirat; maksudnya mengingatkan manusia kepada hari akhirat dan menganjurkan mereka untuk beramal baik sebagai bekal untuk menghadapinya. Menurut suatu qiraat dibaca Bikhaalishati Dzikrad Daar yaitu dengan dimudhafkan untuk menunjukkan makna Bayan, atau keterangan.\qt@no{46}}%
\qt@newcmd\qurantrans@id@mmmmxvii{%
(Dan sesungguhnya mereka pada sisi Kami benar-benar termasuk orang-orang pilihan) yakni orang-orang yang terpilih (yang paling baik) lafal Al-Akhyaar ini adalah bentuk jamak dari lafal Khayyirun, artinya paling baik.\qt@no{47}}%
\qt@newcmd\qurantrans@id@mmmmxviii{%
(Dan ingatlah akan Ismail, Ilyasa') Ilyasa' adalah Yasu', dia seorang nabi; Huruf Alif dan lamnya adalah Zaidah atau tambahan (dan Zulkifli) yang masih diperselisihkan kenabiannya. Menurut suatu pendapat dikatakan, bahwa ia pernah menjamin seratus orang nabi yang berlindung kepadanya untuk menghindari pembunuhan. (Semuanya) artinya, masing-masing dari kesemuanya (termasuk orang-orang yang paling baik) lafal Al-Akhyaar adalah bentuk jamak dari lafal Khayyirun, artinya orang yang paling baik.\qt@no{48}}%
\qt@newcmd\qurantrans@id@mmmmxix{%
(Ini adalah kehormatan) bagi mereka, yaitu mendapat pujian yang baik di sini. (Dan sesungguhnya bagi orang-orang yang bertakwa) antara lain adalah termasuk mereka (benar-benar disediakan tempat kembali yang baik) nanti di akhirat.\qt@no{49}}%
\qt@newcmd\qurantrans@id@mmmmxx{%
(Yaitu surga Adn) menjadi Badal atau 'Athaf Bayan bagi lafal Lahusna Ma-aab (yang pintu-pintunya terbuka bagi mereka) artinya, pintu-pintu surga itu terbuka lebar-lebar buat mereka.\qt@no{50}}%
\qt@newcmd\qurantrans@id@mmmmxxi{%
(Di dalamnya mereka bertelekan) di atas dipan-dipan (sambil meminta buah-buahan yang banyak dan minuman di surga itu.)\qt@no{51}}%
\qt@newcmd\qurantrans@id@mmmmxxii{%
(Dan pada sisi mereka ada bidadari-bidadari yang tidak liar pandangannya) yakni mereka hanya memandang kepada suaminya dan menundukkan pandangan mata dari yang lainnya (dan sebaya umurnya) umur mereka sebaya, yaitu sekitar tiga puluh tiga tahunan. Lafal Atraabun adalah bentuk jamak dari lafal Turbun.\qt@no{52}}%
\qt@newcmd\qurantrans@id@mmmmxxiii{%
(Inilah) hal-hal yang telah disebutkan itu (apa yang dijanjikan kepada kalian) dapat dibaca Yuu'aduuna atau Tuu'aduuna, kalau dibaca Tuu'aduna berarti Iltifat (pada hari berhisab) pada saat hari berhisab.\qt@no{53}}%
\qt@newcmd\qurantrans@id@mmmmxxiv{%
(Sesungguhnya ini adalah benar-benar rezeki dari Kami yang tiada habis-habisnya) yang tak putus-putusnya; jumlah ayat ini menjadi Haal dari lafal Larizqunaa, atau sebagai Khabar kedua dari Inna, artinya selama-lamanya.\qt@no{54}}%
\qt@newcmd\qurantrans@id@mmmmxxv{%
(Beginilah) keadaan yang dialami oleh orang-orang yang beriman. (Dan sesungguhnya bagi orang-orang yang durhaka) kalimat ayat ini merupakan jumlah Isti'naf atau kalimat baru (benar-benar disediakan tempat kembali yang paling buruk.)\qt@no{55}}%
\qt@newcmd\qurantrans@id@mmmmxxvi{%
(Yaitu neraka Jahanam, yang mereka masuk ke dalamnya) mereka dimasukkan ke dalamnya (maka amat buruklah Jahanam itu sebagai tempat tinggal) artinya, hamparan yang paling buruk.\qt@no{56}}%
\qt@newcmd\qurantrans@id@mmmmxxvii{%
(Inilah) azab neraka; pengertian ini disimpulkan dari lafal sesudahnya (biarlah mereka merasakannya, minuman mereka air yang sangat panas) lagi membakar (dan nanah ahli neraka) dapat dibaca Ghassaaqun atau Ghasaaqun artinya nanah yang meleleh dari penghuni neraka.\qt@no{57}}%
\qt@newcmd\qurantrans@id@mmmmxxviii{%
(Dan azab yang lain) dapat dibaca dalam bentuk jamak sehingga menjadi Ukharu atau dapat pula dibaca dalam bentuk Mufrad sehingga bacaannya menjadi Aakharu (yang serupa itu) serupa dengan azab yang telah disebutkan tadi, yaitu air yang sangat panas dan cairan nanah (berbagai macam) beraneka ragam siksaan, maksudnya, azab mereka bermacam-macam.\qt@no{58}}%
\qt@newcmd\qurantrans@id@mmmmxxix{%
Dan dikatakan kepada mereka sewaktu mereka diseret ke dalam neraka bersama dengan para pengikutnya ("Ini adalah suatu rombongan) suatu gelombang (yang masuk berdesak-desak) dijejalkan masuk (bersama kalian") ke neraka. Kalimat itu dikatakan kepada mereka dengan nada yang keras; maka berkatalah pemimpin-pemimpin mereka yang durhaka, ("Tiadalah ucapan selamat datang kepada mereka) artinya, tiada kelapangan buat mereka (karena sesungguhnya mereka akan masuk neraka.")\qt@no{59}}%
\qt@newcmd\qurantrans@id@mmmmxxx{%
(Pengikut-pengikut mereka berkata) atau mengatakan, ("Sebenarnya kalianlah; tiada ucapan selamat datang bagi kalian, karena kalianlah yang menjerumuskan kami) ke dalam kekafiran (maka amat buruklah tempat tinggal") bagi kami dan kalian, yaitu neraka.\qt@no{60}}%
\qt@newcmd\qurantrans@id@mmmmxxxi{%
(Mereka berkata) lagi, ("Ya Rabb kami! Barang siapa yang menjerumuskan kami ke dalam azab ini, maka tambahkanlah azab kepadanya dengan berlipat ganda) dua kali lipat azab yang diterimanya, sebagai balasan dari kekafirannya (di dalam neraka.")\qt@no{61}}%
\qt@newcmd\qurantrans@id@mmmmxxxii{%
(Dan mereka berkata,) yakni orang-orang kafir Mekah, sedang mereka berada dalam neraka, ("Mengapa kami tidak melihat orang-orang yang dahulu kami anggap) sewaktu di dunia (sebagai orang-orang yang hina.")\qt@no{62}}%
\qt@newcmd\qurantrans@id@mmmmxxxiii{%
(Apakah kami dahulu menjadikan mereka olok-olokan) lafal Sukhriyyan dapat pula dibaca Sikhriyyan, yakni kami dahulu sewaktu di dunia menghina mereka. Huruf Ya pada lafal Sukhriyyan adalah Nasab; maksudnya apakah mereka tidak ada (ataukah karena tidak melihat) yakni terhalang (mata kami dari melihat mereka) sehingga mata kami tidak dapat melihat mereka. Yang mereka maksud adalah kaum muslimin yang miskin, seperti Ammar, Bilal, Shuhaib, dan Salman.\qt@no{63}}%
\qt@newcmd\qurantrans@id@mmmmxxxiv{%
(Sesungguhnya yang demikian itu pasti terjadi) sudah pasti terjadinya, yaitu (pertengkaran penghuni neraka) sebagaimana yang telah dijelaskan tadi.\qt@no{64}}%
\qt@newcmd\qurantrans@id@mmmmxxxv{%
(Katakanlah) hai Muhammad kepada orang-orang kafir Mekah! ("Sesungguhnya aku hanya seorang pemberi peringatan) seorang yang memperingatkan kalian dengan neraka (dan sekali-kali tidak ada Tuhan selain Allah Yang Maha Esa lagi Maha Mengalahkan) semua makhluk-Nya.\qt@no{65}}%
\qt@newcmd\qurantrans@id@mmmmxxxvi{%
(Rabb langit dan bumi dan apa yang ada di antara keduanya Yang Maha Perkasa) yakni Maha Menang atas semua perkara-Nya (lagi Maha Pengampun") terhadap kekasih-kekasih-Nya.\qt@no{66}}%
\qt@newcmd\qurantrans@id@mmmmxxxvii{%
(Katakanlah) kepada mereka! ("Berita itu adalah berita besar.)\qt@no{67}}%
\qt@newcmd\qurantrans@id@mmmmxxxviii{%
(Yang kalian berpaling darinya) dari Alquran yang aku beritakan dan aku datangkan kepada kalian; di dalamnya terdapat hal-hal yang tidak dapat diketahui, melainkan hanya dengan jalan wahyu. Yang dimaksud dengan berita yang besar itu ialah:\qt@no{68}}%
\qt@newcmd\qurantrans@id@mmmmxxxix{%
(Aku tiada mempunyai pengetahuan sedikit pun tentang Al-Mala'ul A'la) yakni para malaikat itu (ketika mereka berbantah-bantahan) tentang perihal Nabi Adam, ketika Allah berfirman, 'Sesungguhnya Aku hendak menjadikan seorang khalifah di muka bumi...' (Q.S. Al-Baqarah, 30)\qt@no{69}}%
\qt@newcmd\qurantrans@id@mmmmxl{%
(Tidak) tiada (diwahyukan kepadaku, melainkan bahwa sesungguhnya aku) yakni aku ini (hanyalah seorang pemberi peringatan yang nyata") artinya nyata peringatannya.\qt@no{70}}%
\qt@newcmd\qurantrans@id@mmmmxli{%
Ingatlah (ketika Rabbmu berfirman kepada malaikat, ``Sesungguhnya Aku akan menciptakan manusia dari tanah) yaitu Adam.\qt@no{71}}%
\qt@newcmd\qurantrans@id@mmmmxlii{%
(Maka apabila telah Kusempurnakan kejadiannya) telah sempurna kejadiannya (dan Kutiupkan) Kualirkan (kepadanya roh ciptaan-Ku) sehingga ia menjadi hidup. Dimudhafkannya lafal ruh kepada Allah dimaksud untuk memuliakan Nabi Adam. Roh adalah tubuh yang lembut dan tidak kelihatan oleh mata, yang membuat manusia dapat hidup karena memasuki tubuhnya (maka hendaklah kalian bersungkur dengan sujud kepadanya") sujud penghormatan dengan cara membungkukkan badan.\qt@no{72}}%
\qt@newcmd\qurantrans@id@mmmmxliii{%
(Lalu seluruh malaikat itu sujud semuanya) di dalam ayat ini terdapat dua Taukid, yaitu lafal Kulluhum dan lafal Ajma 'uuna.\qt@no{73}}%
\qt@newcmd\qurantrans@id@mmmmxliv{%
(Kecuali iblis) dia adalah bapaknya jin yang dahulunya campur bersama dengan malaikat (dia menyombongkan diri dan adalah dia termasuk orang-orang yang kafir) menurut ilmu Allah.\qt@no{74}}%
\qt@newcmd\qurantrans@id@mmmmxlv{%
(Allah berfirman, ``Hai iblis! Apakah yang menghalangi kamu sujud kepada yang telah Kuciptakan dengan kedua tangan kekuasaan-Ku?) maksudnya, yang telah Aku atur penciptaannya secara langsung; ungkapan ini dimaksud memuliakan kedudukan Nabi Adam, karena sesungguhnya setiap makhluk diciptakan oleh Allah secara langsung. (Apakah kamu menyombongkan diri) sekarang sehingga kamu tidak mau bersujud kepadanya; Istifham atau kata tanya di sini menunjukkan makna cemoohan (ataukah kamu merasa termasuk orang-orang yang lebih tinggi?") merasa tinggi diri sehingga kamu bersikap takabur tidak mau bersujud.\qt@no{75}}%
\qt@newcmd\qurantrans@id@mmmmxlvi{%
(Iblis berkata, ``Aku lebih baik daripadanya, karena Engkau ciptakan aku dari api, sedangkan dia Engkau ciptakan dari tanah.")\qt@no{76}}%
\qt@newcmd\qurantrans@id@mmmmxlvii{%
(Allah berfirman, ``Maka keluarlah kamu dari surga) menurut pendapat yang lain dari langit (sesungguhnya kamu adalah orang yang diusir) yang terusir.\qt@no{77}}%
\qt@newcmd\qurantrans@id@mmmmxlviii{%
(Sesungguhnya kutukan-Ku tetap atasmu sampai hari pembalasan") yakni hari Allah melakukan pembalasan.\qt@no{78}}%
\qt@newcmd\qurantrans@id@mmmmxlix{%
(Iblis berkata, ``Ya Rabbku! Berilah aku tenggang waktu sampai hari mereka dibangkitkan") sampai manusia dibangkitkan.\qt@no{79}}%
\qt@newcmd\qurantrans@id@mmmml{%
(Allah berfirman, ``Sesungguhnya kamu termasuk orang-orang yang diberi tangguh.)\qt@no{80}}%
\qt@newcmd\qurantrans@id@mmmmli{%
(Sampai kepada hari yang telah ditentukan waktunya") yakni waktu tiupan sangkakala yang pertama atau hari kiamat.\qt@no{81}}%
\qt@newcmd\qurantrans@id@mmmmlii{%
(Iblis menjawab, ``Demi kekuasaan Engkau, aku akan menyesatkan mereka semuanya).\qt@no{82}}%
\qt@newcmd\qurantrans@id@mmmmliii{%
(Kecuali hamba-hamba-Mu yang mukhlis di antara mereka") yakni orang-orang yang beriman.\qt@no{83}}%
\qt@newcmd\qurantrans@id@mmmmliv{%
(Allah berfirman, ``Maka yang benar adalah sumpah-Ku dan hanya kebenaran itulah yang Kukatakan") dapat dibaca Falhaqqa Wal Haqqa atau Falhaqqu Wal Haqqa; kalau dibaca Nashab berarti dinashabkan oleh Fi'il yang sesudahnya. Bila lafal pertama dinashabkan, menurut suatu pendapat dikatakan, bahwa dinashabkan oleh Fi'll yang telah disebutkan. Menurut pendapat yang lainnya lagi dinashabkan karena menjadi Mashdar, bentuk asalnya adalah Uhiqqal Haqqa. Menurut pendapat yang lainnya lagi karena huruf Qasamnya dicabut. Dibaca Rafa' atas dasar karena menjadi Mubtada yang dibuang Khabarnya, bentuk asalnya adalah Falhaqqu Minnii. Menurut pendapat yang lainnya lagi bentuk asalnya adalah, Falhaqqu Qasami, dan jawab Qasamnya ialah kalimat berikutnya, yaitu:\qt@no{84}}%
\qt@newcmd\qurantrans@id@mmmmlv{%
(Sesungguhnya Aku pasti akan memenuhi neraka Jahanam dengan jenis kamu) berikut keturunanmu (dan dengan orang-orang yang mengikuti kamu di antara mereka) yakni umat manusia (semuanya.)\qt@no{85}}%
\qt@newcmd\qurantrans@id@mmmmlvi{%
(Katakanlah! ``Aku tidak meminta kepada kalian atas hal ini) atas penyampaian risalah ini (upah sedikit pun) persenan sedikit pun dari kalian (dan bukanlah aku termasuk orang-orang yang mengada-adakan) maksudnya, membuat-buat Alquran dari diriku sendiri.\qt@no{86}}%
\qt@newcmd\qurantrans@id@mmmmlvii{%
(Tiada lain ini) Alquran ini (hanyalah peringatan) yakni nasihat dan peringatan (bagi semesta alam) maksudnya bagi jenis manusia, jin dan makhluk-makhluk yang berakal selain malaikat.\qt@no{87}}%
\qt@newcmd\qurantrans@id@mmmmlviii{%
(Dan sesungguhnya kalian akan mengetahui) hai orang-orang kafir Mekah (berita Alquran) yaitu berita kebenarannya (setelah beberapa waktu lagi") yakni pada hari kiamat nanti. Lafal 'Alima bermakna 'Arafa yakni mengetahui. Huruf Lam sebelumnya adalah Lam Qasam bagi lafal yang diperkirakan, bentuk asalnya adalah, Wallaahi Lata'lamunna.\qt@no{88}}%
\qt@newcmd\qurantrans@id@mmmmlix{%
\basmalahid (Turunnya Kitab ini) yakni Alquran; berkedudukan sebagai Mubtaba (dari Allah) berkedudukan sebagai Khabar dari Mubtada (Yang Maha Perkasa) di dalam kerajaan-Nya (lagi Maha Bijaksana) dalam tindakan-Nya.\qt@no{1}}%
\qt@newcmd\qurantrans@id@mmmmlx{%
(Sesungguhnya Kami menurunkan kepadamu) hai Muhammad (Kitab Alquran dengan membawa kebenaran) lafal Bilhaqqi berta'alluq kepada lafal Anzalnaa. (Maka sembahlah Allah dengan memurnikan ketaatan kepada-Nya) yakni dari kemusyrikan, maksudnya mentauhidkan-Nya.\qt@no{2}}%
\qt@newcmd\qurantrans@id@mmmmlxi{%
(Ingatlah, hanya kepada Allahlah ketaatan yang murni itu) tiada seorang pun yang berhak menerimanya selain-Nya. (Dan orang-orang yang mengambil selain-Nya) yang mengambil berhala-berhala (sebagai pelindung) mereka adalah orang-orang kafir Mekah yang mengatakan, ("Kami tidak menyembah mereka melainkan supaya mereka mendekatkan kami kepada Allah dengan sedekat-dekatnya.") yakni untuk mendekatkan diri kami kepada-Nya. Lafal Zulfaa adalah Mashdar yang maknanya sama dengan lafal Taqriiban/mendekatkan diri. (Sesungguhnya Allah akan memutuskan di antara mereka) dan kaum Muslimin (tentang apa yang mereka berselisih padanya) tentang masalah agama, maka kelak orang-orang yang beriman akan masuk surga dan orang-orang yang kafir akan masuk neraka. (Sesungguhnya Allah tidak menunjuki orang yang pendusta) yaitu orang yang mengatakan terhadap Allah, bahwa Dia mempunyai anak (lagi sangat ingkar) karena menyembah kepada selain-Nya.\qt@no{3}}%
\qt@newcmd\qurantrans@id@mmmmlxii{%
(Kalau sekiranya Allah hendak mengambil anak) seperti apa yang mereka katakan, yaitu sebagaimana yang disitir oleh firman-Nya, ``Tuhan Yang Maha Pemurah telah mengambil (mempunyai) anak..." (Q.S. Al-Anbiya, 26) (tentu Dia akan memilih apa yang dikehendaki-Nya di antara ciptaan-ciptaan yang diciptakan-Nya) untuk dijadikan-Nya anak; bukan seperti apa yang telah mereka katakan, bahwa para malaikat itu adalah anak-anak perempuan Allah, Uzair itu putra Allah dan juga Al-Masih adalah putra Allah (Maha Suci Allah) kalimat ini memahasucikan-Nya dari mengambil anak (Dialah Allah Yang Maha Esa lagi Maha Mengalahkan) semua makhluk-Nya.\qt@no{4}}%
\qt@newcmd\qurantrans@id@mmmmlxiii{%
(Dia menciptakan langit dan bumi dengan -tujuan- yang benar) lafal Bilhaqqi berta'alluq kepada lafal Khalaqa (Dia menutupkan) yakni memasukkan (malam atas siang) sehingga waktu malam bertambah. (dan menutupkan siang) memasukkannya (atas malam) sehingga waktu siang bertambah (dan Dia menundukkan matahari dan bulan, masing-masing berjalan) pada garis edarnya (hingga waktu yang ditentukan) yakni hari kiamat. (Ingatlah Dialah Yang Maha Perkasa) Yang Maha Menang atas semua perkara-Nya dan Yang Maha Membalas terhadap musuh-musuh-Nya (lagi Maha Pengampun) kepada kekasih-kekasih-Nya.\qt@no{5}}%
\qt@newcmd\qurantrans@id@mmmmlxiv{%
(Dia menciptakan kalian dari seorang diri) yaitu dari Nabi Adam (kemudian Dia jadikan daripadanya istrinya) yaitu Siti Hawa (dan Dia menurunkan untuk kalian binatang ternak) yakni unta, sapi, kambing, domba dan biri-biri (sebanyak delapan ekor yang berpasang-pasangan) yakni dari setiap jenis sepasang, yaitu jantan dan betina sebagaimana yang telah dijelaskan dalam surah Al-An'am (Dia menjadikan kalian dalam perut ibu kalian kejadian demi kejadian) yaitu mulai dari air mani, kemudian menjadi segumpal darah, lalu menjadi segumpal daging (dalam tiga kegelapan) yaitu gelapnya perut, gelapnya rahim dan gelapnya selaput pelindung bayi. (Yang berbuat demikian itu adalah Allah, Rabb kalian, Rabb Yang mempunyai kerajaan; tidak ada Tuhan selain Dia, maka bagaimanakah kalian dapat dipalingkan?) dari menyembah kepada-Nya, kemudian kalian menyembah yang lain-Nya.\qt@no{6}}%
\qt@newcmd\qurantrans@id@mmmmlxv{%
(Jika kalian kafir maka sesungguhnya Allah tidak memerlukan kalian dan Dia tidak meridai kekafiran bagi hamba-hamba-Nya) sekalipun ada di antara hamba-hamba-Nya yang menghendakinya (dan jika kalian bersyukur) kepada Allah, karenanya lalu kalian beriman (niscaya Dia meridai tasyakur) dapat dibaca Yardhah atau Yardhahu, artinya Dia pasti meridai tasyakur (kalian itu; dan tidaklah akan menanggung dosa) yakni seseorang (yang telah berbuat dosa akan dosa) orang (yang lain) maksudnya, seseorang yang berdosa tidak akan memikul dosa orang lain. (Kemudian kepada Rabb kalianlah kembali kalian lalu Dia memberitakan kepada kalian apa yang telah kalian kerjakan. Sesungguhnya Dia Maha Mengetahui apa yang tersimpan dalam dada) dalam kalbu kalian.\qt@no{7}}%
\qt@newcmd\qurantrans@id@mmmmlxvi{%
(Dan apabila manusia itu ditimpa) yakni orang yang kafir (kemudaratan, dia memohon -pertolongan- kepada Rabbnya) yakni merintih kepada-Nya meminta pertolongan (dengan kembali) maksudnya, bertobat (kepada-Nya; kemudian apabila Rabb memberikan nikmat kepadanya) Dia memberinya nikmat (dari-Nya lupalah dia) artinya, dia meninggalkan (akan apa yang pernah ia serukan) yaitu lupa akan rintihannya (kepada-Nya sebelum itu) lupa kepada Allah. Lafal Maa di sini bermakna Man (dan dia mengada-adakan sekutu-sekutu bagi Allah) tandingan-tandingan bagi-Nya (untuk menyesatkan) manusia; lafal liyudhilla dapat dibaca liyadhilla (dari jalan-Nya) dari agama Islam (Katakanlah, ``Bersenang-senanglah dengan kekafiranmu itu sementara waktu) selama sisa hidupmu (sesungguhnya kamu termasuk penghuni neraka.")\qt@no{8}}%
\qt@newcmd\qurantrans@id@mmmmlxvii{%
(Apakah orang) dibaca Amman, dan dapat dibaca Aman (yang beribadah) yang berdiri melakukan amal ketaatan, yakni salat (di waktu-waktu malam) di saat-saat malam hari (dengan sujud dan berdiri) dalam salat (sedangkan ia takut kepada hari akhirat) yakni takut akan azab pada hari itu (dan mengharapkan rahmat) yakni surga (Rabbnya) apakah dia sama dengan orang yang durhaka karena melakukan kekafiran atau perbuatan-perbuatan dosa lainnya. Menurut qiraat yang lain lafal Amman dibaca Am Man secara terpisah, dengan demikian berarti lafal Am bermakna Bal atau Hamzah Istifham (Katakanlah, ``Adakah sama orang-orang yong mengetahui dengan orang-orang yong tidak mengetahui?") tentu saja tidak, perihalnya sama dengan perbedaan antara orang yang alim dan orang yang jahil. (Sesungguhnya orang yang dapat menerima pelajaran) artinya, man menerima nasihat (hanyalah orang-orang yang berakal) yakni orang-orang yang mempunyai pikiran.\qt@no{9}}%
\qt@newcmd\qurantrans@id@mmmmlxviii{%
(Katakanlah, ``Hai hamba-hamba-Ku yang beriman, bertakwalah kalian kepada Rabb kalian") takutlah kalian akan azab-Nya, yaitu dengan jalan menaati-Nya. (Orang-orang yang berbuat baik di dunia ini memperoleh) melalui jalan ketaatan kepada Rabbnya (kebaikan) yakni surga. (Dan bumi Allah itu adalah luas) maka hijrahlah ke negeri yang lain meninggalkan orang-orang kafir demi menghindarkan diri dari menyaksikan hal-hal yang mungkar. (Sesungguhnya orang-orang yang bersabarlah yang dicukupkan) yang sabar di dalam menjalankan ketaatan dan sabar di dalam menahan ujian yang menimpa diri mereka (pahala mereka tanpa batas) yakni tanpa memakai neraca dan timbangan lagi.\qt@no{10}}%
\qt@newcmd\qurantrans@id@mmmmlxix{%
(Katakanlah sesungguhnya aku diperintahkan supaya menyembah Allah dengan memurnikan ketaatan kepada-Nya) dari perbuatan syirik.\qt@no{11}}%
\qt@newcmd\qurantrans@id@mmmmlxx{%
(Dan aku diperintahkan supaya menjadi orang yang pertama-tama berserah diri) dari kalangan umat ini.\qt@no{12}}%
\qt@newcmd\qurantrans@id@mmmmlxxi{%
(Katakanlah, ``Sesungguhnya aku takut akan siksaan hari yang besar jika aku durhaka kepada Rabbku").\qt@no{13}}%
\qt@newcmd\qurantrans@id@mmmmlxxii{%
(Katakanlah, ``Hanya Allah saja yang aku sembah dengan memurnikan ketaatan kepada-Nya") dari perbuatan syirik atau menyekutukan Allah.\qt@no{14}}%
\qt@newcmd\qurantrans@id@mmmmlxxiii{%
(Maka sembahlah oleh kalian apa yang kalian kehendaki selain Dia) selain-Nya. Di dalam ungkapan ayat ini terkandung makna ancaman bagi orang-orang musyrik dan sekaligus sebagai pemberitahuan, bahwa mereka tidak menyembah Allah swt. (Katakanlah, ``Sesungguhnya orang-orang yang rugi ialah orang-orang yang merugikan diri mereka sendiri dan keluarganya pada hari kiamat") karena mereka akan menjadi penghuni neraka yang abadi, dan karena mereka tidak memperoleh bidadari-bidadari yang disediakan buat mereka, jika mereka beriman.- (Ingatlah yang demikian itu adalah kerugian yang nyata) jelas sekali ruginya.\qt@no{15}}%
\qt@newcmd\qurantrans@id@mmmmlxxiv{%
(Bagi mereka gumpalan-gumpalan di atas mereka) lapisan-lapisan (dari api dan di bawah mereka pun gumpalan-gumpalan) lapisan-lapisan dari api. (Demikianlah Allah mempertakuti hamba-hamba-Nya dengan azab itu) yakni hamba-hamba-Nya yang beriman, supaya mereka bertakwa kepada-Nya; pengertian ini disimpulkan dari firman selanjutnya, yaitu, (Maka bertakwalah kepada-Ku hai hamba-hamba-Ku).\qt@no{16}}%
\qt@newcmd\qurantrans@id@mmmmlxxv{%
(Dan orang-orang yang menjauhi thaghut) yakni berhala-berhala (yaitu tidak menyembahnya dan kembali) menghadap (kepada Allah, bagi mereka berita gembira) yaitu mendapatkan surga (sebab itu sampaikanlah berita itu kepada hamba-hamba-Ku).\qt@no{17}}%
\qt@newcmd\qurantrans@id@mmmmlxxvi{%
(Yaitu, orang-orang yang mendengarkan perkataan lalu mengikuti apa yang paling baik di antaranya) mengikuti sesuatu yang mengandung kemaslahatan bagi mereka. (Mereka itulah orang-orang yang telah diberi Allah petunjuk dan mereka itulah orang-orang yang mempunyai akal) yang mempunyai pikiran.\qt@no{18}}%
\qt@newcmd\qurantrans@id@mmmmlxxvii{%
(Apakah orang yang telah pasti ketentuan azab atasnya?) termasuk orang-orang yang digolongkan oleh firman-Nya, ``Sesungguhnya akan Aku penuhi neraka jahanam..." (Q.S. As-Sajdah, 13). (Apakah kamu akan menyelamatkan) maksudnya, mengeluarkan (orang yang berada dalam neraka) kalimat ayat ini menjadi Jawab Syarath, kemudian di dalamnya terdapat Isim Zhahir yaitu lafal Man yang menduduki tempat Isim Mudhmar; dan Hamzah Istifham di sini menunjukkan makna ingkar, yakni, kamu tidak akan mampu memberikan hidayah kepadanya sehingga ia dapat kamu selamatkan dari neraka.\qt@no{19}}%
\qt@newcmd\qurantrans@id@mmmmlxxviii{%
(Tetapi orang-orang yang bertakwa kepada Rabbnya) yaitu bertakwa melalui jalan taat kepada-Nya (mereka mendapat tempat-tempat yang tinggi, di atasnya dibangun pula tempat-tempat yang tinggi, di bawahnya mengalir sungai-sungai) artinya sungai-sungai yang mengalir, baik di bawah tempat-tempat yang teratas maupun di tempat-tempat yang terbawah (sebagai janji Allah) lafal Wa'dallaahi dinashabkan oleh Fi'il yang diperkirakan keberadaannya pada sebelumnya (Allah tidak akan memungkiri janji-Nya) atau mengingkarinya.\qt@no{20}}%
\qt@newcmd\qurantrans@id@mmmmlxxix{%
(Apakah kamu tidak memperhatikan) maksudnya tidak mengetahui (bahwa sesungguhnya Allah menurunkan air dari langit, maka diatur-Nya menjadi sumber-sumber) yakni, dia memasukkan air itu ke tempat-tempat yang dapat menjadi sumber air (di bumi kemudian ditumbuhkan-Nya dengan air itu tanam-tanaman yang bermacam-macam warnanya, lalu ia menjadi kering) menjadi layu dan kering (lalu kamu melihatnya) sesudah hijau menjadi (kekuning-kuningan kemudian dijadikan-Nya hancur berderai) yakni rontok (Sesungguhnya pada yang demikian itu benar-benar terdapat pelajaran) peringatan (bagi orang-orang yang mempunyai akal) bagi orang-orang yang mau mengambil pelajaran darinya untuk menyimpulkan keesaan dan kekuasaan Allah swt.\qt@no{21}}%
\qt@newcmd\qurantrans@id@mmmmlxxx{%
(Maka apakah orang-orang yang dibukakan Allah hatinya untuk menerima Islam) sehingga ia mendapat petunjuk (lalu ia mendapat cahaya dari Rabbnya) sama dengan orang yang hatinya dikunci mati; pengertian ini tersimpul dari firman selanjutnya (Maka kecelakaan yang besarlah) artinya, azab yang besarlah (bagi mereka yang telah membatu hatinya untuk mengingat Allah) maksudnya, untuk menerima Alquran. (Mereka itu dalam kesesatan yang nyata) nyata sekali sesatnya.\qt@no{22}}%
\qt@newcmd\qurantrans@id@mmmmlxxxi{%
(Allah telah menurunkan perkataan yang paling baik yaitu Kitab) Alquran; lafal Kitaaban menjadi Badal lafal Ahsanal Hadiitsi (yang serupa) satu sama lainnya sama dalam hal Nuzhum dan hal-hal lainnya (lagi berulang-ulang) diulang-ulang di dalamnya janji dan ancaman serta hal-hal lainnya (gemetarlah karenanya) yakni gemetar karena takut di kala disebutkan ancaman-Nya (kulit orang-orang yang takut) yang merasa takut (kepada Rabbnya, kemudian menjadi tenang kulit dan kalbu mereka di waktu mengingat Allah) sewaktu ingat akan janji-Nya. (Itulah) kitab Alquran itu (petunjuk Allah, dengan Kitab itu Dia menunjuki siapa yang dikehendaki-Nya. Dan barang siapa yang disesatkan Allah, niscaya tak ada baginya seorang pemberi petunjuk.)\qt@no{23}}%
\qt@newcmd\qurantrans@id@mmmmlxxxii{%
(Maka apakah orang yang menghindarkan) supaya jangan dilemparkan (dirinya ke dalam azab yang paling buruk di hari kiamat), azab yang paling keras, seumpamanya ia dicampakkan ke dalam neraka dalam keadaan terbelenggu tangannya disatukan dengan kepalanya, sama dengan orang yang beriman kepadanya yang dimasukkan ke dalam surga? (Dan dikatakan kepada orang-orang yang aniaya) yakni orang-orang kafir Mekah ("Rasakanlah oleh kalian balasan apa yang telah kalian kerjakan") sebagai pembalasannya.\qt@no{24}}%
\qt@newcmd\qurantrans@id@mmmmlxxxiii{%
(Orang-orang yang sebelum mereka telah mendustakan) rasul-rasulnya yang mengatakan bahwa azab pasti datang (maka datanglah kepada mereka azab dari arah yang tidak mereka sangka) yang tidak mereka duga sedikit pun.\qt@no{25}}%
\qt@newcmd\qurantrans@id@mmmmlxxxiv{%
(Maka Allah merasakan kepada mereka kehinaan) artinya, mereka dihina dan direndahkan dengan berupa kutukan, pembunuhan dan lain sebagainya (pada kehidupan dunia. Dan sesungguhnya azab pada hari akhirat lebih besar kalau mereka) yakni orang-orang yang mendustakannya (mengetahui) azab akhirat, dan niscaya kalau mereka mengetahuinya maka mereka tidak akan mendustakannya.\qt@no{26}}%
\qt@newcmd\qurantrans@id@mmmmlxxxv{%
(Sesungguhnya telah Kami buatkan) telah Kami jadikan (bagi manusia dalam Alquran ini setiap macam perumpamaan supaya mereka dapat pelajaran) maksudnya, supaya mereka mau menerima nasihatnya.\qt@no{27}}%
\qt@newcmd\qurantrans@id@mmmmlxxxvi{%
(Ialah Alquran dalam bahasa Arab) ayat ini berkedudukan menjadi Hal Muakkidah atau kata keterangan yang mengukuhkan (yang tidak ada kebengkokan di dalamnya) tidak ada kekeliruan dan pertentangan (supaya mereka bertakwa) maksudnya, menghindarkan diri dari kekafiran.\qt@no{28}}%
\qt@newcmd\qurantrans@id@mmmmlxxxvii{%
(Allah telah membuat) bagi orang yang musyrik dan orang yang bertauhid (perumpamaan yaitu seorang laki-laki) lafal Rajulan ini menjadi Badal dari lafal Matsalan (yang menjadi budak milik beberapa orang yang berserikat dalam perselisihan) yaitu mereka terlihat di dalam persengketaan dan akhlak mereka sangat buruk (dan seorang budak laki-laki yang menjadi milik penuh) milik sepenuhnya (dari seorang laki-laki saja; adakah kedua budak itu sama halnya?) lafal Matsalan berkedudukan menjadi Tamyiz maksudnya, tentu saja tidak sama antara seorang budak yang menjadi milik suatu kelompok dengan seorang budak yang menjadi milik penuh seorang saja. Sesungguhnya, budak yang pertama tadi apabila disuruh oleh masing-masing dari pemilik dirinya secara sekaligus; ia bingung, siapakah yang harus ia layani di antara mereka. Ini adalah perumpamaan orang yang musyrik sedangkan budak yang kedua adalah perumpamaan bagi orang yang bertauhid. (Segala puji bagi Allah) semata (tetapi kebanyakan mereka) penduduk Mekah (tidak mengetahui) azab apakah yang akan menimpa mereka akibat kemusyrikannya, oleh karena itu mereka berbuat kemusyrikan.\qt@no{29}}%
\qt@newcmd\qurantrans@id@mmmmlxxxviii{%
(Sesungguhnya kamu) khithab ini ditujukan kepada Nabi saw. (akan mati dan mereka akan mati pula) kelak kamu akan mati dan mereka kelak akan mati pula, maka tidak usah ditunggu-tunggu datangnya mati itu. Ayat ini diturunkan sewaktu mereka merasa lambat akan kematian Nabi saw.\qt@no{30}}%
\qt@newcmd\qurantrans@id@mmmmlxxxix{%
(Kemudian sesungguhnya kalian) hai manusia tentang kelaliman-kelaliman yang telah terjadi di antara kalian (pada hari kiamat akan berbantah-bantahan di hadapan Rabb kalian.)\qt@no{31}}%
\qt@newcmd\qurantrans@id@mmmmxc{%
(Maka siapakah) artinya, tiada seorang pun (yang lebih aniaya daripada orang yang membuat-buat dusta terhadap Allah) dengan cara menisbatkan kepada-Nya mempunyai sekutu dan anak (dan mendustakan kebenaran) Alquran (ketika datang kepadanya. Bukankah di neraka Jahanam tersedia tempat tinggal) yakni tempat menetap (bagi orang-orang yang kafir?) tentu saja disediakan.\qt@no{32}}%
\qt@newcmd\qurantrans@id@mmmmxci{%
(Dan orang yang membawa kebenaran) yaitu Nabi saw. (dan membenarkannya) orang-orang mukmin. Lafal Al-Ladzii di sini bermakna Al-Ladziina, yakni jamak (mereka itulah orang-orang yang bertakwa) maksudnya, yang menghindarkan diri dari kemusyrikan.\qt@no{33}}%
\qt@newcmd\qurantrans@id@mmmmxcii{%
(Mereka memperoleh apa yang mereka kehendaki pada sisi Rabb mereka. Demikianlah balasan orang-orang yang berbuat baik) untuk diri mereka sendiri, berkat keimanan mereka.\qt@no{34}}%
\qt@newcmd\qurantrans@id@mmmmxciii{%
(Agar Allah menutupi mengampuni bagi mereka perbuatan buruk yang mereka kerjakan dan membalas mereka dengan upah yang baik dari apa yang telah mereka kerjakan) lafal Aswa-a dan Ahsana bermakna As-Sayyi dan Al-Hasan.\qt@no{35}}%
\qt@newcmd\qurantrans@id@mmmmxciv{%
(Bukankah Allah cukup untuk melindungi hamba-Nya) yakni Nabi saw. tentu saja, (Dan mereka mempertakuti kamu) khithab ini ditujukan kepada Nabi saw. sendiri (dengan sesembahan-sesembahan yang selain Allah) yakni, berhala-berhala; maksud mereka, bahwa berhala-berhala itu akan membunuhnya atau akan membuatnya cacat. (Dan siapa yang disesatkan Allah maka tidak seorang pun pemberi petunjuk baginya.)\qt@no{36}}%
\qt@newcmd\qurantrans@id@mmmmxcv{%
(Dan barang siapa yang diberi petunjuk oleh Allah, maka tidak seorang pun yang dapat menyesatkannya. Bukankah Allah Maha Perkasa) Maha Menang atas semua perkara-Nya (lagi mempunyai pembalasan) terhadap musuh-musuh-Nya. Tentu benar.\qt@no{37}}%
\qt@newcmd\qurantrans@id@mmmmxcvi{%
(Dan sungguh jika) huruf Lam bermakna qasam (kamu tanyakan kepada mereka, ``Siapakah yang menciptakan langit dan bumi?" Niscaya mereka menjawab, ``Allah." Katakanlah, ``Maka terangkanlah kepadaku tentang apa yang kalian seru) yang kalian sembah (selain Allah) yakni berhala-berhala (jika Allah hendak mendatangkan kemudaratan kepadaku, apakah berhala-berhala kalian itu dapat menghilangkan kemudaratan itu) tentu saja tidak (atau jika Allah hendak memberi rahmat kepadaku, apakah mereka dapat menahan rahmat-Nya?) tentu saja tidak pula. Menurut suatu qiraat dibaca Kaasyifaati Dhurrihii dan Mumsikaati rahmatihii (Katakanlah, ``Cukuplah Allah bagiku. Kepada-Nyalah bertawakkal orang-orang yang berserah diri") yaitu orang-orang yang percaya hanya kepada-Nya.\qt@no{38}}%
\qt@newcmd\qurantrans@id@mmmmxcvii{%
(Katakanlah, ``Hai kaumku, bekerjalah sesuai dengan keadaan kalian) kondisi kalian (sesungguhnya aku akan bekerja pula) sesuai dengan keadaanku (maka kelak kalian akan mengetahui)\qt@no{39}}%
\qt@newcmd\qurantrans@id@mmmmxcviii{%
(siapa) lafal Man adalah Isim Maushul (yang akan mendapat siksa yang menghinakannya dan lagi ditimpa) yakni ia ditimpa (oleh azab yang kekal") yang abadi, yaitu azab neraka; dan sungguh Allah telah menghinakan mereka di dalam perang Badar.\qt@no{40}}%
\qt@newcmd\qurantrans@id@mmmmxcix{%
(Sesungguhnya Kami menurunkan kepadamu Alkitab untuk manusia dengan membawa kebenaran) lafal Bil haqqi berta'alluq kepada lafal Anzalnaa (siapa yang mendapat petunjuk maka untuk dirinya sendiri) yakni hidayahnya itu untuk dirinya sendiri (dan siapa yang sesat maka sesungguhnya dia semata-mata sesat buat kerugian dirinya sendiri, dan kamu sekali-kali bukanlah orang yang bertanggung jawab terhadap mereka) lalu karenanya kamu dapat memaksa mereka untuk menerima hidayah.\qt@no{41}}%
\qt@newcmd\qurantrans@id@mmmmc{%
(Allah mematikan jiwa orang ketika matinya dan) memegang (jiwa orang yang belum mati di waktu tidurnya) artinya Allah memegangnya di waktu ia tidur (maka Dia tahan jiwa orang yang telah Dia tetapkan kematiannya dan melepaskan jiwa yang lain sampai waktu yang ditentukan) bagi kematiannya. Jiwa yang dilepaskan itu hanyalah dimatikan perasaannya saja, tetapi ia masih hidup, berbeda dengan jiwa yang benar-benar dimatikan. (Sesungguhnya pada yang demikian itu) pada hal-hal yang telah disebutkan itu (terdapat tanda-tanda) yang menunjukkan akan kekuasaan Allah (bagi kaum yang berpikir) maka karenanya mereka mengetahui, bahwa yang berkuasa melakukan hal tersebut berkuasa pula untuk membangkitkannya; dan orang-orang kafir Quraisy tidak memikirkan hal ini.\qt@no{42}}%
\qt@newcmd\qurantrans@id@mmmmci{%
(Bahkan) tetapi (mereka mengambil selain Allah) yaitu berhala-berhala sebagai tuhan-tuhan (pemberi syafaat) di hadapan Allah nanti, menurut dugaan mereka. (Katakanlah) kepada mereka, ("Apakah) mereka dapat memberikan syafaat (meskipun mereka tidak memiliki sesuatu pun) daripada syafaat itu dan tidak memiliki hal-hal lainnya pula (dan tidak berakal") yakni, kalian hanya menyembah mereka tidak ada alasan lain, hal ini tentu saja tidak patut bagi kalian.\qt@no{43}}%
\qt@newcmd\qurantrans@id@mmmmcii{%
(Katakanlah, ``Hanya kepunyaan Allahlah syafaat itu semua) maksudnya, syafaat itu khusus bagi Dia, maka tiada seorang pun yang dapat memberikannya melainkan dengan seizin Dia. (Kepunyaan-Nya kerajaan langit dan bumi. Kemudian kepada-Nya pulalah kalian dikembalikan.")\qt@no{44}}%
\qt@newcmd\qurantrans@id@mmmmciii{%
(Dan apabila disebutkan nama Allah semata) tanpa menyebut nama tuhan-tuhan mereka kesal) mendongkol dan anti pati (hati orang-orang yang tidak beriman kepada kehidupan akhirat, dan apabila nama-nama sembahan-sembahan selain Allah yang disebut) yakni berhala-berhala (tiba-tiba mereka bergirang hati.)\qt@no{45}}%
\qt@newcmd\qurantrans@id@mmmmciv{%
(Katakanlah, ``Wahai Allah) lafal Allaahumma maknanya sama dengan Yaa Allah (Pencipta langit dan bumi) yakni yang mengadakan keduanya (Yang mengetahui barang yang gaib dan yang nyata) yakni apa-apa yang gaib dan apa-apa yang nyata dapat disaksikan (Engkaulah Yang memutuskan antara hamba-hamba-Mu tentang apa yang selalu mereka perselisihkan") mengenai masalah agama, berilah aku petunjuk kepada yang benar dari apa yang mereka perselisihkan.\qt@no{46}}%
\qt@newcmd\qurantrans@id@mmmmcv{%
(Dan sekiranya orang-orang yang zalim mempunyai apa yang ada di bumi semuanya dan -ada pula- sebanyak itu besertanya, niscaya mereka akan menebus dirinya dengan itu dari siksa yang buruk pada hari kiamat. Dan jelaslah) tampaklah dengan jelas (bagi mereka azab Allah yang belum pernah mereka perkirakan) yang tidak pernah mereka duga.\qt@no{47}}%
\qt@newcmd\qurantrans@id@mmmmcvi{%
(Dan jelaslah bagi mereka akibat buruk dari apa yang telah mereka perbuat dan menimpa) mengenai (kepada mereka apa yang mereka dahulu selalu memperolok-olokkannya) yakni azab.\qt@no{48}}%
\qt@newcmd\qurantrans@id@mmmmcvii{%
(Maka apabila manusia ditimpa) yang dimaksud adalah jenis manusia (bahaya ia menyeru Kami, kemudian apabila Kami berikan kepadanya) Kami anugerahkan kepadanya (nikmat) yakni pemberian nikmat (dari Kami ia berkata, ``Sesungguhnya aku diberi nikmat itu hanyalah atas sepengetahuan) dari Allah bahwasanya aku adalah orang yang pantas untuk mendapatkannya." Atau dengan kata lain, karena kepintaranku. (Sebenarnya itu) maksudnya, ucapan itu (adalah ujian) cobaan yang ditimpakan kepada seorang hamba (tetapi kebanyakan mereka itu tidak mengetahui) bahwasanya pemberian nikmat itu merupakan Istidraj dan ujian baginya.\qt@no{49}}%
\qt@newcmd\qurantrans@id@mmmmcviii{%
(Sungguh orang-orang yang sebelum mereka juga mengatakan itu pula) yakni umat-umat sebelum mereka, seperti apa yang telah dikatakan oleh Qarun dan kaumnya yang mengatakan hal yang serupa (maka tiadalah berguna bagi mereka apa yang dahulu mereka usahakan.)\qt@no{50}}%
\qt@newcmd\qurantrans@id@mmmmcix{%
(Maka mereka ditimpa oleh akibat buruk dari apa yang mereka usahakan) yakni menerima pembalasannya. (Dan orang-orang yang lalim di antara mereka) yakni orang-orang Quraisy (akan ditimpa akibat buruk dari usahanya dan mereka tidak dapat melepaskan diri) dari azab Kami; maka Kami timpakan kepada mereka paceklik selama tujuh tahun, sesudah itu mereka dimudahkan lagi rezekinya.\qt@no{51}}%
\qt@newcmd\qurantrans@id@mmmmcx{%
(Dan tidakkah mereka mengetahui bahwa Allah melapangkan rezeki) meluaskannya (bagi siapa yang dikehendaki-Nya) sebagai ujian baginya (dan menyempitkannya?) membatasinya bagi siapa yang dikehendaki-Nya sebagai cobaan baginya. (Sesungguhnya pada yang demikian itu terdapat tanda-tanda kekuasaan Allah bagi kaum yang beriman) kepada-Nya.\qt@no{52}}%
\qt@newcmd\qurantrans@id@mmmmcxi{%
(Katakanlah, ``Hai hamba-hamba-Ku yang melampaui batas terhadap diri mereka sendiri, janganlah kalian berputus asa) dapat dibaca Laa Taqnithuu atau Laa Taqnathuu; sebagian ahli qiraat ada yang membacanya Laa Taqnuthuu; artinya janganlah kalian putus asa (dari rahmat Allah. Sesungguhnya Allah mengampuni dosa-dosa semuanya) bagi orang yang bertobat dari kemusyrikan. (Sesungguhnya Dialah Yang Maha Pengampun lagi Maha Penyayang.)\qt@no{53}}%
\qt@newcmd\qurantrans@id@mmmmcxii{%
(Dan kembalilah kalian) bertobatlah kalian (kepada Rabb kalian, dan berserah dirilah) ikhlaskanlah di dalam beramal (kepada-Nya sebelum datang kepada kalian azab kemudian kalian tidak dapat ditolong lagi) yakni azab itu tidak dapat dicegah jika kalian tidak bertobat kepada-Nya.\qt@no{54}}%
\qt@newcmd\qurantrans@id@mmmmcxiii{%
(Dan ikutilah sebaik-baik apa yang diturunkan kepada kalian dari Rabb kalian) yaitu Alquran (sebelum datang azab kepada kalian dengan tiba-tiba, sedang kalian tidak menyadari) akan kedatangannya.\qt@no{55}}%
\qt@newcmd\qurantrans@id@mmmmcxiv{%
Maka bersegeralah kalian sebelum tiba waktunya (seseorang mengatakan, ``Alangkah menyesalnya aku) lafal Yaa Hasrataa pada asalnya adalah Yaa Hasratii, artinya amat menyesallah aku (atas kelalaianku terhadap Allah) yaitu karena tidak taat kepada-Nya (dan sesungguhnya) lafal In adalah bentuk Takhfif dari Inna, asalnya Innii yakni sesungguhnya aku (aku adalah termasuk orang-orang yang benar-benar memperolok-olokan") agama-Nya dan Kitab-Nya.\qt@no{56}}%
\qt@newcmd\qurantrans@id@mmmmcxv{%
(Atau datang saatnya seseorang berkata, ``Kalau sekiranya Allah memberi petunjuk kepadaku) untuk mengerjakan ketaatan sehingga aku mendapat petunjuk (tentulah aku termasuk orang-orang yang bertakwa") yakni orang-orang yang takut akan azab-Nya.\qt@no{57}}%
\qt@newcmd\qurantrans@id@mmmmcxvi{%
(Atau datang saatnya seseorang berkata ketika ia melihat azab, ``Kalau sekiranya aku dapat kembali) ke dunia (niscaya aku akan termasuk orang-orang yang berbuat baik.") yakni, orang-orang yang beriman. Maka, dikatakan kepada mereka oleh Allah swt.:\qt@no{58}}%
\qt@newcmd\qurantrans@id@mmmmcxvii{%
("Benar, sesungguhnya telah datang ayat-ayat-Ku kepadamu) yakni, Alquran yang dapat memberikan hidayah kepadamu (lalu kamu mendustakannya dan kamu menyombongkan diri) yaitu tidak mau beriman kepada ayat-ayat-Ku (dan adalah kamu termasuk orang-orang yang kafir.")\qt@no{59}}%
\qt@newcmd\qurantrans@id@mmmmcxviii{%
(Dan pada hari kiamat kamu akan melihat orang-orang yang berbuat dusta terhadap Allah) yaitu mereka yang menisbatkan sekutu dan anak kepada-Nya (mukanya menjadi hitam. Bukankah dalam neraka Jahanam itu ada tempat) yakni tempat tinggal (bagi orang-orang yang menyombongkan diri?) artinya, tidak mau beriman; memang benar.\qt@no{60}}%
\qt@newcmd\qurantrans@id@mmmmcxix{%
(Dan Allah menyelamatkan) dari neraka Jahanam (orang-orang yang bertakwa) orang-orang yang memelihara diri dari kemusyrikan (karena kemenangan mereka) karena mereka memperoleh tempat kemenangan, yaitu surga yang menjadi tempat tinggal mereka (mereka tidak disentuh oleh keburukan dan tidak pula mereka berduka cita.)\qt@no{61}}%
\qt@newcmd\qurantrans@id@mmmmcxx{%
(Allah menciptakan segala sesuatu dan Dia memelihara segala sesuatu) Dia mengatur dan menguasainya menurut apa yang dikehendaki-Nya.\qt@no{62}}%
\qt@newcmd\qurantrans@id@mmmmcxxi{%
(Kepunyaan-Nyalah kunci-kunci perbendaharaan langit dan bumi) yakni berupa air hujan tumbuh-tumbuhan dan lain sebagainya (Dan orang-orang yang kafir terhadap ayat-ayat Allah) yaitu Alquran (mereka itulah orang-orang yang merugi) ayat ini berhubungan langsung dengan firman-Nya, ``Dan Allah menyelamatkan orang-orang yang bertakwa..." (Q.S. Az-Zumar, 61) dan ayat yang ada di antara keduanya merupakan jumlah I'tiradh atau kalimat sisipan.\qt@no{63}}%
\qt@newcmd\qurantrans@id@mmmmcxxii{%
(Katakanlah, ``Maka apakah kalian menyuruh aku menyembah selain Allah, hai orang-orang yang tidak berpengetahuan?") lafal Ghaira dinashabkan oleh lafal A'budu yang juga menjadi Ma'mul dari lafal Ta-muruunnii atau Ta-muruunanii dengan memperkirakan adanya huruf An sebelumnya.\qt@no{64}}%
\qt@newcmd\qurantrans@id@mmmmcxxiii{%
(Dan sesungguhnya telah diwahyukan kepadamu dan kepada nabi-nabi sebelummu) demi Allah ("Jika kamu mempersekutukan Allah) hai Muhammad, seumpamanya (niscaya akan hapuslah amalmu dan tentulah kamu termasuk orang-orang yang merugi.)\qt@no{65}}%
\qt@newcmd\qurantrans@id@mmmmcxxiv{%
(Karena itu, maka hendaklah Allah) saja (kamu sembah dan hendaklah kamu termasuk orang-orang yang bersyukur") atas nikmat-Nya kepadamu.\qt@no{66}}%
\qt@newcmd\qurantrans@id@mmmmcxxv{%
(Dan mereka tidak mengagungkan Allah dengan pengagungan yang semestinya) yakni mereka tidak mengenal Allah dengan pengenalan yang sebenarnya; atau, mereka tidak mengagungkan-Nya dengan pengagungan yang sesungguhnya sewaktu mereka menyekutukan-Nya dengan selain-Nya (padahal bumi seluruhnya) lafal ayat ini menjadi Hal dan maksud dari lafal Jamii'an ialah bumi yang berlapis tujuh itu (dalam genggaman kekuasaan-Nya) maksudnya berada di dalam kekuasaan dan tasharuf-Nya (pada hari kiamat dan langit digulung) dilipat menjadi satu (dengan tangan kanan-Nya) yakni dengan kekuasaan-Nya (Maha Suci dan Maha Tinggi Allah dari apa yang mereka persekutukan) bersama-Nya.\qt@no{67}}%
\qt@newcmd\qurantrans@id@mmmmcxxvi{%
(Dan ditiuplah sangkakala) pada tiupan yang pertama (maka matilah) artinya mati mendadaklah (siapa yang di langit dan di bumi kecuali siapa yang dikehendaki Allah) yaitu para bidadari, para pelayan surga dan selain keduanya. (Kemudian ditiup sangkakala itu sekali lagi maka tiba-tiba mereka) yakni semua makhluk yang telah mati itu (berdiri seraya menunggu) apa yang bakal diputuskan terhadap diri mereka.\qt@no{68}}%
\qt@newcmd\qurantrans@id@mmmmcxxvii{%
(Dan terang-benderanglah bumi) menjadi terang benderanglah ia (dengan Nur Rabbnya) sewaktu Dia menampilkan kekuasaan-Nya untuk memutuskan perkara peradilan di antara makhluk-Nya (dan diberikanlah kitab) yakni buku catatan amal perbuatan untuk menjalani perhitungan (dan didatangkanlah para nabi dan saksi-saksi) yaitu Nabi Muhammad saw. dan umatnya untuk memberikan persaksian, bahwa para rasul benar-benar telah menyampaikan risalah-Nya (dan diberi keputusan di antara mereka dengan hak) yakni secara adil (sedangkan mereka tidak dirugikan) barang sedikit pun.\qt@no{69}}%
\qt@newcmd\qurantrans@id@mmmmcxxviii{%
(Dan disempurnakan bagi tiap-tiap jiwa apa yang telah dikerjakannya) yakni balasannya (dan Dia lebih mengetahui) (apa yang mereka kerjakan) maka Dia tidak membutuhkan saksi lagi.\qt@no{70}}%
\qt@newcmd\qurantrans@id@mmmmcxxix{%
(Dan orang-orang kafir dibawa) dengan secara keras dan paksa (ke neraka Jahanam berombong-rombongan) secara bergelombang lagi terpisah-pisah. (Sehingga apabila mereka sampai ke neraka itu dibukakanlah pintu-pintunya) ayat ini menjadi Jawab dari lafal Idzaa (dan berkatalah kepada mereka penjaga-penjaganya, ``Apakah belum pernah datang kepada kalian rasul-rasul di antara kalian yang membacakan kepada kalian ayat-ayat Rabb kalian) yakni Alquran dan kitab-kitab lainnya (dan memperingatkan kepada kalian akan pertemuan dengan hari ini?" Mereka menjawab, ``Benar telah datang." Tetapi telah pasti berlaku ketetapan azab) yakni sebagaimana yang diungkapkan oleh firman-Nya yang lain, yaitu, ``Sesungguhnya akan Aku penuhi neraka Jahanam..." (Q.S. As-Sajdah, 13) (terhadap orang-orang yang kafir).\qt@no{71}}%
\qt@newcmd\qurantrans@id@mmmmcxxx{%
(Dikatakan kepada mereka, ``Masukilah pintu-pintu Jahanam itu, sedangkan kalian kekal di dalamnya") yakni kalian telah ditetapkan untuk menjadi penghuni yang abadi. (Maka seburuk-buruk tempat) maksudnya, tempat tinggal (orang-orang yang menyombongkan diri) adalah Jahanam.\qt@no{72}}%
\qt@newcmd\qurantrans@id@mmmmcxxxi{%
(Dan orang-orang yang bertakwa kepada Rabbnya dibawa) dengan lemah lembut (ke dalam surga berombong-rombongan pula, sehingga apabila mereka sampai ke surga itu pintu-pintunya telah dibuka) huruf Wau dalam ayat ini menunjukkan makna Hal dengan diperkirakan adanya lafal Qad sesudahnya (dan berkatalah kepada mereka penjaga-penjaganya, ``Kesejahteraan atas kalian, berbahagialah kalian) lafal Thibtum menjadi Hal (maka masukilah surga ini, sedangkan kalian kekal di dalamnya") telah ditetapkan untuk menjadi penghuni yang abadi di dalamnya. Jawab lafal Idzaa diperkirakan keberadaannya, yakni lalu mereka memasukinya. Dan dibawanya orang-orang yang bertakwa ke dalam surga serta dibukakannya pintu-pintu surga sebelum mereka datang, hal ini sebagai penghormatan buat mereka. Sedangkan digiringnya orang-orang kafir serta dibukakannya pintu-pintu neraka Jahanam sewaktu mereka datang dimaksud sebagai hinaan buat mereka agar panas neraka Jahanam itu dapat dirasakan oleh mereka sebelum memasukinya\qt@no{73}}%
\qt@newcmd\qurantrans@id@mmmmcxxxii{%
(Dan mereka mengucapkan) sewaktu mereka memasukinya; lafal ayat ini diathafkan kepada lafal Dukhuuluhaa yang diperkirakan keberadaannya tadi pada ayat sebelumnya, ("Segala puji bagi Allah yang telah memenuhi janji-Nya kepada kami) yakni memasukkan kami ke dalam surga (dan telah memberikan kepada kami tempat ini) surga ini (sedangkan kami diperkenankan menempati) menghuni (tempat dalam surga di mana saja kami kehendaki) karena surga itu semuanya bukanlah tempat yang dipilih antara yang satu dengan yang lainnya, karena semuanya indah (maka sebaik-baik balasan bagi orang-orang yang beramal) adalah surga.\qt@no{74}}%
\qt@newcmd\qurantrans@id@mmmmcxxxiii{%
(Dan kamu akan melihat malaikat-malaikat berlingkar) lafal Haaffiina ini menjadi Hal (di sekeliling 'Arasy) yakni dari segala penjurunya (bertasbih) menjadi Hal dari dhamir Haaffiina (seraya memuji Rabb mereka) yaitu sambil mengucapkan kalimah, Subhaanallaah Wa Bihamdihi, artinya, Maha Suci Allah dan Kami memuji kepada-Nya (dan diberi putusan di antara mereka) di antara semua makhluk (dengan hak) dengan adil, maka orang-orang yang beriman dimasukkan ke dalam surga, dan orang-orang kafir dimasukkan ke dalam neraka (dan diucapkan, ``Segala puji bagi Allah, Rabb semesta alam.") yaitu setelah kedua golongan itu telah selesai pemutusannya, lalu para malaikat mengakhirinya dengan memuji kepada Allah.\qt@no{75}}%
\qt@newcmd\qurantrans@id@mmmmcxxxiv{%
\basmalahid (Haa Miim) hanya Allah saja yang mengetahui arti dan maksudnya.\qt@no{1}}%
\qt@newcmd\qurantrans@id@mmmmcxxxv{%
(Diturunkan Kitab ini) yakni Alquran, menjadi Mubtada (dari Allah) Khabar Mubtada (Yang Maha Perkasa) di dalam kerajaan-Nya (lagi Maha Mengetahui) tentang makhluk-Nya.\qt@no{2}}%
\qt@newcmd\qurantrans@id@mmmmcxxxvi{%
(Yang mengampuni dosa) orang-orang mukmin (dan menerima tobat) mereka (lagi keras hukuman-Nya) terhadap orang-orang kafir, yaitu Dia mengeraskan azab-Nya terhadap mereka (Yang mempunyai karunia) yakni Pemberi nikmat yang lapang; Dia bersifat demikian selama-lamanya. Dimudhafkannya lafal Ghaafir kepada Adz-Dzanbi, lafal Qaabil kepada At-Taubi, dan lafal Syadiid kepada Al-Iqaabi mengandung makna Takrif sebagaimana lafal terakhir yaitu Dzith Thauli. (Tiada Tuhan selain Dia. Hanya kepada-Nyalah kembali) semua makhluk pasti kembali kepada-Nya.\qt@no{3}}%
\qt@newcmd\qurantrans@id@mmmmcxxxvii{%
(Tidak ada yang memperdebatkan tentang ayat-ayat Allah) yakni Alquran (kecuali orang-orang yang kafir) dari kalangan penduduk kota Mekah. (Karena itu janganlah mereka pulang-balik dengan bebas dari suatu kota ke kota yang lain memperdayakan kamu) mereka pulang balik untuk mencari penghidupan dalam keadaan selamat, janganlah hal itu membuatmu teperdaya, karena sesungguhnya akibat dan tempat kembali mereka adalah neraka.\qt@no{4}}%
\qt@newcmd\qurantrans@id@mmmmcxxxviii{%
(Sebelum mereka, kaum Nuh dan golongan-golongan yang bersekutu telah mendustakan) rasul-rasulnya, seperti Ad dan Tsamud serta kaum-kaum lainnya (sesudah mereka, dan tiap-tiap umat telah merencanakan makar terhadap rasul mereka untuk menawannya) untuk membunuhnya (dan mereka membantah dengan alasan yang batil untuk melenyapkan) untuk menghapuskan (kebenaran dengan yang batil itu; karena itu Aku azab mereka) dengan siksaan. (Maka betapa pedihnya azab-Ku) terhadap mereka; hal itu sesuai dengan imbalan yang harus mereka terima.\qt@no{5}}%
\qt@newcmd\qurantrans@id@mmmmcxxxix{%
(Dan demikianlah telah pasti berlaku ketetapan azab Rabbmu) sebagaimana yang telah diungkapkan-Nya dalam firman yang lain, yaitu, ``Sesungguhnya akan Aku penuhi neraka Jahanam itu..." (Q.S. As-Sajdah, 13) (terhadap orang-orang kafir, karena sesungguhnya mereka adalah penghuni neraka) lafal Annahum Ashhaabun Naari merupakan Badal dari lafal Kalimatu Rabbika.\qt@no{6}}%
\qt@newcmd\qurantrans@id@mmmmcxl{%
(Malaikat-malaikat yang memikul Arasy) berkedudukan menjadi Mubtada (dan malaikat yang berada di sekelilingnya) diathafkan kepada ayat sebelumnya (bertasbih) menjadi Khabar dari Mubtada (memuji Rabb mereka) artinya, seraya memuji-Nya yaitu mengucapkan kalimat, ``Subhaanallaah Wa Bihamdihi" (dan mereka beriman kepada-Nya) kepada Allah swt. dengan kalbu mereka, maksudnya, mereka percaya kepada keesaan-Nya (serta memintakan ampun bagi orang-orang yang beriman) seraya mengucapkan, ("Ya Rabb kami! Rahmat dan ilmu Engkau meliputi segala sesuatu) maksudnya, rahmat-Mu meliputi segala sesuatu, dan ilmu-Mu meliputi segala sesuatu. (Maka berilah ampun kepada orang-orang yang bertobat) dari kemusyrikan (dan mengikuti jalan Engkau) yakni agama Islam (dan peliharalah mereka dari siksa neraka Jahim) yang apinya menyala-nyala.\qt@no{7}}%
\qt@newcmd\qurantrans@id@mmmmcxli{%
(Ya Rabb kami! Masukkanlah mereka ke dalam surga Adn) sebagai tempat tinggal mereka (yang telah Engkau janjikan kepada mereka dan orang-orang yang saleh) lafal Man shalaha diathafkan kepada lafal Hum yang terdapat di dalam lafal Wa-adkhilhum atau yang terdapat pada lafal Wa'adtahum (dari bapak-bapak mereka, dan istri-istri mereka, dan keturunan mereka. Sesungguhnya Engkaulah Yang Maha Perkasa lagi Maha Bijaksana) di dalam perbuatan-Nya.\qt@no{8}}%
\qt@newcmd\qurantrans@id@mmmmcxlii{%
(Dan peliharalah mereka dari kejahatan) dari balasan azabnya (Dan orang-orang yang Engkau pelihara dari balasan kejahatan pada hari itu) pada hari kiamat (maka sesungguhnya telah Engkau anugerahkan rahmat kepadanya dan itulah kemenangan yang besar.")\qt@no{9}}%
\qt@newcmd\qurantrans@id@mmmmcxliii{%
(Sesungguhnya orang-orang yang kafir diserukan kepada mereka) oleh para malaikat, sedangkan mereka membenci diri mereka sendiri sewaktu mereka dimasukkan ke dalam neraka ("Sesungguhnya kebencian Allah) kepada kalian (lebih besar daripada kebencian kalian kepada diri kalian sendiri karena kalian diseru) sewaktu di dunia (untuk beriman, lalu kalian kafir.")\qt@no{10}}%
\qt@newcmd\qurantrans@id@mmmmcxliv{%
(Mereka menjawab, ``Ya Rabb kami, Engkau telah mematikan kami dua kali) yakni dua kali mati (dan telah menghidupkan kami dua kali pula) yakni dua kali hidup. Karena sesungguhnya sebelum itu mereka berupa mani, dalam keadaan mati, kemudian mereka dijadikan hidup, lalu mereka dimatikan lagi, lalu mereka dihidupkan lagi pada hari berbangkit (lalu kami mengakui dosa-dosa kami) yaitu dosa keingkaran kami terhadap adanya hari berbangkit. (Maka adakah untuk keluar) dari neraka lalu kembali lagi ke dunia, supaya kami dapat menjalani ketaatan kepada Rabb kami (sesuatu jalan") yakni jalan keluar, maka jawaban mereka adalah tidak ada.\qt@no{11}}%
\qt@newcmd\qurantrans@id@mmmmcxlv{%
(Yang demikian itu) maksudnya, azab yang kalian sedang jalani itu (adalah karena) ketika di dunia (kalian kafir apabila Allah saja disembah) artinya, kalian kafir bilamana Dia diesakan. (Dan apabila Allah dipersekutukan) menjadikan sekutu bagi-Nya (kalian percaya) kalian percaya kepada kemusyrikan itu. (Maka putusan) untuk mengazab kalian (adalah pada Allah Yang Maha Tinggi) atas semua makhluk-Nya (lagi Maha Besar) Maha Agung.\qt@no{12}}%
\qt@newcmd\qurantrans@id@mmmmcxlvi{%
(Dialah yang memperlihatkan kepada kalian tanda-tanda-Nya) yang menunjukkan akan keesaan-Nya (dan menurunkan untuk kalian rezeki dari langit) berupa hujan. (Dan tiadalah mendapat pelajaran) yakni mengambil nasihat (kecuali orang-orang yang kembali kepada Allah) dari kemusyrikan.\qt@no{13}}%
\qt@newcmd\qurantrans@id@mmmmcxlvii{%
(Maka serulah Allah) sembahlah Dia (dengan memurnikan ibadah kepada-Nya) artinya, memurnikan agama dari kemusyrikan (meskipun orang-orang kafir tidak menyukainya) sekalipun mereka tidak menyukai keikhlasan kalian kepada-Nya.\qt@no{14}}%
\qt@newcmd\qurantrans@id@mmmmcxlviii{%
(Dialah Yang Maha Tinggi derajat-Nya) maksudnya, Allah Maha Agung sifat-sifat-Nya, atau Dialah Yang mengangkat derajat orang-orang yang beriman di surga (Yang mempunyai Arasy) Yang menciptakannya (Yang menurunkan Ar-Ruuh) yakni wahyu (dari perintah-Nya) atau firman-nya (kepada siapa yang dikehendaki-Nya di antara hamba-hamba-Nya, supaya dia memperingatkan) maksudnya, orang yang menerima wahyu itu diperintahkan untuk menyampaikan wahyu-Nya kepada manusia (tentang hari pertemuan) dapat dibaca At-Talaaqi atau At-Talaaqiy dengan memakai huruf Ya. Yakni hari kiamat, karena pada hari itu penduduk langit dan penduduk bumi bertemu, dan bertemu pula antara Yang Disembah dan yang menyembah, sebagaimana dipertemukan pula antara orang yang aniaya dan orang yang dianiaya.\qt@no{15}}%
\qt@newcmd\qurantrans@id@mmmmcxlix{%
(Yaitu hari ketika mereka keluar) dari kuburnya masing-masing (tiada suatu pun dari keadaan mereka yang tersembunyi bagi Allah berfirman, ``Kepunyaan siapakah kerajaan pada hari ini?") Allah sendiri yang mengatakannya, kemudian Dia sendiri pula yang menjawabnya, yaitu, ("Hanya kepunyaan Allah Yang Maha Esa lagi Maha Mengalahkan") atas semua makhluk-Nya.\qt@no{16}}%
\qt@newcmd\qurantrans@id@mmmmcl{%
(Pada hari ini tiap-tiap jiwa diberi balasan dengan apa yang diusahakannya. Tidak ada yang dirugikan pada hari ini. Sesungguhnya Allah amat cepat hisab-Nya) Dia menghisab semua makhluk hanya dalam waktu setengah hari dunia, demikianlah menurut keterangan hadis.\qt@no{17}}%
\qt@newcmd\qurantrans@id@mmmmcli{%
(Berilah mereka peringatan dengan hari yang dekat) yakni hari kiamat. Berasal dari kata Azifar Rahiilu, artinya, Waktu berangkat telah dekat (yaitu ketika kalbu) menyesak karena dicekam rasa takut (sampai) artinya hingga sesaknya terasa sampai (di kerongkongan dengan menahan kedukaan) penuh dengan kesedihan. Lafal Kaazhimiina ini adalah Hal atau kata keterangan keadaan bagi lafal Al-Quluubu, kemudian dianggap sebagai jamak dengan memakai huruf Ya dan Nun karena diibaratkan kepada para pemiliknya. (Tiada teman-teman yang setia bagi orang-orang yang zalim) maksudnya tiada teman sejawat dan dekat (dan tidak pula mempunyai seorang pemberi syafaat yang diterima syafaatnya) yang dapat diterima syafaatnya; lafal Yuthaa'u sebagai sifat, tidak mengandung pengertian apa-apa, karena pada asalnya tiada syafaat bagi mereka, sebagaimana yang telah diungkapkan oleh firman-Nya yang lain, yaitu, ``Maka kami tidak mempunyai pemberi syafaat seorang pun." (Q.S. Asy-Syu'ara, 100). Tetapi kalau lafal Syafii'in, memang mengandung makna, karena ditinjau dari segi dugaan mereka yaitu, bahwasanya mereka memiliki pemberi-pemberi syafaat. Maksudnya, seandainya mereka memberi syafaat, niscaya syafaat mereka tidak akan diterima.\qt@no{18}}%
\qt@newcmd\qurantrans@id@mmmmclii{%
(Dia mengetahui) Allah mengetahui (mata yang khianat) ketika mencuri pandang melihat hal-hal yang diharamkan (dan apa yang disembunyikan oleh hati) yang tersimpan di dalam kalbu.\qt@no{19}}%
\qt@newcmd\qurantrans@id@mmmmcliii{%
(Dan Allah menghukum dengan keadilan. Dan sesembahan-sesembahan yang mereka seru) yang mereka sembah (selain Allah) yakni berhala-berhala (tiada dapat menghukum dengan sesuatu apa pun) mana mungkin mereka menjadi sekutu-sekutu Allah? (Sesungguhnya Allah Dialah Yang Maha Mendengar) semua perkataan mereka (lagi Maha Melihat) semua perbuatan mereka.\qt@no{20}}%
\qt@newcmd\qurantrans@id@mmmmcliv{%
(Dan apakah mereka tidak mengadakan perjalanan di muka bumi, lalu memperhatikan betapa kesudahan orang-orang yang sebelum mereka. Mereka itu adalah lebih hebat daripada mereka) menurut suatu qiraat lafal Minhum dibaca Minkum, artinya lebih hebat daripada kalian (kekuatannya dan lebih banyak bekas-bekas mereka di muka bumi) seperti bangunan-bangunan dan gedung-gedungnya (maka Allah mengazab mereka) membinasakan mereka (disebabkan dosa-dosa mereka. Dan sekali-kali mereka tidak mempunyai seorang pelindung dari azab Allah) dari siksaan-Nya.\qt@no{21}}%
\qt@newcmd\qurantrans@id@mmmmclv{%
(Yang demikian itu adalah karena telah datang kepada mereka rasul-rasul mereka dengan membawa bukti-bukti) yakni mukjizat-mukjizat yang tampak (lalu mereka kafir; maka Allah mengazab mereka. Sesungguhnya Dia Maha Kuat lagi Maha Keras hukuman-Nya.)\qt@no{22}}%
\qt@newcmd\qurantrans@id@mmmmclvi{%
(Dan sesungguhnya telah Kami utus Musa dengan membawa ayat-ayat Kami dan keterangan yang nyata) bukti yang jelas dan tampak.\qt@no{23}}%
\qt@newcmd\qurantrans@id@mmmmclvii{%
(Kepada Firaun, Haman dan Qarun; maka mereka berkata,) ``Dia (adalah seorang ahli sihir yang pendusta.")\qt@no{24}}%
\qt@newcmd\qurantrans@id@mmmmclviii{%
(Maka tatkala Musa datang kepada mereka membawa kebenaran) yakni dengan membawa perkara yang hak (dari sisi Kami, mereka berkata, ``Bunuhlah anak-anak orang-orang yang beriman bersama dengan dia dan biarkanlah hidup) yakni biarkanlah tetap hidup (wanita-wanita mereka." Dan tipu daya orang-orang kafir itu tak lain hanyalah sia-sia belaka) yakni menjerumuskan mereka sendiri dalam kebinasaan.\qt@no{25}}%
\qt@newcmd\qurantrans@id@mmmmclix{%
(Dan berkata Firaun kepada pembesar-pembesarnya, ``Biarkanlah aku membunuh Musa) karena mereka mencegahnya melakukan pembunuhan terhadap Musa (dan hendaklah ia memohon kepada Rabbnya) supaya Dia mencegah niatku yang akan membunuhnya (karena sesungguhnya aku khawatir dia akan menukar agama kalian) mencegah kalian menyembahku, lalu kalian mengikutinya (atau menimbulkan kerusakan di muka bumi") seperti melakukan pembunuhan dan lain sebagainya. Menurut suatu qiraat lafal Au dibaca Wa. Dan menurut qiraat lainnya dibaca Ay Yazhhara Fil Ardhil Fasaadu.\qt@no{26}}%
\qt@newcmd\qurantrans@id@mmmmclx{%
(Dan Musa berkata,) kepada kaumnya sedangkan dia telah mendengar ancaman Firaun tadi ("Sesungguhnya aku berlindung kepada Rabbku dan Rabb kalian dari setiap orang yang menyombongkan diri yang tidak beriman kepada hari berhisab.")\qt@no{27}}%
\qt@newcmd\qurantrans@id@mmmmclxi{%
(Dan berkatalah seorang laki-laki yang beriman di antara keluarga Firaun) menurut suatu pendapat disebutkan, bahwa ia adalah anak paman Firaun atau saudara sepupunya (yang menyembunyikan imannya, ``Apakah kalian akan membunuh seorang laki-laki karena) sebab (dia menyatakan, 'Rabbku ialah Allah' padahal dia telah datang kepada kalian dengan membawa keterangan-keterangan) yakni mukjizat-mukjizat yang jelas (dari Rabb kalian. Dan jika ia seorang pendusta maka dialah yang menanggung dosa-dustanya itu) yakni dia sendirilah yang menanggung akibat dari kedustaannya (dan jika ia seorang yang benar niscaya sebagian bencana yang diancamkannya kepada kalian akan menimpa kalian") yakni sebagian azab yang diancamkannya kepada kalian akan segera menimpa diri kalian. (Sesungguhnya Allah tidak menunjuki orang-orang yang melampaui batas) yakni orang yang musyrik (lagi pendusta) yang banyak dustanya.\qt@no{28}}%
\qt@newcmd\qurantrans@id@mmmmclxii{%
(Hai kaumku! Untuk kalianlah kerajaan pada hari ini dengan berkuasa) artinya, dengan mengalami kemenangan; lafal Zhaahiriina berkedudukan menjadi Hal atau kata keterangan keadaan (di muka bumi) di negeri Mesir. (Siapakah yang akan menolong kita dari azab Allah) dari azab-Nya bila kalian membunuh kekasih-kekasih-Nya (jika azab itu menimpa kita) tiada seorang pun yang dapat menolong kita (Firaun berkata, ``Aku tidak mengemukakan kepada kalian, melainkan apa yang aku pandang baik;) maksudnya, aku tidak memberikan isyarat kepada kalian melainkan apa yang telah aku putuskan itu, yaitu membunuh Musa (dan aku tiada menunjukkan kepada kalian, selain jalan yang benar") jalan yang mengandung kebenaran.\qt@no{29}}%
\qt@newcmd\qurantrans@id@mmmmclxiii{%
(Dan orang yang beriman itu berkata, ``Hai kaumku! Sesungguhnya aku khawatir kalian akan ditimpa -bencana- seperti peristiwa kehancuran golongan yang bersekutu) yakni azab yang telah menimpa umat-umat terdahulu, golongan demi golongan.\qt@no{30}}%
\qt@newcmd\qurantrans@id@mmmmclxiv{%
(-Yakni- seperti keadaan kaum Nuh, Ad, Tsamud dan orang-orang yang datang sesudah mereka) lafal Mitsli dalam ayat ini merupakan Badal atau pengganti keterangan dari lafal Mitsli yang sebelumnya, yang ada pada ayat di atas. Yakni, seperti pembalasan yang biasa menimpa orang-orang kafir sebelum kalian; mereka ditimpa azab di dunia. (Dan Allah tidak menghendaki berbuat kelaliman terhadap hamba-hamba-Nya.)\qt@no{31}}%
\qt@newcmd\qurantrans@id@mmmmclxv{%
(Hai kaumku, sesungguhnya aku khawatir terhadap kalian akan siksa hari panggil-memanggil) dapat dibaca At-Tanaadi atau At-Tanaadiy dengan memakai huruf Ya pada akhirnya. Artinya ialah hari kiamat, yang pada hari itu banyak sekali panggil-memanggil antara ahli surga dan ahli neraka; setiap panggilan sesuai dengan apa yang dialami oleh pemanggilnya. Maka panggilan yang mengandung kebahagiaan adalah bagi ahli surga dan panggilan yang mengandung kecelakaan adalah bagi ahli neraka; selain itu masih banyak pula jenis panggilan atau seruan lainnya.\qt@no{32}}%
\qt@newcmd\qurantrans@id@mmmmclxvi{%
(Yaitu hari ketika kalian lari berpaling ke belakang) dari tempat hisab untuk dibawa ke neraka (tidak ada bagi kalian dari Allah) yakni dari azab-Nya (seorang pun yang dapat menyelamatkan kalian) yakni yang dapat mencegah azab dari diri kalian (dan siapa yang disesatkan Allah, niscaya tidak ada baginya seorang pun yang akan memberi petunjuk.")\qt@no{33}}%
\qt@newcmd\qurantrans@id@mmmmclxvii{%
(Dan sesungguhnya telah datang Yusuf kepada kalian sebelumnya) yakni sebelum Nabi Musa; menurut suatu pendapat ia adalah Yusuf bin Yakub yang usianya dipanjangkan sampai zaman Nabi Musa; atau menurut pendapat yang lain dia adalah Yusuf bin Ibrahim bin Yusuf bin Nabi Yakub (dengan membawa keterangan-keterangan) mukjizat-mukjizat yang tampak jelas (tetapi kalian senantiasa dalam keraguan tentang apa yang dibawanya kepada kalian, sehingga ketika dia meninggal, kalian berkata,) tanpa memakai bukti yang benar lagi ("Allah tidak akan mengirim seorang rasul pun sesudahnya.") selagi kalian masih tetap dalam keadaan kafir atau ingkar kepada Nabi Yusuf dan rasul-rasul lainnya. (Demikianlah) maksudnya sebagaimana kalian disesatkan (Allah menyesatkan orang yang melampaui batas) yakni orang yang musyrik (lagi ragu-ragu) artinya, tidak percaya kepada mukjizat-mukjizat yang telah disaksikannya sendiri.\qt@no{34}}%
\qt@newcmd\qurantrans@id@mmmmclxviii{%
(Orang-orang yang memperdebatkan ayat-ayat Allah) yaitu mukjizat-mukjizatnya; kalimat ayat ini menjadi Mubtada (tanpa alasan) tanpa argumentasi (yang datang kepada mereka. Amat besar) dosa perdebatan mereka itu, lafal Kabura ini menjadi Khabar dari Mubtada (kemurkaan -bagi mereka- di sisi Allah dan di sisi orang-orang yang beriman. Demikianlah) sebagaimana disesatkan-Nya mereka (Allah mengunci mati) artinya, menyesatkan (hati setiap orang yang sombong lagi sewenang-wenang) dapat dibaca Qalbin Mutakabbirin atau Qalbi Mutakabbirin. Manakala kalbu seseorang merasa sombong, maka takaburlah pemiliknya, dan demikian pula sebaliknya. Lafal Kullun menurut dua qiraat di atas menunjukkan makna tiap-tiap orang yang memiliki kalbu yang sesat, jadi bukan ditujukan kepada semua orang.\qt@no{35}}%
\qt@newcmd\qurantrans@id@mmmmclxix{%
(Dan berkatalah Firaun, ``Hai Haman! Buatkanlah bagiku sebuah bangunan yang tinggi) bangunan pencakar langit (supaya aku sampai ke pintu-pintu.)\qt@no{36}}%
\qt@newcmd\qurantrans@id@mmmmclxx{%
(Yaitu pintu-pintu langit) maksudnya, jalan-jalan yang menuju ke arahnya (supaya aku dapat melihat) kalau dibaca Rafa', yaitu Fa-aththali'u berarti di'athafkan pada lafal Ablughu, apabila dibaca Fa-aththali'a berarti menjadi Jawab daripada Fi'il Amar, yaitu lafal Ibni (Tuhan Musa dan sesungguhnya aku memandangnya) menganggap Musa (seorang pendusta") karena ia mengatakan, bahwa ia mempunyai Tuhan selain aku. Firaun mengatakan demikian untuk mengelabui pengikut-pengikutnya. (Demikianlah dijadikan Firaun memandang baik perbuatan yang buruk itu, dan dia dihalangi dari jalan) petunjuk; dapat dibaca Shadda sehingga artinya menjadi, Dan Firaun menghalangi jalan petunjuk dapat pula dibaca Shudda yang artinya telah tertera di atas (dan tipu daya Firaun itu tidak lain hanyalah membawa kerugian) mengakibatkan kerugian.\qt@no{37}}%
\qt@newcmd\qurantrans@id@mmmmclxxi{%
(Orang yang beriman itu berkata, ``Hai kaumku! Ikutilah aku) dapat dibaca Ittabi'uuni atau Ittabi'uuniy tanpa atau dengan Ya Mutakallim (aku akan menunjukkan kepada kalian jalan yang benar) penafsirannya sebagaimana yang telah lalu.\qt@no{38}}%
\qt@newcmd\qurantrans@id@mmmmclxxii{%
(Hai kaumku, sesungguhnya kehidupan dunia ini hanyalah kesenangan -sementara-) kesenangan yang bersifat sementara lenyap (dan sesungguhnya akhirat itulah negeri yang kekal.)\qt@no{39}}%
\qt@newcmd\qurantrans@id@mmmmclxxiii{%
(Barang siapa yang mengerjakan perbuatan jahat, maka dia tidak akan dibalas melainkan sebanding dengan kejahatan itu. Dan barang siapa mengerjakan amal yang saleh, baik laki-laki maupun perempuan sedang ia dalam keadaan beriman, maka mereka akan masuk surga) dapat dibaca Yudkhaluuna atau Yadkhuluuna (mereka diberi rezeki di dalamnya tanpa hisab) diberi rezeki yang banyak tanpa perhitungan.\qt@no{40}}%
\qt@newcmd\qurantrans@id@mmmmclxxiv{%
(Hai kaumku bagaimanakah kalian, aku menyeru kalian kepada keselamatan, tetapi kalian menyeru aku ke neraka.)\qt@no{41}}%
\qt@newcmd\qurantrans@id@mmmmclxxv{%
(-Kenapa- kalian menyeruku supaya kafir kepada Allah dan mempersekutukan-Nya dengan apa yang tidak kuketahui padahal aku menyeru kalian -beriman- kepada Yang Maha Perkasa) Yang Maha Menang atas semua perkara-Nya (lagi Maha Pengampun?) kepada orang yang bertobat kepada-Nya.\qt@no{42}}%
\qt@newcmd\qurantrans@id@mmmmclxxvi{%
(Sudah pasti) yakni pastilah (bahwa apa yang kalian seru supaya aku -beriman- kepadanya) artinya, supaya aku menyembahnya (tidak dapat memperkenankan seruan apa pun) maksudnya, tidak dapat memperkenankan suatu doa pun (baik di dunia maupun di akhirat. Dan sesungguhnya kita kembali) atau kembali kita (kepada Allah dan sesungguhnya orang-orang yang melampaui batas) yakni orang-orang kafir (mereka itulah penghuni neraka.)\qt@no{43}}%
\qt@newcmd\qurantrans@id@mmmmclxxvii{%
(Kelak kalian akan ingat) bila kalian menyaksikan azab dengan mata kalian sendiri (kepada apa yang kukatakan kepada kalian. Dan aku menyerahkan urusanku kepada Allah. Sesungguhnya Allah Maha melihat akan hamba-hamba-Nya") Ia mengatakan demikian ketika mereka mengancamnya jika ia menentang agama mereka.\qt@no{44}}%
\qt@newcmd\qurantrans@id@mmmmclxxviii{%
(Maka Allah memeliharanya dari kejahatan tipu daya mereka) terhadap dirinya, yaitu mereka merencanakan akan membunuhnya (dan turunlah) menimpa (kepada keluarga Firaun) maksudnya, kepada kaumnya yang mengikutinya (azab yang buruk) yaitu ditenggelamkan.\qt@no{45}}%
\qt@newcmd\qurantrans@id@mmmmclxxix{%
Kemudian (neraka ditampakkan kepada mereka) maksudnya, mereka dibakar oleh api neraka (pada pagi dan petang) di setiap pagi dan petang (dan pada hari terjadinya kiamat) dikatakan kepada mereka, ("Masuklah kalian) hai (Firaun dan kaumnya) menurut suatu qiraat dibaca Adkhiluu yang artinya, Masukkanlah Firaun dan kaumnya. Ini merupakan perintah Allah kepada malaikat-malaikat-Nya (ke dalam azab yang sangat keras") yakni azab neraka\qt@no{46}}%
\qt@newcmd\qurantrans@id@mmmmclxxx{%
(Dan) ingatlah (ketika mereka berbantah) yaitu ketika orang-orang kafir saling berbantah-bantahan (dalam neraka, maka orang-orang yang lemah berkata kepada orang-orang yang menyombongkan diri, ``Sesungguhnya kami adalah pengikut-pengikut kalian) lafal Taba'an adalah bentuk jamak dari lafal Taabi'un (maka dapatkah kalian menghindarkan) artinya menolak (dari kami sebagian) yakni suatu bagian dari (azab api neraka?")\qt@no{47}}%
\qt@newcmd\qurantrans@id@mmmmclxxxi{%
(Orang-orang yang menyombongkan diri menjawab, ``Sesungguhnya kita semua sama-sama dalam neraka karena sesungguhnya Allah telah menetapkan keputusan antara hamba-hamba-Nya") oleh karena itu maka Dia memasukkan orang-orang yang beriman ke dalam surga, dan orang-orang kafir ke dalam neraka.\qt@no{48}}%
\qt@newcmd\qurantrans@id@mmmmclxxxii{%
(Dan orang-orang yang berada di dalam neraka berkata kepada penjaga-penjaga neraka Jahanam, ``Mohonkanlah kepada Rabb kalian supaya Dia meringankan daripada kami barang sehari) atau selama sehari (dari azab ini.")\qt@no{49}}%
\qt@newcmd\qurantrans@id@mmmmclxxxiii{%
(Para penjaga neraka Jahanam berkata) dengan nada sinis, ("Dan apakah belum datang kepada kalian rasul-rasul kalian dengan membawa keterangan-keterangan?") yakni mukjizat-mukjizat yang tampak. (Mereka menjawab, ``Benar, sudah datang") tetapi mereka kafir kepada rasul-rasul mereka itu. (Penjaga-penjaga Jahanam berkata, ``Berdoalah kalian") karena sesungguhnya kami tidak akan memberikan syafaat/pertolongan kepada orang-orang kafir. Lalu Allah berfirman, (Tiadalah doa orang-orang kafir itu melainkan sia-sia belaka) yakni tiada gunanya, karena pasti tidak akan diperkenankan.\qt@no{50}}%
\qt@newcmd\qurantrans@id@mmmmclxxxiv{%
(Sesungguhnya Kami menolong rasul-rasul Kami dan orang-orang yang beriman dalam kehidupan dunia dan pada hari berdirinya saksi-saksi) yaitu hari kiamat. Lafal Al-Asyhaad adalah bentuk jamak dari lafal Syaahidun; para saksi tersebut adalah malaikat-malaikat yang memberikan kesaksian bagi para rasul, bahwasanya rasul-rasul itu telah menyampaikan risalah-Nya dan mereka mendustakan orang-orang kafir.\qt@no{51}}%
\qt@newcmd\qurantrans@id@mmmmclxxxv{%
(Yaitu hari yang tidak berguna) dapat dibaca Yanfa'u atau Tanfa'u (bagi orang-orang zalim permintaan maafnya) yakni permintaan maaf mereka seandainya mereka meminta maaf (dan bagi merekalah laknat) yaitu dijauhkan dari rahmat Allah (dan bagi mereka tempat tinggal yang buruk) di akhirat, yaitu mendapat azab yang sangat pedih.\qt@no{52}}%
\qt@newcmd\qurantrans@id@mmmmclxxxvi{%
(Dan sesungguhnya telah Kami berikan petunjuk kepada Musa) berupa kitab Taurat dan mukjizat-mukjizat (dan Kami wariskan kepada Bani Israel) sesudah Musa tiada (kitab) yakni Taurat.\qt@no{53}}%
\qt@newcmd\qurantrans@id@mmmmclxxxvii{%
(Untuk menjadi petunjuk) sebagai petunjuk (dan peringatan bagi orang-orang yang berpikir) sebagai peringatan buat orang-orang yang berakal.\qt@no{54}}%
\qt@newcmd\qurantrans@id@mmmmclxxxviii{%
(Maka bersabarlah kamu) hai Muhammad (karena sesungguhnya janji Allah itu) untuk menolong kekasih-kekasih-Nya (benar) dan kamu beserta orang-orang yang mengikutimu adalah termasuk kekasih-kekasih-Nya (dan mohonlah ampun untuk dosamu) supaya hal ini dijadikan teladan bagi umatmu (dan bertasbihlah) yakni, salatlah seraya (memuji Rabbmu pada waktu petang) yaitu sesudah matahari tergelincir (dan pagi) yang dimaksud adalah salat lima waktu.\qt@no{55}}%
\qt@newcmd\qurantrans@id@mmmmclxxxix{%
(Sesungguhnya orang-orang yang memperdebatkan tentang ayat-ayat Allah) yakni Alquran (tanpa alasan) tanpa argumentasi (yang sampai kepada mereka, tidak ada) (dalam dada mereka melainkan hanyalah keinginan akan kebesaran) yakni tinggi diri dan tamak ingin mengatasi kamu (yang mereka sekali-kali tiada akan mencapainya maka mintalah perlindungan) dari kejahatan mereka (kepada Allah. Sesungguhnya Dia Maha Mendengar) akan semua perkataan mereka (lagi Maha Melihat) keadaan mereka; ayat ini diturunkan berkenaan dengan orang-orang yang ingkar kepada hari berbangkit.\qt@no{56}}%
\qt@newcmd\qurantrans@id@mmmmcxc{%
(Sesungguhnya penciptaan langit dan bumi) yakni permulaannya (lebih besar daripada penciptaan manusia) untuk yang kedua kalinya, yaitu mengulanginya (tetapi kebanyakan manusia) yakni orang-orang kafir Mekah (tidak mengetahui) hal tersebut, perihal mereka sama dengan orang buta, sedangkan orang yang mengetahui hal tersebut perumpamaannya sama dengan orang yang melihat.\qt@no{57}}%
\qt@newcmd\qurantrans@id@mmmmcxci{%
(Dan tidaklah sama orang yang buta dengan orang yang melihat, dan) tidak sama pula (orang-orang yang beriman serta mengerjakan amal saleh) yaitu orang yang selalu berbuat kebaikan (dengan orang-orang yang durhaka) di dalam lafal ayat ini terdapat tambahan huruf Laa (Sedikit sekali kalian mengambil pelajaran) mengambil nasihat; dapat dibaca Yatadzakkaruuna atau Tatadzakkaruuna, yakni kesadaran mereka terhadap hal ini sangat sedikit.\qt@no{58}}%
\qt@newcmd\qurantrans@id@mmmmcxcii{%
(Sesungguhnya hari kiamat pasti akan datang, tidak ada keraguan) artinya, tidak diragukan lagi (tentangnya, akan tetapi kebanyakan manusia tidak beriman) kepadanya.\qt@no{59}}%
\qt@newcmd\qurantrans@id@mmmmcxciii{%
(Dan Rabb kalian berfirman, ``Berdoalah kepada-Ku, niscaya akan Kuperkenankan bagi kalian) maksudnya, sembahlah Aku, niscaya Aku akan memberi pahala kepada kalian. Pengertian ini disimpulkan dari ayat selanjutnya, yaitu, (Sesungguhnya orang-orang yang menyombongkan diri dari menyembah-Ku akan masuk) dapat dibaca Sayadkhuluuna atau Sayudkhaluuna, menurut bacaan yang kedua artinya, mereka akan dimasukkan ke dalam (neraka Jahanam dalam keadaan hina dina") dalam keadaan terhina.\qt@no{60}}%
\qt@newcmd\qurantrans@id@mmmmcxciv{%
(Allahlah yang menjadikan malam untuk kalian supaya kalian beristirahat padanya; dan menjadikan siang terang-benderang) dikaitkannya pengertian melihat kepada siang hanyalah majaz atau kata kiasan belaka, karena pada siang hari manusia dapat melihat. (Sesungguhnya Allah benar-benar mempunyai karunia yang dilimpahkan atas manusia, akan tetapi kebanyakan manusia tidak bersyukur) kepada Allah, malahan mereka tidak beriman kepada-Nya.\qt@no{61}}%
\qt@newcmd\qurantrans@id@mmmmcxcv{%
(Yang demikian itu adalah Allah, Rabb kalian, Pencipta segala sesuatu, tiada Tuhan melainkan Dia, maka bagaimanakah kalian dapat dipalingkan?) maksudnya, bagaimanakah kalian dipalingkan dari iman kepada-Nya, padahal bukti-bukti-Nya sudah jelas.\qt@no{62}}%
\qt@newcmd\qurantrans@id@mmmmcxcvi{%
(Seperti demikianlah dipalingkan) artinya sebagaimana mereka dipalingkan, maka dipalingkan pula (orang-orang yang terhadap ayat-ayat Allah) yakni mukjizat-mukjizat-Nya (mereka ingkar.)\qt@no{63}}%
\qt@newcmd\qurantrans@id@mmmmcxcvii{%
(Allahlah yang menjadikan bumi bagi kalian sebagai tempat menetap dan langit sebagai atap) maksudnya, yang menaungi (dan membentuk kalian lalu membaguskan rupa kalian serta memberi kalian rezeki dengan sebagian yang baik-baik. Yang demikian itu adalah Allah Rabb kalian, Maha Agung Allah, Rabb semesta Alam.)\qt@no{64}}%
\qt@newcmd\qurantrans@id@mmmmcxcviii{%
(Dialah Yang hidup kekal tiada Tuhan melainkan Dia, maka serulah Dia) sembahlah Dia (dengan memurnikan ibadah kepada-Nya) dari kemusyrikan. (Segala puji bagi Allah Rabb semesta alam.)\qt@no{65}}%
\qt@newcmd\qurantrans@id@mmmmcxcix{%
(Katakanlah, ``Sesungguhnya aku dilarang menyembah sesembahan yang kalian seru) yang kalian sembah (selain Allah setelah datang kepadaku keterangan-keterangan) yakni bukti-bukti tauhid (dari Rabbku, dan aku diperintahkan supaya tunduk patuh kepada Rabb semesta alam.)\qt@no{66}}%
\qt@newcmd\qurantrans@id@mmmmcc{%
(Dialah Yang menciptakan kalian dari tanah) yang menciptakan bapak moyang kalian yaitu Nabi Adam dari tanah liat (kemudian dari setetes nuthfah) yakni air mani (sesudah itu dari segumpal darah) yakni dari kental (kemudian dikeluarkan-Nya kalian sebagai seorang anak) lafal Thiflan sekalipun bentuknya mufrad atau tunggal, bermakna jamak (kemudian) dibiarkan-Nya kalian hidup (supaya kalian sampai kepada masa dewasa) masa sempurnanya kekuatan kalian, yaitu di antara umur tiga puluh sampai dengan empat puluh tahun (kemudian -dibiarkan-Nya kalian hidup- sampai tua) dapat dibaca Syuyuukhan atau Syiyuukhan (di antara kalian ada yang diwafatkan sebelum itu) sebelum dewasa dan sebelum mencapai usia tua. Dia melakukan hal tersebut kepada kalian supaya kalian hidup (dan supaya kalian sampai pada ajal yang ditentukan) yakni waktu yang telah dibataskan bagi hidup kalian (dan supaya kalian memahami) bukti-bukti yang menunjukkan keesaan-Nya, kemudian kalian beriman kepada-Nya.\qt@no{67}}%
\qt@newcmd\qurantrans@id@mmmmcci{%
(Dialah yang menghidupkan dan yang mematikan, maka apabila Dia menetapkan sesuatu urusan) artinya, Dia berkehendak mewujudkan sesuatu (Dia hanya berkata kepadanya, 'Jadilah!' maka jadilah ia.") lafal Fayakuunu dapat pula dibaca Fayakuuna akan tetapi dengan memperkirakan adanya huruf An sebelumnya. Yakni, sesuatu yang dikehendaki itu langsung ada sesudah ada kehendak-Nya, sebagaimana yang telah digambarkan oleh makna firman yang tadi itu.\qt@no{68}}%
\qt@newcmd\qurantrans@id@mmmmccii{%
(Apakah kamu tidak melihat kepada orang-orang yang membantah ayat-ayat Allah?) membantah Alquran. (Bagaimanakah) (mereka dapat dipalingkan) dari iman?\qt@no{69}}%
\qt@newcmd\qurantrans@id@mmmmcciii{%
(Orang-orang yang mendustakan Alkitab) yakni Al-Qur'an (dan wahyu yang dibawa oleh rasul-rasul Kami yang telah Kami utus) dengan membawa ajaran tauhid dan berita tentang adanya hari berbangkit; mereka adalah orang-orang kafir Mekah. (Kelak mereka akan mengetahui) akibat dari kedustaan mereka.\qt@no{70}}%
\qt@newcmd\qurantrans@id@mmmmcciv{%
(Ketika belenggu dipasang di leher mereka) lafal Idz di sini bermakna Idzaa yakni ketika (dan rantai-rantai) pun dipasang pula di leher mereka. Lafal As-Salaasilu ini diathafkan kepada lafal Al-Aghlaalu. Atau berkedudukan menjadi Mubtada sedangkan Khabarnya tidak disebutkan, yaitu lafal Fii Arjulihim. Dengan demikian maka artinya ialah, Dan rantai-rantai pun dipasang pada kaki mereka Atau Khabar lafal As-Salaasilu ini ialah ayat berikutnya, yaitu (seraya mereka diseret) dengannya.\qt@no{71}}%
\qt@newcmd\qurantrans@id@mmmmccv{%
(Ke dalam air yang sangat panas) yakni neraka Jahanam (kemudian mereka dibakar dalam api) maksudnya, mereka dibakar oleh api neraka.\qt@no{72}}%
\qt@newcmd\qurantrans@id@mmmmccvi{%
(Kemudian dikatakan kepada mereka) sebagai celaan dan penelanjangan, ("Manakah berhala-berhala yang selalu kalian persekutukan?)\qt@no{73}}%
\qt@newcmd\qurantrans@id@mmmmccvii{%
(Selain Allah?") yang kalian sembah selain-Nya; yang dimaksud adalah berhala-berhala. (Mereka menjawab, ``Mereka telah hilang lenyap) artinya, telah tiada (dari kami) maka kami tidak melihat mereka (bahkan kami dahulu tiada pernah menyembah sesuatu") mereka mengingkari penyembahan mereka kepada berhala-berhala itu. Kemudian berhala-berhala sesembahan mereka itu didatangkan, selanjutnya dikatakan kepada mereka, sebagaimana yang disebutkan dalam ayat yang lain, yaitu firman-Nya, ``Sesungguhnya kalian dan apa yang kalian sembah selain Allah, adalah makanan Jahanam." (Q.S. Al-Anbiya, 98). (Seperti demikianlah) yakni sebagaimana disesatkan-Nya orang-orang yang mendustakan Alquran (Allah menyesatkan orang-orang kafir.)\qt@no{74}}%
\qt@newcmd\qurantrans@id@mmmmccviii{%
Dikatakan pula kepada mereka, ("Yang demikian itu) yakni azab itu (disebabkan kalian bersuka ria di muka bumi dengan tidak benar) yaitu melakukan perbuatan syirik dan ingkar kepada adanya hari berbangkit (dan karena kalian selalu bersuka ria) artinya, terlalu berlebih-lebihan di dalam bersuka ria.\qt@no{75}}%
\qt@newcmd\qurantrans@id@mmmmccix{%
(Masuklah kalian ke pintu-pintu neraka Jahanam, sedangkan kalian kekal di dalamnya. Maka itulah seburuk-buruk tempat) yakni tempat tinggal (bagi orang-orang yang sombong.")\qt@no{76}}%
\qt@newcmd\qurantrans@id@mmmmccx{%
(Maka bersabarlah kamu, sesungguhnya janji Allah) yang akan mengazab mereka (adalah benar; maka jika Kami perlihatkan kepadamu) lafal Immaa adalah berasal dari In Syarthiyah yang diidgamkan kepada Maa Zaidah yang berfungsi mengukuhkan makna Syarat di awal Fi'il, kemudian menyusul Nun Taukid sesudahnya yang juga mengukuhkan makna syarath tadi (sebagian siksa yang Kami ancamkan kepada mereka) yakni semasa kamu masih hidup Kami menurunkan sebagian azab kepada mereka. Jawab Syarathnya tidak disebutkan, yaitu lafal Fadzaaka, yakni maka itulah sebagian dari azab Kami (atau pun Kami wafatkan kamu) yaitu sebelum mereka diazab (namun kepada Kami sajalah mereka dikembalikan) lalu Kami akan mengazab mereka dengan siksaan yang sangat keras. Jawab Syarath yang telah disebutkan di atas tadi hanyalah untuk Ma'thuf saja, yakni hanya untuk kalimah, Fa-immaa Nuriyannaka Ba'dhal Ladzii Na'iduhum, Fadzaaka.\qt@no{77}}%
\qt@newcmd\qurantrans@id@mmmmccxi{%
(Dan sesungguhnya telah Kami utus rasul-rasul sebelum kamu; di antara mereka ada yang Kami ceritakan kepadamu dan di antara mereka ada -pula- yang tidak Kami ceritakan kepadamu) menurut suatu riwayat diceritakan, bahwa Allah swt. telah mengutus delapan ribu orang nabi untuk menjadi rasul; yang empat ribu orang di antaranya dari kaum Bani Israel, sedangkan yang empat ribu orang lagi dari kalangan umat-umat selain Bani Israel. (Tidak dapat bagi seorang rasul) di antara rasul-rasul itu (membawa suatu mukjizat, melainkan dengan seizin Allah) karena mereka juga hamba-hamba Allah yang diperintah oleh-Nya (maka apabila telah datang perintah Allah) yang memerintahkan supaya azab diturunkan atas orang-orang kafir (diputuskan) semua perkara di antara rasul-rasul dan orang-orang yang mendustakannya (dengan adil. Dan ketika itu rugilah orang-orang yang berpegang kepada yang batil) yakni, keputusan itu merupakan kemenangan bagi rasul-rasul dan kerugian bagi orang-orang yang mendustakannya; pada hakikatnya sebelum itu pun orang-orang yang mendustakan para rasul sudah merugi.\qt@no{78}}%
\qt@newcmd\qurantrans@id@mmmmccxii{%
(Allahlah yang menjadikan binatang ternak untuk kalian) menurut suatu pendapat dikatakan, bahwa yang dimaksud hanyalah unta saja. Tetapi menurut pendapat yang kuat, ternak yang dimaksud mencakup pula sapi dan kambing (sebagiannya untuk kalian kendarai dan sebagiannya untuk kalian makan.)\qt@no{79}}%
\qt@newcmd\qurantrans@id@mmmmccxiii{%
(Dan -ada lagi- manfaat-manfaat lain pada binatang ternak itu untuk kalian) yaitu berupa air susu, keturunan binatang ternak itu dan juga dari bulu-bulunya (dan supaya kalian mencapai suatu keperluan yang tersimpan dalam hati) maksudnya, dapat kalian gunakan untuk mengangkut barang-barang ke berbagai negeri (dengan mengendarainya) di daratan (dan dengan menaiki bahtera) yakni perahu melalui jalan laut (kalian dapat menaiki semuanya.)\qt@no{80}}%
\qt@newcmd\qurantrans@id@mmmmccxiv{%
(Dan Dia memperlihatkan kepada kalian tanda-tanda-Nya; maka tanda-tanda Allah yang manakah) yakni tanda-tanda yang menunjukkan kepada keesaan-Nya (yang kalian ingkari?) Istifham atau kata tanya di sini mengandung makna cemoohan. Disebutkan lafal Ayyun dalam bentuk Mudzakkar adalah lebih terkenal daripada bentuk Ta'nitsnya.\qt@no{81}}%
\qt@newcmd\qurantrans@id@mmmmccxv{%
(Maka apakah mereka tiada mengadakan perjalanan di muka bumi lalu memperhatikan betapa kesudahan orang-orang yang sebelum mereka. Adalah orang-orang yang sebelum mereka itu lebih hebat kekuatannya dan -lebih banyak- bekas-bekas mereka di muka bumi) seperti gedung-gedung dan bangunan-bangunan lainnya sebagai peninggalan mereka (maka apa yang mereka usahakan itu tidak dapat menolong mereka.)\qt@no{82}}%
\qt@newcmd\qurantrans@id@mmmmccxvi{%
(Maka tatkala datang kepada mereka rasul-rasul mereka dengan membawa keterangan-keterangan) yakni mukjizat-mukjizat yang nyata (mereka merasa senang) orang-orang kafir itu (dengan apa yang ada pada mereka) yakni rasul-rasul itu (yaitu pengetahuan mereka) pengertian gembira di sini mengandung makna ejekan dan olok-olokan seraya ingkar kepada apa yang didatangkan oleh para rasul itu (dan menimpalah) maksudnya, turunlah (kepada mereka apa yang selalu mereka perolok-olokkan itu) yaitu, azab Allah yang selalu mereka ejek itu.\qt@no{83}}%
\qt@newcmd\qurantrans@id@mmmmccxvii{%
(Maka tatkala mereka melihat azab Kami) yakni betapa kerasnya azab Kami (mereka berkata, ``Kami beriman hanya kepada Allah saja, dan kami kafir kepada sesembahan-sesembahan yang telah kami mempersekutukannya dengan Allah.")\qt@no{84}}%
\qt@newcmd\qurantrans@id@mmmmccxviii{%
(Maka iman mereka tiada berguna bagi mereka tatkala mereka telah melihat siksa Kami. Itulah sunah Allah) dinashabkannya lafal Sunnatallaahi karena menjadi Mashdar dari Fi'il yang diperkirakan keberadaannya, dan Fi'il tersebut diambil dari lafalnya (yang telah berlaku terhadap hamba-hamba-Nya) yaitu pada semua umat, bahwasanya iman tiada gunanya apabila timbul di kala azab turun. (Dan di waktu itu merugilah orang-orang kafir) yakni jelaslah kerugian mereka; masing-masing di antara mereka mengalami kerugian yang nyata; dan memang sebelum itu pun mereka adalah orang-orang yang merugi.\qt@no{85}}%
\qt@newcmd\qurantrans@id@mmmmccxix{%
\basmalahid (Haa Miim) hanya Allah saja yang mengetahui arti dan maksudnya.\qt@no{1}}%
\qt@newcmd\qurantrans@id@mmmmccxx{%
(Diturunkan dari Tuhan Yang Maha Pemurah lagi Maha Penyayang) kalimat ayat ini berkedudukan menjadi Mubtada.\qt@no{2}}%
\qt@newcmd\qurantrans@id@mmmmccxxi{%
(Kitab) lafal ayat ini menjadi Khabar Mubtada (yang dijelaskan ayat-ayatnya) maksudnya, dijelaskan di dalamnya hukum-hukum, kisah-kisah dan nasihat-nasihat (yakni bacaan dalam bahasa Arab) lafal Qur-aanan berikut sifatnya menjadi Haal atau kata keterangan keadaan dari lafal Kitaabun (untuk kaum) berta'alluq kepada lafal Fushshilat (yang mengetahui) artinya, bagi mereka yang mengerti, yaitu orang-orang Arab.\qt@no{3}}%
\qt@newcmd\qurantrans@id@mmmmccxxii{%
(Yang membawa berita gembira) menjadi sifat dari lafal Qur-aanan (dan yang membawa peringatan, tetapi kebanyakan mereka berpaling darinya maka mereka tidak mau mendengarkan) dengan pendengaran yang terdorong oleh perasaan mau menerima apa yang didengarnya.\qt@no{4}}%
\qt@newcmd\qurantrans@id@mmmmccxxiii{%
(Mereka berkata) kepada Nabi saw., ("Hati kami berada dalam tutupan) tertutup dari (apa yang kamu seru kami kepadanya dan di telinga kami ada sumbatan) yakni penutup (dan di antara kami dan kamu ada dinding) pemisah dalam masalah agama (maka bekerjalah kamu) sesuai dengan tuntunan agamamu (sesungguhnya kami bekerja pula") sesuai dengan tuntunan agama kami.\qt@no{5}}%
\qt@newcmd\qurantrans@id@mmmmccxxiv{%
(Katakanlah, ``Bahwasanya aku hanyalah seorang manusia seperti kalian, diwahyukan kepadaku bahwasanya Tuhan kalian adalah Tuhan Yang Maha Esa, maka tetaplah pada jalan yang lurus menuju kepada-Nya) yakni dengan beriman dan taat kepada-Nya (dan mohonlah ampun kepada-Nya. Dan kecelakaan yang besarlah) lafal Al-Wail ini merupakan kalimat azab (bagi orang-orang yang musyrik.)\qt@no{6}}%
\qt@newcmd\qurantrans@id@mmmmccxxv{%
(Yaitu orang-orang yang tidak menunaikan zakat dan mereka kepada kehidupan akhirat benar-benar mereka) Hum yang kedua ini mengandung makna mengukuhkan lafal Hum yang pertama (kafir.)\qt@no{7}}%
\qt@newcmd\qurantrans@id@mmmmccxxvi{%
(Sesungguhnya orang-orang yang beriman dan mengerjakan amal yang saleh mereka mendapat pahala yang tiada putus-putusnya") tanpa henti-hentinya.\qt@no{8}}%
\qt@newcmd\qurantrans@id@mmmmccxxvii{%
(Katakanlah, ``Sesungguhnya patutkah kalian) kedua huruf Hamzah pada lafal A-innakum dapat dibaca Tahqiq dan dapat pula dibaca Tas-hil (kafir kepada Yang menciptakan bumi dalam dua hari) yaitu hari Ahad dan hari Senin (dan kalian adakan sekutu-sekutu bagi-Nya") tandingan-tandingan bagi-Nya. (Yang bersifat demikian itulah Rabb) yakni pemilik (semesta alam) lafal Al-Aalamiina adalah bentuk jamak dari lafal Aalamun, maksudnya adalah segala sesuatu yang selain Allah. Kemudian dijamakkan mengingat jenisnya yang bermacam-macam, dan jamak di sini memakai Ya dan Nun karena memprioritaskan makhluk yang berakal.\qt@no{9}}%
\qt@newcmd\qurantrans@id@mmmmccxxviii{%
(Dan Dia menjadikan) merupakan jumlah Istinaf, dan tidak boleh di'athafkan kepada Shilah Al-Ladzii karena ada pemisah yang bersifat Ajnabii yaitu ayat, Wataj'aluuna Lahuu Andaadan dan seterusnya (di bumi itu gunung-gunung) yang kokoh dan kuat (di atasnya dan Dia memberkahinya) dengan air yang banyak, dan tanam-tanaman serta pohon-pohon yang banyak pula (dan Dia menentukan) artinya, membagi-bagikan (padanya kadar makanan-makanannya) untuk manusia dan fauna (dalam) masa penjadian yang sempurna yaitu (empat hari) hal ini dijadikan-Nya pada hari Selasa dan Rabu (yang genap) dinashabkan karena menjadi Mashdar, maksudnya penciptaan itu selama empat hari genap; tidak bertambah dan tidak pula berkurang dari itu (bagi orang-orang yang bertanya) maksudnya, sebagai jawaban bagi orang-orang yang menanyakan tentang penciptaan bumi dan segala isinya.\qt@no{10}}%
\qt@newcmd\qurantrans@id@mmmmccxxix{%
(Kemudian Dia menuju) bermaksud kepada (penciptaan langit dan langit itu masih merupakan asap) masih berbentuk asap yang membumbung tinggi (lalu Dia berfirman kepadanya dan kepada bumi, ``Datanglah kamu keduanya) menurut perintah-Ku (dengan suka hati atau terpaksa") kedua lafal ini berkedudukan sama dengan Hal, yakni baik dalam keadaan senang hati atau terpaksa (keduanya menjawab, ``Kami datang) beserta makhluk yang ada pada kami (dengan suka hati") di dalam ungkapan ini diprioritaskan Dhamir Mudzakkar lagi Aqil; atau khithab kepada keduanya disamakan dengan jamak.\qt@no{11}}%
\qt@newcmd\qurantrans@id@mmmmccxxx{%
(Maka Dia menjadikannya) dhamir yang ada pada lafal ayat ini kembali kepada lafal As-Samaa atau langit, karena memandang dari segi maknanya (tujuh langit dalam dua hari) yakni hari Kamis dan hari Jumat, Dia telah selesai dari menciptakan langit pada saat-saat terakhir dari hari tersebut. Dan pada hari itu juga diciptakan Nabi Adam, oleh karena itu maka di sini tidak dikatakan Fasawwaahunna tetapi Faqadhaahunna. Dan sesuai dengan makna ayat ini yaitu ayat-ayat tentang penciptaan langit dan bumi dalam enam hari (dan Dia mewahyukan pada tiap-tiap langit urusannya) yang telah Dia perintahkan kepada penduduk yang ada di dalamnya, yaitu taat dan beribadah kepada-Nya. (Dan Kami hiasi langit yang dekat dengan pelita-pelita) yakni bintang-bintang yang cemerlang (dan Kami memeliharanya) dinashabkan oleh Fi'ilnya yang keberadaannya diperkirakan, Kami menjaganya dengan meteor-meteor dari setan yang mau mencuri-curi pembicaraan para malaikat. (Demikianlah ketentuan Yang Maha Perkasa) di dalam kerajaan-Nya (lagi Maha Mengetahui) makhluk-Nya.\qt@no{12}}%
\qt@newcmd\qurantrans@id@mmmmccxxxi{%
(Jika mereka berpaling) yaitu orang-orang kafir Mekah dari iman sesudah adanya penjelasan ini (maka katakanlah, ``Aku memperingatkan kalian) aku mempertakuti kalian (dengan petir, seperti petir yang menimpa kaum Ad dan kaum Tsamud) yakni dengan azab yang akan membinasakan kalian sama dengan azab yang membinasakan mereka.\qt@no{13}}%
\qt@newcmd\qurantrans@id@mmmmccxxxii{%
(Ketika rasul-rasul datang kepada mereka dari depan dan dari belakang mereka) rasul-rasul itu datang kepada mereka dari arah depan dan dari arah belakang, akan tetapi mereka tetap ingkar dan kafir, sebagaimana yang akan dijelaskan nanti. Dan pengertian pembinasaan ini hanya berlaku pada zamannya saja ("Janganlah kalian menyembah selain Allah. Mereka menjawab, 'Kalau Rabb kami menghendaki tentu Dia menurunkan) kepada kami (malaikat-malaikat-Nya, maka sesungguhnya kami kepada wahyu yang kalian diutus membawanya) sesuai dengan sangkaan kalian itu (adalah orang-orang yang kafir.'")\qt@no{14}}%
\qt@newcmd\qurantrans@id@mmmmccxxxiii{%
(Adapun kaum Ad maka mereka menyombongkan diri di muka bumi tanpa alasan yang benar dan berkata) ketika mereka diperingatkan dengan azab, ("Siapakah yang lebih besar kekuatannya dari kami?") maksudnya, tiada seorang pun yang lebih kuat dari kami. Menurut suatu riwayat disebutkan, bahwa seseorang dari mereka mampu mengangkat batu yang sangat besar dari sebuah gunung, kemudian ia mengolahnya sesuai dengan apa yang dia kehendaki. (Dan apakah mereka tidak memperhatikan) apakah mereka tidak mengetahui (bahwa Allah Yang menciptakan mereka adalah lebih besar kekuatan-Nya dari mereka? Dan bahwasanya mereka terhadap tanda-tanda Kami) yakni mukjizat-mukjizat Kami (adalah orang-orang yang ingkar.)\qt@no{15}}%
\qt@newcmd\qurantrans@id@mmmmccxxxiv{%
(Maka Kami meniupkan angin yang amat gemuruh kepada mereka) yakni angin dingin yang sangat keras suaranya, tetapi tanpa hujan (dalam beberapa hari yang sial) dapat dibaca Nahisaatin atau Nahsaatin, artinya hari-hari yang penuh dengan kesialan bagi mereka (karena Kami hendak merasakan kepada mereka itu siksaan yang menghinakan) azab yang menghinakan (dalam kehidupan dunia. Dan sesungguhnya siksaan akhirat lebih menghinakan) lebih keras penghinaannya (sedangkan mereka tidak diberi pertolongan) yang dapat mencegah azab dari diri mereka.\qt@no{16}}%
\qt@newcmd\qurantrans@id@mmmmccxxxv{%
(Adapun Kaum Tsamud maka mereka telah Kami beri petunjuk) yaitu Kami telah menjelaskan kepada mereka jalan petunjuk (tetapi mereka lebih menyukai buta) artinya, lebih memilih kafir (daripada petunjuk itu, maka mereka disambar petir azab yang menghinakan) mereka dihinakan oleh azab berupa petir (disebabkan apa yang telah mereka kerjakan.)\qt@no{17}}%
\qt@newcmd\qurantrans@id@mmmmccxxxvi{%
(Dan Kami selamatkan) dari azab itu (orang-orang yang beriman dan mereka adalah orang-orang yang bertakwa.)\qt@no{18}}%
\qt@newcmd\qurantrans@id@mmmmccxxxvii{%
(Dan) ingatlah (hari ketika digiring) dapat dibaca Yuhsyaru atau Nahsyuru (musuh-musuh Allah ke dalam neraka lalu mereka dikumpulkan semuanya) yakni digiring semuanya ke dalam neraka.\qt@no{19}}%
\qt@newcmd\qurantrans@id@mmmmccxxxviii{%
(Sehingga apabila) huruf Maa di sini adalah Zaidah atau tambahan (mereka sampai ke neraka, pendengaran, penglihatan dan kulit mereka menjadi saksi terhadap mereka tentang apa yang telah mereka kerjakan.)\qt@no{20}}%
\qt@newcmd\qurantrans@id@mmmmccxxxix{%
(Dan mereka berkata kepada kulit mereka, ``Mengapa kalian menjadi saksi terhadap kami?" Kulit mereka menjawab, ``Allah yang menjadikan segala sesuatu pandai berkata telah menjadikan kami pandai berkata) yakni segala sesuatu yang dikehendaki-Nya dapat berbicara (dan Dialah Yang menciptakan kalian pada kali yang pertama dan hanya kepada-Nyalah kalian dikembalikan") menurut suatu pendapat, dikatakan bahwa perkataan ini adalah perkataan kulit. Menurut pendapat yang lain, perkataan ini adalah firman Allah swt. sebagaimana hal yang telah diterangkan sebelumnya, dan hal ini mirip sekali dengannya, yaitu: Bahwasanya Tuhan Yang mampu menciptakan kalian pada kali yang pertama, lalu menghidupkan kalian kembali sesudah mati, Dia mampu pula untuk menjadikan kulit kalian dan anggota tubuh kalian lainnya untuk dapat berbicara.\qt@no{21}}%
\qt@newcmd\qurantrans@id@mmmmccxl{%
(Dan kalian sekali-kali tidak dapat bersembunyi) bila kalian berbuat hal-hal yang keji (dari persaksian pendengaran, penglihatan dan kulit kalian terhadap kalian) karena sesungguhnya kalian tidak percaya dengan adanya hari berbangkit (bahkan kalian mengira) sewaktu kalian menyembunyikan diri (bahwa Allah tidak mengetahui kebanyakan dari apa yang kalian kerjakan.)\qt@no{22}}%
\qt@newcmd\qurantrans@id@mmmmccxli{%
(Dan yang demikian itu) menjadi Mubtada (adalah prasangka kalian) menjadi Badal dari lafal Dzaalika (yang kalian sangka terhadap Rabb kalian) menjadi Na`at, sedangkan Khabar Mubtada ialah (akan menghancurkan kalian) akan membinasakan diri kalian sendiri (maka jadilah kalian termasuk orang-orang yang merugi.")\qt@no{23}}%
\qt@newcmd\qurantrans@id@mmmmccxlii{%
(Jika mereka bersabar) menderita azab (maka nerakalah tempat tinggal) tempat kediaman (bagi mereka, dan jika mereka mengemukakan alasan-alasan) maksudnya, jika mereka meminta kerelaan (maka tidaklah mereka termasuk orang-orang yang diterima alasannya) yakni orang-orang yang tidak mendapat kerelaan.\qt@no{24}}%
\qt@newcmd\qurantrans@id@mmmmccxliii{%
(Dan Kami tetapkan) Kami tentukan (bagi mereka teman-teman) dari kalangan setan-setan (yang menjadikan mereka memandang bagus apa yang ada di hadapan mereka) yaitu perkara duniawi dan memperturutkan nafsu syahwat (dan di belakang mereka) yaitu perkara akhirat, melalui perkataan mereka, bahwa tidak ada yang namanya hari berbangkit dan hari hisab itu (dan tetaplah atas mereka keputusan azab) sebagaimana yang telah diungkapkan oleh ayat yang lain, yaitu firman-Nya, ``Sesungguhnya Aku akan penuhi neraka Jahanam..." (Q.S. As-Sajdah, 13) (pada) kalangan (umat-umat terdahulu) yang telah dibinasakan (sebelum mereka dari jin dan manusia, sesungguhnya mereka adalah orang- orang yang merugi.)\qt@no{25}}%
\qt@newcmd\qurantrans@id@mmmmccxliv{%
(Dan orang-orang yang kafir berkata) sewaktu Nabi saw. membaca Alquran, ("Janganlah kalian mendengar bacaan Alquran ini dan buatlah hiruk-pikuk terhadapnya) yakni buatlah suara gaduh dan hiruk-pikuk untuk mengganggu bacaannya, dan mereka memang membuat hiruk-pikuk bilamana Nabi membaca Alquran (supaya kalian dapat mengalahkan") bacaannya lalu ia menjadi diam tidak membaca Alquran.\qt@no{26}}%
\qt@newcmd\qurantrans@id@mmmmccxlv{%
Allah swt. berfirman mengisahkan tentang mereka, (Maka sesungguhnya Kami akan merasakan azab yang keras kepada orang-orang kafir dan Kami akan memberi balasan kepada mereka dengan seburuk-buruk pembalasan bagi apa yang telah mereka kerjakan) yakni pembalasan yang paling buruk sebagai imbalan dari perbuatan mereka itu.\qt@no{27}}%
\qt@newcmd\qurantrans@id@mmmmccxlvi{%
(Demikianlah) azab yang keras itu dan pembalasan yang paling buruk itu (balasan terhadap musuh-musuh Allah) dapat dibaca Jazaa-u A'daaillaahi atau Jazaa-uwa`daaillaahi, yaitu dapat dibaca Tahqiq dan Tas-hil (yaitu neraka) menjadi 'Athaf bayan dari lafal Jazaa-u dan berfungsi menjelaskan maknanya (mereka mendapat tempat tinggal yang kekal di dalamnya) tempat menetap yang tidak akan dipindahkan lagi daripadanya (sebagai pembalasan) dinashabkan karena menjadi Mashdar dari Fi'ilnya yang diperkirakan keberadaannya (dari sikap mereka terhadap ayat-ayat Kami) yakni Alquran (yang mereka ingkari.)\qt@no{28}}%
\qt@newcmd\qurantrans@id@mmmmccxlvii{%
(Dan orang-orang kafir berkata) sedang mereka di dalam neraka, ("Ya Rabb kami! Perlihatkanlah kepada kami dua jenis makhluk yang telah menyesatkan kami yaitu sebagian dari jin dan manusia) yakni iblis dan Qabil yang keduanya adalah orang pertama yang mengerjakan kekafiran dan pembunuhan (agar kami letakkan keduanya di bawah telapak kaki kami) dalam neraka (supaya kedua jenis itu menjadi orang-orang yang paling bawah") di neraka, artinya, azabnya lebih hebat daripada kami.\qt@no{29}}%
\qt@newcmd\qurantrans@id@mmmmccxlviii{%
(Sesungguhnya orang-orang yang mengatakan, ``Rabb kami adalah Allah," kemudian mereka meneguhkan pendirian mereka) dalam ajaran tauhid dan lain-lainnya yang diwajibkan atas mereka (maka malaikat akan turun kepada mereka) sewaktu mereka mati ("Hendaknya kalian jangan merasa takut) akan mati dan hal-hal yang sesudahnya (dan jangan pula kalian merasa sedih) atas semua yang telah kalian tinggalkan, yaitu istri dan anak-anak, maka Kamilah yang akan menggantikan kedudukan mereka di sisi kalian (dan bergembiralah dengan surga yang telah dijanjikan Allah kepada kalian.)\qt@no{30}}%
\qt@newcmd\qurantrans@id@mmmmccxlix{%
(Kamilah pelindung-pelindung kalian dalam kehidupan dunia) artinya, Kami memelihara kalian di dalamnya (dan di akhirat) maksudnya, Kami akan selalu bersama kalian di akhirat hingga kalian masuk surga (di dalamnya kalian memperoleh apa yang kalian inginkan dan memperoleh pula di dalamnya apa yang kalian minta) berupa semua kenikmatan yang kalian minta.\qt@no{31}}%
\qt@newcmd\qurantrans@id@mmmmccl{%
(Sebagai hidangan) sebagai rezeki yang telah dipersiapkan bagi kalian; lafal ayat ini dinashabkan oleh lafal Ja'ala yang keberadaannya diperkirakan sebelumnya (dari Rabb Yang Maha Pengampun lagi Maha Penyayang") yaitu dari Allah swt.\qt@no{32}}%
\qt@newcmd\qurantrans@id@mmmmccli{%
(Siapakah yang lebih baik perkataannya) maksudnya, tiada seorang pun yang lebih baik perkataannya (daripada seorang yang menyeru kepada Allah) yakni mentauhidkan-Nya (mengerjakan amal yang saleh dan berkata, ``Sesungguhnya aku termasuk orang-orang yang berserah diri?")\qt@no{33}}%
\qt@newcmd\qurantrans@id@mmmmcclii{%
(Dan tidaklah sama kebaikan dan kejahatan) dalam tingkatan rinciannya, karena sebagian daripada keduanya berada di atas sebagian yang lain. (Tolaklah) kejahatan itu (dengan cara) yakni dengan perbuatan (yang lebih baik) seperti marah, imbangilah dengan sabar, bodoh imbangilah dengan santunan, dan perbuatan jahat imbangilah dengan lapang dada atau pemaaf (maka tiba-tiba orang yang antaramu dan antara dia ada permusuhan seolah-olah menjadi teman yang setia) maka jadilah yang dulunya musuhmu kini menjadi teman sejawat dalam hal saling kasih mengasihi, jika kamu mempunyai sikap seperti tersebut. Lafal Al Ladzii Mubtada, dan Ka-annahu adalah Khabarnya, lafal Idzaa menjadi Zharaf bagi makna Tasybih.\qt@no{34}}%
\qt@newcmd\qurantrans@id@mmmmccliii{%
(Sifat-sifat yang baik itu tidak dianugerahkan) tidak akan diberikan (melainkan kepada orang-orang yang sabar dan tidak dianugerahkan melainkan kepada orang-orang yang mempunyai keberuntungan) yakni pahala (yang besar.)\qt@no{35}}%
\qt@newcmd\qurantrans@id@mmmmccliv{%
(Dan jika) lafal Immaa ini pada asalnya terdiri dari In Syarthiyyah dan Maa Zaidah yang kemudian keduanya diidgamkan menjadi satu sehingga jadilah Immaa (setan mengganggumu dengan suatu gangguan) yakni jika setan mengalihkan perhatianmu dari pekerti yang baik kepada pekerti yang buruk (maka mohonlah perlindungan kepada Allah) lafal ayat ini menjadi Jawab Syarat, sedangkan Jawab Amar tidak disebutkan, yakni niscaya Dia akan menolak gangguan setan itu dalam dirimu. (Sesungguhnya Dialah Yang Maha Mendengar) semua percakapan (lagi Maha Mengetahui) semua perbuatan.\qt@no{36}}%
\qt@newcmd\qurantrans@id@mmmmcclv{%
(Dan sebagian dari tanda-tanda kekuasaan-Nya ialah malam, siang, matahari, dan bulan. Janganlah kalian bersujud kepada matahari dan jangan pula kepada bulan, tetapi bersujudlah kepada Allah Yang menciptakannya) yang telah menciptakan keempat tanda-tanda tersebut (jika kalian hanya kepada-Nya saja menyembah.)\qt@no{37}}%
\qt@newcmd\qurantrans@id@mmmmcclvi{%
(Jika mereka menyombongkan diri) tidak mau bersujud atau menyembah kepada Allah semata (maka mereka yang di sisi Rabbmu) yakni malaikat-malaikat (bertasbih) artinya, salat (kepada-Nya di malam dan siang hari, sedangkan mereka tidak jemu-jemu) tidak pernah merasa jemu bertasbih.\qt@no{38}}%
\qt@newcmd\qurantrans@id@mmmmcclvii{%
(Dan sebagian dari tanda-tanda kekuasaan-Nya bahwa kamu melihat bumi itu kering tandus) yaitu tidak ada tumbuh-tumbuhan padanya (maka apabila Kami turunkan air di atasnya, niscaya ia bergerak) berubah (dan subur) yakni menjadi subur dan rimbun penuh dengan tetumbuhan. (Sesungguhnya Tuhan Yang menghidupkannya tentu dapat menghidupkan yang mati; sesungguhnya Dia Maha Kuasa atas segala sesuatu.)\qt@no{39}}%
\qt@newcmd\qurantrans@id@mmmmcclviii{%
(Sesungguhnya orang-orang yang mengingkari) diambil dari kata Alhada dan Lahada artinya ingkar (kepada ayat-ayat Kami) yakni Alquran dengan cara mendustakannya (mereka tidak tersembunyi dari Kami) maka pasti Kami akan membalas mereka. (Maka apakah orang-orang yang dilemparkan ke dalam neraka lebih baik ataukah orang-orang yang datang dengan aman sentosa pada hari kiamat? Perbuatlah apa yang kalian kehendaki; sesungguhnya Dia Maha Mengetahui apa yang kalian kerjakan) ayat ini merupakan ancaman bagi mereka.\qt@no{40}}%
\qt@newcmd\qurantrans@id@mmmmcclix{%
(Sesungguhnya orang-orang yang mengingkari peringatan) Alquran (ketika ia datang kepada mereka) niscaya Kami akan membalas mereka (dan sesungguhnya Alquran itu adalah kitab yang mulia) artinya, perkasa.\qt@no{41}}%
\qt@newcmd\qurantrans@id@mmmmcclx{%
(Yang tidak datang kepadanya Alquran kebatilan baik dari depan maupun dari belakangnya) yakni tidak ada suatu kitab pun sebelumnya yang mendustakannya, dan tidak pula sesudahnya (yang diturunkan dari Tuhan Yang Maha Bijaksana lagi Maha Terpuji) Allah Yang Maha Terpuji di dalam semua urusan-Nya.\qt@no{42}}%
\qt@newcmd\qurantrans@id@mmmmcclxi{%
(Tidaklah ada yang dikatakan kepadamu itu) yakni kedustaan (kecuali) sebagaimana (apa yang sesungguhnya telah dikatakan kepada rasul-rasul sebelum kamu. Sesungguhnya Rabbmu benar-benar mempunyai ampunan) buat orang-orang yang beriman (dan hukuman yang pedih) bagi orang-orang kafir.\qt@no{43}}%
\qt@newcmd\qurantrans@id@mmmmcclxii{%
(Dan jika Kami jadikan ia) yakni Alquran itu (suatu bacaan dalam bahasa selain bahasa Arab tentu mereka mengatakan, ``Mengapa tidak) kenapa tidak (dijelaskan) diterangkan (ayat-ayatnya?) sehingga kami dapat memahaminya. (Apakah) patut Alquran (dalam bahasa asing sedangkan) nabi (adalah orang Arab) Istifham atau kata tanya di sini mengandung makna ingkar, yakni menunjukkan keingkaran mereka. Dan lafal A'jamiyyun ini dapat dibaca Tahqiq dan dapat pula dibaca Tas-hil. (Katakanlah, ``Alquran ini bagi orang-orang yang beriman adalah petunjuk) dari kesesatan (dan penawar) dari kebodohan. (Dan orang-orang yang tidak beriman pada telinga mereka ada sumbatan) penutup, sehingga mereka tidak dapat mendengar (sedangkan Alquran itu suatu kegelapan bagi mereka) karena itu mereka tidak dapat memahaminya. (Mereka itu adalah seperti orang-orang yang dipanggil dari tempat yang jauh") karenanya mereka tidak dapat mendengar dan tidak dapat memahami panggilan yang ditujukan kepadanya.\qt@no{44}}%
\qt@newcmd\qurantrans@id@mmmmcclxiii{%
(Dan sesungguhnya telah Kami berikan kepada Musa Kitab) yakni Taurat (lalu diperselisihkan tentang Taurat itu) ada yang mempercayainya dan ada pula yang mendustakannya, sama dengan apa yang dialami oleh Alquran. (Kalau tidak ada keputusan yang telah terdahulu dari Rabbmu) yang telah memutuskan untuk menangguhkan hisab dan pembalasan bagi semua makhluk sampai hari kiamat nanti (tentulah telah diputuskan di antara mereka) di dunia ini tentang apa yang mereka perselisihkan itu. (Dan sesungguhnya mereka) yaitu orang-orang yang mendustakan terhadap Alquran (benar-benar dalam keragu-raguan yang membingungkan terhadap Alquran) mereka benar-benar ragu terhadapnya.\qt@no{45}}%
\qt@newcmd\qurantrans@id@mmmmcclxiv{%
(Barang siapa yang mengerjakan amal yang saleh maka pahalanya untuk dirinya sendiri) ia beramal untuk dirinya sendiri (dan barang siapa yang berbuat jahat maka dosanya atas dirinya sendiri) bahaya dari perbuatan jahatnya itu kembali kepada dirinya sendiri (dan sekali-kali tidaklah Rabbmu menganiaya hamba-hamba-Nya) Dia bukanlah penganiaya hamba-hamba-Nya sebagaimana yang telah diungkapkan oleh ayat lainnya, yaitu firman-Nya, ``Sesungguhnya Allah tidak menganiaya seorang pun walaupun sebesar dzarrah." (Q.S. An-Nisa, 40)\qt@no{46}}%
\qt@newcmd\qurantrans@id@mmmmcclxv{%
(Kepada-Nyalah dikembalikan pengetahuan tentang hari kiamat) bila akan terjadi, tiada seorang pun yang mengetahuinya selain Dia. (Dan tidak ada buah-buahan keluar) menurut suatu qiraat dibaca Tsamaraatin dalam bentuk jamak (dari kelopaknya) dari kelopak-kelopaknya melainkan dengan sepengetahuan-Nya; lafal Akmaam adalah bentuk jamak dari lafal Kimmun (dan tidak seorang perempuan pun mengandung dan tidak pula melahirkan, melainkan dengan sepengetahuan-Nya. Pada hari Tuhan memanggil mereka, ``Di manakah sekutu-sekutu-Ku itu?" Mereka menjawab, ``Kami nyatakan kepada Engkau) artinya, sekarang Kami beritahukan kepada Engkau (bahwa tidak ada seorang pun di antara kami yang memberikan kesaksian bahwa Engkau punya sekutu."\qt@no{47}}%
\qt@newcmd\qurantrans@id@mmmmcclxvi{%
(Dan lenyaplah) hilanglah (dari mereka apa yang selalu mereka seru) yang selalu mereka sembah (dahulu) di dunia yaitu berhala-berhala (dan mereka yakin) merasa yakin (bahwa tidak ada bagi mereka sesuatu jalan keluar pun) jalan selamat dari azab. Huruf Nafi pada dua tempat tidak beramal, dan jumlah yang dinafikan menduduki tempatnya Maf'ul.\qt@no{48}}%
\qt@newcmd\qurantrans@id@mmmmcclxvii{%
(Manusia tidak jemu memohon kebaikan) artinya, masih tetap terus meminta kepada Rabbnya akan harta, kesehatan dan lain-lainnya (dan jika ia ditimpa malapetaka) berupa kemiskinan dan kesengsaraan (dia menjadi putus asa lagi putus harapan) dari rahmat Allah. Ayat ini merupakan gambaran bagi keadaan orang-orang kafir, demikian pula gambaran dalam ayat selanjutnya.\qt@no{49}}%
\qt@newcmd\qurantrans@id@mmmmcclxviii{%
(Dan sungguh jika) huruf Lamnya menunjukkan makna Qasam (Kami rasakan kepadanya) Kami berikan kepadanya (rahmat) kecukupan dan kesehatan (dari Kami sesudah kesusahan) yakni kesengsaraan dan malapetaka (yang telah menimpanya, pastilah dia berkata, ``Ini adalah hakku) artinya, berkat karyaku sendiri (dan aku tidak yakin bahwa hari Kiamat itu akan datang. Dan sungguh jika) huruf Lamnya menunjukkan makna Qasam (aku dikembalikan kepada Rabbku maka sesungguhnya aku akan memperoleh kebaikan di sisi-Nya") yakni surga. (Maka Kami benar-benar akan memberitakan kepada orang-orang kafir apa yang telah mereka kerjakan dan akan Kami rasakan kepada mereka azab yang keras) siksaan yang keras. Huruf Lam yang terdapat pada dua Fi'il bermakna Qasam.\qt@no{50}}%
\qt@newcmd\qurantrans@id@mmmmcclxix{%
(Dan apabila Kami berikan nikmat kepada manusia) yang dimaksud adalah jenis manusia (ia berpaling) tidak mau bersyukur (dan menjauhkan diri) yakni memutarkan badannya seraya menyombongkan diri; menurut suatu qiraat lafal Na-aa dibaca dengan didahulukan huruf Hamzahnya (tetapi apabila ia ditimpa malapetaka maka ia banyak berdoa) banyak permintaannya.\qt@no{51}}%
\qt@newcmd\qurantrans@id@mmmmcclxx{%
(Katakanlah, ``Bagaimana pendapat kalian jika ia) yakni Alquran itu (datang dari sisi Allah) sebagaimana yang telah dikatakan oleh Nabi saw. (kemudian kalian mengingkarinya. Siapakah) yakni tiada seorang pun (yang lebih sesat daripada orang yang selalu berada dalam penyimpangan) yakni perselisihan (yang jauh?") dari kebenaran. Lafal Ba'iidun ini menduduki tempatnya lafal Minkum sebagai penjelasan tentang keadaan mereka.\qt@no{52}}%
\qt@newcmd\qurantrans@id@mmmmcclxxi{%
(Kami akan memperlihatkan kepada mereka tanda-tanda kekuasaan Kami di segenap penjuru) di segenap penjuru langit dan bumi, yaitu berupa api, tumbuh-tumbuhan dan pohon-pohonan (dan pada diri mereka sendiri) yaitu berupa rapihnya ciptaan Allah dan indahnya hikmah yang terkandung di dalam penciptaan itu (sehingga jelaslah bagi mereka bahwa ia) yakni Alquran itu (adalah benar) diturunkan dari sisi Allah yang di dalamnya dijelaskan masalah hari berbangkit, hisab dan siksaan; maka mereka akan disiksa karena kekafiran mereka terhadap Alquran dan terhadap orang yang Alquran diturunkan kepadanya, yaitu Nabi saw. (Dan apakah Rabbmu tidak cukup bagi kamu) lafal Birabbika adalah Fa'il dari lafal Yakfi (bahwa sesungguhnya Dia menyaksikan segala sesuatu?) lafal ayat ini menjadi Mubdal Minhu yakni, apakah tidak cukup sebagai bukti tentang kebenaranmu bagi mereka, yaitu bahwasanya Rabbmu tiada sesuatu pun yang samar bagi-Nya.\qt@no{53}}%
\qt@newcmd\qurantrans@id@mmmmcclxxii{%
(Ingatlah bahwa sesungguhnya mereka adalah dalam keraguan) yakni keragu-raguan (tentang pertemuan dengan Rabb mereka) karena mereka ingkar kepada adanya hari berbangkit. (Ingatlah, bahwa sesungguhnya Dia) yakni Allah swt. (Maha Meliputi segala sesuatu) yaitu ilmu dan kekuasaan-Nya meliputi segala sesuatu, maka dari itu Dia akan membalas mereka disebabkan kekafiran mereka.\qt@no{54}}%
\qt@newcmd\qurantrans@id@mmmmcclxxiii{%
\basmalahid (Haa Miim)\qt@no{1}}%
\qt@newcmd\qurantrans@id@mmmmcclxxiv{%
('Ain Siin Qaaf) kedua ayat ini hanya Allahlah yang mengetahui arti dan maksudnya.\qt@no{2}}%
\qt@newcmd\qurantrans@id@mmmmcclxxv{%
(Demikianlah) artinya seperti penurunan wahyu ini (telah mewahyukannya kepadamu dan) telah mewahyukan pula (kepada orang-orang yang sebelum kamu, yaitu Allah) lafal Allah menjadi Fa'il dari lafal Yuuhii (Yang Maha Perkasa) di dalam kerajaan-Nya (lagi Maha Bijaksana) di dalam perbuatan-Nya.\qt@no{3}}%
\qt@newcmd\qurantrans@id@mmmmcclxxvi{%
(Kepunyaan-Nyalah apa yang ada di langit dan apa yang ada di bumi) sebagai milik-Nya semua makhluk dan hamba-hamba-Nya. (Dan Dialah Yang Maha Tinggi) di atas semua makhluk-Nya (lagi Maha Besar) atau Maha Agung.\qt@no{4}}%
\qt@newcmd\qurantrans@id@mmmmcclxxvii{%
(Hampir saja) dapat dibaca Takaadu atau Yakaadu (langit itu pecah) dibaca Yatafath-tharna dengan huruf tha yang ditasydidkan menurut qiraat lain dibaca Yanfathirna dengan memakai huruf Nun (dari sebelah atasnya) hampir setiap langit itu pecah menimpa yang lainnya karena kebesaran Allah swt. (dan malaikat-malaikat bertasbih serta memuji Rabbnya) disertai dengan mengucapkan puji-pujian (dan memohonkan ampun bagi orang-orang yang ada di bumi) yakni bagi orang-orang yang beriman. (Ingatlah! Bahwa sesungguhnya Allah Dialah Yang Maha Pengampun) kepada kekasih-kekasih-Nya (lagi Maha Penyayang) kepada mereka.\qt@no{5}}%
\qt@newcmd\qurantrans@id@mmmmcclxxviii{%
(Dan orang-orang yang mengambil selain Allah) mengambil berhala-berhala (sebagai pelindung-pelindung, Allah mengawasi) mencatat (perbuatan mereka) untuk membalas mereka kelak (dan kamu bukanlah orang yang diserahi mengawasi mereka) untuk memperoleh apa yang diminta dari mereka, tugasmu tiada lain hanya menyampaikan.\qt@no{6}}%
\qt@newcmd\qurantrans@id@mmmmcclxxix{%
(Demikianlah) sebagaimana penurunan wahyu ini (Kami wahyukan kepadamu Alquran dalam bahasa Arab supaya kamu memberi peringatan) dengannya, (kepada Umulquraa dan penduduk negeri-negeri sekelilingnya) yaitu penduduk kota Mekah dan semua manusia (serta memberi peringatan pula) kepada manusia (tentang hari berkumpul) yakni hari kiamat, yang pada hari itu semua makhluk dikumpulkan (yang tidak ada keraguan) atau keragu-raguan (padanya. Segolongan) dari mereka (masuk surga dan segolongan yang lain masuk Sa'ir) yakni neraka.\qt@no{7}}%
\qt@newcmd\qurantrans@id@mmmmcclxxx{%
(Dan kalau Allah menghendaki niscaya Allah menjadikan mereka satu umat) artinya memeluk satu agama, yaitu agama Islam (tetapi Dia memasukkan orang-orang yang dikehendaki-Nya ke dalam rahmat-Nya. Dan orang-orang yang lalim) yaitu orang-orang kafir (tidak ada bagi mereka seorang pelindung pun dan tidak pula seorang penolong) yang dapat menolak azab Allah dari diri mereka.\qt@no{8}}%
\qt@newcmd\qurantrans@id@mmmmcclxxxi{%
(Atau patutkah mereka mengambil selain-Nya) mengambil berhala-berhala (sebagai pelindung-pelindung) lafal Am adalah Munqathi'ah yang maknanya sama dengan lafal Bal yang menunjukkan makna Intiqal; Hamzahnya atau makna Istifhamnya menunjukkan pengertian ingkar. Maksudnya yang diambil oleh mereka itu bukanlah pelindung-pelindung mereka. (Maka Allah, Dialah Pelindung) Penolong bagi orang-orang Mukmin, huruf Fa di sini hanya untuk Athaf saja (dan Dia menghidupkan orang-orang yang mati dan Dia adalah Maha Kuasa atas segala sesuatu.)\qt@no{9}}%
\qt@newcmd\qurantrans@id@mmmmcclxxxii{%
(Dan apa yang kalian perselisihkan) dengan orang-orang kafir (tentang sesuatu perkara) yang menyangkut masalah agama dan masalah-masalah lainnya (maka putusannya) dikembalikan (kepada Allah) kelak di hari kiamat yaitu Dia akan memutuskan perkara itu di antara kalian. Katakanlah kepada mereka, ("Itulah Allah, Rabbku, kepada-Nyalah aku bertawakal dan kepada-Nyalah aku kembali) yakni dikembalikan.\qt@no{10}}%
\qt@newcmd\qurantrans@id@mmmmcclxxxiii{%
(Pencipta langit dan bumi) Dialah Yang mengadakan langit dan bumi (Dia menjadikan bagi kalian dari jenis kalian sendiri pasangan-pasangan) sewaktu Dia menciptakan Hawa dari tulang rusuk Adam (dan dari jenis binatang ternak pasangan-pasangan) ada jenis jantan dan ada jenis betina (dijadikan-Nya kalian berkembang biak) maksudnya, mengembangbiakkan kalian (dengan jalan itu) yaitu melalui proses perjodohan. Dengan kata lain, Dia memperbanyak kalian melalui anak beranak. Dhamir yang ada kembali kepada manusia dan binatang ternak dengan ungkapan yang lebih memprioritaskan manusia. (Tidak ada sesuatu pun yang serupa dengan Dia) huruf Kaf adalah Zaidah, karena sesungguhnya Allah swt. tiada sesuatu pun yang semisal dengan-Nya (dan Dialah Yang Maha Mendengar) semua apa yang dikatakan (lagi Maha Melihat) semua apa yang dikerjakan.\qt@no{11}}%
\qt@newcmd\qurantrans@id@mmmmcclxxxiv{%
(Kepunyaan-Nyalah khazanah langit dan bumi) yakni kunci-kunci khazanahnya, yaitu berupa hujan, tumbuh-tumbuhan dan lain sebagainya. (Dia melapangkan rezeki) meluaskannya (bagi siapa yang dikehendaki-Nya) sebagai ujian baginya (dan membatasinya) menyempitkannya bagi siapa yang dikehendaki-Nya sebagai cobaan baginya (Sesungguhnya Dia Maha Mengetahui segala sesuatu.)\qt@no{12}}%
\qt@newcmd\qurantrans@id@mmmmcclxxxv{%
(Dia telah mensyariatkan bagi kalian tentang agama apa yang telah diwasiatkan-Nya kepada Nuh) dia adalah nabi pertama yang membawa syariat (yang telah Kami wahyukan kepadamu dan apa yang telah Kami wasiatkan kepada Ibrahim, Musa dan Isa yaitu, ``Tegakkanlah agama dan janganlah kalian berpecah-belah tentangnya.") inilah ajaran yang telah disyariatkan dan yang telah diwasiatkan serta yang telah diwahyukan kepada Nabi Muhammad saw. yaitu ajaran Tauhid. (Amat berat) amat besarlah (bagi orang-orang musyrik agama yang kamu seru mereka kepadanya) yakni ajaran tauhid (Allah menarik kepada agama itu) kepada ajaran tauhid (orang yang dikehendaki-Nya dan memberi petunjuk kepada agama-Nya orang yang kembali kepada-Nya) orang yang mau menerima untuk berbuat taat kepada-Nya.\qt@no{13}}%
\qt@newcmd\qurantrans@id@mmmmcclxxxvi{%
(Dan mereka tidak berpecah-belah) yaitu para pemeluk agama-agama tentang agamanya, umpamanya sebagian dari mereka berpegang kepada ajaran tauhid dan sebagian lainnya kafir (melainkan sesudah datangnya pengetahuan kepada mereka) yakni pengetahuan tentang ajaran tauhid (karena kedengkian) yang dimaksud adalah orang-orang kafir (di antara mereka. Kalau tidaklah karena sesuatu ketetapan yang telah ada dari Rabbmu dahulunya) untuk menangguhkan pembalasan (sampai kepada waktu yang ditentukan) yakni hari kiamat (pastilah telah diputuskan di antara mereka) yaitu diazab-Nya orang-orang kafir di dunia. (Dan sesungguhnya orang-orang yang diwariskan kepada mereka Alkitab sesudah mereka) mereka adalah orang-orang Yahudi dan orang-orang Nasrani (benar-benar dalam keraguan terhadapnya) terhadap Nabi saw. (yang mengguncangkan) yang menyebabkan keragu-raguan.\qt@no{14}}%
\qt@newcmd\qurantrans@id@mmmmcclxxxvii{%
(Maka karena itu) karena ajaran tauhid itu (serulah) manusia, hai Muhammad (dan tetaplah) berpegang teguh kepada ajaran tauhid (sebagaimana diperintahkan kepadamu dan janganlah mengikuti hawa nafsu mereka) yang membujukmu untuk meninggalkan ajaran tauhid (dan katakanlah, ``Aku beriman kepada semua Kitab yang diturunkan Allah dan aku diperintahkan supaya berlaku adil) bersikap adil (di antara kalian) dalam masalah memutuskan hukum (Allahlah Rabb kami dan Rabb kalian. Bagi kami amal-amal kami dan bagi kalian amal-amal kalian) masing-masing akan mendapatkan balasan amalnya sendiri-sendiri. (Tidak ada pertengkaran) persengketaan (antara kami dan kalian) ayat ini diturunkan sebelum nabi diperintahkan untuk berjihad melawan mereka (Allah mengumpulkan antara kita) pada hari semua manusia dikembalikan kepada-Nya untuk menjalani peradilan di hadapan-Nya (dan kepada-Nyalah kembali kita") kita akan dikembalikan.\qt@no{15}}%
\qt@newcmd\qurantrans@id@mmmmcclxxxviii{%
(Dan orang-orang yang membantah) agama (Allah) maksudnya, membantah Nabi-Nya (sesudah agama itu diterima) sesudah diimani dan nyatanya mukjizat yang dibawanya, yang dimaksud dengan mereka adalah orang-orang Yahudi (maka bantahan mereka itu sia-sia saja) atau batil (di sisi Rabb mereka. Mereka mendapat kemurkaan Allah dan bagi mereka azab yang sangat keras.)\qt@no{16}}%
\qt@newcmd\qurantrans@id@mmmmcclxxxix{%
(Allahlah yang menurunkan Kitab) Alquran (dengan membawa kebenaran) lafal Bil Haqqi berta'alluq kepada lafal Anzala (dan neraca), keadilan. (Dan tahukah kamu) apakah kamu tahu (boleh jadi kiamat itu) yakni kedatangannya (sudah dekat?) lafal La'alla amalnya di-ta'alluq-kan kepada Fi'il dan lafal-lafal sesudahnya berkedudukan sebagai dua Maf'ul.\qt@no{17}}%
\qt@newcmd\qurantrans@id@mmmmccxc{%
(Orang-orang yang tidak beriman kepada hari kiamat meminta supaya hari itu segera didatangkan) mereka mengatakan, ``Kapan hari kiamat itu akan datang," demikian itu karena mereka menduga bahwa hari kiamat tidak akan datang (dan orang-orang yang beriman, merasa takut) merasa khawatir (kepadanya dan mereka yakin bahwa kiamat itu adalah benar akan terjadi Ketahuilah bahwa sesungguhnya orang-orang yang membantah) mendebat (tentang terjadinya hari kiamat itu benar-benar dalam kesesatan yang jauh.)\qt@no{18}}%
\qt@newcmd\qurantrans@id@mmmmccxci{%
(Allah Maha Lembut terhadap hamba-hamba-Nya) baik terhadap mereka yang berbakti maupun terhadap mereka yang durhaka, karena Dia tidak membinasakan mereka melalui kelaparan sebab kemaksiatan mereka (Dia memberi rezeki kepada siapa yang dikehendaki-Nya) artinya, Dia memberikan kepada masing-masingnya apa yang Dia kehendaki (dan Dialah Yang Maha Kuat) atas semua kehendak-Nya (lagi Maha Perkasa) Maha Menang atas semua perkara-Nya.\qt@no{19}}%
\qt@newcmd\qurantrans@id@mmmmccxcii{%
(Barang siapa yang menghendaki) dengan amalnya (keuntungan akhirat) pahala akhirat (Kami tambahkan keuntungan itu baginya) dilipatgandakan pahalanya yaitu satu kebaikan dibalas dengan sepuluh kebaikan dan bahkan lebih dari itu (dan barang siapa yang menghendaki keuntungan di dunia, Kami berikan kepadanya sebagian dari keuntungan dunia) tanpa dilipatgandakan (dan tidak ada baginya suatu bagian pun di akhirat.)\qt@no{20}}%
\qt@newcmd\qurantrans@id@mmmmccxciii{%
(Apakah) sebenarnya (mereka mempunyai) yang dimaksud adalah orang-orang kafir Mekah (sesembahan-sesembahan) yaitu setan-setan mereka (yang mensyariatkan) maksudnya, sesembahan-sesembahan mereka itu mensyariatkan (untuk mereka) untuk orang-orang kafir (agama) yang rusak (yang tidak diizinkan oleh Allah?) seperti ajaran menyekutukan Allah dan mengingkari adanya hari berbangkit. (Sekiranya tidak ada ketetapan yang menentukan dari Allah) ketentuan yang telah terdahulu yang menetapkan bahwa pembalasan itu pada hari kiamat (tentulah telah diputuskan di antara mereka) dan orang-orang yang beriman, yaitu orang-orang kafir akan langsung diazab di dunia. (Dan sesungguhnya orang-orang yang zalim itu) yakni orang-orang kafir (akan memperoleh azab yang amat pedih) yang amat menyakitkan.\qt@no{21}}%
\qt@newcmd\qurantrans@id@mmmmccxciv{%
(Kamu lihat orang-orang yang zalim) kelak di hari kiamat (sangat ketakutan) sangat ngeri (karena kejahatan-kejahatan yang telah mereka kerjakan) di dunia, mereka takut akan menerima pembalasannya (sedangkan pembalasan itu) yakni pembalasan perbuatan jahat mereka itu (menimpa mereka) pasti menimpa mereka kelak di hari kiamat. (Dan orang-orang yang beriman serta mengerjakan amal yang saleh berada di dalam taman-taman surga) berada di surga yang paling indah bila dibandingkan dengan orang-orang yang derajatnya di bawah mereka (mereka memperoleh apa yang mereka kehendaki di sisi Rabb mereka. Yang demikian itu adalah karunia yang besar.)\qt@no{22}}%
\qt@newcmd\qurantrans@id@mmmmccxcv{%
(Itulah karunia yang dengan itu Allah menggembirakan) berasal dari lafal Al-Bisyarah (hamba-hamba-Nya yang beriman dan mengerjakan amal yang saleh. Katakanlah, ``Aku tidak meminta kepada kalian atas seruanku ini) atas penyampaian risalah ini (sesuatu upah pun kecuali kasih sayang dalam kekeluargaan) Istitsna di sini bersifat Munqathi' maksudnya, tetapi aku meminta kepada kalian hendaknya kalian mencintai kekerabatan denganku yang memang pada kenyataannya telah ada hubungan kerabat antara kalian dan aku. Karena sesungguhnya bagi Nabi saw. mempunyai hubungan kekerabatan dengan setiap puak yang berakar dari kabilah Quraisy. (Dan siapa yang mengerjakan kebaikan) yakni ketaatan (akan Kami tambahkan baginya kebaikan pada kebaikannya itu) yaitu dengan melipatgandakan pahala kebaikannya. (Sesungguhnya Allah Maha Pengampun) terhadap dosa-dosa (lagi Maha Mensyukuri) bagi orang yang sedikit beramal kebaikan, karenanya Dia melipatgandakan pahalanya.\qt@no{23}}%
\qt@newcmd\qurantrans@id@mmmmccxcvi{%
(Bahkan) tetapi (mereka mengatakan, ``Dia telah mengada-adakan dusta terhadap Allah") yaitu dengan menisbatkan Alquran, bahwasanya diturunkan dari sisi Allah. (Maka jika Allah menghendaki niscaya Dia mengunci mati) maksudnya, mengikat (hatimu) dengan kesabaran, sehingga kamu sabar di dalam menghadapi perlakuan mereka yang menyakitkan melalui perkataan dan perbuatan-perbuatan lainnya; memang Allah swt. telah melaksanakan apa yang dikehendaki-Nya itu (dan Allah menghapuskan yang batil) yakni perkara yang telah mereka katakan itu (dan membenarkan yang hak) menetapkannya (dengan kalimat-kalimat-Nya) yang diturunkan kepada Nabi-Nya. (Sesungguhnya Dia Maha Mengetahui segala isi hati) mengetahui apa yang terkandung di dalam kalbu.\qt@no{24}}%
\qt@newcmd\qurantrans@id@mmmmccxcvii{%
(Dan Dialah yang menerima tobat dari hamba-hamba-Nya) dari sebagian di antara mereka (dan memaafkan kesalahan-kesalahan) yang para pelakunya telah bertobat daripadanya (dan mengetahui apa yang kalian kerjakan) dapat dibaca Taf'aluuna atau Yaf'aluuna; kalau dibaca Yaf'aluuna artinya, mengetahui apa yang mereka kerjakan.\qt@no{25}}%
\qt@newcmd\qurantrans@id@mmmmccxcviii{%
(Dan Dia memperkenankan doa orang-orang yang beriman serta mengerjakan amal yang saleh) maksudnya, Dia mengabulkan apa yang mereka minta (dan menambah kepada mereka) maksudnya, Allah menambah kepada mereka (dari karunia-Nya. Dan orang-orang yang kafir bagi mereka azab yang sangat keras.)\qt@no{26}}%
\qt@newcmd\qurantrans@id@mmmmccxcix{%
(Dan jika Allah melapangkan rezeki kepada hamba-hamba-Nya) semuanya (tentulah mereka akan melampaui batas) semuanya akan melampaui batas; tentulah mereka akan berlaku sewenang-wenang (di muka bumi, tetapi Allah menurunkan) dapat dibaca Yunazzilu atau Yunzilu, yakni menurunkan rezeki-Nya (apa yang dikehendaki-Nya dengan ukuran) maka Dia melapangkan rezeki itu kepada sebagian hamba-hamba-Nya, sedangkan yang lainnya tidak; dan timbulnya sikap melampaui batas ini dari melimpahnya rezeki. (Sesungguhnya Dia Maha Mengetahui keadaan hamba-hamba-Nya lagi Maha Melihat.)\qt@no{27}}%
\qt@newcmd\qurantrans@id@mmmmccc{%
(Dan Dialah Yang menurunkan hujan) yakni air hujan (sesudah mereka berputus asa) putus harapan dari turunnya hujan (dan menyebarkan rahmat-Nya) maksudnya, menyebarkan hujan yang diturunkan-Nya. (Dan Dialah Yang Maha Pelindung) yang berbuat baik kepada orang-orang Mukmin (lagi Maha Terpuji) di kalangan orang-orang beriman.\qt@no{28}}%
\qt@newcmd\qurantrans@id@mmmmccci{%
(Dan di antara tanda-tanda kekuasaan-Nya ialah menciptakan langit dan bumi dan) menciptakan (apa yang Dia sebarkan) Dia sebar ratakan (pada keduanya, yaitu berupa makhluk yang melata) pengertian Ad-Dabbah ialah makhluk yang menempati bumi, yaitu manusia dan lain-lainnya. (Dan Dia untuk mengumpulkan semuanya) mengumpulkan semua makhluk untuk dihadapkan kepada-Nya (Maha Kuasa jika dikehendaki-Nya) Dhamir Hum yang terdapat pada lafal Jam'ihim lebih memprioritaskan makhluk yang berakal daripada makhluk lainnya.\qt@no{29}}%
\qt@newcmd\qurantrans@id@mmmmcccii{%
(Dan apa saja yang telah menimpa kalian) khithab ayat ini ditujukan kepada orang-orang mukmin (berupa musibah) berupa malapetaka dan kesengsaraan (maka adalah karena perbuatan tangan kalian sendiri) artinya, sebab dosa-dosa yang telah kalian lakukan sendiri. Diungkapkan bahwa dosa-dosa tersebut dikerjakan oleh tangan mereka, hal ini mengingat, bahwa kebanyakan pekerjaan manusia itu dilakukan oleh tangan (dan Allah memaafkan sebagian besar) dari dosa-dosa tersebut, karena itu Dia tidak membalasnya. Dia Maha Mulia dari menduakalikan pembalasan-Nya di akhirat. Adapun mengenai musibah yang menimpa kepada orang-orang yang tidak berdosa di dunia, dimaksudkan untuk mengangkat derajatnya di akhirat kelak.\qt@no{30}}%
\qt@newcmd\qurantrans@id@mmmmccciii{%
(Dan kalian tidak dapat) hai orang-orang musyrik (melepaskan diri) melarikan diri dari azab Allah (di muka bumi) maksudnya, kalian tidak akan dapat meloloskan diri dan menghindar dari azab-Nya itu (dan kalian tidak memperoleh selain Allah) (seorang pelindung pun dan tidak pula seorang penolong) yang dapat menolak azab Allah dari kalian.\qt@no{31}}%
\qt@newcmd\qurantrans@id@mmmmccciv{%
(Dan di antara tanda-tanda kekuasaan-Nya ialah kapal-kapal) atau perahu-perahu yang dapat berlayar (di laut seperti gunung-gunung) artinya, mirip seperti bukit-bukit dalam besarnya.\qt@no{32}}%
\qt@newcmd\qurantrans@id@mmmmcccv{%
(Jika Dia menghendaki Dia akan menenangkan angin, maka jadilah kapal-kapal itu) sehingga jadilah kapal-kapal itu (terhenti) diam tidak dapat melaju (di permukaan laut. Sesungguhnya pada yang demikian itu terdapat tanda-tanda kekuasaan-Nya bagi setiap orang yang banyak bersabar dan banyak bersyukur) yang dimaksud adalah orang mukmin, dia dapat bersabar di kala tertimpa musibah dan bersyukur di kala hidup senang.\qt@no{33}}%
\qt@newcmd\qurantrans@id@mmmmcccvi{%
(Atau kapal-kapal itu dibinasakan-Nya) lafal ayat ini di'athafkan kepada Yuskin artinya, atau Dia menenggelamkan kapal-kapal itu berikut para penumpang dan apa yang dimuatnya, yaitu dengan menimbulkan angin badai (karena perbuatan mereka) disebabkan dosa-dosa yang dilakukan oleh para penumpangnya (atau Dia memberi maaf sebagian besar) dari dosa-dosa itu, yang karenanya Dia tidak menenggelamkan para pelakunya.\qt@no{34}}%
\qt@newcmd\qurantrans@id@mmmmcccvii{%
(Dan supaya mengetahui) lafal ayat ini kalau dibaca Rafa' berarti merupakan jumlah Isti'naf atau kalimat baru, kalau dibaca Nashab berarti di'athafkan kepada Ta'lil yang diperkirakan keberadaannya, yaitu; Dia menenggelamkan mereka sebagai pembalasan dari-Nya kepada mereka, dan supaya mengetahui (orang-orang yang membantah ayat-ayat Kami, bahwa mereka sekali-kali tidak akan memperoleh jalan keluar) maksudnya, tempat untuk melarikan diri dari azab Kami. Jumlah Nafi atau lafal Ma Lahum Min Mahiish menduduki tempat dua Maf'ul bagi lafal Ya'lama. Sedangkan Nafinya sendiri di-mu'allaqkan dari amalnya.\qt@no{35}}%
\qt@newcmd\qurantrans@id@mmmmcccviii{%
(Maka apa yang diberikan kepada kalian) khithab ayat ini ditujukan kepada orang-orang mukmin dan lain-lainnya (berupa sesuatu) dari perhiasan duniawi (itu adalah kenikmatan hidup di dunia) untuk dinikmati kemudian lenyap sesudah itu (dan yang ada pada sisi Allah) berupa pahala (lebih baik dan lebih kekal bagi orang-orang yang beriman dan hanya kepada Rabb mereka, mereka bertawakal) kemudian di'athafkan kepadanya ayat berikut ini, yaitu:\qt@no{36}}%
\qt@newcmd\qurantrans@id@mmmmcccix{%
(Dan bagi orang-orang yang menjauhi dosa-dosa besar dan perbuatan-perbuatan keji) yang mengharuskan pelakunya menjalani hukuman Hadd; lafal ayat ini merupakan 'Athful Ba'dh 'Alal Kull (dan apabila mereka marah mereka memberi maaf) maksudnya, mereka selalu bersikap maaf.\qt@no{37}}%
\qt@newcmd\qurantrans@id@mmmmcccx{%
(Dan bagi orang-orang yang menerima seruan Rabbnya) yang mematuhi apa yang diserukan Rabbnya yaitu, mentauhidkan-Nya dan menyembah-Nya (dan mendirikan salat) memeliharanya (sedangkan urusan mereka) yang berkenaan dengan diri mereka (mereka putuskan di antara mereka dengan musyawarah) memutuskannya secara musyawarah dan tidak tergesa-gesa dalam memutuskannya (dan sebagian dari apa yang Kami rezekikan kepada mereka) atau sebagian dari apa yang Kami berikan kepada mereka (mereka menafkahkannya) untuk jalan ketaatan kepada Allah. Dan orang-orang yang telah disebutkan tadi merupakan suatu golongan kemudian golongan yang lainnya ialah;\qt@no{38}}%
\qt@newcmd\qurantrans@id@mmmmcccxi{%
(Dan bagi orang-orang yang apabila mereka diperlakukan dengan lalim) dizalimi (mereka membela diri) maksudnya membalas perlakuan zalim itu sesuai dengan kelaliman yang diterimanya, sebagaimana yang diungkapkan oleh firman-Nya:\qt@no{39}}%
\qt@newcmd\qurantrans@id@mmmmcccxii{%
(Dan balasan suatu kejahatan adalah kejahatan yang serupa) kejahatan yang kedua ini dinamakan pula sebagai kejahatan bukan pembalasan, karena jenis dan gambarannya sama dengan yang pertama. Hal ini tampak jelas di dalam masalah yang menyangkut kisas luka. Sebagian di antara para ahli fikih mengatakan, bahwa jika ada seseorang mengatakan kepadamu, ``Semoga Allah menghinakan kamu," maka pembalasan yang setimpal ialah harus dikatakan pula kepadanya, ``Semoga Allah menghinakan kamu pula (maka barang siapa memaafkan) orang yang berbuat lalim kepadanya (dan berbuat baik) yakni tetap berlaku baik kepada orang yang telah ia maafkan (maka pahalanya atas tanggungan Allah) artinya, Allah pasti akan membalas pahalanya. (Sesungguhnya Dia tidak menyukai orang-orang yang lalim) maksudnya Dia tidak menyukai orang-orang yang memulai berbuat lalim, maka barang siapa yang memulai berbuat lalim dia akan menanggung akibatnya, yaitu siksaan dari-Nya.\qt@no{40}}%
\qt@newcmd\qurantrans@id@mmmmcccxiii{%
(Dan sesungguhnya orang-orang yang membela diri sesudah teraniaya) sesudah ia menerima penganiayaan dari orang lain (tidak ada suatu dosa pun atas mereka) maksudnya, mereka tidak berdosa bila menuntut.\qt@no{41}}%
\qt@newcmd\qurantrans@id@mmmmcccxiv{%
(Sesungguhnya dosa itu atas orang-orang yang berbuat lalim kepada manusia dan melampaui batas) yaitu mereka mengerjakan hal-hal (di muka bumi tanpa hak) mereka mengerjakan perbuatan-perbuatan maksiat. (Mereka itu mendapat azab yang pedih) yaitu azab yang menyakitkan.\qt@no{42}}%
\qt@newcmd\qurantrans@id@mmmmcccxv{%
(Tetapi orang yang bersabar) dan ia tidak membela dirinya atau tidak menuntut balas (dan memaafkan) memaafkan kelaliman orang lain terhadap dirinya (sesungguhnya yang demikian itu) yaitu sabar dan pemaaf (termasuk hal-hal yang diutamakan) yang dianjurkan oleh syariat.\qt@no{43}}%
\qt@newcmd\qurantrans@id@mmmmcccxvi{%
(Dan siapa yang disesatkan Allah maka tidak ada baginya seorang pemimpin pun sesudah itu) artinya tiada seorang pun yang dapat memberikan petunjuk kepadanya sesudah ia disesatkan oleh Allah (Dan kamu akan melihat orang-orang yang lalim ketika mereka melihat azab berkata, ``Adakah kiranya jalan untuk kembali) ke dunia bagi kami."\qt@no{44}}%
\qt@newcmd\qurantrans@id@mmmmcccxvii{%
(Dan kamu akan melihat mereka dihadapkan kepadanya) yakni ke neraka (dalam keadaan tunduk) takut dan merasa rendah diri (karena merasa hina, mereka melihat) ke neraka (dengan pandangan yang lesu) atau dengan pandangan yang malas. Huruf Min di sini bermakna Ibtidaiyah atau bermakna sama dengan huruf Ba. (Dan orang-orang yang beriman berkata, ``Sesungguhnya orang-orang yang merugi ialah orang-orang yang kehilangan diri mereka sendiri dan kehilangan keluarga mereka pada hari kiamat") karena mereka kekal menjadi penghuni neraka dan tidak memperoleh bidadari-bidadari yang telah disediakan buat mereka seandainya mereka beriman. Isim Maushul atau lafal Al Ladziina Khasiruu Anfusahum merupakan Khabar dari lafal Inna. (Ingatlah, sesungguhnya orang-orang yang zalim itu) yakni orang-orang yang kafir itu (berada dalam azab yang kekal) azab yang abadi; ini adalah firman Allah swt.\qt@no{45}}%
\qt@newcmd\qurantrans@id@mmmmcccxviii{%
(Dan mereka sekali-kali tidak mempunyai pelindung-pelindung yang dapat menolong mereka selain Allah) yang dapat menolak azab-Nya dari diri mereka (Dan siapa yang disesatkan Allah maka tidaklah ada baginya sesuatu jalan pun) yaitu jalan yang benar baginya di dunia dan jalan yang dapat mengantarkannya ke surga, di akhirat kelak.\qt@no{46}}%
\qt@newcmd\qurantrans@id@mmmmcccxix{%
(Patuhilah seruan Rabb kalian) perkenankanlah seruan-Nya, yaitu dengan mentauhidkan-Nya dan menyembah-Nya (sebelum datang suatu hari) yakni hari kiamat (dari Allah yang tidak dapat ditolak kedatangannya) apabila hari itu datang tidak dapat ditolak. (Kalian tidak memperoleh tempat berlindung) yang kalian dapat berlindung di dalamnya (pada hari itu dan tidak pula dapat mengingkari) dosa-dosa kalian.\qt@no{47}}%
\qt@newcmd\qurantrans@id@mmmmcccxx{%
(Jika mereka berpaling) tidak mau mematuhi seruan-Nya itu (maka Kami tidak mengutus kamu sebagai pemelihara bagi mereka) sebagai orang yang memelihara amal perbuatan mereka, umpamanya kamu menjadi orang yang memperturutkan apa yang dikehendaki oleh mereka. (Tidak lain) tiada lain (kewajibanmu hanyalah menyampaikan risalah) hal ini sebelum ada perintah untuk berjihad. (Sesungguhnya apabila Kami merasakan kepada manusia sesuatu rahmat dari Kami) berupa nikmat seperti kekayaan atau kecukupan dan kesehatan (dia bergembira ria karena rahmat itu. Dan jika mereka ditimpa) Dhamir yang kembali kepada lafal Al-Insaan memandang kepada segi maknanya atau jenisnya (kesusahan) malapetaka atau musibah (disebabkan perbuatan tangan mereka sendiri) disebabkan yang mereka lakukan; dalam ayat ini diungkapkan kata 'tangan mereka sendiri' karena kebanyakan pekerjaan manusia itu dilakukan oleh tangannya (karena sesungguhnya manusia itu amat ingkar) kepada nikmat yang telah diberikan kepadanya.\qt@no{48}}%
\qt@newcmd\qurantrans@id@mmmmcccxxi{%
(Kepunyaan Allahlah kerajaan langit dan bumi. Dia menciptakan apa yang Dia kehendaki. Dia memberikan kepada siapa yang Dia kehendaki) yakni berupa anak-anak (yaitu anak-anak perempuan dan Dia memberikan anak-anak lelaki kepada siapa yang Dia kehendaki.)\qt@no{49}}%
\qt@newcmd\qurantrans@id@mmmmcccxxii{%
(Atau Dia menganugerahkan kedua jenis) atau Dia menjadikan buat mereka (laki-laki dan perempuan, dan Dia menjadikan mandul siapa yang Dia kehendaki) sehingga tidak mempunyai anak dan tidak dapat membuahi. (Sesungguhnya Dia Maha Mengetahui) apa yang diciptakan-Nya (lagi Maha Kuasa) atas semua apa yang dikehendaki-Nya.\qt@no{50}}%
\qt@newcmd\qurantrans@id@mmmmcccxxiii{%
(Dan tidak mungkin bagi seorang manusia pun bahwa Allah berkata-kata dengan dia kecuali) dengan perantaraan (wahyu) yang Dia wahyukan kepadanya di dalam tidurnya atau melalui ilham (atau) melainkan (di belakang tabir) seumpamanya Allah memperdengarkan kalam-Nya kepadanya, tetapi dia tidak dapat melihat-Nya, sebagaimana yang telah terjadi pada Nabi Musa a.s. (atau) kecuali (dengan mengutus seorang utusan) yakni malaikat, seperti Jibril (lalu diwahyukan kepadanya) maksudnya, utusan itu menyampaikan wahyu-Nya kepada rasul yang dituju (dengan seizin-Nya) dengan seizin Allah (apa yang Dia kehendaki) apa yang Allah kehendaki. (Sesungguhnya Dia Maha Tinggi) dari sifat-sifat yang dimiliki oleh semua makhluk (lagi Maha Bijaksana) di dalam perbuatan-Nya.\qt@no{51}}%
\qt@newcmd\qurantrans@id@mmmmcccxxiv{%
(Dan demikianlah) maksudnya, sebagaimana Kami wahyukan kepada rasul-rasul selain kamu (Kami wahyukan kepadamu) hai Muhammad (wahyu) yakni Alquran, yang karenanya kalbu manusia dapat hidup (dengan perintah Kami) yang Kami wahyukan kepadamu. (Sebelumnya kamu tidaklah mengetahui) sebelum Kami mewahyukan kepadamu (apakah Alkitab) yakni Alquran itu (dan tidak pula mengetahui apakah iman itu) yakni syariat-syariat dan tanda-tanda-Nya Nafi dalam ayat ini amalnya di-ta'alluqkan kepada Fi'il dan lafal-lafal sesudah Fi'il menempati kedudukan dua Maf'ulnya (tetapi Kami menjadikan Alquran itu) wahyu atau Alquran itu (cahaya, yang Kami tunjuki dengan dia siapa yang Kami kehendaki di antara hamba-hamba Kami. Dan sesungguhnya kamu benar-benar memberi petunjuk) maksudnya kamu menyeru dengan wahyu yang diturunkan kepadamu (kepada jalan) tuntunan (yang lurus) yakni agama Islam.\qt@no{52}}%
\qt@newcmd\qurantrans@id@mmmmcccxxv{%
(Yaitu jalan Allah yang kepunyaan-Nya segala apa yang ada di langit dan apa yang ada di bumi) sebagai milik-Nya, makhluk-Nya dan hamba-hamba-Nya. (Ingatlah, bahwa kepada Allahlah kembali semua urusan) semua urusan dikembalikan.\qt@no{53}}%
\qt@newcmd\qurantrans@id@mmmmcccxxvi{%
\basmalahid (Ha Mim) hanya Allah sajalah yang mengetahui arti dan maksudnya.\qt@no{1}}%
\qt@newcmd\qurantrans@id@mmmmcccxxvii{%
(Demi Alkitab) demi Alquran (yang menerangkan) yang menonjolkan jalan petunjuk beserta dengan sarana yang diperlukannya yaitu berupa syariat.\qt@no{2}}%
\qt@newcmd\qurantrans@id@mmmmcccxxviii{%
(Sesungguhnya Kami menjadikan Alquran) maksudnya, Kami adakan Alkitab ini (bacaan yang berbahasa Arab) atau memakai bahasa Arab (supaya kalian) hai penduduk Mekah (memahaminya) memahami makna-maknanya.\qt@no{3}}%
\qt@newcmd\qurantrans@id@mmmmcccxxix{%
(Dan sesungguhnya Alquran itu) telah ditetapkan (dalam induk Alkitab) asal Kitab, yaitu Lohmahfuz (di sisi Kami) lafal ayat ini menjadi Badal dari lafal 'Indana (adalah benar-benar tinggi) yang jauh lebih tinggi daripada Kitab-kitab sebelumnya (dan amat banyak mengandung hikmah) artinya sangat padat dengan hikmah-hikmah.\qt@no{4}}%
\qt@newcmd\qurantrans@id@mmmmcccxxx{%
(Maka apakah Kami akan berhenti) akan menahan (menurunkan Adz-Dzikr kepada kalian) yakni Alquran (dengan sebenar-benarnya) maksudnya Kami benar-benar menahan Alquran dan tidak menurunkannya kepada kalian, karena itu kalian tidak lagi terkena amar makruf dan nahi mungkar, demikian itu hanya (karena kalian adalah kaum yang melampaui batas?) kaum yang musyrik tentu tidak.\qt@no{5}}%
\qt@newcmd\qurantrans@id@mmmmcccxxxi{%
(Berapa banyak nabi-nabi yang telah Kami utus kepada umat-umat yang terdahulu.)\qt@no{6}}%
\qt@newcmd\qurantrans@id@mmmmcccxxxii{%
(Dan tiada) (yang datang kepada mereka) atau tiba kepada mereka (seorang nabi pun melainkan mereka selalu memperolok-olokkannya) sebagaimana kaummu memperolok-olokkan kamu, ayat ini merupakan penghibur bagi Nabi saw.\qt@no{7}}%
\qt@newcmd\qurantrans@id@mmmmcccxxxiii{%
(Maka telah Kami binasakan orang-orang yang lebih hebat daripada mereka) daripada kaummu (kekuatannya) maksudnya daya dan kekuatan mereka lebih kuat daripada kaummu (dan telah terdahulu) telah disebutkan di dalam ayat-ayat yang lain (perumpamaan umat-umat yang terdahulu) yaitu mengenai dibinasakannya mereka, maka akibat yang akan dialami oleh kaummu sama saja.\qt@no{8}}%
\qt@newcmd\qurantrans@id@mmmmcccxxxiv{%
(Dan sungguh jika) huruf Lam di sini bermakna Qasam (kamu tanyakan kepada mereka, ``Siapakah yang menciptakan langit dan bumi?" Niscaya mereka akan menjawab,) dari lafal Layaquulunna terbuang Nun alamat Rafa'nya, karena jika masih ada, maka akan terjadilah huruf Nun yang berturut-turut, dan hal ini dinilai jelek oleh orang-orang Arab. Sebagaimana dibuang pula daripadanya Wawu Dhamir jamak, tetapi 'Illatnya bukan karena bertemunya dua huruf yang disukunkan ("Semuanya diciptakan oleh Yang Maha Perkasa lagi Maha Mengetahui") jawaban terakhir mereka adalah, ``Allah Yang Maha Perkasa dan Maha Mengetahuilah yang menciptakan kesemuanya itu." Selanjutnya Allah swt. menambahkan:\qt@no{9}}%
\qt@newcmd\qurantrans@id@mmmmcccxxxv{%
(Yang menjadikan bumi untuk kalian sebagai tempat menetap) sebagai hamparan yang mirip dengan ayunan bayi (dan Dia membuat jalan-jalan di atas bumi untuk kalian) dilalui (supaya kalian mendapat petunjuk) untuk mencapai tujuan-tujuan di dalam perjalanan kalian.\qt@no{10}}%
\qt@newcmd\qurantrans@id@mmmmcccxxxvi{%
(Dan Yang menurunkan air dari langit menurut kadar) yang diperlukan oleh kalian, dan Dia tidak menurunkannya dalam bentuk hujan yang sangat besar yang disertai dengan angin topan (lalu Kami hidupkan dengan air itu negeri yang mati, seperti itulah) sebagaimana cara menghidupkan itulah (kalian akan dikeluarkan) dari dalam kubur kalian lalu kalian menjadi hidup kembali.\qt@no{11}}%
\qt@newcmd\qurantrans@id@mmmmcccxxxvii{%
(Dan Yang menciptakan makhluk yang berpasang-pasangan) berbagai jenis makhluk berpasang-pasangan (semuanya, dan menjadikan untuk kalian kapal) atau perahu-perahu (dan binatang ternak) misalnya unta (yang kalian tunggangi) di dalam lafal ayat ini dibuang daripadanya Dhamir yang kembali kepada lafal Ma demi untuk meringkas, Dhamir tersebut adalah lafal Fihi maksudnya, yang dapat kalian kendarai.\qt@no{12}}%
\qt@newcmd\qurantrans@id@mmmmcccxxxviii{%
(Supaya kalian dapat duduk) tetap (di atas punggungnya) Dhamir yang ada pada ayat ini dimudzakkarkan, dan lafal Zhahr dikemukakan dalam bentuk jamak sehingga menjadi Zhuhur; hal ini karena memandang makna yang terkandung di dalam lafal Ma (kemudian kalian ingat nikmat Rabb kalian apabila kalian telah duduk di atasnya dan supaya kalian mengatakan, ``Maha Suci Tuhan yang telah menundukkan semua ini bagi kami padahal kami sebelumnya tidak mampu menguasainya) tidak dapat menguasainya.\qt@no{13}}%
\qt@newcmd\qurantrans@id@mmmmcccxxxix{%
(Dan sesungguhnya kami akan kembali kepada Rabb kami") kami akan dikembalikan kepada-Nya.\qt@no{14}}%
\qt@newcmd\qurantrans@id@mmmmcccxl{%
(Dan mereka menjadikan sebagian dari hamba-hamba-Nya sebagai bagian daripada-Nya) karena mereka telah mengatakan, bahwa malaikat-malaikat itu adalah anak-anak perempuan Allah. Dikatakan Juz'an atau bagian, karena anak itu adalah bagian dari orang tuanya; padahal hakikatnya malaikat-malaikat itu adalah hamba-hamba Allah swt. (Sesungguhnya manusia) yang telah mengatakan perkataan tadi (benar-benar pengingkar yang nyata) yang jelas dan nyata kekafirannya.\qt@no{15}}%
\qt@newcmd\qurantrans@id@mmmmcccxli{%
(Patutkah) lafal Am di sini bermakna Istifham Inkari, sedangkan lafal Al Qaulu diperkirakan keberadaannya sesudah itu, yakni Ataquluna: Apakah kalian patut mengatakan (Dia mengambil anak perempuan dari yang diciptakan-Nya) untuk diri-Nya sendiri (dan Dia mengkhususkan buat kalian) memilihkan buat kalian (anak laki-laki) yang hal ini disimpulkan daripada perkataan kalian yang tadi itu; jumlah kalimat ini merupakan kalimat yang diinkari oleh Istifham tadi.\qt@no{16}}%
\qt@newcmd\qurantrans@id@mmmmcccxlii{%
(Padahal apabila salah seorang di antara mereka diberi kabar gembira dengan apa yang dijadikan sebagai misal bagi Allah Yang Maha Pemurah) maksudnya, dijadikan baginya hal serupa dengan apa yang ia nisbatkan kepada Allah, yaitu diberi anak-anak perempuan. Atau dengan kata lain, apabila ia diberi berita gembira tentang kelahiran anak perempuannya (jadilah) maka menjadi berubahlah (mukanya hitam) artinya, roman mukanya tampak berubah menjadi kelabu (sedangkan dia amat menahan sedih) penuh dengan kedukaan, maka mengapa mereka berani menisbatkan anak-anak perempuan kepada Allah swt.?\qt@no{17}}%
\qt@newcmd\qurantrans@id@mmmmcccxliii{%
(Dan apakah patut) Hamzah atau kata tanya di sini mengandung pengertian ingkar, sedangkan Wawu 'Athafnya menunjukkan 'Athaf jumlah kepada jumlah yang lain. Maksudnya, apakah patut mereka menjadikan bagi Allah (orang yang dibesarkan dalam perhiasan) maksudnya selalu berhias diri (sedangkan dia tidak dapat memberi alasan yang terang dalam pertengkaran) tidak pernah menang di dalam adu argumentasi karena kelemahan akalnya sebagai perempuan.\qt@no{18}}%
\qt@newcmd\qurantrans@id@mmmmcccxliv{%
(Dan mereka menjadikan malaikat-malaikat yang mereka itu adalah hamba-hamba Allah Yang Maha Pemurah sebagai orang-orang perempuan. Apakah mereka menyaksikan) apakah mereka hadir menyaksikan (penciptaan malaikat-malaikat itu? Kelak akan dituliskan persaksian mereka) yang menyatakan bahwa malaikat-malaikat itu adalah orang-orang perempuan (dan mereka akan dimintai pertanggungjawaban) di akhirat kelak tentang perkataan itu, karenanya mereka akan menerima siksaan yang pedih.\qt@no{19}}%
\qt@newcmd\qurantrans@id@mmmmcccxlv{%
(Dan mereka berkata, ``Jika Allah Yang Maha Pemurah menghendaki tentulah kami tidak menyembah mereka") tidak menyembah malaikat; maka ibadah atau penyembahan kami kepada mereka berdasarkan kehendak dari-Nya, Dia rela kami melakukan hal itu. Lalu Allah berfirman, ``(Tiadalah bagi mereka tentang hal itu) yakni dugaan mereka yang mengatakan bahwa Allah rela mereka menyembah malaikat (suatu pengetahuan pun, tidak lain) tiada lain (mereka hanya menduga-duga belaka) hanya berdusta belaka tentang itu, karenanya mereka harus menerima siksaan.\qt@no{20}}%
\qt@newcmd\qurantrans@id@mmmmcccxlvi{%
(Atau adakah Kami memberikan sebuah Kitab kepada mereka sebelumnya) sebelum Alquran yang di dalamnya terdapat anjuran untuk menyembah selain Allah (lalu mereka berpegang dengan kitab itu?) hal tersebut tentu saja tidak akan terjadi.\qt@no{21}}%
\qt@newcmd\qurantrans@id@mmmmcccxlvii{%
(Bahkan mereka berkata, 'Sesungguhnya kami mendapati bapak-bapak kami menganut suatu agama) yang diyakininya (dan sesungguhnya kami) berjalan atau mengikuti (jejak-jejak mereka sebagai petunjuk kami')" dan bapak-bapak kami itu menyembah selain Allah.\qt@no{22}}%
\qt@newcmd\qurantrans@id@mmmmcccxlviii{%
(Dan demikianlah Kami tidak mengutus sebelum kamu seorang pemberi peringatan pun dalam suatu negeri, melainkan orang-orang yang hidup mewah di negeri itu berkata) yakni mereka yang bergelimang di dalam kemewahan hidup pasti mengatakan sebagaimana apa yang telah dikatakan oleh kaummu, ("Sesungguhnya kami mendapati bapak-bapak kami menganut suatu agama) suatu tuntunan (dan sesungguhnya kami adalah pengikut jejak-jejak mereka") mengikuti jejak-jejak mereka.\qt@no{23}}%
\qt@newcmd\qurantrans@id@mmmmcccxlix{%
(Rasul itu berkata) kepada mereka, ("Apakah) kalian akan mengikutinya juga (sekalipun aku membawa untuk kalian agama yang lebih nyata memberi petunjuk daripada apa yang kalian dapati bapak-bapak kalian menganutnya?" Mereka menjawab, ``Sesungguhnya kami terhadap agama yang kamu diutus untuk menyampaikannya) yaitu yang disampaikan oleh kamu dan oleh rasul-rasul yang sebelum kamu (adalah orang-orang yang ingkar") maka Allah berfirman seraya mengancam mereka melalui firman selanjutnya:\qt@no{24}}%
\qt@newcmd\qurantrans@id@mmmmcccl{%
(Maka Kami binasakan mereka) orang-orang yang mendustakan rasul-rasul sebelum kamu itu (maka perhatikanlah bagaimana kesudahan orang-orang yang mendustakan itu)\qt@no{25}}%
\qt@newcmd\qurantrans@id@mmmmcccli{%
(Dan) ingatlah (ketika Ibrahim berkata kepada bapaknya dan kaumnya, ``Sesungguhnya aku tidak bertanggung jawab) atau berlepas diri (terhadap apa yang kalian sembah.)\qt@no{26}}%
\qt@newcmd\qurantrans@id@mmmmccclii{%
(Tetapi aku menyembah Tuhan Yang menjadikanku) menyembah Allah yang telah menciptakan aku (karena sesungguhnya Dia akan memberi taufik kepadaku") artinya Dia pasti membimbingku kepada agama-Nya.\qt@no{27}}%
\qt@newcmd\qurantrans@id@mmmmcccliii{%
(Dan Ibrahim menjadikannya) kalimat tauhid, yang tersimpul dari perkataannya, sebagaimana yang disitir oleh firman-Nya, ``Sesungguhnya aku pergi menghadap kepada Rabbku, dan Dia akan memberi petunjuk kepadaku..." (Q.S. Ash shaffat, 99). (sebagai kalimat yang kekal pada keturunannya) pada anak cucunya, maka tetap akan ada orang-orang yang mengesakan Allah di antara keturunannya itu (supaya mereka) penduduk Mekah (kembali) meninggalkan apa yang biasa mereka lakukan, yaitu menyembah berhala, kemudian memeluk agama bapak moyang mereka, yakni Nabi Ibrahim.\qt@no{28}}%
\qt@newcmd\qurantrans@id@mmmmcccliv{%
(Tetapi Aku telah memberikan kenikmatan hidup kepada mereka) kepada orang-orang musyrik itu (dan bapak-bapak mereka) dan Aku tidak menyegerakan hukuman-Ku kepada mereka (sehingga datanglah kebenaran kepada mereka) Alquran yang membawa kebenaran (dan seorang rasul yang memberi penjelasan) yang menampakkan kepada mereka hukum-hukum syariat, yaitu Nabi Muhammad saw.\qt@no{29}}%
\qt@newcmd\qurantrans@id@mmmmccclv{%
(Dan tatkala kebenaran itu datang kepada mereka) yakni Alquran (mereka berkata, ``Ini adalah sihir dan sesungguhnya kami adalah orang-orang yang mengingkarinya.")\qt@no{30}}%
\qt@newcmd\qurantrans@id@mmmmccclvi{%
(Dan mereka berkata, ``Mengapa tidak) kenapa tidak (diturunkan Alquran ini kepada seorang besar dari) kalangan penduduk (da negeri) yakni Mekah dan Madinah, maksudnya dari salah satu antara keduanya (yang besar ini?") yang dimaksud oleh mereka adalah Al Walid Ibnu Mughirah di Mekah, atau Urwah ibnu Mas'ud Ats Tsaqafi di Thaif.\qt@no{31}}%
\qt@newcmd\qurantrans@id@mmmmccclvii{%
(Apakah mereka yang membagi-bagi rahmat Rabbmu?) yang dimaksud dengan rahmat adalah kenabian (Kami telah menentukan antara mereka penghidupan mereka dalam kehidupan dunia) maka Kami jadikan sebagian dari mereka kaya dan sebagian lainnya miskin (dan Kami telah meninggikan sebagian mereka) dengan diberi kekayaan (atas sebagian yang lain beberapa derajat, agar sebagian mereka dapat mempergunakan) golongan orang-orang yang berkecukupan (sebagian yang lain) atas golongan orang-orang yang miskin (sebagai pekerja) maksudnya, pekerja berupah; huruf Ya di sini menunjukkan makna Nasab, dan menurut suatu qiraat lafal Sukhriyyan dibaca Sikhriyyan yaitu dengan dikasrahkan huruf Sin-nya (Dan rahmat Rabbmu) yakni surga Rabbmu (lebih baik daripada apa yang mereka kumpulkan) di dunia.\qt@no{32}}%
\qt@newcmd\qurantrans@id@mmmmccclviii{%
(Dan sekiranya bukan karena hendak menghindari manusia menjadi umat yang satu) dalam kekafiran (tentulah Kami buatkan bagi orang-orang yang kafir kepada Tuhan Yang Maha Pemurah bagi rumah-rumah mereka) lafal Libuyutihim menjadi Badal dari lafal Liman (loteng-loteng) dapat dibaca Saqfan atau Suqfan keduanya adalah bentuk jamak (dari perak dan juga tangga-tangga) dari perak pula (yang mereka menaikinya) yang dapat mereka naiki untuk mencapai atap rumah-rumah mereka.\qt@no{33}}%
\qt@newcmd\qurantrans@id@mmmmccclix{%
(Dan Kami buatkan pula -pintu-pintu bagi rumah-rumah mereka) yang juga terbuat dari perak (dan) begitu pula Kami buatkan untuk mereka (dipan-dipan) yang terbuat dari perak; lafal Sururan adalah bentuk jamak dari lafal Sarirun artinya, ranjang atau dipan (yang mereka bertelekan atasnya.)\qt@no{34}}%
\qt@newcmd\qurantrans@id@mmmmccclx{%
(Dan Kami buatkan pula perhiasan-perhiasan) dari emas untuk mereka. Makna ayat, seandainya tidak karena khawatir orang mukmin akan menjadi kafir, bila Kami anugerahkan kepadanya hal-hal tersebut sebagaimana yang telah Kami berikan kepada orang kafir, tentulah Kami akan memberikan kepada orang mukmin hal-hal itu. Karena keduniaan itu tidak ada artinya di sisi Kami, dan kelak di akhirat tidak berharga sama sekali bila dibandingkan dengan nikmat surga. (Dan sesungguhnya) lafal In di sini adalah bentuk Takhfif dari Inna yang Tsaqilah; artinya sesungguhnya (semuanya itu tiada lain) jika dibaca Lama dengan cara Takhfif, maka huruf Ma adalah Zaidah, jika dibaca Lamma dengan memakai Tasydid pada huruf Mim maknanya sama dengan lafal Illa, dan lafal In bermakna Nafi. Menurut bacaan pertama arti ayat ini ialah, ``Dan sesungguhnya semuanya itu hanyalah. `` Menurut bacaan kedua artinya menjadi, ``Dan tiadalah semuanya itu melainkan (kesenangan kehidupan dunia) yang dapat dipakai untuk bersenang-senang kemudian lenyap sesudah itu (dan kehidupan di akhirat itu) yakni di surga (di sisi Rabbmu bagi orang-orang yang bertakwa.)\qt@no{35}}%
\qt@newcmd\qurantrans@id@mmmmccclxi{%
(Barang siapa yang berpaling) yaitu memalingkan diri (dari pengajaran Tuhan Yang Maha Pemurah) dari Alquran (Kami adakan) Kami jadikan (baginya setan, maka setan itulah yang menjadi teman yang selalu menyertainya) yakni tidak pernah berpisah darinya.\qt@no{36}}%
\qt@newcmd\qurantrans@id@mmmmccclxii{%
(Dan sesungguhnya mereka) setan-setan itu (benar-benar menghalangi mereka) menghalangi orang-orang yang berpaling itu (dari jalan yang benar) atau jalan petunjuk (dan mereka menyangka bahwa mereka mendapat petunjuk) disebutkannya Dhamir dengan memakai kata jamak karena memandang segi makna yang dikandung lafal Man.\qt@no{37}}%
\qt@newcmd\qurantrans@id@mmmmccclxiii{%
(Sehingga apabila orang yang berpaling itu datang kepada Kami) bersama dengan temannya atau setannya di hari kiamat kelak (dia berkata,) orang yang berpaling itu kepada temannya atau setannya ("Aduhai) huruf Ya di sini menunjukkan makna Tanbih (seandainya jarak antara aku dan kamu seperti jarak antara masyriq dan Magrib) yakni sejauh jarak antara timur dan barat (maka sejelek-jelek teman) bagiku adalah kamu." Lalu Allah berfirman:\qt@no{38}}%
\qt@newcmd\qurantrans@id@mmmmccclxiv{%
(Sekali-kali tidak akan memberi manfaat kepada kalian) angan-angan dan penyesalan kalian itu, hai orang-orang yang berpaling (di hari ini karena kalian telah berbuat aniaya) maksudnya telah jelaslah kelaliman kalian dengan sebab menyekutukan Allah sewaktu di dunia. Lafal Idz merupakan Badal dari lafal Al Yaumu. (Bahwasanya kalian) bersama dengan teman-teman kalian (bersekutu dalam azab ini) adanya illat dalam ayat ini diperkirakan keberadaannya, tidak disebutkan karena kurang penting.\qt@no{39}}%
\qt@newcmd\qurantrans@id@mmmmccclxv{%
(Maka apakah kamu dapat menjadikan orang yang pekak dapat mendengar, atau dapatkah kamu memberi petunjuk kepada orang yang buta hatinya dan kepada orang yang tetap dalam kesesatan yang nyata?) jelas sesatnya, maksudnya mereka tidak beriman.\qt@no{40}}%
\qt@newcmd\qurantrans@id@mmmmccclxvi{%
(Sungguh, jika) lafal Imma asalnya adalah gabungan antara Syarthiyyah dan Ma Zaidah (Kami mewafatkan kamu) sebelum Kami mengazab mereka (maka sesungguhnya Kami akan menyiksa mereka) di akhirat.\qt@no{41}}%
\qt@newcmd\qurantrans@id@mmmmccclxvii{%
(Atau kami memperlihatkan kepadamu) sewaktu kamu masih hidup (apa yang telah Kami ancamkan kepada mereka) yakni azab yang Kami ancamkan itu (maka sesungguhnya Kami atas mereka) maksudnya, untuk mengazab mereka (berkuasa) sangat berkuasa atau sangat mampu.\qt@no{42}}%
\qt@newcmd\qurantrans@id@mmmmccclxviii{%
(Maka berpegang teguhlah kamu kepada apa yang telah diwahyukan kepadamu) yakni Alquran. (Sesungguhnya kamu berada di atas jalan) atau tuntunan (yang lurus.)\qt@no{43}}%
\qt@newcmd\qurantrans@id@mmmmccclxix{%
(Dan sesungguhnya Alquran itu benar-benar adalah suatu kemuliaan besar) benar-benar merupakan kemuliaan yang besar (bagimu dan bagi kaummu) karena diturunkan dengan memakai bahasa mereka (dan kelak kalian akan diminta pertanggungan jawab) tentang pengamalannya.\qt@no{44}}%
\qt@newcmd\qurantrans@id@mmmmccclxx{%
(Dan tanyakanlah kepada rasul-rasul Kami yang telah Kami utus sebelum kamu, ``Adakah Kami menentukan selain Allah Yang Maha Pemurah) (sebagai tuhan-tuhan untuk disembah), menurut suatu pendapat bahwa hal ini memang berdasarkan kenyataan, yaitu seumpamanya Allah mengumpulkan rasul-rasul itu pada malam sewaktu nabi diisra-kan. Menurut pendapat yang lain bahwa yang dimaksud adalah umat-umat dari kalangan ahli kitab. Kedua pendapat tadi tidak usah diselidiki kebenarannya, karena makna yang dimaksud dari perintah menanyakan ini ialah untuk menetapkan terhadap orang-orang musyrik Quraisy, bahwasanya tiada seorang utusan pun dari Allah dan tiada pula suatu kitab pun yang diturunkan-Nya yang memerintahkan untuk menyembah kepada selain Allah.\qt@no{45}}%
\qt@newcmd\qurantrans@id@mmmmccclxxi{%
(Dan sesungguhnya Kami telah mengutus Musa dengan membawa mukjizat-mukjizat Kami kepada Firaun dan pemuka-pemuka kaumnya) yaitu bangsa Kobtik, (maka Musa berkata, ``Sesungguhnya aku adalah utusan dari Rabb seru sekalian alam.")\qt@no{46}}%
\qt@newcmd\qurantrans@id@mmmmccclxxii{%
(Maka tatkala dia datang kepada mereka dengan membawa mukjirat-mukjizat Kami) yang menunjukkan kebenaran risalah-Nya (dengan serta merta mereka menertawakannya.)\qt@no{47}}%
\qt@newcmd\qurantrans@id@mmmmccclxxiii{%
(Dan tidaklah Kami perlihatkan kepada mereka sesuatu tanda) yang menunjukkan azab Kami seperti banjir, topan, yaitu berupa air bah yang melanda rumah-rumah mereka yang ketinggiannya mencapai leher orang yang sedang duduk, hal ini berlangsung selama. tujuh hari, dan juga belalang-belalang yang memusnahkan tanaman-tanaman mereka (melainkan tanda atau azab itu lebih besar daripada azab-azab lainnya) yang sebelumnya. (Dan Kami timpakan kepada mereka azab supaya mereka kembali) sadar dari kekafirannya.\qt@no{48}}%
\qt@newcmd\qurantrans@id@mmmmccclxxiv{%
(Dan mereka berkata) kepada Musa tatkala mereka melihat adanya azab itu, ("Hai ahli sihir!) maksudnya, hai orang yang alim lagi sempurna ilmunya! Dikatakan demikian karena menurut mereka ilmu sihir itu adalah ilmu yang paling diagungkan di kalaagan mereka (Berdoalah kepada Rabbmu untuk kami, sesuai dengan apa yang telah dijanjikan-Nya kepadamu) yakni Dia akan melepaskan kami dari azab ini jika kami beriman (sesungguhnya kami benar-benar akan menjadi orang-orang yang mendapat petunjuk") atau mau beriman.\qt@no{49}}%
\qt@newcmd\qurantrans@id@mmmmccclxxv{%
(Maka tatkala Kami hilangkan) berkat doa Musa (azab itu dari mereka, dengan serta merta mereka memungkiri) janjinya, bahkan mereka masih tetap melaju di dalam kekafirannya.\qt@no{50}}%
\qt@newcmd\qurantrans@id@mmmmccclxxvi{%
(Dan Firaun berseru) dengan nada penuh kesombongan (kepada kaumnya seraya berkata, ``Hai kaumku, bukankah kerajaan Mesir ini kepunyaanku dan sungai-sungai ini) yaitu sungai Nil dan anak-anaknya (mengalir di bawahku) di bawah keraton-keratonku, adalah kepunyaanku juga (maka apakah kalian tidak melihat) keagungan dan kebesaranku?\qt@no{51}}%
\qt@newcmd\qurantrans@id@mmmmccclxxvii{%
(Bukankah) kalian telah melihat sesudah kesemuanya itu (aku lebih baik dari orang ini) dari Nabi Musa (yang dia adalah orang hina) lemah lagi hina (dan yang hampir tidak dapat berbicara dengan jelas) tidak dapat menjelaskan perkataannya, karena sewaktu kecil ia pernah memakan bara api, hingga lisannya pelan atau tidak fasih.\qt@no{52}}%
\qt@newcmd\qurantrans@id@mmmmccclxxviii{%
(Mengapa tidak) kenapa tidak dipakaikan kepadanya jika memang ia orang yang benar di dalam pengakuannya (gelang dari emas) lafal Asawirah adalah bentuk jamak dari lafal Aswiratun yang wazannya sama dengan lafal Aghribatun, dan lafal Aswiratun ini merupakan bentuk jamak pula dari lafal Siwarun. Maksud Firaun, mengapa tidak dipakaikan kepadanya gelang dari emas sebagaimana kebiasaan orang-orang yang diberi kekuasaan olehnya, yaitu orang tersebut diberi pakaian kebesaran yang terbuat dari emas dan pula dipakaikan kepadanya gelang emas sebagai tanda kedudukannya (atau malaikat datang bersama-sama dia mengiringkannya") datang berturut-turut kepadanya seraya menyatakan kebenaran kerasulannya.\qt@no{53}}%
\qt@newcmd\qurantrans@id@mmmmccclxxix{%
(Maka Firaun mempengaruhi) berupaya menanamkan pengaruhnya kepada (kaumnya, lalu mereka patuh kepadanya) mematuhi apa yang dikehendaki oleh Firaun, yaitu mendustakan Musa (karena sesungguhnya mereka adalah kaum yang fasik.)\qt@no{54}}%
\qt@newcmd\qurantrans@id@mmmmccclxxx{%
(Maka tatkala mereka membuat Kami murka) (Kami menghukum mereka lalu Kami tenggelamkan mereka semuanya di laut.)\qt@no{55}}%
\qt@newcmd\qurantrans@id@mmmmccclxxxi{%
(Dan Kami jadikan mereka sebagai pelajaran) lafal Salafan merupakan bentuk jamak dari lafal salifun, wazannya sama dengan lafal Khadimun atau pelayan, yang jamaknya adalah Khadamun; yakni orang-orang terdahulu yang dijadikan sebagai pelajaran (dan contoh bagi orang-orang yang kemudian) sesudah mereka, di mana orang-orang yang sesudah mereka itu dapat mengambil contoh dari keadaan mereka, karena itu mereka tidak berani melakukan hal-hal serupa.\qt@no{56}}%
\qt@newcmd\qurantrans@id@mmmmccclxxxii{%
(Dan tatkala dijadikan) dibuat (putra Maryam sebagai perumpamaan) yaitu ketika Allah swt. menurunkan firman-Nya, ``Sesungguhnya kalian dan apa yang kalian sembah selain Allah adalah makanan neraka Jahanam.." (Q.S. Al Anbiya, 98). Seketika itu juga orang-orang musyrik mengatakan, ``Kami rela bila ternyata tuhan-tuhan sesembahan kami bersama dengan Isa, karena ia pun menjadi sesembahan selain Allah pula (tiba-tiba kaummu) yakni mereka yang musyrik (terhadap perumpamaan itu) terhadap misal tersebut (menertawakannya) karena gembira mendengar perumpamaan itu.\qt@no{57}}%
\qt@newcmd\qurantrans@id@mmmmccclxxxiii{%
(Dan mereka berkata, 'Manakah yang lebih baik tuhan-tuhan kami atau dia?') yakni nabi Isa, maka karenanya kami rela tuhan-tuhan kami bersama dia (Mereka tidak memberikan perumpamaan itu) atau misal tersebut (kepadamu melainkan dengan maksud membantah saja) atau menyanggah kamu dengan cara yang batil, karena mereka telah mengetahui, bahwa berhala-berhala yang tidak berakal itu tidak akan dapat menyamai Nabi Isa a.s. (sebenarnya mereka adalah kaum yang suka bertengkar") sangat gemar bertengkar.\qt@no{58}}%
\qt@newcmd\qurantrans@id@mmmmccclxxxiv{%
(Bukankah) tidak lain (dia) yakni Nabi Isa itu (hanyalah seorang hamba yang Kami berikan kepadanya nikmat) kenabian (dan Kami jadikan dia) yaitu kelahirannya dengan tanpa ayah (sebagai perumpamaan untuk Bani Israel) maksudnya, sebagai bukti yang menunjukkan akan kekuasaan Allah swt. yang mampu menciptakan apa yang dikehendaki-Nya.\qt@no{59}}%
\qt@newcmd\qurantrans@id@mmmmccclxxxv{%
(Dan kalau Kami kehendaki benar-benar Kami jadikan sebagai ganti kalian) untuk mengganti kalian (di muka bumi malaikat-malaikat yang turun temurun) misalnya, kalian Kami binasakan terlebih dahulu, lalu Kami jadikan malaikat sebagai ganti kalian.\qt@no{60}}%
\qt@newcmd\qurantrans@id@mmmmccclxxxvi{%
(Dan sesungguhnya dia) Nabi Isa itu (benar-benar merupakan pengetahuan tentang hari kiamat) artinya, dengan diturunkannya dia maka diketahuilah dekatnya hari kiamat. (Karena itu janganlah kalian ragu-ragu tentang kiamat itu) atau janganlah kalian meragukannya. Lafal Tamtarunna asalnya Tamtarunanna, kemudian dibuang daripadanya Nun alamat rafa' karena dijazmkan, dan dibuang pula daripadanya Wawu Dhamir jamak tetapi bukan karena Illat bertemunya dua huruf yang disukunkan, sehingga jadilah Tamtarunna. (Dan) katakanlah kepada mereka, ("Ikutilah aku) yakni ajaran tauhid ini. (Inilah) apa yang kuperintahkan kalian menjalankannya (jalan) atau tuntunan (yang lurus.)\qt@no{61}}%
\qt@newcmd\qurantrans@id@mmmmccclxxxvii{%
(Dan janganlah kalian sekali-kali dipalingkan) dapat dipalingkan dari agama Allah (oleh setan; sesungguhnya setan itu musuh yang nyata bagi kalian") nyata permusuhannya.\qt@no{62}}%
\qt@newcmd\qurantrans@id@mmmmccclxxxviii{%
(Dan tatkala Isa datang dengan membawa keterangan-keterangan) mukjizat-mukjizat dan syariat-syariat (dia berkata, ``Sesungguhnya aku datang kepada kalian dengan membawa hikmah) kenabian dan syariat Injil (dan untuk menjelaskan kepada kalian sebagian dari apa yang kalian berselisih tentangnya) yakni tentang hukum-hukum Taurat, yaitu menyangkut masalah agama dan masalah-masalah lainnya, Nabi Isa menjelaskan kepada mereka perkara agama yang sebenarnya (maka bertakwalah kepada Allah dan taatlah kepadaku.")\qt@no{63}}%
\qt@newcmd\qurantrans@id@mmmmccclxxxix{%
(Sesungguhnya Allah Dialah Rabbku dan Rabb kalian, maka sembahlah Dia, ini adalah jalan) tuntunan (yang lurus.)\qt@no{64}}%
\qt@newcmd\qurantrans@id@mmmmcccxc{%
(Maka berselisihlah golongan-golongan di antara mereka) tentang perkara Nabi Isa ini, apakah dia anak Allah atau Allah, atau tuhan yang ketiga (maka kecelakaan yang besarlah) lafal Al Wail menunjukkan kalimat azab (bagi orang-orang yang lalim) bagi orang-orang kafir, karena perkataan yang mereka ucapkan mengenai Nabi Isa (yaitu siksaan hari yang pedih) atau azab yang menyakitkan.\qt@no{65}}%
\qt@newcmd\qurantrans@id@mmmmcccxci{%
(Mereka tidak menunggu) orang-orang kafir Mekah tidak menunggu-nunggu (kecuali kedatangan hari kiamat kepada mereka) lafal An Ta-tiyahum menjadi Badal dari lafal As Sa'ah (dengan tiba-tiba) atau sekonyong-konyong (sedangkan mereka tidak menyadarinya) tidak menyadari kedatangannya sebelum itu.\qt@no{66}}%
\qt@newcmd\qurantrans@id@mmmmcccxcii{%
(Teman-teman akrab) dalam hal maksiat sewaktu di dunia (pada hari itu) pada hari kiamat itu lafal Yaumaidzin berta'alluq kepada firman selanjutnya (sebagian dari mereka menjadi musuh bagi sebagian yang lain kecuali orang-orang yang bertakwa) terkecuali orang-orang yang saling kasih mengasihi di dalam ketaatan kepada Allah swt., mereka itulah yang sebenarnya berteman, kemudian dikatakan kepada mereka yang bertakwa itu,\qt@no{67}}%
\qt@newcmd\qurantrans@id@mmmmcccxciii{%
("Hai hamba-hamba-Ku, tiada kekuatiran terhadap kalian pada hari ini dan tidak pula kalian bersedih hati.")\qt@no{68}}%
\qt@newcmd\qurantrans@id@mmmmcccxciv{%
(Yaitu orang-orang yang beriman) lafal ayat ini menjadi Na'at atau sifat bagi lafal 'Ibaadi' pada ayat di atas (kepada ayat-ayat Kami) yakni Alquran (dan adalah mereka dahulu orang-orang yang berserah diri.)\qt@no{69}}%
\qt@newcmd\qurantrans@id@mmmmcccxcv{%
(Masuklah kalian ke dalam surga, kalian) lafal Antum berkedudukan menjadi Mubtada (dan pasangan-pasangan kalian) yakni istri-istri kalian (digembirakan) dibahagiakan dan dimuliakan, lafal Tuhbaruuna menjadi Khabar dari Mubtada.\qt@no{70}}%
\qt@newcmd\qurantrans@id@mmmmcccxcvi{%
(Diedarkan kepada mereka piring-piring) yang besar-besar (dari emas, gelas-gelas) tempat untuk minum yang tidak ada pengikatnya hingga si peminum dapat meminum dari sebelah mana saja; lafal Akwaabun adalah bentuk jamak dari lafal Kuubun (dan di dalam surga itu terdapat segala apa yang diingini oleh hati) untuk dinikmati kelezatannya (dan sedap dipandang mata) artinya, sangat menyejukkan bila dipandang (dan kalian kekal di dalamnya.)\qt@no{71}}%
\qt@newcmd\qurantrans@id@mmmmcccxcvii{%
(Dan itulah surga yang diwariskan kepada kalian disebabkan amal-amal yang dahulu kalian kerjakan.)\qt@no{72}}%
\qt@newcmd\qurantrans@id@mmmmcccxcviii{%
(Di dalam surga itu ada buah-buahan yang banyak untuk kalian yang sebagiannya) sebagian daripadanya (kalian makan) dan setiap apa yang telah dimakan secara langsung mendapat penggantinya yang baru.\qt@no{73}}%
\qt@newcmd\qurantrans@id@mmmmcccxcix{%
(Sesungguhnya orang-orang yang berdosa kekal di dalam azab neraka Jahanam.)\qt@no{74}}%
\qt@newcmd\qurantrans@id@mmmmcd{%
(Tidak dihenti-hentikan) maksudnya, tidak diringankan (azab itu dari mereka sedangkan mereka di dalamnya berputus asa) yakni dalam keadaan diam berputus asa.\qt@no{75}}%
\qt@newcmd\qurantrans@id@mmmmcdi{%
(Dan tidaklah Kami menganiaya mereka tetapi merekalah yang menganiaya diri mereka sendiri.)\qt@no{76}}%
\qt@newcmd\qurantrans@id@mmmmcdii{%
(Mereka berseru, ``Hai Malik!) dia adalah malaikat penjaga neraka (Biarlah Rabbmu membunuh kami saja") maksudnya, mematikan kami. (Dia menjawab) seruan mereka setelah seribu tahun kemudian, ("Kalian akan tetap tinggal") di dalam azab yang abadi untuk selama-lamanya.\qt@no{77}}%
\qt@newcmd\qurantrans@id@mmmmcdiii{%
Allah swt. berfirman: (Sesungguhnya Kami benar-benar telah membawa kepada kalian) hai penduduk Mekah (kebenaran) melalui lisan rasul (tetapi kebanyakan di antara kalian benci pada kebenaran itu.)\qt@no{78}}%
\qt@newcmd\qurantrans@id@mmmmcdiv{%
(Bahkan mereka telah menetapkan) yaitu orang-orang kafir Mekah telah memutuskan (suatu tipu daya) kejahatan untuk mencelakakan Nabi Muhammad (maka sesungguhnya Kami menetapkan pula) keputusan Kami untuk membuat tipu muslihat guna membinasakan mereka.\qt@no{79}}%
\qt@newcmd\qurantrans@id@mmmmcdv{%
(Apakah mereka mengira, bahwa Kami tidak mendengar rahasia dan bisikan-bisikan mereka) yakni apa-apa yang mereka rahasiakan dari orang lain dan apa-apa yang mereka perlihatkan dengan terang-terangan di antara sesama mereka sendiri. (Sebenarnya) Kami mendengar hal tersebut (dan utusan-utusan Kami) yakni malaikat-malaikat pencatat amal perbuatan (di sisi mereka) di sisi orang-orang kafir (selalu mencatat) hal tersebut.\qt@no{80}}%
\qt@newcmd\qurantrans@id@mmmmcdvi{%
(Katakanlah! Jika benar Tuhan Yang Maha Pemurah mempunyai anak) seumpamanya (maka akulah orang yang mula-mula menyembahnya) menyembah anak Tuhan itu, akan tetapi telah ditetapkan, bahwa tiada anak bagi-Nya, sehingga tiada pula penyembahan itu.\qt@no{81}}%
\qt@newcmd\qurantrans@id@mmmmcdvii{%
(Maha Suci Rabb Yang empunya langit dan bumi, Rabb Yang empunya Arasy) yakni Al-Kursi (dari apa yang mereka sifatkan) dari apa yang telah mereka katakan itu, berupa kedustaan terhadap-Nya, yaitu menisbatkan kepada-Nya mempunyai anak.\qt@no{82}}%
\qt@newcmd\qurantrans@id@mmmmcdviii{%
(Maka biarlah mereka tenggelam) dalam kesesatannya atau dalam kebatilannya (dan bermain-main) di dalam dunia mereka (sampai mereka menemui hari yang dijanjikan kepada mereka) yaitu azab yang dijanjikan kepada mereka pada hari kiamat nanti.\qt@no{83}}%
\qt@newcmd\qurantrans@id@mmmmcdix{%
(Dan Dialah Tuhan yang disembah di langit) lafal Fis Samaa-i Ilaahun kedua huruf Hamzahnya dapat dibaca Tahqiq dan Tas-hil, yakni Tuhan yang disembah di langit (dan Tuhan yang disembah di bumi) kedua Zharaf yang ada dalam ayat ini berta'alluq kepada lafal sesudahnya (dan Dialah Yang Maha Bijaksana) di dalam mengatur makhluk-Nya (lagi Maha Mengetahui) kemaslahatan-kemaslahatan mereka.\qt@no{84}}%
\qt@newcmd\qurantrans@id@mmmmcdx{%
(Dan Maha Besar) Maha Agung (Tuhan Yang mempunyai kerajaan langit dan bumi; dan apa yang ada di antara keduanya; dan di sisi-Nyalah pengetahuan tentang hari kiamat) yakni kapan ia akan terjadi (dan hanya kepada-Nyalah kalian dikembalikan) lafal Turja'uuna dapat pula dibaca Yurja`uuna; berdasarkan qiraat kedua maka artinya: Dan hanya kepada-Nyalah mereka dikembalikan.\qt@no{85}}%
\qt@newcmd\qurantrans@id@mmmmcdxi{%
(Dan tidaklah memiliki apa-apa yang mereka seru) yang mereka sembah, dimaksud adalah orang-orang kafir pelakunya (selain Dia) selain Allah (suatu syafaat pun) bagi seseorang (tetapi yang dapat memberi syafaat ialah orang yang mengakui yang hak) yakni orang yang telah mengatakan, ``Laa Ilaaha Illallaah"/tiada Tuhan selain Allah (dan mereka mengetahui) apa yang mereka akui dengan kalbunya, yaitu yang telah diucapkan oleh lisannya. Yang dimaksud antara lain ialah Nabi Isa, Nabi Uzair dan malaikat-malaikat, sesungguhnya mereka dapat memberi syafaat kepada orang-orang yang beriman.\qt@no{86}}%
\qt@newcmd\qurantrans@id@mmmmcdxii{%
(Dan sungguh jika) huruf Lam di sini bermakna Qasam (kamu bertanya kepada mereka, ``Siapakah yang menciptakan mereka?" Niscaya mereka menjawab, ``Allah") lafal Layaquulunna dibuang daripadanya Nun alamat Rafa' dan Wawu Dhamir jamak, karena asalnya adalah Layaquuluunanna (maka bagaimanakah mereka dapat dipalingkan) sehingga mereka tidak mau menyembah Allah?\qt@no{87}}%
\qt@newcmd\qurantrans@id@mmmmcdxiii{%
(Dan ucapannya) ucapan Nabi Muhammad; dinashabkannya lafal Qiilihi karena menjadi Mashdar yang dinashabkan oleh Fi'ilnya yang Muqaddar atau diperkirakan keberadaannya; yakni, dan berkatalah dia, ("Ya Rabbku! Sesungguhnya mereka itu adalah kaum yang tidak beriman.")\qt@no{88}}%
\qt@newcmd\qurantrans@id@mmmmcdxiv{%
Lalu Allah swt. berfirman: (Maka berpalinglah) artinya palingkanlah dirimu (dari mereka dan katakanlah, ``Salam") selamat tinggal bagi kalian. Ayat ini diturunkan sebelum diperintah untuk memerangi mereka (Kelak mereka akan mengetahui) ayat ini mengandung ancaman buat mereka; dan dapat dibaca Ya'lamuuna atau Ta'lamuuna, kalau dibaca Ta'lamuuna artinya, kelak kalian akan mengetahui.\qt@no{89}}%
\qt@newcmd\qurantrans@id@mmmmcdxv{%
\basmalahid (Ha Mim) hanya Allah sajalah yang mengetahui arti dan maksudnya.\qt@no{1}}%
\qt@newcmd\qurantrans@id@mmmmcdxvi{%
(Demi Alkitab) yaitu Alquran (yang menjelaskan) yang memenangkan perkara yang halal atas perkara yang haram.\qt@no{2}}%
\qt@newcmd\qurantrans@id@mmmmcdxvii{%
(Sesungguhnya Kami menurunkannya pada suatu malam yang diberkati) yaitu Lailatulkadar, atau malam pertengahan bulan Syakban. Pada malam tersebut diturunkanlah Alquran dari Umul Kitab atau Lohmahfuz yaitu dari langit yang ketujuh hingga ke langit dunia (sesungguhnya Kamilah yang memberi peringatan) yang memperingatkan manusia dengan Alquran.\qt@no{3}}%
\qt@newcmd\qurantrans@id@mmmmcdxviii{%
(Pada malam itu) yakni pada malam Lailatulkadar, atau malam pertengahan bulan Syakban (dijelaskan) dirincikan (segala urusan yang penuh hikmah) segala urusan yang telah ditentukan, yaitu berupa rezeki dan ajal serta perkara-perkara lainnya, mulai dari malam itu sampai dengan malam yang sama untuk tahun berikutnya.\qt@no{4}}%
\qt@newcmd\qurantrans@id@mmmmcdxix{%
(Yaitu urusan yang besar) rinciannya (dari sisi Kami. Sesungguhnya Kami adalah yang mengutus rasul-rasul) Nabi Muhammad dan rasul-rasul sebelumnya.\qt@no{5}}%
\qt@newcmd\qurantrans@id@mmmmcdxx{%
(Sebagai rahmat) maksudnya, karena belas kasihan kepada manusia diutuslah rasul-rasul kepada mereka (dari Rabbmu. Sesungguhnya Dialah Yang Maha Mendengar) perkataan-perkataan mereka (lagi Maha Mengetahui) perbuatan-perbuatan mereka.\qt@no{6}}%
\qt@newcmd\qurantrans@id@mmmmcdxxi{%
(Rabb yang memelihara langit dan bumi dan apa yang ada di antara keduanya) jika dibaca Rabbus Samaawaati berarti menjadi Khabar yang ketiga, jika dibaca Rabbis Samaawaati berarti menjadi Badal dari lafal Rabbika (jika kalian) hai penduduk Mekah (orang-orang yang meyakini) bahwasanya Dia adalah Rabb langit dan bumi, maka yakinilah bahwa Muhammad itu adalah rasul-Nya.\qt@no{7}}%
\qt@newcmd\qurantrans@id@mmmmcdxxii{%
(Tidak ada tuhan melainkan Dia, Yang menghidupkan dan Yang mematikan Dialah Rabb kalian dan Rabb bapak-bapak kalian yang terdahulu).\qt@no{8}}%
\qt@newcmd\qurantrans@id@mmmmcdxxiii{%
(Tetapi mereka dalam keragu-raguan) tentang adanya hari berbangkit (adalah orang-orang yang bermain-main) dengan maksud mengejek kamu, hai Muhammad. Maka Nabi berdoa, ``Ya Allah! Bantulah aku untuk menghadapi mereka, timpakanlah kepada mereka paceklik selama tujuh tahun sebagaimana paceklik yang diminta oleh Nabi Yusuf."\qt@no{9}}%
\qt@newcmd\qurantrans@id@mmmmcdxxiv{%
(Maka tunggulah hari ketika langit membawa kabut yang nyata) maka kala itu bumi menjadi tandus kelaparan serta paceklik makin menjadi-jadi, sehingga karena memuncaknya keadaan, akhirnya mereka melihat seolah-olah ada sesuatu yang berupa kabut di antara langit dan bumi.\qt@no{10}}%
\qt@newcmd\qurantrans@id@mmmmcdxxv{%
(Yang meliputi manusia) lalu mereka berkata, ("Inilah azab yang pedih.)\qt@no{11}}%
\qt@newcmd\qurantrans@id@mmmmcdxxvi{%
('Ya Rabb kami! Lenyapkanlah dari kami azab ini, Sesungguhnya kami akan beriman") atau percaya kepada nabi-Mu.\qt@no{12}}%
\qt@newcmd\qurantrans@id@mmmmcdxxvii{%
("Bagaimana mereka dapat menerima peringatan) maksudnya, iman tidak akan bermanfaat buat mereka bila azab diturunkan (padahal telah datang kepada mereka seorang rasul yang memberi penjelasan) artinya yang jelas risalahnya.\qt@no{13}}%
\qt@newcmd\qurantrans@id@mmmmcdxxviii{%
(Kemudian mereka berpaling darinya dan berkata, ``Dia adalah seorang yang menerima ajaran) maksudnya dia diajari Alquran oleh orang lain (lagi pula dia seorang yang gila.")\qt@no{14}}%
\qt@newcmd\qurantrans@id@mmmmcdxxix{%
(Sesungguhnya kalau Kami lenyapkan siksaan itu) kelaparan dan paceklik itu dari mereka selama beberapa waktu (dalam waktu yang tidak lama) lalu Allah melenyapkan azab itu dari mereka (sesungguhnya kalian akan kembali) kepada kekafiran, dan memang mereka kembali lagi kepada kekafirannya.\qt@no{15}}%
\qt@newcmd\qurantrans@id@mmmmcdxxx{%
Ingatlah (hari ketika Kami menghantam dengan hantaman yang keras) yaitu pada perang Badar. (Sesungguhnya Kami Pemberi balasan) kepada orang-orang yang kafir itu. Lafal Al-Bathsyu artinya menghantam dengan keras.\qt@no{16}}%
\qt@newcmd\qurantrans@id@mmmmcdxxxi{%
(Sesungguhnya telah Kami coba) Kami uji (sebelum mereka kaum Firaun) berikut Firaun sendiri (dan telah datang kepada mereka seorang rasul) yaitu Nabi Musa.s. (yang mulia) di sisi Allah swt.\qt@no{17}}%
\qt@newcmd\qurantrans@id@mmmmcdxxxii{%
(Dengan berkata, ``Hendaknya) atau hendaknyalah (kalian tunaikan kepadaku) apa yang aku seru kalian untuk melakukannya, yaitu beriman kepada Allah. Maksudnya, tampakkanlah iman kalian kepadaku, hai (hamba-hamba Allah. Sesungguhnya aku adalah utusan Allah yang dipercaya kepada kalian) dipercaya untuk menyampaikan apa yang aku diutus untuknya.\qt@no{18}}%
\qt@newcmd\qurantrans@id@mmmmcdxxxiii{%
(Dan Janganlah kalian menyombongkan diri) berlaku takabur (terhadap Allah) yaitu tidak menaati-Nya. (Sesungguhnya aku datang kepada kalian dengan membawa bukti) tanda bukti (yang nyata") yang menunjukkan kebenaran risalahku. Tetapi sebaliknya mereka mengancam akan merajamnya.\qt@no{19}}%
\qt@newcmd\qurantrans@id@mmmmcdxxxiv{%
Maka berdoalah Nabi Musa, ("Dan sesungguhnya aku berlindung kepada Rabbku dan Rabb kalian, dari keinginan kalian merajamku) dengan batu.\qt@no{20}}%
\qt@newcmd\qurantrans@id@mmmmcdxxxv{%
(Dan jika kalian tidak beriman kepadaku) tidak percaya kepadaku (maka biarkanlah aku") artinya, janganlah kalian menyakitiku, akan tetapi mereka tidak mau membiarkannya.\qt@no{21}}%
\qt@newcmd\qurantrans@id@mmmmcdxxxvi{%
(Kemudian Musa berdoa kepada Rabbnya, ``Bahwasanya) (mereka ini adalah kaum yang berdosa") orang-orang yang musyrik.\qt@no{22}}%
\qt@newcmd\qurantrans@id@mmmmcdxxxvii{%
Maka Allah swt. berfirman, ("Maka berjalanlah kamu) lafaz ini dapat dibaca Fa-asri atau Fasri (dengan membawa hamba-hamba-Ku) yaitu Bani Israel (pada malam hari, sesungguhnya kalian akan dikejar) oleh Firaun dan kaumnya.\qt@no{23}}%
\qt@newcmd\qurantrans@id@mmmmcdxxxviii{%
(Dan biarkanlah laut itu) apabila kamu dan pengikut-pengikutmu telah menempuhnya (terbelah) tenang dalam keadaan terbelah hingga orang-orang Koptik atau kaum Firaun memasukinya (sesungguhnya mereka adalah tentara yang akan ditenggelamkan") maka tenanglah kamu jangan khawatir. Akhirnya mereka ditenggelamkan.\qt@no{24}}%
\qt@newcmd\qurantrans@id@mmmmcdxxxix{%
(Alangkah banyaknya taman yang mereka tinggalkan) yaitu kebun-kebun (dan mata air) yang mengalir.\qt@no{25}}%
\qt@newcmd\qurantrans@id@mmmmcdxl{%
(Dan kebun-kebun serta tempat-tempat yang indah-indah) atau tempat yang bagus.\qt@no{26}}%
\qt@newcmd\qurantrans@id@mmmmcdxli{%
(Dan nikmat) kesenangan (yang dahulu mereka bergelimang di dalamnya) bersenang-senang di dalamnya.\qt@no{27}}%
\qt@newcmd\qurantrans@id@mmmmcdxlii{%
(Demikianlah) lafal Kadzaalika ini menjadi Khabar dari Mubtada; maksudnya, perkaranya demikianlah. (Dan Kami wariskan semua itu) yakni harta benda mereka (kepada kaum yang lain) yakni, kaum Bani Israel.\qt@no{28}}%
\qt@newcmd\qurantrans@id@mmmmcdxliii{%
(Maka langit dan bumi tidak menangisi mereka) berbeda dengan orang-orang yang beriman, jika mereka mati tanah tempat salat mereka menangisinya dan langit tempat naiknya amal mereka menangisinya pula (dan mereka pun tidak diberi tangguh) diakhirkan tobatnya.\qt@no{29}}%
\qt@newcmd\qurantrans@id@mmmmcdxliv{%
(Dan sesungguhnya telah Kami selamatkan Bani Israel dari siksa yang menghinakan) yakni dari pembunuhan Firaun terhadap anak-anak laki-laki mereka dan perbudakannya terhadap anak-anak perempuan mereka.\qt@no{30}}%
\qt@newcmd\qurantrans@id@mmmmcdxlv{%
(Dari siksaan Firaun) menurut suatu pendapat menjadi Badal dari lafal Al'Adzaabi yang ada pada ayat sebelumnya dengan memperkirakan adanya Mudhaf sebelumnya, yaitu lafal 'Adzaabi, lengkapnya Min 'Adzaabi Firaun, artinya: dari siksaan Firaun. Tetapi menurut pendapat lain ia menjadi Hal atau kata keterangan keadaan dari lafal Al 'Adzaabi (sesungguhnya dia adalah orang yang sombong lagi salah seorang dari orang-orang yang melampaui batas.)\qt@no{31}}%
\qt@newcmd\qurantrans@id@mmmmcdxlvi{%
(Dan sesungguhnya telah Kami pilih mereka) yaitu kaum Bani Israel (dengan pengetahuan) Kami yang mengetahui semua keadaan mereka (atas orang-orang yang pandai) di zamannya, yakni mereka dipilih menjadi orang-orang yang lebih pandai daripada orang-orang yang pandai di zamannya.\qt@no{32}}%
\qt@newcmd\qurantrans@id@mmmmcdxlvii{%
(Dan sesungguhnya Kami telah memberikan kepada mereka di antara tanda-tanda kekuasaan Kami sesuatu yang di dalamnya terdapat cobaan yang nyata) yang dimaksud adalah nikmat yang nyata, yaitu dapat dibelahnya laut, diturunkannya manna dan salwa serta mukjizat-mukjizat lainnya.\qt@no{33}}%
\qt@newcmd\qurantrans@id@mmmmcdxlviii{%
(Sesungguhnya mereka itu) yakni orang-orang kafir Mekah (benar-benar berkata,)\qt@no{34}}%
\qt@newcmd\qurantrans@id@mmmmcdxlix{%
("Tidak ada kematian) yang sesudahnya ada kehidupan lagi (selain kematian di dunia ini) sewaktu mereka masih dalam keadaan berupa air mani. (Dan kami sekali-kali tidak akan dibangkitkan) tidak akan dihidupkan kembali sesudah kematian yang pertama tadi.\qt@no{35}}%
\qt@newcmd\qurantrans@id@mmmmcdl{%
(Maka datangkanlah bapak-bapak kami) dalam keadaan hidup (jika kalian memang orang-orang yang benar") bahwasanya kami akan dibangkitkan menjadi hidup kembali sesudah kami mati.\qt@no{36}}%
\qt@newcmd\qurantrans@id@mmmmcdli{%
Allah swt. berfirman, ("Apakah mereka yang lebih baik ataukah kaum Tubba'") Tubba' adalah seorang nabi atau seorang yang saleh (dan orang-orang yang sebelum mereka) umat-umat sebelum mereka (Kami telah membinasakan mereka) karena kekafiran mereka. Makna ayat, bahwasanya orang-orang musyrik itu tidaklah lebih kuat daripada mereka, dan ternyata mereka pun telah dibinasakan (karena sesungguhnya mereka adalah orang-orang yang berdosa.)\qt@no{37}}%
\qt@newcmd\qurantrans@id@mmmmcdlii{%
(Dan Kami tidak menciptakan langit dan bumi dan apa yang ada di antara keduanya dengan bermain-main) dalam menciptakan hal tersebut; lafal Laa`ibiina menjadi Hal atau kata keterangan keadaan.\qt@no{38}}%
\qt@newcmd\qurantrans@id@mmmmcdliii{%
(Kami tidak menciptakan keduanya) dan apa yang ada di antara keduanya (melainkan dengan hak) dengan sebenarnya, daripadanya dapat disimpulkan tentang kekuasaan dan keesaan Kami, dan hal-hal lainnya (tetapi kebanyakan mereka) yaitu orang-orang kafir Mekah (tidak mengetahui.)\qt@no{39}}%
\qt@newcmd\qurantrans@id@mmmmcdliv{%
(Sesungguhnya hari keputusan itu) yakni hari kiamat adalah hari di mana Allah memutuskan perkara di antara hamba-hamba-Nya (adalah waktu yang dijanjikan bagi mereka semuanya) untuk menerima azab yang abadi.\qt@no{40}}%
\qt@newcmd\qurantrans@id@mmmmcdlv{%
(Yaitu hari yang seorang karib tidak dapat memberi manfaat kepada karibnya) baik karib karena hubungan kerabat atau karib karena hubungan persahabatan yang dekat. Ia tidak akan dapat membelanya (sedikit pun) dari azab itu (dan mereka tidak akan mendapat pertolongan) maksudnya tidak dapat dicegah dari azab itu. Lafal Yauma dalam ayat ini menjadi Badal dari lafal Yaumal Fashli pada ayat sebelumnya.\qt@no{41}}%
\qt@newcmd\qurantrans@id@mmmmcdlvi{%
(Kecuali orang yang diberi rahmat oleh Allah) mereka adalah orang-orang mukmin, sebagian dari mereka dapat memberikan syafaat kepada sebagian lainnya dengan seizin Allah. (Sesungguhnya Dialah Yang Maha Perkasa) Maha Menang di dalam pembalasan-Nya terhadap orang-orang kafir (lagi Maha Penyayang) terhadap orang-orang mukmin.\qt@no{42}}%
\qt@newcmd\qurantrans@id@mmmmcdlvii{%
(Sesungguhnya pohon zaqqum itu) zaqqum adalah pohon yang paling buruk dan sangat pahit rasanya yang tumbuh di daerah Tihamah, kelak Allah akan menumbuhkannya pula di dasar neraka Jahim.\qt@no{43}}%
\qt@newcmd\qurantrans@id@mmmmcdlviii{%
(Makanan orang yang banyak dosa) seperti Abu Jahal dan teman-temannya.\qt@no{44}}%
\qt@newcmd\qurantrans@id@mmmmcdlix{%
(Ia bagaikan kotoran minyak) yakni hitam pekat bagaikan kotoran minyak; lafal ayat ini menjadi Khabar kedua (yang mendidih di dalam perut) jika dibaca Taghli berarti menjadi Khabar ketiga, jika dibaca Yaghli berarti menjadi Hal atau kata keterangan keadaan bagi lafal Al-Muhli.\qt@no{45}}%
\qt@newcmd\qurantrans@id@mmmmcdlx{%
(Seperti mendidihnya air yang amat panas) panasnya bagaikan air yang sangat panas.\qt@no{46}}%
\qt@newcmd\qurantrans@id@mmmmcdlxi{%
(Peganglah dia) dikatakan kepada malaikat Zabaniyah, ``Peganglah orang yang berdosa (kemudian seretlah dia) dapat dibaca Fa'tiluuhu atau Fa'tuluuhu artinya, seretlah dia dengan keras dan kasar (ke tengah-tengah jahim) ke tengah-tengah neraka.\qt@no{47}}%
\qt@newcmd\qurantrans@id@mmmmcdlxii{%
(Kemudian tuangkanlah di atas kepalanya siksaan dari air yang amat panas) sehingga azab tiada henti-hentinya menimpa mereka dan tidak pernah berpisah darinya. Pengertian ayat ini lebih keras daripada apa yang diungkapkan dalam ayat lain, yaitu, ``Disiramkan air yang sedang mendidih ke atas kepala mereka..." (Q.S. Al-Hajj, 19).\qt@no{48}}%
\qt@newcmd\qurantrans@id@mmmmcdlxiii{%
Kemudian dikatakan kepadanya, ``(Rasakanlah) azab ini (sesungguhnya kamu orang yang perkasa lagi mulia") menurut dugaan dan perkataanmu yang telah menyatakan, bahwa tiada seorang pun di antara penghuni kedua bukit itu, yakni kota Mekah, orang yang lebih perkasa dan lebih mulia daripada dirinya.\qt@no{49}}%
\qt@newcmd\qurantrans@id@mmmmcdlxiv{%
Dan dikatakan kepada mereka, ``(Sesungguhnya ini) azab yang kalian rasakan ini (yang dahulu selalu kalian meragukannya") yaitu meragukan keberadaannya.\qt@no{50}}%
\qt@newcmd\qurantrans@id@mmmmcdlxv{%
(Sesungguhnya orang-orang yang bertakwa berada di dalam tempat) atau kedudukan (yang aman) dari semua hal-hal yang menakutkan.\qt@no{51}}%
\qt@newcmd\qurantrans@id@mmmmcdlxvi{%
(Yaitu di dalam taman-taman) kebun-kebun (dan mata air-mata air.)\qt@no{52}}%
\qt@newcmd\qurantrans@id@mmmmcdlxvii{%
(Mereka memakai sutera yang halus dan sutera yang tebal) (seraya berhadap-hadapan) lafal Mutaqaabiliina adalah Hal atau kata keterangan keadaan, yakni, sebagian dari mereka tidak dapat melihat tengkuk sebagian yang lain, karena dipan-dipan tempat mereka duduk berbentuk bundar.\qt@no{53}}%
\qt@newcmd\qurantrans@id@mmmmcdlxviii{%
(Demikianlah) sebelum lafal ini diperkirakan adanya lafal Al-Amru, yakni perkaranya demikianlah. (Dan Kami kawinkan mereka) dijodohkan atau mereka dibuat senang (dengan bidadari-bidadari) dengan wanita yang putih kulitnya dan jeli matanya serta sangat cantik rupanya.\qt@no{54}}%
\qt@newcmd\qurantrans@id@mmmmcdlxix{%
(Mereka meminta) meminta kepada para pelayan surga (di dalamnya) di dalam surga, supaya para pelayan itu mendatangkan buat mereka (segala macam buah-buahan) surga (dengan aman) dari kehabisan dan dari kemudaratannya, serta aman dari segala kekhawatiran. Lafal Aaminiina berkedudukan menjadi Hal atau kata keterangan keadaan.\qt@no{55}}%
\qt@newcmd\qurantrans@id@mmmmcdlxx{%
(Mereka tidak akan merasakan mati di dalamnya kecuali mati yang pertama) yaitu kematian sewaktu di dunia. Sebagian ahli tafsir ada yang mengatakan bahwa lafal Illaa di sini bermakna Ba'da, yakni sesudah. (Dan Allah memelihara mereka dari azab neraka.)\qt@no{56}}%
\qt@newcmd\qurantrans@id@mmmmcdlxxi{%
(Sebagai karunia) lafal Fadhlan adalah Mashdar yang bermakna Tafadhdhulan, yakni pemberian karunia; dinashabkan oleh lafal Tafadhdhala yang diperkirakan keberadaannya sebelumnya (dari Rabbmu Yang demikian itu adalah keberuntungan yang besar.)\qt@no{57}}%
\qt@newcmd\qurantrans@id@mmmmcdlxxii{%
(Sesungguhnya Kami mudahkan ia) Kami mudahkan Alquran itu (dengan bahasamu) dengan bahasa Arab supaya orang-orang Arab dapat memahaminya darimu (supaya mereka mendapat pelajaran) supaya mereka dapat mengambilnya sebagai nasihat, karena itu lalu mereka beriman kepadamu; tetapi ternyata mereka tidak juga mau beriman.\qt@no{58}}%
\qt@newcmd\qurantrans@id@mmmmcdlxxiii{%
(Maka tunggulah) nantikanlah kebinasaan mereka (sesungguhnya mereka itu menunggu pula) kebinasaanmu. Ayat ini diturunkan sebelum ada perintah untuk berjihad melawan mereka.\qt@no{59}}%
\qt@newcmd\qurantrans@id@mmmmcdlxxiv{%
\basmalahid (Ha Mim) hanya Allah sajalah yang mengetahui arti dan maksudnya.\qt@no{1}}%
\qt@newcmd\qurantrans@id@mmmmcdlxxv{%
(Diturunkannya Kitab ini) yakni Alquran; lafal ayat ini berkedudukan menjadi Mubtada (dari Allah) menjadi Khabar dari Mubtada (Yang Maha Perkasa) di dalam kerajaan-Nya (lagi Maha Bijaksana) di dalam perbuatan-Nya.\qt@no{2}}%
\qt@newcmd\qurantrans@id@mmmmcdlxxvi{%
(Sesungguhnya pada langit dan bumi) pada penciptaan keduanya (benar-benar terdapat tanda-tanda) yang menunjukkan kepada kekuasaan dan keesaan Allah swt. (bagi orang-orang yang beriman.)\qt@no{3}}%
\qt@newcmd\qurantrans@id@mmmmcdlxxvii{%
(Dan pada penciptaan kalian) penciptaan masing-masing di antara kalian, yaitu mulai dari air mani, lalu berupa darah kental, kemudian segumpal daging, lalu menjadi manusia (dan) penciptaan (apa yang bertebaran) di muka bumi (berupa makhluk-makhluk yang melata) arti kata Ad-Daabbah adalah makhluk hidup yang melata di permukaan bumi, yaitu berupa manusia dan lain-lainnya (terdapat tanda-tanda kekuasaan Allah dan keesaan-Nya bagi kaum yang meyakini) adanya hari berbangkit.\qt@no{4}}%
\qt@newcmd\qurantrans@id@mmmmcdlxxviii{%
(Dan) pada (pergantian malam dan siang) yaitu datang dan perginya kedua waktu itu (dan rezeki yang diturunkan Allah dari langit) berupa hujan, dikatakan rezeki karena hujan itu merupakan penyebab rezeki (lalu dihidupkan-Nya dengan air hujan itu bumi sesudah matinya, dan pada pertukaran angin) atau pergantiannya, terkadang bertiup ke arah selatan, terkadang bertiup ke arah utara, terkadang datang membawa udara dingin, dan terkadang datang membawa udara panas (terdapat tanda-tanda pula bagi kaum yang berakal) yaitu tanda-tanda yang menunjukkan kekuasaan dan keesaan Allah, karenanya mereka beriman.\qt@no{5}}%
\qt@newcmd\qurantrans@id@mmmmcdlxxix{%
(Itulah) yakni tanda-tanda yang telah disebutkan itu (ayat-ayat Allah) maksudnya, hujah-hujah-Nya yang menunjukkan kepada keesaan-Nya (yang Kami membacakannya) yang Kami ceritakan (kepadamu dengan sebenarnya) lafal Bil haqqi ber-ta'aluq kepada lafal Natluuhaa (maka dengan perkataan mana lagi sesudah Allah) sesudah firman-Nya, yang dimaksud adalah Alquran (dan keterangan-keterangan-Nya) atau hujah-hujah-Nya (mereka beriman) orang-orang kafir Mekah itu mereka tidak beriman. Menurut suatu qiraat lafal Yu'minuuna dibaca Tu'minuuna.\qt@no{6}}%
\qt@newcmd\qurantrans@id@mmmmcdlxxx{%
(Kecelakaan yang besarlah) lafal Al-Wail menunjukkan kalimat azab (bagi tiap-tiap orang yang banyak berdusta) atau pendusta (lagi banyak berdosa) banyak dosanya.\qt@no{7}}%
\qt@newcmd\qurantrans@id@mmmmcdlxxxi{%
(Dia mendengar ayat-ayat Allah) yakni Alquran (dibacakan kepadanya kemudian dia tetap) atas kekafirannya (menyombongkan diri) takabur tidak mau beriman (seakan-akan dia tidak mendengarnya. Maka beri kabar gembiralah dia dengan azab yang pedih) azab yang menyakitkan.\qt@no{8}}%
\qt@newcmd\qurantrans@id@mmmmcdlxxxii{%
(Dan apabila dia mengetahui tentang ayat-ayat Kami) yakni Alquran (barang sedikit, maka ayat-ayat itu dijadikannya olok-olok) yakni menjadi bahan ejekan mereka. (Merekalah) orang-orang yang banyak mendustakan ayat-ayat Kami itu (yang memperoleh azab yang menghinakan) artinya, siksaan yang mengandung kehinaan.\qt@no{9}}%
\qt@newcmd\qurantrans@id@mmmmcdlxxxiii{%
(Di hadapan mereka) di sini diartikan di hadapan mereka sekalipun lafalnya mengatakan Min Waraa-ihim yakni di belakang mereka, hal ini mengingat mereka masih hidup di dunia (neraka Jahanam dan tidak akan berguna bagi mereka apa yang telah mereka upayakan) berupa harta benda dan hasil-hasil kerja mereka (barang sedikit pun, dan tidak pula berguna apa yang mereka jadikan selain dari Allah) yang dimaksud adalah berhala-berhala (sebagai sesembahan-sesembahan. Dan bagi mereka azab yang besar.)\qt@no{10}}%
\qt@newcmd\qurantrans@id@mmmmcdlxxxiv{%
(Ini) Alquran ini (adalah petunjuk) dari kesesatan. (Dan orang-orang yang kafir kepada ayat-ayat Rabbnya bagi mereka azab) yakni bagian (yaitu siksa) atau azab (yang sangat pedih) sangat menyakitkan.\qt@no{11}}%
\qt@newcmd\qurantrans@id@mmmmcdlxxxv{%
(Allahlah yang menundukkan lautan untuk kalian supaya bahtera-bahtera dapat berlayar) yaitu perahu-perahu (padanya dengan perintah-Nya) dengan seizin-Nya (dan supaya kalian dapat mencari) melalui berdagang (sebagian karunia-Nya dan mudah-mudahan kalian bersyukur.)\qt@no{12}}%
\qt@newcmd\qurantrans@id@mmmmcdlxxxvi{%
(Dan Dia menundukkan untuk kalian apa yang ada di langit) berupa matahari bulan bintang-bintang, air hujan dan lain-lainnya (dan apa yang ada di bumi) berupa binatang-binatang, pohon-pohonan, tumbuh-tumbuhan, sungai-sungai dan lain-lainnya. Maksudnya, Dia menciptakan kesemuanya itu untuk dimanfaatkan oleh kalian (semuanya) lafal Jamii'an ini berkedudukan menjadi Taukid, atau mengukuhkan makna lafal sebelumnya (dari-Nya) lafal Minhu ini menjadi Hal atau kata keterangan keadaan, maksudnya semuanya itu ditundukkan oleh-Nya. (Sesungguhnya pada yang demikian itu benar-benar terdapat tanda-tanda kekuasaan dan keesaan Allah bagi kaum yang berpikir) mengenainya, karena itu lalu mereka beriman.\qt@no{13}}%
\qt@newcmd\qurantrans@id@mmmmcdlxxxvii{%
(Katakanlah kepada orang-orang yang beriman hendaklah mereka memaafkan orang-orang yang tiada mengharapkan) mereka yang tidak takut (akan hari-hari Allah) yaitu hari-hari di waktu Allah menimpakan azab kepada mereka. Maksudnya, maafkanlah orang-orang kafir atas perlakuan mereka terhadap diri kalian yang menyakitkan itu. Ayat ini diturunkan sebelum ada perintah untuk berjihad melawan mereka (karena Dia akan membalas) Allah akan membalas; menurut suatu qiraat dibaca Linajziya, artinya: karena Kami akan membalas (sesuatu kaum terhadap apa yang telah mereka kerjakan) atas pemaafannya terhadap orang-orang kafir yang telah menyakiti mereka.\qt@no{14}}%
\qt@newcmd\qurantrans@id@mmmmcdlxxxviii{%
(Barang siapa yang mengerjakan amal yang saleh maka itu adalah untuk dirinya sendiri) (dan barang siapa mengerjakan kejahatan, maka itu akan menimpa dirinya sendiri) (kemudian kepada Rabb kalianlah kalian dikembalikan) kalian akan dikembalikan kemudian orang yang berbuat baik dan orang yang berbuat jahat akan menerima balasannya masing-masing.\qt@no{15}}%
\qt@newcmd\qurantrans@id@mmmmcdlxxxix{%
(Dan sesungguhnya telah Kami berikan kepada Bani Israel Alkitab) yakni Taurat (dan hukum) yakni kitab Taurat sebagai sumber hukum untuk memutuskan perkara di antara orang-orang Bani Israel (dan kenabian) kepada Musa dan Harun, di antara mereka (dan Kami berikan kepada mereka rezeki-rezeki yang baik) atau rezeki-rezeki yang halal, yaitu manna dan salwa (dan Kami lebihkan mereka atas bangsa-bangsa) atas orang-orang pandai di zamannya.\qt@no{16}}%
\qt@newcmd\qurantrans@id@mmmmcdxc{%
(Dan Kami berikan kepada mereka keterangan-keterangan yang nyata tentang urusan) agama, menyangkut masalah halal dan haram, serta berita tentang akan diutusnya Nabi Muhammad saw. (maka mereka tidak berselisih) tentang diutusnya Nabi Muhammad (melainkan sesudah datang kepada mereka pengetahuan karena permusuhan di antara mereka) karena permusuhan yang ada di antara mereka sebab mereka dengki kepada Nabi Muhammad. (Sesungguhnya Rabbmu akan memutuskan antara mereka pada hari kiamat terhadap apa yang mereka selalu berselisih padanya.)\qt@no{17}}%
\qt@newcmd\qurantrans@id@mmmmcdxci{%
(Kemudian Kami jadikan kamu) hai Muhammad (berada di atas suatu syariat) yakni peraturan (dari urusan itu) dari urusan agama (maka ikutilah syariat itu dan janganlah kamu ikuti hawa nafsu orang-orang yang tidak mengetahui) untuk menyembah kepada selain Allah.\qt@no{18}}%
\qt@newcmd\qurantrans@id@mmmmcdxcii{%
(Sesungguhnya mereka sekali-kali tidak akan dapat memberikan manfaat) mereka tidak akan dapat menolak (atas kamu dari siksaan Allah) yakni azab-Nya (barang sedikit pun. Dan sesungguhnya orang-orang yang zalim itu) orang-orang kafir itu (sebagian mereka menjadi penolong bagi sebagian yang lain dan Allah adalah Pelindung orang-orang yang bertakwa.)\qt@no{19}}%
\qt@newcmd\qurantrans@id@mmmmcdxciii{%
(Inilah) Alquran ini (adalah pedoman bagi manusia) artinya, sebagai pedoman yang dijadikan sumber bagi mereka dalam masalah hukum-hukum dan hudud (petunjuk dan rahmat bagi kaum yang meyakini) adanya hari berbangkit.\qt@no{20}}%
\qt@newcmd\qurantrans@id@mmmmcdxciv{%
(Apakah) lafal Am di sini maknanya sama dengan Hamzah yang menunjukkan makna ingkar (berprasangka orang-orang yang mengerjakan) orang-orang yang melakukan (kejahatan) kekafiran dan kemaksiatan (bahwa Kami akan menjadikan mereka seperti orang-orang yang beriman dan mengerjakan amal yang saleh, yaitu sama) lafal Sawaa-an ini menjadi Khabar (antara kehidupan dan kematian mereka?) menjadi Mubtada dan Ma'thuf, sedangkan Jumlah kalimat ini menjadi Badal dari huruf Kaf yang ada pada lafal Kalladziina, dan kedua Dhamirnya kembali kepada orang-orang kafir. Makna ayat, apakah mereka berprasangka bahwasanya Kami menjadikan mereka di akhirat sama dengan orang-orang mukmin, yaitu mereka hidup dalam kesejahteraan yang sama dengan kehidupan mereka sewaktu di dunia. Karena mereka telah mengatakan kepada orang-orang mukmin: ``Sungguh jika kami dibangkitkan hidup kembali, niscaya kami akan diberi kebaikan seperti apa yang diberikan kepada kalian." Lalu Allah berfirman menyangkal dugaan mereka sesuai dengan pengertian ingkar yang terkandung di dalam permulaan ayat. (Amat buruklah apa yang mereka sangka itu) maksudnya, perkara yang sebenarnya tidaklah demikian, karena sesungguhnya mereka di akhirat berada di dalam azab, berbeda dengan keadaan kehidupan mereka sewaktu di dunia. Sedangkan orang-orang mukmin di akhirat, mereka mendapatkan pahala yang berlimpah disebabkan amal perbuatan mereka sewaktu di dunia, yaitu berupa amal salat, amal zakat, amal puasa dan amal-amal lainnya. Huruf Maa pada ayat ini adalah Mashdariyah, yakni, seburuk-buruknya keputusan adalah keputusan mereka itu.\qt@no{21}}%
\qt@newcmd\qurantrans@id@mmmmcdxcv{%
(Dan Allah menciptakan langit dan) menciptakan (bumi dengan tujuan yang benar) lafal Bil haqqi ber-ta'alluq kepada lafal Khalaqa; penciptaan langit dan bumi itu dimaksud untuk menunjukkan kekuasaan dan keesaan-Nya (dan agar dibalasi tiap-tiap diri terhadap apa yang dikerjakannya) yaitu kemaksiatan dan ketaatan yang dilakukannya, maka tidaklah sama balasan yang diterima orang kafir dan orang mukmin (dan mereka tidak akan dirugikan.)\qt@no{22}}%
\qt@newcmd\qurantrans@id@mmmmcdxcvi{%
(Apakah kamu pernah melihat) maksudnya ceritakanlah kepadaku (orang yang menjadikan hawa nafsunya sebagai tuhannya) maksudnya, yang disukai oleh hawa nafsunya, yaitu batu demi batu ia ganti dengan yang lebih baik sebagai sesembahannya (dan Allah membiarkan-Nya sesat berdasarkan ilmu-Nya) berdasarkan pengetahuan Allah swt. Dengan kata lain Dia telah mengetahui, bahwa orang itu termasuk orang yang disesatkan sebelum ia diciptakan (dan Allah telah mengunci mati pendengaran dan hatinya) maka, karena itu ia tidak dapat mendengar petunjuk dan tidak mau memikirkannya (dan meletakkan tutupan atas penglihatannya) mengambil kegelapan hingga ia tidak dapat melihat petunjuk. Pada ayat ini diperkirakan adanya Maf'ul kedua bagi lafal Ra-ayta, yaitu lafal ayat tadi, yang artinya; apakah ia mendapat petunjuk? (Maka siapakah yang akan memberinya petunjuk sesudah Allah) membiarkannya sesat? Maksudnya, tentu saja ia tidak dapat petunjuk. (Maka mengapa kalian tidak mengambil pelajaran?) atau mengapa kalian tidak mau mengambilnya sebagai pelajaran buat kalian. Lafal Tadzakkaruuna asalnya salah satu dari huruf Ta-nya diidgamkan kepada huruf Dzal.\qt@no{23}}%
\qt@newcmd\qurantrans@id@mmmmcdxcvii{%
(Dan mereka berkata) yaitu orang-orang yang ingkar akan adanya hari berbangkit, ("Kehidupan ini) kehidupan yang sebenarnya (tiada lain hanyalah kehidupan kita) yang kita alami (di dunia saja, kita mati dan kita hidup) sebagian dari kita mati kemudian sebagian yang lain hidup karena mereka dilahirkan (dan tiada yang membinasakan kita selain masa") atau berlalunya masa. Lalu Allah berfirman menyangkal perkataan mereka melalui firman-Nya: (dan mereka tidak mempunyai mengenai hal itu) mengenai perkataan mereka yang demikian tadi (pengetahuan sedikit pun, tiada lain) tidak lain (mereka hanyalah menduga-duga saja.)\qt@no{24}}%
\qt@newcmd\qurantrans@id@mmmmcdxcviii{%
(Dan apabila dibacakan kepada mereka ayat-ayat Kami) dari Alquran yang menunjukkan akan kekuasaan Kami yang mampu membangkitkan makhluk menjadi hidup kembali (yang jelas) yang keadaannya jelas sekali (tidak ada bantahan mereka selain dari mengatakan, ``Datangkanlah nenek moyang kami) dalam keadaan hidup (jika kalian adalah orang-orang yang benar") bahwasanya kami benar-benar akan dibangkitkan menjadi hidup kembali sesudah kami mati.\qt@no{25}}%
\qt@newcmd\qurantrans@id@mmmmcdxcix{%
(Katakanlah, ``Allahlah yang menghidupkan kalian) sewaktu kalian masih dalam bentuk air mani (kemudian mematikan kalian, setelah itu mengumpulkan kalian) dalam keadaan hidup (pada hari kiamat yang tidak ada keraguan padanya) tidak diragukan lagi kedatangannya (akan tetapi kebanyakan manusia) yang dimaksud adalah mereka yang telah mengatakan apa yang telah disebutkan tadi (tidak mengetahui.")\qt@no{26}}%
\qt@newcmd\qurantrans@id@mmmmd{%
(Dan hanya kepunyaan Allahlah kerajaan langit dan bumi. Dan pada hari terjadinya kiamat) kemudian dijelaskan maksud sebenarnya oleh firman berikutnya, yaitu: (akan rugilah pada hari itu orang-orang yang mengerjakan kebatilan) yakni orang-orang kafir. Maksudnya, kerugian mereka akan tampak jelas karena mereka dimasukkan ke dalam neraka.\qt@no{27}}%
\qt@newcmd\qurantrans@id@mmmmdi{%
(Dan pada hari itu kamu lihat tiap-tiap umat) tiap-tiap pemeluk suatu agama (berlutut) mereka berdiri pada lututnya, atau mereka membentuk kumpulan. (Tiap-tiap umat dipanggil untuk melihat kitabnya) untuk melihat catatan amalnya, lalu dikatakan kepada mereka, ("Pada hari ini kalian diberi balasan terhadap apa yang telah kalian kerjakan") sebagai pembalasannya.\qt@no{28}}%
\qt@newcmd\qurantrans@id@mmmmdii{%
(Inilah kitab catatan Kami) yakni kitab catatan malaikat pencatat amal perbuatan manusia (yang menuturkan terhadap kalian dengan benar. Sesungguhnya Kami telah menyuruh mencatat) menulis dan mengarsipkan (apa yang telah kalian kerjakan.)\qt@no{29}}%
\qt@newcmd\qurantrans@id@mmmmdiii{%
(Adapun orang-orang yang beriman dan mengerjakan amal yang saleh maka Rabb mereka memasukkan mereka ke dalam rahmat-Nya) yakni surga-Nya. (Itulah keberuntungan yang nyata) nyata lagi jelas keuntungannya.\qt@no{30}}%
\qt@newcmd\qurantrans@id@mmmmdiv{%
(Dan adapun orang-orang yang kafir) dikatakan kepada mereka: ("Maka apakah belum ada ayat-ayat-Ku) yakni Alquran (yang dibacakan kepada kalian lalu kalian menyombongkan diri) bersifat takabur terhadapnya (dan kalian jadi kaum yang berbuat dosa?") jadi orang-orang yang kafir.\qt@no{31}}%
\qt@newcmd\qurantrans@id@mmmmdv{%
(Dan apabila dikatakan) kepada kalian hai orang-orang kafir, ("Sesungguhnya janji Allah itu) mengenai hari berbangkit (adalah benar dan hari kiamat itu) dapat dibaca Was Saa'atu atau Was Saa'ata (tidak ada keraguan) tidak ada keragu-raguan (padanya," niscaya kalian menjawab, ``Kami tidak tahu apakah hari kiamat itu, tidak lain) tiada lain (kami hanya menduga-duga saja) menurut Iman Mubarrad, bahwa asal dari lafal In Nazhunnu Illaa Zhannan adalah In Nahnu Illaa Nazhunnu Zhannan, yang artinya: kami sekali-kali tidak lain hanyalah menduga-duga saja (dan Kami sekali-kali tidak meyakini") bahwa hari kiamat itu benar-benar akan datang.\qt@no{32}}%
\qt@newcmd\qurantrans@id@mmmmdvi{%
(Dan nyatalah) jelaslah (bagi mereka) di akhirat nanti (keburukan-keburukan dari apa yang mereka kerjakan) sewaktu di dunia, yang dimaksud adalah pembalasannya (dan menimpalah) turunlah (kepada mereka apa yang mereka selalu memperolok-olokkannya) yaitu, azab yang dahulu mereka selalu memperolok-olokkannya.\qt@no{33}}%
\qt@newcmd\qurantrans@id@mmmmdvii{%
(Dan dikatakan kepada mereka, ``Pada hari ini Kami melupakan kalian) Kami membiarkan kalian berada di dalam neraka (sebagaimana kalian telah melupakan pertemuan dengan hari kalian ini) yaitu kalian tidak mau beramal sebagai bekal untuk menghadapinya (dan tempat tinggal kalian ialah neraka dan kalian sekali-kali tidak memperoleh penolong") yang dapat mencegah diri kalian dari azab neraka.\qt@no{34}}%
\qt@newcmd\qurantrans@id@mmmmdviii{%
(Yang demikian itu, karena sesungguhnya kalian menjadikan ayat-ayat Allah) Alquran (sebagai olok-olokan dan kalian telah ditipu oleh kehidupan dunia) sehingga kalian berani mengatakan bahwa tidak ada hari berbangkit dan tidak ada hari hisab (maka pada hari ini mereka tidak dikeluarkan) dapat dibaca Yukhrajuuna dan Yakhrujuuna, kalau dibaca Yakhrujuuna artinya mereka tidak dapat keluar (daripadanya) dari neraka (dan tidak pula mereka diberi kesempatan untuk bertobat) tidak dituntut untuk membuat amal keridaan terhadap Rabbnya, yaitu berupa tobat dan ketaatan kepada-Nya, karena pada hari itu hal-hal tersebut sudah tidak bermanfaat lagi.\qt@no{35}}%
\qt@newcmd\qurantrans@id@mmmmdix{%
(Maka bagi Allahlah segala puji) sanjungan yang baik atas ketepatan ancaman-Nya terhadap orang-orang yang mendustakan-Nya (Rabb langit dan bumi, Rabb semesta alam) Pencipta hal-hal yang telah disebutkan tadi. Pengertian kata Al-'Aalam adalah semua yang selain Allah, diungkapkan dalam bentuk jamak mengingat jenisnya yang bermacam-macam dan lafal Rabb adalah Badal.\qt@no{36}}%
\qt@newcmd\qurantrans@id@mmmmdx{%
(Dan bagi-Nyalah keagungan) kebesaran (di langit dan bumi) lafal Fis Samaawaati Wal Ardhi ini berkedudukan menjadi Hal atau kata keterangan keadaan; yakni keagungan yang ada pada keduanya. (Dialah Yang Maha Perkasa lagi Maha Bijaksana) sebagaimana yang telah dijelaskan pada penafsiran-penafsiran sebelumnya.\qt@no{37}}%
\qt@newcmd\qurantrans@id@mmmmdxi{%
\basmalahid (Ha Mim) hanya Allah sajalah yang mengetahui arti dan maksudnya.\qt@no{1}}%
\qt@newcmd\qurantrans@id@mmmmdxii{%
(Diturunkan Alkitab ini) yaitu Alquran; lafal ayat ini menjadi Mubtada (dari Allah) menjadi Khabar dari Mubtada (Yang Maha Perkasa) di dalam kerajaan-Nya (lagi Maha Bijaksana) di dalam perbuatan-Nya.\qt@no{2}}%
\qt@newcmd\qurantrans@id@mmmmdxiii{%
(Kami tiada menciptakan langit dan bumi dan apa yang ada di antara keduanya melainkan) dengan tujuan (yang benar) guna menunjukkan kekuasaan dan keesaan Kami (dan dalam waktu yang ditentukan) bagi kemusnahannya, yaitu hingga hari kiamat. (Dan orang-orang yang kafir; terhadap apa yang diperingatkan kepada mereka) berupa dipertakuti dengan siksa (mereka berpaling)\qt@no{3}}%
\qt@newcmd\qurantrans@id@mmmmdxiv{%
(Katakanlah, ``Terangkanlah kepadaku) ceritakanlah oleh kalian kepadaku (tentang apa yang kalian seru) kalian sembah (selain Allah) yakni berhala-berhala; menjadi Maf'ul Awwal (perlihatkanlah kepadaku) ceritakanlah oleh kalian kepadaku (apakah yang telah mereka ciptakan) menjadi Maf'ul kedua (dari bumi ini) lafal ayat ini berkedudukan menjadi Maf'ul Tsani (atau adakah mereka berserikat) artinya, mempunyai andil (dalam) penciptaan (langit) bersama dengan Allah; lafal Am di sini bermakna Hamzah atau kata tanya yang menunjukkan makna ingkar. (Bawalah kepada-Ku Kitab yang sebelum ini) sebelum Alquran ini (atau peninggalan) yakni sisa-sisa (dari pengetahuan) yang ditemukan dari orang-orang terdahulu, yang hal tersebut membenarkan pengakuan kalian bahwa menyembah berhala itu dapat mendekatkan diri kalian kepada Allah? (jika kalian adalah orang-orang yang benar") di dalam pengakuan kalian.\qt@no{4}}%
\qt@newcmd\qurantrans@id@mmmmdxv{%
(Dan siapakah) Istifham atau kata tanya ini menunjukkan makna negatif, yakni tidak ada seorang pun (yang lebih sesat daripada orang yang menyeru) yang menyembah (selain Allah) (yang tidak dapat memperkenankan doanya sampai hari kiamat) yang dimaksud adalah berhala-berhala yang menjadi sesembahan mereka, sedikit pun dan untuk selamanya tidak akan dapat memperkenankan apa yang diminta oleh para penyembahnya (dan mereka terhadap seruan para penyembahnya) yakni penyembahan yang dilakukan oleh para penyembahnya (lalai) karena berhala-berhala itu adalah benda mati dan tidak berakal.\qt@no{5}}%
\qt@newcmd\qurantrans@id@mmmmdxvi{%
(Dan apabila manusia dikumpulkan pada hari kiamat niscaya sesembahan-sesembahan itu) berhala-berhala itu (terhadap mereka) yang menyembahnya (menjadi musuh mereka dan sesembahan-sesembahan itu terhadap penyembahan) para penyembahnya (ingkar) menyangkalnya.\qt@no{6}}%
\qt@newcmd\qurantrans@id@mmmmdxvii{%
(Dan apabila dibacakan kepada mereka) kepada penduduk Mekah (ayat-ayat Kami) yakni Alquran (yang menjelaskan) atau yang jelas keadaannya (berkatalah orang-orang yang ingkar) di antara mereka (kepada kebenaran) kepada Alquran (ketika kebenaran itu datang kepada mereka, ``Ini adalah sihir yang nyata") jelas sihirnya.\qt@no{7}}%
\qt@newcmd\qurantrans@id@mmmmdxviii{%
(Bahkan) lafal Am di sini mempunyai makna sama dengan lafal Bal dan Hamzah yang menunjukkan makna ingkar (mereka mengatakan, ``Dia telah mengada-adakannya") maksudnya, Alquran itu. (Katakanlah, ``Jika aku mengada-adakannya) umpamanya (maka kalian tiada mempunyai kuasa mempertahankan aku dari Allah) dari azab-Nya (barang sedikit pun) artinya, kalian tidak akan mampu menolak azab-Nya daripada diriku, jika Dia mengazab aku (Dia lebih mengetahui apa-apa yang kalian percakapkan tentangnya) tentang Alquran itu. (Cukuplah Dia) Yang Maha Tinggi (menjadi saksi antaraku dan antara kalian dan Dialah Yang Maha Pengampun) kepada orang yang bertobat (lagi Maha Penyayang") kepada orang yang bertobat kepada-Nya; karena itu Dia tidak menyegerakan azab-Nya kepada mereka.\qt@no{8}}%
\qt@newcmd\qurantrans@id@mmmmdxix{%
(Katakanlah, ``Aku bukanlah rasul yang pertama) atau untuk, pertama kalinya (di antara rasul-rasul) maksudnya aku bukanlah rasul yang pertama, karena telah, banyak rasul yang diutus sebelumku, maka mengapa kalian mendustakan aku (dan aku tidak mengetahui apa yang akan diperbuat terhadapku dan tidak pula terhadap kalian) di dunia ini; apakah aku akan diusir dari negeriku, atau apakah aku akan dibunuh sebagaimana nasib yang telah dialami oleh nabi-nabi sebelumku, atau adakalanya kalian melempariku dengan batu, atau barangkali kalian akan tertimpa azab sebagaimana apa yang dialami oleh kaum yang mendustakan sebelum kalian. (Tiada lain) tidak lain (aku hanyalah mengikuti apa yang diwahyukan kepadaku) yaitu Alquran, dan aku sama sekali belum pernah membuat-buat dari diriku sendiri (dan aku tidak lain hanyalah seorang pemberi peringatan yang menjelaskan") yang jelas peringatannya.\qt@no{9}}%
\qt@newcmd\qurantrans@id@mmmmdxx{%
(Katakanlah, ``Terangkanlah kepadaku) ceritakanlah kepadaku, bagaimana pendapat kalian (jika ia) yakni jika Alquran itu (datang dari sisi Allah padahal kalian mengingkarinya) lafal Wakafartum Bihi merupakan jumlah Haliyah (dan seorang saksi dari Bani Israel mengakui kebenaran) yaitu Abdullah bin Salam (yang serupa dengan yang tersebut dalam Alquran) bahwasanya Alquran itu datang dari sisi Allah (lalu dia beriman) yakni saksi tersebut beriman kepada Alquran (sedangkan kalian menyombongkan diri) tidak mau beriman kepada Alquran. Sedangkan Jawab Syaratnya ialah 'Bukankah kalau demikian kalian adalah orang-orang yang lalim', hal ini disimpulkan dari pengertian ayat selanjutnya, ('Sesungguhnya Allah tiada memberi petunjuk kepada orang-orang yang lalim.")\qt@no{10}}%
\qt@newcmd\qurantrans@id@mmmmdxxi{%
(Dan orang-orang kafir berkata kepada orang-orang yang beriman) sehubungan dengan perihal orang-orang yang beriman, ("Kalau sekiranya beriman) kepada Alquran itu (adalah suatu yang baik, tentulah mereka tiada mendahului kami beriman kepadanya. Dan karena mereka tidak mendapat petunjuk) yaitu orang-orang yang mengatakan demikian (dengannya) tidak mendapat petunjuk dari Alquran (maka mereka akan berkata, 'Ini) Alquran ini (adalah dusta) maksudnya, kebohongan (yang lama.'")\qt@no{11}}%
\qt@newcmd\qurantrans@id@mmmmdxxii{%
(Dan sebelumnya) sebelum Alquran (telah ada kitab Musa) kitab Taurat (sebagai petunjuk dan rahmat) bagi orang-orang yang beriman kepadanya; lafal Imaaman dan Rahmatan keduanya merupakan Hal. (Dan ini) yaitu Alquran (adalah Kitab yang membenarkan) kitab-kitab sebelumnya (dalam bahasa Arab) menjadi Hal dari Dhamir yang terkandung di dalam lafal Mushaddiquun (untuk memberi peringatan kepada orang-orang yang lalim) yakni orang-orang musyrik Mekah (dan) dia adalah (memberi kabar gembira kepada orang-orang yang berbuat baik) yakni orang-orang yang beriman.\qt@no{12}}%
\qt@newcmd\qurantrans@id@mmmmdxxiii{%
(Sesungguhnya orang-orang yang mengatakan, ``Rabb kami ialah Allah," kemudian mereka beristiqamah) atau menetapi ketaatan (maka tidak ada kekhawatiran terhadap mereka dan mereka tiada pula berduka cita.)\qt@no{13}}%
\qt@newcmd\qurantrans@id@mmmmdxxiv{%
(Mereka itulah penghuni-penghuni surga, mereka kekal di dalamnya) lafal Khaalidiina Fiihaa menjadi Hal atau kata keterangan keadaan (sebagai balasan) menjadi Mashdar yang dinashabkan oleh Fi'ilnya yang diperkirakan keberadaannya, yaitu lafal Yujzauna; artinya: mereka diberi pahala sebagai balasan (atas apa yang telah mereka kerjakan.)\qt@no{14}}%
\qt@newcmd\qurantrans@id@mmmmdxxv{%
(Kami perintahkan kepada manusia supaya berbuat baik kepada dua orang ibu bapaknya) menurut suatu qiraat lafal Ihsaan dibaca Husnan; maksudnya: Kami perintahkan manusia supaya berbuat baik kepada kedua orang tuanya. Lafal Ihsaanan adalah Mashdar yang dinashabkan oleh Fi'ilnya yang diperkirakan keberadaannya; demikian pula penjabarannya bila dibaca Husnan (ibunya mengandungnya dengan susah payah dan melahirkannya dengan susah pula) artinya penuh dengan susah payah. (Mengandungnya sampai menyapihnya) dari penyusuannya (adalah tiga puluh bulan) yakni dalam masa enam bulan sebagai batas yang paling minim bagi mengandung, sedangkan sisanya dua puluh empat bulan, yaitu lama masa penyusuan yang maksimal. Menurut suatu pendapat disebutkan bahwa jika sang ibu mengandungnya selama enam bulan atau sembilan bulan, maka sisanya adalah masa penyusuan (sehingga) menunjukkan makna Ghayah bagi jumlah yang diperkirakan keberadaannya, yakni dia hidup sehingga (apabila dia telah dewasa) yang dimaksud dengan pengertian dewasa ialah kekuatan fisik dan akal serta inteligensinya telah sempurna yaitu sekitar usia tiga puluh tiga tahun atau tiga puluh tahun (dan umurnya sampai empat puluh tahun) yakni genap mencapai empat puluh tahun, dalam usia ini seseorang telah mencapai batas maksimal kedewasaannya (ia berdoa, ``Ya Rabbku!) dan seterusnya. Ayat ini diturunkan berkenaan dengan Abu Bakar Ash-Shiddiq, yaitu sewaktu usianya mencapai empat puluh tahun sesudah dua tahun Nabi saw. diangkat menjadi rasul. Lalu ia beriman kepada Nabi saw. lalu beriman pula kedua orang tuanya, lalu menyusul anaknya yang bernama Abdurrahman, lalu cucunya yang bernama Atiq (Tunjukilah aku) maksudnya berilah ilham (untuk mensyukuri nikmat Engkau yang telah Engkau berikan) nikmat tersebut (kepadaku dan kepada ibu bapakku) yaitu nikmat tauhid (dan supaya aku dapat berbuat amal saleh yang Engkau ridai) maka Abu Bakar segera memerdekakan sembilan orang hamba sahaya yang beriman; mereka disiksa karena memeluk agama Allah (berilah kebaikan kepadaku dengan memberi kebaikan kepada cucuku) maka semua anak cucunya adalah orang-orang yang beriman. (Sesungguhnya aku bertobat kepada Engkau dan sesungguhnya aku termasuk orang-orang yang berserah diri.")\qt@no{15}}%
\qt@newcmd\qurantrans@id@mmmmdxxvi{%
(Mereka itulah) maksudnya yang mengatakan ucapan ini, yaitu Abu Bakar dan lain-lainnya (orang-orang yang Kami terima dari mereka amal baik) lafal Ahsana di sini bermakna Hasana (yang telah mereka kerjakan dan Kami ampuni kesalahan-kesalahan mereka, bersama penghuni-penghuni surga) lafal Fii Ash-haabil Jannah berkedudukan menjadi Hal atau kata keterangan keadaan maksudnya, mereka digolongkan ke dalam para penghuni surga (sebagai janji yang benar yang telah dijanjikan kepada mereka) yaitu sebagaimana yang telah diungkapkan dalam ayat yang lain, yakni firman-Nya, ``Allah menjanjikan kepada orang-orang yang mukmin lelaki dan perempuan, (akan mendapat) surga." (Q.S. At-Taubah, 72).\qt@no{16}}%
\qt@newcmd\qurantrans@id@mmmmdxxvii{%
(Dan orang yang berkata kepada dua orang ibu bapaknya) menurut suatu qiraat dibaca Idgham dimaksud adalah jenisnya ("Cis) dapat dibaca Uffin atau Uffan, merupakan Mashdar yang artinya, busuk dan buruk (bagi kamu keduanya) yakni aku marah kepada kamu berdua (apakah kamu keduanya memperingatkan kepadaku) menurut qiraat lain dibaca Ata'idannii, dengan diidgamkan (bahwa aku akan dibangkitkan) dari kubur (padahal sungguh telah berlalu beberapa umat) yakni generasi-generasi (sebelumku") dan ternyata mereka tidak dikeluarkan dari kuburnya (lalu kedua ibu bapaknya itu memohon pertolongan kepada Allah) meminta pertolongan supaya anaknya sadar dan bertobat, seraya mengatakan, bahwa apabila kamu tidak mau bertobat, ("Celakalah kamu) binasalah kamu (berimanlah) kepada adanya hari berbangkit. (Sesungguhnya janji Allah adalah benar." Lalu dia berkata: ``Ini tidak lain) maksudnya ucapan yang menyatakan adanya hari berbangkit ini (hanyalah dongengan orang-orang dahulu belaka") artinya, kedustaan-kedustaan mereka.\qt@no{17}}%
\qt@newcmd\qurantrans@id@mmmmdxxviii{%
(Mereka itulah orang-orang yang telah pasti) telah ditentukan (ketetapan atas mereka) yakni ketetapan azab (bersama umat-umat yang telah berlalu sebelum mereka dari jin dan manusia. Sesungguhnya mereka adalah orang-orang yang merugi.)\qt@no{18}}%
\qt@newcmd\qurantrans@id@mmmmdxxix{%
(Dan bagi masing-masing mereka) bagi masing-masing dari orang mukmin dan orang kafir (derajat), derajat orang-orang yang beriman memperoleh kedudukan yang tinggi di dalam surga, sedangkan derajat orang-orang kafir memperoleh kedudukan di dasar neraka (menurut apa yang telah mereka kerjakan) berdasar pada amal ketaatan bagi orang-orang mukmin dan kemaksiatan bagi orang-orang kafir (dan agar Dia mencukupkan bagi mereka) yakni Allah mencukupkan bagi mereka; menurut suatu qiraat dibaca Walinuwaffiyahum (pekerjaan-pekerjaan mereka) maksudnya balasannya (sedangkan mereka tiada dirugikan) barang sedikit pun, misalkan untuk orang-orang mukmin dikurangi dan untuk orang-orang kafir ditambahi.\qt@no{19}}%
\qt@newcmd\qurantrans@id@mmmmdxxx{%
(Dan ingatlah hari ketika orang-orang kafir dihadapkan ke neraka) neraka diperlihatkan-Nya kepada mereka, kemudian dikatakan kepada mereka, ("Kalian telah menghabiskan) dapat dibaca Adzhabtum, A-adzhabtum atau Adzhabtum (rezeki kalian yang baik) dengan cara menghambur-hamburkannya demi kelezatan kalian (dalam kehidupan dunia kalian saja dan kalian telah bersenang-senang) bersuka-ria (dengannya, maka pada hari ini kalian dibalasi dengan azab yang menghinakan) atau azab yang mengerikan (karena kalian telah menyombongkan diri yaitu bersikap takabur (di muka bumi tanpa hak dan karena kalian telah fasik") atau berbuat kefasikan padanya, maka karena itu kalian diazab.\qt@no{20}}%
\qt@newcmd\qurantrans@id@mmmmdxxxi{%
(Dan ingatlah saudara kaum Ad) yakni Nabi Hud a.s. (yaitu ketika) mulai lafal Idz dan seterusnya menjadi Badal Isytimal (dia memberi peringatan kepada kaumnya) maksudnya, mempertakuti mereka (di Al-Ahqaf) nama sebuah lembah tempat tinggal mereka yang terletak di negeri Yaman (dan sesungguhnya telah terdahulu beberapa orang pemberi peringatan) beberapa orang rasul (sebelumnya dan sesudahnya) sebelum Nabi Hud datang dan sesudahnya, kepada kaumnya masing-masing seraya mengatakan, ("Janganlah kalian menyembah selain Allah) jumlah Waqad Khalat merupakan jumlah Mu'taridhah, atau kalimat sisipan (sesungguhnya aku khawatir kalian) jika kalian menyembah kepada selain Allah (akan ditimpa azab hari yang besar.")\qt@no{21}}%
\qt@newcmd\qurantrans@id@mmmmdxxxii{%
(Mereka menjawab, ``Apakah kamu datang kepada kami untuk memalingkan kami dari menyembah tuhan-tuhan kami?) maksudnya kamu datang untuk memalingkan kami daripada menyembahnya. (Maka datangkanlah kepada kami azab yang telah kamu ancamkan kepada kami) bahwa jika kami menyembahnya pasti kami tertimpa azab (jika kamu termasuk orang-orang yang benar") bahwasanya azab itu benar-benar menimpa kami.\qt@no{22}}%
\qt@newcmd\qurantrans@id@mmmmdxxxiii{%
(Ia berkata) Nabi Hud berkata, ("Sesungguhnya pengetahuan tentang itu hanya pada sisi Allah) artinya hanya Dialah yang mengetahui kapan azab itu menimpa kalian (dan aku hanya menyampaikan kepada kalian apa yang aku diutus dengan membawanya) untuk disampaikan kepada kalian (tetapi aku lihat kalian adalah kaum yang bodoh") karena kalian meminta supaya azab didatangkan dengan segera.\qt@no{23}}%
\qt@newcmd\qurantrans@id@mmmmdxxxiv{%
(Maka tatkala mereka melihat azab itu) (berupa awan) atau mendung yang muncul di cakrawala langit (menuju ke lembah-lembah mereka, berkatalah mereka, ``Inilah awan yang akan menurunkan hujan kepada kami) maksudnya, awan yang membawa hujan buat kami, Allah swt. berfirman, ('Bahkan itulah azab yang kalian minta supaya datang dengan segera) maksudnya, azab itu yang kalian minta agar disegerakan datangnya (yaitu berupa angin) lafal Riihun menjadi Badal dari lafal Maa (yang mengandung azab yang pedih) yang menyakitkan.\qt@no{24}}%
\qt@newcmd\qurantrans@id@mmmmdxxxv{%
(Yang menghancurkan) yang membinasakan (segala sesuatu) yang dilewatinya (dengan perintah Rabbnya) dengan seizin-Nya; maksudnya angin itu dapat membinasakan segala sesuatu yang dikehendaki-Nya untuk dibinasakan. Akhirnya binasalah kaum laki-laki dan wanita serta anak-anak mereka berikut dengan harta bendanya; semuanya terbawa terbang oleh angin yang besar itu antara langit dan bumi dalam keadaan tercabik-cabik. Kini yang tertinggal dalam keadaan selamat adalah Nabi Hud beserta orang-orang yang beriman kepadanya (maka jadilah mereka tidak ada yang kelihatan lagi kecuali bekas-bekas tempat tinggal mereka.' Demikianlah) sebagaimana Kami memberikan balasan kepada kaum Hud (Kami memberi balasan kepada kaum yang berdosa") selain mereka.\qt@no{25}}%
\qt@newcmd\qurantrans@id@mmmmdxxxvi{%
(Dan sesungguhnya Kami telah meneguhkan kedudukan mereka dalam hal-hal) (yang belum pernah) lafal In di sini dapat dikatakan sebagai In Nafiyah atau In Zaidah (Kami meneguhkan kedudukan kalian) hai penduduk Mekah (dalam hal itu) dalam hal kekuatan dan banyaknya harta benda (dan Kami telah memberikan kepada mereka pendengaran) lafal Sam'an bermakna Asmaa'an bermakna jamak (dan penglihatan serta hati) atau kalbu (tetapi pendengaran, penglihatan dan hati mereka itu tidak berguna sedikit jua pun bagi mereka) maksudnya, hal-hal tersebut sama sekali tidak dapat memberikan manfaat sedikit pun buat diri mereka; lafal Min di sini adalah Zaidah (karena) lafal Idz adalah yang dima'mulkan oleh lafal Aghnaa kemudian diberlakukan sebagai makna Ta'lil (mereka selalu mengingkari ayat-ayat Allah) yaitu hujah-hujah-Nya yang nyata (dan turunlah) yaitu menimpalah (kepada mereka apa yang dahulu selalu mereka memperolok-olokkannya) yaitu azab yang dahulu mereka suka memperolok-olokkannya.\qt@no{26}}%
\qt@newcmd\qurantrans@id@mmmmdxxxvii{%
(Dan sesungguhnya Kami telah membinasakan negeri-negeri di sekitar kalian) yakni penduduk-penduduknya, seperti kaum Tsamud, kaum Ad dan kaum Luth (dan Kami telah mendatangkan tanda-tanda kebesaran Kami berulang-ulang) maksudnya Kami telah mengulang-ulang hujah-hujah Kami yang nyata (supaya mereka kembali.)\qt@no{27}}%
\qt@newcmd\qurantrans@id@mmmmdxxxviii{%
(Maka mengapa tidak) atau kenapa tidak (menolong mereka) dengan cara menolak azab dari diri mereka (sesembahan-sesembahan selain Allah yang mereka jadikan) selain dari Allah (sebagai taqarrub) untuk mendekatkan diri mereka kepada Allah (dan sebagai tuhan-tuhan) di samping Allah, yaitu berupa berhala-berhala. Maf'ul pertama dari lafal Ittakhadza adalah Dhamir yang tidak disebutkan yang kembali kepada Isim Maushul, yaitu lafal Hum, sedangkan Maf'ul keduanya adalah lafal Qurbaanan, dan lafal Aalihatan sebagai Badal dari lafal Qurbaanan. (Bahkan tuhan-tuhan itu telah lenyap) yakni pergi (dari mereka) sewaktu azab itu datang menimpa mereka. (Itulah) yakni pengambilan mereka terhadap berhala-berhala sebagai tuhan-tuhan untuk mendekatkan diri kepada Allah (akibat kebohongan mereka) kedustaan mereka (dan apa yang dahulu mereka ada-adakan) yang dahulu mereka buat-buat. Maa adalah Mashdariyah atau Maushulah, sedangkan Dhamir yang kembali kepadanya tidak disebutkan yaitu lafal Fiihi; lengkapnya: Wa Maa Kaanuu Fiihi Yaftaruuna.\qt@no{28}}%
\qt@newcmd\qurantrans@id@mmmmdxxxix{%
(Dan) ingatlah (ketika Kami hadapkan) Kami cenderungkan (kepadamu serombongan jin) yaitu jin Nashibin dari negeri Yaman atau Jin Nainawi, jumlah mereka ada tujuh atau sembilan jin. Nabi saw. ketika itu berada di lembah Nakhl sedang melakukan salat Subuh berjemaah dengan para sahabatnya. Demikianlah menurut hadis yang diriwayatkan oleh Bukhari dan Muslim (yang mendengarkan Alquran, maka tatkala mereka menghadiri pembacaannya, lalu mereka berkata) sebagian dari mereka berkata kepada sebagian yang lain, ("Diamlah kalian") untuk mendengarkan bacaannya. (Ketika pembacaan telah selesai) ketika nabi selesai membaca Alquran (mereka kembali) pulang kembali (kepada kaumnya untuk memberi peringatan) artinya, mereka kembali setelah mendengarkan Alquran kepada kaumnya sebagai pemberi peringatan akan datangnya azab jika mereka tidak beriman kepada Nabi. Mereka sebelum itu pemeluk agama Yahudi, lalu setelah mendengarkan bacaan Alquran mereka masuk Islam.\qt@no{29}}%
\qt@newcmd\qurantrans@id@mmmmdxl{%
(Mereka berkata, ``Hai kaum kami, sesungguhnya kami telah mendengarkan Kitab) yakni Alquran (yang telah diturunkan sesudah Musa yang membenarkan kitab-kitab sebelumnya) seperti kitab Taurat (lagi memimpin kepada kebenaran) kepada agama Islam (dan kepada jalan yang lurus) yaitu tuntunan agama Islam.\qt@no{30}}%
\qt@newcmd\qurantrans@id@mmmmdxli{%
(Hai kaum kami! Terimalah seruan orang yang menyeru kepada Allah) yakni seruan iman yang dilakukan oleh Nabi Muhammad saw. (dan berimanlah kepada-Nya, niscaya Dia akan mengampuni) Allah pasti akan mengampuni (dosa-dosa kalian) sebagian dari dosa-dosa kalian, diartikan demikian karena di antara dosa-dosa itu terdapat jenis dosa yang tidak dapat diampuni melainkan setelah mendapat kerelaan dari orang yang dianiaya oleh orang yang bersangkutan (dan melindungi kalian dari azab yang pedih) atau azab yang menyakitkan.\qt@no{31}}%
\qt@newcmd\qurantrans@id@mmmmdxlii{%
(Dan orang yang tidak menerima seruan orang yang menyeru kepada Allah maka dia tidak akan dapat melepaskan diri dari azab Allah di muka bumi) artinya ia tidak akan dapat melemahkan Allah dengan cara lari dari-Nya sehingga ia selamat dari azab-Nya (dan tidak ada baginya) yakni bagi orang yang tidak menerima seruan itu (selain Allah) (pelindung-pelindung) yang dapat menolak azab Allah daripada dirinya. (dalam kesesatan yang nyata") jelas sesatnya.\qt@no{32}}%
\qt@newcmd\qurantrans@id@mmmmdxliii{%
(Dan apakah mereka tidak memperhatikan) atau apakah orang-orang yang ingkar kepada hari berbangkit itu tidak mengetahui (bahwa sesungguhnya Allah yang menciptakan langit dan bumi dan Dia tidak merasa payah karena menciptakannya) artinya, Dia mampu menciptakan kesemuanya dengan mudah (kuasa) lafal Biqaadirin menjadi Khabar dari Anna, kemudian ditambahkan huruf Ba, karena pengertian ayat ini sejajar kekuatannya dengan kalimat Alaisallaahu Biqaadirin, artinya; Bukankah Allah kuasa (menghidupkan orang-orang mati? Ya) Dia Maha Kuasa untuk menghidupkan orang-orang mati (sesungguhnya Dia Maha Kuasa atas segala sesuatu.)\qt@no{33}}%
\qt@newcmd\qurantrans@id@mmmmdxliv{%
(Dan ingatlah hari ketika orang-orang kafir dihadapkan kepada neraka) ketika mereka diazab di dalamnya, lalu dikatakan kepada mereka, ("Bukankah ini) yakni azab ini (benar?" Mereka menjawab, ``Ya benar demi Rabb kami." Allah berfirman, ``Maka rasakanlah azab ini disebabkan kalian selalu ingkar.")\qt@no{34}}%
\qt@newcmd\qurantrans@id@mmmmdxlv{%
(Maka bersabarlah kamu) di dalam menghadapi perlakuan kaummu yang menyakitkan itu (sebagaimana orang-orang yang mempunyai keteguhan hati) yaitu orang-orang yang teguh dan sabar di dalam menghadapi cobaan dan tantangan (dari rasul-rasul) sebelummu, karena itu kamu akan termasuk orang yang mempunyai keteguhan hati. Lafal Min di sini menunjukkan makna Bayan, sehingga pengertiannya menunjukkan, bahwa semua rasul-rasul itu mempunyai keteguhan hati. Tetapi menurut pendapat yang lain itu menunjukkan makna Lit Tab'idh, karena Nabi Adam bukanlah termasuk di antara mereka yang memiliki keteguhan hati, sebagaimana yang diungkapkan oleh ayat lain yaitu firman-Nya: ``.. dan tidak Kami dapati padanya kemauan yang kuat." (Q.S. Thaha, 115) demikian pula Nabi Yunus tidak termasuk di antara mereka yang Ulil 'Azmi, sebagaimana yang diungkapkan oleh firman-Nya, ``.. dan janganlah kamu seperti orang yang berada dalam (perut) ikan (Yunus)." (Q.S. Al-Qalam, 48) (dan janganlah kamu meminta disegerakan azab bagi mereka) bagi kaummu yaitu disegerakan turunnya azab bagi mereka. Menurut pendapat lain, bahwa hal ini timbul sebagai reaksi dari sikap mereka terhadapnya, maka Nabi suka jika azab diturunkan kepada mereka, tetapi selanjutnya Nabi diperintahkan supaya bersabar dan jangan meminta supaya disegerakan azab bagi mereka. Karena sesungguhnya azab itu pasti akan menimpa mereka. (Pada hari mereka melihat apa yang diancamkan kepada mereka, mereka merasa seolah-olah) yang dimaksud adalah azab di akhirat mengingat lamanya masa di akhirat mereka merasa seolah-olah (tidak tinggal) di dunia menurut dugaan mereka (melainkan sesaat pada siang hari) Alquran ini adalah (suatu peringatan) peringatan dari Allah buat kalian (maka tidaklah) tiadalah (dibinasakan) sewaktu azab sudah di ambang pintu (melainkan orang-orang yang fasik) yaitu orang-orang yang kafir.\qt@no{35}}%
\qt@newcmd\qurantrans@id@mmmmdxlvi{%
\basmalahid (Orang-orang yang kafir) dari kalangan penduduk Mekah (dan menghalang-halangi) orang-orang lainnya (dari jalan Allah) dari jalan keimanan (Allah melebur) menghapus (amal-amal mereka) seperti memberi makan dan menghubungkan silaturahim; mereka tidak akan melihat pahala amalnya di akhirat nanti dan mereka hanya mendapat balasan di dunia saja dari kemurahan-Nya.\qt@no{1}}%
\qt@newcmd\qurantrans@id@mmmmdxlvii{%
(Dan orang-orang yang beriman) yaitu para sahabat Anshar dan lainnya (dan mengerjakan amal-amal yang saleh serta beriman pula kepada apa yang diturunkan kepada Muhammad) yakni Alquran (dan itulah yang hak dari Rabb mereka, Allah menghapuskan daripada mereka) artinya, Dia mengampuni (kesalahan-kesalahan mereka dan memperbaiki keadaan mereka) karena itu mereka tidak lagi mendurhakai-Nya.\qt@no{2}}%
\qt@newcmd\qurantrans@id@mmmmdxlviii{%
(Yang demikian) maksudnya penghapusan amal dan pengampunan kesalahan-kesalahan itu (adalah karena) disebabkan (orang-orang kafir mengikuti yang batil) yakni ajakan setan (dan sesungguhnya orang-orang yang beriman mengikuti yang hak) yakni Alquran (dari Rabb mereka. Demikianlah) sebagaimana penjelasan tersebut (Allah membuat untuk manusia perbandingan-perbandingan bagi mereka) untuk menjelaskan keadaan mereka, yaitu orang kafir amalnya akan dihapus, sedangkan orang mukmin kesalahan-kesalahannya akan diampuni.\qt@no{3}}%
\qt@newcmd\qurantrans@id@mmmmdxlix{%
(Apabila kalian bertemu dengan orang-orang kafir di medan perang maka pancunglah batang leher mereka) lafal Dharbur Riqaab adalah bentuk Mashdar yang menggantikan kedudukan Fi'ilnya, karena asalnya adalah, Fadhribuu Riqaabahum artinya, maka pancunglah batang leher mereka. Maksudnya, bunuhlah mereka. Di sini diungkapkan dengan kalimat Dharbur Riqaab yang artinya memancung leher, karena pukulan yang mematikan itu kebanyakan dilakukan dengan cara memukul atau memancung batang leher. (Sehingga apabila kalian telah mengalahkan mereka) artinya kalian telah banyak membunuh mereka (maka kencangkanlah) tangkaplah dan tawanlah mereka lalu ikatlah mereka (ikatan mereka) dengan tali pengikat tawanan perang (dan sesudah itu kalian boleh membebaskan mereka) lafal Mannan adalah bentuk Mashdar yang menggantikan kedudukan Fi'ilnya; maksudnya, kalian memberikan anugerah kepada mereka, yaitu dengan cara melepaskan mereka tanpa imbalan apa-apa (atau menerima tebusan) artinya, kalian meminta tebusan berupa harta atau tukaran dengan kaum muslimin yang ditawan oleh mereka (sampai perang meletakkan) maksudnya, orang-orang yang terlibat di dalam peperangan itu meletakkan (senjatanya) artinya, menghentikan adu senjata dan adu lain-lainnya, misalnya orang-orang kafir menyerah kalah atau mereka menandatangani perjanjian gencatan senjata; hal inilah akhir dari suatu peperangan dan saling tawan-menawan. (Demikianlah) menjadi Khabar dari Mubtada yang diperkirakan keberadaannya, yaitu perkara tentang menghadapi orang-orang kafir adalah sebagaimana yang telah disebutkan tadi (apabila Allah menghendaki niscaya Allah dapat menang atas mereka) tanpa melalui peperangan lagi (tetapi) Dia memerintahkan kalian supaya berperang (untuk menguji sebagian kalian dengan sebagian yang lain) di antara mereka dalam peperangan itu, sebagian orang yang gugur di antara kalian ada yang dimasukkan ke dalam surga, dan sebagian lagi dimasukkan ke dalam neraka. (Dan orang-orang yang gugur) menurut suatu qiraat dibaca Qaataluu dan seterusnya, ayat ini diturunkan pada waktu perang Uhud, karena banyak di antara pasukan kaum muslimin yang gugur dan mengalami luka-luka (di jalan Allah, Allah tidak akan menyia-nyiakan) maksudnya, tidak akan menghapuskan (amal mereka.)\qt@no{4}}%
\qt@newcmd\qurantrans@id@mmmmdl{%
(Allah akan memberi petunjuk kepada mereka) di dunia dan di akhirat kepada yang bermanfaat buat diri mereka (dan memperbaiki keadaan mereka) di dunia dan di akhirat. Perbaikan di dunia adalah bagi mereka yang tidak gugur, yang termasuk ke dalam pengertian ungkapan Qutiluu dengan cara Taghlib, artinya lebih memprioritaskan mereka yang gugur di jalan Allah swt.\qt@no{5}}%
\qt@newcmd\qurantrans@id@mmmmdli{%
(Dan memasukkan mereka ke dalam surga yang telah diperkenalkan) telah dijelaskan (kepada mereka) sehingga mereka mengetahui tempat-tempat tinggal mereka dalam surga itu dan mereka telah mengenal istri-istri mereka dan telah mengenal pelayan-pelayan yang akan melayani mereka tanpa membutuhkan petunjuk lagi.\qt@no{6}}%
\qt@newcmd\qurantrans@id@mmmmdlii{%
(Hai orang-orang yang beriman! Jika kalian menolong Allah) yakni agama-Nya dan Rasul-Nya (niscaya Dia menolong kalian) atas musuh-musuh kalian (dan meneguhkan telapak kaki kalian) di dalam medan perang.\qt@no{7}}%
\qt@newcmd\qurantrans@id@mmmmdliii{%
(Dan orang-orang yang kafir) dari kalangan penduduk Mekah; lafal ayat ini berkedudukan menjadi Mubtada, sedangkan Khabarnya, niscaya mereka celaka. Pengertian ini disimpulkan dari firman selanjutnya yaitu (maka kecelakaanlah bagi mereka) yakni kebinasaan dan kekecewaanlah yang akan mereka terima dari Allah (dan Allah menyesatkan amal perbuatan mereka) lafal ayat ini diathafkan pada Ta'isuu yang keberadaannya diperkirakan.\qt@no{8}}%
\qt@newcmd\qurantrans@id@mmmmdliv{%
(Yang demikian itu) kecelakaan dan penyesatan itu (adalah karena sesungguhnya mereka benci kepada apa yang diturunkan Allah) yakni Alquran yang diturunkan-Nya, di dalamnya terkandung masalah-masalah taklif atau kewajiban-kewajiban (lalu Allah menghapuskan pahala amal-amal mereka.)\qt@no{9}}%
\qt@newcmd\qurantrans@id@mmmmdlv{%
(Maka apakah mereka tidak mengadakan perjalanan di bumi sehingga mereka dapat memperhatikan bagaimana kesudahan orang-orang yang sebelum mereka; Allah telah menimpakan kebinasaan atas mereka) atas diri mereka, dan anak-anak serta harta benda mereka (dan orang-orang kafir akan menerima hal yang seperti itu) yaitu mereka akan menerima akibat-akibat yang sama dengan apa yang telah diterima oleh orang-orang kafir sebelum mereka.\qt@no{10}}%
\qt@newcmd\qurantrans@id@mmmmdlvi{%
(Yang demikian itu) dimenangkannya orang-orang mukmin dan dikalahkannya orang-orang kafir (karena sesungguhnya Allah adalah pelindung) pelindung dan penolong (orang-orang yang beriman dan karena sesungguhnya orang-orang kafir itu tiada mempunyai pelindung.)\qt@no{11}}%
\qt@newcmd\qurantrans@id@mmmmdlvii{%
(Sesungguhnya Allah memasukkan orang-orang yang beriman dan mengerjakan amal saleh ke dalam surga yang mengalir di bawahnya sungai-sungai. Dan orang-orang yang kafir itu bersenang-senang) di dunia (dan mereka makan seperti makannya binatang-binatang) tiada lagi yang menjadi kepentingan mereka selain dari perut dan nafsu syahwatnya dan mereka sama sekali tidak menoleh sedikit pun kepada masalah akhirat. (Dan neraka adalah tempat tinggal mereka) atau, tempat menetap dan tempat kembali mereka untuk selama-lamanya.\qt@no{12}}%
\qt@newcmd\qurantrans@id@mmmmdlviii{%
(Dan berapa banyaknya) sudah berapa banyak (negeri-negeri) yakni penduduknya (yang lebih kuat dari penduduk negerimu) lebih kuat daripada penduduk negeri Mekah (yang telah mengusirmu itu) Dhamir di sini lebih memperhatikan lafal Qaryah (Kami telah membinasakan mereka) di sini lebih diperhatikan makna yang terkandung pada lafal Qaryah yang pertama (maka tidak ada seorang penolong pun bagi mereka) dari kebinasaan yang Kami lakukan.\qt@no{13}}%
\qt@newcmd\qurantrans@id@mmmmdlix{%
(Maka apakah orang yang berpegang pada keterangan) yakni hujah dan argumentasi (yang datang dari Rabbnya) mereka adalah orang-orang mukmin (sama dengan orang yang dihiasi oleh keburukan amal perbuatannya) karena itu lalu ia memandangnya sebagai perbuatan yang baik, mereka adalah orang-orang kafir Mekah (dan mengikuti hawa nafsunya?) dalam menyembah berhala-berhala, maksudnya tentu saja tidak ada persamaan di antara keduanya.\qt@no{14}}%
\qt@newcmd\qurantrans@id@mmmmdlx{%
(Perumpamaan) gambaran tentang (surga yang dijanjikan kepada orang-orang yang bertakwa) dan yang menjadi milik bersama bagi orang-orang yang memasukinya. Lafal ayat ini menjadi Mubtada, sedangkan Khabarnya ialah (yang di dalamnya ada sungai-sungai dari air yang tiada berubah rasa dan baunya) dapat dibaca Aasinin atau Asinin, jika dibaca Aasinin wazannya sama dengan lafal Dhaaribin, jika dibaca Asinin Wazannya sama dengan lafal Hadzirun. Artinya, airnya tidak berubah atau tidak berbeda dengan air dunia yang dapat berubah karena ada sesuatu yang mencampurinya (sungai-sungai dari air susu yang tiada berubah rasanya) berbeda dengan air susu di dunia, karena air susu di dunia keluar dari susu (sungai-sungai dari khamar yang lezat rasanya) sangat lezat rasanya (bagi peminumnya) berbeda halnya dengan khamar di dunia, khamar dunia rasanya tidak enak bila diminum (dan sungai-sungai dari madu yang disaring) berbeda dengan madu di dunia, karena madu di dunia keluar dari perut tawon kemudian bercampur dengan lilin dan lain sebagainya (dan mereka memperoleh di dalamnya) berbagai macam jenis (dari aneka ragam buah-buahan, dan ampunan dari Rabb mereka) Rabb mereka rela terhadap mereka di samping kebaikan-Nya yang terus melimpah bagi mereka tanpa henti-hentinya, yaitu berupa kenikmatan-kenikmatan yang telah disebutkan tadi. Berbeda halnya dengan perihal seorang tuan atau pemilik hamba sahaya di dunia, karena sesungguhnya sekalipun majikan dari hamba sahaya itu berbuat baik kepadanya hal itu dibarengi dengan amarahnya, yakni terkadang sang majikan memarahinya (sama dengan orang yang kekal dalam neraka) lafal ayat ini menjadi Khabar dari Mubtada yang diperkirakan keberadaannya yakni, apakah orang yang berada dalam kenikmatan tersebut sama dengan orang yang kekal di dalam neraka (dan diberi minuman dengan air yang mendidih) yakni air yang sangat panas (sehingga memotong-motong ususnya?) artinya, minuman itu menghancurkan dan mencabik-cabik isi perutnya. Lafal Am'aa adalah bentuk jamak dari lafal Mi'a, sedangkan huruf Alifnya adalah ganti dari huruf Ya, karena sebagian dari mereka ada yang mengatakan Mi'yaani.\qt@no{15}}%
\qt@newcmd\qurantrans@id@mmmmdlxi{%
(Dan di antara mereka) orang-orang kafir itu (ada orang yang mendengarkan perkataanmu) sewaktu kamu berkhutbah Jumat, mereka adalah orang-orang munafik (sehingga apabila mereka keluar dari sisimu mereka berkata kepada orang-orang yang telah diberi ilmu pengetahuan) dari kalangan sahabat Nabi saw. antara lain adalah Ibnu Masud dan Ibnu Abbas r.a.; mereka mengatakan kepadanya dengan nada sinis dan mengejek, ("Apakah yang dikatakannya tadi?") dapat dibaca Aanifan atau Anifan, maksudnya kami kurang jelas. (Mereka itulah orang-orang yang dikunci mati hati mereka oleh Allah) dengan kekafiran (dan mengikuti hawa nafsu mereka) dalam kemunafikan.\qt@no{16}}%
\qt@newcmd\qurantrans@id@mmmmdlxii{%
(Dan orang-orang yang mendapat petunjuk) mereka adalah orang-orang mukmin (Dia menambah kepada mereka) yakni Allah swt. (petunjuk dan memberikan kepada mereka -balasan- ketakwaannya) maksudnya, Allah memberikan ilham kepada mereka untuk mengamalkan hal-hal yang dapat memelihara diri mereka dari neraka.\qt@no{17}}%
\qt@newcmd\qurantrans@id@mmmmdlxiii{%
(Maka tidaklah yang mereka tunggu-tunggu) maksudnya tiadalah yang ditunggu-tunggu, oleh orang-orang kafir Mekah (melainkan hari kiamat yaitu kedatangannya kepada mereka) lafal An Ta'tiyahum menjadi Badal Isytimal dari lafal As-Saa'ah; yakni, perkaranya tiada lain hanyalah menunggu kedatangan kiamat kepada mereka (dengan tiba-tiba) atau secara sekonyong-konyong (karena sesungguhnya telah datang tanda-tandanya) alamat-alamatnya, antara lain diutusnya Nabi saw., terbelahnya bulan dan munculnya Ad-Dukhaan. (Maka apabila ia datang kepada mereka apakah faedahnya) yang dimaksud adalah kedatangan hari kiamat (kesadaran mereka) keinsafan mereka, tidak ada manfaatnya lagi buat mereka.\qt@no{18}}%
\qt@newcmd\qurantrans@id@mmmmdlxiv{%
(Maka ketahuilah, bahwa sesungguhnya tidak ada Tuhan melainkan Allah) maksudnya, tetaplah engkau hai Muhammad pada prinsipmu yang demikian itu, karena itu bermanfaat kelak di hari kiamat (dan mohonlah ampunan bagi dosamu) yakni demi dosamu. Menurut suatu pendapat disebutkan, bahwa dikatakan demikian kepada Nabi Muhammad saw. dimaksud sebagai pelajaran buat umatnya, supaya mereka meniru jejaknya. Sedangkan bagi nabi dima'shum atau terpelihara dari perbuatan dosa. Memang Nabi saw. telah mengerjakan hal ini sebagaimana yang diungkapkan di dalam salah satu sabdanya yang mengatakan, ``Sesungguhnya aku selalu memohon ampun kepada Allah sebanyak seratus kali untuk setiap harinya." (dan bagi dosa orang-orang mukmin, laki-laki dan perempuan) di dalam ungkapan ayat ini terkandung penghormatan buat mereka, karena Allah swt. memerintahkan kepada nabi supaya memintakan ampun buat mereka. (Dan Allah mengetahui tempat kalian berusaha) tempat kalian bergerak di siang hari dalam rangka mencari upaya penghidupan (dan tempat tinggal kalian) maksudnya, tempat kalian beristirahat di tempat tidur kalian pada malam hari. Makna yang dimaksud ialah bahwa Allah swt. mengetahui semua hal ikhwal kalian, tiada sesuatu pun yang samar bagi-Nya, maka berhati-hatilah kalian kepada-Nya. Khitab dalam ayat ini ditujukan kepada orang-orang mukmin dan lain-lainnya.\qt@no{19}}%
\qt@newcmd\qurantrans@id@mmmmdlxv{%
(Dan orang-orang yang beriman berkata) dalam rangka meminta berjihad, ("Mengapa tidak) atau kenapa tidak (diturunkan suatu surah?") yang di dalamnya disebutkan masalah jihad. (Maka apabila diturunkan suatu surah yang muhkam) tiada suatu ayat pun darinya yang dimansukh (dan disebutkan di dalamnya perintah perang) anjuran untuk berperang bagi kalian (kalian lihat orang-orang yang di dalam hatinya ada penyakit) berupa keragu-raguan dalam memeluk agamamu, mereka adalah orang-orang munafik (melihat kepadamu dengan pandangan seperti orang yang pingsan) tidak sadarkan diri (karena takut mati) khawatir akan mati dan benci kepadanya; maksudnya mereka takut menghadapi peperangan dan sangat benci kepadanya. (Maka hal yang lebih utama bagi mereka) lafal ayat ini berkedudukan menjadi Mubtada, sedangkan Khabarnya ialah:\qt@no{20}}%
\qt@newcmd\qurantrans@id@mmmmdlxvi{%
(Adalah taat dan mengucapkan perkataan yang baik) artinya bersikap baik terhadapmu. (Apabila telah tetap perintah) maksudnya, perang telah difardukan. (Maka jika mereka menepati kepada Allah) dalam beriman dan taat kepada-Nya (niscaya yang demikian itu lebih baik bagi mereka) Jumlah yang jatuh sesudah Lau merupakan Jawab dari lafal Idzaa.\qt@no{21}}%
\qt@newcmd\qurantrans@id@mmmmdlxvii{%
(Maka apakah sekiranya) dapat dibaca `Asaitum atau `Asiitum, di dalam ungkapan ini terkandung ungkapan Iltifat dari Ghaibah kepada Mukhathab; maksudnya barangkali kalian (jika kalian berpaling) memalingkan diri dari iman (kalian akan membuat kerusakan di muka bumi dan memutuskan hubungan kekeluargaan) maksudnya, kalian akan kembali kepada akhlak jahiliyah, yaitu gemar mengadakan kerusakan dan peperangan.\qt@no{22}}%
\qt@newcmd\qurantrans@id@mmmmdlxviii{%
(Mereka itulah) yakni orang-orang yang merusak itu (orang-orang yang dilaknati Allah dan ditulikan-Nya telinga mereka) dari mendengarkan perkara yang hak (dan dibutakan-Nya mata mereka) dari jalan petunjuk.\qt@no{23}}%
\qt@newcmd\qurantrans@id@mmmmdlxix{%
(Maka apakah mereka tidak memperhatikan Alquran) yang dapat membimbing mereka untuk mengetahui perkara yang hak (ataukah) sebenarnya (pada hati) mereka (terdapat kuncinya) karena itu mereka tidak dapat memahami kebenaran.\qt@no{24}}%
\qt@newcmd\qurantrans@id@mmmmdlxx{%
(Sesungguhnya orang-orang yang kembali) karena nifaq (ke belakang sesudah petunjuk itu jelas bagi mereka, setan telah menjadikan mereka memandang baik) artinya, setan telah menghiasi mereka (dan memanjangkan angan-angan mereka) dapat dibaca Umlii atau Amlaa; yang memanjangkan angan-angan mereka adalah setan berdasarkan kehendak dari Allah swt. karena pada kenyataannya Dialah yang menyesatkan mereka.\qt@no{25}}%
\qt@newcmd\qurantrans@id@mmmmdlxxi{%
(Yang demikian itu) yakni kesesatan mereka itu (karena sesungguhnya mereka itu berkata kepada orang-orang yang benci kepada apa yang diturunkan Allah) yakni berkata kepada orang-orang musyrik, ("Kami akan mematuhi kalian dalam beberapa urusan") yaitu bersedia untuk membantu dalam memusuhi Nabi saw. dan menghasut kaum muslimin supaya mereka tidak mau berjihad bersamanya. Orang-orang munafik itu mengatakan demikian secara rahasia, akan tetapi kemudian Allah swt. menampakkannya (sedangkan Allah mengetahui rahasia mereka) kalau dibaca Asraarahum berarti bentuk jamak dari lafal Sirrun yang artinya rahasia, kalau dibaca Israarahum berarti Mashdar.\qt@no{26}}%
\qt@newcmd\qurantrans@id@mmmmdlxxii{%
(Bagaimanakah) keadaan mereka (apabila malaikat mencabut nyawa mereka seraya memukul) lafal Yadhribuuna merupakan Hal atau kata keterangan keadaan dari malaikat (muka dan punggung mereka) dengan pemukul-pemukul dari besi.\qt@no{27}}%
\qt@newcmd\qurantrans@id@mmmmdlxxiii{%
(Yang demikian itu) yakni, kematian mereka seperti yang telah disebutkan tadi (karena sesungguhnya mereka mengikuti apa yang menimbulkan kemurkaan Allah dan karena mereka membenci keridaan-Nya) artinya, mereka tidak mau mengamalkan hal-hal yang membuat keridaan-Nya (sebab itu Allah menghapus pahala amal-amal mereka.)\qt@no{28}}%
\qt@newcmd\qurantrans@id@mmmmdlxxiv{%
(Atau apakah orang-orang yang ada penyakit dalam kalbunya mengira bahwa Allah tidak akan menampakkan kedengkian mereka) kepada Nabi saw. dan orang-orang mukmin?\qt@no{29}}%
\qt@newcmd\qurantrans@id@mmmmdlxxv{%
(Dan kalau Kami menghendaki, niscaya Kami tunjukkan mereka kepadamu) atau Kami kenalkan mereka kepadamu, kemudian huruf Lam Taukid diulangi pada firman berikutnya (sehingga kamu benar-benar dapat mengenal mereka dengan tanda-tanda) berikut ciri-ciri khas mereka. (Dan sungguh kamu benar-benar akan mengenal mereka) huruf Wawu menunjukkan makna bagi Qasam atau sumpah yang tidak disebutkan, sedangkan lafal sesudahnya merupakan Jawabnya (dari kiasan-kiasan perkataan mereka) atau makna perkataan mereka, bilamana mereka berkata di hadapanmu mereka pasti menyindir dengan kata-kata yang mengandung hinaan terhadap perkara kaum muslimin (dan Allah mengetahui perbuatan-perbuatan kalian.)\qt@no{30}}%
\qt@newcmd\qurantrans@id@mmmmdlxxvi{%
(Dan sesungguhnya Kami benar-benar akan menguji kalian) mencoba kalian dengan berjihad dan lainnya (agar Kami mengetahui) dengan pengetahuan yang tampak (orang-orang yang berjihad dan bersabar di antara kalian) dalam berjihad dan lainnya (dan agar Kami menyatakan) menampakkan (hal ikhwal kalian) tentang ketaatan kalian dan kedurhakaan kalian di dalam masalah jihad dan masalah-masalah lainnya. Ketiga Fi'il yang ada dalam ayat ini, ketiga-tiganya dapat dibaca dengan memakai huruf Mudhara'ah Ya atau Nun.\qt@no{31}}%
\qt@newcmd\qurantrans@id@mmmmdlxxvii{%
(Sesungguhnya orang-orang kafir dan menghalang-halangi jalan Allah) jalan yang hak (dan memusuhi rasul) atau menentangnya (setelah petunjuk itu jelas bagi mereka) yang dimaksud petunjuk adalah jalan Allah tadi (mereka tidak dapat memberi mudarat kepada Allah sedikit pun. Dan Allah akan menghapuskan amal mereka) seperti sedekah dan lain-lainnya, yaitu pahalanya. Di akhirat kelak mereka tidak akan dapat melihat pahalanya. Ayat ini diturunkan berkenaan dengan orang-orang kafir yang terlibat dalam perang Badar, atau orang-orang kafir Bani Quraizhah dan Bani Nadhir.\qt@no{32}}%
\qt@newcmd\qurantrans@id@mmmmdlxxviii{%
(Hai orang-orang yang beriman! Taatlah kepada Allah dan taatlah kepada rasul dan janganlah kalian merusakkan amal-amal kalian) dengan melakukan perbuatan-perbuatan maksiat, umpamanya.\qt@no{33}}%
\qt@newcmd\qurantrans@id@mmmmdlxxix{%
(Sesungguhnya orang-orang yang kafir dan menghalangi jalan Allah) tuntunan-Nya, yaitu jalan petunjuk (kemudian mereka mati dalam keadaan kafir, maka sekali-kali Allah tidak akan memberi ampun kepada mereka) ayat ini diturunkan berkenaan dengan orang-orang kafir yang dikubur di Al-Qulaib, seusai perang Badar.\qt@no{34}}%
\qt@newcmd\qurantrans@id@mmmmdlxxx{%
(Janganlah kalian lemah) merasa lemah (dan minta damai) dapat dibaca As-Salmi atau As-Silmi, artinya damai bersama dengan orang-orang kafir bila kalian bertemu dengan mereka dalam perang (padahal kalianlah yang di atas) lafal Al-A'launa asalnya adalah Al-A'lawuuna, kemudian Wawu Lam Fi'ilnya dibuang sehingga jadilah Al-A'launa, artinya, yang menang dan yang mengalahkan (dan Allah pun beserta kalian) yakni bantuan dan pertolongan-Nya (dan Dia sekali-kali tidak akan mengurangi) Allah tidak akan mengurangi kalian (amal-amal kalian) pahala amal-amal kalian.\qt@no{35}}%
\qt@newcmd\qurantrans@id@mmmmdlxxxi{%
(Sesungguhnya kehidupan dunia) maksudnya, menyibukkan diri dalam kehidupan dunia (hanyalah permainan dan senda gurau. Dan jika kalian beriman serta bertakwa) kepada Allah, yang demikian itu adalah termasuk perkara akhirat (Allah akan memberikan pahala kepada kalian dan Dia tidak akan meminta harta-harta kalian) semuanya, melainkan hanya zakat yang diwajibkan.\qt@no{36}}%
\qt@newcmd\qurantrans@id@mmmmdlxxxii{%
(Jika Dia memintanya dari kalian lalu mendesak kalian) mendesak meminta zakat tersebut (niscaya kalian akan kikir dan keluarlah) karena kekikiran kalian (kedengkian kalian) terhadap agama Islam.\qt@no{37}}%
\qt@newcmd\qurantrans@id@mmmmdlxxxiii{%
(Ingatlah kalian) wahai, kalian ingatlah (kalian ini orang-orang yang diajak untuk menafkahkan harta kalian pada jalan Allah) maksudnya untuk menafkahkan apa yang telah diwajibkan atas kalian, yaitu zakat. (Maka di antara kalian ada orang yang kikir, dan siapa yang kikir sesungguhnya dia hanyalah kikir terhadap dirinya sendiri) lafal Bakhila dapat bermuta'addikan 'Ala atau 'An, untuk itu dapat dikatakan Rakhila 'Alaihi dan Bakhila 'Anhu. (Dan Allahlah Yang Maha Kaya) artinya, tidak membutuhkan infak kalian (sedangkan kalianlah orang-orang yang berhajat) kepada-Nya (dan jika kalian berpaling) dari taat kepada-Nya (niscaya Dia akan mengganti kalian dengan kaum yang lain) Dia akan menjadikan yang lain sebagai pengganti kalian (dan mereka tidak akan seperti kalian) tidak akan berpaling dari taat kepada-Nya, bahkan mereka benar-benar akan taat kepada-Nya.\qt@no{38}}%
\qt@newcmd\qurantrans@id@mmmmdlxxxiv{%
\basmalahid (Sesungguhnya Kami telah memberikan kemenangan kepadamu) maksudnya Kami telah memastikan kemenangan bagimu atas kota Mekah dan kota-kota lainnya di masa mendatang secara paksa melalui jihadmu (yaitu kemenangan yang nyata) artinya, kemenangan yang jelas dan nyata.\qt@no{1}}%
\qt@newcmd\qurantrans@id@mmmmdlxxxv{%
(Supaya Allah memberi ampunan kepadamu) berkat jihadmu itu (terhadap dosamu yang telah lalu dan yang akan datang) supaya umatmu mau berjihad karena akan mendapat ampunan seperti kamu. Pengertian ayat ini mengandung penakwilan, mengingat para nabi maksum dari segala perbuatan dosa yang hal ini telah ditetapkan berdasarkan dalil aqli dan naqli. Dengan demikian maka huruf Lam pada permulaan ayat ini menunjukkan makna Illatul Ghaaiyyah dan lafal yang dimasukinya merupakan Musabbab bukan Sebab (serta menyempurnakan) melalui kemenangan tersebut (nikmat-Nya) pemberian nikmat-Nya (atasmu dan memimpin kamu) melalui kemenangan itu (kepada jalan) yakni tuntunan (yang lurus) artinya Allah memantapkan kamu pada agama Islam.\qt@no{2}}%
\qt@newcmd\qurantrans@id@mmmmdlxxxvi{%
(Dan supaya Allah menolongmu) melalui agama Islam itu (dengan pertolongan yang mulia) tidak pernah hina atau pertolongan yang kuat dan tidak dapat dikalahkan.\qt@no{3}}%
\qt@newcmd\qurantrans@id@mmmmdlxxxvii{%
(Dialah yang telah menurunkan ketenangan) yakni ketenteraman (ke dalam kalbu orang-orang mukmin supaya keimanan mereka bertambah di samping keimanan mereka) kepada syariat-syariat agama, yaitu sewaktu turun salah satu daripadanya mereka langsung beriman antara lain ialah syariat berjihad. (Dan kepunyaan Allahlah tentara langit dan bumi) jika Dia menghendaki untuk menolong agama-Nya tanpa kalian, niscaya Dia dapat melakukannya (dan adalah Allah Maha Mengetahui) semua makhluk-Nya (lagi Maha Bijaksana) di dalam perbuatan-Nya, yakni Dia terus-menerus bersifat demikian.\qt@no{4}}%
\qt@newcmd\qurantrans@id@mmmmdlxxxviii{%
(Supaya Dia memasukkan) lafal Liyudkhila ini berta'alluq kepada lafal yang tidak disebutkan, yakni Dia memerintahkan berjihad supaya memasukkan (orang-orang mukmin laki-laki dan perempuan ke dalam surga yang mengalir di bawahnya sungai-sungai, mereka kekal di dalamnya dan supaya Dia menutupi kesalahan-kesalahan mereka. Dan yang demikian itu adalah keberuntungan yang besar di sisi Allah.)\qt@no{5}}%
\qt@newcmd\qurantrans@id@mmmmdlxxxix{%
(Dan supaya Dia mengazab orang-orang munafik laki-laki dan perempuan dan orang-orang musyrik laki-laki dan perempuan yang mereka itu berprasangka buruk terhadap Allah) dapat dibaca As-Sau' atau As-Suu' dan demikian pula pada ayat selanjutnya. Mereka berprasangka bahwa Allah pasti tidak akan menolong Nabi Muhammad saw. dan orang-orang mukmin. (Mereka akan mendapat giliran yang amat buruk) yaitu akan mendapatkan kehinaan dan azab (dan Allah memurkai mereka dan mengutuk mereka) artinya menjauhkan mereka dari rahmat-Nya (serta menyediakan bagi mereka neraka Jahanam. Dan neraka Jahanam itulah seburuk-buruk tempat kembali) tempat kembali yang paling buruk.\qt@no{6}}%
\qt@newcmd\qurantrans@id@mmmmdxc{%
(Dan kepunyaan Allahlah tentara langit dan bumi. Dan adalah Allah Maha Perkasa) di dalam kerajaan-Nya (lagi Maha Bijaksana) di dalam perbuatan-Nya, yakni Dia terus-menerus bersifat demikian.\qt@no{7}}%
\qt@newcmd\qurantrans@id@mmmmdxci{%
(Sesungguhnya Kami mengutus kamu sebagai saksi) atas umatmu pada hari kiamat nanti (dan pembawa berita gembira) kepada mereka di dunia (dan pemberi peringatan) maksudnya memberi peringatan dan mempertakuti mereka selama di dunia akan siksa neraka kelak di akhirat bila mereka melakukan perbuatan yang berdosa.\qt@no{8}}%
\qt@newcmd\qurantrans@id@mmmmdxcii{%
(Supaya kamu sekalian beriman kepada Allah dan Rasul-Nya) lafal Litu`minuu dapat dibaca Liyu`minuu, demikian pula pada tiga tempat lainnya dalam ayat ini, sesudahnya (menguatkan agama-Nya) maksudnya supaya kalian menolong agama-Nya; dan menurut suatu qiraat lafal Tu'azziruuhu dibaca Tu'azzizuuhu (membesarkan-Nya) artinya supaya kalian mengagungkan-Nya, Dhamir pada kedua fi'il tersebut dapat merujuk, kepada Allah atau Rasul-Nya (dan supaya kalian bertasbih kepada-Nya) yakni kepada Allah (di waktu pagi dan petang) pada setiap pagi dan sore.\qt@no{9}}%
\qt@newcmd\qurantrans@id@mmmmdxciii{%
(Sesungguhnya orang-orang yang berjanji setia kepada kamu) yaitu melakukan baiat Ridwan di Hudaibiah (sesungguhnya mereka berjanji setia kepada Allah) pengertian ini sama dengan makna yang terkandung dalam ayat lainnya, yaitu firman-Nya, ``Barang siapa yang menaati rasul, sesungguhnya ia telah menaati Allah." (Q.S. An-Nisa, 80). (Tangan kekuasaan Allah berada di atas tangan mereka) yang berbaiat kepada Nabi saw. Maksudnya, bahwa Allah swt. menyaksikan pembaiatan mereka, maka Dia kelak akan memberikan balasan pahala-Nya kepada mereka (maka barang siapa yang melanggar janjinya) yakni merusak baiatnya (maka sesungguhnya ia hanya melanggar) karena itu akibat dari pelanggarannya akan menimpa (dirinya sendiri dan barang siapa menepati janjinya kepada Allah maka Allah akan memberinya) dapat dibaca Fasaya`tiihi atau Fasanu`tiihi, kalau dibaca Fasanu`tihi artinya, Kami akan memberinya (pahala yang besar.)\qt@no{10}}%
\qt@newcmd\qurantrans@id@mmmmdxciv{%
(Orang-orang Badui yang tertinggal akan mengatakan) yang dimaksud adalah mereka yang tinggal di sekitar kota Madinah yang tidak mau ikut dengan kamu sewaktu kamu meminta mereka supaya berangkat bersamamu ke Mekah pada tahun perjanjian Hudaibiah karena merasa takut orang-orang Quraisy nanti akan mencegatmu. Mereka akan mengatakan sekembalimu dari Mekah, ("Harta dan keluarga kami telah merintangi kami) sehingga kami tidak dapat keluar untuk berangkat bersamamu (maka mohonkanlah ampunan untuk kami") kepada Allah, karena kami tidak dapat ikut keluar bersamamu. Lalu Allah menjawab kepada mereka seraya mendustakan alasan mereka itu melalui firman selanjutnya, ("Mereka mengucapkan dengan lidahnya) yaitu meminta untuk memohonkan ampunan buat mereka dan perkataan mereka yang lainnya sebelum itu (apa yang tidak ada dalam hatinya) karena mereka adalah orang-orang yang berdusta di dalam alasannya. (Katakanlah, ``Maka siapakah) Istifham atau kata tanya di sini mengandung makna negatif, yakni tidak ada seorang pun (yang dapat menghalang-halangi kehendak Allah jika Dia menghendaki kemudaratan bagi kalian) dapat dibaca Dharran atau Dhurran (atau jika Dia menghendaki manfaat bagi kalian." Sebenarnya Allah Maha Mengetahui apa yang kalian kerjakan) artinya Dia terus-menerus bersifat demikian.\qt@no{11}}%
\qt@newcmd\qurantrans@id@mmmmdxcv{%
(Tetapi) lafal Bal pada kedua tempat, yakni pada ayat ini dan ayat sebelumnya, menunjukkan makna Intiqal atau perpindahan dari suatu pembahasan kepada pembahasan yang lain (kalian menyangka bahwa rasul dan orang-orang mukmin tidak sekali-kali akan kembali kepada keluarganya untuk selama-lamanya dan hal tersebut dipandang baik menurut hati kalian) yakni bahwa mereka mengharapkan supaya rasul dan orang-orang mukmin tertumpas habis sehingga mereka tidak kembali lagi ke Madinah (dan kalian telah menyangka dengan sangkaan-sangkaan yang buruk) yakni sangkaan seperti ini dan sangkaan-sangkaan yang buruk lainnya (dan kalian menjadi kaum yang binasa) lafal Buura adalah bentuk jamak dari lafal Baairun, yakni binasa menurut Allah dengan berprasangka seperti itu.\qt@no{12}}%
\qt@newcmd\qurantrans@id@mmmmdxcvi{%
(Dan barang siapa yang tidak beriman kepada Allah dan rasul-Nya maka sesungguhnya Kami menyediakan untuk orang-orang kafir neraka yang menyala-nyala) neraka yang apinya sangat besar nyalanya.\qt@no{13}}%
\qt@newcmd\qurantrans@id@mmmmdxcvii{%
(Dan hanya kepunyaan Allahlah kerajaan langit dan bumi, Dia memberi ampun kepada siapa yang dikehendaki-Nya dan mengazab siapa yang dikehendaki-Nya Dan adalah Allah Maha Pengampun lagi Maha Penyayang") Dia terus menerus bersifat demikian.\qt@no{14}}%
\qt@newcmd\qurantrans@id@mmmmdxcviii{%
(Orang-orang yang tertinggal itu akan berkata) yakni mereka yang telah disebutkan tadi (apabila kalian berangkat menuju tempat barang rampasan) yang dimaksud adalah ganimah perang Khaibar (untuk mengambilnya, ``Biarkanlah kami) maksudnya janganlah kalian halangi kami (mengikuti kalian") supaya kami dapat mengambil sebagian dari ganimah tersebut (mereka bermaksud) dengan sikap mereka yang demikian itu (hendak merubah keputusan Allah) menurut suatu qiraat dibaca Kalimullah artinya, janji atau ancaman-Nya. Maksudnya, mereka mengubah ancaman Allah dengan ganimah Khaibar yang khusus hanya untuk mereka yang ikut dalam baiat Ridwan di Hudaibiyah. (Katakanlah, ``Kalian sekali-kali tidak boleh mengikuti kami; demikian Allah telah menetapkan sebelumnya") sebelum kami kembali (mereka akan mengatakan, ``Sebenarnya kalian dengki kepada kami") bila kami ikut memperoleh ganimah bersama kalian, karena bagian kalian akan berkurang jadinya. (Bahkan mereka tidak mengerti) masalah agama (melainkan sedikit sekali) dari kalangan mereka yang mengerti tentangnya.\qt@no{15}}%
\qt@newcmd\qurantrans@id@mmmmdxcix{%
(Katakanlah kepada orang-orang Badui yang tertinggal,) yakni orang-orang Badui yang tertinggal tadi sebagai cobaan buat mereka ("Kalian akan diajak untuk memerangi kaum yang mempunyai) kaum yang memiliki (kekuatan yang besar) menurut suatu pendapat dikatakan, bahwa yang dimaksud adalah menghadapi orang-orang Bani Hanifah yang menguasai tanah Yamamah, dan menurut pendapat yang lain lagi, yang dimaksud adalah kerajaan Persia dan kerajaan Romawi (kalian akan memerangi mereka) lafal ayat ini menjadi Hal atau kata keterangan keadaan bagi lafal yang diperkirakan keberadaannya, yaitu kaum yang dimaksud tadi (atau) mereka (menyerah) karena itu maka kalian tidak berperang lagi. (Maka jika kalian patuhi) ajakan untuk memerangi mereka itu (niscaya Allah akan memberikan kepada kalian pahala yang baik dan jika kalian berpaling sebagaimana kalian telah berpaling sebelumnya, niscaya Dia akan mengazab kalian dengan azab yang pedih") azab yang menyakitkan.\qt@no{16}}%
\qt@newcmd\qurantrans@id@mmmmdc{%
(Tiada dosa atas orang-orang yang buta dan atas orang yang pincang dan atas orang yang sakit) apabila tidak ikut berjihad. (Dan barang siapa yang taat kepada Allah dan Rasul-Nya, niscaya Allah akan memasukkannya) dapat dibaca Yudkhilhu atau Nudkhilhu, kalau dibaca Nudkhilhu artinya, niscaya Kami akan memasukkannya (ke dalam surga yang mengalir di bawahnya sungai-sungai dan barang siapa yang berpaling niscaya akan diazab-Nya) dapat dibaca Yu'adzdzibhu atau Nu'adzdzibhu, kalau dibaca Nu'adzdzibhu artinya, niscaya Kami akan mengazabnya (dengan azab yang pedih.)\qt@no{17}}%
\qt@newcmd\qurantrans@id@mmmmdci{%
(Sesungguhnya Allah telah rida terhadap orang-orang mukmin ketika mereka berjanji setia kepadamu) di Hudaibiyah (di bawah pohon) yaitu pohon Samurah, jumlah mereka yang menyatakan baiat itu ada seribu tiga ratus orang atau lebih. Kemudian mereka berbaiat kepada Nabi saw. yaitu hendaknya mereka saling bahu-membahu melawan orang-orang Quraisy dan janganlah mereka lari karena takut mati (maka Dia mengetahui) yakni Allah mengetahui (apa yang ada dalam hati mereka) yaitu kejujuran dan kesetiaan mereka (lalu menurunkan ketenangan atas mereka dan memberi balasan kepada mereka dengan kemenangan yang dekat waktunya) yaitu takluknya tanah Khaibar sesudah mereka kembali dari Hudaibiyah.\qt@no{18}}%
\qt@newcmd\qurantrans@id@mmmmdcii{%
(Serta harta rampasan yang banyak yang dapat mereka ambil) dari tanah Khaibar. (Dan adalah Allah Maha Perkasa lagi Maha Bijaksana) Dia terus-menerus bersifat demikian.\qt@no{19}}%
\qt@newcmd\qurantrans@id@mmmmdciii{%
(Allah menjanjikan kepada kalian harta rampasan yang banyak yang dapat kalian ambil) dari penaklukan-penaklukan (maka disegerakan-Nya harta rampasan ini untuk kalian) yang dimaksud adalah harta rampasan tanah Khaibar (dan Dia menahan tangan manusia dari kalian) yakni ulah mereka terhadap anak-anak dan istri-istri kalian sewaktu kalian berangkat berperang dan memang orang-orang Yahudi, sewaktu kalian keluar bermaksud untuk membinasakan mereka, akan tetapi Allah melemparkan ke dalam hati mereka rasa takut sehingga mereka tidak berani melakukannya (dan agar hal itu) yakni harta rampasan yang disegerakan itu; lafal ayat ini diathafkan kepada lafal yang diperkirakan keberadaannya; yaitu lafal Litasykuruuhu yang artinya, supaya kalian bersyukur kepada-Nya (menjadi bukti bagi orang-orang mukmin) yang menunjukkan bahwa mereka mendapat pertolongan dari Allah (dan agar Dia menunjuki kalian kepada jalan yang lurus) yakni jalan untuk bertawakal dan menyerahkan segala sesuatu kepada Allah swt.\qt@no{20}}%
\qt@newcmd\qurantrans@id@mmmmdciv{%
(Dan harta-harta rampasan yang lain) lafal Ukhraa ini menjadi Sifat dari lafal yang diperkirakan keberadaannya yaitu Maghaanima yang berkedudukan menjadi Mubtada (yang kalian belum dapat menguasainya) yaitu harta rampasan dari negeri Persia dan negeri Romawi (yang sungguh Allah telah meliputinya) dengan ilmu-Nya bahwa semuanya kelak akan kalian raih. (Dan adalah Allah Maha Kuasa atas segala sesuatu) yakni Dia terus menerus bersifat demikian.\qt@no{21}}%
\qt@newcmd\qurantrans@id@mmmmdcv{%
(Dan sekiranya orang-orang kafir itu memerangi kalian) sewaktu kalian di Hudaibiah (pastilah mereka berbalik melarikan diri ke belakang, kemudian mereka tiada memperoleh pelindung) yang dapat memelihara dan menjaga mereka (dan tidak pula penolong.)\qt@no{22}}%
\qt@newcmd\qurantrans@id@mmmmdcvi{%
(Sebagai suatu sunatullah) lafal ayat ini adalah Mashdar yang berfungsi mengukuhkan makna jumlah kalimat sebelumnya, yaitu mengenai kalahnya orang-orang kafir dan ditolong-Nya orang-orang mukmin. Maksudnya yang demikian itu merupakan suatu sunatullah (yang telah berlaku sejak dahulu, kamu sekali-kali tidak akan menemukan perubahan bagi sunatullah itu) sebagai ganti darinya.\qt@no{23}}%
\qt@newcmd\qurantrans@id@mmmmdcvii{%
(Dan Dialah yang menahan tangan mereka dari kalian dan tangan kalian dari mereka di lembah Mekah) yakni di Hudaibiah (sesudah Allah memenangkan kalian atas mereka) karena sesungguhnya delapan puluh orang lelaki dari kalangan mereka mengelilingi perkemahan kalian dengan tujuan untuk menyergap kalian, tetapi akhirnya mereka dapat dilumpuhkan dan mereka dihadapkan kepada Rasulullah saw. maka ia memberi maaf kepada mereka lalu dilepaskannya mereka dengan bebas. Hal ini merupakan penyebab adanya perjanjian gencatan senjata (dan adalah Allah Maha Melihat apa yang kalian kerjakan.) Lafal Ta'maluuna dapat dibaca Ya'maluuna, kalau dibaca Ya'maluuna maka artinya, ``Dan adalah Allah Maha Melihat apa yang mereka kerjakan." Maksud ungkapan ayat ini ialah bahwa Allah masih tetap bersifat demikian.\qt@no{24}}%
\qt@newcmd\qurantrans@id@mmmmdcviii{%
(Merekalah orang-orang yang kafir yang menghalangi kalian dari Masjidilharam) yakni menghalangi kalian untuk memasukinya (dan hewan kurban) diathafkan kepada Dhamir Kum yang ada pada lafal Washadduukum (dalam keadaan tertahan) yakni terhenti, lafal ini menjadi Hal atau kata keterangan keadaan (tidak dapat mencapai tempatnya) yaitu tempat penyembelihannya sebagaimana biasanya, lafal ayat ini berkedudukan menjadi Badal Isytimal. (Dan kalau tidaklah karena laki-laki yang mukmin dan perempuan-perempuan yang mukmin) yang masih ada tinggal bersama dengan orang-orang kafir di Mekah (yang tiada kalian ketahui) keimanan mereka (bahwa kalian akan membunuh mereka) kalian akan membunuh mereka bersama dengan orang-orang kafir, sekiranya kalian diizinkan-Nya untuk melakukan penaklukan. Lafal ayat ini menjadi Badal Isytimal dari Dhamir Hum yang terdapat pada lafal Lam Ta'lamuuhum (yang menyebabkan kalian berdosa) yakni perbuatan yang berdosa (tanpa pengetahuan) kalian tentangnya. Semua Dhamir Ghaibah yang ada menunjukkan makna untuk kedua jenis, yaitu jenis lelaki dan perempuan, hal tersebut hanya memprioritaskan Mudzakkar. Jawab dari lafal Laulaa tidak disebutkan, yakni tentulah Allah mengizinkan kalian untuk melakukan penaklukan, tetapi ketika itu Dia ternyata tidak mengizinkan kalian melakukan hal itu. (Supaya Allah memasukkan siapa yang dikehendaki-Nya ke dalam rahmat-Nya) seperti orang-orang mukmin yang telah disebutkan tadi. (Sekiranya mereka tidak bercampur-baur) seandainya mereka membedakan dari orang-orang kafir (tentulah Kami akan mengazab orang-orang kafir di antara mereka) yakni di antara penduduk Mekah pada saat itu juga, seumpamanya Kami memberikan izin kepada kalian untuk melakukan penaklukan (dengan azab yang pedih) azab yang menyakitkan.\qt@no{25}}%
\qt@newcmd\qurantrans@id@mmmmdcix{%
(Ketika menanamkan) berta'alluq kepada lafal La'adzdzabnaa (orang-orang kafir itu) menjadi Fa'il dari lafal Ja'ala (ke dalam hati mereka kesombongan) perasaan tinggi diri dari sesuatu (yaitu kesombongan jahiliah) menjadi Badal dari lafal Hamiyah. Makna yang dimaksud ialah hambatan dan cegahan mereka terhadap Nabi dan para sahabatnya untuk mencapai Masjidilharam (lalu Allah menurunkan ketenangan kepada Rasul-Nya dan kepada orang-orang mukmin) lalu akhirnya Nabi saw. dan para sahabatnya mengadakan perdamaian dengan mereka, yaitu hendaknya mereka diperbolehkan kembali ke Mekah tahun depan dan ternyata mereka tidak terbakar atau terpancing oleh panasnya perasaan, tidak sebagaimana yang menimpa orang-orang kafir, akhirnya peperangan antara mereka terhindarkan (dan Allah mewajibkan kepada mereka) yakni kepada orang-orang mukmin (kalimat takwa) yaitu ``Tiada Tuhan selain Allah dan Muhammad utusan Allah", kalimat ini dikaitkan dengan takwa, karena merupakan penyebabnya (dan adalah mereka lebih berhak dengannya) yakni dengan kalimat takwa itu daripada orang-orang kafir (dan patut memilikinya) merupakan Athaf Tafsir. (Dan adalah Allah Maha Mengetahui segala sesuatu) artinya Dia tetap bersifat demikian, dan di antara apa yang diketahui oleh Allah swt. ialah bahwa orang-orang mukmin itu berhak memiliki kalimat takwa itu.\qt@no{26}}%
\qt@newcmd\qurantrans@id@mmmmdcx{%
(Sesungguhnya Allah akan membuktikan kepada Rasul-Nya tentang kebenaran mimpinya dengan sebenarnya) Rasulullah saw. bermimpi pada tahun terjadinya perjanjian Hudaibiah, yaitu sebelum beliau berangkat menuju ke Hudaibiah, bahwasanya ia memasuki kota Mekah bersama-sama dengan para sahabatnya dalam keadaan aman hingga mereka dapat bercukur dan ada pula yang hanya memendekkan rambutnya. Kemudian Rasulullah saw. menceritakan hal mimpinya itu kepada para sahabatnya, maka mereka sangat gembira mendengarnya. Ketika para sahabat berangkat bersama Rasulullah menuju Mekah, tiba-tiba mereka dihalang-halangi oleh orang-orang kafir sewaktu mereka sampai di Hudaibiah. Akhirnya mereka kembali ke Madinah dengan perasaan yang berat, pada saat itu timbullah rasa keraguan di dalam hati sebagian orang-orang munafik, lalu turunlah ayat ini. Firman-Nya, ``Bil haqqi" berta'alluq kepada lafal Shadaqa, atau merupakan Hal atau kata keterangan keadaan dari lafal Ar-Ru'yaa sedangkan kalimat sesudahnya berfungsi menjadi penafsirnya (yaitu bahwa sesungguhnya kamu sekalian pasti akan memasuki Masjidilharam, insya Allah) lafal Insya Allah artinya, jika Allah menghendaki, hanyalah sebagai kalimat Tabarruk saja, yaitu untuk meminta keberkahan (dalam keadaan aman dengan mencukur rambut kepala) mencukur semua rambut kepala (dan mengguntingnya) yakni menggunting sebagiannya saja; kedua lafal ini merupakan Hal bagi lafal yang diperkirakan keberadaannya (sedangkan kalian tidak merasa takut) selama-lamanya (Maka Allah mengetahui) di dalam perjanjian damai itu (apa yang tidak kalian ketahui) mengenai kemaslahatan yang terkandung di dalamnya (dan Dia memberikan sebelum itu) sebelum kalian memasuki Mekah (kemenangan yang dekat) yaitu ditaklukkannya tanah Khaibar, kemudian mimpi itu menjadi kenyataan pada tahun berikutnya.\qt@no{27}}%
\qt@newcmd\qurantrans@id@mmmmdcxi{%
(Dialah yang mengutus Rasul-Nya dengan membawa petunjuk dan agama yang hak agar dimenangkan-Nya) agama yang hak itu (terhadap semua agama) atas agama-agama yang lainnya. (Dan cukuplah Allah sebagai saksi) bahwasanya kamu diutus untuk membawa hal tersebut, sebagaimana yang diungkapkan-Nya pada ayat berikut ini.\qt@no{28}}%
\qt@newcmd\qurantrans@id@mmmmdcxii{%
(Muhammad itu) lafal ayat ini berkedudukan menjadi Mubtada (adalah utusan Allah) menjadi Khabar dari Mubtada (dan orang-orang yang bersama dengan dia) yakni para sahabatnya yang terdiri dari kaum mukminin. Lafal ayat ini menjadi Mubtada sedangkan Khabarnya ialah (adalah keras) yakni mereka adalah orang-orang yang bersikap keras (terhadap orang-orang kafir) mereka tidak mengasihaninya (tetapi berkasih sayang sesama mereka) menjadi Khabar yang kedua; yakni mereka saling kasih-mengasihi di antara sesama mukmin bagaikan kasih orang tua kepada anaknya (kamu lihat mereka) kamu perhatikan mereka (rukuk dan sujud) keduanya merupakan Hal atau kata keterangan keadaan (mencari) lafal ayat ini merupakan jumlah Isti`naf, yakni mereka melakukan demikian dalam rangka mencari (karunia Allah dan keridaan-Nya, tanda-tanda mereka) ciri-ciri mereka, lafal ayat ini menjadi Mubtada (tampak pada muka mereka) menjadi Khabar dari Mubtada. Tanda-tanda tersebut berupa nur dan sinar yang putih bersih yang menjadi ciri khas mereka kelak di akhirat, sebagai pertanda bahwa mereka orang-orang yang gemar bersujud sewaktu di dunia (dari bekas sujud.) Lafal ayat ini berta'alluq kepada lafal yang menjadi Ta'alluq atau gantungan bagi Khabar, yaitu lafal Kaainatan. Kemudian dii'rabkan sebagai Hal karena mengingat Dhamirnya yang dipindahkan kepada Khabar. (Demikianlah) sifat-sifat yang telah disebutkan tadi (sifat-sifat mereka) yakni gambaran tentang mereka, kalimat ayat ini menjadi Mubtada (di dalam kitab Taurat) menjadi Khabarnya (dan sifat-sifat mereka dalam kitab Injil) menjadi Mubtada, sedangkan Khabarnya adalah (yaitu seperti tanaman yang mengeluarkan tunasnya) dapat dibaca Syath`ahu atau Syatha`ahu, yakni tunasnya (maka tunas itu menjadikan tanaman itu kuat) dapat dibaca Fa`aazarahuu atau Fa`azarahu, yakni tunas itu membuat tanaman menjadi kuat (lalu menjadi besarlah dia) membesarlah dia (dan tegak lurus) yakni kuat dan tegak lurus (di atas pokoknya) lafal Suuq ini adalah bentuk jamak dari lafal Saaqun (tanaman itu menyenangkan hati penanam-penanamnya) karena keindahannya. Perumpamaan ini merupakan gambaran tentang keadaan para sahabat karena mereka pada mulanya berjumlah sedikit lagi masih lemah, kemudian jumlah mereka makin bertambah banyak dan bertambah kuat dengan sistem yang sangat rapi (karena Allah hendak menjengkelkan hati orang-orang kafir dengan kekuatan orang-orang mukmin) lafal ayat ini berta'alluq kepada lafal yang tidak disebutkan yang disimpulkan dari kalimat sebelumnya, yakni mereka diserupakan demikian karena Allah hendak menjengkelkan hati orang-orang kafir (Allah menjanjikan kepada orang-orang yang beriman dan mengerjakan amal yang saleh dari kalangan mereka) yakni para sahabat; huruf Min di sini menunjukkan makna Bayanul Jinsi atau untuk menjelaskan jenis, bukan untuk menunjukkan makna Tab'idh atau sebagian, demikian itu karena para sahabat semuanya memiliki sifat-sifat tersebut (ampunan dan pahala yang besar) yakni surga; kedua pahala itu berlaku pula bagi orang-orang sesudah mereka, sebagaimana yang telah dijelaskan dalam berbagai ayat lainnya\qt@no{29}}%
\qt@newcmd\qurantrans@id@mmmmdcxiii{%
\basmalahid (Hai orang-orang yang beriman, janganlah kalian mendahului) berasal dari lafal Qadima yang maknanya sama dengan lafal Taqaddama artinya, janganlah kalian mendahului baik melalui perkataan atau perbuatan kalian (di hadapan Allah dan Rasul-Nya) yang menyampaikan wahyu dari-Nya, makna yang dimaksud ialah janganlah kalian mendahului Allah dan Rasul-Nya tanpa izin dari keduanya (dan bertakwalah kepada Allah. Sesungguhnya Allah Maha Mendengar) semua perkataan kalian (lagi Maha Mengetahui) semua perbuatan kalian. Ayat ini diturunkan berkenaan dengan perdebatan antara Abu Bakar r.a., dan sahabat Umar r.a. Mereka berdua melakukan perdebatan di hadapan Nabi saw. mengenai pengangkatan Aqra' bin Habis atau Qa'qa' bin Ma'bad. Ayat selanjutnya diturunkan berkenaan dengan orang yang mengangkat suaranya keras-keras di hadapan Nabi saw. yaitu firman-Nya:\qt@no{1}}%
\qt@newcmd\qurantrans@id@mmmmdcxiv{%
("Hai orang-orang beriman janganlah kalian meninggikan suara kalian) bila kalian berbicara (lebih dari suara Nabi) bila ia berbicara (dan janganlah kalian berkata kepadanya dengan suara keras) bila kalian berbicara dengannya (sebagaimana kerasnya suara sebagian kalian terhadap sebagian yang lain) tetapi rendahkanlah suara kalian di bawah suaranya demi untuk menghormati dan mengagungkannya (supaya tidak dihapus pahala amal kalian sedangkan kalian tidak menyadarinya") maksudnya, takutlah kalian akan hal tersebut disebabkan suara kalian yang tinggi dan keras di hadapannya. Ayat berikutnya diturunkan berkenaan dengan orang-orang yang merendahkan suaranya di hadapan Nabi saw.\qt@no{2}}%
\qt@newcmd\qurantrans@id@mmmmdcxv{%
("Sesungguhnya orang-orang yang merendahkan suaranya di sisi Rasulullah, mereka itulah orang-orang yang telah diuji) dicoba (hati mereka oleh Allah untuk bertakwa) artinya, ujian untuk menampakkan ketakwaan mereka. (Bagi mereka ampunan dan pahala yang besar") yakni surga. Ayat berikutnya diturunkan berkenaan dengan orang-orang yang datang di waktu tengah hari kepada Nabi saw. sedangkan Nabi saw. pada saat itu berada di dalam rumahnya, lalu mereka memanggil-manggilnya, yaitu firman-Nya:\qt@no{3}}%
\qt@newcmd\qurantrans@id@mmmmdcxvi{%
("Sesungguhnya orang-orang yang memanggil kamu dari luar kamar) yakni dari luar kamar istri-istrinya. Lafal Hujuraat bentuk jamak dari lafal Hujratun, yang artinya; sepetak tanah yang dikelilingi oleh tembok atau lainnya, yang digunakan sebagai tempat tinggal. Masing-masing di antara mereka memanggil Nabi saw. dari belakang kamar-kamarnya, karena mereka tidak mengetahui di kamar manakah Nabi saw. berada. Mereka memanggilnya dengan suara yang biasa dilakukan oleh orang-orang Arab Badui, yaitu dengan suara yang keras dan kasar (kebanyakan mereka tidak mengerti) tentang apa yang harus mereka kerjakan di dalam menghadapi kedudukanmu yang tinggi, dan sikap penghormatan manakah yang pantas mereka lakukan untukmu.\qt@no{4}}%
\qt@newcmd\qurantrans@id@mmmmdcxvii{%
(Dan kalau sekiranya mereka bersabar) lafal Annahum berada dalam Mahall Rafa' sebagai Mubtada. Tetapi menurut pendapat lain menjadi Fa'il dari Fi'il yang diperkirakan keberadaannya, yaitu lafal Tsabata (sampai kamu keluar menemui mereka, sesungguhnya itu adalah lebih baik bagi mereka, dan Allah Maha Pengampun lagi Maha Penyayang") kepada orang yang bertobat di antara mereka. Ayat berikut ini diturunkan berkenaan dengan Walid bin Uqbah. Ia telah diutus oleh Nabi saw. ke Bani Mushthaliq untuk menarik zakat, tetapi ia merasa takut terhadap mereka, karena dahulu di masa jahiliah ia bermusuhan dengan mereka. Akhirnya di tengah perjalanan ia kembali lagi seraya melaporkan, bahwa mereka tidak mau membayar zakat dan bahkan mereka hampir saja membunuhnya. Karena itu hampir saja Nabi saw. bermaksud untuk memerangi mereka, hanya karena mereka keburu datang menghadap Nabi saw. seraya mengingkari apa yang telah dikatakan oleh Walid mengenai mereka.\qt@no{5}}%
\qt@newcmd\qurantrans@id@mmmmdcxviii{%
(Hai orang-orang yang beriman! Jika datang kepada kalian orang fasik membawa suatu berita) (maka periksalah oleh kalian) kebenaran beritanya itu, apakah ia benar atau berdusta. Menurut suatu qiraat dibaca Fatatsabbatuu berasal dari lafal Ats-Tsabaat, artinya telitilah terlebih dahulu kebenarannya (agar kalian tidak menimpakan musibah kepada suatu kaum) menjadi Maf'ul dari lafal Fatabayyanuu, yakni dikhawatirkan hal tersebut akan menimpa musibah kepada suatu kaum (tanpa mengetahui keadaannya) menjadi Hal atau kata keterangan keadaan dari Fa'il, yakni tanpa sepengetahuannya (yang menyebabkan kalian) membuat kalian (atas perbuatan kalian itu) yakni berbuat kekeliruan terhadap kaum tersebut (menyesal) selanjutnya Rasulullah saw. mengutus Khalid kepada mereka sesudah mereka kembali ke negerinya. Ternyata Khalid tiada menjumpai mereka melainkan hanya ketaatan dan kebaikan belaka, lalu ia menceritakan hal tersebut kepada Nabi saw.\qt@no{6}}%
\qt@newcmd\qurantrans@id@mmmmdcxix{%
(Dan ketahuilah oleh kamu sekalian bahwa di kalangan kalian ada Rasulullah) maka janganlah sekali-kali kalian mengatakan hal-hal yang batil, karena sesungguhnya Allah akan memberitahukannya seketika itu juga. (Kalau ia menuruti kemauan kalian dalam banyak urusan) yang kalian beritakan tidak sesuai dengan kenyataannya, oleh karena itu maka hasilnya sesuai dengan apa yang kalian beritakan itu (niscaya kalian akan mendapat dosa) yakni benar-benar kalian mendapat dosa karena hal itu, yaitu dosa memberikan keterangan yang palsu (tetapi Allah menjadikan kalian cinta kepada keimanan dan menjadikan iman itu indah) yakni dipandang baik (dalam hati kalian serta menjadikan kalian benci kepada kekafiran, kefasikan dan kedurhakaan) pengertian Istidrak yang dikandung oleh lafal Laakin dipandang dari segi makna bukan lafalnya, karena sesungguhnya orang yang cinta kepada keimanan memiliki sifat-sifat berbeda dengan sifat-sifat yang dimiliki oleh orang-orang yang telah disebutkan tadi. (Mereka itulah) di dalam ungkapan ini terkandung iltifat dari Mukhathab (orang-orang yang mengikuti jalan yang lurus) yakni orang-orang yang teguh dalam agamanya.\qt@no{7}}%
\qt@newcmd\qurantrans@id@mmmmdcxx{%
(Sebagai karunia dari Allah) lafal Fadhlan adalah Mashdar yang dinashabkan oleh Fi'ilnya yang keberadaannya diperkirakan sebelumnya, yaitu lafal Afdhala (dan nikmat) dari-Nya. (Dan Allah Maha Mengetahui) keadaan mereka (lagi Maha Bijaksana) di dalam memberikan nikmat-Nya kepada mereka.\qt@no{8}}%
\qt@newcmd\qurantrans@id@mmmmdcxxi{%
(Dan jika ada dua golongan dari orang-orang mukmin) hingga akhir ayat. Ayat ini diturunkan berkenaan dengan suatu masalah, yaitu bahwa Nabi saw. pada suatu hari menaiki keledai kendaraannya, lalu ia melewati Ibnu Ubay. Ketika melewatinya tiba-tiba keledai yang dinaikinya itu kencing, lalu Ibnu Ubay menutup hidungnya, maka berkatalah Ibnu Rawwahah kepadanya, ``Demi Allah, sungguh bau kencing keledainya jauh lebih wangi daripada bau minyak kesturimu itu," maka terjadilah antara kaum mereka berdua saling baku hantam dengan tangan, terompah dan pelepah kurma (berperang) Dhamir yang ada pada ayat ini dijamakkan karena memandang dari segi makna yang dikandung lafal Thaaifataani, karena masing-masing Thaaifah atau golongan terdiri dari sekelompok orang. Menurut suatu qiraat ada pula yang membacanya Iqtatalataa, yakni hanya memandang dari segi lafal saja (maka damaikanlah antara keduanya) dan Dhamir pada lafal ini ditatsniyahkan karena memandang dari segi lafal. (Jika berbuat aniaya) atau berbuat melewati batas (salah satu dari kedua golongan itu terhadap golongan yang lain maka perangilah golongan yang berbuat aniaya itu sehingga golongan itu kembali) artinya, rujuk kembali (kepada perintah Allah) kepada jalan yang benar (jika golongan itu telah kembali kepada perintah Allah maka damaikanlah antara keduanya dengan adil) yaitu dengan cara pertengahan (dan berlaku adillah) bersikap jangan memihaklah. (Sesungguhnya Allah menyukai orang-orang yang berlaku adil.)\qt@no{9}}%
\qt@newcmd\qurantrans@id@mmmmdcxxii{%
(Sesungguhnya orang-orang mukmin adalah saudara) dalam seagama (karena itu damaikanlah antara kedua saudara kalian) apabila mereka berdua bersengketa. Menurut qiraat yang lain dibaca Ikhwatikum, artinya saudara-saudara kalian (dan bertakwalah kepada Allah supaya kalian mendapat rahmat.)\qt@no{10}}%
\qt@newcmd\qurantrans@id@mmmmdcxxiii{%
(Hai orang-orang yang beriman, janganlah berolok-olokan) dan seterusnya, ayat ini diturunkan berkenaan dengan delegasi dari Bani Tamim sewaktu mereka mengejek orang-orang muslim yang miskin, seperti Ammar bin Yasir dan Shuhaib Ar-Rumi. As-Sukhriyah artinya merendahkan dan menghina (suatu kaum) yakni sebagian di antara kalian (kepada kaum yang lain karena boleh jadi mereka yang diolok-olokkan lebih baik dari mereka yang mengolok-olokkan) di sisi Allah (dan jangan pula wanita-wanita) di antara kalian mengolok-olokkan (wanita-wanita lain karena boleh jadi wanita-wanita yang diperolok-olokkan lebih baik dari wanita-wanita yang mengolok-olokkan dan janganlah kalian mencela diri kalian sendiri) artinya, janganlah kalian mencela, maka karenanya kalian akan dicela; makna yang dimaksud ialah, janganlah sebagian dari kalian mencela sebagian yang lain (dan janganlah kalian panggil-memanggil dengan gelar-gelar yang buruk) yaitu janganlah sebagian di antara kalian memanggil sebagian yang lain dengan nama julukan yang tidak disukainya, antara lain seperti, hai orang fasik, atau hai orang kafir. (Seburuk-buruk nama) panggilan yang telah disebutkan di atas, yaitu memperolok-olokkan orang lain mencela dan memanggil dengan nama julukan yang buruk (ialah nama yang buruk sesudah iman) lafal Al-Fusuuq merupakan Badal dari lafal Al-Ismu, karena nama panggilan yang dimaksud memberikan pengertian fasik dan juga karena nama panggilan itu biasanya diulang-ulang (dan barang siapa yang tidak bertobat) dari perbuatan tersebut (maka mereka itulah orang-orang yang lalim.)\qt@no{11}}%
\qt@newcmd\qurantrans@id@mmmmdcxxiv{%
(Hai orang-orang yang beriman, jauhilah kebanyakan dari prasangka, sesungguhnya sebagian prasangka itu adalah dosa) artinya, menjerumuskan kepada dosa, jenis prasangka itu cukup banyak, antara lain ialah berburuk sangka kepada orang mukmin yang selalu berbuat baik. Orang-orang mukmin yang selalu berbuat baik itu cukup banyak, berbeda keadaannya dengan orang-orang fasik dari kalangan kaum muslimin, maka tiada dosa bila kita berburuk sangka terhadapnya menyangkut masalah keburukan yang tampak dari mereka (dan janganlah kalian mencari-cari kesalahan orang lain) lafal Tajassasuu pada asalnya adalah Tatajassasuu, lalu salah satu dari kedua huruf Ta dibuang sehingga jadilah Tajassasuu, artinya janganlah kalian mencari-cari aurat dan keaiban mereka dengan cara menyelidikinya (dan janganlah sebagian kalian menggunjing sebagian yang lain) artinya, janganlah kamu mempergunjingkan dia dengan sesuatu yang tidak diakuinya, sekalipun hal itu benar ada padanya. (Sukakah salah seorang di antara kalian memakan daging saudaranya yang sudah mati?) lafal Maytan dapat pula dibaca Mayyitan; maksudnya tentu saja hal ini tidak layak kalian lakukan. (Maka tentulah kalian merasa jijik kepadanya) maksudnya, mempergunjingkan orang semasa hidupnya sama saja artinya dengan memakan dagingnya sesudah ia mati. Kalian jelas tidak akan menyukainya, oleh karena itu janganlah kalian melakukan hal ini. (Dan bertakwalah kepada Allah) yakni takutlah akan azab-Nya bila kalian hendak mempergunjingkan orang lain, maka dari itu bertobatlah kalian dari perbuatan ini (sesungguhnya Allah Maha Penerima tobat) yakni selalu menerima tobat orang-orang yang bertobat (lagi Maha Penyayang) kepada mereka yang bertobat.\qt@no{12}}%
\qt@newcmd\qurantrans@id@mmmmdcxxv{%
(Hai manusia, sesungguhnya Kami menciptakan kalian dari seorang laki-laki dan seorang perempuan) yakni dari Adam dan Hawa (dan Kami menjadikan kalian berbangsa-bangsa) lafal Syu'uuban adalah bentuk jamak dari lafal Sya'bun, yang artinya tingkatan nasab keturunan yang paling tinggi (dan bersuku-suku) kedudukan suku berada di bawah bangsa, setelah suku atau kabilah disebut Imarah, lalu Bathn, sesudah Bathn adalah Fakhdz dan yang paling bawah adalah Fashilah. Contohnya ialah Khuzaimah adalah nama suatu bangsa, Kinanah adalah nama suatu kabilah atau suku, Quraisy adalah nama suatu Imarah, Qushay adalah nama suatu Bathn, Hasyim adalah nama suatu Fakhdz, dan Al-Abbas adalah nama suatu Fashilah (supaya kalian saling kenal-mengenal) lafal Ta'aarafuu asalnya adalah Tata'aarafuu, kemudian salah satu dari kedua huruf Ta dibuang sehingga jadilah Ta'aarafuu; maksudnya supaya sebagian dari kalian saling mengenal sebagian yang lain bukan untuk saling membanggakan ketinggian nasab atau keturunan, karena sesungguhnya kebanggaan itu hanya dinilai dari segi ketakwaan. (Sesungguhnya orang yang paling mulia di antara kalian di sisi Allah ialah orang yang paling bertakwa. Sesungguhnya Allah Maha Mengetahui) tentang kalian (lagi Maha Mengenal) apa yang tersimpan di dalam batin kalian.\qt@no{13}}%
\qt@newcmd\qurantrans@id@mmmmdcxxvi{%
(Orang-orang Arab Badui itu berkata,) yang dimaksud adalah segolongan dari kalangan Bani Asad ("Kami telah beriman") yakni hati kami telah beriman. (Katakanlah) kepada mereka, ("Kalian belum beriman, tetapi katakanlah, 'Kami telah berserah diri,'") artinya, kami telah tunduk secara lahiriah (karena masih belumlah) yakni masih belum lagi (iman masuk ke dalam hati kalian) sampai sekarang hanya saja hal itu baru merupakan dugaan bagi kalian (dan jika kalian taat kepada Allah dan Rasul-Nya) yakni dengan cara beriman yang sesungguhnya dan taat dalam segala hal (Dia tidak akan mengurangi) Dia tidak akan mengurangkan (amal-amal kalian) yakni pahala amal-amal kalian (barang sedikit pun; sesungguhnya Allah Maha Pengampun) kepada orang-orang mukmin (lagi Maha Penyayang") kepada mereka.\qt@no{14}}%
\qt@newcmd\qurantrans@id@mmmmdcxxvii{%
(Sesungguhnya orang-orang yang beriman) yakni orang-orang yang benar-benar beriman, sebagaimana yang telah diterangkan sebelumnya (hanyalah orang-orang yang beriman kepada Allah dan Rasul-Nya kemudian mereka tidak ragu-ragu) dalam keimanannya (dan mereka berjihad dengan harta dan jiwa mereka pada jalan Allah) mereka benar-benar berjihad berkat kesungguhan iman mereka (mereka itulah orang-orang yang benar) dalam keimanan mereka, bukan seperti orang-orang yang mengatakan, ``Kami telah beriman", sedangkan dalam diri mereka yang dijumpai hanya ketundukan belaka.\qt@no{15}}%
\qt@newcmd\qurantrans@id@mmmmdcxxviii{%
(Katakanlah) kepada mereka ("Apakah kalian akan memberitahukan kepada Allah tentang agama kalian) lafal Tu'allimuuna berasal dari 'Allama yang artinya Sya'ara atau memberitahukan. Maksudnya, apakah kalian melalui perkataan kalian, 'Kami telah beriman', hendak memberitahukan kepada Allah tentang keyakinan kalian (padahal Allah mengetahui apa yang ada di langit dan apa yang ada di bumi dan Allah Mengetahui segala sesuatu.")\qt@no{16}}%
\qt@newcmd\qurantrans@id@mmmmdcxxix{%
(Mereka telah merasa memberi nikmat kepadamu dengan keislaman mereka) tanpa melalui perang, berbeda dengan orang-orang selain mereka yang masuk Islam setelah melalui peperangan terlebih dahulu. (Katakanlah, ``Janganlah kalian merasa telah memberi nikmat kepadaku dengan keislaman kalian) lafal Islamakum dinashabkan karena huruf Jarrnya yaitu Ba dicabut darinya, sebagaimana keberadaan huruf Ba ini diperkirakan pula sebelum An pada permulaan ayat (sebenarnya Allah Dialah yang melimpahkan nikmat kepada kalian dengan menunjuki kalian kepada keimanan, jika kalian adalah orang-orang yang benar") di dalam perkataan kalian yang menyatakan, ``Kami telah beriman."\qt@no{17}}%
\qt@newcmd\qurantrans@id@mmmmdcxxx{%
(Sesungguhnya Allah mengetahui apa yang gaib di langit dan di bumi) yakni apa-apa yang tidak kelihatan pada keduanya. (Dan Allah Maha Melihat apa yang kalian kerjakan) dapat dibaca Ta'maluuna atau Ya'maluuna, kalau dibaca Ya'maluuna artinya, Allah Maha Melihat apa yang mereka kerjakan. Maksudnya tiada sesuatu pun darinya yang samar bagi-Nya.\qt@no{18}}%
\qt@newcmd\qurantrans@id@mmmmdcxxxi{%
\basmalahid (Qaaf) hanya Allah saja yang mengetahui arti dan maksudnya. (Demi Alquran yang sangat agung) artinya, yang sangat mulia, tiadalah orang-orang kafir Mekah beriman kepada Nabi Muhammad saw.\qt@no{1}}%
\qt@newcmd\qurantrans@id@mmmmdcxxxii{%
(Bahkan mereka tercengang karena telah datang kepada mereka seorang pemberi peringatan dari kalangan mereka sendiri) yakni seorang rasul yang memperingatkan mereka tentang adanya azab neraka sesudah hari berbangkit, bila mereka tidak beriman (maka berkatalah orang-orang kafir, ``Ini) tentang peringatan itu (adalah suatu hal yang amat ajaib.)\qt@no{2}}%
\qt@newcmd\qurantrans@id@mmmmdcxxxiii{%
(Apakah bila) dapat dibaca Tahqiq, dapat pula dibaca Tas-hil (kami telah mati dan setelah menjadi tanah) kami akan kembali menjadi hidup? (itu adalah suatu pengembalian yang tidak mungkin") yakni sangat jauh dari kemungkinan.\qt@no{3}}%
\qt@newcmd\qurantrans@id@mmmmdcxxxiv{%
(Sesungguhnya Kami telah mengetahui apa yang dihancurkan oleh bumi) apa yang telah dimakan olehnya (dari tubuh-tubuh mereka, dan pada sisi Kami ada kitab yang memelihara) yaitu Lohmahfuz, di dalamnya telah tertera segala sesuatu yang telah dipastikan ketentuannya.\qt@no{4}}%
\qt@newcmd\qurantrans@id@mmmmdcxxxv{%
(Sebenarnya mereka telah mendustakan kebenaran) yakni Alquran (tatkala kebenaran itu datang kepada mereka, maka mereka) menanggapi tentang perihal Nabi saw. dan Alquran (berada dalam keadaan kacau-balau) yakni tidak menentu, terkadang mereka mengatakan, bahwa Nabi adalah penyihir dan Alquran adalah sihir, terkadang juga mengatakan bahwa dia adalah penyair dan Alquran adalah syairnya, terkadang mereka mengatakan bahwa dia adalah seorang peramal dan Alquran adalah ramalannya.\qt@no{5}}%
\qt@newcmd\qurantrans@id@mmmmdcxxxvi{%
(Maka apakah mereka tidak melihat) dengan mata mereka. Padahal mata itu, dipasang untuk mengambil pelajaran dari apa yang dilihatnya, yaitu sewaktu mereka ingkar kepada adanya hari berbangkit (akan langit) yang ada (di atas mereka bagaimana Kami telah membangunnya) tanpa tiang penyangga (dan Kami hiasi dia) dengan bintang-bintang (dan langit itu tidak mempunyai retak-retak sedikit pun?) yakni tidak ada celah-celah yang membuatnya cacat.\qt@no{6}}%
\qt@newcmd\qurantrans@id@mmmmdcxxxvii{%
(Dan bumi itu) di'athafkan kepada kedudukan lafal As-samaa' yakni, dan bumi itu bagaimana (Kami hamparkan) Kami jadikan terhampar menurut pandangan mata di atas permukaan air (dan Kami letakkan padanya gunung-gunung) yang memantapkannya (dan Kami tumbuhkan padanya segala macam tanaman) segala jenis tumbuh-tumbuhan (yang indah) yang tampak sangat indah dipandang mata karena keindahannya.\qt@no{7}}%
\qt@newcmd\qurantrans@id@mmmmdcxxxviii{%
(Untuk menjadi pelajaran) menjadi maf'ul lah, yakni, Kami lakukan hal tersebut sebagai pemberian pelajaran dari Kami (dan peringatan) untuk dijadikan sebagai peringatan (bagi tiap-tiap hamba yang kembali) untuk taat kepada Kami.\qt@no{8}}%
\qt@newcmd\qurantrans@id@mmmmdcxxxix{%
(Dan Kami turunkan dari langit air yang penuh keberkatan) berkah dan manfaatnya (lalu Kami tumbuhkan dengan air itu pohon-pohon) maksudnya kebun-kebun (dan biji-biji tanaman) yakni ladang-ladang (yang diketam) yang dipanen.\qt@no{9}}%
\qt@newcmd\qurantrans@id@mmmmdcxl{%
(Dan pohon-pohon kurma yang tinggi-tinggi) lafal Baasiqaatin ini berkedudukan menjadi Hal bagi lafal yang diperkirakan keberadaannya (yang mempunyai mayang yang bersusun-susun) yaitu sebagian di antaranya bertumpuk di atas sebagian yang lain.\qt@no{10}}%
\qt@newcmd\qurantrans@id@mmmmdcxli{%
(Untuk menjadi rezeki bagi hamba-hamba) Kami; lafal Rizqan menjadi Maf'ul Lah (dan Kami hidupkan dengan air itu tanah yang mati) lafal Maytan dapat digunakan untuk Mudzakkar dan Muannats. (Seperti itulah) dengan cara itulah (terjadinya kebangkitan) dari kubur, maka mengapa kalian mengingkarinya? Istifham atau kata tanya mengandung makna Taqrir, makna yang dimaksud adalah bahwa mereka melihat dan mengetahui hal tersebut.\qt@no{11}}%
\qt@newcmd\qurantrans@id@mmmmdcxlii{%
(Sebelum mereka telah mendustakan pula kaum Nuh) di-ta`nits-kannya dhamir yang ada pada lafal Kadzdzabat karena memandang makna yang terkandung dalam lafal Qaumun (dan penduduk Rass) Rass adalah nama sebuah sumur yang di sekitarnya tinggal suatu kaum berikut ternak mereka; mereka menyembah berhala, menurut suatu pendapat nabi mereka bernama Hanzhalah bin Shafwan; menurut pendapat lainnya bukanlah dia, (dan Tsamud) yaitu kaum Nabi Shaleh.\qt@no{12}}%
\qt@newcmd\qurantrans@id@mmmmdcxliii{%
(Dan kaum Ad) kaum Nabi Hud (kaum Firaun dan kaum Luth.)\qt@no{13}}%
\qt@newcmd\qurantrans@id@mmmmdcxliv{%
(Dan penduduk Aikah) yakni penduduk Ghaidhah kaum Nabi Syuaib (serta kaum Tubba') Tubba' adalah nama raja di negeri Yaman; ia masuk Islam lalu menyeru kaumnya untuk masuk Islam, tetapi mereka mendustakannya (masing-masing) dari kaum-kaum yang telah disebutkan tadi (mendustakan rasul-rasul) sebagaimana yang dilakukan oleh kabilah Quraisy (maka sudah semestinya mereka mendapat ancaman-Ku) artinya sudah semestinya semuanya menerima azab-Ku, maka janganlah kamu susah dengan kekafiran orang-orang Quraisy terhadap dirimu.\qt@no{14}}%
\qt@newcmd\qurantrans@id@mmmmdcxlv{%
(Maka apakah Kami letih dengan penciptaan yang pertama?) maksudnya, Kami tidak merasa letih dengan penciptaan yang pertama itu, demikian pula Kami tidak merasa letih untuk mengembalikan mereka. (Sebenarnya mereka dalam keadaan ragu-ragu) yakni berada dalam keragu-raguan (tentang penciptaan yang baru) yaitu membangkitkan mereka menjadi hidup kembali pada hari berbangkit nanti.\qt@no{15}}%
\qt@newcmd\qurantrans@id@mmmmdcxlvi{%
(Dan sesungguhnya Kami telah menciptakan manusia sedangkan Kami mengetahui) lafal Na'lamu ini berkedudukan menjadi Hal atau kata keterangan keadaan dan sebelumnya diperkirakan adanya lafal Nahnu (apa) huruf Maa di sini adalah Mashdariyah (yang dibisikkan) dibicarakan (oleh dia) yakni oleh manusia, huruf Ba di sini adalah Zaidah, atau untuk Ta'diyah (dalam hatinya, dan Kami lebih dekat kepadanya) maksudnya ilmu Kami (daripada urat lehernya) Idhafah di sini mengandung makna Bayan atau untuk menjelaskan, dan pengertian yang dimaksud dari lafal Al-Wariid adalah dua urat vital yang terdapat pada bagian belakang leher.\qt@no{16}}%
\qt@newcmd\qurantrans@id@mmmmdcxlvii{%
(Ingatlah ketika) lafal Idz di sini dinashabkan oleh lafal Udzkur yang keberadaannya diperkirakan (mencatat) yakni menulis (dua malaikat pencatat amal) artinya, yang diserahi tugas oleh Allah untuk mencatat amal perbuatan yang dilakukan oleh manusia (yang satu berada di sebelah kanan dan yang lain berada di sebelah kiri) manusia (dalam keadaan duduk) yakni keduanya duduk, lafal Qa'iid ini adalah Mubtada dan Khabarnya adalah lafal sebelumnya.\qt@no{17}}%
\qt@newcmd\qurantrans@id@mmmmdcxlviii{%
(Tiada suatu ucapan pun yang dikatakan melainkan ada malaikat pengawas) yakni malaikat pencatat amal (yang selalu hadir) selalu berada di sisinya; lafal Raqiib dan 'Atiid ini keduanya mengandung makna Mutsanna.\qt@no{18}}%
\qt@newcmd\qurantrans@id@mmmmdcxlix{%
(Dan datanglah sakaratul maut) yakni kesusahan dan rasa sakit yang memuncak menjelang maut (dengan membawa kebenaran) yakni perkara akhirat, hingga orang yang ingkar kepada hari akhirat dapat melihatnya secara nyata, hal ini termasuk pula hal yang menyakitkan. (Itulah) kematian itu (hal yang kamu tidak dapat menghindar darinya) yakni tidak dapat melarikan diri darinya.\qt@no{19}}%
\qt@newcmd\qurantrans@id@mmmmdcl{%
(Dan ditiuplah sangkakala) untuk membangkitkan manusia. (Itulah) yakni hari peniupan itu (hari terlaksananya ancaman) bagi orang-orang kafir, yaitu mereka akan mengalami siksaan.\qt@no{20}}%
\qt@newcmd\qurantrans@id@mmmmdcli{%
(Dan datanglah) pada hari itu (tiap-tiap diri) ke tempat mereka dikumpulkan yaitu padang Mahsyar (bersama dengan dia penggiringnya) yaitu malaikat yang menggiringnya ke padang Mahsyar (dan pemberi saksi) yang akan memberikan kesaksian tentang semua amal perbuatannya, yaitu tangan dan kakinya serta anggota-anggota tubuhnya yang lain. Kemudian pada saat itu dikatakan kepada orang yang kafir:\qt@no{21}}%
\qt@newcmd\qurantrans@id@mmmmdclii{%
("Sesungguhnya kamu) sewaktu di dunia (berada dalam keadaan lalai dari hal ini) yang sekarang menimpa kamu (maka Kami singkapkan daripadamu tutupmu) maksudnya, Kami lenyapkan kelalaianmu dengan apa yang kamu saksikan sekarang ini (maka penglihatanmu pada hari ini tajam") yakni menjadi terang dan dapat melihat apa yang kamu ingkari sewaktu di dunia.\qt@no{22}}%
\qt@newcmd\qurantrans@id@mmmmdcliii{%
(Dan yang menyertai dia berkata,) yakni malaikat yang diserahi tugas mencatat amal perbuatannya: ("Inilah apa) yakni catatan amalmu (yang ada pada sisiku") yakni catatan amalmu yang ada padaku. Lalu dikatakan kepada malaikat Malik:\qt@no{23}}%
\qt@newcmd\qurantrans@id@mmmmdcliv{%
("Lemparkanlah olehmu ke dalam neraka Jahanam) maksudnya, lemparkanlah, atau cepat lemparkan. Menurut bacaan atau qiraat Imam Al-Hasan lafal Alqiyaa dibaca Alqiyan. Jadi asal kata lafal Alqiyaa adalah Alqiyan, kemudian huruf Nun Taukidnya diganti menjadi Alif sehingga jadilah Alqiyaa (semua orang yang ingkar dan keras kepala) maksudnya, membangkang terhadap perkara yang hak.\qt@no{24}}%
\qt@newcmd\qurantrans@id@mmmmdclv{%
(Yang sangat menghalangi kebaikan) seperti perkara zakat (melanggar batas) yakni suka berbuat zalim (lagi ragu-ragu) ragu dalam agamanya.\qt@no{25}}%
\qt@newcmd\qurantrans@id@mmmmdclvi{%
(Yang menjadikan tuhan lain di samping Allah) lafal ayat ini berkedudukan menjadi Mubtada yang mengandung makna Syarat, sedangkan Khabarnya ialah: (maka lemparkanlah dia ke dalam siksaan yang keras") penafsiran lafal ayat ini sama dengan ayat yang semisal dengannya di atas tadi.\qt@no{26}}%
\qt@newcmd\qurantrans@id@mmmmdclvii{%
(Yang menyertai dia berkata) yakni setannya mengatakan: ("Ya Rabb kami! Aku tidak menyesatkannya) kami tidak membuatnya sesat (tetapi dialah yang berada dalam kesesatan yang jauh") lalu kami mengajaknya dan ternyata ia memenuhi ajakanku. Sedangkan dia menjawab, ``Setanlah yang menyesatkan aku", yaitu melalui ajakannya.\qt@no{27}}%
\qt@newcmd\qurantrans@id@mmmmdclviii{%
(Allah berfirman,) Maha Tinggi Dia ("Janganlah kalian bertengkar di hadapan-Ku) maksudnya, tiada gunanya pertengkaran kalian di sini (padahal sesungguhnya Aku dahulu telah memberikan kepada kalian) sewaktu kalian hidup di dunia (ancaman) akan adanya azab di akhirat jika kalian tidak beriman, dan ini merupakan suatu kepastian yang tidak dapat dihindari lagi.\qt@no{28}}%
\qt@newcmd\qurantrans@id@mmmmdclix{%
(Tidaklah dapat diganti) diubah (keputusan yang ada di sisi-Ku) mengenai hal tersebut (dan Aku sekali-kali tidak menganiaya hamba-hamba-Ku) yaitu dengan cara Aku mengazab mereka tanpa dosa; lafal Zhallaamin bermakna seperti lafal Dzuu Zhulmin yaitu menganiaya, demikian itu karena ada firman lainnya yang mengatakan, ``Tidak ada yang dianiaya pada hari ini." (Q.S. Al-Mukmin, 17)\qt@no{29}}%
\qt@newcmd\qurantrans@id@mmmmdclx{%
(Pada hari) lafal ini dinashabkan oleh lafal Zhallaamin (Kami bertanya) dapat dibaca Naquulu atau Yaquulu, kalau dibaca Yaquulu artinya, Allah bertanya (kepada neraka Jahanam, ``Apakah kamu sudah penuh?") kata tanya di sini dimaksud mengecek ancaman-Nya yang menyatakan akan memenuhinya. (Dan dia menjawab, ``Masih adakah tambahan?") maksudnya, kami tidak memuat melainkan hanya apa yang telah Engkau penuhkan kepada kami. Artinya kami telah penuh.\qt@no{30}}%
\qt@newcmd\qurantrans@id@mmmmdclxi{%
(Dan didekatkanlah surga itu) atau dijadikan dekat (kepada orang-orang yang bertakwa) surga itu didekatkan pada suatu tempat (yang tidak jauh) dari orang-orang yang bertakwa, sehingga mereka dapat melihatnya dengan jelas, kemudian dikatakan kepada mereka:\qt@no{31}}%
\qt@newcmd\qurantrans@id@mmmmdclxii{%
(Inilah) artinya, pemandangan yang dilihat ini (yang dijanjikan kepada kalian) dapat dibaca Tuu'aduuna atau Yuu'aduuna, kalau dibaca Yuu'aduuna artinya, yang dijanjikan kepada mereka sewaktu mereka di dunia. Kemudian lafal Al-Muttaqiina tadi dijelaskan melalui firman selanjutnya, yaitu: (kepada setiap hamba yang selalu kembali) yakni kembali kepada jalan ketaatan kepada Allah (lagi memelihara) batasan-batasan-Nya.\qt@no{32}}%
\qt@newcmd\qurantrans@id@mmmmdclxiii{%
(Yaitu orang yang takut kepada Yang Maha Pemurah sedangkan Dia tidak kelihatan olehnya) sekalipun ia tidak melihat-Nya (dan dia datang dengan kalbu yang bertobat) yakni dengan kalbu yang taat kepada-Nya. Dan dikatakan pula kepada orang-orang yang bertakwa:\qt@no{33}}%
\qt@newcmd\qurantrans@id@mmmmdclxiv{%
("Masukilah surga itu dengan aman) artinya, dengan perasaan yang aman dari semua hal yang menakutkan. Atau dengan selamat, yakni selamatlah dan masuklah kalian ke dalamnya (itulah) yaitu hari sewaktu mereka memasuki surga itu (hari kekekalan") artinya hidup abadi di dalam surga.\qt@no{34}}%
\qt@newcmd\qurantrans@id@mmmmdclxv{%
(Mereka di dalamnya memperoleh apa yang mereka kehendaki; dan pada sisi Kami ada tambahannya) yakni sebagai pahala tambahan dari apa yang telah kalian amalkan, dan sebagai tambahan dari apa yang telah kalian minta.\qt@no{35}}%
\qt@newcmd\qurantrans@id@mmmmdclxvi{%
(Dan berapa banyaknya umat-umat yang telah Kami binasakan sebelum mereka) sebelum orang-orang kafir Quraisy Kami telah membinasakan banyak umat yang kafir (yang mereka itu lebih besar kekuatannya daripada mereka ini) maksudnya umat-umat dahulu itu jauh lebih kuat daripada mereka (maka mereka telah pernah menjelajah) telah mengembara (di beberapa negeri. Adakah mereka mendapat tempat lari) dari kematian; yang dimaksud adalah mereka yang telah dibinasakan atau lainnya. Maka ternyata mereka tidak dapat menemukan jalan untuk melarikan diri dari kematian.\qt@no{36}}%
\qt@newcmd\qurantrans@id@mmmmdclxvii{%
(Sesungguhnya pada yang demikian itu) pada hal-hal yang telah disebutkan itu (benar-benar terdapat peringatan) yakni pelajaran (bagi orang yang mempunyai akal) pikiran (atau yang menggunakan pendengarannya) artinya, mau mendengar nasihat (sedangkan dia menyaksikannya) maksudnya, hatinya hadir.\qt@no{37}}%
\qt@newcmd\qurantrans@id@mmmmdclxviii{%
(Dan sesungguhnya telah Kami ciptakan langit dan bumi dan apa yang ada antara keduanya dalam enam hari) pada permulaannya adalah hari Ahad dan selesai pada hari Jumat (dan Kami sedikit pun tidak ditimpa keletihan) kepayahan. Ayat ini diturunkan sebagai sanggahan terhadap orang-orang Yahudi yang telah mengatakan bahwa Allah swt. pada hari Sabtu-Nya beristirahat. Ditiadakannya sifat lebih daripada-Nya karena memang Dia Maha Suci dari sifat-sifat yang dimiliki oleh makhluk-Nya, dan pula karena tiada kesamaan antara Allah dan selain-Nya. Di dalam ayat lain sehubungan dengan masalah penciptaan ini disebutkan melalui firman-Nya, ``Sesungguhnya keadaan-Nya apabila Dia menghendaki sesuatu hanyalah berkata kepadanya, 'Jadilah!' Maka terjadilah ia." (Q.S. Yaasin, 82)\qt@no{38}}%
\qt@newcmd\qurantrans@id@mmmmdclxix{%
(Maka bersabarlah kamu) khithab pada ayat ini ditujukan kepada Nabi saw. (terhadap apa yang mereka katakan) yang dikatakan orang-orang Yahudi dan lainnya yang menyerupakan Allah dengan makhluk-Nya dan yang mendustakan kamu (dan bertasbihlah seraya memuji Rabbmu) yakni salatlah seraya memuji-Nya (sebelum terbit matahari) yakni salat Subuh (dan sebelum terbenamnya) yakni salat Zuhur dan salat Asar.\qt@no{39}}%
\qt@newcmd\qurantrans@id@mmmmdclxx{%
(Dan bertasbihlah kamu di malam hari) artinya lakukanlah kedua salat pada waktu permulaan malam hari (dan setiap selesai salat) kalau dibaca Adbaar berarti bentuk jamak dari lafal Duburun, sedangkan kalau dibaca Idbaar berarti Mashdar dari lafal Adbara. Artinya, lakukanlah salat tambahan yang disunahkan setiap selesai menjalankan salat fardu. Menurut suatu pendapat makna yang dimaksud adalah hakikat dari ucapan tasbih seraya memuji Allah yang dilakukan pada waktu-waktu tersebut.\qt@no{40}}%
\qt@newcmd\qurantrans@id@mmmmdclxxi{%
(Dan dengarkanlah) hai orang yang diajak bicara akan seruan-Ku ini (pada hari penyeru menyeru) yakni malaikat Israfil (dari tempat yang dekat) dari langit, yaitu dari atas Kubbah Shakhr di Baitulmakdis, karena tempat itu yang paling dekat dengan langit. Ia menyerukan kata-kata, ``Hai tulang-belulang yang telah hancur dan sendi-sendi yang telah bercerai-berai dan daging-daging yang telah tercabik-cabik dan rambut-rambut yang telah berantakan! Sesungguhnya Allah memerintahkan kalian semua untuk berhimpun guna melaksanakan peradilan."\qt@no{41}}%
\qt@newcmd\qurantrans@id@mmmmdclxxii{%
(Yaitu pada hari) menjadi Badal Isytimal dari lafal Yauma sebelumnya (mereka mendengar) maksudnya, ketika makhluk semuanya mendengar (teriakan dengan sebenar-benarnya) untuk membangkitkan makhluk semuanya, yaitu tiupan yang kedua dari malaikat Israfil. Dan teriakan ini adakalanya sesudah seruan itu atau sebelumnya (itulah) yakni hari seruan yang semua makhluk mendengarnya (hari keluar) dari kubur. Dan yang menashabkan lafal Yauma Yunaadi keberadaannya diperkirakan; lengkapnya: Mereka mengetahui akibat dari kedustaan mereka itu, pada hari penyeru menyerukan.\qt@no{42}}%
\qt@newcmd\qurantrans@id@mmmmdclxxiii{%
(Sesungguhnya Kami menghidupkan dan mematikan dan hanya kepada Kamilah tempat kembali -semua makhluk-.)\qt@no{43}}%
\qt@newcmd\qurantrans@id@mmmmdclxxiv{%
(Yaitu pada hari) lafal Yauma pada ayat ini menjadi Badal atau pengganti dari lafal Yauma sebelumnya, sedangkan kalimat-kalimat yang menengah-nengahi di antara keduanya merupakan jumlah I'tiradh atau kalimat sisipan (terbelah-belah) dapat dibaca Tasyaqqaqu atau Tasysyaqqaqu, pada asalnya adalah Tatasyaqqaqu, lalu huruf Ta yang kedua diidgamkan kepada huruf Syin sehingga menjadi Tasysyaqqaqu (bumi menampakkan mereka dengan cepat) lafal Siraa'an adalah bentuk jamak dari lafal Sarii'un yang artinya cepat; berkedudukan menjadi Hal atau kata keterangan keadaan bagi lafal yang diperkirakan keberadaannya. Lengkapnya, mereka keluar dengan cepat dari kuburnya masing-masing. (Yang demikian itu adalah pengumpulan yang mudah bagi Kami) pada ayat ini terdapat Fashl atau pemisah yang memisahkan antara Maushuf dan Shifatnya, yang menjadi pemisah adalah Muta'alliqnya, hal ini mengandung makna Ikhtishash, dan hal seperti ini tidak mengapa. Demikian ini mengisyaratkan kepada pengertian pengumpulan yang dimaksud, yaitu menghidupkan kembali makhluk yang telah mati, dan pengumpulan ini dimaksud untuk menghadapkan semua makhluk ke hadapan-Nya guna menjalani hisab.\qt@no{44}}%
\qt@newcmd\qurantrans@id@mmmmdclxxv{%
(Kami lebih mengetahui tentang apa yang mereka katakan) yaitu yang dikatakan oleh orang-orang kafir Quraisy (dan kamu sekali-kali bukanlah seorang pemaksa terhadap mereka yang memaksa mereka untuk beriman, ayat ini diturunkan sebelum ada perintah berjihad. (Maka berilah peringatan dengan Alquran orang yang takut kepada ancaman-Ku) mereka adalah orang-orang mukmin.\qt@no{45}}%
\qt@newcmd\qurantrans@id@mmmmdclxxvi{%
\basmalahid (Demi yang menerbangkan debu) yakni angin dan lain-lainnya (dengan sekuat-kuatnya) adalah Mashdar, yang diambil dari kata: Tudzriihi Dzaryan, artinya angin itu menerbangkannya.\qt@no{1}}%
\qt@newcmd\qurantrans@id@mmmmdclxxvii{%
(Dan demi awan yang mengandung) awan yang membawa air (hujan) yakni beban berupa air hujan, berkedudukan menjadi Maf'ul dari lafal Al Haamiaat.\qt@no{2}}%
\qt@newcmd\qurantrans@id@mmmmdclxxviii{%
(Dan demi yang berlayar) yakni kapal-kapal yang berlayar di atas permukaan air (dengan mudah) dengan sangat mudahnya. Kalimat ini adalah Mashdar yang berkedudukan menjadi Hal, yakni Muyassaratan.\qt@no{3}}%
\qt@newcmd\qurantrans@id@mmmmdclxxix{%
(Dan demi yang membagi-bagi urusan) demi malaikat-malaikat yang membagi-bagi rezeki, hujan dan lain-lainnya ke berbagai negeri dan kepada semua hamba-hamba Allah.\qt@no{4}}%
\qt@newcmd\qurantrans@id@mmmmdclxxx{%
(Sesungguhnya apa yang dijanjikan kepada kalian) huruf Maa pada lafal Innamaa adalah Mashdariyah; yakni janji Allah kepada mereka, yaitu tentang hari berbangkit dan lain-lainnya (pasti benar) artinya sungguh merupakan janji yang benar.\qt@no{5}}%
\qt@newcmd\qurantrans@id@mmmmdclxxxi{%
(Dan Sesungguhnya pembalasan itu) yakni pembalasan sesudah hisab (pasti terjadi) pasti akan terjadi.\qt@no{6}}%
\qt@newcmd\qurantrans@id@mmmmdclxxxii{%
(Demi langit yang mempunyai jalan-jalan) lafal Al Hubuk adalah bentuk jamak dari Habiikah, sama halnya dengan lafal Thariiqah yang bentuk jamaknya Thuruq, yakni sejak ia diciptakan mempunyai jalan-jalan, sebagaimana jalan di padang pasir.\qt@no{7}}%
\qt@newcmd\qurantrans@id@mmmmdclxxxiii{%
(Sesungguhnya kalian) hai penduduk Mekah terhadap Nabi saw. dan Alquran (benar-benar dalam keadaan berbeda-beda pendapat) terkadang mengatakannya sebagai penyair, dan terkadang penyihir, dan terkadang peramal, dan terhadap Alquran terkadang mereka mengatakannya sebagai syair; terkadang sebagai sihir dan terkadang dianggap sebagai ramalan.\qt@no{8}}%
\qt@newcmd\qurantrans@id@mmmmdclxxxiv{%
(Dipalingkan) dijauhkan (daripadanya) dari Nabi saw. dan Alquran; maksudnya dipalingkan dari beriman kepadanya (orang yang dipalingkan) dari jalan petunjuk, menurut ilmu Allah swt.\qt@no{9}}%
\qt@newcmd\qurantrans@id@mmmmdclxxxv{%
(Terkutuklah orang-orang yang banyak berdusta) amat terkutuklah orang-orang yang berdusta, yaitu orang-orang yang mempunyai pendapat yang berbeda-beda.\qt@no{10}}%
\qt@newcmd\qurantrans@id@mmmmdclxxxvi{%
(Yaitu orang-orang yang terbenam di dalam kebodohannya) di dalam kebodohan yang menutupi akal mereka (lagi lalai) akan perkara akhirat.\qt@no{11}}%
\qt@newcmd\qurantrans@id@mmmmdclxxxvii{%
(Mereka bertanya) kepada nabi dengan nada memperolok-olokkan, ("Bilakah hari pembalasan?") kapan datangnya hari pembalasan itu. Jawaban yang patut buat mereka ialah, ``Memang Kiamat pasti datang,\qt@no{12}}%
\qt@newcmd\qurantrans@id@mmmmdclxxxviii{%
(Yaitu pada hari ketika mereka di azab di dalam neraka") yakni sewaktu mereka diazab di dalamnya, lalu dikatakan kepada mereka ketika mereka sedang diazab,\qt@no{13}}%
\qt@newcmd\qurantrans@id@mmmmdclxxxix{%
("Rasakanlah azab kalian) siksaan kalian. (Inilah) azab (yang dahulu kalian minta supaya disegerakan") di dunia dengan nada mengejek.\qt@no{14}}%
\qt@newcmd\qurantrans@id@mmmmdcxc{%
(Sesungguhnya orang-orang yang bertakwa berada di dalam surga) di taman-taman surga (dan di mata air-mata air) yang mengalir di dalam surga.\qt@no{15}}%
\qt@newcmd\qurantrans@id@mmmmdcxci{%
(Sambil mengambil) menjadi Hal dari Dhamir yang terkandung di dalam Khabarnya Inna (apa yang didatangkan kepada mereka) apa yang diberikan kepada mereka (oleh Rabb mereka) yaitu berupa pahala-pahala. (Sesungguhnya mereka sebelum itu) sebelum mereka masuk surga (adalah orang-orang yang berbuat baik) di dunia.\qt@no{16}}%
\qt@newcmd\qurantrans@id@mmmmdcxcii{%
(Mereka sedikit sekali tidur di waktu malam) lafal Yahja'uuna artinya mereka tidur, dan lafal Maa adalah Zaidah, sedangkan lafal Yahja'uuna adalah Khabar dari Kaana, dan lafal Qaliilan adalah Zharaf. Yakni, mereka tidur di malam hari hanya sedikit, karena kebanyakan dipakai untuk salat.\qt@no{17}}%
\qt@newcmd\qurantrans@id@mmmmdcxciii{%
(Dan di akhir-akhir malam mereka memohon ampun) mereka berdoa dengan mengucapkan, ``Allaahumaghfir Lanaa", Ya Allah ampunilah kami.\qt@no{18}}%
\qt@newcmd\qurantrans@id@mmmmdcxciv{%
(Dan pada harta-harta mereka ada hak untuk orang miskin yang meminta dan orang miskin yang tidak meminta-minta) karena ia memelihara dirinya dari perbuatan itu.\qt@no{19}}%
\qt@newcmd\qurantrans@id@mmmmdcxcv{%
(Dan di bumi itu) yakni gunung-gunung, tanahnya, lautan, pohon-pohonan, buah-buahan, dan tumbuh-tumbuhannya serta lain-lainnya (terdapat tanda-tanda) yang menunjukkan akan kekuasaan Allah swt. dan keesaan-Nya (bagi orang-orang yang yakin).\qt@no{20}}%
\qt@newcmd\qurantrans@id@mmmmdcxcvi{%
(Dan juga pada diri kalian sendiri) terdapat pula tanda-tanda yang menunjukkan kekuasaan dan keesaan-Nya, yaitu mulai dari permulaan penciptaan kalian hingga akhirnya, dan di dalam susunan penciptaan kalian terkandung pula keajaiban-keajaiban. (Maka apakah kalian tidak memperhatikan?) akan hal tersebut yang karena itu lalu kalian dapat menyimpulkan akan Penciptanya dan kekuasaan-Nya yang Maha Besar.\qt@no{21}}%
\qt@newcmd\qurantrans@id@mmmmdcxcvii{%
(Dan di langit terdapat rezeki kalian) yaitu hujan yang menyebabkan tumbuhnya tumbuh-tumbuhan sebagai rezeki (dan terdapat pula apa yang dijanjikan kepada kalian) yakni tempat kembali, pahala, dan siksaan. Catatan mengenai hal tersebut terdapat di langit.\qt@no{22}}%
\qt@newcmd\qurantrans@id@mmmmdcxcviii{%
(Maka demi Rabb langit dan bumi, sesungguhnya ia) yakni apa yang dijanjikan kepada kalian (adalah benar seperti perkataan yang kalian ucapkan) di-rafa-kannya lafal Mitslu karena menjadi sifat, sedangkan huruf Maa yang sesudahnya adalah Zaidah. Bila dibaca Mitsla maka tulisannya disatukan dengan Maa. Maknanya, kenyataannya seperti perkataan yang kalian ucapkan, yakni pengetahuan mengenai hal itu sudah dimaklumi oleh kalian, dan hal itu justru timbul dari diri kalian sendiri.\qt@no{23}}%
\qt@newcmd\qurantrans@id@mmmmdcxcix{%
(Sudahkah sampai kepadamu) khithab ini ditujukan kepada Nabi saw. (cerita tamu Ibrahim yang dimuliakan) mereka adalah malaikat-malaikat yang jumlahnya ada dua belas atau sepuluh atau tiga malaikat; di antara mereka terdapat malaikat Jibril.\qt@no{24}}%
\qt@newcmd\qurantrans@id@mmmmdcc{%
(Ketika) lafal Idz di sini berkedudukan menjadi Zharaf bagi lafal Hadiitsu Dhaifi Ibraahiima (mereka masuk ke tempatnya lalu mengucapkan, ``Salaaman") tamu-tamu itu mengucapkan perkataan tersebut. (Ibrahim menjawab, ``Salaamun") menjawab dengan ucapan yang sama (mereka adalah orang-orang yang tidak dikenal) maksudnya, kami tidak mengenal mereka, Nabi Ibrahim mengatakan ucapan ini di dalam hatinya. Kalimat ini berkedudukan menjadi Khabar dari Mubtada yang keberadaannya diperkirakan, yaitu lafal Haa`ulaa`i yang artinya mereka.\qt@no{25}}%
\qt@newcmd\qurantrans@id@mmmmdcci{%
(Maka dia pergi) yakni ia beranjak dari situ (menemui keluarganya) dengan diam-diam (kemudian dibawanya daging anak sapi yang gemuk). Di dalam surah Hud telah disebutkan pula melalui firman-Nya, ``... dengan membawa daging anak sapi yang dipanggang." (Q.S. Hud, 69) yakni daging anak sapi gemuk itu sudah dipanggang.\qt@no{26}}%
\qt@newcmd\qurantrans@id@mmmmdccii{%
(Lalu dihidangkannya kepada mereka. Ibrahim berkata, ``Silakan kalian makan") Nabi Ibrahim mempersilakan mereka untuk makan, tetapi mereka tidak mau memakannya.\qt@no{27}}%
\qt@newcmd\qurantrans@id@mmmmdcciii{%
(Maka Ibrahim memendam) di dalam hatinya (rasa takut terhadap mereka. Mereka berkata, ``Janganlah kamu takut") sesungguhnya kami adalah utusan-utusan Rabbmu (dan mereka memberi kabar gembira dengan kelahiran seorang anak yang alim) yakni anak yang mempunyai ilmu banyak yaitu, Nabi Ishak sebagaimana yang telah disebutkan di dalam surah Hud.\qt@no{28}}%
\qt@newcmd\qurantrans@id@mmmmdcciv{%
(Kemudian istrinya datang) yakni Siti Sarah (seraya memekik) karena tercengang, berkedudukan menjadi Hal; yakni Siti Sarah datang seraya memekik karena kaget (lalu menepuk mukanya sendiri) menampar mukanya sendiri (seraya berkata, ``Aku adalah seorang perempuan tua yang mandul") yang tidak dapat melahirkan anak sama sekali, pada saat itu umur Sarah mencapai sembilan puluh sembilan tahun, sedangkan Nabi Ibrahim seratus tahun; atau umur Nabi Ibrahim pada saat itu seratus dua puluh tahun, sedangkan umur Siti Sarah sembilan puluh tahun.\qt@no{29}}%
\qt@newcmd\qurantrans@id@mmmmdccv{%
(Mereka berkata, ``Demikianlah) sebagaimana perkataan kami tentang berita gembira ini (Rabbmu memfirmankan". Sesungguhnya Dialah Yang Maha Bijaksana) di dalam perbuatan-Nya (lagi Maha Mengetahui) tentang makhluk-Nya.\qt@no{30}}%
\qt@newcmd\qurantrans@id@mmmmdccvi{%
(Ibrahim bertanya, ``Apakah urusan kalian) maksudnya, kepentingan kalian (hai para utusan?");\qt@no{31}}%
\qt@newcmd\qurantrans@id@mmmmdccvii{%
(Mereka menjawab, ``Sesungguhnya kami diutus kepada kaum yang berdosa) kaum yang kafir, mereka adalah kaum Nabi Luth.\qt@no{32}}%
\qt@newcmd\qurantrans@id@mmmmdccviii{%
(Agar kami timpakan kepada mereka batu-batu dari tanah yang keras) yang dibakar oleh api.\qt@no{33}}%
\qt@newcmd\qurantrans@id@mmmmdccix{%
(Yang ditandai) yang diberi tanda padanya nama orang-orang yang akan dilemparkan (di sisi Rabbmu) menjadi Zharaf dari lafal yang sebelumnya (untuk orang-orang yang melampaui batas") karena mereka gemar melakukan homosex, dan kekafiran mereka.\qt@no{34}}%
\qt@newcmd\qurantrans@id@mmmmdccx{%
(Lalu Kami keluarkan orang-orang yang berada di negeri itu) kampung-kampung Nabi Luth (yakni orang-orang yang beriman) karena orang-orang kafirnya akan dibinasakan.\qt@no{35}}%
\qt@newcmd\qurantrans@id@mmmmdccxi{%
(Dan Kami tidak mendapati di negeri itu, kecuali sebuah rumah dari orang-orang yang berserah diri) mereka adalah Nabi Luth dan kedua orang putrinya, mereka dinamakan sebagai orang-orang yang beriman dan berserah diri, karena mereka adalah orang-orang yang beriman dengan sepenuh kalbu serta mengamalkan ketaatan dengan semua anggota tubuh mereka.\qt@no{36}}%
\qt@newcmd\qurantrans@id@mmmmdccxii{%
(Dan Kami tinggalkan pada negeri itu) sesudah semua orang-orang kafir dibinasakan (suatu tanda) yakni tanda yang menunjukkan bahwa mereka telah dibinasakan (bagi orang-orang yang takut kepada siksa yang pedih) hingga hal itu dijadikan sebagai peringatan buat mereka, supaya mereka tidak melakukan perbuatan yang sama.\qt@no{37}}%
\qt@newcmd\qurantrans@id@mmmmdccxiii{%
(Dan juga pada Musa) di-'athaf-kan kepada lafal Fiihaa. Maknanya, Dan Kami jadikan pada kisah Musa suatu tanda (ketika Kami mengutusnya kepada Firaun) (dengan membawa bukti yang nyata) yakni hujjah yang jelas dan terang.\qt@no{38}}%
\qt@newcmd\qurantrans@id@mmmmdccxiv{%
(Maka dia berpaling) yakni Firaun tidak mau beriman (bersama tentaranya) bersama dengan pasukannya; di sini bala tentara dinamakan Ar Rukn yang arti asalnya adalah pilar karena memang bala tentara itu adalah pilar atau penopang bagi pemimpinnya (dan berkata) kepada Nabi Musa, bahwa (dia adalah seorang tukang sihir atau seorang gila).\qt@no{39}}%
\qt@newcmd\qurantrans@id@mmmmdccxv{%
(Maka Kami siksa dia dan bala tentaranya lalu Kami lemparkan mereka) Kami campakkan mereka (ke dalam laut) hingga tenggelamlah mereka (sedangkan dia) yakni Firaun (melakukan pekerjaan yang tercela) yaitu mendustakan rasul-rasul dan mengaku-ngaku menjadi Tuhan.\qt@no{40}}%
\qt@newcmd\qurantrans@id@mmmmdccxvi{%
(Dan juga pada) kisah pembinasaan kaum (Ad) terdapat tanda yang dijadikan sebagai pelajaran (ketika Kami kirimkan kepada mereka angin yang membinasakan) yaitu angin yang sama sekali tidak membawa kebaikan, karena tidak membawa air hujan dan tidak dapat menyerbukkan pohon-pohon, angin ini dinamakan angin puting beliung.\qt@no{41}}%
\qt@newcmd\qurantrans@id@mmmmdccxvii{%
(Angin itu tidak membiarkan sesuatu pun) baik jiwa atau harta benda (yang dilandanya, melainkan dijadikannya seperti serbuk) yakni sebagai barang rongsokan yang tercabik-cabik.\qt@no{42}}%
\qt@newcmd\qurantrans@id@mmmmdccxviii{%
(Dan pada) kisah pembinasaan kaum (Tsamud) terdapat tanda yang dijadikan sebagai pelajaran (ketika dikatakan kepada mereka) sesudah mereka menyembelih unta, ("Bersenang-senanglah kalian sampai suatu waktu") yakni sampai habisnya ajal kalian, dan di dalam ayat lain disebutkan, ``Bersukarialah kamu sekalian di rumah kalian selama tiga, hari." (Q.S. Hud, 65)\qt@no{43}}%
\qt@newcmd\qurantrans@id@mmmmdccxix{%
(Maka mereka berlaku angkuh) bersikap sombong (terhadap perintah Rabb mereka) yaitu mereka tidak mau mengerjakannya (lalu mereka disambar petir) yakni teriakan yang membinasakan mereka, hal ini terjadi setelah tiga hari sejak mereka menyembelih unta itu (sedangkan mereka melihatnya) karena azab itu terjadi di siang hari.\qt@no{44}}%
\qt@newcmd\qurantrans@id@mmmmdccxx{%
(Maka mereka sama sekali tidak dapat bangun) mereka tidak mampu bangkit sewaktu azab turun kepada mereka (dan tiadalah mereka orang-orang yang dapat mengalahkan) yang membinasakan mereka.\qt@no{45}}%
\qt@newcmd\qurantrans@id@mmmmdccxxi{%
(Dan kaum Nuh) kalau dibaca Qaumi Nuuh, dibaca Jar, berarti di-'athaf-kan kepada lafal Tsamuuda; yakni di dalam pembinasaan mereka dengan azab yang turun dari langit dan azab dari bumi terdapat pelajaran. Kalau dibaca Nashab yakni Qauma Nuuh artinya, kami telah membinasakan kaum Nuh (sebelum itu) sebelum dibinasakan orang-orang yang telah disebutkan tadi. (Sesungguhnya mereka adalah kaum yang fasik).\qt@no{46}}%
\qt@newcmd\qurantrans@id@mmmmdccxxii{%
(Dan langit itu Kami bangun dengan kekuasaan Kami) dengan kekuatan Kami (dan sesungguhnya Kami benar-benar berkuasa) dikatakan Adar Rajulu Ya-idu Qawiyyu artinya lelaki itu menjadi kuat. Dikatakan Awsa'ar Rajulu, artinya ia menjadi orang yang memiliki pengaruh dan kekuatan.\qt@no{47}}%
\qt@newcmd\qurantrans@id@mmmmdccxxiii{%
(Dan bumi itu Kami hamparkan) Kami buat terhampar, menurut pandangan mata (maka sebaik-baik yang menghamparkan) adalah Kami.\qt@no{48}}%
\qt@newcmd\qurantrans@id@mmmmdccxxiv{%
(Dan segala sesuatu) ber-ta'alluq kepada lafal Khalaqnaa (Kami ciptakan berpasang-pasangan) yakni dari dua jenis, yaitu jenis pria dan wanita; ada langit dan ada bumi; ada matahari dan ada bulan; ada dataran rendah dan ada dataran tinggi, ada musim panas dan ada musim dingin, ada rasa manis dan ada rasa masam, ada gelap dan ada terang (supaya kalian berfikir) asal kata Tadzakkaruuna adalah Tatadzakkaruuna, lalu salah satu huruf Ta-nya dibuang sehingga jadilah Tadzakkaruuna. Karena itu kalian mengetahui bahwa Pencipta pasangan-pasangan itu adalah Esa, lalu kalian menyembah-Nya.\qt@no{49}}%
\qt@newcmd\qurantrans@id@mmmmdccxxv{%
(Maka segeralah kembali kepada Allah) larilah kalian kepada pahala-Nya dari siksaan-Nya, yaitu dengan jalan menaati-Nya dan tidak mendurhakai-Nya. (Sesungguhnya aku seorang pemberi peringatan yang nyata dari Allah untuk kalian) aku adalah seorang pemberi peringatan yang jelas lagi gamblang.\qt@no{50}}%
\qt@newcmd\qurantrans@id@mmmmdccxxvi{%
(Dan Janganlah kalian mengadakan tuhan Yang lain di samping Allah. Sesunguhnya aku seorang pemberi peringatan yang nyata dari Allah untuk kalian) sebelum firman-Nya, ``Fafirruu" diperkirakan ada lafal Qul Lahum artinya, ``Katakanlah kepada mereka."\qt@no{51}}%
\qt@newcmd\qurantrans@id@mmmmdccxxvii{%
(Demikianlah tidak seorang rasul pun yang datang kepada orang-orang yang sebelum mereka, melainkan mereka mengatakan,) ``Dia (adalah seorang tukang sihir atau orang gila") sebagaimana mereka mendustakanmu melalui perkataan mereka, bahwa sesungguhnya kami adalah seorang tukang sihir atau kamu adalah orang gila. Maka umat-umat terdahulu pun pernah mengatakan hal yang serupa sewaktu mereka mendustakan rasul-rasulnya.\qt@no{52}}%
\qt@newcmd\qurantrans@id@mmmmdccxxviii{%
(Apakah mereka saling berpesan) mereka semuanya (tentang hal itu) Istifham atau kata tanya di sini mengandung makna Nafi. (Sebenarnya mereka adalah kaum yang melampaui batas) sikap kelewat batas merekalah yang mendorong mereka semuanya mengatakan perkataan tersebut.\qt@no{53}}%
\qt@newcmd\qurantrans@id@mmmmdccxxix{%
(Maka berpalinglah kamu) palingkanlah dirimu (dari mereka dan kamu sekali-kali tidak tercela) karena sesungguhnya kamu telah menyampaikan risalahmu kepada mereka.\qt@no{54}}%
\qt@newcmd\qurantrans@id@mmmmdccxxx{%
(Dan tetaplah memberi peringatan) maksudnya, tetaplah memberi nasihat dengan Alquran (karena sesungguhnya peringatan itu bermanfaat bagi orang-orang yang beriman) hal ini termasuk ilmu Allah swt. yang telah mengetahui, bahwa orang yang bersangkutan adalah orang yang beriman.\qt@no{55}}%
\qt@newcmd\qurantrans@id@mmmmdccxxxi{%
(Dan Aku tidak menciptakan jin dan manusia melainkan supaya mereka menyembah-Ku) pengertian dalam ayat ini sama sekali tidak bertentangan dengan kenyataan, bahwa orang-orang kafir tidak menyembah-Nya. Karena sesungguhnya tujuan dari ayat ini tidaklah memastikan keberadaannya. Perihalnya sama saja dengan pengertian yang terdapat di dalam perkataanmu, ``Aku runcingkan pena ini supaya aku dapat menulis dengannya." Dan kenyataannya terkadang kamu tidak menggunakannya.\qt@no{56}}%
\qt@newcmd\qurantrans@id@mmmmdccxxxii{%
(Aku tidak menghendaki rezeki sedikit pun dari mereka) untuk-Ku dan untuk mereka serta untuk selain mereka (dan Aku tidak menghendaki supaya mereka memberi Aku makan) baik dari diri mereka atau pun dari selain mereka.\qt@no{57}}%
\qt@newcmd\qurantrans@id@mmmmdccxxxiii{%
(Sesungguhnya Allah Dialah Maha Pemberi rezeki Yang mempunyai Kekuatan lagi Sangat Kokoh) yakni Sangat Perkasa.\qt@no{58}}%
\qt@newcmd\qurantrans@id@mmmmdccxxxiv{%
(Maka sesungguhnya untuk orang-orang yang aniaya) terhadap diri mereka sendiri karena melakukan kekafiran, yaitu dari kalangan penduduk Mekah dan lain-lainnya (ada bagian) bagian siksaan (seperti bagian) yakni sebagaimana bagian siksa yang diterima oleh (teman-teman mereka) yang telah binasa sebelum mereka (maka janganlah mereka meminta kepada-Ku menyegerakannya) meminta azab disegerakan atas mereka bila Aku menangguhkannya sampai hari kiamat nanti.\qt@no{59}}%
\qt@newcmd\qurantrans@id@mmmmdccxxxv{%
(Maka kecelakaanlah) artinya, azab yang amat keraslah (bagi orang-orang yang kafir pada) (hari yang diancamkan kepada mereka) pada hari kiamat nanti.\qt@no{60}}%
\qt@newcmd\qurantrans@id@mmmmdccxxxvi{%
\basmalahid (Demi Thur) Thur nama sebuah bukit tempat Allah berfirman secara langsung kepada Nabi Musa.\qt@no{1}}%
\qt@newcmd\qurantrans@id@mmmmdccxxxvii{%
(Dan demi Kitab yang ditulis).\qt@no{2}}%
\qt@newcmd\qurantrans@id@mmmmdccxxxviii{%
(Pada lembaran yang terbuka) yakni kitab Taurat atau kitab Alquran.\qt@no{3}}%
\qt@newcmd\qurantrans@id@mmmmdccxxxix{%
(Dan demi Baitulmakmur) yang berada di langit ketiga, atau keenam atau yang ketujuh, letaknya persis berada di atas Kakbah; setiap hari diziarahi oleh tujuh puluh ribu malaikat yang melakukan tawaf dan salat di situ dan mereka tidak kembali lagi kepadanya untuk selama-lamanya.\qt@no{4}}%
\qt@newcmd\qurantrans@id@mmmmdccxl{%
(Dan demi atap yang ditinggikan) yakni langit.\qt@no{5}}%
\qt@newcmd\qurantrans@id@mmmmdccxli{%
(Dan demi laut yang penuh) penuh airnya.\qt@no{6}}%
\qt@newcmd\qurantrans@id@mmmmdccxlii{%
(Sesungguhnya azab Rabbmu pasti terjadi) pasti menimpa orang yang berhak menerimanya.\qt@no{7}}%
\qt@newcmd\qurantrans@id@mmmmdccxliii{%
(Tidak ada seorang pun yang dapat menolaknya) yang mampu menolak azab itu.\qt@no{8}}%
\qt@newcmd\qurantrans@id@mmmmdccxliv{%
(Pada hari) menjadi Ma'mul bagi lafal Waaqi'un (ketika langit benar-benar berguncang) pada waktu langit bergerak dan berputar.\qt@no{9}}%
\qt@newcmd\qurantrans@id@mmmmdccxlv{%
(Dan gunung-gunung benar-benar berjalan) maksudnya, menjadi debu yang beterbangan, demikian itu adalah hari kiamat.\qt@no{10}}%
\qt@newcmd\qurantrans@id@mmmmdccxlvi{%
(Maka kecelakaan yang besar) azab yang keras (di hari itu bagi orang-orang yang mendustakan) rasul-rasul.\qt@no{11}}%
\qt@newcmd\qurantrans@id@mmmmdccxlvii{%
(Yaitu orang-orang yang dalam kebatilan) dalam perkara yang batil (mereka bermain-main) mereka sibuk dengan kekafiran mereka.\qt@no{12}}%
\qt@newcmd\qurantrans@id@mmmmdccxlviii{%
(pada hari mereka didorong ke neraka Jahanam dengan sekuat-kuatnya) mereka didorong dengan kasar. Lafal ayat ini menjadi Badal dari lafal Yauma Tamuuru. Kemudian dikatakan kepada mereka dengan nada mencemoohkan,\qt@no{13}}%
\qt@newcmd\qurantrans@id@mmmmdccxlix{%
("Inilah neraka yang dahulu kalian selalu mendustakannya").\qt@no{14}}%
\qt@newcmd\qurantrans@id@mmmmdccl{%
(Maka apakah ini sihir) maksudnya, apakah azab yang kalian lihat sekarang seperti juga apa yang kalian katakan mengenai wahyu, bahwa itu adalah sihir. (Ataukah kalian tidak melihat?).\qt@no{15}}%
\qt@newcmd\qurantrans@id@mmmmdccli{%
(Masukilah ia dan bersabarlah kalian) menanggung azabnya (atau kalian tidak bersabar) kalian tidak tahan (sama saja bagi kalian) karena sesungguhnya kesabaran kalian tidak ada manfaatnya sama sekali (sesungguhnya kalian hanya diberi balasan terhadap apa yang telah kalian kerjakan) tentang pembalasannya.\qt@no{16}}%
\qt@newcmd\qurantrans@id@mmmmdcclii{%
(Sesungguhnya orang-orang yang bertakwa berada dalam surga dan kenikmatan).\qt@no{17}}%
\qt@newcmd\qurantrans@id@mmmmdccliii{%
(Mereka bersuka ria) artinya, hidup penuh dengan kesenangan (dengan apa) huruf Maa di sini adalah Mashdariyah (yang didatangkan kepada mereka) diberikan kepada mereka (oleh Rabb mereka; dan Rabb mereka memelihara mereka dari azab neraka) lafal Wawaqaahum di'athafkan kepada lafal Ataahum. Yakni mereka hidup dengan pemberian Rabb mereka dan berada dalam pemeliharaan-Nya. Lalu dikatakan kepada mereka,\qt@no{18}}%
\qt@newcmd\qurantrans@id@mmmmdccliv{%
("Makan dan minumlah dengan enak) lafal Hanii-an menjadi Hal atau kata keterangan keadaan, artinya dengan nikmat (sebagai balasan dari apa) huruf Ba di sini mengandung makna Sababiyah (yang telah kalian kerjakan").\qt@no{19}}%
\qt@newcmd\qurantrans@id@mmmmdcclv{%
(Mereka bertelekan) menjadi Hal dari Dhamir yang terkandung di dalam firman-Nya, ``Fii jannaatin" (di atas dipan-dipan berderetan) sebagian dari dipan-dipan itu letaknya berdampingan dengan yang lainnya (dan Kami kawinkan mereka) di'athafkan kepada lafal jannaatin, yakni Kami buat mereka senang dan tenang (dengan bidadari-bidadari) yang jeli matanya lagi sangat cantik.\qt@no{20}}%
\qt@newcmd\qurantrans@id@mmmmdcclvi{%
(Dan orang-orang yang beriman) berkedudukan menjadi Mubtada (dan mereka diikuti) menurut suatu qiraat dibaca Wa-atba'naahum yakni, Kami ikutkan kepada mereka, Di'athafkan kepada lafal Amanuu (oleh anak cucu mereka) menurut suatu qiraat dibaca Dzurriyyatahum, dalam bentuk Mufrad; artinya oleh keturunan mereka, baik yang masih kecil maupun yang sudah dewasa (dalam keimanan) maksudnya, diikuti oleh anak cucu mereka keimanannya. Dan yang menjadi Khabarnya ialah (Kami hubungkan anak cucu mereka dengan mereka) ke dalam surga, dengan demikian maka anak cucu mereka memiliki kedudukan yang sama dengan mereka, sekalipun anak cucu mereka tidak mempunyai amalan sebagaimana mereka. Hal ini dimaksudkan sebagai kehormatan buat bapak-bapak mereka, yang karenanya lalu anak cucu mereka dikumpulkan dengan mereka (dan Kami tidak mengurangi) dapat dibaca Alatnaahum atau Alitnaahum, artinya Kami tidak mengurangi (dari pahala amal mereka) huruf Min di sini adalah Zaidah (barang sedikit pun) yang ditambahkan kepada amal perbuatan anak-cucu mereka. (Tiap-tiap orang dengan apa yang dikerjakannya) yakni amal baik atau amal buruknya (terikat) yakni, ia dalam keadaan terikat, bila ia mengerjakan kejahatan diazab dan bila ia mengerjakan kebaikan diberi pahala.\qt@no{21}}%
\qt@newcmd\qurantrans@id@mmmmdcclvii{%
(Dan Kami beri mereka) Kami tambahkan kepada mereka dari waktu ke waktu yang lain (dengan buah-buahan dan daging dari segala jenis yang mereka inginkan) sekalipun mereka tidak menjelaskan permintaannya.\qt@no{22}}%
\qt@newcmd\qurantrans@id@mmmmdcclviii{%
(Mereka saling memperebutkan) mereka saling beri (di dalamnya) dalam surga (piala) yang berisikan khamar (yang isinya tidak menimbulkan kata-kata yang tidak berfaedah) di antara mereka disebabkan karena meminumnya (dan tiada pula perbuatan dosa) yang menimpa mereka disebabkan meminumnya, berbeda dengan khamar di dunia.\qt@no{23}}%
\qt@newcmd\qurantrans@id@mmmmdcclix{%
(Dan berkeliling di sekitar mereka) sebagai pelayan-pelayan (anak-anak muda) yang semuanya orang-orang merdeka (untuk meladeni mereka seakan-akan mereka itu) kecakapan dan kelembutannya (mutiara yang tersimpan) artinya mereka itu bagaikan mutiara yang disimpan di dalam laut; karena sesungguhnya mutiara yang tersimpan di dalam laut itu jauh lebih indah daripada mutiara-mutiara yang berada di tempat lainnya.\qt@no{24}}%
\qt@newcmd\qurantrans@id@mmmmdcclx{%
(Dan sebagian mereka menghadap kepada sebagian yang lain saling tanya menanya) atau sebagian di antara mereka bertanya kepada sebagian yang lain tentang apa yang telah mereka kerjakan di dunia, dan tentang pahala yang telah mereka peroleh, dengan maksud untuk bersenang-senang dan mengakui nikmat Allah.\qt@no{25}}%
\qt@newcmd\qurantrans@id@mmmmdcclxi{%
(Mereka berkata) seraya mengisyaratkan kepada penyebab mereka sampai kepada derajat ini, ("Sesungguhnya kami dahulu, sewaktu berada di tengah-tengah keluarga kami) di dunia (kami merasa takut) akan azab Allah.\qt@no{26}}%
\qt@newcmd\qurantrans@id@mmmmdcclxii{%
(Maka Allah memberikan karunia kepada kami) berupa ampunan (dan memelihara kami dari azab neraka") dinamakan Samuum karena sakitnya sampai merasuk ke dalam pori-pori. Dan mereka mengisyaratkan pula melalui perkataan mereka,\qt@no{27}}%
\qt@newcmd\qurantrans@id@mmmmdcclxiii{%
("Sesungguhnya kami dahulu) sewaktu di dunia (menyeru-Nya) menyembah dan mengesakan-Nya. (Sesungguhnya Dia) kalau dibaca Innahuu dengan dikasrahkan huruf Hamzahnya, berarti merupakan jumlah Isti'naf atau kalimat permulaan, sekalipun maknanya mengandung 'Illat. Dan bila dibaca Annahuu dengan difatahkan huruf Hamzahnya, berarti lafalnya menunjukkan makna 'Illat (adalah yang melimpahkan kebaikan) Yang berbuat kebaikan dan menepati janji-Nya (lagi Maha\qt@no{28}}%
\qt@newcmd\qurantrans@id@mmmmdcclxiv{%
(Maka tetaplah memberi peringatan) tetaplah kamu memberi peringatan kepada orang-orang musyrik dan jangan sekali-kali kamu mundur dalam hal ini hanya karena mereka mengatakanmu sebagai seorang penenung lagi gila (dan kamu disebabkan nikmat Rabbmu bukanlah) karena limpahan nikmat-Nya kepadamu (seorang tukang tenung) menjadi Khabar dari Maa (dan bukan pula seorang gila") lafal ayat ini di'athafkan kepada lafal Kaahinin.\qt@no{29}}%
\qt@newcmd\qurantrans@id@mmmmdcclxv{%
(Bahkan) lebih dari itu (mereka mengatakan,) ``Dia (adalah seorang penyair yang kami tunggu-tunggu kecelakaan menimpanya") malapetaka menimpanya lalu ia binasa sebagaimana nasib yang dialami oleh para penyair lainnya.\qt@no{30}}%
\qt@newcmd\qurantrans@id@mmmmdcclxvi{%
(Katakanlah! ``Tunggulah) oleh kalian kebinasaanku (maka sesungguhnya aku pun termasuk orang yang menunggu pula bersama kalian") menunggu kebinasaan kalian; akhirnya mereka disiksa oleh Allah melalui pedang dalam perang Badar. Makna Tarabbush. adalah menunggu.\qt@no{31}}%
\qt@newcmd\qurantrans@id@mmmmdcclxvii{%
(Apakah mereka diperintah oleh pikiran pikiran mereka) oleh akal pikiran mereka (untuk mengucapkan tuduhan-tuduhan itu) yakni perkataan mereka terhadapnya, bahwa dia adalah seorang tukang sihir, seorang tukang tenung, dan seorang gila. Maksudnya, ialah bahwa pikiran-pikiran mereka tidak memerintahkan mereka untuk melakukan hal tersebut (bahkan) lebih dari itu (mereka kaum yang melampaui batas) dengan keingkaran dan pembangkangan mereka itu.\qt@no{32}}%
\qt@newcmd\qurantrans@id@mmmmdcclxviii{%
(Ataukah mereka mengatakan, bahwa dia membuat-buatnya) yakni Nabi Muhammad telah membuat-buat Alquran, padahal dia tidak membuat-buatnya (sebenarnya mereka tidak beriman) karena kesombongan mereka. Jika mereka mengatakan bahwa Muhammad telah membuat-buatnya.\qt@no{33}}%
\qt@newcmd\qurantrans@id@mmmmdcclxix{%
(Maka hendaklah mereka mendatangkan kalimat) yang dibuat-buat (yang semisal dengan Alquran itu jika mereka orang-orang yang benar) di dalam tuduhannya itu.\qt@no{34}}%
\qt@newcmd\qurantrans@id@mmmmdcclxx{%
(Apakah mereka diciptakan tanpa sesuatu pun) tanpa ada yang menciptakannya (ataukah mereka yang menciptakan) diri mereka sendiri. Dan tidak masuk akal ada makhluk tanpa pencipta, dan tiada sesuatu yang Ma'dum yakni yang asalnya tiada, dapat menciptakan yang menciptakannya, yaitu Allah yang Maha Esa. Mereka tetap tidak mau mengesakan-Nya dan tidak mau beriman kepada rasul dan kitab-Nya.\qt@no{35}}%
\qt@newcmd\qurantrans@id@mmmmdcclxxi{%
(Ataukah mereka telah menciptakan langit dan bumi itu?) tiada seorang pun yang dapat menciptakan keduanya selain Allah Yang Maha Pencipta; maka mengapa tidak menyembah-Nya. (Sebenarnya mereka tidak meyakini) Allah, karena seandainya mereka beriman kepada-Nya, niscaya mereka pun akan beriman kepada Nabi-Nya.\qt@no{36}}%
\qt@newcmd\qurantrans@id@mmmmdcclxxii{%
(Ataukah di sisi mereka ada perbendaharaan Rabbmu) berupa kenabian, rezeki dan hal-hal lainnya, lalu karenanya mereka dapat memberikannya kepada siapa yang dikehendaki oleh mereka sesuai dengan apa yang mereka sukai (atau merekakah yang berkuasa?) yang mempunyai kekuasaan dan dapat berlaku sewenang-wenang. Fi'il atau kata kerja dari lafal Mushaythir ini adalah Saythara, maknanya sesinonim dengan lafal Baithara dan Baiqara.\qt@no{37}}%
\qt@newcmd\qurantrans@id@mmmmdcclxxiii{%
(Ataukah mereka mempunyai tangga) alat untuk naik ke langit (untuk mendengarkan pada langit itu?) perkataan para malaikat sehingga mereka dapat menyaingi nabi, sesuai dengan pengakuan mereka seandainya mereka mengaku-aku memiliki hal tersebut (Maka hendaklah orang yang mendengarkan di antara mereka mendatangkan) orang yang mengaku-aku dapat mendengarkan perkataan malaikat-malaikat di langit (suatu keterangan yang nyata) atau hujah yang jelas lagi gamblang. Mengingat adanya keserupaan pada tuduhan ini dengan tuduhan mereka yang menyatakan, bahwa malaikat-malaikat itu adalah anak-anak perempuan Allah, maka Allah swt. berfirman,\qt@no{38}}%
\qt@newcmd\qurantrans@id@mmmmdcclxxiv{%
("Ataukah untuk Allah anak-anak perempuan) sesuai dengan tuduhan kalian (dan untuk kalian anak-anak laki-laki?) Maha Tinggi Allah dari segala apa yang mereka duga itu.\qt@no{39}}%
\qt@newcmd\qurantrans@id@mmmmdcclxxv{%
(Ataukah kalian meminta upah kepada mereka) atas jerih payahmu di dalam menyampaikan agama yang kamu datangkan itu (sehingga mereka oleh utang mereka) oleh tanggungan dalam hal itu (dibebani) karena itu mereka tidak dapat mengembalikannya.\qt@no{40}}%
\qt@newcmd\qurantrans@id@mmmmdcclxxvi{%
(Apakah ada pada sisi mereka pengetahuan tentang yang gaib) mengetahui hal yang gaib (lalu mereka menuliskannya?) sehingga mereka mampu untuk menentang Nabi saw dalam masalah hari berbangkit dan perkara-perkara akhirat sesuai dengan dugaan mereka.\qt@no{41}}%
\qt@newcmd\qurantrans@id@mmmmdcclxxvii{%
(Ataukah mereka hendak melakukan tipu daya?) terhadap dirimu dengan maksud untuk membinasakan dirimu, sewaktu mereka berkumpul di Darunnadwah. (Maka orang-orang yang kafir itu merekalah yang kena tipu daya) maksudnya, merekalah yang kalah dan binasa. Allah memelihara nabi dari ulah mereka, kemudian Dia membinasakan mereka dalam perang Badar.\qt@no{42}}%
\qt@newcmd\qurantrans@id@mmmmdcclxxviii{%
(Ataukah mereka mempunyai tuhan selain Allah. Maha Suci Allah dari apa yang mereka persekutukan") yakni berhala-berhala yang mereka persekutukan dengan-Nya. Kata tanya dengan memakai lafal Am pada ayat ini dan ayat-ayat sebelumnya mengandung makna memburuk-burukkan dan mencela perbuatan mereka.\qt@no{43}}%
\qt@newcmd\qurantrans@id@mmmmdcclxxix{%
(Jika mereka melihat sebagian) bagian (dari langit yang gugur) menimpa mereka, sebagaimana yang mereka minta, yaitu seperti yang dijelaskan oleh ayat lain melalui firman-Nya, ``Maka jatuhkanlah atas kami gumpalan dari langit." (Q.S. Asy Syu'ara, 187) sebagai azab atas mereka (mereka akan mengatakan,) ``Ini (adalah awan yang bertindih-tindih) awan yang tebal yang akan menyegarkan kami dan mereka tidak mau beriman."\qt@no{44}}%
\qt@newcmd\qurantrans@id@mmmmdcclxxx{%
(Maka biarkanlah mereka hingga mereka menemui hari mereka yang pada hari itu mereka dibinasakan) yaitu mati semuanya.\qt@no{45}}%
\qt@newcmd\qurantrans@id@mmmmdcclxxxi{%
(Yaitu hari ketika tidak berguna) menjadi Badal dari lafal Yaumahum (bagi mereka sedikit pun tipu daya mereka dan mereka tidak ditolong) tidak diselamatkan dari azab di akhirat.\qt@no{46}}%
\qt@newcmd\qurantrans@id@mmmmdcclxxxii{%
(Dan sesungguhnya untuk orang-orang yang lalim) disebabkan kekafiran mereka (ada azab selain daripada itu) di dunia, sebelum kematian mereka; maka mereka disiksa oleh kelaparan dan kekeringan selama tujuh tahun, serta oleh pembunuhan dalam perang Badar. (Tetapi kebanyakan mereka tidak mengetahui) bahwasanya azab itu akan menimpa mereka.\qt@no{47}}%
\qt@newcmd\qurantrans@id@mmmmdcclxxxiii{%
(Dan bersabarlah dalam menunggu ketetapan Rabbmu) yaitu dengan ditangguhkannya mereka dan janganlah dadamu merasa sempit karenanya (maka sesungguhnya kamu berada dalam pengawasan-Ku) yaitu selalu dalam lindungan dan pengawasan-Ku (dan bertasbihlah) seraya (memuji Rabbmu) yaitu katakanlah, 'Subhaanallah Wa Bihamdihii' (ketika kamu bangun berdiri) dari tidurmu atau dari tempat majelismu.\qt@no{48}}%
\qt@newcmd\qurantrans@id@mmmmdcclxxxiv{%
(Dan pada beberapa saat di malam hari bertasbih pulalah) pengertian bertasbih di sini adalah tasbih hakiki yaitu membaca, 'Subhaanallaah Wa bihamdihii' (dan di waktu terbenam bintang-bintang) lafal Idbaar adalah bentuk Mashdar, yakni setelah bintang-bintang itu terbenam maka bertasbih pulalah kamu. Atau lakukanlah salat Isya'ain yaitu Magrib dan Isya, pada pengertian yang pertama, dan pada pengertian yang kedua adalah salat fajar; menurut pendapat lain salat Subuh.\qt@no{49}}%
\qt@newcmd\qurantrans@id@mmmmdcclxxxv{%
\basmalahid (Demi bintang) yaitu bintang Tsurayya (ketika terbenam) sewaktu terbenam.\qt@no{1}}%
\qt@newcmd\qurantrans@id@mmmmdcclxxxvi{%
(Kawanmu tidak sesat) artinya, Nabi Muhammad saw. tidak sesat dari jalan petunjuk (dan tidak pula keliru) tidak pula salah, yang dimaksud adalah dia tidak bodoh tentang akidah yang rusak.\qt@no{2}}%
\qt@newcmd\qurantrans@id@mmmmdcclxxxvii{%
(Dan tiadalah apa yang diucapkannya itu) apa yang disampaikannya kepada kalian (menurut kemauan hawa nafsunya) menurut kehendaknya sendiri.\qt@no{3}}%
\qt@newcmd\qurantrans@id@mmmmdcclxxxviii{%
(Tiada lain) tidak lain (ucapannya itu hanyalah wahyu yang diwahyukan) kepadanya.\qt@no{4}}%
\qt@newcmd\qurantrans@id@mmmmdcclxxxix{%
(Yang diajarkan kepadanya) oleh malaikat (yang sangat kuat).\qt@no{5}}%
\qt@newcmd\qurantrans@id@mmmmdccxc{%
(Yang mempunyai kecerdasan) yang mempunyai kekuatan dan keperkasaan, atau yang mempunyai pandangan yang baik, yang dimaksud adalah malaikat Jibril a.s. (maka menetaplah ia) maksudnya, menampakkan diri dengan rupa aslinya.\qt@no{6}}%
\qt@newcmd\qurantrans@id@mmmmdccxci{%
(Sedangkan dia berada di ufuk yang tinggi) berada pada tempat terbitnya matahari dalam bentuk aslinya ketika ia diciptakan. Nabi saw., melihatnya sewaktu berada di gua Hira; dan ternyata tubuh malaikat Jibril menutupi cakrawala tempat terbitnya matahari hingga sampai ke cakrawala bagian timur. Lalu Nabi saw. pingsan tidak sadarkan diri setelah melihat wujud asli malaikat Jibril itu. Nabi saw. pernah meminta kepada malaikat Jibril supaya menampakkan wujud aslinya sebagaimana ketika ia diciptakan oleh Allah, lalu malaikat Jibril menjanjikan akan memenuhi hal tersebut di gua Hira. Setelah itu baru malaikat Jibril turun untuk menemuinya dalam bentuk Bani Adam.\qt@no{7}}%
\qt@newcmd\qurantrans@id@mmmmdccxcii{%
(Kemudian dia mendekat) kepadanya (lalu bertambah dekat) semakin dekat dengannya.\qt@no{8}}%
\qt@newcmd\qurantrans@id@mmmmdccxciii{%
(Maka jadilah dia) padanya (mendekat) dalam jarak (dua ujung busur panah atau lebih dekat lagi) dari tempatnya yang semula sehingga nabi menjadi sadar kembali dan hilanglah rasa takutnya.\qt@no{9}}%
\qt@newcmd\qurantrans@id@mmmmdccxciv{%
(Lalu Dia menyampaikan) yakni Allah swt. (kepada hamba-Nya) yaitu malaikat Jibril (apa yang telah diwahyukan)-Nya kepada malaikat Jibril untuk disampaikan kepada Nabi saw. Di sini yang mewahyukan tidak disebutkan karena mengagungkan kedudukan-Nya.\qt@no{10}}%
\qt@newcmd\qurantrans@id@mmmmdccxcv{%
(Tiada mendustakan) dapat dibaca Kadzaba atau Kadzdzaba, artinya tiada mengingkari (hati) atau kalbu Nabi saw. (apa yang telah dilihatnya) dengan mata kepalanya sendiri tentang rupa malaikat Jibril.\qt@no{11}}%
\qt@newcmd\qurantrans@id@mmmmdccxcvi{%
(Maka apakah kalian hendak membantahnya) apakah kalian hendak mendebatnya dan mengalahkannya (tentang apa yang telah dilihatnya?) khithab di sini ditujukan kepada orang-orang musyrik yang tidak mempercayai bahwa Nabi saw. melihat malaikat Jibril.\qt@no{12}}%
\qt@newcmd\qurantrans@id@mmmmdccxcvii{%
(Dan sesungguhnya dia telah melihat Jibril itu) dalam rupa yang asli (pada waktu) pada kesempatan (yang lain).\qt@no{13}}%
\qt@newcmd\qurantrans@id@mmmmdccxcviii{%
(Yaitu di Sidratul Muntaha) sewaktu nabi dibawanya Isra ke langit. Sidratul Muntaha adalah nama sebuah pohon Nabaq yang terletak di sebelah kanan Arasy; tiada seorang malaikat pun dan tidak pula yang lainnya dapat melewati tempat itu.\qt@no{14}}%
\qt@newcmd\qurantrans@id@mmmmdccxcix{%
(Di dekatnya ada surga tempat tinggal) tempat tinggal para malaikat dan arwah-arwah para syuhada dan orang-orang yang bertakwa.\qt@no{15}}%
\qt@newcmd\qurantrans@id@mmmmdccc{%
(Ketika) sewaktu (Sidratul Muntaha diliputi oleh sesuatu yang meliputinya) yaitu oleh burung-burung dan lain-lainnya. Lafal Idz menjadi Ma'mul dari lafal Ra-aahu.\qt@no{16}}%
\qt@newcmd\qurantrans@id@mmmmdccci{%
(Penglihatannya tidak berpaling) penglihatan Nabi saw. tidak berpaling (dan tidak melampauinya) maksudnya, tidak berpaling dari apa yang dilihatnya dan tidak pula melampaui apa yang dilihatnya pada malam ketika ia diisrakkan.\qt@no{17}}%
\qt@newcmd\qurantrans@id@mmmmdcccii{%
(Sesungguhnya dia telah melihat) pada malam itu (sebagian tanda-tanda kekuasaan Rabbnya yang paling besar) yang paling agung, dimaksud adalah sebagian dari tanda-tanda itu, maka dia melihat sebagian dari keajaiban-keajaiban alam malakut, dan Rafraf berwarna hijau menutupi cakrawala langit, dan malaikat Jibril yang memiliki enam ratus sayap.\qt@no{18}}%
\qt@newcmd\qurantrans@id@mmmmdccciii{%
(Maka apakah patut kalian menganggap Laata dan Al Uzzaa).\qt@no{19}}%
\qt@newcmd\qurantrans@id@mmmmdccciv{%
(Dan Manat yang ketiga) yang ketiga dari yang telah disebutkan tadi (yang paling terkemudian) berkedudukan sebagai sifat yang mengandung makna celaan. Ketiganya adalah nama berhala-berhala yang terbuat dari batu. Orang-orang musyrik dahulu menyembahnya, karena mereka menduga, bahwa berhala-berhala itu dapat memberikan syafaat kepada diri mereka di sisi Allah. Maf'ul pertama bagi lafal Afara`aytum adalah lafal Al Laata dan lafal-lafal yang di'athafkan kepadanya. Sedangkan Maf'ul yang keduanya tidak disebutkan. Makna ayat, ``Ceritakanlah kepadaku, apakah berhala-berhala ini memiliki kemampuan untuk berbuat sesuatu yang karena itu kalian menyembahnya selain Allah Yang memiliki kemampuan untuk melakukan hal-hal yang telah disebutkan tadi." Ketika mereka menduga bahwa malaikat-malaikat itu adalah anak-anak perempuan Allah, sedangkan mereka sendiri tidak menyukai anak-anak perempuan, lalu turunlah firman-Nya berikut ini,\qt@no{20}}%
\qt@newcmd\qurantrans@id@mmmmdcccv{%
("Apakah patut untuk kalian anak laki-laki dan untuk Allah -anak -perempuan?").\qt@no{21}}%
\qt@newcmd\qurantrans@id@mmmmdcccvi{%
(Yang demikian itu tentulah suatu pembagian yang tidak adil) pembagian yang lalim; berasal dari lafal Dhaazahu Yadhiizuhu, artinya berlaku aniaya dan melampaui batas.\qt@no{22}}%
\qt@newcmd\qurantrans@id@mmmmdcccvii{%
(Itu tidak lain) apa-apa yang telah disebutkan itu (hanyalah nama-nama yang kalian adakan) kalian menamakannya (yakni oleh kalian dan bapak-bapak kalian) sebagai berhala-berhala yang kalian menyembahnya (Allah tidak menurunkan tentangnya) tentang menyembah kepada berhala-berhala itu (suatu keterangan pun) yakni bukti dan hujjah (tiada lain) (mereka hanya mengikuti) di dalam menyembah berhala-berhala itu (sangkaan saja dan apa yang diinginkan oleh hawa nafsu mereka) mengikuti apa yang dihiaskan oleh setan, ke dalam hati mereka, yaitu bahwasanya berhala-berhala itu dapat memberikan syafaat kepada diri mereka di sisi Allah swt. (dan sesungguhnya telah datang petunjuk kepada mereka dari Rabb mereka) melalui lisan Nabi saw. yang membawa bukti yang pasti, akan tetapi mereka tidak mau meninggalkan apa yang biasa mereka lakukan itu, yaitu menyembah berhala.\qt@no{23}}%
\qt@newcmd\qurantrans@id@mmmmdcccviii{%
(Atau apakah manusia akan mendapat) bagi masing-masing dari mereka (segala yang dicita-citakannya) yang beranggapan, bahwa berhala-berhala itu dapat memberikan syafaat kepada mereka? Padahal kenyataannya tidaklah demikian.\qt@no{24}}%
\qt@newcmd\qurantrans@id@mmmmdcccix{%
(Maka hanya bagi Allah kehidupan akhirat dan kehidupan dunia) tiada sesuatu pun yang terjadi pada keduanya melainkan sesuai dengan apa yang dikehendaki-Nya.\qt@no{25}}%
\qt@newcmd\qurantrans@id@mmmmdcccx{%
(Dan berapa banyaknya malaikat) banyak di antara para Malaikat (di langit) yang sangat dimuliakan oleh Allah di sisi-Nya (syafaat mereka sedikit pun tidak berguna kecuali sesudah Allah mengizinkan) kepada mereka untuk memberikan syafaat (bagi orang yang dikehendaki)-Nya di antara hamba-hamba-Nya (dan diridai) ia diridai oleh-Nya, karena ada firman lainnya yang menyatakan, ``.. dan mereka tiada memberi syafaat melainkan kepada orang yang diridai Allah." (Q.S. Al Anbiya, 28) Sudah kita maklumi bahwa syafaat para malaikat itu baru ada setelah terlebih dahulu mendapat izin dari Allah, sebagaimana yang dijelaskan dalam ayat lainnya, yaitu firman-Nya, ``Siapakah yang dapat memberi syafaat di sisi Allah tanpa izin-Nya?" (Q.S. Al-Baqarah, 255)\qt@no{26}}%
\qt@newcmd\qurantrans@id@mmmmdcccxi{%
(Sesungguhnya orang-orang yang tiada beriman kepada kehidupan akhirat, mereka benar-benar menamakan malaikat itu dengan nama perempuan) karena mereka telah mengatakan, bahwa para malaikat itu adalah anak-anak perempuan Allah.\qt@no{27}}%
\qt@newcmd\qurantrans@id@mmmmdcccxii{%
(Dan mereka tidak mendasari perkataan mereka itu) ucapan mereka itu tidak didasari (dengan sesuatu pengetahuan pun tentangnya. Tiada lain) mereka hanya mengikuti) dalam hal tersebut (prasangka) yang mereka khayalkan (sedangkan sesungguhnya prasangka itu tiada berfaedah sedikit pun terhadap kebenaran) maksudnya, tiada sedikit pun pengetahuan yang bermanfaat dalam prasangka itu di dalam menelaah hal-hal yang dituntut adanya pengetahuan.\qt@no{28}}%
\qt@newcmd\qurantrans@id@mmmmdcccxiii{%
(Maka berpalinglah dari orang yang berpaling dari peringatan Kami) orang yang berpaling dari Alquran (dan tidak mengingini kecuali kehidupan duniawi) ayat ini diturunkan sebelum ada perintah berjihad dari Allah.\qt@no{29}}%
\qt@newcmd\qurantrans@id@mmmmdcccxiv{%
(Yang demikian itu) yakni mencari keduniaan (adalah sejauh-jauh pengetahuan mereka) artinya, tujuan pengetahuan mereka ialah memilih keduniawian daripada akhirat. (Sesungguhnya Rabbmu, Dia-lah yang paling mengetahui siapa yang tersesat dari jalan-Nya dan Dia pulalah yang paling mengetahui siapa yang mendapat petunjuk) atau Dia mengetahui siapa yang mendapat petunjuk dan siapa yang tersesat, kelak Dia akan memberikan balasan-Nya kepada masing-masing.\qt@no{30}}%
\qt@newcmd\qurantrans@id@mmmmdcccxv{%
(Dia hanya kepunyaan Allah-lah apa yang ada di langit dan apa yang ada di bumi) Dia-lah yang memiliki kesemuanya itu; antara lain ialah orang yang tersesat dan orang yang mendapat petunjuk; Dia menyesatkan siapa yang dikehendaki-Nya dan Dia memberikan petunjuk kepada siapa yang dikehendaki-Nya (supaya Dia memberi balasan kepada orang-orang yang berbuat jahat terhadap apa yang mereka kerjakan) berupa kemusyrikan dan perbuatan-perbuatan dosa lainnya (dan memberi balasan kepada orang-orang yang berbuat baik) maksudnya, mereka yang mengerjakan ketauhidan dan amal-amal ketaatan lainnya (dengan pahala yang lebih baik) yakni surga. Kemudian Allah menjelaskan siapakah yang disebut orang-orang yang telah berbuat baik itu melalui firman selanjutnya,\qt@no{31}}%
\qt@newcmd\qurantrans@id@mmmmdcccxvi{%
("Yaitu orang-orang yang menjauhi dosa-dosa besar dan perbuatan-perbuatan keji selain dari kesalahan-kesalahan kecil) yang dimaksud dari lafal Al Lamam adalah dosa-dosa kecil seperti, melihat wanita lain, menciumnya dan menyentuhnya. Istitsna atau pengecualian di sini bersifat Munqathi' artinya dosa-dosa kecil itu diampuni oleh sebab menjauhi dosa-dosa besar. (Sesungguhnya Rabbmu Maha Luas ampunan-Nya) disebabkan hal tersebut, sebab Dia Penerima Tobat. Ayat ini diturunkan berkenaan dengan orang-orang yang telah mengatakan, salat kami, shaum kami dan haji kami (Dia lebih mengetahui) (tentang kalian ketika Dia menjadikan kalian dari tanah) ketika Dia menciptakan bapak moyang kalian yaitu Adam dari tanah (dan ketika kalian masih berupa janin lafal Ajinnatin adalah bentuk jamak dari lafal Janiin (dalam perut ibu kalian; maka janganlah kalian mengatakan diri kalian suci) janganlah kalian memuji-muji diri kalian sendiri dengan cara ujub atau takabur, akan tetapi bila kalian melakukannya dengan cara mengakui nikmat Allah, maka hal ini dianggap baik (Dia-lah Yang paling mengetahui) Yang mengetahui (tentang orang yang bertakwa").\qt@no{32}}%
\qt@newcmd\qurantrans@id@mmmmdcccxvii{%
(Maka apakah kamu melihat orang yang berpaling) dari keimanan, orang tersebut murtad dari Islam, yaitu ketika ia dicela karena masuk Islam. Lalu ia menjawab, ``Sesungguhnya aku takut akan azab atau siksaan Allah". Lalu orang yang mencelanya itu mau menanggung siksaan Allah yang akan diterimanya, bila ia kembali kepada kemusyrikan, dan orang yang menanggung itu bersedia untuk memberikan hartanya kepada dia, sejumlah sekian. Akhirnya dia mau kembali kepada kemusyrikannya.\qt@no{33}}%
\qt@newcmd\qurantrans@id@mmmmdcccxviii{%
(Serta memberi sedikit) dari harta yang telah disebutkan tadi (dan tidak mau memberi lagi?) yaitu dia tidak mau memberikan sisanya. Lafal Akdaa diambil dari asal kata Al Kidyah, arti asalnya adalah tanah yang keras seperti tanah yang berbatu, sehingga penggali sumur bila sampai kepada lapisan yang berbatu itu tidak dapat melanjutkan penggaliannya.\qt@no{34}}%
\qt@newcmd\qurantrans@id@mmmmdcccxix{%
(Apakah dia mempunyai pengetahuan tentang yang gaib sehingga dia mengetahui) sebagiannya, yaitu bahwa seseorang dapat menanggung azab akhirat yang diterima oleh orang lain? Jawabannya tentu saja tidak. Orang yang dimaksud dalam ayat ini adalah Walid ibnu Mughirah atau lainnya. Jumlah kalimat A'indahuu merupakan Maf'ul kedua dari lafal Ra-ayta, yang maknanya Akhbirnii, yakni ceritakanlah kepada-Ku.\qt@no{35}}%
\qt@newcmd\qurantrans@id@mmmmdcccxx{%
(Ataukah) yakni sebenarnya (belum diberitakan kepadanya apa yang ada dalam lembaran-lembaran Musa) yaitu lembaran-lembaran kitab Taurat atau lembaran-lembaran kitab suci sebelumnya.\qt@no{36}}%
\qt@newcmd\qurantrans@id@mmmmdcccxxi{%
(Dan) lembaran-lembaran (Ibrahim yang selalu memenuhi janji) maksudnya Nabi Ibrahim itu selalu menepati apa yang diperintahkan kepadanya,, sebagaimana yang disebutkan dalam ayat yang lain, yaitu firman-Nya, ``Dan (ingatlah) ketika Ibrahim diuji Rabbnya dengan beberapa kalimat (perintah dan larangan), lalu Ibrahim menunaikannya dengan lengkap." (Q.S. Al Baqarah, 124) Kemudian pengertian yang terkandung di dalam lafal Maa pada ayat sebelumnya, dijelaskan oleh firman berikutnya,\qt@no{37}}%
\qt@newcmd\qurantrans@id@mmmmdcccxxii{%
("Yaitu bahwasanya seorang yang berdosa tidak akan memikul dosa orang lain) dan seterusnya. Lafal An adalah bentuk Mukhaffafah dari Anna; artinya bahwa setiap diri itu tidak dapat menanggung dosa orang lain.\qt@no{38}}%
\qt@newcmd\qurantrans@id@mmmmdcccxxiii{%
(Dan bahwasanya) bahwasanya perkara yang sesungguhnya itu ialah (seorang manusia tiada memperoleh selain apa yang telah diusahakannya) yaitu memperoleh kebaikan dari usahanya yang baik, maka dia tidak akan memperoleh kebaikan sedikit pun dari apa yang diusahakan oleh orang lain.\qt@no{39}}%
\qt@newcmd\qurantrans@id@mmmmdcccxxiv{%
(Dan bahwasanya usahanya itu kelak akan diperlihatkan) kepadanya di akhirat.\qt@no{40}}%
\qt@newcmd\qurantrans@id@mmmmdcccxxv{%
(Kemudian akan diberi balasan kepadanya dengan balasan yang paling sempurna") pembalasan yang paling lengkap. Diambil dari asal kata, Jazaituhu Sa'yahu atau Bisa'yihi, artinya, ``Aku memberikan balasan terhadap usahanya, atau aku memberikannya balasan atas usahanya." Dengan kata lain lafal Jazaa ini boleh dibilang sebagai Fi'il Muta'addi atau Fi'il Lazim.\qt@no{41}}%
\qt@newcmd\qurantrans@id@mmmmdcccxxvi{%
(Dan bahwasanya) jika dibaca Anna berarti di'athafkan kepada kalimat sebelumnya, jika dibaca Inna berarti merupakan jumlah Isti-naf atau kalimat baru. Hal ini berlaku pula terhadap lafal yang sama yang jatuh sesudahnya, dengan demikian maka pengertian yang terkandung pada kalimat sesudah Anna pertama bukan termasuk ke dalam pengertian yang terkandung di dalam lembaran-lembaran Ibrahim (kepada Rabbmulah kesudahan) tempat kembali sesudah mati, lalu Dia memberikan balasan yang setimpal kepada mereka masing-masing.\qt@no{42}}%
\qt@newcmd\qurantrans@id@mmmmdcccxxvii{%
(Dan bahwasanya Dia-lah yang membuat orang tertawa) yang menjadikan gembira siapa yang dikehendaki-Nya (dan menangis) yang menjadikan sedih siapa yang dikehendaki-Nya.\qt@no{43}}%
\qt@newcmd\qurantrans@id@mmmmdcccxxviii{%
(Dan bahwasanya Dia-lah yang mematikan dan yang menghidupkan) kembali pada hari berbangkit nanti.\qt@no{44}}%
\qt@newcmd\qurantrans@id@mmmmdcccxxix{%
(Dan bahwasanya Dia-lah yang menciptakan berpasang-pasangan) kedua jenis yang berpasangan (laki-laki dan perempuan).\qt@no{45}}%
\qt@newcmd\qurantrans@id@mmmmdcccxxx{%
(Dari nuthfah) yakni air mani (apabila dipancarkan) bila ditumpahkan ke dalam rahim.\qt@no{46}}%
\qt@newcmd\qurantrans@id@mmmmdcccxxxi{%
(Dan bahwasanya Dia-lah yang menetapkan kejadian) huruf Hamzah lafal An Nasy`ah boleh dibaca panjang dan boleh dibaca pendek (yang lain) kejadian yang lain untuk dibangkitkan menjadi hidup kembali, sesudah penciptaan yang pertama.\qt@no{47}}%
\qt@newcmd\qurantrans@id@mmmmdcccxxxii{%
(Dan bahwasanya Dia yang memberi kekayaan) kepada manusia berupa harta benda (dan yang memberikan kecukupan) Dia memberikan harta untuk mencukupi kebutuhan orang itu.\qt@no{48}}%
\qt@newcmd\qurantrans@id@mmmmdcccxxxiii{%
(Dan bahwasanya Dia-lah Rabb bintang syi'ra) nama bintang yang berada di belakang bintang Jauza; bintang itu pada zaman jahiliah disembah-sembah.\qt@no{49}}%
\qt@newcmd\qurantrans@id@mmmmdcccxxxiv{%
(Dan bahwasanya Dia telah membinasakan kaum 'Ad yang pertama) menurut suatu qiraat harakat Tanwinnya diidgamkan kepada huruf Lam, bila huruf Lamnya didamahkan, tanpa memakai Hamzah. Ad adalah nama suatu kaum yang dikenal dengan nama kaum 'Ad, sedangkan kaum yang lainnya adalah kaum Nabi Saleh.\qt@no{50}}%
\qt@newcmd\qurantrans@id@mmmmdcccxxxv{%
(Dan kaum Tsamud) jika dibaca Sharf, dengan memakai Tanwin berarti nama kakek moyang, bila dibaca dengan tidak memakai Tanwin berarti nama suatu kabilah, berarti di'athafkan kepada lafal Ad. (Maka tidak seorang pun yang ditinggalkan) hidup; maksudnya tiada seorang pun di antara mereka yang dibiarkan hidup oleh-Nya.\qt@no{51}}%
\qt@newcmd\qurantrans@id@mmmmdcccxxxvi{%
(Dan Kaum Nuh sebelum itu) sebelum kaum Ad dan kaum Tsamud; kami binasakan mereka semuanya. (Sesungguhnya mereka adalah orang-orang yang paling lalim dan paling durhaka) yakni kaum Nabi Nuh itu jauh lebih lalim dan lebih durhaka daripada kaum 'Ad dan kaum Tsamud, karena Nabi Nuh tinggal bersama mereka dalam waktu yang lama sekali sebagaimana yang diungkapkan oleh Allah dalam firman-Nya, ``maka ia tinggal di antara mereka seribu tahun kurang lima puluh tahun." (Q.S. Al 'Ankabut, 14) Di samping mereka tidak mau beriman kepada Nabi Nuh, mereka juga menyakiti bahkan memukulinya.\qt@no{52}}%
\qt@newcmd\qurantrans@id@mmmmdcccxxxvii{%
(Dan penduduk Mu`tafikah) yaitu negeri-negeri tempat tinggal kaum Nabi Luth (yang telah dihancurkan) yaitu dijatuhkan dari atas langit sesudah diangkat dalam keadaan terbalik, lalu dijatuhkan ke bumi oleh malaikat Jibril atas perintah Allah swt.\qt@no{53}}%
\qt@newcmd\qurantrans@id@mmmmdcccxxxviii{%
(Lalu Allah menimpakan atas negeri-negeri itu) batu-batu sesudah dibalikkan (azab besar yang menimpanya) di dalam ungkapan ayat azab yang dimaksud sengaja tidak disebutkan secara jelas, sebagai gambaran tentang kengeriannya yang tak terperikan, hingga tidak dapat diungkapkan oleh kata-kata. Azab ini dijelaskan pula dalam surah Hud, melalui firman-Nya, ``Kami jadikan negeri kaum Luth itu yang di atas ke bawah (Kami balikkan), dan Kami hujani mereka dengan batu dari tanah yang terbakar." (Q.S. Hud, 82)\qt@no{54}}%
\qt@newcmd\qurantrans@id@mmmmdcccxxxix{%
(Maka terhadap nikmat Rabbmu yang manakah) yakni nikmat-nikmat-Nya yang menunjukkan kepada keesaan dan kekuasaan-Nya (kamu ragu-ragu) kamu meragukannya, hai manusia. Atau, kamu mendustakannya hai manusia?\qt@no{55}}%
\qt@newcmd\qurantrans@id@mmmmdcccxl{%
(Ini) Muhammad ini (adalah seorang pemberi peringatan di antara pemberi-pemberi peringatan yang terdahulu) artinya, sama dengan mereka. Maksudnya, dia adalah seorang rasul yang sama dengan rasul-rasul lain sebelumnya; ia diutus kepada kalian, sebagaimana para rasul terdahulu diutus kepada kaumnya masing-masing.\qt@no{56}}%
\qt@newcmd\qurantrans@id@mmmmdcccxli{%
(Telah dekat terjadinya hari kiamat) kiamat telah dekat masanya.\qt@no{57}}%
\qt@newcmd\qurantrans@id@mmmmdcccxlii{%
(Tiada baginya selain dari Allah) tiada seorang pun selain Allah (yang dapat menyatakan terjadinya) tiada yang mengetahui kapan terjadi dan tiada seorang pun yang dapat menyatakan kejadiannya selain Allah. Ayat ini mempunyai arti yang senada dengan ayat lainnya yaitu, firman-Nya, ``tidak ada seorang pun yang dapat menjelaskan waktu kedatangannya selain Dia." (Q.S. Al A'raf, 187).\qt@no{58}}%
\qt@newcmd\qurantrans@id@mmmmdcccxliii{%
(Maka apakah terhadap pemberitaan ini) Alquran ini (kalian merasa heran?) makna yang dimaksud ialah mendustakannya.\qt@no{59}}%
\qt@newcmd\qurantrans@id@mmmmdcccxliv{%
(Dan kalian menertawakan) karena memperolok-olokkannya (dan tidak menangis) sewaktu kalian mendengarkan ancaman dan peringatannya.\qt@no{60}}%
\qt@newcmd\qurantrans@id@mmmmdcccxlv{%
(Sedangkan kalian melengahkannya) lengah dan lalai mengenai apa yang diwajibkan kepada kalian untuk mengerjakannya.\qt@no{61}}%
\qt@newcmd\qurantrans@id@mmmmdcccxlvi{%
(Maka bersujudlah kalian kepada Allah) Yang telah menciptakan kalian (dan sembahlah) Dia, dan janganlah kalian menyembah dan bersujud kepada berhala-berhala.\qt@no{62}}%
\qt@newcmd\qurantrans@id@mmmmdcccxlvii{%
\basmalahid (Telah dekat datangnya saat itu) dimaksud hari kiamat (dan telah terbelah bulan) menjadi dua bagian; yang satu di atas bukit Abu Qubais dan yang lainnya tampak di atas bukit Qaiqa'an; hal itu merupakan mukjizat bagi Nabi saw. yaitu sewaktu orang-orang Quraisy memintanya, lalu Nabi saw. bersabda, ``Saksikanlah oleh kalian." Demikianlah menurut keterangan hadis yang diketengahkan oleh Asy Syaikhain.\qt@no{1}}%
\qt@newcmd\qurantrans@id@mmmmdcccxlviii{%
(Dan jika mereka melihat) yaitu orang-orang kafir Quraisy (sesuatu tanda) suatu mukjizat yang timbul dari Nabi saw. (mereka berpaling dan berkata,) ``Ini adalah (sihir yang kuat) sihir yang paling kuat", berasal dari kata Al Mirrah; artinya kuat atau terus menerus.\qt@no{2}}%
\qt@newcmd\qurantrans@id@mmmmdcccxlix{%
(Dan mereka mendustakan) Nabi saw. (dan mengikuti hawa nafsu mereka) dalam perkara yang batil (sedangkan tiap-tiap urusan) atau perkara yang baik dan perkara yang buruk (telah ada ketetapannya) bagi pemiliknya masing-masing, yaitu adakalanya masuk ke surga atau ke neraka.\qt@no{3}}%
\qt@newcmd\qurantrans@id@mmmmdcccl{%
(Dan sesungguhnya telah datang kepada mereka beberapa kisah) berita-berita tentang dibinasakan-Nya umat-umat yang telah mendustakan rasul-rasul mereka (yang di dalamnya terdapat cegahan) bagi mereka untuk melakukan hal yang serupa. Lafal Muzdajar adalah Mashdar atau Isim yang menunjukkan arti tempat, sedangkan huruf Dal-nya merupakan pergantian dari Ta Wazan Ifta'ala. Bila dikatakan Izdajartuhu atau Zajartuhu maka artinya, aku mencegahnya dengan keras. Huruf Maa adalah Maushulah atau Maa Maushufah.\qt@no{4}}%
\qt@newcmd\qurantrans@id@mmmmdcccli{%
(Itulah suatu hikmah) merupakan Khabar dari Mubtada yang tidak disebutkan, atau menjadi Badal dari lafal Maa, atau dari lafal Muzdajir (yang sempurna) maksudnya, hikmah yang lengkap (tetapi tiada berguna) tidak ada gunanya bagi mereka (peringatan-peringatan itu) lafal An Nudzur adalah bentuk jamak dari lafal Nadziirun yang bermakna Mundzirun, yakni hal-hal yang dijadikan peringatan buat mereka. Lafal Maa boleh dikatakan sebagai huruf Nafi atau Istifham Inkari; jika dianggap sebagai Istifham Inkari berarti kedudukannya sebagai Maf'ul Muqaddam.\qt@no{5}}%
\qt@newcmd\qurantrans@id@mmmmdccclii{%
(Maka berpalinglah kamu dari mereka) menjadi pelengkap atau kesimpulan dari pembahasan sebelumnya (pada hari ketika penyeru memanggil) yaitu malaikat Israfil. Yang menashabkan lafal Yauma adalah lafal Yakhrujuuna yang disebutkan dalam ayat berikutnya, artinya, sesudah mereka keluar dari kuburnya masing-masing yaitu, ketika sang penyeru memanggil mereka (kepada sesuatu yang tidak menyenangkan) dapat dibaca Nukur atau Nukr, artinya, hal yang paling tidak disukai oleh jiwa manusia yaitu, hari penghisaban amal perbuatan.\qt@no{6}}%
\qt@newcmd\qurantrans@id@mmmmdcccliii{%
(Sambil menundukkan) keadaan mereka pada saat itu hina Menurut suatu qiraat dibaca Khaasyi'an (pandangan-pandangan mereka) lafal Khusysya'an menjadi Hal atau kata keterangan keadaan dari Fa'il (mereka keluar) yakni manusia semuanya (dari kuburan) dari tempat-tempat mereka dikuburkan (seakan-akan mereka belalang yang beterbangan) mereka tidak mengetahui hendak ke manakah tujuan mereka, karena tercekam oleh rasa takut dan bimbang yang amat sangat. Jumlah kalimat Ka annahum dan seterusnya menjadi Hal dari Fa'il yang terkandung di dalam lafal Yakhrujuna, demikian pula firman selanjutnya, yaitu,\qt@no{7}}%
\qt@newcmd\qurantrans@id@mmmmdcccliv{%
(Mereka datang dengan cepat) seraya menjulurkan leher-leher mereka (kepada penyeru itu. Orang-orang kafir berkata) orang-orang kafir di antara mereka mengatakan, ("Ini adalah hari yang berat") atau sulit bagi orang-orang kafir, sebagaimana yang telah dijelaskan dalam surah Al Muddatstsir melalui firman-Nya, ``Hari yang sulit bagi orang-orang kafir." (Q.S. Al-Muddatstsir 9-10)\qt@no{8}}%
\qt@newcmd\qurantrans@id@mmmmdccclv{%
(Sebelum mereka telah mendustakan -pula -) yakni sebelum orang-orang Quraisy (kaum Nuh) dita`nits kannya lafal Kadzdzabat karena memandang segi makna yang terkandung dalam lafal Qaumun (maka mereka mendustakan hamba Kami) yakni Nabi Nuh (dan mereka mengatakan, ``Dia seorang gila dan dia sudah pernah diberi ancaman") pernah diperingatkan oleh mereka dengan caci-maki dan lain sebagainya.\qt@no{9}}%
\qt@newcmd\qurantrans@id@mmmmdccclvi{%
(Maka dia mengadu kepada Rabbnya, ``Bahwasanya aku ini) dibaca Annii artinya, bahwa aku ini (adalah orang yang dikalahkan, oleh karena itu menangkanlah aku")\qt@no{10}}%
\qt@newcmd\qurantrans@id@mmmmdccclvii{%
(Maka Kami bukakan) dapat dibaca Fafatahnaa atau Fafattahnaa (pintu-pintu langit dengan menurunkan air yang tercurah) air yang ditumpahkan dari langit dengan sangat derasnya.\qt@no{11}}%
\qt@newcmd\qurantrans@id@mmmmdccclviii{%
(Dan Kami jadikan bumi memancarkan mata air-mata air) yang menyumber dengan derasnya (maka bertemulah air-air itu) yaitu air yang ditumpahkan dari langit dan air yang disemburkan dari bumi (untuk suatu urusan) berkedudukan menjadi Hal (yang sungguh telah ditetapkan) yang telah dipastikan di zaman Azali, yaitu bahwa mereka dibinasakan dengan ditenggelamkan.\qt@no{12}}%
\qt@newcmd\qurantrans@id@mmmmdccclix{%
(Dan Kami angkut dia) yakni Nabi Nuh (ke atas) bahtera (yang terbuat dari papan dan paku) lafal Dusur artinya benda-benda yang dipakai untuk menyambung kayu-kayu, baik berupa paku atau benda-benda lainnya, bentuk tunggalnya adalah Disaarun yang wazannya sama dengan lafal Kitaabun\qt@no{13}}%
\qt@newcmd\qurantrans@id@mmmmdccclx{%
(Yang berlayar dengan pemeliharaan Kami) atau dalam pengawasan Kami (sebagai balasan) dinashabkan oleh Fi'il yang diperkirakan keberadaannya, yakni mereka ditenggelamkan sebagai pertanda kemenangan (bagi orang yang diingkari) yaitu bagi Nabi Nuh a.s. Dan menurut suatu qiraat lafal Kufira dibaca Kafar, artinya, mereka ditenggelamkan sebagai hukuman bagi mereka yang kafir.\qt@no{14}}%
\qt@newcmd\qurantrans@id@mmmmdccclxi{%
(Dan sesungguhnya telah Kami tinggalkan) telah Kami biarkan perbuatan Kami itu (sebagai tanda) bagi orang yang mau mengambilnya sebagai pelajaran buat dirinya. Makna yang dimaksud ialah, berita mengenai banjir besar ini telah tersiar dan tetap lestari ketenarannya (maka adakah orang yang mau mengambil pelajaran?) untuk menasihati dirinya. Asal lafal Muddakir adalah Mudztakir, lalu huruf Ta diganti menjadi Dal, demikian pula huruf Dzal diganti menjadi Dal, lalu keduanya diidgamkan menjadi satu sehingga jadilah Muddakir.\qt@no{15}}%
\qt@newcmd\qurantrans@id@mmmmdccclxii{%
(Maka alangkah dahsyatnya azab-Ku dan ancaman-ancaman-Ku) peringatan-Ku, Istifham atau kata tanya di sini mengandung makna Taqrir. Lafal Kaifa adalah Khabar dari lafal Kaana, menunjukkan makna pertanyaan tentang keadaan. Pengertiannya ialah menganggap orang-orang yang diajak berbicara telah mengakui terjadinya. azab Allah swt. yang telah menimpa orang-orang yang mendustakan Nabi Nuh.\qt@no{16}}%
\qt@newcmd\qurantrans@id@mmmmdccclxiii{%
(Dan sesungguhnya telah Kami mudahkan Alquran untuk pelajaran) Kami telah memudahkannya untuk dihafal dan Kami telah mempersiapkannya untuk mudah diingat (maka adakah orang yang mengambil pelajaran?) yang mau mengambilnya sebagai pelajaran dan menghafalnya. Istifham di sini mengandung makna perintah yakni, hafalkanlah Alquran itu oleh kalian dan ambillah sebagai nasihat buat diri kalian. Sebab tidak ada orang yang lebih hafal tentang Alquran selain daripada orang yang mengambilnya sebagai nasihat buat dirinya.\qt@no{17}}%
\qt@newcmd\qurantrans@id@mmmmdccclxiv{%
(Kaum Ad pun telah mendustakan) nabi mereka yaitu Nabi Hud, karena itu mereka diazab. (Maka alangkah dahsyatnya azab-Ku dan ancaman-ancaman-Ku) peringatan-Ku kepada mereka, bahwa mereka akan Kami azab sebelum azab itu turun menimpa mereka. Kemudian dijelaskan oleh firman berikutnya.\qt@no{18}}%
\qt@newcmd\qurantrans@id@mmmmdccclxv{%
(Sesungguhnya Kami telah menghembuskan kepada mereka angin yang sangat kencang) sangat keras suaranya dan kuat sekali (pada hari nahas) atau pada hari yang sial (yang terus-menerus) yakin kesialannya terus-menerus. Atau sangat kuat sialnya, hal itu terjadi pada hari Rabu di penghujung bulan.\qt@no{19}}%
\qt@newcmd\qurantrans@id@mmmmdccclxvi{%
(Yang mencabut manusia) yang menghempaskan mereka dari tempat perlindungannya di bawah tanah, kemudian angin itu menjatuhkannya ke kepala mereka sehingga matilah mereka semua dan terpisahlah kepala dari tubuh mereka (seakan-akan mereka) yakni keadaan mereka pada waktu itu sebagaimana yang telah disebutkan tadi (pokok-pokok) atau batang-batang (kurma yang tumbang) maksudnya, keadaan mereka ketika itu bagaikan pokok-pokok kurma yang tumbang ke bumi. Mereka diserupakan dengan pokok kurma karena keadaan tubuh mereka yang tinggi-tinggi. Lafal Munqa'ir disebutkan ayat ini dalam bentuk Mudzakkar, sedangkan di dalam surah Al Haaqqah kata sifatnya disebutkan dalam bentuk Ta`nits yaitu, di dalam firman-Nya, ``batang-batang pohon kurma yang telah kosong (lapuk)." (Q.S. Al-Haaqqah, 7) Demikian itu karena demi memelihara kesamaan bunyi pada akhir ayat pada kedua tempat tersebut.\qt@no{20}}%
\qt@newcmd\qurantrans@id@mmmmdccclxvii{%
(Maka betapa dahsyatnya azab-Ku dan ancaman-ancaman-Ku)\qt@no{21}}%
\qt@newcmd\qurantrans@id@mmmmdccclxviii{%
(Dan sesungguhnya telah kami mudahkan Alquran untuk pelajaran, maka adakah orang yang mengambil pelajaran?)\qt@no{22}}%
\qt@newcmd\qurantrans@id@mmmmdccclxix{%
(Kaum Tsamud pun telah mendustakan ancaman-ancaman itu) lafal An Nudzur adalah bentuk jamak dari lafal Nadziirun yang bermakna Mundzirun, yaitu perkara-perkara yang dijadikan peringatan oleh nabi mereka (Nabi Saleh) jika mereka tidak mau beriman dan tidak mau mengikutinya.\qt@no{23}}%
\qt@newcmd\qurantrans@id@mmmmdccclxx{%
(Maka mereka berkata, ``Apakah kepada manusia) lafal Basyaran dinashabkan karena Isytighal (yakni seseorang di antara kami) kedua lafal ini menjadi sifat bagi lafal Basyaran (kami harus mengikutinya) merupakan penafsir dari Fi'il yang menashabkan lafal Basyaran. Istifham atau kata tanya di sini mengandung makna Nafi atau negatif. Maksudnya, bagaimana kami harus mengikutinya sedangkan kami adalah golongan mayoritas dan dia adalah seseorang di antara kami, lagi dia bukanlah seorang raja. Maksud mereka ialah bahwa mereka tidak mau mengikutinya. (Sesungguhnya kami kalau demikian) jika kami mengikutinya (benar-benar berada dalam kesesatan) atau menyimpang dari kebenaran (dan gila) atau tidak berakal waras.\qt@no{24}}%
\qt@newcmd\qurantrans@id@mmmmdccclxxi{%
(Apakah diturunkan) boleh dibaca Tahqiq dan boleh pula dibaca Tas-hil (wahyu itu) peringatan itu (kepadanya di antara kita) maksudnya, tidak pantas wahyu diturunkan kepadanya. (Sebenarnya dia adalah seorang yang amat pendusta) di dalam pengakuannya itu yang menyatakan bahwa hal tersebut telah diwahyukan kepadanya (lagi sombong") congkak dan takabur. Lalu Allah berfirman,\qt@no{25}}%
\qt@newcmd\qurantrans@id@mmmmdccclxxii{%
("Kelak mereka akan mengetahui) di akhirat nanti (siapakah yang sebenarnya amat pendusta lagi sombong") dia ataukah mereka? Kelak Allah pasti akan mengazab mereka yang telah mendustakan nabinya yakni, Nabi Saleh.\qt@no{26}}%
\qt@newcmd\qurantrans@id@mmmmdccclxxiii{%
(Sesungguhnya Kami akan mengirimkan unta betina) yaitu mengeluarkan unta dari batu besar yang terdapat di lembah tempat mereka sebagaimana yang mereka minta (sebagai cobaan) ujian (bagi mereka) Kami lakukan hal itu guna mencoba mereka (maka tunggulah mereka) hai Saleh apa yang akan mereka kerjakan dan apa yang akan ditimpakan kepada mereka (dan bersabarlah) atas perlakuan mereka yang menyakitkan itu terhadap dirimu. Lafal Ishthabir pada asalnya adalah Ishtabir, kemudian huruf Ta diganti menjadi huruf Tha sehingga jadilah Ishthabir, maknanya bersabarlah kamu.\qt@no{27}}%
\qt@newcmd\qurantrans@id@mmmmdccclxxiv{%
(Dan beritakanlah kepada mereka bahwa sesungguhnya air itu terbagi) dibagi-bagi (antara mereka) dengan unta betina itu; yakni sehari buat mereka dan hari yang lainnya buat unta betina, demikianlah seterusnya (tiap-tiap minum) bagian air (dihadiri) oleh yang punya giliran, yakni kaum Nabi Saleh dan unta betina. Akhirnya lama kelamaan mereka merasa bosan dengan adanya pembagian ini, lalu mereka bersepakat untuk membunuh unta betina itu.\qt@no{28}}%
\qt@newcmd\qurantrans@id@mmmmdccclxxv{%
(Maka mereka memanggil kawannya) yaitu seorang yang gagah perkasa untuk membunuh unta betina itu (lalu kawannya itu menangkap) unta itu seraya menghunus pedangnya (dan menyembelihnya) menyembelih unta betina itu dengan pedangnya dan membunuhnya sesuai dengan apa yang diinginkan oleh mereka.\qt@no{29}}%
\qt@newcmd\qurantrans@id@mmmmdccclxxvi{%
(Maka alangkah dahsyatnya azab-Ku dan ancaman-ancaman-Ku) yakni peringatan-Ku terhadap mereka sebelum azab diturunkan kepada mereka. Lalu Allah menjelaskan hal ini melalui firman selanjutnya,\qt@no{30}}%
\qt@newcmd\qurantrans@id@mmmmdccclxxvii{%
("Sesungguhnya Kami menimpakan atas mereka satu suara yang keras mengguntur, maka jadilah mereka seperti kayu-kayu kering yang dijadikan sebagai kandang kambing") Al Muhtazhar artinya pohon dan duri-duri yang kering kemudian dijadikan sebagai kandang kambing untuk menjaga kambing-kambing dari sergapan binatang buas seperti serigala dan binatang pemangsa lainnya. Dan kayu-kayu atau duri-duri kering yang terjatuh dari kandang tersebut lalu diinjak-injak oleh kambing dinamakan Al Hasyiim.\qt@no{31}}%
\qt@newcmd\qurantrans@id@mmmmdccclxxviii{%
(Dan sesungguhnya telah Kami mudahkan Alquran untuk pelajaran, maka adakah orang yang mau mengambil pelajaran?)\qt@no{32}}%
\qt@newcmd\qurantrans@id@mmmmdccclxxix{%
(Kaum Luth pun telah mendustakan ancaman-ancaman itu) mendustakan hal-hal yang diancamkan kepada mereka melalui lisan Nabi Luth.\qt@no{33}}%
\qt@newcmd\qurantrans@id@mmmmdccclxxx{%
(Sesungguhnya Kami telah mengembuskan kepada mereka angin yang membawa terbang batu-batu) yakni angin yang melempari mereka dengan batu-batu yang diterbangkannya. Al Hashbaa adalah batu-batu kecil yang besarnya lebih kecil dari genggaman tangan; akhirnya binasalah mereka karenanya (kecuali keluarga Luth) mereka adalah Nabi Luth dan kedua orang putrinya. (Mereka Kami selamatkan di waktu sebelum fajar menyingsing) berasal dari lafal As-haar artinya, waktu menjelang subuh dari hari yang tidak ditentukan. Dan seandainya hari yang dimaksud adalah hari yang ditentukan, niscaya ungkapannya tidak memakai harakat Tanwin karena termasuk Isim yang Ma'rifat dan dima'dul dari lafal As Sahar. Karena, bila dimaksud sebagai hari yang ditentukan pasti memakai Alif dan Lam. Apakah batu kerikil itu dihembuskan kepada keluarga Nabi Luth atau tidak? Sehubungan dengan hal ini ada dua pendapat. Menurut pendapat pertama yakni dihembuskan juga, berarti Istisna di sini bersifat Muttashil. Menurut pendapat kedua yakni, tidak dihembuskan berarti Istitsnanya bersifat Munqathi'. Akan tetapi pada akhirnya keluarga Nabi Luth diselamatkan dari azab itu.\qt@no{34}}%
\qt@newcmd\qurantrans@id@mmmmdccclxxxi{%
(sebagai nikmat) menjadi mashdar, artinya sebagai pemberian nikmat. (dari sisi Kami. Demikianlah) sebagaimana pembalasan tersebut (Kami memberi balasan kepada orang-orang yang bersyukur) terhadap nikmat-nikmat Kami; dia adalah orang mukmin atau orang yang beriman kepada Allah dan Rasul-Nya serta menaati keduanya.\qt@no{35}}%
\qt@newcmd\qurantrans@id@mmmmdccclxxxii{%
(Dan sesungguhnya dia telah memperingatkan kepada mereka) yaitu Nabi Luth telah memberi peringatan kepada mereka (akan azab Kami) akan pembalasan Kami kepada mereka melalui azab-Nya (maka mereka mendustakan) mereka membantah dan mendustakan (ancaman-ancaman itu) ancaman-ancaman Nabi Luth.\qt@no{36}}%
\qt@newcmd\qurantrans@id@mmmmdccclxxxiii{%
(Dan sesungguhnya mereka telah membujuknya agar menyerahkan tamunya) mereka membujuknya supaya dia membiarkan mereka dengan orang-orang yang datang kepadanya sebagai tamu. Mereka bermaksud akan berbuat homosex dengan para tamunya itu, padahal para tamunya itu adalah malaikat-malaikat yang menjelma menjadi manusia (lalu Kami butakan mata mereka) Kami jadikan buta mata mereka dan Kami jadikan mata mereka tertutup rapat atau rata, sama rata dengan bagian muka yang lainnya. Yaitu, setelah malaikat Jibril menampar mereka dengan sayapnya (maka rasakanlah) maksudnya, Kami berkata kepada mereka, ``Rasakanlah oleh kalian (azab-Ku dan ancaman-ancaman-Ku) ini". Yakni, ancaman dan peringatan-Ku ini; makna yang dimaksud adalah buah dan akibat daripada ancaman-Ku.\qt@no{37}}%
\qt@newcmd\qurantrans@id@mmmmdccclxxxiv{%
(Dan sesungguhnya pada esok harinya mereka ditimpa) yaitu, di waktu subuh dari hari yang tidak ditentukan itu (azab yang kekal) azab yang terus-menerus hingga sampai kepada saatnya azab akhirat.\qt@no{38}}%
\qt@newcmd\qurantrans@id@mmmmdccclxxxv{%
(Maka rasakanlah azab-Ku dan ancaman-ancaman-Ku)\qt@no{39}}%
\qt@newcmd\qurantrans@id@mmmmdccclxxxvi{%
(Dan sesungguhnya telah Kami mudahkan Alquran untuk pelajaran, maka sudah adakah orang yang mengambil pelajaran?).\qt@no{40}}%
\qt@newcmd\qurantrans@id@mmmmdccclxxxvii{%
(Dan sesungguhnya telah datang kepada kaum Firaun) kepada Firaun dan kaumnya (ancaman-ancaman itu) ancaman-Ku melalui lisan Nabi Musa dan Nabi Harun, tetapi mereka masih tetap tidak mau beriman. Bahkan,\qt@no{41}}%
\qt@newcmd\qurantrans@id@mmmmdccclxxxviii{%
(mereka mendustakan ayat-ayat Kami kesemuanya) yakni sembilan ayat yang diberikan kepada Nabi Musa (lalu Kami azab mereka) yakni, Kami turunkan azab kepada mereka (sebagai azab dari Yang Maha Perkasa) Yang Maha Kuat (lagi Maha Kuasa) tiada sesuatu pun yang dapat melemahkan dan menghalang-halangi-Nya.\qt@no{42}}%
\qt@newcmd\qurantrans@id@mmmmdccclxxxix{%
(Apakah orang-orang kafir kalian) hai orang-orang Quraisy (lebih baik daripada mereka itu) yang telah disebutkan yaitu, mulai dari kaum Nabi Nuh hingga sampai kepada Firaun dan kaumnya yang tidak mendapatkan ampunan (atau apakah kalian telah mempunyai) hai orang-orang kafir Quraisy (jaminan kebebasan) dari azab (dalam kitab-kitab) yang terdahulu. Istifham yang terdapat pada dua tempat ini mengandung makna Nafi artinya, kenyataannya tidaklah demikian.\qt@no{43}}%
\qt@newcmd\qurantrans@id@mmmmdcccxc{%
(Atau apakah mereka mengatakan) yakni orang-orang kafir Quraisy, ("Kami adalah suatu golongan yang bersatu) orang-orang yang bersatu dalam satu golongan (yang pasti menang") atas Muhammad. Sewaktu Abu Jahal mengatakan dalam perang Badar, bahwa sesungguhnya kami adalah golongan yang bersatu yang pasti menang. Maka turunlah firman-Nya,\qt@no{44}}%
\qt@newcmd\qurantrans@id@mmmmdcccxci{%
("Golongan Itu pasti akan dikalahkan dan mereka akan mundur ke belakang") akhirnya mereka dikalahkan oleh Nabi Muhammad saw. dalam perang Badar, dan Nabi Muhammad saw. mendapat kemenangan yang gemilang atas mereka.\qt@no{45}}%
\qt@newcmd\qurantrans@id@mmmmdcccxcii{%
(Sebenarnya hari kiamat itulah hari yang dijanjikan kepada mereka) yaitu azab akan ditimpakan kepada mereka (dan kiamat itu) azab hari kiamat itu (lebih dahsyat) lebih besar bencananya (lagi lebih pahit) jauh lebih pahit daripada azab di dunia.\qt@no{46}}%
\qt@newcmd\qurantrans@id@mmmmdcccxciii{%
(Sesungguhnya orang-orang yang berdosa berada dalam kesesatan) dalam kebinasaan, mereka akan terbunuh di dunia (dan dalam neraka) neraka yang besar nyalanya. Maksudnya, kelak di akhirat mereka akan dimasukkan ke dalam neraka yang apinya menyala-nyala.\qt@no{47}}%
\qt@newcmd\qurantrans@id@mmmmdcccxciv{%
(Pada hari mereka diseret ke neraka atas muka mereka) di akhirat kelak, lalu dikatakan kepada mereka ("Rasakanlah sentuhan api neraka") rasakanlah panasnya api neraka Jahanam ini oleh kalian.\qt@no{48}}%
\qt@newcmd\qurantrans@id@mmmmdcccxcv{%
(Sesungguhnya segala sesuatu itu Kami) dinashabkan oleh Fi'il yang terdapat pada firman selanjutnya yang berfungsi menafsirkannya (ciptakan menurut ukuran) masing-masing. Menurut suatu qiraat lafal Kulla dibaca KuIlu dan dianggap sebagai Mubtada, sedangkan Khabarnya adalah lafal Khalaqnaahu.\qt@no{49}}%
\qt@newcmd\qurantrans@id@mmmmdcccxcvi{%
(Dan tiada lain perintah Kami) terhadap sesuatu yang Kami kehendaki ada (hanyalah) sekali (satu firman seperti kejapan mata) dalam hal kecepatannya, yaitu melalui firman-Nya 'Kun' yakni adalah kamu, maka sesuatu yang dikehendaki itu langsung ada dengan seketika; pengertian ini diungkapkan pula oleh firman lainnya, yaitu, ``Sesungguhnya keadaan-Nya apabila Dia menghendaki sesuatu hanyalah berkata kepadanya, 'Jadilah', maka terjadilah ia." (Q.S. Yaasin, 82)\qt@no{50}}%
\qt@newcmd\qurantrans@id@mmmmdcccxcvii{%
(Dan sesungguhnya telah Kami binasakan orang yang serupa dengan kalian) dalam kekafirannya dari umat-umat terdahulu. (Maka adakah orang yang mau mengambil pelajaran?) Istifham atau kata tanya di sini mengandung makna perintah yakni, ingatlah kalian dan ambillah hal ini sebagai pelajaran buat kalian!\qt@no{51}}%
\qt@newcmd\qurantrans@id@mmmmdcccxcviii{%
(Dan segala sesuatu yang telah mereka perbuat) apa yang telah dikerjakan oleh semua hamba-hamba Allah telah tercatat (di dalam buku-buku) catatan amal perbuatan.\qt@no{52}}%
\qt@newcmd\qurantrans@id@mmmmdcccxcix{%
(Dan segala urusan yang kecil maupun besar) berupa dosa atau amal perbuatan (adalah tertulis) tercatat di Lohmahfuz.\qt@no{53}}%
\qt@newcmd\qurantrans@id@mmmmcm{%
(Sesungguhnya orang-orang yang bertakwa itu di dalam surga-surga) taman-taman (dan sungai-sungai makna yang dimaksud adalah jenisnya. Menurut suatu qiraat lafal Nahar dibaca Nuhur dalam bentuk jamak, yang wazannya sama dengan lafal Asadun bila dijamakkan menjadi Usudun. Makna yang dimaksud ialah, bahwa mereka meminum dari sungai-sungai surga itu air, susu, madu dan khamar.\qt@no{54}}%
\qt@newcmd\qurantrans@id@mmmmcmi{%
(Di tempat yang benar) di majelis yang benar, karena tidak ada perkataan yang tidak berguna dan tidak pula ada perkataan yang berdosa di dalamnya; pengertian Maq'ad di sini adalah ditinjau dari segi jenisnya. Menurut qiraat yang lain lafal Maq'ad dibaca dalam bentuk jamak yaitu Maqaa'id. Makna yang dimaksud ialah bahwa ahli surga itu berada di dalam majelis-majelis surga dalam keadaan bebas dari perkataan yang tidak ada gunanya dan bebas pula dari hal-hal yang berdosa, keadaan mereka berbeda dengan keadaan majelis-majelis di dunia. Karena sesungguhnya majelis-majelis di dunia itu jarang sekali bebas dari hal-hal tersebut. Lafal ayat ini berkedudukan sebagai Khabar yang kedua, dan lafal Shidqin menjadi Badal dari lafal Shaadiqin, yakni Badal Ba'dh atau lainnya (di sisi Yang Maha Raja) merupakan perumpamaan yang mengandung makna Mubalaghah, yakni Maha Raja Yang Maha Perkasa lagi Maha Luas (lagi Maha Berkuasa) tiada sesuatu pun yang melemahkan-Nya, Dia adalah Allah swt. Lafal 'Inda menunjukkan isyarat yang mengandung makna derajat dan kedudukan mereka yang dekat di sisi-Nya, sebagai anugerah dari Allah swt. kepada para penghuni surga.\qt@no{55}}%
\qt@newcmd\qurantrans@id@mmmmcmii{%
\basmalahid (Yang Maha Pemurah) yakni Allah swt.\qt@no{1}}%
\qt@newcmd\qurantrans@id@mmmmcmiii{%
(Telah mengajarkan) kepada siapa yang dikehendaki-Nya (Alquran).\qt@no{2}}%
\qt@newcmd\qurantrans@id@mmmmcmiv{%
(Dia menciptakan manusia) jenis manusia.\qt@no{3}}%
\qt@newcmd\qurantrans@id@mmmmcmv{%
(Mengajarinya pandai berbicara) atau dapat berbicara.\qt@no{4}}%
\qt@newcmd\qurantrans@id@mmmmcmvi{%
(Matahari dan bulan menurut perhitungan) maksudnya, keduanya beredar menurut perhitungan.\qt@no{5}}%
\qt@newcmd\qurantrans@id@mmmmcmvii{%
(Dan tumbuh-tumbuhan) jenis tumbuh-tumbuhan yang tidak mempunyai batang (dan pohon-pohonan) jenis tumbuh-tumbuhan yang memiliki batang (kedua-duanya tunduk kepada-Nya) keduanya tunduk kepada apa yang dikehendaki-Nya.\qt@no{6}}%
\qt@newcmd\qurantrans@id@mmmmcmviii{%
(Dan Dia telah meninggikan langit dan meletakkan neraca) yaitu menetapkan keadilan.\qt@no{7}}%
\qt@newcmd\qurantrans@id@mmmmcmix{%
(Supaya kalian jangan melampaui batas) agar kalian jangan berbuat curang (dalam timbangan itu) maksudnya dalam menimbang sesuatu dengan mempergunakan timbangan itu.\qt@no{8}}%
\qt@newcmd\qurantrans@id@mmmmcmx{%
(Dan tegakkanlah timbangan itu dengan adil) artinya tidak curang (dan janganlah kalian mengurangi timbangan itu) maksudnya mengurangi barang yang ditimbang itu.\qt@no{9}}%
\qt@newcmd\qurantrans@id@mmmmcmxi{%
(Dan bumi telah diletakkan-Nya) telah dimantapkan-Nya (untuk semua makhluk) untuk manusia, jin, dan lain-lainnya.\qt@no{10}}%
\qt@newcmd\qurantrans@id@mmmmcmxii{%
(Di bumi itu ada buah-buahan dan pohon kurma) yang ditanam dan dipelihara (yang mempunyai kelopak mayang) memiliki kelopak-kelopak di bagian atasnya.\qt@no{11}}%
\qt@newcmd\qurantrans@id@mmmmcmxiii{%
(Dan biji-bijian) seperti gandum dan jawawut (yang berbulir) yang ada merangnya (dan daun-daunan yang harum baunya) wangi baunya.\qt@no{12}}%
\qt@newcmd\qurantrans@id@mmmmcmxiv{%
(Maka manakah nikmat-nikmat) atau karunia-karunia (Rabb kamu berdua) hai manusia dan jin (yang kamu dustakan?) ayat ini disebutkan di dalam surah ini sebanyak tiga puluh satu kali. Istifham atau kata tanya yang terdapat dalam ayat ini mengandung makna taqrir atau menetapkan, demikian itu karena ada sebuah hadis yang diriwayatkan oleh Imam Hakim melalui Jabir r.a. yang telah menceritakan, bahwa Rasulullah saw. membacakan kepada kami surah Ar Rahman hingga selesai. Kemudian beliau bersabda, ``Mengapa kalian ini diam saja?" Sungguh jin lebih baik jawabannya daripada kalian. Karena sesungguhnya tiada sekali-kali aku bacakan kepada mereka ayat ini, ``Maka manakah nikmat-nikmat Rabb kamu berdua yang kamu dustakan?" (Q.S. Ar Rahman, 13) melainkan mereka menjawabnya, ``Wahai Rabb kami, tiada satu pun nikmat-Mu yang kami dustakan, bagi-Mu segala puji."\qt@no{13}}%
\qt@newcmd\qurantrans@id@mmmmcmxv{%
(Dia menciptakan manusia) yakni Nabi Adam (dari tanah kering) tanah kering yang apabila diketuk akan mengeluarkan suara berdenting (seperti tembikar) seperti tanah liat yang dibakar.\qt@no{14}}%
\qt@newcmd\qurantrans@id@mmmmcmxvi{%
(Dan Dia menciptakan jin) yakni bapak moyang jin, yaitu iblis (dari nyala api) yaitu nyala api yang tidak berasap\qt@no{15}}%
\qt@newcmd\qurantrans@id@mmmmcmxvii{%
(Maka manakah nikmat-nikmat Rabb kamu berdua yang kamu dustakan?)\qt@no{16}}%
\qt@newcmd\qurantrans@id@mmmmcmxviii{%
(Rabb yang memelihara kedua tempat terbit matahari) yaitu tempat terbitnya di waktu musim dingin dan tempat terbitnya di waktu musim panas (dan Rabb yang memelihara kedua tempat terbenamnya) penafsirannya seperti pada yang pertama tadi.\qt@no{17}}%
\qt@newcmd\qurantrans@id@mmmmcmxix{%
(Maka manakah nikmat-nikmat Rabb kamu berdua yang kamu dustakan?)\qt@no{18}}%
\qt@newcmd\qurantrans@id@mmmmcmxx{%
(Dia membiarkan) atau melepaskan (dua laut) yang airnya tawar dan yang asin (saling bertemu) menurut pandangan mata.\qt@no{19}}%
\qt@newcmd\qurantrans@id@mmmmcmxxi{%
(Antara keduanya ada batas) ada penghalang yang membatasi keduanya dari kekuasaan Allah swt. (yang tidak dilampaui oleh masing-masing) yang satu melampaui yang lainnya sehingga bercampur.\qt@no{20}}%
\qt@newcmd\qurantrans@id@mmmmcmxxii{%
(Maka manakah nikmat-nikmat Rabb kamu berdua yang kamu dustakan?)\qt@no{21}}%
\qt@newcmd\qurantrans@id@mmmmcmxxiii{%
(Keluarlah) dapat dibaca Yakhruju. dan Yukhraju (daripada keduanya) dari pertemuan di antara keduanya, yakni dari bagian yang airnya asin (mutiara dan marjan) marjan artinya batu yang berwarna merah atau yang dimaksud adalah mutiara yang kecil.\qt@no{22}}%
\qt@newcmd\qurantrans@id@mmmmcmxxiv{%
(Maka manakah nikmat-nikmat Rabb kamu berdua yang kamu dustakan?)\qt@no{23}}%
\qt@newcmd\qurantrans@id@mmmmcmxxv{%
(Dan kepunyaan-Nyalah bahtera-bahtera) perahu-perahu (yang dibangun) yang dibuat (di lautan laksana gunung-gunung) lautan besar yang tingginya bagaikan gunung-gunung.\qt@no{24}}%
\qt@newcmd\qurantrans@id@mmmmcmxxvi{%
(Maka manakah nikmat-nikmat Rabb kamu berdua yang kamu dustakan?)\qt@no{25}}%
\qt@newcmd\qurantrans@id@mmmmcmxxvii{%
(Semua yang ada di bumi itu) yakni semua makhluk hidup yang ada padanya (akan binasa) akan mati; di sini diungkapkan semua makhluk hidup dengan memakai kata Man, karena memprioritaskan makhluk yang berakal.\qt@no{26}}%
\qt@newcmd\qurantrans@id@mmmmcmxxviii{%
(Dan tetap kekal Zat Rabbmu) yakni Zat-Nya (Yang mempunyai kebesaran) atau keagungan (dan kemuliaan) Yang Maha Dermawan kepada orang-orang mukmin dengan melimpahkan nikmat-nikmat-Nya kepada mereka.\qt@no{27}}%
\qt@newcmd\qurantrans@id@mmmmcmxxix{%
(Maka manakah nikmat-nikmat Rabb kamu berdua yang kamu dustakan?)\qt@no{28}}%
\qt@newcmd\qurantrans@id@mmmmcmxxx{%
(Semua yang ada di langit dan di bumi selalu meminta kepada-Nya) baik melalui ucapan mereka atau pun perbuatan mereka, yaitu meminta apa-apa yang mereka perlukan berupa kekuatan untuk menjalankan ibadah, rezeki, ampunan dan lain sebagainya. (Setiap hari) setiap waktu (Dia dalam suatu perkara) yaitu perkara yang hendak dilahirkan-Nya sesuai dengan apa yang telah ditentukan-Nya sejak zaman Azali antara lain, menghidupkan, mematikan, memuliakan, menghinakan, memberikan kecukupan, memiskinkan, mengabulkan doa dan memenuhi yang meminta.\qt@no{29}}%
\qt@newcmd\qurantrans@id@mmmmcmxxxi{%
(Maka manakah nikmat-nikmat Rabb kamu berdua yang kamu dustakan?)\qt@no{30}}%
\qt@newcmd\qurantrans@id@mmmmcmxxxii{%
(Kami akan menyelesaikan kamu sekalian) artinya, Kami hendak menghisab kalian semuanya (hai manusia dan jin) hai jenis manusia dan jenis jin.\qt@no{31}}%
\qt@newcmd\qurantrans@id@mmmmcmxxxiii{%
(Maka manakah nikmat-nikmat Rabb kamu berdua yang kamu dustakan?)\qt@no{32}}%
\qt@newcmd\qurantrans@id@mmmmcmxxxiv{%
(Hai semua jin dan manusia, jika kalian sanggup menembus) melintasi (penjuru) atau kawasan-kawasan (langit dan bumi, maka lintasilah) perintah di sini mengandung makna yang menunjukkan ketidakmampuan mereka untuk melakukan hal tersebut (kalian tidak dapat menembusnya melainkan dengan kekuatan) dan kalian tidak akan mempunyai kekuatan untuk itu.\qt@no{33}}%
\qt@newcmd\qurantrans@id@mmmmcmxxxv{%
(Maka manakah nikmat-nikmat Rabb kamu berdua yang kamu dustakan?)\qt@no{34}}%
\qt@newcmd\qurantrans@id@mmmmcmxxxvi{%
(Kepada kamu berdua akan dilepaskan nyala api) yakni nyala api yang tidak berasap atau nyala api yang berasap (dan asap) yaitu asap murni yang tidak ada nyala apinya (maka kamu berdua tidak akan dapat menyelamatkan diri) daripadanya, bahkan kalian kelak akan digiring ke padang Mahsyar.\qt@no{35}}%
\qt@newcmd\qurantrans@id@mmmmcmxxxvii{%
(Maka manakah nikmat-nikmat Rabb kamu berdua yang kamu dustakan?)\qt@no{36}}%
\qt@newcmd\qurantrans@id@mmmmcmxxxviii{%
(Maka apabila langit telah terbelah) artinya, terbuka pintu-pintunya karena turunnya malaikat-malaikat (dan menjadi merah mawar) memerah seperti warna bunga mawar (seakan-akan kilapan minyak) bagaikan minyak yang berwarna merah berbeda keadaannya dengan yang biasa. Di dalam ungkapan ayat ini terkandung jawabannya, yakni apabila saat itu datang, betapa dahsyatnya kengerian dan ketakutan melihatnya.\qt@no{37}}%
\qt@newcmd\qurantrans@id@mmmmcmxxxix{%
(Maka manakah nikmat-nikmat Rabb kamu berdua yang kamu dustakan?).\qt@no{38}}%
\qt@newcmd\qurantrans@id@mmmmcmxl{%
(Pada waktu itu manusia dan jin tidak ditanya tentang dosanya) tetapi mereka akan ditanya mengenai dosanya di lain waktu, karena ini merupakan suatu janji sebagaimana yang diungkapkan di dalam firman lainnya, yaitu, ``Maka demi Rabbmu, Kami pasti akan menanyai mereka semua." (Q.S. Al Hijr, 92) Lafal Al Jaan di sini sebagaimana yang akan dijelaskan nanti adalah bermakna jin, dan lafal Al Insu artinya manusia.\qt@no{39}}%
\qt@newcmd\qurantrans@id@mmmmcmxli{%
(Maka manakah nikmat-nikmat Rabb kamu berdua yang kamu dustakan?)\qt@no{40}}%
\qt@newcmd\qurantrans@id@mmmmcmxlii{%
(Orang-orang yang berdosa dikenal dengan tanda-tandanya) yakni, mukanya berwarna hitam dan matanya berwarna biru (lalu dipegang ubun-ubun dan kaki mereka).\qt@no{41}}%
\qt@newcmd\qurantrans@id@mmmmcmxliii{%
(Maka manakah nikmat-nikmat Rabb kamu berdua yang kamu dustakan?) Keadaan orang-orang yang berdosa pada saat itu, kedua telapak kaki mereka disatukan dengan ubun-ubunnya dari arah belakang, yaitu dilipat lalu mereka dilemparkan ke dalam neraka dan dikatakan kepada mereka,\qt@no{42}}%
\qt@newcmd\qurantrans@id@mmmmcmxliv{%
("Inilah neraka Jahanam yang didustakan oleh orang-orang yang berdosa").\qt@no{43}}%
\qt@newcmd\qurantrans@id@mmmmcmxlv{%
(Mereka berkeliling) yakni berjalan dengan cepat (di antaranya dan di antara air yang mendidih yaitu air panas (yang memuncak panasnya) panasnya tak terperikan, lalu mereka diberi minum air panas tersebut apabila mereka meminta tolong karena panasnya api neraka; lafal Anin termasuk Isim Manqush, sama halnya dengan lafal Qaadhin.\qt@no{44}}%
\qt@newcmd\qurantrans@id@mmmmcmxlvi{%
(Maka manakah nikmat-nikmat Rabb kamu berdua yang kamu dustakan?)\qt@no{45}}%
\qt@newcmd\qurantrans@id@mmmmcmxlvii{%
(Dan bagi orang yang takut) bagi masing-masing dari mereka atau bagi mereka semuanya (akan saat menghadap Rabbnya) yaitu takut manakala ia berdiri di hadapan Rabbnya untuk menjalani hisab. Oleh karena itu, maka ia tidak mau berbuat durhaka kepada-Nya (ada dua taman).\qt@no{46}}%
\qt@newcmd\qurantrans@id@mmmmcmxlviii{%
(Maka manakah nikmat-nikmat Rabb kamu berdua yang kamu dustakan?)\qt@no{47}}%
\qt@newcmd\qurantrans@id@mmmmcmxlix{%
(Kedua taman itu mempunyai) lafal Dzawaata adalah bentuk Tatsniyah dari lafal Dzawaat sesuai dengan bentuk asalnya; dan Lam fi'ilnya pada asalnya adalah huruf Ya (pohon-pohon yang rindang) banyak tangkainya; merupakan bentuk jamak dari lafal Fananun yang wazannya sama dengan lafal Thalalun.\qt@no{48}}%
\qt@newcmd\qurantrans@id@mmmmcml{%
(Maka manakah nikmat-nikmat Rabb kamu berdua yang kamu dustakan?)\qt@no{49}}%
\qt@newcmd\qurantrans@id@mmmmcmli{%
(Di dalam kedua taman surga itu ada dua buah mata air yang mengalir).\qt@no{50}}%
\qt@newcmd\qurantrans@id@mmmmcmlii{%
(Maka manakah nikmat-nikmat Rabb kamu berdua yang kamu dustakan?)\qt@no{51}}%
\qt@newcmd\qurantrans@id@mmmmcmliii{%
(Di dalam kedua taman surga itu terdapat segala macam buah-buahan) di dunia atau semua yang dianggap sebagai buah-buahan (yang berpasang-pasangan) yakni dua jenis-dua jenis, ada yang basah dan ada yang kering. Buah Hanzhal yang di dunia terasa amat pahit, tetapi di surga akan terasa manis.\qt@no{52}}%
\qt@newcmd\qurantrans@id@mmmmcmliv{%
(Maka manakah nikmat-nikmat Rabb kamu berdua yang kamu dustakan?)\qt@no{53}}%
\qt@newcmd\qurantrans@id@mmmmcmlv{%
(Mereka bersandarkan) menjadi Hal atau kata keterangan keadaan dari 'Amilnya yang tidak disebutkan, yakni mereka bersenang-senang seraya bersandarkan (di atas permadani yang bagian dalamnya terbuat dari sutera) yaitu sutera yang tebal lagi kasar, sedangkan bagian luarnya yang diduduki terbuat dari sutera yang halus sekali. (Dan buah-buahan kedua surga itu) semua buah-buahannya (dapat dipetik dari dekat) artinya, dekat sekali letaknya sehingga mudah dipetik, baik oleh orang yang sedang berdiri maupun yang duduk dan yang sedang berbaring.\qt@no{54}}%
\qt@newcmd\qurantrans@id@mmmmcmlvi{%
(Maka manakah nikmat-nikmat Rabb kamu berdua yang kamu dustakan?)\qt@no{55}}%
\qt@newcmd\qurantrans@id@mmmmcmlvii{%
(Di dalam surga itu) maksudnya, dalam kedua surga itu dan pada gedung-gedung dan istana-istana yang ada di dalamnya (ada bidadari-bidadari yang selalu menundukkan pandangan matanya) artinya, pandangan mereka terbatas hanya kepada suami-suami mereka saja yang terdiri dari manusia dan jin (tidak pernah disentuh) mereka belum pernah digauli; mereka terdiri dari bidadari-bidadari atau wanita-wanita dunia yang masuk surga (oleh manusia sebelum mereka -penghuni-penghuni surga yang menjadi suami mereka dan tidak pula oleh jin).\qt@no{56}}%
\qt@newcmd\qurantrans@id@mmmmcmlviii{%
(Maka manakah nikmat-nikmat Rabb kamu berdua yang kamu dustakan?)\qt@no{57}}%
\qt@newcmd\qurantrans@id@mmmmcmlix{%
(Seakan-akan bidadari-bidadari itu permata yaqut) dalam hal beningnya (dan marjan) maksudnya, putihnya bagaikan permata.\qt@no{58}}%
\qt@newcmd\qurantrans@id@mmmmcmlx{%
(Maka manakah nikmat-nikmat Rabb kamu berdua yang kamu dustakan?)\qt@no{59}}%
\qt@newcmd\qurantrans@id@mmmmcmlxi{%
(Tidak ada) tiada (balasan kebaikan) atau ketaatan (kecuali kebaikan pula) atau kenikmatan.\qt@no{60}}%
\qt@newcmd\qurantrans@id@mmmmcmlxii{%
(Maka manakah nikmat-nikmat Rabb kamu berdua yang kamu dustakan?)\qt@no{61}}%
\qt@newcmd\qurantrans@id@mmmmcmlxiii{%
(Dan selain dari kedua surga itu) yakni kedua surga yang telah disebutkan tadi (ada dua surga lagi) yaitu bagi orang yang takut akan saat menghadap kepada Rabbnya.\qt@no{62}}%
\qt@newcmd\qurantrans@id@mmmmcmlxiv{%
(Maka manakah nikmat-nikmat Rabb kamu berdua yang kamu dustakan?)\qt@no{63}}%
\qt@newcmd\qurantrans@id@mmmmcmlxv{%
(Kedua surga itu hijau tua warnanya) kelihatan hijau pekat karena sangat hijaunya.\qt@no{64}}%
\qt@newcmd\qurantrans@id@mmmmcmlxvi{%
(Maka manakah nikmat-nikmat Rabb kamu berdua yang kamu dustakan?)\qt@no{65}}%
\qt@newcmd\qurantrans@id@mmmmcmlxvii{%
(Di dalam kedua surga itu ada dua mata air yang memancar) bagaikan air mancur.\qt@no{66}}%
\qt@newcmd\qurantrans@id@mmmmcmlxviii{%
(Maka manakah nikmat-nikmat Rabb kamu berdua yang kamu dustakan?)\qt@no{67}}%
\qt@newcmd\qurantrans@id@mmmmcmlxix{%
(Di dalam keduanya ada buah-buahan dan kurma serta delima) buah kurma dan delima itu menurut suatu pendapat adalah sebagaimana aslinya, tetapi menurut pendapat yang lain tidak seperti bentuk aslinya.\qt@no{68}}%
\qt@newcmd\qurantrans@id@mmmmcmlxx{%
(Maka manakah nikmat-nikmat Rabb kamu berdua yang kamu dustakan?)\qt@no{69}}%
\qt@newcmd\qurantrans@id@mmmmcmlxxi{%
(Di dalam surga-surga itu) di kedua surga dan apa-apa yang ada di dalamnya itu (ada bidadari-bidadari yang baik-baik) akhlaknya (lagi cantik-cantik) rupanya.\qt@no{70}}%
\qt@newcmd\qurantrans@id@mmmmcmlxxii{%
(Maka manakah nikmat-nikmat Rabb kamu berdua yang kamu dustakan?)\qt@no{71}}%
\qt@newcmd\qurantrans@id@mmmmcmlxxiii{%
(Bidadari-bidadari itu-sangat jelita) mata mereka sangat jelita (mereka dipingit) tertutup (di dalam kemah-kemah) yang terbuat dari permata yang dilubangi, keadaan mereka diserupakan dengan gadis-gadis yang dipingit di dalam kemahnya.\qt@no{72}}%
\qt@newcmd\qurantrans@id@mmmmcmlxxiv{%
(Maka manakah nikmat-nikmat Rabb kamu berdua yang kamu dustakan?)\qt@no{73}}%
\qt@newcmd\qurantrans@id@mmmmcmlxxv{%
(Mereka tidak pernah disentuh oleh manusia sebelum mereka) sebelum oleh suami-suami mereka (dan tidak pula oleh jin).\qt@no{74}}%
\qt@newcmd\qurantrans@id@mmmmcmlxxvi{%
(Maka manakah nikmat-nikmat Rabb kamu berdua yang kamu dustakan?)\qt@no{75}}%
\qt@newcmd\qurantrans@id@mmmmcmlxxvii{%
(Mereka bersandarkan) suami-suami mereka bertelekan; I'rab lafal ayat ini sama dengan sebelumnya (pada bantal-bantal yang hijau) merupakan bentuk jamak dari lafal Rafrafatun, artinya permadani atau bantal (dan bergelarkan pada permadani-permadani yang indah) merupakan bentuk jamak dari lafal 'Abqariyyah, artinya permadani.\qt@no{76}}%
\qt@newcmd\qurantrans@id@mmmmcmlxxviii{%
(Maka manakah nikmat-nikmat Rabb kamu berdua yang kamu dustakan?)\qt@no{77}}%
\qt@newcmd\qurantrans@id@mmmmcmlxxix{%
(Maha Agung nama Rabbmu Yang mempunyai kebesaran dan Karunia) penafsirannya sebagaimana sebelumnya, dan lafal Ismi pada ayat ini merupakan Isim Zaaid atau Isim yang ditambahkan.\qt@no{78}}%
\qt@newcmd\qurantrans@id@mmmmcmlxxx{%
\basmalahid (Apabila hari kiamat terjadi) bilamana hari terakhir tiba.\qt@no{1}}%
\qt@newcmd\qurantrans@id@mmmmcmlxxxi{%
(Tidak ada seorang pun dapat berdusta tentang kejadiannya) maksudnya, tiada seorang pun yang tidak mempercayai kejadiannya sebagaimana ia tidak mempercayainya sewaktu di dunia.\qt@no{2}}%
\qt@newcmd\qurantrans@id@mmmmcmlxxxii{%
(Ia merendahkan dan meninggikan) artinya, kejadian hari kiamat itu menampakkan siapa di antara mereka yang terhina karena dimasukkan ke dalam neraka, dan siapa di antara mereka yang ditinggikan derajatnya karena dimasukkan ke dalam surga.\qt@no{3}}%
\qt@newcmd\qurantrans@id@mmmmcmlxxxiii{%
(Apabila bumi diguncangkan dengan se dahsyat-dahsyatnya) yakni bilamana bumi mengalami gempa yang amat dahsyat.\qt@no{4}}%
\qt@newcmd\qurantrans@id@mmmmcmlxxxiv{%
(Dan gunung-gunung dihancurluluhkan sehancur-hancurnya) atau apabila gunung-gunung dihancurleburkan.\qt@no{5}}%
\qt@newcmd\qurantrans@id@mmmmcmlxxxv{%
(Maka jadilah dua debu) yaitu berupa debu (yang beterbangan) yang menyebar ke mana-mana. Lafal Idzaa kedua menjadi Badal dari lafal Idza pertama.\qt@no{6}}%
\qt@newcmd\qurantrans@id@mmmmcmlxxxvi{%
(Dan kalian menjadi) pada hari kiamat itu (bergolong-golongan) terdiri dari golongan-golongan (yang terbagi tiga).\qt@no{7}}%
\qt@newcmd\qurantrans@id@mmmmcmlxxxvii{%
(Yaitu golongan kanan) mereka adalah orang-orang yang kitab catatan amal perbuatan mereka diberikan kepadanya dari sebelah kanan. Kalimat ayat ini menjadi Mubtada sedangkan Khabarnya ialah, (Alangkah mulianya golongan kanan itu) kalimat ayat ini mengandung makna yang mengagungkan dan memuliakan kedudukan mereka, karena mereka dimasukkan ke dalam surga.\qt@no{8}}%
\qt@newcmd\qurantrans@id@mmmmcmlxxxviii{%
(Dan golongan kiri) yakni mereka yang kitab catatan amalnya diberikan kepadanya dari sebelah kiri. (Alangkah sengsaranya golongan kiri itu) ungkapan ini mengandung makna yang menghinakan kedudukan mereka, karena mereka dimasukkan ke dalam neraka.\qt@no{9}}%
\qt@newcmd\qurantrans@id@mmmmcmlxxxix{%
(Dan orang-orang yang paling dahulu) dalam kebaikan, mereka adalah para nabi; ayat ini berkedudukan menjadi Mubtada (yaitu orang-orang yang paling dahulu) lafal ayat ini mengukuhkan makna ayat pertama, dimaksud sebagai ungkapan tentang keagungan kedudukan mereka.\qt@no{10}}%
\qt@newcmd\qurantrans@id@mmmmcmxc{%
(Mereka itulah orang yang didekatkan).\qt@no{11}}%
\qt@newcmd\qurantrans@id@mmmmcmxci{%
(Berada di dalam surga-surga yang penuh dengan kenikmatan).\qt@no{12}}%
\qt@newcmd\qurantrans@id@mmmmcmxcii{%
(Segolongan besar dari orang-orang yang terdahulu) menjadi Mubtada, artinya golongan mayoritas dari umat-umat terdahulu.\qt@no{13}}%
\qt@newcmd\qurantrans@id@mmmmcmxciii{%
(Dan segolongan kecil dari orang-orang yang kemudian) yakni dari kalangan umat Nabi Muhammad saw. Mereka terdiri dari bagian besar umat-umat terdahulu dan umat Nabi Muhammad adalah orang-orang yang paling dahulu masuk surga.\qt@no{14}}%
\qt@newcmd\qurantrans@id@mmmmcmxciv{%
(Mereka berada di atas dipan-dipan yang bertahtakan emas dan permata) yaitu singgasana-singgasana yang terbuat dari emas dan permata.\qt@no{15}}%
\qt@newcmd\qurantrans@id@mmmmcmxcv{%
(Seraya bersandarkan di atasnya berhadap-hadapan) kedua lafal ayat ini berkedudukan menjadi Hal atau kata keterangan keadaan bagi Dhamir yang terkandung di dalam Khabar.\qt@no{16}}%
\qt@newcmd\qurantrans@id@mmmmcmxcvi{%
(Mereka dikelilingi) oleh para pelayan (yang terdiri dari anak-anak muda yang tetap muda) maksudnya, mereka tetap muda untuk selama-lamanya.\qt@no{17}}%
\qt@newcmd\qurantrans@id@mmmmcmxcvii{%
(Dengan membawa gelas-gelas) atau tempat-tempat minum yang tidak ada ikatan atau pegangannya (dan cerek) yakni tempat untuk menuangkan minuman yang mempunyai pegangan dan ada pipa penuangannya (dan guci) yaitu, tempat untuk meminum khamar (yang isinya diambil dari air yang mengalir) yaitu dari khamar yang mengalir dari sumbernya yang tidak pernah kering untuk selama-lamanya.\qt@no{18}}%
\qt@newcmd\qurantrans@id@mmmmcmxcviii{%
(Mereka tidak pernah merasa pening karenanya dan tidak pula mabuk) dapat dibaca Yanzafuuna atau Yanzifuuna, berasal dari lafal Nazafasy Syaaribu, dan Anzafasy Syaaribu. Artinya mereka tidak merasa pening dan tidak pula merasa mabuk karena meminumnya, berbeda dengan khamar di dunia.\qt@no{19}}%
\qt@newcmd\qurantrans@id@mmmmcmxcix{%
(Dan buah-buahan dari apa yang mereka pilih).\qt@no{20}}%
\qt@newcmd\qurantrans@id@mmmmm{%
(Dan daging burung dari apa yang mereka inginkan) untuk mereka nikmati sepuas-puasnya.\qt@no{21}}%
\qt@newcmd\qurantrans@id@mmmmmi{%
(Dan bidadari-bidadari) yakni wanita-wanita yang memiliki mata hitam pekat pada bagian yang hitamnya dan putih bersih pada bagian yang putihnya (yang bermata jeli) artinya, matanya lebar tetapi cantik. Harakat huruf 'Ainnya dikasrahkan sebagai pengganti dari harakat fatahnya demi untuk menyesuaikan diri dengan huruf Ya sesudahnya. Bentuk tunggalnya adalah 'Ainaa wazannya sama dengan Hamraa. Tetapi menurut suatu qiraat dibaca Huurin 'Inin yakni dibaca Jarr.\qt@no{22}}%
\qt@newcmd\qurantrans@id@mmmmmii{%
(Laksana mutiara yang tersimpan) yang disimpan dan terpelihara.\qt@no{23}}%
\qt@newcmd\qurantrans@id@mmmmmiii{%
(Sebagai balasan) menjadi Maf'ul Lah, atau Mashdar, sedangkan 'Amilnya diperkirakan keberadaannya, yaitu, Kami jadikan hal-hal yang telah disebutkan itu buat mereka sebagai pembalasan. Atau, Kami memberikan balasan kepada mereka (bagi apa yang telah mereka kerjakan).\qt@no{24}}%
\qt@newcmd\qurantrans@id@mmmmmiv{%
(Mereka tidak mendengar di dalamnya) di dalam surga itu (perkataan yang tidak ada gunanya) yakni perkataan jorok (dan tidak pula perkataan yang menimbulkan dosa) maksudnya perkataan yang berdosa.\qt@no{25}}%
\qt@newcmd\qurantrans@id@mmmmmv{%
(Akan tetapi) (dikatakan) kepada mereka ucapan (Salam, Salam) lafal ayat ini menjadi Badal dari lafal Qiilan; mereka benar-benar mendengarnya.\qt@no{26}}%
\qt@newcmd\qurantrans@id@mmmmmvi{%
(Dan golongan kanan, alangkah bahagianya golongan kanan itu).\qt@no{27}}%
\qt@newcmd\qurantrans@id@mmmmmvii{%
(Berada di antara pohon bidara) atau dikenal dengan nama pohon Nabaq (yang tidak berduri) tidak ada durinya.\qt@no{28}}%
\qt@newcmd\qurantrans@id@mmmmmviii{%
(Dan pohon pisang) yang juga dikenal dengan nama pohon muz (yang bersusun-susun) buahnya mulai dari bagian atas hingga bagian bawahnya.\qt@no{29}}%
\qt@newcmd\qurantrans@id@mmmmmix{%
(Dan naungan yang terbentang luas) untuk selama-lamanya.\qt@no{30}}%
\qt@newcmd\qurantrans@id@mmmmmx{%
(Dan air yang tercurah) maksudnya air yang mengalir terus selama-lamanya.\qt@no{31}}%
\qt@newcmd\qurantrans@id@mmmmmxi{%
(Dan buah-buahan yang banyak).\qt@no{32}}%
\qt@newcmd\qurantrans@id@mmmmmxii{%
(Yang tidak berhenti) buahnya. karena musim-musiman (dan tidak terlarang mengambilnya) artinya, ia boleh diambil tanpa harus membayarnya.\qt@no{33}}%
\qt@newcmd\qurantrans@id@mmmmmxiii{%
(Dan kasur-kasur yang tebal lagi empuk) yang diletakkan di atas dipan-dipan.\qt@no{34}}%
\qt@newcmd\qurantrans@id@mmmmmxiv{%
(Sesungguhnya Kami menciptakan mereka dengan langsung) maksudnya, bidadari-bidadari yang jelita lagi cantik itu Kami ciptakan tanpa melalui proses kelahiran terlebih dahulu.\qt@no{35}}%
\qt@newcmd\qurantrans@id@mmmmmxv{%
(Dan Kami jadikan mereka gadis-gadis perawan) yakni perawan semuanya; setiap kali suami-suami mereka menggaulinya, para suami itu menjumpai mereka dalam keadaan perawan kembali; dan tidak ada rasa sakit dikala menggaulinya.\qt@no{36}}%
\qt@newcmd\qurantrans@id@mmmmmxvi{%
(Penuh cinta) dapat dibaca 'Uruban atau 'Urban, bentuk jamak dari lafal 'Aruubun, artinya wanita yang sangat mencintai suaminya dan sangat merindukannya (lagi sebaya umurnya) setara umurnya; bentuk jamak dari lafal Turbun.\qt@no{37}}%
\qt@newcmd\qurantrans@id@mmmmmxvii{%
(Untuk golongan kanan) menjadi Shilah dari lafal Ansya-naahunna, atau dari lafal Ja'alnaahunna. Yakni Kami ciptakan atau Kami jadikan mereka untuk golongan kanan. Golongan kanan itu adalah,\qt@no{38}}%
\qt@newcmd\qurantrans@id@mmmmmxviii{%
(segolongan besar dari orang-orang yang terdahulu).\qt@no{39}}%
\qt@newcmd\qurantrans@id@mmmmmxix{%
(Dan segolongan besar pula dari orang-orang yang kemudian).\qt@no{40}}%
\qt@newcmd\qurantrans@id@mmmmmxx{%
(Dan golongan kiri, alangkah celakanya golongan kiri itu).\qt@no{41}}%
\qt@newcmd\qurantrans@id@mmmmmxxi{%
(Dalam angin yang amat panas) yaitu angin panas dari neraka, panas angin itu dapat menembus sampai ke pori-pori (dan air panas yang mendidih) yang panasnya tak terperikan.\qt@no{42}}%
\qt@newcmd\qurantrans@id@mmmmmxxii{%
(Dan dalam naungan asap yang hitam) mereka diliputi oleh asap yang sangat hitam.\qt@no{43}}%
\qt@newcmd\qurantrans@id@mmmmmxxiii{%
(Tidak sejuk) tidak sebagaimana naungan yang biasanya (dan tidak menyenangkan) tidak baik pemandangannya.\qt@no{44}}%
\qt@newcmd\qurantrans@id@mmmmmxxiv{%
(Sesungguhnya mereka sebelum itu) yakni sewaktu-waktu berada di dunia (hidup bermewah-mewah) mereka selalu hidup bersenang-senang dan tidak mau melelahkan diri mereka dalam ketaatan.\qt@no{45}}%
\qt@newcmd\qurantrans@id@mmmmmxxv{%
(Dan mereka terus menerus mengerjakan dosa) melakukan perbuatan dosa (yang besar) yaitu perbuatan menyekutukan Allah.\qt@no{46}}%
\qt@newcmd\qurantrans@id@mmmmmxxvi{%
(Dan mereka selalu mengatakan, ``Apabila kami mati dan menjadi tanah dan tulang belulang, apakah sesungguhnya kami benar-benar akan dibangkitkan?) kedua huruf Hamzah pada dua tempat dapat dibaca Tahqiq dan dapat pula dibaca Tas-hil.\qt@no{47}}%
\qt@newcmd\qurantrans@id@mmmmmxxvii{%
(Apakah bapak-bapak kami yang terdahulu dibangkitkan pula?") lafal Awa huruf Wawunya dibaca Fat-hah, sedangkan huruf Hamzahnya menunjukkan kata tanya, Hamzah atau kata tanya pada ayat ini dan pada ayat sebelumnya mengandung arti Istib'ad, artinya jauh dari kemungkinan; ini berdasarkan keyakinan mereka yang tidak mempercayainya. Tetapi menurut suatu qiraat huruf Wawu dibaca Sukun sehingga bacaannya menjadi Au karena di'athafkan kepada Inna dan Isimnya secara Mahall.\qt@no{48}}%
\qt@newcmd\qurantrans@id@mmmmmxxviii{%
(Katakanlah, ``Sesungguhnya orang-orang yang terdahulu dan orang-orang yang terkemudian,)\qt@no{49}}%
\qt@newcmd\qurantrans@id@mmmmmxxix{%
(benar-benar akan dikumpulkan di waktu tertentu) atau waktu yang tertentu (pada hari yang dikenal) yaitu pada hari kiamat.\qt@no{50}}%
\qt@newcmd\qurantrans@id@mmmmmxxx{%
(Kemudian sesungguhnya kalian, hai orang-orang yang sesat lagi mendustakan!)\qt@no{51}}%
\qt@newcmd\qurantrans@id@mmmmmxxxi{%
(Benar-benar akan memakan pohon zaqqum) lafal Min zaqquum menjadi Bayan dari lafal Min Syajarin.\qt@no{52}}%
\qt@newcmd\qurantrans@id@mmmmmxxxii{%
(Maka kalian akan memenuhi dengannya) dengan pohon zaqqum itu (perut-perut kalian).\qt@no{53}}%
\qt@newcmd\qurantrans@id@mmmmmxxxiii{%
(Sesudah itu kalian minum) yakni sesudah memakan buah pohon zaqqum itu (air yang sangat panas).\qt@no{54}}%
\qt@newcmd\qurantrans@id@mmmmmxxxiv{%
(Maka kalian minum seperti minumnya) dapat dibaca Syarba, atau Syurba, dalam keadaan Nashab karena menjadi Mashdar (unta yang kehausan) maksudnya, bagaikan unta yang sedang kehausan. Lafal Al Hiim adalah bentuk jamak dari lafal Haiman untuk jenis jantan, dan untuk jenis betina dikatakan Haimaa; wazannya sama dengan lafal 'Athsyaan dan 'Athsyaa.\qt@no{55}}%
\qt@newcmd\qurantrans@id@mmmmmxxxv{%
(Itulah hidangan untuk mereka) apa yang disediakan untuk mereka (pada hari pembalasan") yakni di hari kiamat nanti.\qt@no{56}}%
\qt@newcmd\qurantrans@id@mmmmmxxxvi{%
(Kami telah menciptakan kalian) dari tiada (maka mengapa tidak) kenapa tidak (kalian membenarkan) atau mempercayai adanya hari berbangkit, karena sesungguhnya Allah yang mampu menciptakan mereka. Dia mampu pula untuk menghidupkan mereka kembali.\qt@no{57}}%
\qt@newcmd\qurantrans@id@mmmmmxxxvii{%
(Maka terangkanlah kepada-Ku nuthfah yang kalian tumpahkan) yakni air mani yang kalian tumpahkan ke dalam rahim wanita.\qt@no{58}}%
\qt@newcmd\qurantrans@id@mmmmmxxxviii{%
(Kamukah) dapat dibaca Tahqiq dan dapat pula dibaca Tas-hil (yang menciptakannya) yakni air mani itu kemudian menjadi manusia (atau Kami kah yang menciptakannya?)\qt@no{59}}%
\qt@newcmd\qurantrans@id@mmmmmxxxix{%
(Kami telah menentukan) dapat dibaca Qaddarnaa atau Qadarnaa (kematian di antara kalian dan Kami sekali-kali tidak dapat dikalahkan) dibuat tak berdaya.\qt@no{60}}%
\qt@newcmd\qurantrans@id@mmmmmxl{%
(Untuk) maksudnya, supaya Kami (menggantikan) menjadikan (orang-orang yang seperti kalian) sebagai pengganti dari kalian (dan menciptakan kalian kelak) di akhirat (dalam keadaan yang tidak kalian ketahui) maksudnya, dalam bentuk yang belum kalian ketahui, seperti dalam bentuk kera atau babi, umpamanya.\qt@no{61}}%
\qt@newcmd\qurantrans@id@mmmmmxli{%
(Dan sesungguhnya kalian telah mengetahui penciptaan yang pertama) menurut suatu qiraat lafal An Nasy`ata boleh dibaca An-Nasya`ata (maka mengapa kalian tidak mengambil pelajaran?) lafal Tadzakkaruuna asalnya adalah Tatadzakkaruuna, lalu huruf Ta yang kedua diidgamkan kepada huruf Dzal.\qt@no{62}}%
\qt@newcmd\qurantrans@id@mmmmmxlii{%
(Maka terangkanlah kepada-Ku tentang yang kalian tanam?) yaitu tentang tanah yang kalian bajak lalu kalian semaikan benih-benih di atasnya.\qt@no{63}}%
\qt@newcmd\qurantrans@id@mmmmmxliii{%
(Kaliankah yang menumbuhkannya) suatu pertanyaan, apakah kalian yang telah menumbuhkannya (ataukah Kami yang menumbuhkannya?)\qt@no{64}}%
\qt@newcmd\qurantrans@id@mmmmmxliv{%
(Kalau Kami kehendaki, benar-benar Kami jadikan dia kering lagi keropos) maksudnya, tumbuhan yang kalian tanam itu menjadi kering tak ada biji dan isinya (maka jadilah kalian) pada asalnya lafal Zhaltum adalah Zhaliltum, lalu huruf Lam yang berharakat dibuang demi untuk meringankan bunyi sehingga jadilah Zhaltum, yakni jadilah kalian pada keesokan harinya (heran tercengang) keheranan karena melihat hal tersebut. Lafal Tafakkahuuna asalnya Tatafakkahuuna, lalu salah satu dari kedua huruf Ta dibuang sehingga menjadi Tafakkahuuna.\qt@no{65}}%
\qt@newcmd\qurantrans@id@mmmmmxlv{%
(-Seraya mengatakan-, ``Sesungguhnya kami benar-benar menderita kerugian,) biaya yang telah kami tanamkan buat tanaman kami.\qt@no{66}}%
\qt@newcmd\qurantrans@id@mmmmmxlvi{%
(Bahkan kami menjadi orang-orang yang tidak mendapat hasil apa-apa") kami tidak mendapatkan rezeki apa-apa.\qt@no{67}}%
\qt@newcmd\qurantrans@id@mmmmmxlvii{%
(Maka terangkanlah kepada-Ku tentang air yang kalian minum.)\qt@no{68}}%
\qt@newcmd\qurantrans@id@mmmmmxlviii{%
(Kaliankah yang menurunkannya dari awan) lafal Muzni adalah bentuk jamak dari lafal Muznatun, artinya awan yang membawa air hujan (ataukah Kami yang menurunkannya).\qt@no{69}}%
\qt@newcmd\qurantrans@id@mmmmmxlix{%
(Kalau Kami kehendaki niscaya Kami jadikan dia asin) berasa asin hingga tidak dapat diminum (maka mengapa tidak) kenapa tidak (kalian bersyukur?\qt@no{70}}%
\qt@newcmd\qurantrans@id@mmmmml{%
(Maka terangkanlah kepada-Ku tentang api yang kalian nyalakan) yang kalian keluarkan dari gosokan-gosokan kayu yang hijau.\qt@no{71}}%
\qt@newcmd\qurantrans@id@mmmmmli{%
(Kaliankah yang menjadikan kayu itu) yang dimaksud adalah pohon Marakh dan pohon 'Affar yang kayunya dapat dijadikan sebagai pemantik api (atau Kamikah yang menjadikannya?).\qt@no{72}}%
\qt@newcmd\qurantrans@id@mmmmmlii{%
(Kami menjadikan api itu untuk peringatan) yakni mengingatkan tentang neraka Jahanam (dan sebagai bekal) dalam perjalanan (bagi orang-orang yang mengadakan perjalanan) diambil dari lafal Aqwal Qaumu, yakni kaum itu kini berada di padang pasir yang tandus, tiada tumbuh-tumbuhan dan air padanya.\qt@no{73}}%
\qt@newcmd\qurantrans@id@mmmmmliii{%
(Maka bertasbihlah) artinya, Maha Sucikanlah (dengan menyebut nama) huruf Ba di sini adalah Zaidah (Rabbmu Yang Maha Besar) yakni Allah Yang Maha Besar.\qt@no{74}}%
\qt@newcmd\qurantrans@id@mmmmmliv{%
(Maka Aku bersumpah) huruf Laa di sini adalah Zaidah (dengan nama tempat-tempat terbenamnya bintang-bintang) tempat-tempat bintang-bintang tenggelam.\qt@no{75}}%
\qt@newcmd\qurantrans@id@mmmmmlv{%
(Sesungguhnya sumpah itu) sumpah dengan memakai namanya ita (adalah sumpah yang besar kalau kalian mengetahui) jika kalian termasuk orang-orang yang memiliki ilmu pengetahuan niscaya kalian mengetahui besarnya sumpah ini.\qt@no{76}}%
\qt@newcmd\qurantrans@id@mmmmmlvi{%
(Sesungguhnya ini) yakni yang dibacakan kepada kalian (adalah Alquran yang sangat mulia).\qt@no{77}}%
\qt@newcmd\qurantrans@id@mmmmmlvii{%
(Pada Kitab) yang tertulis dalam Kitab (yang terpelihara) yang dijaga, maksudnya Mushhaf Alquran.\qt@no{78}}%
\qt@newcmd\qurantrans@id@mmmmmlviii{%
(Tidak menyentuhnya) adalah kalimat berita, tetapi mengandung makna perintah, yakni jangan menyentuhnya (kecuali orang-orang yang telah bersuci) yakni orang-orang yang telah menyucikan dirinya dari hadas-hadas.\qt@no{79}}%
\qt@newcmd\qurantrans@id@mmmmmlix{%
(Diturunkan) ia diturunkan (dari Rabb semesta alam).\qt@no{80}}%
\qt@newcmd\qurantrans@id@mmmmmlx{%
(Maka apakah terhadap firman ini) Alquran ini (kalian menganggapnya remeh?) meremehkan dan mendustakannya\qt@no{81}}%
\qt@newcmd\qurantrans@id@mmmmmlxi{%
(Kalian menjadikan rezeki yang diberikan kepada kalian) yaitu berupa air hujan; kalian membalasnya (dengan mendustakan) rezeki yang diberikan Allah kepada kalian berupa air hujan itu karena kalian telah mengatakan, ``Kami di beri hujan oleh bintang anu".\qt@no{82}}%
\qt@newcmd\qurantrans@id@mmmmmlxii{%
(Maka mengapa tidak) kenapa tidak (sewaktu nyawa sampai) pada saat menjelang kematian (di tenggorokan) yakni pada saat nyawa sampai pada kerongkongan.\qt@no{83}}%
\qt@newcmd\qurantrans@id@mmmmmlxiii{%
(Padahal kalian) hai orang-orang yang menghadiri saat kematian (ketika itu melihat) kapada orang yang sedang mengalami kematiannya.\qt@no{84}}%
\qt@newcmd\qurantrans@id@mmmmmlxiv{%
(Dan Kami lebih dekat kepadanya daripada kalian) yakni melalui pengetahuan-Ku. (Tetapi kalian tidak melihat) kalian tidak mengetahui hal tersebut, lafal Tubshiruuna ini diambil dari lafal Bashiirah yang artinya melihat.\qt@no{85}}%
\qt@newcmd\qurantrans@id@mmmmmlxv{%
(Maka mengapa tidak) kenapa tidak (jika kalian merasa tidak akan dibalas) merasa tidak akan dibangkitkan nanti, sesuai dengan dugaan kalian.\qt@no{86}}%
\qt@newcmd\qurantrans@id@mmmmmlxvi{%
(Kalian mengembalikan nyawa itu) maksudnya, mengembalikannya ke dalam tubuh kalian sendiri sesudah nyawa itu mencapai kerongkongan? (jika kalian adalah orang-orang yang benar) di dalam pengakuan kalian itu. Lafal Falaulaa yang kedua mengukuhkan makna lafal Laulaa pertama. Sedangkan lafal Idzaa yang terkandung di dalam lafal Hiinaidzin menjadi Zharaf bagi lafal Tarji'uuna yang bergantung kepadanya kedua Syarat tersebut. Makna ayat, mengapa kalian tidak mengembalikan nyawa kalian sendiri ke dalam tubuh kalian, jika kalian tidak mempercayai adanya hari berbangkit dan kalian benar-benar meniadakannya? Yakni hendaknya kalian meniadakan pula kematian itu sebagai pengganti dari ketidakpercayaan kalian kepada adanya hari berbangkit.\qt@no{87}}%
\qt@newcmd\qurantrans@id@mmmmmlxvii{%
(Adapun jika dia) orang yang mati itu (termasuk orang-orang yang didekatkan-kepada Allah-).\qt@no{88}}%
\qt@newcmd\qurantrans@id@mmmmmlxviii{%
(Maka dia memperoleh ketenteraman) dia mendapatkan ketenangan (dan rezeki) yang baik (serta surga yang penuh dengan kenikmatan) apakah jawab ini bagi lafal Amma ataukah bagi In, ataukah menjadi Jawab bagi kedua-duanya?, sehubungan dengan masalah ini ada beberapa pendapat.\qt@no{89}}%
\qt@newcmd\qurantrans@id@mmmmmlxix{%
(Dan adapun jika dia termasuk golongan kanan).\qt@no{90}}%
\qt@newcmd\qurantrans@id@mmmmmlxx{%
(Maka keselamatan bagi kamu) yakni baginya keselamatan dari siksaan (karena kamu termasuk golongan kanan) karena dia termasuk di antara mereka.\qt@no{91}}%
\qt@newcmd\qurantrans@id@mmmmmlxxi{%
(Dan adapun jika dia termasuk golongan orang-orang yang mendustakan lagi sesat).\qt@no{92}}%
\qt@newcmd\qurantrans@id@mmmmmlxxii{%
(Maka dia mendapat hidangan air yang sangat panas).\qt@no{93}}%
\qt@newcmd\qurantrans@id@mmmmmlxxiii{%
(Dan dibakar di dalam neraka Jahim).\qt@no{94}}%
\qt@newcmd\qurantrans@id@mmmmmlxxiv{%
(Sesungguhnya yang disebutkan ini adalah suatu keyakinan yang benar) lafal Haqqul Yaqiin termasuk ungkapan dengan memakai cara mengidhafahkan Maushuf kepada sifatnya.\qt@no{95}}%
\qt@newcmd\qurantrans@id@mmmmmlxxv{%
(Maka bertasbihlah kamu dengan menyebut nama Rabbmu Yang Maha Besar) penafsirannya sebagaimana yang telah lalu.\qt@no{96}}%
\qt@newcmd\qurantrans@id@mmmmmlxxvi{%
\basmalahid (Semua yang berada di langit dan yang berada di bumi bertasbih kepada Allah) memahasucikan-Nya dari semua yang tidak layak bagi-Nya. Huruf Lam adalah Zaidah, dan dipakai lafal Ma bukannya Man karena memandang dari segi mayoritasnya. (Dan Dia-lah Yang Maha Perkasa) di dalam kerajaan-Nya (lagi Maha Bijaksana) di dalam perbuatan-Nya.\qt@no{1}}%
\qt@newcmd\qurantrans@id@mmmmmlxxvii{%
(Kepunyaan-Nyalah kerajaan langit dan bumi, Dia menghidupkan) melalui penciptaan (dan mematikan) sesudah itu (dan Dia Maha Kuasa atas segala sesuatu).\qt@no{2}}%
\qt@newcmd\qurantrans@id@mmmmmlxxviii{%
(Dialah Yang Awal) sebelum segala sesuatu ada, keawalan Dia tidak ada permulaannya (dan Yang Akhir) sesudah segala sesuatu berakhir, keakhiran-Nya tanpa batas (dan Yang Maha Zahir) melalui bukti-bukti yang menunjukkan kezahiran Nya (dan Yang Batin) yakni tidak dapat dilihat dan ditemukan oleh panca indra (dan Dia Maha Mengetahui atas segala sesuatu).\qt@no{3}}%
\qt@newcmd\qurantrans@id@mmmmmlxxix{%
(Dialah yang menciptakan langit dan bumi dalam enam hari) yakni sebagaimana hari-hari di dunia; dimulai dari hari Ahad dan berakhir pada hari Jumat. (Kemudian Dia bersemayam/berkuasa di atas Arasy) di atas Al Kursiy sesuai dengan keagungan dan kebesaran-Nya (Dia mengetahui apa yang masuk) semua yang masuk (ke dalam bumi) seperti air hujan dan orang-orang yang mati (dan apa yang keluar daripadanya) seperti tumbuh-tumbuhan dan mineral (dan apa yang turun dari langit) seperti rahmat/hujan dan azab (dan apa yang naik kepada-Nya) seperti amal-amal saleh dan amal-amal yang buruk. (Dan Dia bersama kalian) melalui ilmu-Nya (di mana saja kalian berada. Dan Allah Maha Melihat apa yang kalian kerjakan).\qt@no{4}}%
\qt@newcmd\qurantrans@id@mmmmmlxxx{%
(Kepunyaan-Nyalah kerajaan langit dan bumi. Dan kepada Allah-lah dikembalikan segala sesuatu) yakni semua yang ada ini.\qt@no{5}}%
\qt@newcmd\qurantrans@id@mmmmmlxxxi{%
(Dialah Yang memasukkan malam) yang memasukkannya (ke dalam siang) sehingga bertambah panjanglah waktu siang dan berkuranglah waktu malam (dan memasukkan siang ke dalam malam) sehingga waktu malam bertambah panjang sedangkan waktu siang semakin berkurang. (Dan Dia Maha Mengetahui segala isi hati) maksudnya, Dia Maha Mengetahui akan rahasia-rahasia dan keyakinan-keyakinan yang terkandung di dalam kalbu.\qt@no{6}}%
\qt@newcmd\qurantrans@id@mmmmmlxxxii{%
(Berimanlah kalian) artinya, tetaplah kalian beriman (kepada Allah dan Rasul-Nya dan nafkahkanlah) di jalan Allah (sebagian dari harta kalian yang Allah telah menjadikan kalian menguasainya) yakni dari harta orang-orang yang sebelum kalian dan kelak Dia akan menguasakannya kepada orang-orang yang sesudah kalian. Ayat ini diturunkan sewaktu perang 'Ursah atau dikenal dengan nama perang Tabuk. (Maka orang-orang yang beriman di antara kalian dan menafkahkan hartanya) ayat ini mengisyaratkan kepada apa yang telah dilakukan oleh sahabat Usman r.a. (mereka akan memperoleh pahala yang besar).\qt@no{7}}%
\qt@newcmd\qurantrans@id@mmmmmlxxxiii{%
(Dan mengapa kalian tidak beriman) khitab pada ayat ini ditujukan kepada orang-orang kafir, yakni tidak ada halangan bagi kalian untuk beriman (kepada Allah padahal Rasul menyeru kalian supaya kalian beriman kepada Rabb kalian. Dan sesungguhnya Dia telah mengambil) ia dapat dibaca Ukhidza dan Akhadza, kalau dibaca Akhadza maka lafal sesudahnya dibaca Nashab (perjanjian kalian) terhadap-Nya; yakni Allah telah mengambil janji itu di alam arwah, yaitu ketika Allah mengambil kesaksian terhadap jiwa mereka, Allah adalah Rabb mereka, sebagaimana yang diungkapkan di dalam ayat lain, yaitu firman-Nya, ``Bukankah Aku ini Rabb kalian?" Mereka menjawab, ``Betul (Engkau Rabb kami), kami menjadi saksi". (Q.S. Al A'raf, 172) (Jika kalian adalah orang-orang yang beriman) maksudnya, jika kalian hendak beriman kepada-Nya maka bersegeralah iman kepada-Nya.\qt@no{8}}%
\qt@newcmd\qurantrans@id@mmmmmlxxxiv{%
(Dialah yang menurunkan kepada hamba-Nya ayat-ayat yang terang) ayat-ayat Alquran yang jelas (supaya Dia mengeluarkan kalian dari kegelapan) dari kekafiran (kepada cahaya) kepada keimanan. (Dan sesungguhnya Allah benar-benar terhadap kalian) karena Dia telah mengeluarkan kalian dari kekafiran kepada iman (Maha Penyantun lagi Maha Penyayang).\qt@no{9}}%
\qt@newcmd\qurantrans@id@mmmmmlxxxv{%
(Dan mengapa kalian) sesudah beriman (tidak) lafal Allaa pada asalnya terdiri dari An dan Laa kemudian keduanya diidgamkan menjadi satu sehingga jadilah Allaa (menafkahkan sebagian harta kalian di jalan Allah, padahal Allah-lah yang mempusakai mempunyai langit dan bumi) berikut semua yang ada pada keduanya; maka sampailah kepada-Nya harta kalian tanpa membawa sedikit pun pahala infak kalian, berbeda halnya seandainya kalian menafkahkannya di jalan Allah, maka kalian akan mendapatkan pahala di sisi-Nya. (Tidak sama di antara kalian orang yang menafkahkan hartanya sebelum penaklukan) kota Mekah (dan ikut berperang sebelumnya -. Mereka lebih tinggi derajatnya daripada orang-orang yang menafkahkan hartanya dan berperang sesudah itu. Kepada masing-masing) dari dua golongan itu. Menurut suatu qiraat ia dibaca Kullun karena dianggap sebagai Mubtada (Allah telah menjanjikan balasan yang lebih baik) yaitu surga (Dan Allah mengetahui apa yang kalian kerjakan) maka kelak Dia akan membalasnya untuk kalian.\qt@no{10}}%
\qt@newcmd\qurantrans@id@mmmmmlxxxvi{%
(Siapakah yang mau meminjamkan kepada Allah) dengan cara menafkahkan hartanya di jalan Allah (pinjaman yang baik) seumpamanya hartanya itu dinafkahkan demi karena Allah (maka Allah akan melipatgandakan balasan pinjaman itu) menurut suatu qiraat dibaca Fayudha' 'ifahu (untuknya) mulai dari sepuluh kali lipat hingga tujuh ratus kali lipat, sebagaimana keterangan yang telah disebutkan di dalam surah Al Baqarah (dan baginya) di samping pahala yang dilipatgandakan itu (pahala yang banyak) juga disertai mendapat keridaan dari Allah dan disambut dengan baik.\qt@no{11}}%
\qt@newcmd\qurantrans@id@mmmmmlxxxvii{%
Ingatlah (pada hari ketika kamu melihat orang-orang mukmin laki-laki dan perempuan, sedangkan cahaya mereka bersinar di hadapan mereka) artinya bersinar menerangi bagian depan mereka (dan) cahaya itu pun (bersinar di sebelah kanan mereka) kemudian dikatakan kepada mereka, ("Pada hari ini ada berita gembira untuk kalian, yaitu surga-surga) masuklah kalian ke dalam surga-surga itu (yang di bawahnya mengalir sungai-sungai, yang kalian kekal di dalamnya. Itulah keberuntungan yang besar").\qt@no{12}}%
\qt@newcmd\qurantrans@id@mmmmmlxxxviii{%
(Pada hari ketika orang-orang munafik laki-laki dan perempuan berkata kepada orang-orang yang beriman, ``Perhatikanlah kami) lihatlah kami. Menurut suatu qiraat dibaca Anzhiruunaa, tunggulah kami (supaya kami dapat mengambil) maksudnya supaya kami kebagian cahaya dan sinar (sebagian dari cahaya kalian." Dikatakan) kepada mereka dengan nada yang memperolok-olokkan mereka, ("Kembalilah kalian ke belakang dan carilah sendiri cahaya untuk kalian") mereka mundur. (Lalu diadakan di antara mereka) dan antara orang-orang yang beriman (dinding) menurut suatu pendapat dinding itu dinamakan Al A'raaf (yang mempunyai pintu. Di sebelah dalamnya ada rahmat) ada bagian yang menghadap orang-orang yang beriman (dan di sebelah luarnya) ada bagian yang menghadap orang-orang munafik (dari situ ada azab).\qt@no{13}}%
\qt@newcmd\qurantrans@id@mmmmmlxxxix{%
(Orang-orang munafik itu memanggil mereka orang-orang mukmin, ``Bukankah kami dahulu bersama-sama kalian?") dalam ketaatan kepada Allah. (mereka menjawab, ``Benar, tetapi kalian mencelakakan diri kalian sendiri) disebabkan kemunafikan kalian (dan kalian selalu mengincar) kehancuran orang-orang mukmin (dan kalian ragu-ragu) masih ragu terhadap agama Islam (serta kalian ditipu oleh angan-angan kosong) yakni ketamakan (sehingga datanglah ketetapan Allah) yaitu kematian (dan kalian telah ditipu terhadap Allah oleh yang amat penipu) yakni oleh setan.\qt@no{14}}%
\qt@newcmd\qurantrans@id@mmmmmxc{%
(Maka pada hari ini tidak diterima) dapat dibaca Yu`khadzu dan Tu`khadzu (tebusan dari kalian dan tidak pula dari orang-orang kafir. Tempat kalian ialah neraka. Neraka itulah tempat yang layak buat kalian) tempat yang utama bagi kalian. (Dan neraka itu adalah seburuk-buruk tempat kembali") tempat kembali yang paling buruk adalah neraka.\qt@no{15}}%
\qt@newcmd\qurantrans@id@mmmmmxci{%
(Belumkah datang) maksudnya apakah belum tiba saatnya (bagi orang-orang yang beriman) ayat ini diturunkan berkenaan dengan kelakuan para sahabat, yaitu sewaktu mereka banyak bergurau (untuk tunduk hati mereka mengingat Allah dan mengingat apa yang telah diturunkan kepada mereka) dapat dibaca Nazzala dan Nazala (berupa kebenaran) yakni Alquran (dan janganlah mereka) di'athafkan kepada lafal Takhsya'a (seperti orang-orang yang sebelumnya telah diturunkan Alkitab kepadanya) mereka adalah orang-orang Yahudi dan orang-orang Nasrani (kemudian berlalulah masa yang panjang atas mereka) yaitu zaman antara mereka dan nabi-nabi mereka telah berlalu sangat lama (lalu hati mereka menjadi keras) tidak lunak lagi untuk mengingat Allah. (Dan kebanyakan di antara mereka adalah orang-orang fasik).\qt@no{16}}%
\qt@newcmd\qurantrans@id@mmmmmxcii{%
(Ketahuilah oleh kalian) khithab ayat ini ditujukan kepada orang-orang mukmin yang telah disebutkan di atas tadi (bahwa sesungguhnya Allah menghidupkan bumi sesudah matinya) dengan menumbuhkan tumbuh-tumbuhan padanya, demikianlah Allah menjadikan hati kalian untuk taat dan khusuk kembali dalam mengingat Allah. (Sesungguhnya Kami telah menjelaskan kepada kalian tanda-tanda) yang menunjukkan akan kekuasaan Kami terhadap hal ini dan hal-hal lainnya (supaya kalian memikirkannya).\qt@no{17}}%
\qt@newcmd\qurantrans@id@mmmmmxciii{%
(Sesungguhnya orang-orang yang membenarkan, baik laki-laki) mushshaddiqiina berasal dari mashdar tashadduq, kemudian huruf ta diidghamkan kepada huruf shad sehingga jadilah mushshaddiqiina, bentuk asalnya adalah mutashaddiqiina (maupun perempuan) yang percaya kepada Allah dan Rasul-Nya. Menurut qiraat lain kedua lafal tersebut dibaca tanpa tasydid, sehingga bacaannya menjadi innal mushaddiqiina wal mushaddiqaati, karena dianggap berasal dari tashdiq, sehingga artinya menjadi: Sesungguhnya orang-orang yang beriman, baik laki-laki maupun perempuan (dan meminjamkan kepada Allah pinjaman yang baik) dhamir yang ada pada lafal `aqradhuu kembali pada laki-laki dan perempuan, karena memprioritaskan kaum laki-laki. Fi'il atau kata kerja di sini diathafkan kepada isim, yaitu kepada shilah alif dan lam, karena sesungguhnya lafal al-mushshaddiqiina wal mushshaddiqaati yang dimasuki alif dan lam sama kedudukannya dengan fi'il yang berada sesudah shilah. Disebutkannya lafal al-qardhu berikut sifatnya sesudah pengertian tashadduq, hal ini memberikan pengertian adanya ikatan di antara lafal-lafal tersebut. Atau dengan kata lain, bahwa orang-orang yang membenarkan Allah dan Rasul-Nya itu adalah orang-orang yang mau meminjamkan kepada Allah pinjaman yang baik (maka Allah akan melipatgandakan) menurut suatu qiraat dibaca yudha`'af dengan memakai tasydid pada huruf 'ainnya, artinya balasan pinjaman mereka itu akan dilipatgandakan pahalanya (kepada mereka; dan bagi mereka pahala yang banyak).\qt@no{18}}%
\qt@newcmd\qurantrans@id@mmmmmxciv{%
(Dan orang-orang yang beriman kepada Allah dan Rasul-Nya, mereka itu adalah orang-orang shiddiqin) orang-orang yang sangat beriman kepada Allah dan Rasul-Nya (dan orang-orang yang menjadi saksi di sisi Rabb mereka) atas kedustaan umat-umat yang terdahulu terhadap nabi-nabi mereka. (Bagi mereka pahala dan cahaya mereka. Dan orang-orang yang kafir dan mendustakan ayat-ayat Kami) yang menunjukkan kepada keesaan Kami (mereka itulah penghuni-penghuni Jahim) yakni neraka.\qt@no{19}}%
\qt@newcmd\qurantrans@id@mmmmmxcv{%
(Ketahuilah, bahwa sesungguhnya kehidupan dunia itu hanyalah permainan dan suatu yang melalaikan, perhiasan) sebagai perhiasan (dan bermegah-megahan antara kalian serta berbangga-bangga tentang banyaknya harta dan anak) artinya, menyibukkan diri di dalamnya. Adapun mengenai ketaatan dan hal-hal yang membantu menuju kepadanya termasuk perkara-perkara akhirat (seperti) kehidupan dunia yang menyilaukan kalian dan kepunahannya sesudah itu bagaikan (hujan) bagaikan air hujan (yang membuat orang-orang yang bertani merasa kagum) merasa takjub (akan tanam-tanamannya) yang tumbuh disebabkan turunnya hujan itu (kemudian tanaman itu menjadi kering) lapuk dan kering (dan kamu lihat warnanya yang kuning itu kemudian menjadi hancur) menjadi keropos dan berjatuhan ditiup angin. (Dan di akhirat ada azab yang keras) bagi orang-orang yang lebih memilih keduniaan (dan ampunan dari Allah serta keridaan-Nya) bagi orang-orang yang lebih memilih akhirat daripada dunia. (Dan kehidupan dunia ini tidak lain) maksudnya bersenang-senang dalam dunia ini tiada lain (hanyalah kesenangan yang menipu).\qt@no{20}}%
\qt@newcmd\qurantrans@id@mmmmmxcvi{%
(Berlomba-lombalah kalian kepada ampunan dari Rabb kalian dan surga yang luasnya seluas langit dan bumi) seandainya jarak di antara keduanya dapat diukur; lafal al-'ardh artinya luas (yang disediakan bagi orang-orang yang beriman kepada Allah dan Rasul-Nya. Itulah karunia Allah, diberikan-Nya kepada siapa yang dikehendaki-Nya. Dan Allah mempunyai karunia yang besar).\qt@no{21}}%
\qt@newcmd\qurantrans@id@mmmmmxcvii{%
(Tiada suatu bencana pun yang menimpa di bumi) seperti kekeringan (dan tidak pula pada diri kalian sendiri) seperti sakit dan kematian anak (melainkan telah tertulis dalam Kitab) di Lohmahfuz (sebelum Kami menciptakannya) sebelum Kami menciptakan semuanya. Demikian pula mengenai hal yang menyangkut nikmat dikatakan seperti itu. (Sesungguhnya yang demikian itu adalah mudah bagi Allah).\qt@no{22}}%
\qt@newcmd\qurantrans@id@mmmmmxcviii{%
(Supaya janganlah) lafal kay di sini menashabkan fi'il yang jatuh sesudahnya, maknanya sama dengan lafal an. Allah swt. menjelaskan yang demikian itu supaya janganlah (kalian berduka cita) bersedih hati (terhadap apa yang luput dari kalian, dan supaya kalian jangan terlalu gembira) artinya gembira yang dibarengi dengan rasa takabur, berbeda halnya dengan gembira yang dibarengi dengan rasa syukur atas nikmat (terhadap apa yang diberikan-Nya kepada kalian) jika lafal aataakum dibaca panjang berarti maknanya sama dengan lafal a`thaakum, artinya apa yang diberikan-Nya kepada kalian. Jika dibaca pendek, yaitu ataakum artinya, apa yang didatangkan-Nya kepada kalian. (Dan Allah tidak menyukai setiap orang yang sombong) dengan apa yang telah diberikan oleh Allah kepadanya (lagi membanggakan diri) membangga-banggakannya terhadap orang lain.\qt@no{23}}%
\qt@newcmd\qurantrans@id@mmmmmxcix{%
(Orang-orang yang kikir) tidak mau menunaikan apa yang telah diwajibkan atas mereka (dan menyuruh manusia berbuat kikir) supaya jangan menunaikan kewajiban itu, maka bagi mereka ancaman yang keras dari Allah. (Dan barang siapa yang berpaling) dari menunaikan apa yang telah diwajibkan atasnya (maka sesungguhnya Allah Dialah) lafal huwa adalah dhamir fashl, sedangkan menurut suatu qiraat tanpa memakainya (Yang Maha Kaya) artinya tidak membutuhkan orang lain (lagi Maha Terpuji) terhadap kekasih-kekasih-Nya.\qt@no{24}}%
\qt@newcmd\qurantrans@id@mmmmmc{%
(Sesungguhnya Kami telah mengutus rasul-rasul Kami) yaitu malaikat-malaikat-Nya kepada nabi-nabi (dengan membawa bukti-bukti yang nyata) hujah-hujah yang jelas dan akurat (dan telah Kami turunkan bersama mereka Alkitab) lafal Alkitab ini sekalipun bentuknya mufrad tetapi makna yang dimaksud adalah jamak, yakni al-kutub (dan neraca) yakni keadilan (supaya manusia dapat melaksanakan keadilan. Dan Kami ciptakan besi) maksudnya Kami keluarkan besi dari tempat-tempat penambangannya (yang padanya terdapat kekuatan yang hebat) yakni dapat dipakai sebagai alat untuk berperang (dan berbagai manfaat bagi manusia, dan supaya Allah mengetahui) supaya Allah menampilkan; lafal waliya'lamallaahu diathafkan pada lafal liyaquman-naaasu (siapa yang menolong-Nya) maksudnya siapakah yang menolong agama-Nya dengan memakai alat-alat perang yang terbuat dari besi dan lain-lainnya itu (dan rasul-rasul-Nya padahal Allah tidak dilihatnya) lafal bil-ghaibi menjadi hal atau kata keterangan keadaan dari dhamir ha yang terdapat pada lafal yanshuruhu. Yakni sekalipun Allah tidak terlihat oleh mereka di dunia ini. Ibnu Abbas r.a. memberikan penakwilannya, mereka menolong agama-Nya padahal mereka tidak melihat-Nya. (Sesungguhnya Allah Maha Kuat lagi Maha Perkasa) artinya Dia tidak memerlukan pertolongan siapa pun, akan tetapi perbuatan itu manfaatnya akan dirasakan sendiri oleh orang yang mengerjakannya.\qt@no{25}}%
\qt@newcmd\qurantrans@id@mmmmmci{%
(Dan sesungguhnya Kami telah mengutus Nuh dan Ibrahim dan Kami jadikan pada keturunan keduanya kenabian dan Alkitab) yaitu kitab yang empat; Taurat, Injil, Zabur dan Al-Furqan. Kitab-kitab tersebut diturunkan kepada anak cucu Nabi Ibrahim (maka di antara mereka ada yang menerima petunjuk dan kebanyakan di antara mereka adalah orang-orang fasik).\qt@no{26}}%
\qt@newcmd\qurantrans@id@mmmmmcii{%
(Kemudian Kami iringi di belakang mereka dengan rasul-rasul Kami dan Kami iringi pula dengan Isa putra Maryam; dan Kami berikan kepadanya Injil dan Kami jadikan dalam hati orang-orang yang mengikutinya rasa santun dan kasih sayang. Dan kerahbaniyahan) yakni tidak mau kawin dan hidup membaktikan diri di dalam gereja-gereja (yang mereka ada-adakan) oleh diri mereka sendiri (padahal Kami tidak mewajibkannya kepada mereka) Kami tidak memerintahkan hal itu kepada mereka (tetapi) melainkan mereka mengerjakannya (untuk mencari keridaan) demi mencari kerelaan (Allah, lalu mereka tidak memeliharanya dengan pemeliharaan yang semestinya) karena kebanyakan di antara mereka meninggalkannya dan kafir kepada agama Nabi Isa, lalu mereka memasuki agama raja mereka. Akan tetapi masih banyak pula di antara mereka yang berpegang teguh kepada ajaran Nabi Isa, lalu mereka beriman kepada Nabi Muhammad. (Maka Kami berikan kepada orang-orang yang beriman) kepada Nabi Isa (di antara mereka pahalanya dan banyak di antara mereka orang-orang fasik).\qt@no{27}}%
\qt@newcmd\qurantrans@id@mmmmmciii{%
(Hai orang-orang yang beriman) kepada Nabi Isa (bertakwalah kepada Allah dan berimanlah kepada Rasul-Nya) kepada Nabi Muhammad saw. dan Nabi Isa (niscaya Allah memberikan kepada kalian dua bagian) dua kali bagian (dari rahmat-Nya) karena kalian telah beriman kepada dua nabi (dan menjadikan untuk kalian cahaya yang dengan cahaya itu kalian dapat berjalan) di atas shirath/jembatan (dan Dia mengampuni kalian. Dan Allah Maha Pengampun lagi Maha Penyayang).\qt@no{28}}%
\qt@newcmd\qurantrans@id@mmmmmciv{%
(Supaya diketahui) maksudnya Allah menerangkan hal tersebut kepada kalian, supaya diketahui (oleh ahli kitab) Taurat yang tidak beriman kepada Nabi Muhammad (bahwa) an di sini adalah bentuk takhfif dari anna yang ditasydidkan, artinya bahwasanya mereka (mereka tiada mendapat sedikit pun akan karunia Allah) berbeda dengan apa yang mereka duga, yaitu bahwasanya mereka adalah kekasih-kekasih Allah dan orang-orang yang mendapat keridaan-Nya (dan bahwasanya karunia itu berada di tangan kekuasaan Allah. Dia berikan karunia itu) yakni Dia memberikannya (kepada siapa yang dikehendaki-Nya) maka Dia memberikan karunia-Nya kepada orang-orang yang beriman di antara mereka, berupa pahala yang mereka terima sebanyak dua kali lipat, sebagaimana keterangan yang telah lalu. Yaitu karena beriman kepada dua nabi. (Dan Allah mempunyai karunia yang besar).\qt@no{29}}%
\qt@newcmd\qurantrans@id@mmmmmcv{%
\basmalahid (Sesungguhnya Allah telah mendengar perkataan wanita yang mengajukan gugatan kepada kamu) yakni seorang wanita yang melapor kepadamu, hai nabi (tentang suaminya) yang telah mengucapkan kata-kata zihar kepadanya. Suami wanita itu berkata kepadanya, ``Kamu menurutku bagaikan punggung ibuku." Lalu wanita itu menanyakan hal tersebut kepada Nabi saw., maka beliau menjawab bahwa dia haram atas suaminya. Hal ini sesuai dengan tradisi yang berlaku di kalangan mereka, bahwa zihar itu akibatnya adalah perpisahan untuk selama-lamanya. Wanita yang dimaksud bernama Khaulah binti Tsa'labah, sedangkan suaminya bernama Aus bin Shamit (dan mengadukan halnya kepada Allah) yakni tentang keadaannya yang tidak mempunyai orang tua dan famili yang terdekat, serta keadaan ekonominya yang serba kekurangan, di samping itu ia menanggung beban anak-anaknya yang masih kecil-kecil; apabila anak-anaknya dibawa oleh suaminya, niscaya mereka akan tersia-sia dan tak terurus lagi keadaannya tetapi apabila anak-anak itu di bawah pemeliharaannya, niscaya mereka akan kelaparan. (Dan Allah mendengar soal jawab antara kamu berdua) dialog kamu berdua. (Sesungguhnya Allah Maha Mendengar lagi Maha Melihat) artinya Maha Mengetahui.\qt@no{1}}%
\qt@newcmd\qurantrans@id@mmmmmcvi{%
(Orang-orang yang menzihar) asal kata yazhzhahharuuna adalah yatazhahharuuna, kemudian huruf ta diidgamkan ke dalam huruf zha sehingga jadilah yazhzhahharuuna. Akan tetapi menurut suatu qiraat dibaca dengan memakai huruf alif di antara huruf zha dan ha, sehingga bacaannya menjadi yazhaaharuuna. Menurut qiraat lainnya dibaca seperti wazan yuqaatiluuna, yakni menjadi yuzhaahiruuna. Lafal yang sama pada ayat berikutnya berlaku pula ketentuan ini (istrinya di antara kalian, padahal tiadalah istri mereka itu ibu mereka. Ibu-ibu mereka tidak lain hanyalah wanita-wanita) lafal allaaiy dapat dibaca dengan memakai huruf ya dan dapat pula dibaca tanpa ya (yang melahirkan mereka. Sesungguhnya mereka) dengan melakukan zihar itu (sungguh-sungguh mengucapkan suatu perkataan yang mungkar dan dusta). (Dan sesungguhnya Allah Maha Pemaaf lagi Maha Pengampun) kepada orang yang melakukan zihar dengan pembayaran kifarat.\qt@no{2}}%
\qt@newcmd\qurantrans@id@mmmmmcvii{%
(Dan orang-orang yang menzihar istri mereka, kemudian mereka hendak menarik kembali apa yang mereka ucapkan) tentang zihar ini, seumpama dia bersikap berbeda dengan apa yang telah dikatakannya itu, yaitu dengan cara tetap memegang istri yang diziharnya. Sedangkan perbuatan ini jelas bertentangan dengan maksud tujuan daripada perkataan zihar, yaitu menggambarkan istri dengan sifat yang menjadikannya haram bagi dia (maka memerdekakan seorang budak) maksudnya wajib atasnya memerdekakan seorang budak (sebelum kedua suami istri itu bercampur) bersetubuh. (Demikianlah yang diajarkan kepada kalian, dan Allah Maha Mengetahui apa yang kalian kerjakan).\qt@no{3}}%
\qt@newcmd\qurantrans@id@mmmmmcviii{%
(Maka barang siapa yang tidak mendapatkan) budak (maka wajib atasnya berpuasa dua bulan berturut-turut, sebelum keduanya bercampur. Maka siapa yang tidak mampu) melakukan puasa (memberi makan enam puluh orang miskin) diwajibkan atasnya, yakni sebelum keduanya bercampur kembali sebagai suami istri; untuk tiap-tiap orang miskin satu mudd makanan pokok negeri orang yang bersangkutan. Kesimpulan hukum ini berdasarkan pemahaman menyamakan pengertian yang mutlak dengan yang muqayyad. (Demikianlah) keringanan ini dengan memakai kifarat (supaya kalian beriman kepada Allah dan Rasul-Nya. Dan itulah) yakni hukum-hukum tersebut (batasan-batasan Allah, dan bagi orang-orang yang ingkar) kepada batasan-batasan atau hukum-hukum Allah itu (azab yang sangat pedih) atau siksaan yang amat menyakitkan.\qt@no{4}}%
\qt@newcmd\qurantrans@id@mmmmmcix{%
(Sesungguhnya orang-orang yang menentang) orang-orang yang melawan (Allah dan Rasul-Nya pasti mendapat kehinaan) mereka pasti akan memperoleh kehinaan (sebagaimana orang-orang yang sebelum mereka telah mendapat kehinaan) karena mereka menentang rasul-rasul mereka. (Sesungguhnya Kami telah menurunkan ayat-ayat yang jelas) yang menunjukkan kebenaran Rasul. (Dan bagi orang-orang yang kafir) yang ingkar kepada ayat-ayat itu (ada azab yang menghinakan) yaitu siksaan yang membuat mereka hina.\qt@no{5}}%
\qt@newcmd\qurantrans@id@mmmmmcx{%
(Pada hari ketika mereka semuanya dibangkitkan Allah lalu diberitakan-Nya kepada mereka apa yang telah mereka kerjakan. Allah menghitung amal perbuatan itu, padahal mereka telah melupakannya. Dan Allah Maha Menyaksikan segala sesuatu).\qt@no{6}}%
\qt@newcmd\qurantrans@id@mmmmmcxi{%
(Tidakkah kamu perhatikan) tidakkah kamu ketahui (bahwa sesungguhnya Allah mengetahui apa yang ada di langit dan apa yang ada di bumi? Tiada pembicaraan rahasia antara tiga orang, melainkan Dialah yang keempatnya) yakni melalui ilmu-Nya. (Dan tiada pembicaraan antara lima orang, melainkan Dialah yang keenamnya. Dan tiada pula pembicaraan antara jumlah yang kurang dari itu atau lebih banyak, melainkan Dia ada bersama mereka di mana pun mereka berada. Kemudian Dia akan memberitakan kepada mereka pada hari kiamat apa yang telah mereka kerjakan. Sesungguhnya Allah Maha Mengetahui segala sesuatu).\qt@no{7}}%
\qt@newcmd\qurantrans@id@mmmmmcxii{%
(Apakah tidak kamu perhatikan) apakah tidak kamu lihat (orang-orang yang telah dilarang mengadakan pembicaraan rahasia, kemudian mereka kembali mengerjakan larangan itu dan mereka mengadakan pembicaraan rahasia untuk berbuat dosa, permusuhan dan durhaka kepada rasul) mereka adalah orang-orang Yahudi; Nabi saw. telah melarang mereka dari pembicaraan rahasia yang dahulu sering mereka lakukan. Pembicaraan rahasia mereka itu dalam rangka merencanakan tindakan sabotase terhadap kaum mukminin, dimaksud supaya mereka dapat menanamkan keraguan dalam hati kaum mukminin. (Dan apabila mereka datang kepadamu, mereka mengucapkan salam kepadamu) hai nabi (dengan memberi salam yang bukan sebagai yang ditentukan Allah untukmu) yaitu perkataan mereka, ``As-Sammu 'alaika," yakni kematian atasmu. (Dan mereka mengatakan pada diri mereka sendiri, ``Mengapa tidak) kenapa tidak (diturunkan azab atas kami oleh Allah disebabkan apa yang kita katakan itu?") Yakni salam penghinaan yang kami katakan itu, kalau begitu dia bukanlah seorang nabi, sekalipun dia adalah nabi. (Cukuplah bagi mereka neraka Jahanam yang akan mereka masuki Dan seburuk-buruk tempat kembali itu) adalah neraka Jahanam.\qt@no{8}}%
\qt@newcmd\qurantrans@id@mmmmmcxiii{%
(Hai orang-orang yang beriman, apabila kalian mengadakan pembicaraan rahasia, janganlah kalian membicarakan tentang berbuat dosa, permusuhan dan durhaka kepada rasul. Dan bicarakanlah tentang berbuat kebaikan dan takwa. Dan bertakwalah kepada Allah yang kepada-Nya kalian akan dikembalikan).\qt@no{9}}%
\qt@newcmd\qurantrans@id@mmmmmcxiv{%
(Sesungguhnya pembicaraan rahasia itu) yakni yang membicarakan berbuat dosa dan yang sejenisnya (adalah dari setan) melalui bujuk rayuannya (supaya orang-orang yang beriman itu berduka cita, sedangkan tiadalah) pembicaraan itu (dapat memberikan mudarat kepada mereka barang sedikit pun kecuali dengan izin Allah) atas kehendak-Nya (dan kepada Allah-lah hendaknya orang-orang yang beriman bertawakal).\qt@no{10}}%
\qt@newcmd\qurantrans@id@mmmmmcxv{%
(Hai orang-orang yang beriman, apabila dikatakan kepada kalian, ``Berlapang-lapanglah) berluas-luaslah (dalam majelis") yaitu majelis tempat Nabi saw. berada, dan majelis zikir sehingga orang-orang yang datang kepada kalian dapat tempat duduk. Menurut suatu qiraat lafal al-majaalis dibaca al-majlis dalam bentuk mufrad (maka lapangkanlah, niscaya Allah akan memberi kelapangan untuk kalian) di surga nanti. (Dan apabila dikatakan, ``Berdirilah kalian") untuk melakukan salat dan hal-hal lainnya yang termasuk amal-amal kebaikan (maka berdirilah) menurut qiraat lainnya kedua-duanya dibaca fansyuzuu dengan memakai harakat damah pada huruf Syinnya (niscaya Allah akan meninggikan orang-orang yang beriman di antara kalian) karena ketaatannya dalam hal tersebut (dan) Dia meninggikan pula (orang-orang yang diberi ilmu pengetahuan beberapa derajat) di surga nanti. (Dan Allah Maha Mengetahui apa yang kalian kerjakan).\qt@no{11}}%
\qt@newcmd\qurantrans@id@mmmmmcxvi{%
(Hai orang-orang yang beriman, apabila kalian mengadakan pembicaraan khusus dengan rasul) yakni kalian bermaksud untuk melakukannya dengan dia (hendaklah kalian mengeluarkan sebelum pembicaraan kalian itu) sebelum pembicaraan khusus itu diadakan (sedekah. Yang demikian itu adalah lebih baik bagi kalian dan lebih bersih) artinya lebih membersihkan dosa-dosa kalian (jika kalian tidak menemukan) apa yang kalian sedekahkan (maka sesungguhnya Allah Maha Pengampun) terhadap pembicaraan khusus yang akan kalian lakukan itu (lagi Maha Penyayang) terhadap kalian. Makna yang dimaksud, tiada dosa bagi kalian untuk melakukan pembicaraan khusus itu sekalipun tanpa sedekah.\qt@no{12}}%
\qt@newcmd\qurantrans@id@mmmmmcxvii{%
(Apakah kalian takut) dapat dibaca tahqiq dan tashil, artinya merasa takut dari (karena kamu memberikan sedekah sebelum pembicaraan dengan rasul) karena takut menjadi miskin. (Maka jika kalian tiada memperbuatnya) artinya tidak memberikan sedekah (dan Allah telah memberi tobat kepada kalian) maksudnya Dia telah membebaskan kalian dari sedekah itu (maka dirikanlah salat, tunaikanlah zakat dan taatlah kepada Allah dan Rasul-Nya) yakni terus-meneruslah kalian melakukan hal-hal tersebut (dan Allah Maha Mengetahui apa yang kalian kerjakan).\qt@no{13}}%
\qt@newcmd\qurantrans@id@mmmmmcxviii{%
(Tidakkah kamu perhatikan) tidakkah kamu melihat (orang-orang yang menjadikan teman) mereka adalah kaum munafik (suatu kaum) yang dimaksud adalah orang-orang Yahudi (yang dimurkai Allah? Orang-orang itu bukan) yakni orang-orang munafik itu bukan (dari golongan kalian) orang-orang mukmin (dan bukan pula dari golongan mereka) bukan dari kalangan orang-orang Yahudi akan tetapi mereka adalah orang-orang yang bermuka dua. (Dan mereka bersumpah untuk menguatkan kebohongan) yakni perkataan mereka bahwa sesungguhnya mereka adalah orang-orang beriman (sedang mereka mengetahui) bahwa dalam hal ini mereka berdusta belaka.\qt@no{14}}%
\qt@newcmd\qurantrans@id@mmmmmcxix{%
(Allah telah menyediakan bagi mereka azab yang sangat keras, sesungguhnya amat buruklah apa yang telah mereka kerjakan) dari perbuatan-perbuatan maksiat.\qt@no{15}}%
\qt@newcmd\qurantrans@id@mmmmmcxx{%
(Mereka menjadikan sumpah-sumpah mereka sebagai perisai) untuk melindungi jiwa dan harta mereka (lalu mereka halangi) dengan sumpah mereka itu orang-orang mukmin (dari jalan Allah) untuk berjihad melawan mereka yang musuh dalam selimut itu, dengan cara membunuh mereka dan merampas harta benda mereka (karena itu mereka mendapat azab yang menghinakan) siksaan yang membuat mereka hina.\qt@no{16}}%
\qt@newcmd\qurantrans@id@mmmmmcxxi{%
(Harta benda dan anak-anak mereka tiada berguna untuk menolong mereka dari Allah) dari azab-Nya (barang sedikit pun) yakni tiada berguna sama sekali. (Mereka itulah penghuni neraka, mereka kekal di dalamnya).\qt@no{17}}%
\qt@newcmd\qurantrans@id@mmmmmcxxii{%
Ingatlah (hari ketika mereka dibangkitkan Allah semuanya, lalu mereka bersumpah kepada-Nya) bahwasanya mereka adalah orang-orang yang beriman (sebagaimana mereka bersumpah kepada kalian; dan mereka menyangka bahwa sesungguhnya mereka akan memperoleh sesuatu) manfaat dari sumpah mereka di akhirat itu sebagaimana sumpah mereka di dunia. (Ketahuilah, bahwa sesungguhnya merekalah orang-orang pendusta).\qt@no{18}}%
\qt@newcmd\qurantrans@id@mmmmmcxxiii{%
(Telah berkuasa) maksudnya telah berhasil mempengaruhi (atas mereka setan) karena ternyata mereka menaatinya (lalu menjadikan mereka lupa mengingat Allah; mereka itulah golongan setan) yakni pengikut-pengikutnya. (Ketahuilah bahwa sesungguhnya golongan setan itulah golongan yang merugi).\qt@no{19}}%
\qt@newcmd\qurantrans@id@mmmmmcxxiv{%
(Sesungguhnya orang-orang yang menentang) melawan (Allah dan Rasul-Nya, mereka termasuk orang-orang yang sangat hina) yang dikalahkan.\qt@no{20}}%
\qt@newcmd\qurantrans@id@mmmmmcxxv{%
(Allah telah menetapkan) di Lohmahfuz, atau Allah telah memastikan: ("Aku dan Rasul-Ku pasti menang.") Dalam berhujah atau berdebat atau menggunakan senjata. (Sesungguhnya Allah Maha Kuat lagi Maha Perkasa).\qt@no{21}}%
\qt@newcmd\qurantrans@id@mmmmmcxxvi{%
(Kamu tidak akan mendapati sesuatu kaum yang beriman kepada Allah dan hari akhirat, saling berkasih sayang) artinya berteman (dengan orang-orang yang menentang Allah dan Rasul-Nya sekalipun orang-orang itu) yakni orang-orang yang menentang itu (bapak-bapak mereka) yakni bapak-bapak orang-orang yang beriman (atau anak-anak mereka, atau saudara-saudara mereka, atau pun keluarga mereka) bahkan orang-orang yang beriman itu pasti memusuhi mereka dan memerangi mereka demi keimanannya, sebagaimana yang dialami oleh sebagian para sahabat. (Mereka itulah) orang-orang yang tidak mau berkasih sayang dengan orang-orang yang menentang Allah dan Rasul-Nya (yang Allah telah menanamkan) yakni meneguhkan (keimanan dalam kalbu mereka dan menguatkan mereka dengan cahaya) yakni nur (dari-Nya) dari Allah swt. (Dan dimasukkan-Nya mereka ke dalam surga yang mengalir di bawahnya sungai-sungai, mereka kekal di dalamnya. Allah rida terhadap mereka) karena ketaatan mereka kepada-Nya (dan mereka pun merasa puas terhadap-Nya) atas pahala. (Mereka itulah golongan Allah) artinya yang mengikuti perintah-Nya dan menjauhi larangan-Nya. (Ketahuilah, bahwa sesungguhnya golongan Allah itulah yang beruntung) yang memperoleh keberuntungan.\qt@no{22}}%
\qt@newcmd\qurantrans@id@mmmmmcxxvii{%
\basmalahid (Bertasbih kepada Allah apa yang ada di langit dan apa yang ada di bumi) semuanya memahasucikan-Nya. Huruf lam pada lafal lillaahi adalah zaidah; ungkapan dengan memakai lafal maa, karena lebih memprioritaskan makhluk yang tidak berakal yang jumlahnya lebih banyak (dan Dialah Yang Maha Perkasa lagi Maha Bijaksana) di dalam kerajaan-Nya dan dalam perbuatan-Nya.\qt@no{1}}%
\qt@newcmd\qurantrans@id@mmmmmcxxviii{%
(Dialah Yang mengeluarkan orang-orang kafir di antara ahli kitab) mereka adalah Bani Nadhir yang terdiri dari orang-orang Yahudi (dari kampung mereka) dari tempat-tempat tinggal mereka di Madinah (pada saat pengusiran pertama) yaitu sewaktu mereka diusir ke negeri Syam, dan terakhir mereka diusir ke tanah Khaibar oleh Khalifah Umar semasa ia menjabat sebagai khalifah. (Kalian tidak mengira) hai orang-orang mukmin (bahwa mereka akan keluar dan mereka pun yakin, bahwa dapat mencegah mereka) lafal maani'atuhum adalah khabar dari anna (benteng-benteng mereka) menjadi fa'il dari lafal maani'atuhum; dan dengan keberadaannya maka lengkaplah pengertian khabar (dari Allah) yakni dari azab-Nya (maka Allah mendatangkan kepada mereka) hukuman dan azab-Nya (dari arah yang tidak mereka sangka-sangka) yakni dari pihak kaum mukminin yang hal ini tidak masuk ke dalam perhitungan mereka. (Dan Allah melemparkan) maksudnya menanamkan (rasa takut ke dalam hati mereka) dapat dibaca ar-ru'ba atau ar-ru'uba, artinya rasa takut mati, karena pemimpin mereka bernama Ka'b bin Asyraf telah terbunuh mati (mereka memusnahkan) dapat dibaca yukharribuuna, dan kalau dibaca yukhribuuna berarti berasal dari lafal akhraba, artinya merusak (rumah-rumah mereka) untuk mengambil barang-barang yang dianggap berharga oleh mereka berupa kayu-kayu dan lain-lainnya (dengan tangan mereka sendiri dan tangan orang-orang yang beriman. Maka ambillah hal itu untuk menjadi pelajaran, hai orang-orang yang mempunyai pandangan).\qt@no{2}}%
\qt@newcmd\qurantrans@id@mmmmmcxxix{%
(Dan jika tidaklah karena Allah telah menetapkan) telah memastikan (pengusiran terhadap mereka) yakni dikeluarkan dari kampung halamannya (benar-benar Allah mengazab mereka di dunia) dengan dibunuh dan ditawan, sebagaimana yang telah dilakukan-Nya terhadap orang-orang Yahudi Bani Quraizhah. (Dan bagi mereka di akhirat azab neraka).\qt@no{3}}%
\qt@newcmd\qurantrans@id@mmmmmcxxx{%
(Yang demikian itu adalah karena sesungguhnya mereka telah menentang) telah melawan (Allah dan Rasul-Nya. Barang siapa menentang Allah, maka sesungguhnya Allah sangat keras hukuman-Nya) terhadap dia.\qt@no{4}}%
\qt@newcmd\qurantrans@id@mmmmmcxxxi{%
(Apa saja yang kalian tebang) hai orang-orang muslim (dari pohon kurma) milik orang kafir (atau yang kalian biarkan tumbuh berdiri di atas pokoknya, maka semua itu adalah dengan izin Allah) yakni Allah swt. menyerahkannya kepada kalian (dan karena Dia hendak memberikan kehinaan) dengan mengizinkan kalian menebangnya (kepada orang-orang fasik) yakni orang-orang Yahudi, karena mereka telah menentang, bahwa menebang pohon yang berbuah itu adalah pengrusakan.\qt@no{5}}%
\qt@newcmd\qurantrans@id@mmmmmcxxxii{%
(Dan apa saja harta difaikan) harta yang diberikan (oleh Allah kepada Rasul-Nya dari harta benda mereka, maka kalian tidak mengerahkan) tidak melarikan hai kaum muslimin (untuk mendapatkannya) huruf min di sini adalah huruf zaidah (seekor kuda pun dan tidak pula seekor unta pun) yang dimaksud dengan lafal rikabin adalah unta kendaraan. Makna yang dimaksud ialah bahwa untuk mendapatkan harta fai itu kalian tidak susah payah lagi (tetapi Allah yang memberikan kekuasaan kepada Rasul-Nya terhadap siapa yang dikehendaki-Nya. Dan Allah Maha Kuasa atas segala sesuatu) maka tidak ada hak lagi bagi kalian dalam harta fai itu; itu khusus hanya untuk Nabi saw. dan untuk orang-orang yang akan disebutkan pada ayat selanjutnya, yaitu terdiri dari empat golongan, sesuai dengan apa yang telah ditentukan oleh Allah dalam pembagiannya. Maka bagi setiap golongan di antara mereka mendapatkan seperlimanya, dan bagi Nabi saw. sendiri adalah sisanya, artinya sama juga dengan seperlima. Nabi saw. boleh memberlakukan bagiannya itu sesuai dengan apa yang disukainya, untuk itu maka beliau memberikan sebagian daripadanya kepada orang-orang Muhajirin dan tiga orang dari kalangan sahabat Ansar karena mengingat kefakiran mereka.\qt@no{6}}%
\qt@newcmd\qurantrans@id@mmmmmcxxxiii{%
(Apa saja harta rampasan atau fai yang diberikan Allah kepada Rasul-Nya yang berasal dari penduduk kota-kota) seperti tanah Shafra, lembah Al-Qura dan tanah Yanbu' (maka adalah untuk Allah) Dia memerintahkannya sesuai dengan apa yang dikehendaki-Nya (untuk Rasul, orang-orang yang mempunyai) atau memiliki (hubungan kekerabatan) yaitu kaum kerabat Nabi dari kalangan Bani Hasyim dan Bani Mutthalib (anak-anak yatim) yaitu anak-anak kaum muslimin yang bapak-bapak mereka telah meninggal dunia sedangkan mereka dalam keadaan fakir (orang-orang miskin) yaitu orang-orang muslim yang serba kekurangan (dan orang-orang yang dalam perjalanan) yakni orang-orang muslim yang mengadakan perjalanan lalu terhenti di tengah jalan karena kehabisan bekal. Yakni harta fai itu adalah hak Nabi saw. beserta empat golongan orang-orang tadi, sesuai dengan apa yang telah ditentukan oleh Allah swt. dalam pembagiannya, yaitu bagi masing-masing golongan yang empat tadi seperlimanya dan sisanya untuk Nabi saw. (supaya janganlah) lafal kay di sini bermakna lam, dan sesudah kay diperkirakan adanya lafal an (harta fai itu) yakni harta rampasan itu, dengan adanya pembagian ini (hanya beredar) atau berpindah-pindah (di antara orang-orang kaya saja di antara kalian. Apa yang telah diberikan kepada kalian) yakni bagian yang telah diberikan kepada kalian (oleh Rasul) berupa bagian harta fa-i dan harta-harta lainnya (maka terimalah dia. Dan apa yang dilarangnya bagi kalian maka tinggalkanlah; dan bertakwalah kepada Allah. Sesungguhnya Allah sangat keras hukuman-Nya).\qt@no{7}}%
\qt@newcmd\qurantrans@id@mmmmmcxxxiv{%
(Terhadap orang-orang fakir) bertaalluq kepada lafal yang tidak disebutkan, lengkapnya: Takjublah kalian terhadap orang-orang fakir (yang berhijrah, yang diusir dari kampung halaman dan dari harta benda mereka karena mencari karunia dari Allah dan keridaan-Nya dan mereka menolong agama, Allah dan Rasul-Nya. Mereka itulah orang-orang yang benar) dalam keimanannya.\qt@no{8}}%
\qt@newcmd\qurantrans@id@mmmmmcxxxv{%
(Dan orang-orang yang telah menempati kota) Madinah (dan telah beriman) yang dimaksud adalah sahabat-sahabat Anshar (sebelum kedatangan mereka, Muhajirin, mereka mencintai orang-orang yang berhijrah kepada mereka. Dan mereka tiada menaruh keinginan dalam hati mereka) artinya mereka tidak iri hati (terhadap apa-apa yang diberikan kepada mereka) yakni apa yang telah diberikan oleh Nabi saw. kepada mereka berupa harta rampasan dari Bani Nadhir, yang memang harta itu khusus buat kaum Muhajirin (dan mereka mengutamakan, orang-orang Muhajirin, atas diri mereka sendiri sekalipun mereka dalam kesusahan) yakni mereka memerlukan apa yang mereka relakan kepada orang-orang Muhajirin. (Dan siapa yang dipelihara dari kekikiran dirinya) dari ketamakannya terhadap harta benda (mereka itulah orang-orang yang beruntung).\qt@no{9}}%
\qt@newcmd\qurantrans@id@mmmmmcxxxvi{%
(Dan orang-orang yang datang sesudah mereka) yakni sesudah kaum Muhajirin dan kaum Ansar hingga hari kiamat nanti (mereka berdoa, ``Ya Rabb kami! Beri ampunlah kami dan saudara-saudara kami yang telah beriman lebih dahulu dari kami, dan janganlah Engkau membiarkan kedengkian dalam hati kami) yakni rasa dengki (terhadap orang-orang yang beriman; Ya Rabb kami, sesungguhnya Engkau Maha Penyantun lagi Maha Penyayang.")\qt@no{10}}%
\qt@newcmd\qurantrans@id@mmmmmcxxxvii{%
(Apakah kamu tiada memperhatikan) tiada melihat (orang-orang yang munafik yang berkata kepada saudara-saudara mereka yang kafir di antara ahli kitab) yaitu kepada Bani Nadhir dan saudara-saudara mereka yang kafir: ("Sesungguhnya jika) huruf lam di sini menunjukkan makna qasam dan demikian pula pada tempat-tempat lainnya yang semuanya ada di empat tempat (kalian diusir) dari Madinah (niscaya kami pun akan keluar bersama kalian, dan kami tidak akan patuh untuk menghinakan kalian) yakni untuk menjadikan kalian terhina (kepada siapa pun selama-lamanya, dan jika kalian diperangi) dari lafal wa in terbuang huruf lam yang menunjukkan makna permulaan (pasti kami akan membantu kalian." Dan Allah menyaksikan, bahwa sesungguhnya mereka benar-benar pendusta).\qt@no{11}}%
\qt@newcmd\qurantrans@id@mmmmmcxxxviii{%
(Sesungguhnya jika mereka diusir, orang-orang munafik itu tiada akan keluar bersama mereka, dan sesungguhnya jika mereka diperangi, niscaya mereka tidak akan menolongnya; sesungguhnya jika mereka menolongnya) artinya mereka datang untuk menolong dan membantunya (niscaya mereka akan berpaling ke belakang) jawab qasam yang keberadaannya diperkirakan sudah memberikan pengertian yang cukup, tanpa harus menyebut jawab syarat pada kelima tempat tadi (kemudian mereka tidak akan mendapat pertolongan) yang dimaksud adalah orang-orang Yahudi.\qt@no{12}}%
\qt@newcmd\qurantrans@id@mmmmmcxxxix{%
(Sesungguhnya kalian lebih ditakuti) lebih disegani (dalam hati mereka) dalam hati orang-orang munafik itu (daripada Allah) karena siksaan-Nya yang ditangguhkan. (Yang demikian itu karena mereka adalah kaum yang tiada mengerti.\qt@no{13}}%
\qt@newcmd\qurantrans@id@mmmmmcxl{%
(Mereka tidak akan memerangi kalian) yakni orang-orang Yahudi itu (dalam keadaan bersatu padu) maksudnya, secara serentak (kecuali dalam kampung-kampung yang berbenteng atau di balik tembok) yang tinggi. Menurut suatu qiraat lafal judurin dibaca jidaarin. (Permusuhan) peperangan (di antara sesama mereka sangat hebat. Kalian kira mereka itu bersatu sedangkan hati mereka berpecah belah) berbeda-beda, bertentangan dengan apa yang diduga. (Yang demikian itu karena sesungguhnya mereka adalah kaum yang tiada mengerti).\qt@no{14}}%
\qt@newcmd\qurantrans@id@mmmmmcxli{%
Perumpamaan mereka dalam hal tidak mau beriman (seperti orang-orang yang belum lama sebelum mereka) yakni sebagaimana orang-orang musyrik yang terlibat dalam perang Badar (yang telah merasai akibat buruk dari perbuatan mereka) sebagai hukuman-Nya di dunia, yaitu mereka mati terbunuh dan hukuman-hukuman yang lainnya yang mereka rasakan (dan bagi mereka azab yang pedih) siksaan yang menyakitkan kelak di akhirat.\qt@no{15}}%
\qt@newcmd\qurantrans@id@mmmmmcxlii{%
Dan juga perumpamaan mereka dalam hal mendengar dari orang-orang munafik, tetapi orang-orang munafik itu tidak mau mengikuti jejak mereka sesudahnya (seperti halnya setan; ia berkata kepada manusia, ``Kafirlah kamu," maka tatkala manusia itu telah kafir, ia berkata, ``Sesungguhnya aku berlepas diri dari kamu karena sesungguhnya aku takut kepada Allah, Rabb semesta alam.") Padahal ia dusta dan hanya ria belaka.\qt@no{16}}%
\qt@newcmd\qurantrans@id@mmmmmcxliii{%
(Maka adalah sesudah keduanya) yakni orang yang sesat dan orang yang disesatkan. Menurut suatu qiraat lafal 'aaqibatahumaa dibaca 'aaqibatuhumaa dengan memakai harakat damah di atas huruf ta, hal ini berarti sebagai isim dari lafal kaana (bahwa sesungguhnya keduanya masuk ke dalam neraka, mereka kekal di dalamnya. Demikianlah balasan orang-orang yang lalim) orang-orang yang kafir.\qt@no{17}}%
\qt@newcmd\qurantrans@id@mmmmmcxliv{%
(Hai orang-orang yang beriman! Bertakwalah kepada Allah dan hendaklah setiap diri memperhatikan apa yang telah diperbuatnya untuk hari esok) yakni untuk menghadapi hari kiamat (dan bertakwalah kepada Allah, sesungguhnya Allah Maha Mengetahui apa yang kalian kerjakan).\qt@no{18}}%
\qt@newcmd\qurantrans@id@mmmmmcxlv{%
(Dan janganlah kalian seperti orang-orang yang lupa kepada Allah) maksudnya tidak mau taat kepada-Nya (lalu Allah menjadikan mereka lupa kepada diri mereka sendiri) untuk melakukan perbuatan ketaatan dan perbuatan baik. (Mereka itulah orang-orang yang fasik).\qt@no{19}}%
\qt@newcmd\qurantrans@id@mmmmmcxlvi{%
(Tidak sama penghuni-penghuni neraka dengan penghuni-penghuni surga; penghuni-penghuni surga itulah orang-orang yang beruntung).\qt@no{20}}%
\qt@newcmd\qurantrans@id@mmmmmcxlvii{%
(Kalau sekiranya Kami menurunkan Alquran ini kepada sebuah gunung) lalu dijadikan-Nya pada gunung tersebut akal sebagaimana manusia (pasti kamu akan melihatnya tunduk terpecah belah) terbelah-belah (disebabkan takut kepada Allah. Dan perumpamaan-perumpamaan itu) yang telah disebutkan di atas tadi (Kami buat untuk manusia supaya mereka berpikir) yang karenanya lalu mereka beriman.\qt@no{21}}%
\qt@newcmd\qurantrans@id@mmmmmcxlviii{%
(Dialah Allah Yang tiada Tuhan selain Dia, Yang Mengetahui yang gaib dan yang nyata. Dialah Yang Maha Pemurah lagi Maha Penyayang).\qt@no{22}}%
\qt@newcmd\qurantrans@id@mmmmmcxlix{%
(Dialah Allah yang tiada Tuhan selain Dia, Raja Yang Maha Suci) dari semua apa yang tidak layak bagi keagungan dan kebesaran-Nya (Yang Maha Selamat) artinya Yang Bebas dari segala sifat-sifat kekurangan (Yang Maha Mengamankan) para rasul-rasul-Nya dengan menciptakan mukjizat bagi mereka (Yang Maha Memelihara) berasal dari lafal haimana-yuhaiminu, dikatakan demikian apabila seseorang selalu mengawasi sesuatu. Makna yang dimaksud ialah, Dia Maha Menyaksikan amal perbuatan hamba-hamba-Nya (Yang Maha Perkasa) yakni Yang Maha Kuat (Yang Maha Kuasa) untuk memaksa makhluk-Nya supaya menuruti apa yang dikehendaki-Nya (Yang Maha Agung) dari semua sifat yang tidak layak bagi keagungan-Nya. (Maha Suci Allah) Dia memahasucikan Zat-Nya sendiri melalui ayat ini (dari apa yang mereka persekutukan) dengan-Nya.\qt@no{23}}%
\qt@newcmd\qurantrans@id@mmmmmcl{%
(Dialah Allah Yang Menciptakan, Yang Mengadakan) makhluk-Nya dari tiada (Yang membentuk rupa, hanya kepunyaan-Nyalah asma-asma yang paling baik) yang berjumlah sembilan puluh sembilan, sebagaimana yang telah disebutkan dalam hadis. Lafal al-husna adalah bentuk muannats dari lafal al-ahsan. (Bertasbih kepada-Nya apa yang ada di langit dan di bumi. Dan Dialah Yang Maha Perkasa lagi Maha Bijaksana) penafsirannya sebagaimana yang telah lalu.\qt@no{24}}%
\qt@newcmd\qurantrans@id@mmmmmcli{%
\basmalahid (Hai orang-orang yang beriman, janganlah kalian mengambil musuh-Ku dan musuh kalian) yakni orang-orang kafir Mekah (menjadi teman-teman setia yang kalian sampaikan) kalian beritakan (kepada mereka) tujuan Nabi saw. yang akan memerangi mereka; Nabi memerintahkan kepada kalian supaya merahasiakannya yaitu sewaktu perang Hunain (karena rasa kasih sayang) di antara kalian dan mereka. Sehubungan dengan peristiwa ini Hathib bin Abu Balta'ah mengirimkan sepucuk surat kepada orang-orang musyrik, karena Hathib mempunyai beberapa orang anak dan sanak famili yang musyrik. Akan tetapi Nabi saw. dapat mengambil surah itu dari tangan orang yang diutus olehnya, berkat pemberitahuan dari Allah kepada Nabi saw. melalui wahyu-Nya. Lalu alasan dan permintaan maaf Hathib diterima oleh Nabi saw. (padahal sesungguhnya mereka telah ingkar kepada kebenaran yang datang kepada kalian) yakni agama Islam dan Alquran (mereka mengusir Rasul dan mengusir kalian) dari Mekah setelah terlebih dahulu mereka mengganggu kalian supaya kalian keluar dari Mekah (karena kalian beriman) disebabkan kalian beriman (kepada Allah, Rabb kalian. Jika kalian benar-benar keluar untuk berjihad) untuk melakukan jihad (pada jalan-Ku dan mencari keridaan-Ku) maka janganlah kalian mengambil mereka sebagai teman-teman setia. Jawab syarat ini disimpulkan dari pengertian ayat yang selanjutnya, yaitu: (Kalian memberitahukan secara rahasia kepada mereka, karena rasa kasih sayang. Aku lebih mengetahui apa yang kalian sembunyikan dan apa yang kalian nyatakan. Dan barang siapa di antara kalian yang melakukannya) yaitu memberitahukan berita-berita Nabi saw. kepada orang-orang musyrik secara rahasia (maka sesungguhnya dia telah tersesat dari jalan yang lurus) artinya menyimpang dari jalan hidayah. Lafal as-sawaa menurut pengertian asalnya berarti tengah-tengah.\qt@no{1}}%
\qt@newcmd\qurantrans@id@mmmmmclii{%
(Jika mereka menangkap kalian) yakni berhasil menahan kalian (niscaya mereka bertindak sebagai musuh bagi kalian dan melepaskan tangan mereka kepada kalian) maksudnya membunuh dan memukuli kalian (dan lisan mereka mengeluarkan kata-kata yang kotor) yakni mencaci maki kalian (dan mereka ingin) mengharapkan (supaya kalian kafir kembali).\qt@no{2}}%
\qt@newcmd\qurantrans@id@mmmmmcliii{%
(Tidak akan bermanfaat bagi kalian karib kerabat kalian) famili-famili kalian (dan anak-anak kalian) yang musyrik, karena kalian memberitahukan berita-berita Nabi secara rahasia kepada mereka; mereka semuanya sekali-kali tiada bermanfaat bagi diri kalian untuk menolak azab di hari akhirat (pada hari kiamat Dia akan memisahkan) dapat dibaca yafshilu dan yufshalu (antara kalian) dan antara mereka; karena kalian berada di dalam surga, sedangkan mereka bersama-sama dengan orang-orang kafir di dalam neraka. (Dan Allah Maha Melihat apa yang kalian kerjakan).\qt@no{3}}%
\qt@newcmd\qurantrans@id@mmmmmcliv{%
(Sesungguhnya telah ada suri teladan bagi kalian) lafal uswatun dapat pula dibaca iswatun, artinya teladan atau panutan (yang baik pada Ibrahim) yakni pada diri Nabi Ibrahim, baik perkataan maupun perbuatannya (dan pada orang-orang yang bersama dia) dari kalangan orang-orang yang beriman (ketika mereka berkata kepada kaum mereka, ``Sesungguhnya kami berlepas diri) lafal bura-aa-u adalah bentuk jamak dari lafal barii'un, wazannya sama dengan lafal zharifun yang jamaknya zhurafaa'u (dari kalian apa yang kalian sembah selain Allah, kami ingkar kepada kekafiran kalian) kami membenci kekafiran kalian (dan telah nyata antara kami dan kalian permusuhan dan kebencian buat selama-lamanya) lafal wal baghdhaa'u abadan dapat dibaca secara tahqiq dan dapat pula dibaca secara tashil, yakni mengganti huruf hamzah yang kedua menjadi wau (sampai kalian beriman kepada Allah semata." Kecuali perkataan Ibrahim kepada bapaknya, ``Sesungguhnya aku akan memohonkan ampunan bagi kamu) perkataan ini merupakan perkataan yang dikecualikan daripada pengertian suri teladan tadi. Maka sekali-kali kalian tidak boleh mengucapkan kata penyesalan seperti itu, seumpamanya kalian memohonkan ampunan buat orang-orang kafir. Dan juga perkataan Nabi Ibrahim berikut ini (dan aku tiada dapat melindungimu dari Allah) dari siksaan dan pahala-Nya (barang sedikit pun.") Nabi Ibrahim mengungkapkan kata-kata ini sebagai kiasan, bahwasanya dia tidak memiliki buatnya selain dari memohonkan ampun. Perkataan ini pun termasuk di antara hal yang dikecualikan untuk tidak boleh diikuti, karena sekalipun pengertian lahiriahnya sebagai ungkapan penyesalan, akan tetapi maksudnya berkaitan dengan pengertian kalimat yang pertama. Pengertian lahiriah kalimat yang kedua ini sama dengan pengertian yang terkandung di dalam firman Allah swt., `` Katakanlah! 'Maka siapakah gerangan yang dapat menghalang-halangi kehendak Allah jika Dia menghendaki kemudaratan bagi kamu.'" (Q.S. Al-Fath 11) Permohonan ampun Nabi Ibrahim buat bapaknya ini sebelum jelas bagi Nabi Ibrahim, bahwa bapaknya itu adalah benar-benar musuh Allah, sebagaimana yang telah dijelaskan di dalam surah Al-Bara'ah atau surah At-Taubah. ("Ya Rabb kami, hanya kepada Engkaulah kami bertawakal dan hanya kepada Engkaulah kami bertobat dan hanya kepada Engkaulah kami kembali.") Kalimat ini termasuk doa yang selalu diucapkan oleh Al-Khalil atau Nabi Ibrahim dan orang-orang beriman yang bersamanya; yakni, mereka mengucapkan kata-kata tersebut.\qt@no{4}}%
\qt@newcmd\qurantrans@id@mmmmmclv{%
("Ya Rabb kami, janganlah Engkau jadikan kami sasaran fitnah bagi orang-orang kafir) maksudnya janganlah Engkau menjadikan mereka menang atas kami, sehingga nanti mereka menduga, bahwa mereka berada dalam jalan yang benar, lalu karena itu mereka terfitnah, yakni akal mereka ditujukan untuk mempengaruhi kami. (Dan ampunilah kami Ya Rabb kami. Sesungguhnya Engkau, Engkaulah Yang Maha Perkasa lagi Maha Bijaksana.") Maha Perkasa di dalam kerajaan-Mu lagi Maha Bijaksana perbuatan-Mu.\qt@no{5}}%
\qt@newcmd\qurantrans@id@mmmmmclvi{%
(Sesungguhnya telah ada bagi kalian) hai umat Muhammad, menjadi jawab qasam yang keberadaannya diperkirakan (teladan yang baik pada mereka itu, yaitu bagi orang yang mengharap pahala Allah dan hari akhirat) yakni bagi orang yang takut kepada keduanya; atau bagi orang yang menduga bahwa dirinya akan mendapat pahala dan selamat dari siksa. (Dan barang siapa yang berpaling) seumpamanya dia mengambil orang-orang kafir sebagai teman setia (maka sesungguhnya Allah, Dialah Yang Maha Kaya) yakni tidak membutuhkan makhluk-Nya (lagi Maha terpuji) di kalangan orang-orang yang taat kepada-Nya.\qt@no{6}}%
\qt@newcmd\qurantrans@id@mmmmmclvii{%
(Mudah-mudahan Allah menimbulkan antara kalian dengan orang-orang yang kalian musuhi di antara mereka) yakni di antara orang-orang kafir Mekah, demi taat kepada perintah Allah swt. (kasih sayang) seumpamanya karena Allah memberikan petunjuk kepada mereka untuk beriman, karenanya mereka lalu menjadi teman-teman setia kalian. (Dan Allah adalah Maha Kuasa) untuk melakukan hal tersebut, dan ternyata Allah swt. melakukan hal tersebut sesudah penaklukan kota Mekah. (Dan Allah Maha Pengampun) kepada mereka atas kesalahan-kesalahan mereka di masa lalu sebelum mereka masuk Islam (lagi Maha Penyayang) terhadap mereka.\qt@no{7}}%
\qt@newcmd\qurantrans@id@mmmmmclviii{%
(Allah tiada melarang kalian terhadap orang-orang yang tidak memerangi kalian) dari kalangan orang-orang kafir (karena agama dan tidak mengusir kalian dari negeri kalian untuk berbuat baik kepada mereka) lafal an tabarruuhum menjadi badal isytimal dari lafal alladziina (dan berlaku adil) yaitu melakukan peradilan (terhadap mereka) dengan secara adil. Ayat ini diturunkan sebelum ada perintah untuk berjihad melawan mereka. (Sesungguhnya Allah menyukai orang-orang yang adil) yang berlaku adil.\qt@no{8}}%
\qt@newcmd\qurantrans@id@mmmmmclix{%
(Sesungguhnya Allah hanya melarang kalian terhadap orang-orang yang memerangi kalian karena agama dan mengusir kalian dari negeri kalian dan membantu) yakni menolong orang lain (untuk mengusir kalian untuk menjadikan mereka sebagai kawan kalian) lafal An Tawallauhum menjadi Badal Isytimal dari lafal Al Ladzina, yakni Dia melarang kalian untuk menjadikan mereka sebagai teman-teman setia kalian. (Dan barang siapa menjadikan mereka sebagai kawan, maka mereka itulah orang-orang yang lalim).\qt@no{9}}%
\qt@newcmd\qurantrans@id@mmmmmclx{%
(Hai orang-orang yang beriman, apabila datang kepada kalian perempuan-perempuan yang beriman) secara lisannya (untuk berhijrah) dari orang-orang kafir sesudah kalian mengadakan perjanjian perdamaian dengan orang-orang kafir dalam perjanjian Hudaibiah, yaitu bahwa barang siapa yang datang kepada orang-orang mukmin dari kalangan mereka, maka orang itu harus dikembalikan lagi kepada mereka (maka hendaklah kalian uji mereka) melalui sumpah, yaitu bahwa sesungguhnya mereka sekali-kali tidak keluar meninggalkan kampung halamannya melainkan karena senang kepada Islam, bukan karena benci terhadap suami mereka yang kafir, dan bukan pula karena mencintai orang-orang lelaki dari kalangan kaum muslimin. Demikianlah isi sumpah yang dilakukan oleh Nabi saw. kepada perempuan-perempuan itu (Allah telah mengetahui tentang keimanan mereka; maka jika kalian telah mengetahui, bahwa mereka) yakni kalian menduga melalui sumpah yang telah mereka ucapkan, bahwa mereka (benar-benar beriman maka janganlah kalian kembalikan mereka) janganlah kalian mengembalikan mereka (kepada orang-orang kafir. Mereka tidak halal bagi orang-orang kafir itu dan orang-orang kafir itu tiada halal pula bagi mereka. Dan berikanlah kepada mereka) yakni kembalikanlah kepada orang-orang kafir yang menjadi suami mereka (mahar yang telah mereka bayar) kepada perempuan-perempuan mukmin itu. (Dan tiada dosa atas kalian mengawini mereka) dengan syarat (apabila kalian bayar kepada mereka maharnya) maskawinnya. (Dan janganlah kalian tetap berpegang) dapat dibaca tumsikuu, dan tumassikuu yakni dengan memakai tasydid dan tanpa tasydid (pada tali perkawinan dengan perempuan-perempuan kafir) yakni istri-istri kalian yang kafir, karena keislaman kalian telah memutuskannya dari kalian berikut syarat-syaratnya. Atau perempuan-perempuan yang menyusul atau mengikuti orang-orang musyrik dalam keadaan murtad, karena kemurtadannya telah memutuskan tali perkawinan mereka dengan kalian, berikut syarat-syaratnya (dan hendaklah kalian minta) hendaklah kalian tuntut (apa yang telah kalian nafkahkan) kepada mereka yaitu mahar-mahar yang telah kalian bayar kepada mereka, berupa pengembalian dari orang-orang kafir yang mengawini mereka (dan hendaklah mereka meminta mahar yang telah mereka bayar) kepada perempuan-perempuan yang ikut berhijrah, sebagaimana penjelasan yang telah lalu yaitu bahwasanya kaum musliminlah yang membayarkannya. (Demikianlah hukum Allah yang ditetapkan-Nya di antara kalian) untuk kalian laksanakan. (Dan Allah Maha Mengetahui lagi Maha Bijaksana).\qt@no{10}}%
\qt@newcmd\qurantrans@id@mmmmmclxi{%
(Dan jika seseorang dari istri-istri kalian lari) seorang atau lebih di antara istri-istri kalian. Atau sebagian dari mahar mereka luput dari kalian, karena mereka lari (kepada orang-orang kafir) dalam keadaan murtad (lalu kalian mengalahkan mereka) maksudnya, memerangi mereka kemudian kalian memperoleh ganimah (maka bayarkanlah kepada orang-orang yang istrinya lari itu) dari ganimah yang kalian peroleh (mahar sebanyak yang telah mereka bayar) karena sebagian dari mahar tersebut tidak sempat mereka terima dari pihak orang-orang kafir. (Dan bertakwalah kepada Allah Yang kepada-Nya kalian beriman) kemudian orang-orang mukmin itu benar-benar mengerjakan apa yang telah diperintahkan kepada mereka, yaitu memberikan ganti rugi mahar kepada orang-orang kafir, dan juga kepada orang-orang mukmin yang istrinya lari, kemudian hukum ini sesudah itu ditiadakan.\qt@no{11}}%
\qt@newcmd\qurantrans@id@mmmmmclxii{%
(Hai nabi, apabila datang kepada kamu perempuan-perempuan yang beriman untuk mengadakan janji setia, bahwa mereka tidak akan mempersekutukan sesuatu pun dengan Allah, tidak akan mencuri tidak akan berzina, tidak akan membunuh anak-anaknya) sebagaimana yang biasa mereka lakukan di zaman jahiliah, yaitu mengubur hidup-hidup bayi perempuan mereka, karena takut tercela dan takut jatuh miskin (dan tidak akan berbuat dusta yang mereka ada-adakan antara tangan dan kaki mereka) seumpamanya mereka memungut seorang anak, kemudian mereka mengaitkan anak itu sebagai hasil hubungannya dengan suami, lalu anak itu dipredikatkan sebagai anak kandungnya sendiri. Karena sesungguhnya seorang ibu itu apabila melahirkan anaknya, berarti anak itu adalah anak kandungnya sendiri yang keluar dari antara tangan dan kakinya, yakni dari perutnya (dan tidak akan mendurhakaimu dalam) pekerjaan (yang makruf) pekerjaan yang makruf artinya perbuatan yang sesuai dengan ketaatan kepada Allah, seperti meninggalkan niahah atau menjerit-jerit seraya menangis, menyobek-nyobek kerah baju, mengawut-awutkan rambut, dan mencakar-cakar muka, yang semuanya itu dilakukan di kala mereka ditinggal mati oleh suami atau keluarga mereka (maka terimalah janji setia mereka) Nabi saw. melantik janji setia mereka hanya melalui ucapan saja tanpa bersalaman atau berjabatan tangan dengan seseorang pun di antara mereka (dan mohonkanlah ampunan kepada Allah untuk mereka. Sesungguhnya Allah Maha Pengampun lagi Maha Penyayang).\qt@no{12}}%
\qt@newcmd\qurantrans@id@mmmmmclxiii{%
(Hai orang-orang yang beriman! Janganlah kalian jadikan penolong kalian kaum yang Allah murka terhadap mereka) yaitu orang-orang Yahudi (sesungguhnya mereka telah putus asa terhadap negeri akhirat) yakni dari pahala akhirat, padahal mereka meyakini adanya hari akhirat; demikian itu karena mereka ingkar kepada Nabi saw. padahal mereka mengetahui, bahwa Nabi saw. itu adalah benar (sebagaimana telah berputus asa orang-orang kafir) yang kini berada (dalam kubur) yaitu orang-orang kafir yang telah mati terkubur, telah putus asa dari kebaikan akhirat. Demikian itu karena di dalam kubur diperlihatkan kepada mereka tempat kedudukan mereka di surga seandainya mereka beriman, sebagaimana diperlihatkan pula kepada mereka tempat kembali yang akan mereka tempati, yaitu neraka.\qt@no{13}}%
\qt@newcmd\qurantrans@id@mmmmmclxiv{%
\basmalahid (Telah bertasbih kepada Allah apa saja yang ada di langit dan apa saja yang ada di bumi) yakni semuanya memahasucikan-Nya. Huruf lam yang terdapat pada lafal lillaah adalah huruf zaidah; dan di sini dipakai lafal maa, karena lebih memprioritaskan yang mayoritas (dan Dialah Yang Maha Perkasa) di dalam kerajaan-Nya (lagi Maha Bijaksana) di dalam perbuatan-Nya.\qt@no{1}}%
\qt@newcmd\qurantrans@id@mmmmmclxv{%
(Hai orang-orang yang beriman mengapa kalian mengatakan) sewaktu kalian meminta berjihad (apa yang tidak kalian perbuat) karena ternyata kalian mengalami kekalahan atau mundur dalam perang Uhud.\qt@no{2}}%
\qt@newcmd\qurantrans@id@mmmmmclxvi{%
(Amat besar) yakni besar sekali (kebencian) lafal maqtan berfungsi menjadi tamyiz (di sisi Allah bahwa kalian mengatakan) lafal an taquuluu menjadi fa'il dari lafal kabura (apa-apa yang tiada kalian kerjakan).\qt@no{3}}%
\qt@newcmd\qurantrans@id@mmmmmclxvii{%
(Sesungguhnya Allah menyukai) artinya selalu menolong dan memuliakan (orang-orang yang berperang di jalannya dalam barisan yang teratur) lafal shaffan merupakan hal atau kata keterangan keadaan, yakni dalam keadaan berbaris rapi (seakan-akan mereka seperti bangunan yang tersusun kokoh) yakni sebagian di antara mereka menempel rapat dengan sebagian yang lain lagi kokoh.\qt@no{4}}%
\qt@newcmd\qurantrans@id@mmmmmclxviii{%
(Dan) ingatlah (ketika Musa berkata kepada kaumnya, ``Hai kaumku! Mengapa kalian menyakitiku?) mereka mengatakan bahwa Nabi Musa itu orang yang besar buah pelirnya atau berpenyakit burut, padahal kenyataannya tidaklah demikian, dan mereka pun mendustakannya (padahal sesungguhnya) lafal qad di sini menunjukkan makna tahqiq (kalian mengetahui, bahwa aku adalah utusan Allah kepada kalian.") Kalimat wa qad ta`lamuuna dan seterusnya berkedudukan menjadi hal atau kata keterangan keadaan. Dan seorang yang menjadi rasul itu seharusnya kalian hormati. (Maka tatkala mereka berpaling) maksudnya menyimpang dari kebenaran, karena mereka telah menyakitinya (Allah memalingkan hati mereka) dari jalan petunjuk, sesuai dengan apa yang telah ditetapkan-Nya di zaman azali (dan Allah tiada memberi petunjuk kepada kaum yang fasik) yakni orang-orang yang kafir, menurut ilmu dan pengetahuan-Nya.\qt@no{5}}%
\qt@newcmd\qurantrans@id@mmmmmclxix{%
(Dan) ingatlah (ketika Isa putra Maryam berkata, ``Hai Bani Israel!) di sini Nabi Isa tidak mengatakan hai kaumku, karena sesungguhnya dia tidak mempunyai kerabat di kalangan mereka (Sesungguhnya aku adalah utusan Allah kepada kalian, membenarkan kitab sebelumku) kitab yang diturunkan sebelumku (yaitu Taurat dan memberi kabar gembira dengan datangnya seorang rasul yang akan datang sesudahku, namanya Ahmad.") Allah berfirman: (Maka tatkala rasul itu datang kepada mereka) yakni Ahmad alias Muhammad kepada orang-orang kafir (dengan membawa bukti-bukti yang nyata) yakni ayat-ayat dan tanda-tanda (mereka berkata, ``Ini) maksudnya, apa yang didatangkannya itu (adalah sihir) menurut suatu qiraat lafal sihrun dibaca saahirun artinya orang yang datang ini adalah penyihir (yang nyata") yang jelas.\qt@no{6}}%
\qt@newcmd\qurantrans@id@mmmmmclxx{%
(Dan siapakah) artinya tiada seseorang pun (yang lebih zalim) maksudnya lebih besar kezalimannya (daripada orang yang mengada-adakan dusta terhadap Allah) yakni dengan cara menisbatkan adanya sekutu bagi-Nya, menyebutkan-Nya bahwa Dia mempunyai anak dan mengatakan ayat-ayat-Nya sebagai sihir (sedangkan dia diajak kepada agama Islam? Dan Allah tiada memberi petunjuk kepada orang-orang yang zalim) kepada orang-orang yang kafir.\qt@no{7}}%
\qt@newcmd\qurantrans@id@mmmmmclxxi{%
(Mereka hendak memadamkan) lafal liyuthfi'uu dinashabkan oleh an yang keberadaannya diperkirakan, sedangkan huruf lam-nya adalah zaidah (cahaya Allah) yakni syariat dan bukti-bukti-Nya (dengan mulut mereka) melalui ucapan-ucapan mereka bahwa Alquran itu adalah sihir, syair dan ramalan atau tenungan (dan Allah tetap menyempurnakan) artinya memenangkan atau menampakkan (cahaya-Nya) menurut suatu qiraat dibaca mutimmu nuurihi dengan dimudhafkan (meskipun orang-orang kafir benci) akan hal tersebut.\qt@no{8}}%
\qt@newcmd\qurantrans@id@mmmmmclxxii{%
(Dialah Yang mengutus Rasul-Nya dengan membawa petunjuk dan agama yang benar agar Dia memenangkannya) maksudnya menjadikannya berada di (atas segala agama-agama) yakni di atas semua agama yang bertentangan dengannya (meskipun orang-orang musyrik benci) akan hal tersebut.\qt@no{9}}%
\qt@newcmd\qurantrans@id@mmmmmclxxiii{%
(Hai orang-orang yang beriman, sukakah kalian Aku tunjukkan suatu perniagaan yang dapat menyelamatkan kalian) dapat dibaca tunjiikum dan tunajjiikum, yakni tanpa memakai tasydid dan dengan memakainya (dari azab yang pedih) yang menyakitkan; mereka seolah-olah menjawab, mengiyakan. Lalu Allah melanjutkan firman-Nya:\qt@no{10}}%
\qt@newcmd\qurantrans@id@mmmmmclxxiv{%
(Yaitu kalian beriman) artinya kalian tetap beriman (kepada Allah dan Rasul-Nya dan berjihad di jalan Allah dengan harta dan jiwa kalian. Itulah yang lebih baik bagi kalian jika kalian mengetahui) bahwasanya hal ini lebih baik bagi kalian, maka kerjakanlah.\qt@no{11}}%
\qt@newcmd\qurantrans@id@mmmmmclxxv{%
(Niscaya Allah akan mengampuni) menjadi jawab dari syarat yang diperkirakan keberadaannya; lengkapnya, jika kalian mengerjakannya, niscaya Dia akan mengampuni (dosa-dosa kalian dan memasukkan kalian ke dalam surga yang mengalir di bawahnya sungai-sungai dan memasukkan kalian ke tempat-tempat tinggal yang baik di dalam surga Adn) sebagai tempat menetap. (Itulah keberuntungan yang besar).\qt@no{12}}%
\qt@newcmd\qurantrans@id@mmmmmclxxvi{%
(Dan) Dia memberikan kepada kalian nikmat (yang lain yang kalian sukai, yaitu pertolongan dari Allah dan kemenangan yang dekat waktunya. Dan sampaikanlah berita gembira kepada orang-orang yang beriman) yaitu berita tentang mendapat pertolongan dan kemenangan.\qt@no{13}}%
\qt@newcmd\qurantrans@id@mmmmmclxxvii{%
(Hai orang-orang yang beriman jadilah kalian penolong-penolong Allah) yakni agama-Nya; menurut suatu qiraat dibaca anshaarallah, artinya dengan dimudhafkan (sebagaimana telah dikatakan) dan seterusnya; makna yang dimaksud ialah sebagaimana yang telah dikatakan oleh kaum Hawariyyun. Pengertian ini disimpulkan dari ayat selanjutnya, yaitu (oleh Isa putra Maryam kepada pengikut-pengikutnya yang setia, ``Siapakah yang akan menjadi penolong-penolongku untuk menegakkan agama Allah?") di antara orang-orang yang bersamaku. (Pengikut-pengikut yang setia itu berkata, ``Kami-lah penolong-penolong agama Allah") penolong-penolong atau Hawariyyun adalah teman-teman pilihan Nabi Isa, mereka adalah orang-orang yang paling pertama dan paling dahulu beriman kepada Nabi Isa, dan jumlah mereka ada dua belas orang laki-laki. Lafal Hawariyyun ini diambil dari asal kata al-hur yang artinya putih cemerlang. Akan tetapi menurut suatu pendapat yang lain dikatakan, adalah terdiri dari orang-orang yang pendek dan pakaian mereka dicelup dengan warna putih (lalu segolongan dari Bani Israel beriman) kepada Nabi Isa, dan mereka mengatakan, bahwa Nabi Isa itu adalah hamba Allah yang kemudian diangkat naik ke langit (dan segolongan yang lain kafir) karena mereka telah mengatakan, bahwasanya Nabi Isa itu adalah anak Allah, yang kemudian diangkat ke langit ke sisi-Nya. Akhirnya kedua golongan tersebut berperang (maka Kami berikan kekuatan) Kami jadikan kuat (orang-orang yang beriman) di antara dua golongan tersebut (terhadap musuh-musuh mereka) yakni golongan yang kafir (lalu mereka menjadi orang-orang yang menang) memperoleh kemenangan atas golongan yang kafir\qt@no{14}}%
\qt@newcmd\qurantrans@id@mmmmmclxxviii{%
\basmalahid (Telah bertasbih kepada Allah) telah memahasucikan-Nya; huruf lam yang terdapat pada lafal lillaahi adalah huruf zaidah (apa yang ada di langit dan apa yang ada di bumi) pemakaian lafal maa di sini karena memprioritaskan yang mayoritas (Raja, Yang Maha Suci) yakni Maha Suci dari sifat-sifat yang tidak layak bagi-Nya (Yang Maha Perkasa lagi Maha Bijaksana) di dalam kerajaan dan dalam perbuatan-Nya.\qt@no{1}}%
\qt@newcmd\qurantrans@id@mmmmmclxxix{%
(Dialah yang mengutus kepada kaum yang buta huruf) yaitu bangsa Arab; lafal ummiy artinya orang yang tidak dapat menulis dan membaca kitab (seorang rasul di antara mereka) yaitu Nabi Muhammad saw. (yang membacakan kepada mereka ayat-ayat-Nya) yakni Alquran (menyucikan mereka) membersihkan mereka dari kemusyrikan (dan mengajarkan kepada mereka Kitab) Alquran (dan hikmah) yaitu hukum-hukum yang terkandung di dalamnya, atau hadis. (Dan sesungguhnya) lafal in di sini adalah bentuk takhfif dari inna, sedangkan isimnya tidak disebutkan selengkapnya; dan sesungguhnya (mereka adalah sebelumnya) sebelum kedatangan Nabi Muhammad saw. (benar-benar dalam kesesatan yang nyata) artinya jelas sesatnya.\qt@no{2}}%
\qt@newcmd\qurantrans@id@mmmmmclxxx{%
(Dan juga kepada kaum yang lain) lafal ini diathafkan kepada lafal al-ummiyyiina, yakni orang-orang yang ada (dari mereka) yaitu orang-orang yang datang kemudian dari mereka, artinya sesudah mereka (tiadalah) (dapat menyusul para pendahulunya) yakni dalam hal kepeloporan dan keutamaannya. (Dan Dialah Yang Maha Perkasa lagi Maha Bijaksana) di dalam kerajaan-Nya dan dalam perbuatan-Nya. Yang dimaksud dengan kaum yang lain ini adalah para tabiin; disebutkannya para sahabat secara khusus pada ayat sebelumnya merupakan dalil yang cukup untuk membuktikan keutamaan para sahabat karena mereka dapat bertemu langsung dengan Nabi saw. yang diutus kepada mereka. Keutamaan mereka jauh lebih besar daripada orang-orang yang datang kemudian sesudah mereka di antara orang-orang yang Nabi pun diutus kepada mereka, dan mereka beriman kepadanya baik dari jenis manusia maupun dari jenis jin hingga hari kiamat. Karena sesungguhnya setiap generasi itu jauh lebih baik daripada generasi penerusnya.\qt@no{3}}%
\qt@newcmd\qurantrans@id@mmmmmclxxxi{%
(Demikianlah karunia Allah, diberikan-Nya kepada siapa yang dikehendaki-Nya) yaitu kepada Nabi dan orang-orang yang disebutkan bersamanya (dan Allah mempunyai karunia yang besar).\qt@no{4}}%
\qt@newcmd\qurantrans@id@mmmmmclxxxii{%
(Perumpamaan orang-orang yang dipikulkan kepadanya kitab Taurat) mereka yang dibebani untuk mengamalkannya (kemudian mereka tidak memikulnya) tidak mengamalkannya, antara lain, mereka tidak beriman kepada perkara yang menyangkut sifat-sifat Nabi saw. sebagai nabi yang akan datang padahal telah terkandung di dalamnya. Mereka itu (adalah seperti keledai yang membawa kitab-kitab) yang dimaksud dengan sifir-sifir adalah kitab-kitab, dalam arti kata keledai itu tidak dapat memanfaatkannya. (Amatlah buruknya perumpamaan kaum yang mendustakan ayat-ayat Allah) yang membenarkan Nabi saw. Sedangkan subjek yang dicelanya tidak disebutkan, lengkapnya, seburuk-buruk perumpamaan kaum yang mendustakan ayat-ayat Allah adalah perumpamaan ini. (Dan Allah tiada memberi petunjuk kepada kaum yang lalim) yaitu kaum yang kafir.\qt@no{5}}%
\qt@newcmd\qurantrans@id@mmmmmclxxxiii{%
(Katakanlah, ``Hai orang-orang yang menganut agama Yahudi! Jika kalian mendakwakan bahwa sesungguhnya kalian sajalah kekasih-kekasih Allah bukan manusia-manusia yang lain, maka harapkanlah kematian kalian, jika kalian adalah orang-orang yang benar") kedua Syarat yang ada pada ayat ini, yakni lafal in za'amtum dan lafal in kuntum bertaalluq atau bergantung kepada lafal tamannau dalam arti kata bahwa syarat yang pertama menjadi qaid atau pengertian yang mengikat bagi syarat yang kedua. Artinya, jika kalian benar-benar di dalam dugaan kalian yang menganggap bahwa kalian adalah kekasih-kekasih Allah. Dan merupakan suatu kelaziman bagi kekasih Allah itu selalu mementingkan kehidupan di akhirat, dan permulaan jalan untuk menuju ke akhirat itu adalah mati; karena itu harapkanlah kematian itu.\qt@no{6}}%
\qt@newcmd\qurantrans@id@mmmmmclxxxiv{%
(Mereka tiada akan mengharapkan kematian itu selama-lamanya disebabkan kejahatan yang telah mereka perbuat dengan tangan-tangan mereka sendiri) yaitu berupa kekafiran mereka kepada Nabi saw. yang hal ini menunjukkan kepada kedustaan mereka terhadap ayat-ayat Allah. (Dan Allah Mengetahui orang-orang yang lalim) yakni orang-orang yang kafir.\qt@no{7}}%
\qt@newcmd\qurantrans@id@mmmmmclxxxv{%
(Katakanlah!, ``Sesungguhnya kematian yang kalian lari daripadanya, sesungguhnya kematian itu) huruf fa pada lafal fa-innahu adalah huruf zaidah (akan menemui kalian, kemudian kalian akan dikembalikan kepada Allah Yang Maha Mengetahui yang gaib dan yang nyata) artinya mengetahui pada yang rahasia dan terang-terangan (lalu Dia beritakan kepada kalian apa yang telah kalian kerjakan.") maka Dia akan membalasnya kepada kalian.\qt@no{8}}%
\qt@newcmd\qurantrans@id@mmmmmclxxxvi{%
(Hai orang-orang yang beriman, apabila diseru untuk menunaikan salat pada) huruf min di sini bermakna fi, yakni pada (hari Jumat maka bersegeralah kalian) yakni cepat-cepatlah kalian berangkat (untuk mengingat Allah) yakni salat (dan tinggalkanlah jual beli) tinggalkanlah transaksi jual beli itu. (Yang demikian itu lebih baik bagi kalian jika kalian mengetahui) bahwasanya hal ini lebih baik, maka kerjakanlah ia.\qt@no{9}}%
\qt@newcmd\qurantrans@id@mmmmmclxxxvii{%
(Apabila telah ditunaikan salat, maka bertebaranlah kalian di muka bumi) perintah ini menunjukkan pengertian ibahah atau boleh (dan carilah) carilah rezeki (karunia Allah, dan ingatlah Allah) dengan ingatan (sebanyak-banyaknya supaya kalian beruntung) yakni memperoleh keberuntungan. Pada hari Jumat, Nabi saw. berkhutbah akan tetapi tiba-tiba datanglah rombongan kafilah membawa barang-barang dagangan, lalu dipukullah genderang menyambut kedatangannya sebagaimana biasanya. Maka orang-orang pun berhamburan keluar dari mesjid untuk menemui rombongan itu, kecuali hanya dua belas orang saja yang masih tetap bersama Nabi saw. lalu turunlah ayat ini.\qt@no{10}}%
\qt@newcmd\qurantrans@id@mmmmmclxxxviii{%
(Dan apabila mereka melihat perniagaan atau permainan, mereka bubar untuk menuju kepadanya) yakni kepada barang dagangan, karena barang dagangan itu merupakan kebutuhan yang mereka perlukan, berbeda dengan permainan (dan mereka tinggalkan kamu) dalam khotbahmu (dalam keadaan berdiri. Katakanlah, ``Apa yang di sisi Allah) berupa pahala (lebih baik) bagi orang-orang yang beriman (dari permainan dan perniagaan," dan Allah sebaik-baik pemberi rezeki) bila dikatakan, setiap orang itu memberi rezeki kepada keluarganya, maka pengertian yang dimaksud ialah dari rezeki Allah swt.\qt@no{11}}%
\qt@newcmd\qurantrans@id@mmmmmclxxxix{%
\basmalahid (Apabila orang-orang munafik datang kepadamu, mereka berkata) dengan mulut mereka mengenai hal-hal yang bertentangan dengan apa yang ada dalam hati mereka ("Kami mengakui, bahwa sesungguhnya kamu benar-benar Rasul Allah." Dan Allah mengetahui bahwa sesungguhnya kamu benar-benar Rasul-Nya; dan Allah menyaksikan) yakni mengetahui (bahwa sesungguhnya orang-orang munafik itu benar-benar pendusta) yakni isi hati mereka berbeda dengan apa yang mereka katakan.\qt@no{1}}%
\qt@newcmd\qurantrans@id@mmmmmcxc{%
(Mereka itu menjadikan sumpah mereka sebagai perisai) maksudnya untuk melindungi harta benda mereka dan jiwa mereka (lalu mereka menghalangi) melalui sumpah itu (jalan Allah) artinya mereka menghalangi manusia untuk berjihad melawan mereka. (Sesungguhnya amat buruklah apa yang telah mereka kerjakan).\qt@no{2}}%
\qt@newcmd\qurantrans@id@mmmmmcxci{%
(Yang demikian itu) yakni pekerjaan mereka yang buruk itu (adalah karena sesungguhnya mereka telah beriman) mulutnya (kemudian menjadi kafir) hatinya. Artinya, mereka masih tetap dalam kekafirannya, (lalu dikunci matilah) dikuncilah (hati mereka) dengan kekafiran (karena itu mereka tidak dapat mengerti) tentang iman yang sesungguhnya.\qt@no{3}}%
\qt@newcmd\qurantrans@id@mmmmmcxcii{%
(Dan apabila kamu melihat mereka, tubuh-tubuh mereka menjadikan kamu kagum) karena keindahan dan kebagusannya. (Dan jika mereka berkata kamu mendengarkan perkataan mereka) karena kefasihan tutur katanya. (Mereka adalah seakan-akan) karena tubuhnya yang besar akan tetapi pikirannya kosong tidak dapat memahami (kayu) dapat dibaca khusyubun dan khusybun (yang tersandar) artinya bagaikan kayu yang tersandar ke tembok. (Mereka mengira bahwa tiap-tiap teriakan keras) teriakan sebagaimana seruan di dalam kemiliteran, atau bagaikan seruan orang yang mencari barang yang hilang (ditujukan kepada mereka) demikian itu karena hati mereka sudah memendam rasa kecut dan takut terhadap hal-hal yang akan menimpa mereka yang memperbolehkan darah mereka dialirkan. (Mereka itulah musuh yang sebenarnya, maka waspadalah terhadap mereka) karena sesungguhnya mereka pasti membeberkan rahasia kamu kepada orang-orang kafir (semoga Allah membinasakan mereka) menghancurkan mereka. (Bagaimanakah mereka sampai dipalingkan?) dari iman, padahal bukti-buktinya sudah cukup jelas.\qt@no{4}}%
\qt@newcmd\qurantrans@id@mmmmmcxciii{%
(Dan apabila dikatakan kepada mereka, ``Marilah) seraya memberi maaf (supaya Rasulullah memberikan ampunan bagi kalian," mereka membuang) lafal lawwau dapat dibaca dengan memakai tasydid, dapat pula dibaca tanpa memakainya sehingga menjadi lawau, artinya memalingkan (muka mereka dan kamu lihat mereka berpaling) dari hal tersebut (sedangkan mereka menyombongkan diri).\qt@no{5}}%
\qt@newcmd\qurantrans@id@mmmmmcxciv{%
(Sama saja bagi mereka, kamu mintakan ampunan bagi mereka) dalam ungkapan kalimat astaghfarta, keberadaan hamzah istifham cukup diwakili oleh hamzah washal (atau kamu tidak memintakan ampunan bagi mereka, Allah tidak akan memberikan ampunan kepada mereka. Sesungguhnya Allah tidak memberi petunjuk kepada orang-orang yang fasik).\qt@no{6}}%
\qt@newcmd\qurantrans@id@mmmmmcxcv{%
(Mereka orang-orang yang mengatakan) kepada teman-teman mereka dari kalangan kaum Ansar: ("Janganlah kalian memberikan perbelanjaan kepada orang-orang yang ada di sisi Rasulullah) yakni orang-orang Muhajirin (supaya mereka bubar") bercerai-berai dari sisinya. (Padahal kepunyaan Allahlah perbendaharaan langit dan bumi) yakni pemberian rezeki-Nya, Dia Maha Pemberi rezeki kepada orang-orang Muhajirin dan lain-lainnya (tetapi orang-orang munafik itu tidak memahami).\qt@no{7}}%
\qt@newcmd\qurantrans@id@mmmmmcxcvi{%
(Mereka berkata, ``Sesungguhnya jika kita telah kembali) yakni kembali dari peperangan Bani Mushthaliq (ke Madinah, benar-benar orang yang kuat akan mengusir) yang dimaksud orang-orang kuat adalah diri mereka sendiri (orang-orang yang lemah daripadanya") yang dimaksud oleh mereka adalah orang-orang mukmin. (Padahal kekuatan itu hanyalah bagi Allah) yakni kemenangan itu milik Allah (bagi Rasul-Nya dan bagi orang-orang mukmin, tetapi orang-orang munafik itu tidak mengetahui) hal tersebut.\qt@no{8}}%
\qt@newcmd\qurantrans@id@mmmmmcxcvii{%
(Hai orang-orang yang beriman, janganlah melalaikan kalian) yakni melupakan kalian (harta-harta kalian dan anak-anak kalian dari mengingat Allah) dari melakukan salat lima waktu. (Barang siapa yang berbuat demikian maka mereka itulah orang-orang yang rugi).\qt@no{9}}%
\qt@newcmd\qurantrans@id@mmmmmcxcviii{%
(Dan belanjakanlah) dalam berzakat (sebagian dari apa yang telah Kami berikan kepada kalian sebelum datang kematian kepada salah seorang di antara kalian; lalu ia berkata, ``Ya Rabbku! Mengapa tidak) lafal laula di sini bermakna halla, yakni kenapa tidak. Atau huruf la dianggap sebagai huruf zaidah dan huruf lau bermakna tamanni, yakni seandainya (Engkau menangguhkan aku sampai waktu yang dekat, yang menyebabkan aku dapat bersedekah) bentuk asli lafal ashshaddaqa adalah atashaddaqa, kemudian huruf ta diidghamkan ke dalam huruf shad sehingga jadilah ashshaddaqa, yakni supaya aku dapat membayar zakatku (dan aku termasuk orang-orang yang saleh?") seumpamanya aku akan menunaikan ibadah haji. Ibnu Abbas r.a. telah memberikan penafsirannya, bahwa tiada seseorang pun yang melalaikan untuk membayar zakat dan melakukan ibadah haji, melainkan ia meminta supaya kematiannya ditangguhkan di saat ia menjelang ajalnya.\qt@no{10}}%
\qt@newcmd\qurantrans@id@mmmmmcxcix{%
(Dan Allah sekali-kali tidak akan menangguhkan, kematian, seseorang apabila datang waktu kematiannya. Dan Allah Maha Mengenal apa yang kalian kerjakan) lafal ta'maluuna dapat pula dibaca ya'maluuna, sehingga artinya menjadi, yang mereka kerjakan.\qt@no{11}}%
\qt@newcmd\qurantrans@id@mmmmmcc{%
\basmalahid (Bertasbih kepada Allah apa yang ada di langit dan apa yang ada di bumi) artinya, semuanya memahasucikan Dia. Huruf lam pada lafal lillaahi adalah zaidah. Dan dalam ungkapan ayat ini dipakai huruf maa, hal ini tiada lain karena memprioritaskan yang mayoritas (hanya Allah lah yang mempunyai semua kerajaan dan semua puji-pujian, dan Dia Maha Kuasa atas segala sesuatu).\qt@no{1}}%
\qt@newcmd\qurantrans@id@mmmmmcci{%
(Dialah Yang menciptakan kalian maka di antara kalian ada yang kafir dan di antara kalian ada yang beriman) menurut asal kejadiannya, kemudian Dia mematikan kalian, lalu Dia menghidupkan kalian dalam keadaan seperti itu. (Dan Allah Maha Melihat apa yang kalian kerjakan).\qt@no{2}}%
\qt@newcmd\qurantrans@id@mmmmmccii{%
(Dia menciptakan langit dan bumi dengan, tujuan, yang benar. Dia membentuk rupa kalian dan dibaguskan-Nya rupa kalian itu) karena Dia telah menjadikan bentuk Bani Adam dalam bentuk yang paling baik dan rupa yang paling bagus (dan hanya kepada-Nyalah kembali).\qt@no{3}}%
\qt@newcmd\qurantrans@id@mmmmmcciii{%
(Dia mengetahui apa yang ada di langit dan apa yang ada di bumi, dan mengetahui apa yang kalian rahasiakan dan apa yang kalian nyatakan. Dan Allah Maha Mengetahui segala isi hati) semua rahasia dan keyakinan yang terpendam di dalamnya.\qt@no{4}}%
\qt@newcmd\qurantrans@id@mmmmmcciv{%
(Apakah belum datang kepada kalian) hai orang-orang kafir Mekah (berita) atau cerita (tentang orang-orang kafir dahulu? Maka mereka telah merasakan akibat yang buruk dari perbuatan mereka) yaitu hukuman di dunia sebagai pembalasan dari kekafiran mereka (dan bagi mereka) di akhirat nanti (azab yang pedih) yang menyakitkan.\qt@no{5}}%
\qt@newcmd\qurantrans@id@mmmmmccv{%
(Yang demikian itu) atau azab di dunia itu (adalah karena sesungguhnya) dhamir yang terdapat dalam lafal annahu adalah dhamir sya'n (telah datang kepada mereka rasul-rasul mereka dengan membawa keterangan-keterangan yang nyata) hujah-hujah yang jelas yang menunjukkan kepada keimanan (lalu mereka berkata, ``Apakah manusia) yang dimaksud adalah jenisnya (yang akan memberi petunjuk kepada kami?" Lalu mereka ingkar dan berpaling) dari keimanan (dan Allah tidak memerlukan) keimanan mereka. (Dan Allah Maha Kaya) dari makhluk-Nya (lagi Maha Terpuji) dalam perbuatan-perbuatan-Nya.\qt@no{6}}%
\qt@newcmd\qurantrans@id@mmmmmccvi{%
(Orang-orang yang kafir menduga, bahwa sesungguhnya) mereka. Lafal An di sini adalah bentuk Takhfif dari Anna sedangkan yang menjadi Isimnya tidak disebutkan, yakni sesungguhnya mereka (sekali-kali tidak akan dibangkitkan. Katakanlah, ``Memang demi Rabbku, benar-benar kalian akan dibangkitkan, kemudian akan diberitakan kepada kalian apa yang telah kalian kerjakan." Yang demikian itu adalah mudah bagi Allah).\qt@no{7}}%
\qt@newcmd\qurantrans@id@mmmmmccvii{%
(Maka berimanlah kalian kepada Allah dan Rasul-Nya dan cahaya) yakni Alquran (yang telah Kami turunkan. Dan Allah Maha Mengetahui apa yang kalian kerjakan).\qt@no{8}}%
\qt@newcmd\qurantrans@id@mmmmmccviii{%
Ingatlah (hari yang di waktu itu Allah mengumpulkan kalian pada hari pengumpulan) yakni hari kiamat (itulah hari ditampakkannya kesalahan-kesalahan) maksudnya orang-orang mukmin pada hari itu memperoleh keuntungan yang besar dari orang-orang kafir, karena orang-orang mukmin mengambil tempat-tempat tinggal dan istri-istri mereka di surga, seandainya mereka beriman. (Dan barang siapa yang beriman kepada Allah dan mengerjakan amal saleh niscaya Allah akan menutupi kesalahan-kesalahannya dan memasukkannya) menurut suatu qiraat lafal yukaffir dan yudkhilhu dibaca nukaffir dan nudkhilhu (ke dalam surga yang mengalir di bawahnya sungai-sungai, mereka kekal di dalamnya selama-lamanya. Itulah keberuntungan yang besar).\qt@no{9}}%
\qt@newcmd\qurantrans@id@mmmmmccix{%
(Dan orang-orang yang kafir mendustakan ayat-ayat Kami) yakni Alquran (mereka itulah penghuni-penghuni neraka. Dan itulah seburuk-buruk tempat kembali) yakni neraka itu.\qt@no{10}}%
\qt@newcmd\qurantrans@id@mmmmmccx{%
(Tidak ada sesuatu musibah pun yang menimpa seseorang kecuali dengan izin Allah) atau dengan kepastian-Nya. (Dan barang siapa yang beriman kepada Allah) melalui ucapannya, bahwa musibah itu datang atas kepastian dari-Nya (niscaya Dia akan memberi petunjuk kepada kalbunya) untuk bersabar di dalam menghadapinya. (Dan Allah Maha Mengetahui segala sesuatu).\qt@no{11}}%
\qt@newcmd\qurantrans@id@mmmmmccxi{%
(Dan taatlah kepada Allah dan taatlah kepada Rasul, jika kalian berpaling maka sesungguhnya kewajiban rasul Kami hanyalah menyampaikan, amanat Allah, dengan terang) yakni secara jelas.\qt@no{12}}%
\qt@newcmd\qurantrans@id@mmmmmccxii{%
(Dialah Allah, tidak ada Tuhan selain Dia. Dan hendaklah orang-orang mukmin bertawakal kepada Allah saja).\qt@no{13}}%
\qt@newcmd\qurantrans@id@mmmmmccxiii{%
(Hai orang-orang yang beriman! Sesungguhnya di antara istri-istri kalian dan anak-anak kalian ada yang menjadi musuh bagi kalian, maka berhati-hatilah kalian) janganlah kalian menaati mereka sehingga menyebabkan kalian ketinggalan tidak mau melakukan perbuatan yang baik, seperti berjihad dan berhijrah. Karena sesungguhnya latar belakang turunnya ayat ini adalah karena menaatinya (dan jika kalian meaafkan) mereka yang telah memperlambat kalian untuk melakukan perbuatan-perbuatan yang baik, karena alasan bahwa mereka merasa berat berpisah dengan kalian (dan tidak memarahi serta mengampuni, mereka, maka sesungguhnya Allah Maha Pengampun lagi Maha Penyayang).\qt@no{14}}%
\qt@newcmd\qurantrans@id@mmmmmccxiv{%
(Sesungguhnya harta kalian dan anak-anak kalian hanyalah cobaan) bagi kalian yang melupakan kalian dari perkara-perkara akhirat (dan di sisi Allah lah pahala yang besar) maka janganlah kalian lewatkan hal ini, karena kalian sibuk dengan harta benda dan anak-anak kalian.\qt@no{15}}%
\qt@newcmd\qurantrans@id@mmmmmccxv{%
(Maka bertakwalah kalian kepada Allah menurut kesanggupan kalian) ayat ini memansukh firman-Nya, ``Bertakwalah kepada Allah sebenar-benar takwa kepada-Nya." (Q.S. Ali Imran 102) (dan dengarlah) apa yang telah diperintahkan kepada kalian, dengan pendengaran yang dibarengi dengan rasa menerima apa yang kalian dengar (serta taatlah) kepada Allah (dan nafkahkanlah) di jalan ketaatan (nafkah yang baik untuk diri kalian) lafal khairan berkedudukan menjadi khabar dari lafal yakun yang keberadaannya diperkirakan, dan sekaligus menjadi jawab dari amar, yakni niscaya pahalanya buat diri kalian sendiri. (Dan barang siapa yang dipelihara dari kekikiran dirinya, maka mereka itulah orang-orang yang beruntung) orang-orang yang memperoleh keberuntungan.\qt@no{16}}%
\qt@newcmd\qurantrans@id@mmmmmccxvi{%
(Jika kalian meminjamkan kepada Allah pinjaman yang baik) seumpamanya kalian mengeluarkan sedekah dengan hati yang tulus ikhlas (niscaya Allah melipatgandakannya kepada kalian) menurut suatu qiraat dibaca yudha``afhu lakum. Dilipatgandakan pembalasannya mulai dari sepuluh kali lipat hingga sampai tujuh ratus kali lipat, dan bahkan lebih dari itu (dan mengampuni kalian) apa yang dikehendaki-Nya. (Dan Allah Maha Pembalas jasa) artinya selalu memberikan balasan amal ketaatan (lagi Maha Penyantun) dalam siksaan-Nya terhadap perbuatan maksiat.\qt@no{17}}%
\qt@newcmd\qurantrans@id@mmmmmccxvii{%
(Yang Mengetahui yang gaib) yang tersembunyi (dan yang nyata) yang terang-terangan (Yang Maha Perkasa) di dalam kerajaan-Nya (lagi Maha Bijaksana) dalam perbuatan dan tindakan-Nya.\qt@no{18}}%
\qt@newcmd\qurantrans@id@mmmmmccxviii{%
\basmalahid (Hai Nabi!) makna yang dimaksud ialah umatnya, pengertian ini disimpulkan dari ayat selanjutnya. Atau makna yang dimaksud ialah, katakanlah kepada mereka (apabila kalian menceraikan istri-istri kalian) apabila kalian hendak menjatuhkan talak kepada mereka (maka hendaklah kalian ceraikan mereka pada waktu mereka menghadapi idahnya) yaitu pada permulaan idah, seumpamanya kamu menjatuhkan talak kepadanya sewaktu ia dalam keadaan suci dan kamu belum menggaulinya. Pengertian ini berdasarkan penafsiran dari Rasulullah saw. sendiri menyangkut masalah ini; demikianlah menurut hadis yang telah diriwayatkan oleh Bukhari dan Muslim (dan hitunglah waktu idahnya) artinya jagalah waktu idahnya supaya kalian dapat merujukinya sebelum waktu idah itu habis (serta bertakwalah kepada Allah Rabb kalian) taatlah kalian kepada perintah-Nya dan larangan-Nya. (Janganlah kalian keluarkan mereka dari rumah mereka dan janganlah mereka diizinkan keluar) dari rumahnya sebelum idahnya habis (kecuali kalau mereka mengerjakan perbuatan keji) yakni zina (yang terang) dapat dibaca mubayyinah, artinya terang, juga dapat dibaca mubayyanah, artinya dapat dibuktikan. Maka bila ia melakukan hal tersebut dengan dapat dibuktikan atau ia melakukannya secara jelas, maka ia harus dikeluarkan untuk menjalani hukuman hudud. (Itulah) yakni hal-hal yang telah disebutkan itu (hukum-hukum Allah dan barang siapa yang melanggar hukum-hukum Allah, maka sesungguhnya dia telah berbuat aniaya terhadap dirinya sendiri. Kamu tidak mengetahui barangkali Allah mengadakan sesudah itu) sesudah perceraian itu (sesuatu hal yang baru) yaitu rujuk kembali dengan istri yang telah dicerainya, jika talak yang dijatuhkannya itu baru sekali atau dua kali.\qt@no{1}}%
\qt@newcmd\qurantrans@id@mmmmmccxix{%
(Apabila mereka telah mendekati akhir idahnya) atau masa idah mereka hampir habis (maka tahanlah mereka) seumpamanya kalian rujuk dengan mereka (dengan baik) artinya tidak memudaratkan kepada mereka (atau lepaskanlah mereka dengan baik) biarkanlah mereka menyelesaikan idahnya dan janganlah kamu menjatuhkan kemudaratan terhadap mereka melalui rujuk (dan persaksikanlah dengan dua orang saksi yang adil di antara kalian) dalam masalah rujuk atau talak ini (dan hendaklah kalian tegakkan kesaksian itu karena Allah) bukan karena demi rang yang dipersaksikan atau bukan karena demi rujuk atau talaknya. (Demikianlah diberi pengajaran dengan itu orang yang beriman kepada Allah dan hari akhirat. Barang siapa yang bertakwa kepada Allah niscaya Dia akan mengadakan baginya jalan keluar) dari malapetaka di dunia dan di akhirat.\qt@no{2}}%
\qt@newcmd\qurantrans@id@mmmmmccxx{%
(Dan memberinya rezeki dari arah yang tiada disangka-sangkanya) dari arah yang belum pernah terbisik dalam kalbunya. (Dan barang siapa yang bertawakal kepada Allah) dalam semua perkaranya (niscaya Allah akan memberi kecukupan) akan mencukupinya. (Sesungguhnya Allah melaksanakan urusan-Nya) tentang apa yang dikehendaki-Nya. Menurut suatu qiraat dibaca baalighu amrihi yakni dengan dimudhafkan. (Sesungguhnya Allah telah menjadikan bagi setiap sesuatu) seperti hidup penuh dengan kecukupan, dan hidup sengsara (ketentuan) atau waktu-waktu yang ditentukan.\qt@no{3}}%
\qt@newcmd\qurantrans@id@mmmmmccxxi{%
(Dan perempuan-perempuan) dibaca wallaa'iy dan wallaa'i, dengan memakai hamzah dan ya atau tanpa memakai ya, demikian pula lafal yang sama sesudahnya (yang putus asa dari haid) lafal al-mahidh di sini bermakna haid (di antara perempuan-perempuan kalian jika kalian ragu-ragu) tentang masa idahnya (maka idah mereka adalah tiga bulan; dan begitu pula perempuan-perempuan yang tidak haid) karena mengingat mereka masih di bawah umur, maka idah mereka tiga bulan pula. Kedua kasus ini menyangkut wanita-wanita atau istri-istri yang tidak ditinggal mati oleh suaminya. Adapun istri-istri yang ditinggal mati oleh suaminya, idah mereka sebagaimana yang disebutkan di dalam firman-Nya berikut ini, yaitu, ``Hendaklah para istri itu menangguhkan dirinya (beridah) empat bulan sepuluh hari." (Q.S. Al-Baqarah 234) (Dan perempuan-perempuan yang hamil masa idahnya) baik mereka itu karena ditalak atau karena ditinggal mati oleh suaminya, maka batas masa idah mereka ialah (sampai mereka melahirkan kandungannya. Dan barang siapa yang bertakwa kepada Allah niscaya Allah menjadikan baginya kemudahan dalam urusannya) baik di dunia maupun di akhirat.\qt@no{4}}%
\qt@newcmd\qurantrans@id@mmmmmccxxii{%
(Itulah) yaitu hal-hal yang menyangkut masalah idah adalah (perintah Allah) atau hukum-Nya (yang diturunkan-Nya kepada kalian; dan barang siapa yang bertakwa kepada Allah niscaya Dia akan menutupi kesalahan-kesalahannya dan akan melipatgandakan pahala baginya).\qt@no{5}}%
\qt@newcmd\qurantrans@id@mmmmmccxxiii{%
(Tempatkanlah mereka) yakni istri-istri yang ditalak itu (pada tempat kalian tinggal) pada sebagian tempat-tempat tinggal kalian (menurut kemampuan kalian) sesuai dengan kemampuan kalian, lafal ayat ini menjadi athaf bayan atau badal dari lafal yang sebelumnya dengan mengulangi penyebutan huruf jarr-nya/kata depan dan memperkirakan adanya mudhaf. Yakni pada tempat-tempat tinggal yang kalian mampui, bukannya pada tempat-tempat tinggal yang di bawah itu (dan janganlah kalian menyusahkan mereka untuk menyempitkan hati mereka) dengan memberikan kepada mereka tempat-tempat tinggal yang tidak layak, sehingga mereka terpaksa butuh untuk keluar atau membutuhkan nafkah, lalu karena itu maka mereka mengeluarkan biaya sendiri. (Dan jika mereka itu sedang hamil, maka berikanlah kepada mereka nafkahnya hingga mereka bersalin, kemudian jika mereka menyusukan bayi kalian) maksudnya menyusukan anak-anak kalian hasil hubungan dengan mereka (maka berikanlah kepada mereka upahnya) sebagai upah menyusukan (dan bermusyawarahlah di antara kalian) antara kalian dan mereka (dengan baik) dengan cara yang baik menyangkut hak anak-anak kalian, yaitu melalui permusyawaratan sehingga tercapailah kesepakatan mengenai upah menyusukan (dan jika kalian menemui kesulitan) artinya kalian enggan untuk menyusukannya; yaitu dari pihak ayah menyangkut masalah upah, sedangkan dari pihak ibu, siapakah yang akan menyusukannya (maka boleh menyusukan bayinya) maksudnya menyusukan si anak itu semata-mata demi ayahnya (wanita yang lain) dan ibu si anak itu tidak boleh dipaksa untuk menyusukannya.\qt@no{6}}%
\qt@newcmd\qurantrans@id@mmmmmccxxiv{%
(Hendaklah memberikan nafkah) kepada istri-istri yang telah ditalak, dan kepada istri-istri yang sedang menyusukan (orang yang mampu menurut kemampuannya. Dan orang yang dibatasi) disempitkan (rezekinya hendaklah memberi nafkah dari apa yang didatangkan kepadanya) yaitu dari rezeki yang telah diberikan kepadanya (oleh Allah) sesuai dengan kemampuannya. (Allah tidak memikulkan beban kepada seseorang melainkan sekedar apa yang Allah berikan kepadanya. Allah kelak akan memberikan kelapangan sesudah kesempitan) dan ternyata Allah memberikan kelapangan itu melalui kemenangan-kemenangan yang dialami oleh kaum muslimin.\qt@no{7}}%
\qt@newcmd\qurantrans@id@mmmmmccxxv{%
(Dan berapalah banyaknya) lafal ka'ayyin huruf kafnya adalah huruf jarr, masuk ke dalam huruf ayy yang bermakna kam. Sudah berapa banyak (negeri) yakni banyak negeri-negeri (yang mendurhakai) yang penduduknya telah berbuat durhaka (perintah Rabbnya dan rasul-rasul-Nya, maka Kami hisab penduduk negeri-negeri itu) di akhirat, sekalipun hari akhirat itu belum datang. Diungkapkan dengan memakai fi'il madhi, yaitu haasabnaahaa, karena hal itu pasti terjadi (dengan hisab yang keras, dan Kami azab mereka dengan azab yang mengerikan) dapat dibaca nukra dan nukura, artinya azab yang mengerikan, yaitu azab neraka.\qt@no{8}}%
\qt@newcmd\qurantrans@id@mmmmmccxxvi{%
(Maka mereka merasakan akibat dari perbuatannya) hukuman dari perbuatannya (dan adalah akibat perbuatan mereka kerugian yang besar) kerugian dan kebinasaan.\qt@no{9}}%
\qt@newcmd\qurantrans@id@mmmmmccxxvii{%
(Allah menyediakan bagi mereka azab yang keras) di sini ancaman tersebut diulangi untuk mengukuhkan makna (maka bertakwalah kepada Allah, hai orang-orang yang mempunyai akal) pikiran (yaitu orang-orang yang beriman) lafal alladziina aamanuu merupakan sifat bagi munada atau orang-orang yang diseru tadi atau merupakan bayan atau penjelasan baginya. (Sesungguhnya Allah telah menurunkan peringatan kepada kalian) yakni Alquran.\qt@no{10}}%
\qt@newcmd\qurantrans@id@mmmmmccxxviii{%
(Dan mengutus seorang rasul) yakni Nabi Muhammad saw. Dinashabkan oleh fi'il yang diperkirakan keberadaannya yakni Allah mengutus seorang rasul (yang membacakan kepada kalian ayat-ayat Allah yang menerangkan) dapat dibaca mubayyanatun, artinya yang menerangkan, juga dapat dibaca mubayyinatun, artinya yang terang; penafsirannya sebagaimana yang telah lalu (supaya Dia mengeluarkan orang-orang yang beriman dan mengerjakan amal-amal saleh) sesudah datangnya peringatan atau Alquran dan rasul (dari kegelapan) dari kekafiran yang mereka bergelimang di dalamnya (kepada cahaya) kepada iman yang menegakkan mereka sesudah mereka kafir. (Dan barang siapa beriman kepada Allah dan mengerjakan amal saleh niscaya Dia akan memasukkannya) menurut suatu qiraat lafal yudkhilhu dibaca nudkhilhu, artinya niscaya Kami akan memasukkannya (ke dalam surga-surga yang mengalir di bawahnya sungai-sungai, mereka kekal di dalamnya selama-lamanya. Sesungguhnya Allah memberikan rezeki yang baik kepadanya) yaitu rezeki surga yang kenikmatannya tiada henti-hentinya.\qt@no{11}}%
\qt@newcmd\qurantrans@id@mmmmmccxxix{%
(Allah-lah yang menciptakan tujuh langit dan seperti itu pula bumi) tujuh lapis bumi. (Turunlah perintah) wahyu-Nya (di antaranya) di antara langit dan bumi, malaikat Jibril turun dari langit yang ketujuh hingga ke bumi lapis tujuh (agar kalian mengetahui) lafal lita'lamuu bertaalluq kepada lafal yang tidak disebutkan, yakni Allah memberi tahu kepada kalian akan hal tersebut, yaitu mengenai masalah penciptaan dan penurunan wahyu-Nya (bahwasanya Allah Maha Kuasa atas segala sesuatu, dan sesungguhnya Allah ilmu-Nya benar-benar meliputi segala sesuatu).\qt@no{12}}%
\qt@newcmd\qurantrans@id@mmmmmccxxx{%
\basmalahid (Hai nabi! Mengapa kamu mengharamkan apa yang Allah menghalalkannya bagimu) mengenai istri budak wanitamu, yakni Mariyah Qibtiah; yaitu sewaktu Nabi saw. menggaulinya di rumah Hafshah, sedangkan pada waktu itu Siti Hafshah sedang tidak ada di rumah. Lalu datanglah Siti Hafshah, dan ia merasa keberatan dengan adanya hal tersebut yang dilakukan oleh Nabi saw. di dalam rumahnya dan di tempat tidurnya. Lalu kamu mengatakan, dia (Siti Mariyah) haram atas diriku (kamu mencari) dengan mengharamkannya atas dirimu (keridaan istri-istrimu) kerelaan mereka terhadap dirimu. (Dan Allah Maha Pengampun lagi Maha Penyayang) Dia telah mengampunimu atas tindakan pengharamanmu itu.\qt@no{1}}%
\qt@newcmd\qurantrans@id@mmmmmccxxxi{%
(Sesungguhnya Allah telah mewajibkan) telah mensyariatkan (kepada kamu sekalian membebaskan diri dari sumpah kalian) artinya kalian melepaskan diri dari sumpah yang telah kalian katakan dengan cara membayar kifarat sebagaimana yang telah disebutkan di dalam surat Al-Maidah. Dan termasuk di antara sumpah-sumpah itu ialah mengharamkan budak wanita. Apakah Nabi saw. membayar kifarat? Muqatil mengatakan, bahwa Nabi saw. telah memerdekakan seorang budak sebagai kifaratnya yang telah mengharamkan Siti Mariyah atas dirinya. Akan tetapi Hasan mengatakan, bahwa Nabi saw. tidak membayar kifarat, karena sesungguhnya ia telah mendapat ampunan dari Allah (dan Allah adalah Pelindung kalian) yang menolong kalian (dan Dia Maha Mengetahui lagi Maha Bijaksana).\qt@no{2}}%
\qt@newcmd\qurantrans@id@mmmmmccxxxii{%
(Dan) ingatlah (ketika Nabi membicarakan secara rahasia kepada salah seorang dari istri-istrinya) yakni kepada Siti Hafshah (suatu pembicaraan) tentang mengharamkan Siti Mariyah atas dirinya, kemudian Nabi saw. berkata kepada Siti Hafshah, ``Jangan sekali-kali kamu membuka rahasia ini." (Maka tatkala menceritakan peristiwa itu) kepada Siti Aisyah, ia menduga bahwa hal ini tidak dosa (dan Allah memberitahukan hal itu) Dia membukanya (kepadanya) yakni kepada Nabi Muhammad tentang pembicaraan Siti Hafshah kepada Siti Aisyah itu (lalu dia memberitahukan sebagiannya) kepada Siti Hafshah (dan menyembunyikan sebagian yang lain) sebagai kemurahan dari dirinya terhadap dia. (Maka tatkala dia, Muhammad, memberitahukan pembicaraan itu, lalu Hafshah bertanya, ``Siapakah yang telah memberitahukan hal ini kepadamu?" Nabi menjawab, ``Telah diberitahukan kepadaku oleh Yang Maha Mengetahui lagi Maha Waspada") yakni Allah swt.\qt@no{3}}%
\qt@newcmd\qurantrans@id@mmmmmccxxxiii{%
(Jika kamu berdua bertobat) yakni Siti Hafshah dan Siti Aisyah (kepada Allah, maka sesungguhnya hati kamu berdua telah condong) cenderung untuk diharamkannya Siti Mariyah, artinya, kamu berdua merahasiakan hal tersebut dalam hati kamu, padahal Nabi saw. tidak menyukai hal tersebut, dan hal ini adalah suatu perbuatan yang berdosa. Jawab Syarat dari kalimat ini tidak disebutkan, yakni jika kamu berdua bertobat kepada Allah, maka tobat kamu diterima. Diungkapkan dengan memakai lafal quluubun dalam bentuk jamak sebagai pengganti dari lafal qalbaini, hal ini tiada lain karena dirasakan amat berat mengucapkan dua isim tatsniah yang digabungkan dalam satu lafal (dan jika kamu berdua saling bantu-membantu) lafal tazhaahara artinya bantu-membantu. Menurut qiraat yang lain dibaca tazhzhaharaa bentuk asalnya adalah Tatazhaaharaa, kemudian huruf ta yang kedua diidgamkan ke dalam huruf zha sehingga jadilah tazhzhaaharaa (terhadapnya) terhadap Nabi saw. dalam melakukan hal-hal yang tidak disukainya, yakni membuat susah Nabi saw. (maka sesungguhnya Allah adalah) lafal huwa ini merupakan dhamir fashl (Pelindungnya) maksudnya, yang menolongnya (dan begitu pula Jibril dan orang-orang mukmin yang saleh) seperti Abu Bakar dan Umar r.a. Lafal ini diathafkan secara mahall kepada isimnya inna, yakni begitu pula mereka akan menjadi penolongnya (dan selain dari itu malaikat-malaikat) yaitu sesudah pertolongan Allah dan orang-orang yang telah disebutkan tadi (adalah penolongnya pula) maksudnya mereka semua menjadi penolong Nabi terhadap kamu berdua.\qt@no{4}}%
\qt@newcmd\qurantrans@id@mmmmmccxxxiv{%
(Jika Nabi menceraikan kalian, boleh jadi Rabbnya) maksudnya, jika nabi menceraikan istri-istrinya (akan memberi ganti kepadanya) dapat dibaca yubdilahu dan yubaddilahu (dengan istri-istri yang lebih baik daripada kalian) lafal azwaajan ini menjadi khabar dari lafal 'asaa sedangkan jumlah an yubdilahu dan seterusnya menjadi jawab syarath. Di sini tidak ada badal karena apa yang disebutkan pada syarat tidak terjadi, yakni perceraian itu tidak pernah terjadi (yang patuh) artinya mengakui Islam (yang beriman) yakni ikhlas hatinya kepada Islam (yang taat) mereka taat (yang bertobat, rajin beribadat, rajin berpuasa) yakni gemar melakukan puasa atau yang berhijrah (yang janda dan yang perawan)\qt@no{5}}%
\qt@newcmd\qurantrans@id@mmmmmccxxxv{%
(Hai orang-orang yang beriman! Peliharalah diri kalian dan keluarga kalian) dengan mengarahkan mereka kepada jalan ketaatan kepada Allah (dari api neraka yang bahan bakarnya adalah manusia) orang-orang kafir (dan batu) seperti berhala-berhala yang mereka sembah adalah sebagian dari bahan bakar neraka itu. Atau dengan kata lain api neraka itu sangat panas, sehingga hal-hal tersebut dapat terbakar. Berbeda halnya dengan api di dunia, karena api di dunia dinyalakan dengan kayu dan lain-lainnya (penjaganya malaikat-malaikat) yakni, juru kunci neraka itu adalah malaikat-malaikat yang jumlahnya ada sembilan belas malaikat, sebagaimana yang akan diterangkan nanti dalam surat Al-Muddatstsir (yang kasar) lafal ghilaazhun ini diambil dari asal kata ghilazhul qalbi, yakni kasar hatinya (yang keras) sangat keras hantamannya (mereka tidak pernah mendurhakai Allah terhadap apa yang telah diperintahkan-Nya kepada mereka) lafal maa amarahum berkedudukan sebagai badal dari lafal Allah. Atau dengan kata lain, malaikat-malaikat penjaga neraka itu tidak pernah mendurhakai perintah Allah (dan mereka selalu mengerjakan apa yang diperintahkan) lafaz ayat ini berkedudukan menjadi badal dari lafal yang sebelumnya. Dalam ayat ini terkandung ancaman bagi orang-orang mukmin supaya jangan murtad; dan juga ayat ini merupakan ancaman pula bagi orang-orang munafik yaitu, mereka yang mengaku beriman dengan lisannya tetapi hati mereka masih tetap kafir.\qt@no{6}}%
\qt@newcmd\qurantrans@id@mmmmmccxxxvi{%
(Hai orang-orang kafir, janganlah kalian mengemukakan uzur pada hari ini) ucapan ini dikatakan kepada mereka sewaktu mereka dimasukkan ke dalam neraka; dikatakan demikian karena uzur atau alasan itu tiada gunanya. (Sesungguhnya kalian hanya diberi balasan menurut apa yang kalian kerjakan) sebagai balasannya.\qt@no{7}}%
\qt@newcmd\qurantrans@id@mmmmmccxxxvii{%
(Hai orang-orang yang beriman, bertobatlah kepada Allah dengan tobat yang semurni-murninya) dapat dibaca nashuuhaa dan nushuuhaa, artinya tobat yang sebenar-benarnya, bertobat tidak akan mengulangi dosa lagi, dan menyesali apa yang telah dikerjakannya (mudah-mudahan Rabb kalian) lafal 'asaa ini mengandung makna tarajji, yakni sesuatu yang dapat diharapkan akan terjadi (akan menutupi kesalahan-kesalahan kalian, dan memasukkan kalian ke dalam surga-surga) yakni taman-taman surga (yang mengalir di bawahnya sungai-sungai, pada hari ketika Allah tidak menghinakan) Allah tidak akan memasukkan ke dalam neraka (Nabi dan orang-orang yang beriman bersama dia; sedangkan cahaya mereka memancar di hadapan mereka) maksudnya, di depan mereka terang benderang oleh cahayanya (dan) cahaya itu pun memancar pula (di sebelah kanan mereka. Mereka berkata) lafal yaquuluuna merupakan jumlah isti'naf atau kalimat baru: ("Ya Rabb kami! Sempurnakanlah bagi kami cahaya kami) hingga sampai ke surga, sedangkan orang-orang munafik cahaya mereka padam (dan ampunilah kami) wahai Rabb kami (sesungguhnya Engkau Maha Kuasa atas segala sesuatu.").\qt@no{8}}%
\qt@newcmd\qurantrans@id@mmmmmccxxxviii{%
(Hai Nabi! Perangilah orang-orang kafir) dengan memakai senjata (dan orang-orang munafik) dengan memakai lisan dan hujah (dan bersikap keraslah terhadap mereka) dengan berbicara keras dan membenci mereka. (Tempat mereka adalah neraka Jahanam, dan seburuk-buruk tempat kembali itu) adalah neraka Jahanam.\qt@no{9}}%
\qt@newcmd\qurantrans@id@mmmmmccxxxix{%
(Allah membuat istri Nuh dan istri Luth perumpamaan bagi orang-orang kafir. Keduanya berada di bawah pengawasan dua orang hamba yang saleh di antara hamba-hamba Kami; lalu kedua istri itu berkhianat kepada kedua suaminya) dalam masalah agama, karena ternyata keduanya kafir dan adalah istri Nabi Nuh yang dikenal dengan nama Wahilah telah berkata kepada kaumnya, ``Sesungguhnya Nuh ini adalah orang gila." Sedangkan istri Nabi Luth yang dikenal dengan nama Wailah, memberikan petunjuk kepada kaumnya tentang tamu-tamunya, yaitu bahwa jika tamu-tamu itu tinggal di rumahnya, maka ia akan memberi tanda kepada mereka dengan api di waktu malam dan kalau siang hari dengan memakai asap (maka kedua suaminya itu tiada dapat membantu) yaitu Nabi Nuh dan Nabi Luth tidak bisa menolong (mereka berdua dari Allah) dari azab-Nya (barang sedikit pun; dan dikatakan) kepada kedua istri itu ("Masuklah kamu berdua ke dalam neraka bersama orang-orang yang memasukinya") yaitu bersama orang-orang kafir dari kalangan kaum Nabi Nuh dan kaum Nabi Luth.\qt@no{10}}%
\qt@newcmd\qurantrans@id@mmmmmccxl{%
(Dan Allah membuat istri Firaun perumpamaan bagi orang-orang yang beriman) istri Firaun itu beriman kepada Nabi Musa, ia bernama Asiah. Lalu Firaun menyiksanya dengan cara mengikat kedua tangan dan kedua kakinya, lalu di dadanya diletakkan kincir yang besar, kemudian dihadapkan kepada sinar matahari yang terik. Bilamana orang yang diperintahkan oleh Firaun untuk menjaganya pergi maka, malaikat menaunginya dari sengatan sinar matahari (ketika ia berkata) sewaktu dalam keadaan disiksa ("Ya Rabbku! Bangunlah untukku sebuah rumah di sisi-Mu dalam surga) maka Allah menampakkan rumahnya yang di surga itu, hingga ia dapat melihatnya, maka siksaan yang dialaminya itu terasa ringan baginya setelah melihat pahalanya (dan selamatkanlah aku dari Firaun dan perbuatannya) dari siksaannya terhadap diriku (dan selamatkanlah aku dari kaum yang lalim.") yakni pemeluk agama Firaun. Setelah itu lalu Allah mencabut rohnya. Menurut Ibnu Kaisan, bahwa Siti Asiah diangkat ke surga dalam keadaan hidup, dan ia makan dan minum di dalam surga.\qt@no{11}}%
\qt@newcmd\qurantrans@id@mmmmmccxli{%
(Dan Maryam) lafal ini diathafkan kepada lafaz imra'atu fir`auna (putri Imran yang memelihara kehormatannya) menjaga kehormatannya (maka Kami tiupkan ke dalam rahimnya sebagian dari roh Kami) yakni malaikat Jibril, ia meniupkan ke dalam kerah bajunya roh ciptaan Allah berdasarkan perintah dari Allah, hingga tiupan itu masuk ke dalam kemaluannya, lalu setelah itu Maryam mengandung Isa (dan dia membenarkan kalimat-kalimat Rabbnya) yakni syariat-syariat-Nya (dan Kitab-kitab-Nya) yang telah diturunkan (dan adalah dia termasuk orang-orang yang taat) termasuk golongan orang-orang yang taat kepada Allah.\qt@no{12}}%
\qt@newcmd\qurantrans@id@mmmmmccxlii{%
\basmalahid (Maha Suci Allah) Maha Suci dari sifat-sifat semua makhluk (Yang di tangan kekuasaan-Nyalah) yang berada dalam pengaturan-Nyalah (segala kerajaan) segala kekuasaan dan pengaruh (dan Dia Maha Kuasa atas segala sesuatu).\qt@no{1}}%
\qt@newcmd\qurantrans@id@mmmmmccxliii{%
(Yang menjadikan mati) di dunia (dan hidup) di akhirat, atau yang menjadikan mati dan hidup di dunia. Nuthfah pada asalnya sebagai barang mati, kemudian jadilah ia hidup; pengertian hidup ialah karena ia mempunyai perasaan. Pengertian mati adalah kebalikannya. Pengertian lafal al-khalqu berdasarkan makna yang kedua ini berarti memastikan (supaya Dia menguji kalian) atau mencoba kalian di dalam kehidupan ini (siapa di antara kalian yang lebih baik amalnya) maksudnya yang paling taat kepada Allah. (Dan Dia Maha Perkasa) di dalam melakukan pembalasan terhadap orang yang durhaka kepada-Nya (lagi Maha Pengampun) kepada orang yang bertobat kepada-Nya.\qt@no{2}}%
\qt@newcmd\qurantrans@id@mmmmmccxliv{%
(Yang telah menciptakan tujuh langit berlapis-lapis) yakni sebagian di antaranya berada di atas sebagian yang lain tanpa bersentuhan. (Kamu sekali-kali tidak melihat pada ciptaan Yang Maha Pemurah) pada tujuh langit yang berlapis-lapis itu atau pada makhluk yang lain (sesuatu yang tidak seimbang) yang berbeda dan tidak seimbang. (Maka lihatlah berulang-ulang) artinya lihatlah kembali ke langit (adakah kamu lihat) padanya (keretakan?) maksudnya retak dan berbelah-belah.\qt@no{3}}%
\qt@newcmd\qurantrans@id@mmmmmccxlv{%
(Kemudian pandanglah sekali lagi) ulangilah kembali penglihatanmu berkali-kali (niscaya akan berbalik) akan kembali (penglihatanmu itu kepadamu dalam keadaan hina) karena tidak menemukan sesuatu cacat (dan penglihatanmu itu pun dalam keadaan payah) yakni tidak melihat sama sekali adanya cacat.\qt@no{4}}%
\qt@newcmd\qurantrans@id@mmmmmccxlvi{%
(Dan sesungguhnya Kami telah menghiasi langit yang dekat) yang dekat dengan bumi (dengan lampu-lampu) dengan bintang-bintang (dan Kami jadikan bintang-bintang itu alat-alat pelempar) alat untuk melempar dan merajam (setan-setan) bilamana mereka mencuri pembicaraan para malaikat dengan telinga mereka; umpamanya terpisah batu meteor dari bintang-bintang itu yang bentuknya bagaikan segumpal api, lalu mengejar setan dan membunuhnya atau membuatnya cacat. Pengertian ini bukan berarti bahwa bintang-bintang itu lenyap dari tempatnya (dan Kami sediakan bagi mereka siksa neraka yang menyala-nyala) yang besar apinya.\qt@no{5}}%
\qt@newcmd\qurantrans@id@mmmmmccxlvii{%
(Dan orang-orang yang kafir kepada Rabb mereka, memperoleh azab Jahanam. Dan itulah seburuk-buruk tempat kembali) yakni neraka Jahanam.\qt@no{6}}%
\qt@newcmd\qurantrans@id@mmmmmccxlviii{%
(Apabila mereka dilemparkan ke dalamnya mereka mendengar suara neraka yang mengerikan) yaitu suara yang tidak enak didengar sebagaimana suara keledai (sedang neraka itu menggelegar) yakni mendidih.\qt@no{7}}%
\qt@newcmd\qurantrans@id@mmmmmccxlix{%
(Hampir-hampir neraka itu terpecah-pecah) menurut suatu qiraat lafal tamayyazu dibaca tatamayyazu sesuai dengan asalnya, artinya terbelah-belah (lantaran marah) karena murka kepada orang kafir. (Setiap kali dilemparkan ke dalamnya sekumpulan orang) segolongan di antara orang-orang kafir (penjaga-penjaga neraka itu bertanya kepada mereka) dengan pertanyaan yang mengandung nada celaan, ("Apakah belum pernah datang kepada kalian seorang pemberi peringatan?") maksudnya seorang rasul yang memberikan peringatan kepada kalian akan azab Allah swt.\qt@no{8}}%
\qt@newcmd\qurantrans@id@mmmmmccl{%
(Mereka menjawab, ``Benar ada, sesungguhnya telah datang kepada kami seorang pemberi peringatan, maka kami mendustakannya dan kami katakan, Allah tidak menurunkan sesuatu pun; tidak lain) tiadalah (kamu hanyalah di dalam kesesatan yang besar.") Kalimat in antum illaa fii dhalaalin kabiir dapat dianggap sebagai perkataan para malaikat penjaga neraka kepada orang-orang kafir sewaktu mereka dijelaskan sebagai orang-orang yang mendustakan rasul-rasul. Kalimat ini pun dapat pula dianggap sebagai perkataan orang-orang kafir sebagai alasan mereka tidak percaya kepada rasul-rasul.\qt@no{9}}%
\qt@newcmd\qurantrans@id@mmmmmccli{%
(Dan mereka berkata, ``Sekiranya kami mendengarkan) maksudnya mendengar yang disertai pemahaman (atau memikirkan) memikirkan apa yang didengarnya, yaitu peringatan rasul-rasul kepada mereka (niscaya tidaklah kami termasuk penghuni-penghuni neraka yang menyala-nyala").\qt@no{10}}%
\qt@newcmd\qurantrans@id@mmmmmcclii{%
(Mereka mengakui) orang-orang kafir itu mengaku di saat tiada gunanya lagi pengakuan (dosa mereka) yaitu dosa mendustakan peringatan-peringatan. (Maka kebinasaanlah) dapat dibaca fasuhqan dan fasuhuqan (bagi penghuni-penghuni neraka yang menyala-nyala) mereka dijauhkan dari rahmat Allah swt.\qt@no{11}}%
\qt@newcmd\qurantrans@id@mmmmmccliii{%
(Sesungguhnya orang-orang yang takut kepada Rabbnya) mereka yang takut kepada-Nya (dalam sendirian) sewaktu mereka tidak kelihatan oleh orang lain, mereka tetap taat kepada-Nya. Dengan demikian berarti bila mereka berada secara terang-terangan maka lebih takut lagi (mereka akan memperoleh ampunan dan pahala yang besar) yang dimaksud adalah surga.\qt@no{12}}%
\qt@newcmd\qurantrans@id@mmmmmccliv{%
(Dan rahasiakanlah) hai manusia (perkataan kalian atau lahirkanlah ia; sesungguhnya Dia) yakni Allah swt. (Maha Mengetahui segala isi hati) Maha Mengetahui apa yang tersimpan di dalam kalbu dan apa yang kalian ucapkan. Asbabun nuzul ayat ini ialah karena orang-orang musyrik mengatakan, sebagian di antara mereka kepada sebagian yang lain, ``Rahasiakanlah pembicaraan kalian, niscaya Tuhannya Muhammad tidak akan dapat mendengarkannya."\qt@no{13}}%
\qt@newcmd\qurantrans@id@mmmmmcclv{%
(Apakah Tuhan yang telah menciptakan tidak mengetahui) apa yang kalian rahasiakan itu, yakni apakah ilmu-Nya tidak dapat menjangkau hal tersebut (sedangkan Dia Maha Halus) ilmu-Nya (lagi Maha Waspada).\qt@no{14}}%
\qt@newcmd\qurantrans@id@mmmmmcclvi{%
(Dialah yang menjadikan bumi itu mudah bagi kalian) mudah untuk dipakai berjalan di atas permukaannya (maka berjalanlah di segala penjurunya) pada semua arahnya (dan makanlah sebagian dari rezeki-Nya) yang sengaja diciptakan buat kalian. (Dan hanya kepada-Nyalah kalian dibangkitkan) dari kubur untuk mendapatkan pembalasan.\qt@no{15}}%
\qt@newcmd\qurantrans@id@mmmmmcclvii{%
(Apakah kalian merasa aman) dapat dibaca secara tahqiq dan dapat pula dibaca secara tashil (terhadap kekuasaan Allah yang di langit) yakni pengaruh dan kekuasaan-Nya yang di langit (bahwa Dia akan menjungkir balikkan) berkedudukan menjadi badal dari lafal man (bumi bersama kalian, sehingga dengan tiba-tiba bumi itu berguncang) menjadi gempa dan menindih kalian.\qt@no{16}}%
\qt@newcmd\qurantrans@id@mmmmmcclviii{%
(Atau apakah kalian merasa aman terhadap kekuasaan Allah yang di langit bahwa Dia akan mengirimkan) lafal an yursila menjadi badal dari lafal man (kepada kalian badai yang berbatu) yakni angin dahsyat yang menghujani kalian dengan batu. (Maka kelak kalian akan mengetahui) di saat kalian menyaksikan azab-Nya (bagaimana peringatan-Ku) yakni azab-Ku; maksudnya bahwa azab-Ku itu adalah benar.\qt@no{17}}%
\qt@newcmd\qurantrans@id@mmmmmcclix{%
(Dan sesungguhnya orang-orang sebelum mereka telah mendustakan) umat-umat sebelum mereka. (Maka alangkah hebatnya kemurkaan-Ku) keingkaran-Ku terhadap mereka disebabkan kedustaan mereka, yaitu sewaktu mereka dibinasakan, bahwasanya pembinasaan-Ku itu adalah benar.\qt@no{18}}%
\qt@newcmd\qurantrans@id@mmmmmcclx{%
(Apakah mereka tidak melihat) tidak memperhatikan (burung-burung yang berada di atas mereka) yakni di udara (yang mengembangkan sayapnya) melebarkan sayapnya (dan mengatupkannya?) menutupkannya sesudah dikembangkan. (Tidak ada yang menahan mereka) agar jangan jatuh ke bumi sewaktu mengembangkan dan mengatupkan sayapnya (selain Yang Maha Penyayang) yakni dengan kekuasaan-Nya. (Sesungguhnya Dia Maha Melihat segala sesuatu) makna yang dimaksud, apakah mereka tidak menyimpulkan dengan tetapnya burung-burung di udara tentang kekuasaan Kami, bahwa Kami dapat menimpakan kepada mereka azab yang telah disebutkan di atas tadi dan azab lainnya.\qt@no{19}}%
\qt@newcmd\qurantrans@id@mmmmmcclxi{%
(Atau siapakah) berkedudukan menjadi mubtada (dia) menjadi khabar dari mubtada (yang) menjadi badal dari lafal haadza (menjadi tentara) yakni penolong-penolong (kalian) berkedudukan menjadi shilah dari lafal alladzii (yang akan menolong kalian) menjadi sifat dari lafal jundun (selain daripada Allah Yang Maha Penyayang) yang dapat menolak datangnya azab bagi kalian; yakni tiada seseorang pun yang dapat menolong kalian (tidak lain) tiadalah (orang-orang kafir itu hanyalah dalam keadaan tertipu) mereka tertipu oleh setan, bahwasanya azab tidak akan turun atas mereka.\qt@no{20}}%
\qt@newcmd\qurantrans@id@mmmmmcclxii{%
(Atau siapakah dia yang memberi kalian rezeki jika Dia menahan) yakni Allah Yang Maha Penyayang menahan (rezeki-Nya) yakni hujan-Nya terhadap kalian. Jawab syaratnya tidak disebutkan, karena dapat disimpulkan dari kalimat sebelumnya. Lengkapnya, siapakah yang dapat memberi kalian rezeki? Tentu tiada seorang pun yang dapat memberikan rezeki kepada kalian selain-Nya. (Tetapi mereka terus-menerus) berkelanjutan (di dalam kesombongan) dalam kesombongannya (dan menjauhkan diri) dari kebenaran.\qt@no{21}}%
\qt@newcmd\qurantrans@id@mmmmmcclxiii{%
(Maka apakah orang yang berjalan terjungkal) yakni terbalik (di atas mukanya itu lebih banyak mendapat petunjuk, ataukah orang yang berjalan tegap) yakni secara wajar dengan kakinya (di atas jalan) tuntunan (yang lurus) khabar dari mubtada yang kedua tidak disebutkan karena cukup hanya ditunjukkan oleh makna yang terkandung di dalam khabar yang pertama, yakni lebih banyak mendapat petunjuk. Perumpamaan ini menggambarkan tentang keadaan orang yang kafir pada permintaan yang pertama, dan orang yang beriman pada perumpamaan yang kedua, yakni manakah di antara keduanya yang lebih banyak mendapat petunjuk?\qt@no{22}}%
\qt@newcmd\qurantrans@id@mmmmmcclxiv{%
(Katakanlah! ``Dialah Yang menjadikan kalian) yakni yang telah menciptakan kalian (dan menjadikan bagi kalian pendengaran, penglihatan dan hati") atau kalbu. (Tetapi amat sedikit kalian bersyukur) huruf maa adalah huruf zaidah, dan jumlah kalimat ini merupakan jumlah isti'naf atau kalimat baru yang memberitakan tentang syukur mereka yang amat sedikit terhadap nikmat-nikmat tersebut.\qt@no{23}}%
\qt@newcmd\qurantrans@id@mmmmmcclxv{%
(Katakanlah! ``Dialah Yang menjadikan kalian berkembang biak) artinya menciptakan kalian dapat berkembang biak (di muka bumi, dan hanya kepada-Nyalah kalian kelak dikumpulkan") untuk menjalani hisab.\qt@no{24}}%
\qt@newcmd\qurantrans@id@mmmmmcclxvi{%
(Dan mereka berkata) kepada orang-orang yang beriman, ("Kapankah datangnya Janji itu) yakni janji datangnya hari semua makhluk dihimpun (jika kalian adalah orang-orang yang benar?") dalam hal ini.\qt@no{25}}%
\qt@newcmd\qurantrans@id@mmmmmcclxvii{%
(Katakanlah!, ``Sesungguhnya ilmu) tentang kedatangan hari tersebut (hanya pada sisi Allah, dan sesungguhnya aku hanyalah seorang pemberi peringatan yang menjelaskan.") Yakni yang jelas peringatannya.\qt@no{26}}%
\qt@newcmd\qurantrans@id@mmmmmcclxviii{%
(Ketika mereka melihat azab itu) sesudah mereka dihimpunkan (sudah dekat) artinya, dekat sekali (menjadi muramlah) menjadi hitam muramlah (muka orang-orang kafir itu. Dan dikatakan) kepada mereka, yakni para malaikat penjaga neraka berkata kepada mereka ("Inilah) azab (yang dahulu kalian terhadapnya) yakni sewaktu kalian diancam dengan azab ini (selalu menganggapnya sebagai yang diada-adakan.") Yakni kalian menduga, bahwasanya kalian tidak akan dibangkitkan menjadi hidup kembali. Hal ini menceritakan keadaan di masa mendatang, akan tetapi ungkapannya memberikan pengertian sudah terjadi. Ini tiada lain karena subjeknya pasti benar-benar terjadi.\qt@no{27}}%
\qt@newcmd\qurantrans@id@mmmmmcclxix{%
(Katakanlah!, ``Terangkanlah kepadaku jika Allah mematikan aku dan orang-orang yang bersama dengan aku) yakni orang-orang mukmin, kami binasa karena azab-Nya, sebagaimana yang kalian maksudkan (atau memberi rahmat kepada kami) maksudnya, Dia tidak mengazab kami (tetapi siapakah yang dapat melindungi orang-orang yang kafir dari siksa yang pedih?") Tentu saja tiada seorang pun yang dapat melindungi mereka dari azab-Nya.\qt@no{28}}%
\qt@newcmd\qurantrans@id@mmmmmcclxx{%
(Katakanlah!, ``Dialah Allah Yang Maha Penyayang kami beriman kepada-Nya dan kepada-Nyalah kami bertawakal. Kelak kalian akan mengetahui) bilamana mereka menyaksikan azab itu. Lafal fasata`lamuuna dapat pula dibaca fasaya`lamuuna, artinya kelak mereka akan mengetahui di saat mereka menyaksikan azab (siapakah yang berada dalam kesesatan yang nyata.") Kami-kah atau mereka?\qt@no{29}}%
\qt@newcmd\qurantrans@id@mmmmmcclxxi{%
(Katakanlah, ``Terangkanlah kepadaku jika sumber air kalian menjadi kering;) yakni airnya masuk jauh ke dalam bumi (maka siapakah yang akan mendatangkan air yang mengalir bagi kalian?") Sehingga air itu menyumber dan dapat dicapai oleh tangan atau oleh timba-timba, sebagaimana air yang kalian miliki sekarang? Tiada seorang pun yang dapat mendatangkannya selain Allah swt. Maka, mengapa kalian mengingkari adanya hari berbangkit, yaitu hari di mana Dia membangkitkan kalian menjadi hidup kembali. Disunahkan bagi pembaca surah ini, bila bacaannya sampai kepada lafal ma`iin, hendaknya ia mengucapkan kalimat jawabannya, yaitu ``allaahu rabbul 'aalamiina/Allah Rabb semesta alam yang dapat mengeluarkannya. Demikianlah menurut keterangan yang dikemukakan di dalam hadis. Dan ayat ini dibacakan terhadap sebagian orang-orang yang bersifat angkara murka, maka menurut perawinya, bahwa cangkul dan sekop penggali tanah terus menghunjam ke tanah, akan tetapi sumber air tidak muncul-muncul juga; ia telah pergi jauh meresap ke dalam bumi yang tidak dapat dicapainya. Kami berlindung kepada Allah dari perbuatan berani melawan Allah dan ayat-ayat-Nya.\qt@no{30}}%
\qt@newcmd\qurantrans@id@mmmmmcclxxii{%
\basmalahid (Nun) adalah salah satu dari huruf hijaiah, hanya Allahlah yang mengetahui arti dan maksudnya (demi qalam) yang dipakai untuk menulis nasib semua makhluk di Lohmahfuz (dan apa yang mereka tulis) apa yang ditulis oleh para malaikat berupa kebaikan dan kesalehan.\qt@no{1}}%
\qt@newcmd\qurantrans@id@mmmmmcclxxiii{%
(Kamu sekali-kali bukanlah) hai Muhammad (orang gila, berkat nikmat Rabbmu) yang telah mengaruniakan kenabian kepadamu, dan juga nikmat-nikmat-Nya yang lain. Ayat ini merupakan jawaban terhadap perkataan orang-orang kafir, yang mengatakan bahwa Muhammad adalah orang gila.\qt@no{2}}%
\qt@newcmd\qurantrans@id@mmmmmcclxxiv{%
(Dan sesungguhnya bagi kamu benar-benar pahala yang besar yang tidak putus-putusnya) tiada pernah terputus.\qt@no{3}}%
\qt@newcmd\qurantrans@id@mmmmmcclxxv{%
(Dan sesungguhnya kamu benar-benar berbudi pekerti) beragama (yang agung.)\qt@no{4}}%
\qt@newcmd\qurantrans@id@mmmmmcclxxvi{%
(Maka kelak kamu akan melihat dan mereka pun akan melihat.)\qt@no{5}}%
\qt@newcmd\qurantrans@id@mmmmmcclxxvii{%
(Siapakah di antara kalian yang gila) yang tidak waras akalnya, kamukah atau mereka. Lafal al-maftuun ini wazannya sama dengan lafal al-ma`quul, berasal dari mashdar al-futuun, artinya gila.\qt@no{6}}%
\qt@newcmd\qurantrans@id@mmmmmcclxxviii{%
(Sesungguhnya Rabbmu, Dialah Yang Paling Mengetahui siapa yang sesat dari jalan-Nya dan Dialah Yang Paling mengetahui orang-orang yang mendapat petunjuk) lafal a`lamu di sini bermakna 'aalimun, yakni Dia mengetahui siapa yang sesat dari jalan-Nya dan Dialah Yang mengetahui orang-orang yang mendapat petunjuk.\qt@no{7}}%
\qt@newcmd\qurantrans@id@mmmmmcclxxix{%
(Maka janganlah kamu ikuti orang-orang yang mendustakan ayat-ayat Allah.)\qt@no{8}}%
\qt@newcmd\qurantrans@id@mmmmmcclxxx{%
(Mereka menginginkan) mengharapkan (supaya) merupakan mashdariyah (kamu bersikap lunak) bersikap lembut terhadap mereka (lalu mereka bersikap lunak) pula terhadapmu; diathafkan kepada lafal tudhinu. Seandainya dijadikan sebagai jawab dari tamanni yang tersimpulkan dari lafal wadduu, maka sebelum huruf fa diperkirakan adanya lafal hum. Yakni, seandainya kamu bersikap lunak terhadap mereka, maka mereka pun akan bersikap lunak pula terhadapmu.\qt@no{9}}%
\qt@newcmd\qurantrans@id@mmmmmcclxxxi{%
(Dan janganlah kamu ikuti setiap orang yang banyak bersumpah) dengan cara yang batil (lagi hina) yakni rendah.\qt@no{10}}%
\qt@newcmd\qurantrans@id@mmmmmcclxxxii{%
(Yang banyak mencela) atau sering mengumpat (yang kian ke mari menghambur fitnah) yakni berjalan ke sana dan ke mari di antara orang-orang dengan maksud merusak mereka, yakni menghasut mereka.\qt@no{11}}%
\qt@newcmd\qurantrans@id@mmmmmcclxxxiii{%
(Yang banyak menghalangi perbuatan baik) artinya sangat kikir tidak mau membelanjakan hartanya kepada hak-hak yang diwajibkan atas dirinya (yang melampaui batas) sangat aniaya (lagi banyak dosa) banyak melakukan perbuatan dosa.\qt@no{12}}%
\qt@newcmd\qurantrans@id@mmmmmcclxxxiv{%
(Yang kaku kasar) wataknya kaku lagi kasar (selain dari itu, yang terkenal kejahatannya) dia adalah seseorang yang dianggap sebagai orang Quraisy, padahal dia bukan dari kalangan mereka, yaitu Walid bin Mughirah. Ayahnya menjulukinya sebagai orang Quraisy setelah ia berumur delapan belas tahun. Ibnu Abbas r.a. mengatakan, bahwa kami belum pernah mengetahui, bahwa Allah swt. menyifati seseorang dengan sifat-sifat yang tercela sebagaimana yang telah dilakukan-Nya terhadap Walid, sehingga keaiban itu tetap menempel pada diri Walid untuk selama-lamanya. Dan bertaalluq kepada lafal zaniim, zharaf yang terdapat pada sebelumnya.\qt@no{13}}%
\qt@newcmd\qurantrans@id@mmmmmcclxxxv{%
(Karena dia mempunyai banyak harta dan anak) bentuk asalnya adalah lian, dan bertaalluq kepada makna yang menunjukkan terhadap pengertiannya.\qt@no{14}}%
\qt@newcmd\qurantrans@id@mmmmmcclxxxvi{%
(Apabila dibacakan kepadanya ayat-ayat Kami) yakni Alquran (ia berkata) bahwa Alquran itu (dongeng-dongengan orang-orang dahulu kala.") Yaitu hanyalah kedustaan yang sengaja dibuat-buat guna menyenangkan hati kami sewaktu ia disebutkan atau diceritakan. Menurut suatu qiraat ada lafal a-an dengan memakai dua huruf Hamzah yang kedua-duanya difathahkan.\qt@no{15}}%
\qt@newcmd\qurantrans@id@mmmmmcclxxxvii{%
(Kelak akan Kami beri tanda dia di belalainya) Kami akan menjadikan tanda pada hidungnya, yang menyebabkannya cacat seumur hidup. Maka dia terpotong-potong hidungnya ketika perang Badar.\qt@no{16}}%
\qt@newcmd\qurantrans@id@mmmmmcclxxxviii{%
(Sesungguhnya Kami telah mencoba mereka) Kami telah menguji orang-orang musyrik Mekah dengan paceklik dan kelaparan (sebagaimana Kami telah mencoba pemilik-pemilik kebun) atau ladang (ketika mereka bersumpah bahwa mereka sungguh-sungguh akan memetik hasilnya) akan memetik buahnya (di pagi hari) di pagi buta, supaya orang-orang miskin tidak mengetahuinya. Maka orang-orang yang memiliki kebun itu mempunyai alasan bila mereka tidak memberikan sedekah kepada mereka; tidak sebagaimana bapak-bapak mereka yang selalu memberikan sebagian dari hasilnya buat orang-orang miskin sebagai sedekahnya.\qt@no{17}}%
\qt@newcmd\qurantrans@id@mmmmmcclxxxix{%
(Dan mereka tidak mengecualikan) di dalam sumpah mereka itu kepada kehendak Allah swt. Ayat ini merupakan jumlah isti'naf atau kalimat permulaan; yakni, kelakuan mereka seperti itu; mereka tidak pernah menggantungkan sumpahnya itu kepada kehendak Allah swt.\qt@no{18}}%
\qt@newcmd\qurantrans@id@mmmmmccxc{%
(Lalu kebun itu diliputi malapetaka dari Rabbmu) berupa api yang melahap kesemuanya di waktu malam (ketika mereka sedang tidur.)\qt@no{19}}%
\qt@newcmd\qurantrans@id@mmmmmccxci{%
(Maka jadilah kebun itu hitam seperti malam yang gelap gulita) yakni menjadi hangus terbakar semuanya, sehingga tampak hitam.\qt@no{20}}%
\qt@newcmd\qurantrans@id@mmmmmccxcii{%
(Lalu mereka panggil-memanggil di pagi hari.)\qt@no{21}}%
\qt@newcmd\qurantrans@id@mmmmmccxciii{%
("Pergilah di waktu pagi ini ke kebun kalian) ke ladang kalian; lafal ini menafsirkan pengertian yang terkandung di dalam lafal tanadauw; atau huruf an dianggap sebagai an mashdariyah (jika kalian hendak memetik buahnya") ingin memetik hasilnya; jawab syaratnya ditunjukkan oleh pengertian kalimat sebelumnya.\qt@no{22}}%
\qt@newcmd\qurantrans@id@mmmmmccxciv{%
(Maka pergilah mereka saling berbisik-bisikan) yakni dengan secara diam-diam.\qt@no{23}}%
\qt@newcmd\qurantrans@id@mmmmmccxcv{%
("Pada hari ini janganlah ada seorang miskin pun masuk ke dalam kebun kalian.") Ayat ini merupakan penafsiran dari makna yang terkandung pada ayat sebelumnya; atau huruf an dianggap sebagai huruf mashdariyah.\qt@no{24}}%
\qt@newcmd\qurantrans@id@mmmmmccxcvi{%
(Dan berangkatlah mereka di pagi hari dengan niat menghalangi) orang-orang miskin (seraya merasa mampu) yakni mampu untuk menghalangi orang-orang miskin, menurut dugaan mereka sendiri.\qt@no{25}}%
\qt@newcmd\qurantrans@id@mmmmmccxcvii{%
(Tatkala mereka melihat kebun itu) dalam keadaan hangus terbakar (mereka berkata, ``Sesungguhnya kita benar-benar orang-orang yang sesat.") Bukankah ini kebun kita. Kemudian setelah mereka mengetahui, bahwa itu adalah benar-benar kebun mereka, lalu mereka mengatakan:\qt@no{26}}%
\qt@newcmd\qurantrans@id@mmmmmccxcviii{%
(Bahkan kita dihalangi) dari memperoleh buahnya disebabkan kita telah menghalang-halangi orang-orang miskin dari memperoleh bagiannya.\qt@no{27}}%
\qt@newcmd\qurantrans@id@mmmmmccxcix{%
(Berkatalah seorang yang paling baik pikirannya di antara mereka) yaitu orang yang terbaik di antara mereka ("Bukankah aku mengatakan kepada kalian, mengapa tidak) kenapa tidak (kalian bertasbih?") kepada Allah seraya bertobat kepada-Nya.\qt@no{28}}%
\qt@newcmd\qurantrans@id@mmmmmccc{%
(Mereka mengucapkan, ``Maha Suci Rabb kami, sesungguhnya kami adalah orang-orang yang zalim.") Karena kami telah menghalang-halangi orang-orang miskin dari haknya.\qt@no{29}}%
\qt@newcmd\qurantrans@id@mmmmmccci{%
(Lalu sebagian mereka menghadapi sebagian yang lain seraya cela-mencela.)\qt@no{30}}%
\qt@newcmd\qurantrans@id@mmmmmcccii{%
(Mereka berkata, ``Aduhai) huruf ya di sini bermakna tanbih (celakalah kita) binasalah kita (sesungguhnya kita ini benar-benar orang-orang yang melampaui batas.)\qt@no{31}}%
\qt@newcmd\qurantrans@id@mmmmmccciii{%
(Mudah-mudahan Rabb kita memberikan ganti kepada kita) dapat dibaca yubdilanaa dan yubaddilanaa (yang lebih baik daripada itu; sesungguhnya kita mengharapkan ampunan dari Rabb kita.") Supaya Dia menerima tobat kita dan mendatangkan kepada kita kebun yang lebih baik dari kebun kita yang dahulu. Menurut suatu riwayat disebutkan, bahwa setelah itu mereka diberi kebun yang lebih baik dari yang semula.\qt@no{32}}%
\qt@newcmd\qurantrans@id@mmmmmccciv{%
(Seperti itulah) sebagaimana azab Kami kepada mereka (azab) di dunia, bagi orang yang menentang perintah Kami dari kalangan orang-orang kafir Mekah dan lain-lainnya. (Dan sesungguhnya azab akhirat lebih besar jika mereka mengetahui) jika mereka mengetahuinya, niscaya mereka tidak akan menentang perintah Kami. Ayat ini diturunkan sewaktu orang-orang kafir Mekah mengatakan, bahwa jika Dia membangkitkan kami, niscaya kami akan diberi pahala yang lebih baik daripada kalian.\qt@no{33}}%
\qt@newcmd\qurantrans@id@mmmmmcccv{%
(Sesungguhnya bagi orang-orang yang bertakwa surga-surga yang penuh kenikmatan di sisi Rabbnya.)\qt@no{34}}%
\qt@newcmd\qurantrans@id@mmmmmcccvi{%
(Maka apakah patut Kami menjadikan orang-orang Islam itu sama dengan orang-orang yang berdosa?) maksudnya mendapatkan pahala yang sama dengan orang-orang kafir.\qt@no{35}}%
\qt@newcmd\qurantrans@id@mmmmmcccvii{%
(Mengapa kalian berbuat demikian; bagaimanakah kalian mengambil keputusan?) dengan keputusan yang rusak ini?\qt@no{36}}%
\qt@newcmd\qurantrans@id@mmmmmcccviii{%
(Atau adakah) artinya, benarkah (kalian mempunyai kitab) yang diturunkan dari Allah (yang kalian mempelajarinya) yang kalian membacanya.\qt@no{37}}%
\qt@newcmd\qurantrans@id@mmmmmcccix{%
(Bahwa di dalamnya kalian benar-benar boleh memilih apa yang kalian sukai) kalian boleh memilih sesuka hati.\qt@no{38}}%
\qt@newcmd\qurantrans@id@mmmmmcccx{%
(Atau apakah kalian memperoleh janji-janji) perjanjian-perjanjian (yang diperkuat dengan sumpah dari Kami) yang telah diperkuat oleh Kami (yang tetap berlaku sampai hari kiamat) lafal ilaa yaumil qiyaamah ini bertaalluq kepadanya makna yang terkandung di dalam lafal 'alainaa, dan di dalam kalam ini terkandung makna qasam atau sumpah, yakni Kami telah bersumpah untuk mewajibkannya bagi kalian (sesungguhnya kalian benar-benar dapat mengambil keputusan) sekehendak kalian tentangnya?\qt@no{39}}%
\qt@newcmd\qurantrans@id@mmmmmcccxi{%
(Tanyakanlah kepada mereka, ``Siapakah di antara mereka terhadap hal tersebut) hukum atau keputusan yang mereka ambil buat diri mereka sendiri, yaitu bahwasanya mereka kelak di akhirat akan diberi pahala yang lebih utama dari orang-orang mukmin (yang bertanggung jawab?") yang menanggungnya bagi mereka.\qt@no{40}}%
\qt@newcmd\qurantrans@id@mmmmmcccxii{%
(Atau apakah mereka mempunyai) di sisi mereka (sekutu-sekutu?) yang sepakat dengan mereka tentang ucapan itu, yaitu mereka akan menjamin bagi mereka dalam hal ini. Maka apabila memang demikian keadaannya (maka hendaklah mereka mendatangkan sekutu-sekutu mereka) yang akan memberikan jaminan tentang hal itu bagi mereka (jika mereka adalah orang-orang yang benar.)\qt@no{41}}%
\qt@newcmd\qurantrans@id@mmmmmcccxiii{%
Ingatlah (pada hari betis disingkapkan) ungkapan ini menggambarkan tentang dahsyatnya keadaan pada hari kiamat, yaitu sewaktu hisab dan pembalasan dilaksanakan. Dikatakan ``kasyafatil harbu 'an saaqin", artinya perang itu berkobar dengan sengitnya (dan mereka dipanggil untuk bersujud) sebagai ujian buat keimanan mereka (maka mereka tidak kuasa) karena punggung mereka lekat bertumpuk menjadi satu, sehingga mereka tidak dapat bersujud.\qt@no{42}}%
\qt@newcmd\qurantrans@id@mmmmmcccxiv{%
(Seraya tunduk ke bawah) lafal khaasyi`atan ini merupakan hal dari dhamir yang terkandung pada lafal yad`uuna, artinya, dalam keadaan terhina (pandangan mereka) maksudnya, mereka tidak dapat mengangkat pandangan matanya (lagi mereka diliputi) mereka diselimuti (kehinaan. Dan sesungguhnya mereka dahulu diseru) sewaktu di dunia (untuk bersujud sedang mereka dalam keadaan sejahtera) akan tetapi mereka tidak mau melakukannya, yakni tidak mau salat.\qt@no{43}}%
\qt@newcmd\qurantrans@id@mmmmmcccxv{%
(Maka serahkanlah kepada-Ku) berikanlah kepada Aku (orang-orang yang mendustakan perkataan ini) yang mendustakan Alquran. (Nanti Kami akan menarik mereka dengan berangsur-angsur) Kami akan mengambil mereka secara berangsur-angsur (dari arah yang tidak mereka ketahui.)\qt@no{44}}%
\qt@newcmd\qurantrans@id@mmmmmcccxvi{%
(Dan Aku memberi tangguh kepada mereka) Aku menangguhkan mereka. (Sesungguhnya rencana-Ku amat teguh) amat kuat dan tak dapat ditinggalkan.\qt@no{45}}%
\qt@newcmd\qurantrans@id@mmmmmcccxvii{%
(Ataukah) yakni apakah (kamu meminta kepada mereka) atas penyampaian risalahmu (upah dengan utang, lalu mereka karena utang itu) karena apa yang harus mereka bayarkan kepadamu (merasa keberatan) karena itu lalu mereka tidak mau beriman kepada Alquran.\qt@no{46}}%
\qt@newcmd\qurantrans@id@mmmmmcccxviii{%
(Ataukah ada pada mereka ilmu tentang yang gaib) yaitu mengenai apa yang tertulis di Lohmahfuz (lalu mereka menulis) daripadanya apa yang mereka katakan itu.\qt@no{47}}%
\qt@newcmd\qurantrans@id@mmmmmcccxix{%
(Maka bersabarlah kamu terhadap ketetapan Rabbmu) terhadap mereka, sesuai dengan apa yang dikehendaki-Nya (dan janganlah kamu seperti orang yang berada dalam perut ikan paus) dalam hal ketergesa-gesaannya dan ketidaksabarannya, yaitu sebagaimana Nabi Yunus a.s. (ketika ia berdoa) kepada Rabbnya (sedangkan ia dalam keadaan marah) terhadap kaumnya, hatinya penuh dengan kemarahan sewaktu ia berada di dalam perut ikan besar itu.\qt@no{48}}%
\qt@newcmd\qurantrans@id@mmmmmcccxx{%
(Kalau sekiranya ia tidak segera mendapat) tidak segera disusul oleh (nikmat) yakni rahmat (dari Rabbnya, benar-benar ia dicampakkan) dari perut ikan besar itu (ke tanah yang tandus) tanah yang tidak ada tumbuh-tumbuhannya (dalam keadaan tercela) akan tetapi Allah mengasihaninya sehingga ia dicampakkan tidak dalam keadaan tercela.\qt@no{49}}%
\qt@newcmd\qurantrans@id@mmmmmcccxxi{%
(Lalu Rabbnya memilihnya) memberinya kenabian (dan menjadikannya termasuk orang-orang yang saleh) yakni sebagian dari para nabi.\qt@no{50}}%
\qt@newcmd\qurantrans@id@mmmmmcccxxii{%
(Dan sesungguhnya orang-orang kafir itu benar-benar hampir menggelincirkan kamu) dapat dibaca layuzliquunaka dan layazliquunaka (dengan pandangan mereka) mereka memandangmu dengan pandangan yang sangat tajam, sehingga pandangannya hampir-hampir membuatmu pingsan dan menjatuhkanmu dari tempat atau kedudukanmu (tatkala mereka mendengar peringatan) yakni Alquran (dan mereka berkata) karena dengki, ("Sesungguhnya ia benar-benar orang gila.") Mereka dengki karena Alquran yang diturunkan kepadanya itu.\qt@no{51}}%
\qt@newcmd\qurantrans@id@mmmmmcccxxiii{%
(Dan tidak lain dia) yakni Alquran itu (hanyalah peringatan) pelajaran (bagi seluruh umat) yaitu jin dan manusia, dan tiada menimbulkan kegilaan disebabkannya.\qt@no{52}}%
\qt@newcmd\qurantrans@id@mmmmmcccxxiv{%
\basmalahid (Hari yang benar) yaitu hari kiamat, dikatakan demikian karena pada hari itu dibenarkan hal-hal yang diingkari, seperti mengenai adanya hari kebangkitan, hari hisab dan hari pembalasan. Atau dinamakan demikian karena pada hari itu ditampakkan kepada mereka hal-hal tersebut.\qt@no{1}}%
\qt@newcmd\qurantrans@id@mmmmmcccxxv{%
(Apakah hari yang benar itu) ungkapan ini mengandung makna yang menggambarkan tentang keagungan hari kiamat; dan berkedudukan sebagai mubtada yang sekaligus sebagai khabar dari lafal al-haaqqah yang pertama.\qt@no{2}}%
\qt@newcmd\qurantrans@id@mmmmmcccxxvi{%
(Dan tahukah kamu) sudah tahukah kamu (apakah hari yang benar itu?) ungkapan ini menambah keagungan hari kiamat. Maa yang pertama menjadi mubtada sedangkan maa yang kedua menjadi khabarnya. Dan maa yang kedua berikut khabarnya berkedudukan sebagai maf'ul kedua dari lafal adraa.\qt@no{3}}%
\qt@newcmd\qurantrans@id@mmmmmcccxxvii{%
(Kaum Tsamud dan kaum 'Ad telah mendustakan hari yang menggentarkan) yakni hari kiamat, hari kiamat dinamakan demikian karena kedahsyatan dan kengerian yang terjadi pada hari itu sangat menggentarkan hati.\qt@no{4}}%
\qt@newcmd\qurantrans@id@mmmmmcccxxviii{%
(Adapun kaum Tsamud, maka mereka telah dibinasakan dengan teriakan yang dahsyat) teriakan yang kerasnya melampaui batas.\qt@no{5}}%
\qt@newcmd\qurantrans@id@mmmmmcccxxix{%
(Adapun kaum Ad maka mereka telah dibinasakan dengan angin yang sangat keras) sangat keras suaranya (lagi amat kuat) kuat lagi keras; angin tersebut ditimpakan atas kaum Ad, sekalipun mereka kuat lagi keras tetapi menghadapi angin ini mereka tidak berarti apa-apa.\qt@no{6}}%
\qt@newcmd\qurantrans@id@mmmmmcccxxx{%
(Yang Allah tundukkan angin itu) artinya Allah mengirimkannya dengan kekuasaan-Nya (kepada mereka selama tujuh malam dan delapan hari) dimulai pada pagi hari Rabu, tanggal dua puluh dua bulan Syawal; angin itu terjadi di pertengahan musim dingin (terus-menerus) atau secara berturut-turut. Keadaan angin itu diserupakan dengan pekerjaan yang dilakukan oleh tukang setrika, yaitu sewaktu ia mengulang-ulang setrikaannya pada penyakit yang diobatinya. Yakni, ia mengulang-ulanginya dari satu waktu ke waktu yang lainnya hingga penyakitnya lenyap sama sekali (maka kamu lihat kaum 'Ad pada waktu itu mati bergelimpangan) mereka tercampakkan ke dalam keadaan binasa (seakan-akan mereka batang) pokok (pohon kurma yang lapuk) yang jatuh karena keropos atau lapuk.\qt@no{7}}%
\qt@newcmd\qurantrans@id@mmmmmcccxxxi{%
(Maka apakah kamu melihat bekas-bekas mereka?) lafal baaqiyah adalah sifat dari lafal nafsin yang diperkirakan keberadaannya; yaitu apakah kamu melihat seseorang pun yang tinggal di antara mereka? Atau lafal baaqiyah ini huruf ta-nya untuk menunjukkan makna mubalaghah, yakni bekas-bekasnya? Tentu saja tidak.\qt@no{8}}%
\qt@newcmd\qurantrans@id@mmmmmcccxxxii{%
(Dan telah datang Firaun dan orang-orang yang mengikutinya) beserta para pengikutnya. Menurut suatu qiraat, lafal qabilahu dibaca qablahu sehingga artinya, orang-orang kafir yang sebelumnya (dan negeri-negeri yang dijungkirbalikkan) penduduknya dijungkirbalikkan berikut negeri-negeri tempat tinggal mereka; yang dimaksud adalah negeri-negeri tempat tinggal kaum Nabi Luth (karena kesalahan yang besar) karena mereka mengerjakan perbuatan-perbuatan dosa besar.\qt@no{9}}%
\qt@newcmd\qurantrans@id@mmmmmcccxxxiii{%
(Maka masing-masing mereka mendurhakai rasul Rabb mereka) mendurhakai Nabi Luth dan nabi-nabi lainnya (lalu Allah menyiksa mereka dengan siksaan yang sangat keras) siksaan yang lebih keras daripada siksaan-siksaan lainnya.\qt@no{10}}%
\qt@newcmd\qurantrans@id@mmmmmcccxxxiv{%
(Sesungguhnya Kami tatkala air naik) naik ke atas, sehingga segala sesuatu termasuk gunung-gunung dan lain-lainnya semuanya tenggelam yaitu, pada masa banjir besar (Kami bawa kalian) bapak moyang kalian, karena kalian pada zaman itu masih berada di dalam tulang sulbi mereka (ke dalam bahtera) atau perahu yang dibuat oleh Nabi Nuh. Akhirnya, selamatlah Nabi Nuh beserta orang-orang yang beriman bersamanya yang berada di dalam bahtera itu, sedangkan yang lainnya semua mati tenggelam.\qt@no{11}}%
\qt@newcmd\qurantrans@id@mmmmmcccxxxv{%
(Agar Kami jadikan peristiwa itu) atau perbuatan ini, yaitu diselamatkan-Nya orang-orang yang beriman dan ditenggelamkan-Nya orang-orang yang kafir (peringatan bagi kalian) pelajaran (dan agar diperhatikan) supaya hal itu tetap diingat (oleh telinga yang mau mendengar) mau menerima apa yang didengarnya.\qt@no{12}}%
\qt@newcmd\qurantrans@id@mmmmmcccxxxvi{%
(Maka apabila sangkakala ditiup sekali tiup) yaitu, untuk tiupan yang kedua kalinya, sebagai pemula untuk dijalankannya peradilan di antara semua makhluk.\qt@no{13}}%
\qt@newcmd\qurantrans@id@mmmmmcccxxxvii{%
(Dan diangkatlah) diangkatlah ke atas (bumi dan gunung-gunung, lalu dibenturkan keduanya) diadukan (sekali bentur.)\qt@no{14}}%
\qt@newcmd\qurantrans@id@mmmmmcccxxxviii{%
(Maka pada hari itu terjadilah hari kiamat) yakni hari terakhir.\qt@no{15}}%
\qt@newcmd\qurantrans@id@mmmmmcccxxxix{%
(Dan terbelahlah langit, karena pada hari itu langit menjadi lemah) melemah.\qt@no{16}}%
\qt@newcmd\qurantrans@id@mmmmmcccxl{%
(Dan malaikat-malaikat) lafal al-malaku adalah bentuk jamak dari lafal malaa'ikah, artinya malaikat-malaikat (berada di penjuru-penjuru langit) berada di seantero langit. (Dan diangkatlah Arasy Rabbmu di atas mereka) oleh malaikat-malaikat tersebut (pada hari itu yang jumlahnya ada delapan malaikat) ada delapan malaikat atau delapan barisan malaikat.\qt@no{17}}%
\qt@newcmd\qurantrans@id@mmmmmcccxli{%
(Pada hari itu kalian dihadapkan) untuk menjalani hisab (tiada yang tersembunyi) dapat dibaca laa takhfaa dan laa yakhfaa (dari keadaan kalian barang sedikit pun) yaitu dari hal-hal yang kalian rahasiakan.\qt@no{18}}%
\qt@newcmd\qurantrans@id@mmmmmcccxlii{%
(Adapun orang-orang yang diberikan kepadanya kitabnya dari sebelah kanannya, maka dia berkata) kepada golongannya untuk mengetahui apa yang dia rahasiakan: ("Ambillah) terimalah (bacalah kitabku ini.") Di dalam ungkapan ini terdapat perselisihan pendapat, manakah di antara lafal haa-umu dan iqra`uu yang menjadi amil dari lafal kitabiyah ini?\qt@no{19}}%
\qt@newcmd\qurantrans@id@mmmmmcccxliii{%
("Sesungguhnya aku yakin) aku telah merasa yakin (bahwa sesungguhnya aku akan menemui hisab terhadap diriku.")\qt@no{20}}%
\qt@newcmd\qurantrans@id@mmmmmcccxliv{%
(Maka orang itu berada dalam kehidupan yang diridai) lafal raadhiyah berarti mardhiyah, artinya diridai.\qt@no{21}}%
\qt@newcmd\qurantrans@id@mmmmmcccxlv{%
(Dalam surga yang tinggi.)\qt@no{22}}%
\qt@newcmd\qurantrans@id@mmmmmcccxlvi{%
(Buah-buahannya) buah-buahan yang dipetiknya (dekat) sangat dekat yaitu dapat dicapai oleh orang yang berdiri, orang yang duduk, dan malah orang yang berbaring.\qt@no{23}}%
\qt@newcmd\qurantrans@id@mmmmmcccxlvii{%
Maka dikatakan kepada mereka: ("Makan dan minumlah dengan nyaman) lafal hanii'an berkedudukan sebagai hal, dengan sedap (disebabkan amal yang telah kalian kerjakan pada hari-hari yang telah lalu") sewaktu kalian di dunia.\qt@no{24}}%
\qt@newcmd\qurantrans@id@mmmmmcccxlviii{%
(Adapun orang-orang yang diberikan kepadanya kitabnya dari sebelah kirinya, maka dia berkata, ``Aduhai) wahai; lafal ya di sini menunjukkan makna tanbih (alangkah baiknya kiranya tidak diberikan kepadaku kitabku.)\qt@no{25}}%
\qt@newcmd\qurantrans@id@mmmmmcccxlix{%
(Dan aku tidak mengetahui apa hisab terhadap diriku.)\qt@no{26}}%
\qt@newcmd\qurantrans@id@mmmmmcccl{%
(Wahai kiranya kematian itulah) kematian di dunia (yang menyelesaikan segala sesuatu.) Yang memutuskan hidupku dan tidak akan dibangkitkan lagi.\qt@no{27}}%
\qt@newcmd\qurantrans@id@mmmmmcccli{%
(Hartaku sekali-kali tidak memberi manfaat kepadaku.)\qt@no{28}}%
\qt@newcmd\qurantrans@id@mmmmmccclii{%
(Telah hilang kekuasaanku dariku") kekuatanku dan argumentasi atau hujahku. Huruf Ha yang terdapat dalam lafal kitabiyah, hisabiyah, maliyah, dan sulthaniyah, semuanya adalah ha saktah yang tetap dibaca baik dalam keadaan Waqaf maupun dalam keadaan Washal. Demikian itu karena mengikut mushhaf imam/induk dan karena mengikut dalil naqli. Akan tetapi sekali pun demikian, ada pula sebagian ulama yang tidak membacakannya bila diwashalkan.\qt@no{29}}%
\qt@newcmd\qurantrans@id@mmmmmcccliii{%
("Peganglah dia) khithab atau perintah dalam ayat ini ditujukan kepada para malaikat penjaga neraka Jahanam (lalu belenggulah dia.") Ikatlah kedua tangannya menjadi satu dengan kepalanya ke dalam belenggu.\qt@no{30}}%
\qt@newcmd\qurantrans@id@mmmmmcccliv{%
("Kemudian ke dalam neraka Jahanam) neraka yang apinya menyala-nyala (masukkanlah dia") jebloskanlah dia ke dalamnya.\qt@no{31}}%
\qt@newcmd\qurantrans@id@mmmmmccclv{%
("Kemudian dengan rantai yang panjangnya tujuh puluh hasta) menurut ukuran hasta malaikat (belitlah dia") lilitlah dia dengan rantai itu sesudah ia dimasukkan ke dalam neraka. Huruf fa di sini tidak dapat mencegah hubungan antara fi'il dan zharaf yang mendahuluinya.\qt@no{32}}%
\qt@newcmd\qurantrans@id@mmmmmccclvi{%
("Sesungguhnya dia dahulu tidak beriman kepada Allah Yang Maha Besar.")\qt@no{33}}%
\qt@newcmd\qurantrans@id@mmmmmccclvii{%
("Dan juga dia tidak mendorong untuk memberi makan orang miskin.")\qt@no{34}}%
\qt@newcmd\qurantrans@id@mmmmmccclviii{%
(Maka tiada seorang teman pun baginya pada hari ini di sini) maksudnya, pada hari ini tiada kaum kerabat yang bermanfaat bagi dirinya.\qt@no{35}}%
\qt@newcmd\qurantrans@id@mmmmmccclix{%
(Dan tiada pula makanan sedikit pun baginya kecuali dari darah dan nanah) yaitu nanah dan darah ahli neraka, atau shadiid, yaitu nama sejenis pohon yang ada di dalam neraka.\qt@no{36}}%
\qt@newcmd\qurantrans@id@mmmmmccclx{%
(Tidak ada yang memakannya kecuali orang-orang yang berdosa) orang-orang yang kafir.\qt@no{37}}%
\qt@newcmd\qurantrans@id@mmmmmccclxi{%
(Maka) huruf laa di sini adalah huruf zaidah (Aku bersumpah dengan apa yang kalian lihat) makhluk-makhluk yang kalian lihat.\qt@no{38}}%
\qt@newcmd\qurantrans@id@mmmmmccclxii{%
(Dan dengan apa yang tidak kalian lihat) di antara makhluk-makhluk itu.\qt@no{39}}%
\qt@newcmd\qurantrans@id@mmmmmccclxiii{%
(Sesungguhnya dia) yakni Alquran itu (adalah benar-benar perkataan utusan yang mulia) yang disampaikan oleh malaikat Jibril dari Allah swt.\qt@no{40}}%
\qt@newcmd\qurantrans@id@mmmmmccclxiv{%
(Dan Alquran itu bukanlah perkataan seorang penyair. Sedikit sekali kalian beriman kepadanya.)\qt@no{41}}%
\qt@newcmd\qurantrans@id@mmmmmccclxv{%
(Dan bukan pula perkataan tukang tenung. Sedikit sekali kalian mengambil pelajaran darinya) lafal tu'minuuna pada ayat di atas dan lafal tadzakkaruuna, kedua-duanya dapat pula dibaca yu'minuuna dan yadzakkaruuna. Huruf maa-nya merupakan huruf zaidah yang berfungsi mengukuhkan makna. Makna ayat, bahwasanya mereka itu hanya beriman kepada hal-hal yang sedikit sekali, dan mereka pun hanya ingat sedikit tentang hal-hal yang didatangkan oleh Nabi saw. yaitu berupa kebaikan, silaturahmi, dan memelihara kehormatan. Maka hal-hal tersebut tiada memberi manfaat kepada mereka barang sedikit pun.\qt@no{42}}%
\qt@newcmd\qurantrans@id@mmmmmccclxvi{%
Bahkan Alquran itu (diturunkan dari Rabb semesta alam.)\qt@no{43}}%
\qt@newcmd\qurantrans@id@mmmmmccclxvii{%
(Seandainya dia mengada-adakan) yakni Nabi Muhammad (sebagian perkataan atas nama Kami) seumpamanya dia mengatakan dari Kami, padahal Kami tidak pernah mengatakannya.\qt@no{44}}%
\qt@newcmd\qurantrans@id@mmmmmccclxviii{%
(Niscaya benar-benar Kami pegang) niscaya Kami tangkap (dia) sebagai hukuman baginya (dengan kekuatan) dan kekuasaan-Ku.\qt@no{45}}%
\qt@newcmd\qurantrans@id@mmmmmccclxix{%
(Kemudian benar-benar Kami potong urat tali jantungnya) yang apabila urat itu terputus maka orang itu akan mati.\qt@no{46}}%
\qt@newcmd\qurantrans@id@mmmmmccclxx{%
(Maka sekali-kali tidak ada seorang pun dari kalian) lafal min ahadin adalah isimnya maa, sedangkan huruf min adalah huruf zaidah yang mengandung makna mengukuhkan kenafiannya. Dan lafal minkum adalah hal dari lafal ahadin (yang dapat menghalang-halangi Kami daripadanya) tiada seorang pun yang dapat mencegah-Ku daripadanya. Lafal haajiziina adalah khabar dari maa, dan ia dijamakkan karena lafal ahadan di dalam konteks nafi yang maknanya mengandung pengertian jamak. Dan dhamir yang terdapat di dalam lafal `anhu merujuk kepada Nabi saw.; yakni tiada seorang pun yang dapat mencegah Kami dari hukumannya.\qt@no{47}}%
\qt@newcmd\qurantrans@id@mmmmmccclxxi{%
(Dan sesungguhnya dia itu) Alquran itu (benar-benar suatu pelajaran bagi orang-orang yang bertakwa.)\qt@no{48}}%
\qt@newcmd\qurantrans@id@mmmmmccclxxii{%
(Dan sesungguhnya Kami benar-benar mengetahui, bahwa di antara kalian) hai manusia (ada orang-orang yang mendustakan) Alquran dan ada pula yang mempercayainya.\qt@no{49}}%
\qt@newcmd\qurantrans@id@mmmmmccclxxiii{%
(Dan sesungguhnya dia itu) Alquran itu (menjadi penyesalan bagi orang-orang kafir) di saat mereka melihat pahala yang diterima oleh orang-orang yang beriman kepadanya, dan hukuman yang diterima oleh orang-orang yang mendustakannya.\qt@no{50}}%
\qt@newcmd\qurantrans@id@mmmmmccclxxiv{%
(Dan sesungguhnya dia itu) Alquran itu (benar-benar perkara hak yang diyakini) atau keyakinan yang hak.\qt@no{51}}%
\qt@newcmd\qurantrans@id@mmmmmccclxxv{%
(Maka bertasbihlah) sucikanlah Dia (dengan menyebut nama) huruf ba di sini adalah huruf zaidah (Rabbmu Yang Maha Besar) Maha Suci Dia.\qt@no{52}}%
\qt@newcmd\qurantrans@id@mmmmmccclxxvi{%
\basmalahid (Seseorang telah meminta) yakni berdoa meminta (kedatangan azab yang akan menimpa.)\qt@no{1}}%
\qt@newcmd\qurantrans@id@mmmmmccclxxvii{%
(Untuk orang-orang kafir, yang tidak seorang pun dapat menolaknya) dia adalah Nadhr bin Haris, ia mengatakan di dalam permintaannya, sebagaimana yang disitir oleh firman-Nya, ``Ya Allah, jika betul (Alquran) ini, dialah yang benar dari sisi Engkau..." (Q.S. Al-Anfal 32)\qt@no{2}}%
\qt@newcmd\qurantrans@id@mmmmmccclxxviii{%
(Yang datang dari Allah) lafal minallaah ini berkaitan erat dengan lafal Waaqi' yang ada di akhir ayat pertama (yang mempunyai tempat-tempat naik) tempat-tempat naik bagi para malaikat, yaitu langit.\qt@no{3}}%
\qt@newcmd\qurantrans@id@mmmmmccclxxix{%
(Naiklah) dapat dibaca ta`ruju dan ya`ruju (malaikat-malaikat dan Jibril) Malaikat Jibril (kepada-Nya) kepada tempat turun bagi perintah-Nya di langit (dalam sehari) lafal fii yaumin bertaalluq kepada lafal yang tidak disebutkan, azab menimpa orang-orang kafir pada hari kiamat (yang kadarnya lima puluh ribu tahun) ini menurut apa yang dirasakan oleh orang kafir, karena penderitaan dan kesengsaraan yang mereka temui di hari itu. Adapun orang yang beriman merasakan hal itu amat pendek, bahkan lebih pendek daripada satu kali salat fardu yang dilakukan sewaktu di dunia. Demikianlah menurut keterangan yang disebutkan di dalam hadis.\qt@no{4}}%
\qt@newcmd\qurantrans@id@mmmmmccclxxx{%
(Maka bersabarlah kamu) ayat ini diturunkan sebelum ada perintah berperang (dengan sabar yang baik) sabar yang tidak disertai dengan gelisah.\qt@no{5}}%
\qt@newcmd\qurantrans@id@mmmmmccclxxxi{%
(Sesungguhnya mereka memandangnya) memandang azab itu (jauh) artinya mustahil akan terjadi.\qt@no{6}}%
\qt@newcmd\qurantrans@id@mmmmmccclxxxii{%
(Sedangkan Kami memandangnya dekat) pasti terjadi.\qt@no{7}}%
\qt@newcmd\qurantrans@id@mmmmmccclxxxiii{%
(Pada hari ketika langit) lafal ayat ini bertaalluq kepada lafal yang tidak disebutkan, yaitu azab itu terjadi pada hari ketika langit (menjadi seperti luluhan perak) seperti leburan perak.\qt@no{8}}%
\qt@newcmd\qurantrans@id@mmmmmccclxxxiv{%
(Dan gunung-gunung menjadi seperti bulu) maksudnya bagaikan bulu domba ringannya, terbawa terbang oleh angin.\qt@no{9}}%
\qt@newcmd\qurantrans@id@mmmmmccclxxxv{%
(Dan tidak ada seorang teman akrab pun menanyakan temannya) tiada karib kerabat yang menanyakan kerabatnya, karena pada hari itu masing-masing orang disibukkan oleh keadaannya sendiri.\qt@no{10}}%
\qt@newcmd\qurantrans@id@mmmmmccclxxxvi{%
(Sedangkan mereka saling melihat) sebagian teman-teman akrab itu saling melihat kepada sebagian yang lain, dan mereka saling mengenal antara yang satu dengan yang lainnya akan tetapi mereka tiada berkata barang sepatah pun. Jumlah ayat ini merupakan kalimat baru atau jumlah isti'naf. (Orang kafir ingin) ia berharap (kalau sekiranya) lafal lau di sini bermakna an, yakni bahwasanya (dia dapat menebus dirinya dari azab hari itu) dapat dibaca yaumi'idzin dan yauma'idzin (dengan anak-anaknya.)\qt@no{11}}%
\qt@newcmd\qurantrans@id@mmmmmccclxxxvii{%
(Dan istrinya) atau teman hidupnya (dan saudaranya.)\qt@no{12}}%
\qt@newcmd\qurantrans@id@mmmmmccclxxxviii{%
(Dan kaum familinya) atau famili-familinya, mereka dinamakan fashiilah karena orang yang bersangkutan terpisah hubungannya dengan mereka (yang melindunginya) yang pernah mengasuhnya.\qt@no{13}}%
\qt@newcmd\qurantrans@id@mmmmmccclxxxix{%
(Dan orang-orang di atas bumi seluruhnya, kemudian mengharapkan tebusan itu dapat menyelamatkannya) dapat membebaskannya dari azab itu. Lafal ayat ini diathafkan kepada lafal yaftadii.\qt@no{14}}%
\qt@newcmd\qurantrans@id@mmmmmcccxc{%
(Sekali-kali tidak dapat) lafal ini merupakan sanggahan terhadap apa yang dia harapkan itu (sesungguhnya neraka ini) neraka yang mereka saksikan itu (adalah api yang bergejolak) lafal lazhaa adalah nama lain dari neraka Jahanam, dinamakan demikian karena apinya bergejolak membakar orang-orang kafir.\qt@no{15}}%
\qt@newcmd\qurantrans@id@mmmmmcccxci{%
(Yang mengelupaskan kulit kepala) asy-syawaa bentuk jamak dari lafal syawaatun, artinya kulit kepala.\qt@no{16}}%
\qt@newcmd\qurantrans@id@mmmmmcccxcii{%
(Yang memanggil orang yang membelakang dan yang berpaling) dari iman; sebab neraka Jahanam itu mengatakan kepada mereka kemarilah, kemarilah.\qt@no{17}}%
\qt@newcmd\qurantrans@id@mmmmmcccxciii{%
(Serta mengumpulkan) harta (lalu menyimpannya) menaruhnya di dalam peti simpanan dan tidak menunaikan hak Allah yang ada pada harta bendanya itu.\qt@no{18}}%
\qt@newcmd\qurantrans@id@mmmmmcccxciv{%
(Sesungguhnya manusia diciptakan bersifat keluh-kesah) lafal haluu`an merupakan hal atau kata keterangan keadaan dari lafal yang tidak disebutkan, dan sekaligus sebagai penafsirnya.\qt@no{19}}%
\qt@newcmd\qurantrans@id@mmmmmcccxcv{%
(Apabila ia ditimpa kesusahan ia berkeluh kesah) atau sewaktu ia ditimpa keburukan berkeluh kesah.\qt@no{20}}%
\qt@newcmd\qurantrans@id@mmmmmcccxcvi{%
(Dan apabila ia mendapat kebaikan ia amat kikir) sewaktu ia mendapat harta benda ia kikir, tidak mau menunaikan hak Allah yang ada pada hartanya itu.\qt@no{21}}%
\qt@newcmd\qurantrans@id@mmmmmcccxcvii{%
(Kecuali orang-orang yang mengerjakan salat) yakni, orang-orang yang beriman.\qt@no{22}}%
\qt@newcmd\qurantrans@id@mmmmmcccxcviii{%
(Yang mereka itu tetap mengerjakan salatnya) terus-menerus mengerjakannya.\qt@no{23}}%
\qt@newcmd\qurantrans@id@mmmmmcccxcix{%
(Dan orang-orang yang dalam hartanya tersedia bagian tertentu) yakni zakat.\qt@no{24}}%
\qt@newcmd\qurantrans@id@mmmmmcd{%
(Bagi orang miskin yang meminta dan orang yang tidak mempunyai apa-apa) yang tidak mau meminta-minta, demi memelihara kehormatannya sekalipun ia tidak punya.\qt@no{25}}%
\qt@newcmd\qurantrans@id@mmmmmcdi{%
(Dan orang-orang yang mempercayai hari pembalasan) yaitu, hari ketika semua orang mendapatkan balasan amal perbuatannya.\qt@no{26}}%
\qt@newcmd\qurantrans@id@mmmmmcdii{%
(Dan orang-orang yang takut terhadap azab Rabbnya) mereka takut akan azab-Nya.\qt@no{27}}%
\qt@newcmd\qurantrans@id@mmmmmcdiii{%
(Karena sesungguhnya azab Rabb mereka tidak dapat orang merasa aman) dari kedatangannya.\qt@no{28}}%
\qt@newcmd\qurantrans@id@mmmmmcdiv{%
(Dan orang-orang yang memelihara kemaluannya.)\qt@no{29}}%
\qt@newcmd\qurantrans@id@mmmmmcdv{%
(Kecuali terhadap istri-istri mereka atau budak-budak yang mereka miliki) yakni budak-budak perempuan (maka sesungguhnya mereka dalam hal ini tidak tercela.)\qt@no{30}}%
\qt@newcmd\qurantrans@id@mmmmmcdvi{%
(Barang siapa mencari yang di balik itu, maka mereka itulah orang-orang yang melampaui batas) melanggar batas kehalalan menuju kepada keharaman.\qt@no{31}}%
\qt@newcmd\qurantrans@id@mmmmmcdvii{%
(Dan orang-orang yang terhadap amanat-amanat mereka) menurut suatu qiraat lafal amaanaatihim dibaca dalam bentuk mufrad atau tunggal, sehingga bacaannya menjadi amaanatihim, yakni perkara agama dan duniawi yang dipercayakan kepadanya untuk menunaikannya (dan janji mereka) yang telah diambil dari mereka dalam hal tersebut (mereka memeliharanya) benar-benar menjaganya.\qt@no{32}}%
\qt@newcmd\qurantrans@id@mmmmmcdviii{%
(Dan orang-orang yang terhadap kesaksiannya) menurut suatu qiraat dibaca dalam bentuk jamak, sehingga bacaannya menjadi syahaadaatihim (mereka menunaikannya) mereka menegakkannya dan tidak menyembunyikannya.\qt@no{33}}%
\qt@newcmd\qurantrans@id@mmmmmcdix{%
(Dan orang-orang yang memelihara salatnya) yaitu dengan mengerjakan pada waktunya.\qt@no{34}}%
\qt@newcmd\qurantrans@id@mmmmmcdx{%
(Mereka itu dimasukkan ke dalam surga lagi dimuliakan.)\qt@no{35}}%
\qt@newcmd\qurantrans@id@mmmmmcdxi{%
(Mengapakah orang-orang kami itu ke arahmu) menuju kepadamu (dengan bersegera) lafal muhthi`iina berkedudukan sebagai hal atau kata keterangan keadaan, yakni mereka selalu menatapkan pandangannya ke arahmu secara terus-menerus.\qt@no{36}}%
\qt@newcmd\qurantrans@id@mmmmmcdxii{%
(Dari kanan dan dari kiri) dari sebelah kananmu dan sebelah kirimu (dengan berkelompok-kelompok) secara bergerombol dan membentuk lingkaran di sekitarmu. Mereka berbuat demikian seraya mengatakan dengan nada mengejek, ``Sungguh jika mereka, yakni orang-orang yang beriman, masuk ke dalam surga, niscaya kami benar-benar akan masuk ke dalamnya sebelum mereka." Maka Allah berfirman:\qt@no{37}}%
\qt@newcmd\qurantrans@id@mmmmmcdxiii{%
("Adakah setiap orang dari orang-orang kafir itu ingin masuk ke dalam surga yang penuh dengan kenikmatan?")\qt@no{38}}%
\qt@newcmd\qurantrans@id@mmmmmcdxiv{%
(Sekali-kali tidak!) kalimat ini merupakan sanggahan terhadap mereka yang ingin masuk surga, padahal mereka kafir. (Sesungguhnya Kami ciptakan mereka) sama dengan selain mereka (dari apa yang mereka ketahui) yakni dari air mani; maka tidak cukup hanya dengan itu mereka mengharapkan surga, karena sesungguhnya surga itu hanya dapat diharapkan bagi orang-orang yang bertakwa.\qt@no{39}}%
\qt@newcmd\qurantrans@id@mmmmmcdxv{%
(Maka) huruf laa di sini adalah huruf zaidah (Aku bersumpah dengan nama Rabb yang memiliki arah timur dan arah barat) yang memiliki matahari, bulan dan bintang-bintang lainnya (sesungguhnya Kami benar-benar Maha Kuasa.)\qt@no{40}}%
\qt@newcmd\qurantrans@id@mmmmmcdxvi{%
(Untuk mengganti) mereka (dengan kaum yang lebih baik dari mereka, dan sekali-kali Kami tidak dapat dikalahkan) tidak ada yang dapat mengalahkan Kami dalam hal ini.\qt@no{41}}%
\qt@newcmd\qurantrans@id@mmmmmcdxvii{%
(Maka biarkanlah mereka) tinggalkanlah mereka (tenggelam) dalam kebatilan (dan bermain-main) dalam keduniaan (sampai mereka menjumpai) menemui (hari yang diancamkan kepada mereka) yang pada hari itu ada azab bagi mereka.\qt@no{42}}%
\qt@newcmd\qurantrans@id@mmmmmcdxviii{%
(Yaitu pada hari mereka keluar dari kubur) dari tempat-tempat mereka dikubur (dengan cepat) menuju ke padang Mahsyar tempat mereka dihimpunkan (seakan-akan mereka pergi kepada berhala-berhala) menurut suatu qiraat dibaca nushubin, artinya sesuatu yang dibangun untuk pertanda atau tugu, yang dimaksud adalah berhala-berhala (dengan cepatnya) mereka pergi dengan cepat seakan-akan pergi kepada berhala-berhala mereka.\qt@no{43}}%
\qt@newcmd\qurantrans@id@mmmmmcdxix{%
(Dalam keadaan hina) atau nista (pandangan mereka karena diliputi) diselimuti (oleh rasa hina. Itulah hari yang dahulunya diancamkan kepada mereka) lafal dzaalika menjadi mubtada, dan lafal-lafal sesudahnya berkedudukan menjadi khabarnya; makna yang dimaksud adalah hari kiamat.\qt@no{44}}%
\qt@newcmd\qurantrans@id@mmmmmcdxx{%
\basmalahid (Sesungguhnya Kami telah mengutus Nuh kepada kaumnya, dengan memerintahkan, berilah peringatan) dengan memperingatkan (kepada kaummu sebelum datang kepada mereka) jika mereka tetap tidak mau beriman (azab yang pedih) siksaan yang menyakitkan di dunia dan akhirat.\qt@no{1}}%
\qt@newcmd\qurantrans@id@mmmmmcdxxi{%
(Nuh berkata, ``Hai kaumku! Sesungguhnya aku adalah pemberi peringatan yang menjelaskan kepada kalian.") Jelas peringatannya.\qt@no{2}}%
\qt@newcmd\qurantrans@id@mmmmmcdxxii{%
(Yaitu hendaknya) artinya aku perintahkan kepada kalian hendaknya (kalian menyembah Allah, bertakwalah kalian kepada-Nya dan taat kepadaku.)\qt@no{3}}%
\qt@newcmd\qurantrans@id@mmmmmcdxxiii{%
(Niscaya Allah akan mengampuni sebagian dosa-dosa kalian) huruf min di sini dapat dianggap sebagai huruf zaidah, karena sesungguhnya Islam itu mengampuni semua dosa yang terjadi sebelumnya; yakni semua dosa kalian. Sebagaimana dapat pula dianggap sebagai min yang mengandung makna sebagian, hal ini karena mengecualikan hak-hak yang bersangkutan dengan orang lain (dan menangguhkan kalian) tanpa diazab (sampai kepada waktu yang ditentukan) yaitu ajal kematiannya. (Sesungguhnya ketetapan Allah) yang memutuskan untuk mengazab kalian, jika kalian tidak beriman kepada-Nya (apabila telah datang tidak dapat ditangguhkan, kalau kalian mengetahui) seandainya kalian mengetahui hal tersebut, niscaya kalian beriman kepada-Nya.\qt@no{4}}%
\qt@newcmd\qurantrans@id@mmmmmcdxxiv{%
(Nuh berkata, ``Ya Rabbku! Sesungguhnya aku telah menyeru kaumku malam dan siang) terus-menerus tanpa mengenal waktu.\qt@no{5}}%
\qt@newcmd\qurantrans@id@mmmmmcdxxv{%
(Maka seruanku itu hanyalah menambah mereka lari) dari iman.\qt@no{6}}%
\qt@newcmd\qurantrans@id@mmmmmcdxxvi{%
(Dan sesungguhnya setiap kali aku menyeru mereka, agar Engkau mengampuni mereka, mereka memasukkan anak jari mereka ke dalam telinganya) supaya mereka tidak dapat mendengar seruanku (dan menutupkan bajunya ke mukanya) supaya mereka tidak melihatku (dan mereka tetap) dalam kekafiran mereka (dan menyombongkan diri) tidak mau beriman (dengan sangat.)\qt@no{7}}%
\qt@newcmd\qurantrans@id@mmmmmcdxxvii{%
(Kemudian sesungguhnya aku telah menyeru mereka dengan terang-terangan) dengan sekuat suaraku.\qt@no{8}}%
\qt@newcmd\qurantrans@id@mmmmmcdxxviii{%
(Kemudian sesungguhnya aku telah mengeraskan kepada mereka) suaraku (dan pula telah membisikkan) suaraku atau seruanku (kepada mereka dengan sangat rahasia.)\qt@no{9}}%
\qt@newcmd\qurantrans@id@mmmmmcdxxix{%
(Maka aku katakan, ``Mohonlah ampun kepada Rabb kalian) dari kemusyrikan kalian (sesungguhnya Dia adalah Maha Pengampun.")\qt@no{10}}%
\qt@newcmd\qurantrans@id@mmmmmcdxxx{%
(Niscaya Dia akan mengirimkan hujan) pada saat itu mereka sedang mengalami kekeringan karena terlalu lama tidak ada hujan (kepada kalian dengan lebat) dengan deras.\qt@no{11}}%
\qt@newcmd\qurantrans@id@mmmmmcdxxxi{%
(Dan membanyakkan harta dan anak-anak kalian dan mengadakan untuk kalian kebun-kebun) ladang-ladang (dan mengadakan pula bagi kalian sungai-sungai) yang mengalir di dalamnya.\qt@no{12}}%
\qt@newcmd\qurantrans@id@mmmmmcdxxxii{%
(Mengapa kalian tidak mengharapkan keagungan dari Allah?) tidak mengharapkan Allah mengangkat derajat kalian, agar kalian beriman kepada-Nya.\qt@no{13}}%
\qt@newcmd\qurantrans@id@mmmmmcdxxxiii{%
(Padahal sesungguhnya Dia telah menciptakan kalian dalam beberapa tingkatan kejadian) lafal athwaaran bentuk jamak dari lafal thaurun, artinya tahap; yakni mulai dari tahap air mani terus menjadi darah kental atau alaqah, hingga menjadi manusia yang sempurna bentuknya. Dan memperhatikan kejadian makhluk-Nya seharusnya menuntun mereka iman kepada yang telah menciptakannya.\qt@no{14}}%
\qt@newcmd\qurantrans@id@mmmmmcdxxxiv{%
(Tidakkah kalian perhatikan) kalian lihat (bagaimana Allah telah menciptakan tujuh langit bertingkat-tingkat?) sebagian di antaranya berada di atas sebagian yang lain.\qt@no{15}}%
\qt@newcmd\qurantrans@id@mmmmmcdxxxv{%
(Dan Allah menciptakan padanya bulan) yaitu pada langit yang paling terdekat di antara keseluruhan langit itu (sebagai cahaya dan menjadikan matahari sebagai pelita?) yang memancarkan sinar terang yang jauh lebih kuat daripada sinar bulan.\qt@no{16}}%
\qt@newcmd\qurantrans@id@mmmmmcdxxxvi{%
(Dan Allah menumbuhkan kalian) Dia telah menciptakan kalian (dari tanah) karena Dia telah menciptakan bapak moyang kalian, yaitu Nabi Adam daripadanya (dengan sebaik-baiknya.)\qt@no{17}}%
\qt@newcmd\qurantrans@id@mmmmmcdxxxvii{%
(Kemudian Dia mengembalikan kalian ke dalam tanah) dalam keadaan terkubur di dalamnya (dan mengeluarkan kalian) dari dalamnya menjadi hidup kembali pada hari kiamat (dengan sebenar-benarnya.)\qt@no{18}}%
\qt@newcmd\qurantrans@id@mmmmmcdxxxviii{%
(Dan Allah menjadikan bagi kalian bumi sebagai hamparan) yakni dalam keadaan terhampar.\qt@no{19}}%
\qt@newcmd\qurantrans@id@mmmmmcdxxxix{%
(Supaya kalian menempuh padanya jalan-jalan) atau menempuh jalan-jalan (yang luas.") yang lebar.\qt@no{20}}%
\qt@newcmd\qurantrans@id@mmmmmcdxl{%
(Nuh berkata, ``Ya Rabbku! Sesungguhnya mereka telah mendurhakaiku, dan mereka telah mengikuti) orang-orang yang hina dan orang-orang yang miskin di antara mereka (orang-orang yang harta dan anak-anaknya tidak menambah kepadanya) maksudnya orang-orang yang rendah dan orang-orang miskin dari kalangan kaum Nabi Nuh itu, lebih senang mengikuti pemimpin-pemimpin yang diberi nikmat akan hal-hal tersebut, yakni banyak harta dan anaknya. Lafal wuldun dengan didamahkan huruf waunya dan sukun pada lamnya, atau waladun dengan difatahkan kedua-duanya; kalau bentuk yang pertama menurut suatu pendapat, bahwa itu adalah bentuk jamak dari lafal waladun. Dalam arti kata disamakan dengan wazan lafal khasyabun yang jamaknya khusybun. Menurut pendapat yang lain, lafal wuldun mempunyai arti yang sama dengan lafal waladun, karena wazannya dianggap sama dengan lafal bukhlun dan bakhiilun (melainkan kerugian belaka) yaitu keangkaramurkaan dan kekafiran.\qt@no{21}}%
\qt@newcmd\qurantrans@id@mmmmmcdxli{%
(Dan mereka melakukan tipu daya) yaitu para pemimpin mereka (yang amat besar.") Tipu daya mereka sangat besar, yaitu mereka telah mendustakan Nabi Nuh dan menyakitinya serta menyakiti orang-orang yang beriman kepadanya.\qt@no{22}}%
\qt@newcmd\qurantrans@id@mmmmmcdxlii{%
(Dan mereka berkata) kepada orang-orang yang menjadi bawahan mereka ("Jangan sekali-kali kalian meninggalkan tuhan-tuhan sesembahan kalian dan jangan pula sekali-kali kalian meninggalkan wadd) dapat dibaca waddan dan wuddan (dan jangan pula suwa', yaghuts, ya'uq dan nasr") nama-nama tersebut adalah nama-nama berhala-berhala mereka.\qt@no{23}}%
\qt@newcmd\qurantrans@id@mmmmmcdxliii{%
(Dan sesungguhnya mereka telah menyesatkan) dengan nama-nama tersebut (kebanyakan manusia) karena mereka telah memerintahkan manusia untuk menyembahnya (dan janganlah Engkau tambahkan bagi orang-orang yang lalim itu selain kesesatan) ayat ini diathafkan kepada lafal qad adhalluu, yakni merupakan doa Nabi Nuh setelah Allah mewahyukan kepadanya, bahwasanya sekali-kali tidak ada orang yang mau beriman di antara kaummu, melainkan orang-orang yang telah beriman saja.\qt@no{24}}%
\qt@newcmd\qurantrans@id@mmmmmcdxliv{%
(Disebabkan) huruf maa di sini adalah huruf shilah atau penghubung (kesalahan-kesalahan mereka) menurut suatu qiraat dibaca khathii'aatihim dengan memakai huruf hamzah sesudah huruf ya (mereka ditenggelamkan) oleh banjir besar (lalu dimasukkan ke dalam neraka) yaitu mereka diazab sesudah mereka ditenggelamkan di bawah air (maka mereka tidak dapat menemukan selain) selain daripada (Allah, seseorang pun yang menolong mereka) yang dapat melindungi mereka dari azab.\qt@no{25}}%
\qt@newcmd\qurantrans@id@mmmmmcdxlv{%
(Nuh berkata, ``Ya Rabbku! Janganlah Engkau biarkan seorang pun di antara orang-orang kafir itu tinggal di atas bumi) bertempat tinggal, makna yang dimaksud ialah jangan biarkan seorang pun di antara mereka.\qt@no{26}}%
\qt@newcmd\qurantrans@id@mmmmmcdxlvi{%
(Sesungguhnya jika Engkau biarkan mereka tinggal, niscaya mereka akan menyesatkan hamba-hamba-Mu, dan mereka tidak akan melahirkan selain anak yang berbuat maksiat lagi sangat kafir) lafal faajiran dan kaffaaran berasal dari yafjuru dan yakfuru. Nabi Nuh berdoa demikian setelah ada wahyu mengenai keadaan mereka yang telah disebutkan tadi yakni, bahwa mereka tidak akan beriman, kecuali hanya orang-orang yang telah beriman kepadanya.\qt@no{27}}%
\qt@newcmd\qurantrans@id@mmmmmcdxlvii{%
(Ya Rabbku! Ampunilah aku, ibu bapakku) kedua orang tua Nabi Nuh termasuk orang-orang yang beriman (orang yang masuk ke dalam rumahku) atau mesjidku (dengan beriman, dan semua orang yang beriman laki-laki dan perempuan) hingga hari kiamat nanti (dan janganlah Engkau tambahkan kepada orang-orang yang zalim itu selain kebinasaan.") Atau kehancuran, akhirnya mereka benar-benar dibinasakan.\qt@no{28}}%
\qt@newcmd\qurantrans@id@mmmmmcdxlviii{%
\basmalahid (Katakanlah) hai Muhammad! ("Telah diwahyukan kepadaku) maksudnya aku telah diberitahu oleh Allah melalui wahyu-Nya (bahwasanya) dhamir yang terdapat pada lafal annahu ini adalah dhamir sya'n (telah mendengarkan) bacaan Alquranku (sekumpulan jin.") yakni jin dari Nashibin; demikian itu terjadi sewaktu Nabi saw. sedang melakukan salat Subuh di lembah Nakhlah, yang terletak di tengah-tengah antara Mekah dan Thaif. Jin itulah yang disebutkan di dalam firman-Nya, ``Dan (ingatlah) ketika Kami hadapkan serombongan jin kepadamu." (Q.S. Al-Ahqaf 29) (lalu mereka berkata) kepada kaum mereka setelah mereka kembali kepada kaumnya: ("Sesungguhnya kami telah mendengarkan Alquran yang menakjubkan) artinya mereka takjub akan kefasihan bahasanya dan kepadatan makna-makna yang dikandungnya, serta hal-hal lainnya.\qt@no{1}}%
\qt@newcmd\qurantrans@id@mmmmmcdxlix{%
(Yang memberi petunjuk kepada jalan yang benar) yaitu kepada keimanan dan kebenaran (lalu kami beriman kepadanya. Dan kami sekali-kali tidak akan mempersekutukan) sesudah hari ini (seorang pun dengan Rabb kami.)\qt@no{2}}%
\qt@newcmd\qurantrans@id@mmmmmcdl{%
(Dan bahwasanya) dhamir yang terdapat pada ayat ini adalah dhamir sya'n, demikian pula pada dua tempat lain sesudahnya (Maha Tinggi Kebesaran Rabb kami) Maha Suci kebesaran dan keagungan-Nya dari apa-apa yang dinisbatkan kepada-Nya (Dia tidak beristri) tidak mempunyai istri (dan tidak pula beranak.)\qt@no{3}}%
\qt@newcmd\qurantrans@id@mmmmmcdli{%
(Dan bahwasanya orang yang kurang akal daripada kami selalu mengatakan) maksudnya orang yang bodoh di antara kami (perkataan yang melampaui batas terhadap Allah) dusta yang berlebihan, yaitu dengan menyifati Allah punya istri dan anak.\qt@no{4}}%
\qt@newcmd\qurantrans@id@mmmmmcdlii{%
(Dan sesungguhnya kami mengira, bahwa) huruf an di sini adalah bentuk takhfif dari anna, yakni annahu (manusia dan jin sekali-kali tidak akan mengatakan perkataan yang dusta terhadap Allah) yakni menyifati-Nya dengan hal-hal tersebut hingga kami dapat buktikan kedustaan mereka dalam hal itu. Allah berfirman:\qt@no{5}}%
\qt@newcmd\qurantrans@id@mmmmmcdliii{%
(Dan bahwasanya ada beberapa orang laki-laki di antara manusia meminta perlindungan) memohon perlindungan (kepada beberapa laki-laki di antara jin) di dalam perjalanan mereka sewaktu mereka beristirahat di tempat yang menyeramkan, lalu masing-masing orang mengatakan, aku berlindung kepada penunggu tempat ini dari gangguan penunggu lainnya yang jahat (maka jin-jin itu menambah bagi mereka) dengan permintaan perlindungannya kepada jin-jin itu (dosa dan kesalahan) karena mereka mengatakan, bahwa kami telah dilindungi oleh jin anu dan orang anu.\qt@no{6}}%
\qt@newcmd\qurantrans@id@mmmmmcdliv{%
(Dan sesungguhnya mereka) yakni jin-jin itu (menyangka sebagaimana sangkaan kalian) hai manusia (bahwa) bentuk takhfif dari anna, asalnya annahu (Allah sekali-kali tidak akan membangkitkan seorang pun.") sesudah matinya.\qt@no{7}}%
\qt@newcmd\qurantrans@id@mmmmmcdlv{%
Jin mengatakan: ("Dan sesungguhnya kami telah mencoba menyentuh langit) maksudnya kami telah bermaksud untuk mencuri pendengaran di langit (maka kami menjumpainya penuh dengan penjaga) para malaikat (yang kuat dan panah-panah api) yakni bintang-bintang yang membakar; hal ini terjadi setelah Nabi saw. diutus menjadi rasul.\qt@no{8}}%
\qt@newcmd\qurantrans@id@mmmmmcdlvi{%
(Dan sesungguhnya kami dahulu) sebelum Nabi saw. diutus (dapat menduduki beberapa tempat di langit itu untuk mendengar-dengarkan) berita-beritanya dan untuk mencurinya. (Tetapi sekarang barang siapa yang mencoba mendengar-dengarkan, seperti itu, tentu akan menjumpai panah api yang mengintai) panah-panah api yang terdiri dari meteor-meteor itu telah mengintainya dalam keadaan siap untuk memburunya.\qt@no{9}}%
\qt@newcmd\qurantrans@id@mmmmmcdlvii{%
(Dan sesungguhnya kami tidak mengetahui apakah keburukan yang dikehendaki) sesudah terjaganya langit dari pencurian pendengaran (bagi orang yang di bumi ataukah Rabb mereka menghendaki kebaikan bagi mereka) lafal rasyadan artinya khairan, yaitu kebaikan.\qt@no{10}}%
\qt@newcmd\qurantrans@id@mmmmmcdlviii{%
(Dan sesungguhnya di antara kami ada orang-orang yang saleh) sesudah mendengarkan Alquran ini (dan di antara kami ada pula yang tidak demikian halnya) ada kaum yang tidak saleh. (Adalah kami menempuh jalan yang berbeda-beda) terdiri dari golongan yang berbeda-beda; ada yang muslim dan ada pula yang kafir.\qt@no{11}}%
\qt@newcmd\qurantrans@id@mmmmmcdlix{%
(Dan sesungguhnya kami yakin, bahwa) huruf an ini adalah bentuk takhfif dari anna, asalnya annahu (kami sekali-kali tidak akan dapat melepaskan diri, dari kekuasaan, Allah di muka bumi, dan sekali-kali tidak pula dapat melepaskan diri daripada-Nya dengan lari) maksudnya, kami tidak akan dapat menyelamatkan diri daripada-Nya, apakah kami berada di bumi atau kami lari dari bumi menuju ke langit.\qt@no{12}}%
\qt@newcmd\qurantrans@id@mmmmmcdlx{%
(Dan sesungguhnya kami tatkala mendengar petunjuk) yakni Alquran (kami beriman kepadanya. Barang siapa beriman kepada Rabbnya, maka ia tidak usah takut) sesudah lafal yakhaafu diperkirakan adanya lafal huwa (akan kekurangan) pengurangan pahala kebaikannya (dan tidak pula takut akan dizalimi) diperlakukan secara zalim, yaitu dengan penambahan kesalahan dan dosanya.\qt@no{13}}%
\qt@newcmd\qurantrans@id@mmmmmcdlxi{%
(Dan sesungguhnya di antara kami ada orang-orang yang taat dan ada pula orang-orang yang menyimpang dari kebenaran) yakni melewati batas disebabkan kekafiran mereka. (Barang siapa yang taat, maka mereka itu benar-benar telah memilih jalan petunjuk) atau menuju ke jalan hidayah.\qt@no{14}}%
\qt@newcmd\qurantrans@id@mmmmmcdlxii{%
(Adapun orang-orang yang menyimpang dari kebenaran, maka mereka menjadi kayu api bagi neraka Jahanam.") atau sebagai bahan bakarnya. Dhamir anna dan annahum serta annahu yang terdapat pada dua belas tempat kembali kepada jin. Dan firman-Nya, ``Wa innaa minnal muslimuuna wa minnal qaasithuuna," dibaca kasrah huruf hamzahnya, yaitu innaa berarti merupakan jumlah isti'naf atau kalimat baru. Jika dibaca fathah yaitu menjadi anna berarti kedudukannya disamakan dengan kalimat-kalimat sebelumnya.\qt@no{15}}%
\qt@newcmd\qurantrans@id@mmmmmcdlxiii{%
Allah swt. berfirman mengenai orang-orang kafir Mekah: (Dan bahwasanya) mereka; adalah bentuk takhfif dari anna, sedangkan isimnya tidak disebutkan, yakni annahum, artinya, bahwasanya mereka; diathafkan kepada lafal annahus tama`a (jika mereka tetap berjalan lurus di atas jalan itu) yaitu agama Islam (benar-benar Kami akan memberi minum kepada mereka air yang banyak) dari langit. Demikian itu setelah hujan dihentikan dari mereka selama tujuh tahun.\qt@no{16}}%
\qt@newcmd\qurantrans@id@mmmmmcdlxiv{%
(Untuk Kami beri cobaan kepada mereka) untuk Kami uji mereka (dengan melaluinya) hingga Kami mengetahui bagaimana kesyukuran mereka, dengan pengetahuan yang nyata. (Dan barang siapa yang berpaling dari peringatan Rabbnya) yakni Alquran (niscaya Kami akan memasukkannya) (ke dalam azab yang amat berat.)\qt@no{17}}%
\qt@newcmd\qurantrans@id@mmmmmcdlxv{%
(Dan sesungguhnya mesjid-mesjid itu) atau tempat-tempat salat itu (adalah kepunyaan Allah. Maka janganlah kalian menyembah) di dalamnya (seseorang pun di samping Allah) seumpamanya kalian berbuat kemusyrikan di dalamnya, sebagaimana yang telah dilakukan oleh orang-orang Yahudi dan orang-orang Nasrani, yaitu apabila mereka memasuki gereja dan sinagog mereka, maka mereka menyekutukan-Nya.\qt@no{18}}%
\qt@newcmd\qurantrans@id@mmmmmcdlxvi{%
(Dan bahwasanya) dapat dibaca annahu dan innahu; juga merupakan kalimat baru, sedangkan dhamir yang ada ialah dhamir sya'n (tatkala hamba Allah berdiri) yakni Nabi Muhammad saw. (menyembah-Nya) beribadah kepada-Nya di lembah Nakhl (hampir saja mereka) yakni jin-jin yang mendengarkan bacaan Alquran itu (desak-mendesak mengerumuninya) yaitu sebagian di antara mereka menindih sebagian yang lain berjejal-jejal karena keinginan mereka yang sangat untuk mendengarkan bacaan Alquran. Lafal libadan dapat pula dibaca lubadan; dan merupakan bentuk jamak dari lubdatun.\qt@no{19}}%
\qt@newcmd\qurantrans@id@mmmmmcdlxvii{%
(Berkatalah dia) Nabi Muhammad berkata sebagai jawabannya terhadap orang-orang kafir yang mengatakan kepadanya, kembalilah kamu dari apa yang kamu lakukan sekarang ini. Akan tetapi menurut qiraat yang lain lafal qaala dibaca qul, artinya katakanlah: ("Sesungguhnya aku hanya menyembah Rabbku) sebagai Tuhanku (dan aku tidak mempersekutukan sesuatu pun dengan-Nya.")\qt@no{20}}%
\qt@newcmd\qurantrans@id@mmmmmcdlxviii{%
(Katakanlah, ``Sesungguhnya aku tidak kuasa untuk mendatangkan sesuatu kemudaratan pun kepada kalian) atau keburukan (dan tidak pula sesuatu kemanfaatan.") Atau kebaikan.\qt@no{21}}%
\qt@newcmd\qurantrans@id@mmmmmcdlxix{%
(Katakanlah, ``Sesungguhnya aku sekali-kali tiada yang dapat melindungiku dari Allah) dari azab-Nya jika aku mendurhakai-Nya (seseorang pun, dan sekali-kali aku tiada akan memperoleh selain dari-Nya) atau selain-Nya (tempat untuk berlindung) maksudnya, tempat aku berlindung.\qt@no{22}}%
\qt@newcmd\qurantrans@id@mmmmmcdlxx{%
(Akan tetapi, aku hanya, menyampaikan peringatan) makna yang dikandung dalam lafal ini merupakan pengecualian atau istitsna dari maf'ul atau objek yang terdapat di dalam lafal amliku. Yakni aku tiada memiliki bagi kalian selain hanya menyampaikan peringatan (dari Allah) yang aku terima dari-Nya (dan risalah-Nya) lafal ini diathafkan kepada lafal balaaghan dan lafal-lafal yang terdapat di antara mustatsna minhu dan istitsna merupakan jumlah mu`taridhah atau kalimat sisipan yang berfungsi untuk mengukuhkan makna tiada memiliki. (Dan barang siapa yang mendurhakai Allah dan Rasul-Nya) dalam hal ketauhidan, lalu ia tidak beriman (maka sesungguhnya baginya neraka Jahanam, mereka kekal) lafal khaalidiina adalah hal atau kata keterangan keadaan dari dhamir man. Sehubungan dengan lafal lahuu dhamir yang ada padanya adalah untuk menyesuaikan maknanya dengan lafal man. Lafal khaalidiina ini merupakan hal dari lafal yang tidak disebutkan, lengkapnya mereka memasukinya dalam keadaan pasti kekal (di dalamnya untuk selama-lamanya.)\qt@no{23}}%
\qt@newcmd\qurantrans@id@mmmmmcdlxxi{%
(Sehingga apabila mereka melihat) lafal hattaa di sini mengandung makna ibtidaiyah atau permulaan, dan sekaligus mengandung makna ghayah atau tujuan terakhir dari lafal yang diperkirakan sebelumnya; lengkapnya, mereka masih tetap berada di dalam kekafirannya sehingga mereka melihat (apa yang diancamkan kepada mereka) yaitu azab (maka mereka akan mengetahui) manakala azab itu datang menimpa mereka, yaitu dalam perang Badar atau pada hari kiamat nanti (siapakah yang lebih lemah penolongnya dan lebih sedikit bilangannya.") maksudnya pembantu-pembantunya, apakah mereka ataukah orang-orang mukmin; penafsiran ini menurut pendapat yang pertama, yaitu dalam perang Badar. Aku ataukah mereka; penafsiran ini berdasarkan pendapat yang kedua, yaitu pada hari kiamat nanti. Sebagian di antara mereka, atau di antara orang-orang kafir itu ada yang bertanya, kapankah datangnya ancaman yang dijanjikan itu? Kemudian turunlah firman selanjutnya, yaitu:\qt@no{24}}%
\qt@newcmd\qurantrans@id@mmmmmcdlxxii{%
(Katakanlah, ``Tiadalah) tidaklah (aku mengetahui apa yang diancamkan kepada kalian itu dekat) artinya, apakah azab itu dekat (ataukah Rabbku menjadikan bagi kedatangannya masa yang panjang?) Yang tidak diketahui oleh siapa pun kecuali hanya Dia.\qt@no{25}}%
\qt@newcmd\qurantrans@id@mmmmmcdlxxiii{%
(Dia adalah Tuhan Yang Mengetahui yang gaib) mengetahui semua hal yang gaib di mata hamba-hamba-Nya (maka Dia tidak memperlihatkan) tidak menampakkan (kepada seorang pun tentang yang gaib itu) di antara manusia ini.\qt@no{26}}%
\qt@newcmd\qurantrans@id@mmmmmcdlxxiv{%
(Kecuali kepada rasul yang diridai-Nya, maka sesungguhnya Dia) di samping Dia memperhatikan hal yang gaib kepada Rasul-Nya sesuai dengan apa yang dikehendaki-Nya sebagai mukjizat bagi rasul itu (mengadakan) menjadikan dan memberlakukan (di muka) rasul itu (dan di belakangnya penjaga-penjaga) yang terdiri dari malaikat-malaikat untuk menjaganya, hingga rasul itu dapat menyampaikan hal tersebut, di antara sejumlah wahyu-wahyu-Nya kepada manusia.\qt@no{27}}%
\qt@newcmd\qurantrans@id@mmmmmcdlxxv{%
(Supaya Dia mengetahui) yakni supaya Allah menampakkan (bahwa) adalah bentuk takhfif dari anna. (sesungguhnya mereka itu telah menyampaikan) yakni rasul-rasul itu (risalah-risalah Rabbnya) di sini dipakai dhamir hum karena memandang segi makna yang terkandung di dalam lafal man (sedangkan, sebenarnya, ilmu-Nya meliputi apa yang ada pada mereka) diathafkan kepada lafal yang tidak disebutkan, lengkapnya ilmu mengenai hal tersebut telah diliputi oleh ilmu-Nya (dan Dia menghitung segala sesuatu satu per satu.") lafal `adadan adalah tamyiz yang mengganti kedudukan maf`ulnya, asalnya ialah ``ahshaa `adada kulli syai'in," yakni Dia telah menghitung bilangan segala sesuatu.\qt@no{28}}%
\qt@newcmd\qurantrans@id@mmmmmcdlxxvi{%
\basmalahid (Hai orang yang berselimut) yakni Nabi Muhammad. Asal kata al-muzzammil ialah al-mutazammil, kemudian huruf ta diidghamkan kepada huruf za sehingga jadilah al-muzzammil, artinya, orang yang menyelimuti dirinya dengan pakaian sewaktu wahyu datang kepadanya karena merasa takut akan kehebatan wahyu itu.\qt@no{1}}%
\qt@newcmd\qurantrans@id@mmmmmcdlxxvii{%
(Bangunlah di malam hari) maksudnya, salatlah di malam hari (kecuali sedikit.)\qt@no{2}}%
\qt@newcmd\qurantrans@id@mmmmmcdlxxviii{%
(Yaitu seperduanya) menjadi badal dari lafal qaliilan; pengertian sedikit ini bila dibandingkan dengan keseluruhan waktu malam hari (atau kurangilah daripadanya) dari seperdua itu (sedikit) hingga mencapai sepertiganya.\qt@no{3}}%
\qt@newcmd\qurantrans@id@mmmmmcdlxxix{%
(Atau lebih dari seperdua) hingga mencapai dua pertiganya; pengertian yang terkandung di dalam lafal au menunjukkan makna boleh memilih. (Dan bacalah Alquran itu) mantapkanlah bacaannya (dengan perlahan-lahan.)\qt@no{4}}%
\qt@newcmd\qurantrans@id@mmmmmcdlxxx{%
(Sesungguhnya Kami akan menurunkan kepadamu perkataan) atau bacaan Alquran (yang berat) yang hebat. Dikatakan berat mengingat kewajiban-kewajiban yang terkandung di dalamnya.\qt@no{5}}%
\qt@newcmd\qurantrans@id@mmmmmcdlxxxi{%
(Sesungguhnya bangun di waktu malam) maksudnya, melakukan salat sunah di malam hari sesudah tidur (lebih tepat) untuk khusyuk di dalam memahami bacaan Alquran (dan bacaan di waktu itu lebih berkesan) lebih jelas dan lebih mantap serta lebih berkesan.\qt@no{6}}%
\qt@newcmd\qurantrans@id@mmmmmcdlxxxii{%
(Sesungguhnya kamu pada siang hari mempunyai urusan yang panjang) mempunyai banyak kesibukan, sehingga kamu tidak mempunyai cukup waktu untuk banyak membaca Alquran.\qt@no{7}}%
\qt@newcmd\qurantrans@id@mmmmmcdlxxxiii{%
(Sebutlah nama Rabbmu) katakanlah bismillahirrahmanirrahiim di awal bacaan Alquranmu (dan curahkanlah) kerahkanlah dirimu (untuk beribadat kepada-Nya dengan ketekunan yang penuh) lafal tabtiilan ini adalah mashdar dari lafal batula, sengaja didatangkan demi untuk memelihara fawashil, dan merupakan lafal yang berakar dari lafal tabattul.\qt@no{8}}%
\qt@newcmd\qurantrans@id@mmmmmcdlxxxiv{%
Dialah (Rabb masyriq dan magrib, tiada Tuhan melainkan Dia, maka ambillah Dia sebagai pelindung) artinya serahkanlah semua urusan-urusanmu di bawah perlindungan-Nya.\qt@no{9}}%
\qt@newcmd\qurantrans@id@mmmmmcdlxxxv{%
(Dan bersabarlah terhadap apa yang mereka ucapkan) bersabarlah kamu di dalam menghadapi gangguan orang-orang kafir Mekah (dan jauhilah mereka dengan cara yang baik) tanpa keluh-kesah; ayat ini diturunkan sebelum ada perintah memerangi mereka.\qt@no{10}}%
\qt@newcmd\qurantrans@id@mmmmmcdlxxxvi{%
(Dan biarkanlah Aku) maksudnya biar Aku saja yang bertindak (terhadap orang-orang yang mendustakan itu) lafal al-mukadzdzibiin diathafkan kepada maf`ul atau kepada maf'ul ma`ah. Maknanya Akulah yang akan bertindak terhadap mereka; mereka adalah pemimpin-pemimpin kaum Quraisy (orang-orang yang mempunyai kemewahan) kemewahan hidup (dan beri tangguhlah mereka barang sebentar) dalam jangka waktu yang tidak lama, dan ternyata selang beberapa waktu kemudian, akhirnya mereka mati terbunuh dalam perang Badar.\qt@no{11}}%
\qt@newcmd\qurantrans@id@mmmmmcdlxxxvii{%
(Karena sesungguhnya pada sisi Kami ada belenggu-belenggu) merupakan bentuk jamak dari lafal niklun, artinya belenggu-belenggu yang berat (dan neraka Jahim) yaitu neraka yang apinya sangat membakar.\qt@no{12}}%
\qt@newcmd\qurantrans@id@mmmmmcdlxxxviii{%
(Dan makanan yang menyumbat di kerongkongan) mengganjal di kerongkongan, itu adalah buah pohon zaqum atau buah pohon dhari' atau buah pohon ghislin atau berupa duri api, apabila dimakan tidak dapat dikeluarkan dan pula tidak dapat masuk ke dalam perut (dan azab yang pedih) di samping azab yang telah disebutkan tadi, hal ini disediakan bagi orang-orang yang mendustakan Nabi saw.\qt@no{13}}%
\qt@newcmd\qurantrans@id@mmmmmcdlxxxix{%
(Pada hari berguncang) karena gempa yang dahsyat (bumi dan gunung-gunung, dan menjadilah gunung-gunung itu tumpukan-tumpukan) tumpukan-tumpukan pasir (yang beterbangan) menjadi debu yang beterbangan yang pada sebelumnya kokoh bersatu. Lafal mahiilan berasal dari lafal haala, yahiilu; bentuk asalnya adalah mahyuulun, kemudian karena mengingat harakat dhammah dianggap berat atas huruf ya, maka dipindahkan kepada huruf ha, sehingga jadilah mahuwylun. Kemudian huruf wawu dibuang karena mengingat kedudukannya yang zaidah, sehingga jadilah mahuylun, selanjutnya harakat damah diganti menjadi kasrah untuk menyesuaikannya dengan huruf ya, sehingga jadilah mahiilun.\qt@no{14}}%
\qt@newcmd\qurantrans@id@mmmmmcdxc{%
(Sesungguhnya Kami telah mengutus kepada kalian) hai penduduk Mekah (seorang rasul) yakni Nabi Muhammad saw. (yang menjadi saksi terhadap kalian) kelak di hari kiamat, tentang kedurhakaan-kedurhakaan yang telah kalian kerjakan (sebagaimana Kami telah mengutus, dahulu, seorang rasul kepada Firaun) yakni Nabi Musa a.s.\qt@no{15}}%
\qt@newcmd\qurantrans@id@mmmmmcdxci{%
(Maka Firaun mendurhakai rasul itu, lalu Kami siksa dia dengan siksaan yang berat) atau azab yang keras.\qt@no{16}}%
\qt@newcmd\qurantrans@id@mmmmmcdxcii{%
(Maka bagaimanakah kalian dapat memelihara diri kalian jika tetap kafir) di dunia (kepada hari) lafal yauman menjadi maf'ul kedua dari lafal tattaquuna. Yakni memelihara diri dari azab hari itu. Atau dengan kata lain, dengan benteng apakah kalian memelihara diri dari azab pada hari itu (yang menjadikan anak-anak beruban) lafal syiiban bentuk jamak dari lafal asyyab; dikatakan anak-anak beruban, sebagai gambaran tentang hari itu yang penuh dengan kengerian yang sangat mencekam; hari yang dimaksud adalah hari kiamat. Bentuk asal lafal syiiban adalah syuyban, dengan memakai harakat damah pada huruf syin. Kemudian harakat itu diganti menjadi kasrah demi untuk menyelaraskannya dengan huruf ya yang jatuh sesudahnya, sehingga jadilah syiiban. Dikatakan di dalam menggambarkan hari yang penuh dengan malapetaka, yaumun yusyiibu nawaashial athfaali, yakni hari yang dapat membuat ubun-ubun anak-anak beruban. Ungkapan ini adalah ungkapan majaz atau kata kiasan. Akan tetapi boleh juga makna yang terkandung di dalam ayat ini dimaksud adalah makna hakiki bukan majazi.\qt@no{17}}%
\qt@newcmd\qurantrans@id@mmmmmcdxciii{%
(Langit pun menjadi pecah belah) menjadi retak dan pecah-pecah (pada hari itu) mengingat beratnya hari itu. (Adalah janji Dia) janji Allah swt. mengenai kedatangan hari itu (pasti terlaksana) pasti terjadi.\qt@no{18}}%
\qt@newcmd\qurantrans@id@mmmmmcdxciv{%
(Sesungguhnya ini) yaitu ayat-ayat yang memperingatkan ini (adalah suatu peringatan) suatu nasihat bagi semua makhluk. (Maka barang siapa yang menghendaki niscaya ia menempuh jalan kepada Rabbnya) menempuh jalan yang menyampaikan kepada-Nya, yaitu melalui iman dan taat kepada-Nya.\qt@no{19}}%
\qt@newcmd\qurantrans@id@mmmmmcdxcv{%
(Sesungguhnya Rabbmu mengetahui bahwasanya kamu berdiri, salat, kurang) kurang sedikit (dari dua pertiga malam, atau seperdua malam, atau sepertiganya) jika dibaca nishfihi dan tsulutsihi berarti diathafkan kepada lafal tsulutsay; dan jika dibaca nishfahu dan tsulutsahu berarti diathafkan kepada lafal adnaa. Pengertian berdiri atau melakukan salat sunat di malam hari di sini pengertiannya sama dengan apa yang terdapat di awal surah ini, yakni sesuai dengan apa yang telah diperintahkan Allah kepadanya (dan segolongan dari orang-orang yang bersama kamu) lafal ayat ini diathafkan kepada dhamir yang terkandung di dalam lafal taquumu, demikian pula sebagian orang-orang yang bersamamu. Pengathafan ini diperbolehkan sekalipun tanpa mengulangi huruf taukidnya, demikian itu karena mengingat adanya fashl atau pemisah. Makna ayat secara lengkap, dan segolongan orang-orang yang bersama kamu yang telah melakukan hal yang sama. Mereka melakukan demikian mengikuti jejak Nabi saw. sehingga disebutkan, bahwa ada di antara mereka orang-orang yang tidak menyadari berapa rakaat salat malam yang telah mereka kerjakan, dan waktu malam tinggal sebentar lagi. Sesungguhnya Nabi saw. selalu melakukan salat sunah sepanjang malam, karena demi melaksanakan perintah Allah secara hati-hati. Para sahabat mengikuti jejaknya selama satu tahun, atau lebih dari satu tahun, sehingga disebutkan bahwa telapak-telapak kaki mereka bengkak-bengkak karena terlalu banyak salat. Akhirnya Allah swt. memberikan keringanan kepada mereka. (Dan Allah menetapkan) menghitung (ukuran malam dan siang. Dia mengetahui bahwa) huruf an adalah bentuk takhfif dari anna sedangkan isimnya tidak disebutkan, asalnya ialah annahu (kalian sekali-kali tidak dapat menentukan batas waktu-waktu itu) yaitu waktu malam hari. Kalian tidak dapat melakukan salat malam sesuai dengan apa yang diwajibkan atas kalian melainkan kalian harus melakukannya sepanjang malam. Dan yang demikian itu memberatkan kalian (maka Dia mengampuni kalian) artinya, Dia mencabut kembali perintah-Nya dan memberikan keringanan kepada kalian (karena itu bacalah apa yang mudah dari Alquran) dalam salat kalian (Dia mengetahui, bahwa) huruf an adalah bentuk takhfif dari anna, lengkapnya annahu (akan ada di antara kalian orang-orang yang sakit dan orang-orang yang berjalan di muka bumi) atau melakukan perjalanan (mencari sebagian karunia Allah) dalam rangka mencari rezeki-Nya melalui berniaga dan lain-lainnya (dan orang-orang yang lain lagi, mereka berperang di jalan Allah) ketiga golongan orang-orang tersebut, amat berat bagi mereka hal-hal yang telah disebutkan tadi menyangkut salat malam. Akhirnya Allah memberikan keringanan kepada mereka, yaitu mereka diperbolehkan melakukan salat malam sebatas kemampuan masing-masing. Kemudian ayat ini dinasakh oleh ayat yang mewajibkan salat lima waktu (maka bacalah apa yang mudah dari Alquran) sebagaimana yang telah disebutkan di atas (dan dirikanlah salat) fardu (tunaikanlah zakat dan berikanlah pinjaman kepada Allah) seumpamanya kalian membelanjakan sebagian harta kalian yang bukan zakat kepada jalan kebajikan (pinjaman yang baik) yang ditunaikan dengan hati yang tulus ikhlas. (Dan kebaikan apa saja yang kalian perbuat untuk diri kalian, niscaya kalian akan memperoleh balasannya di sisi Allah sebagai balasan yang jauh lebih baik) dari apa yang telah kalian berikan. Lafal huwa adalah dhamir fashal. Lafal maa sekalipun bukan termasuk isim makrifat akan tetapi diserupakan dengan isim makrifat karena tidak menerima takrif (dan yang paling besar pahalanya. Mohonlah ampun kepada Allah, sesungguhnya Allah Maha Pengampun lagi Maha Penyayang) kepada orang-orang mukmin.\qt@no{20}}%
\qt@newcmd\qurantrans@id@mmmmmcdxcvi{%
\basmalahid (Hai orang yang berselimut!) yakni Nabi saw. Bentuk asal lafal al-muddatstsir ialah al-mutadatstsir, kemudian huruf ta diidgamkan kepada huruf dal sehingga jadilah al-Muddatstsir, artinya orang yang menyelimuti dirinya dengan pakaiannya sewaktu wahyu turun kepadanya.\qt@no{1}}%
\qt@newcmd\qurantrans@id@mmmmmcdxcvii{%
(Bangunlah, lalu berilah peringatan) maksudnya pertakutilah penduduk Mekah dengan neraka jika mereka tidak mau beriman.\qt@no{2}}%
\qt@newcmd\qurantrans@id@mmmmmcdxcviii{%
(Dan Rabbmu agungkanlah) agungkanlah Dia dari persekutuan yang diada-adakan oleh orang-orang musyrik.\qt@no{3}}%
\qt@newcmd\qurantrans@id@mmmmmcdxcix{%
(Dan pakaianmu bersihkanlah) dari najis, atau pendekkanlah pakaianmu sehingga berbeda dengan kebiasaan orang-orang Arab yang selalu menguntaikan pakaian mereka hingga menyentuh tanah di kala mereka menyombongkan diri, karena dikhawatirkan akan terkena barang yang najis.\qt@no{4}}%
\qt@newcmd\qurantrans@id@mmmmmd{%
(Dan perbuatan dosa) lafal Ar-Rujza ditafsirkan oleh Nabi saw. berhala-berhala (tinggalkanlah) hal itu untuk selama-lamanya.\qt@no{5}}%
\qt@newcmd\qurantrans@id@mmmmmdi{%
(Dan janganlah kamu memberi dengan maksud memperoleh balasan yang lebih banyak) lafal Tastaktsiru dibaca Rafa' berkedudukan sebagai Haal atau kata keterangan keadaan. Maksudnya, janganlah kamu memberi sesuatu dengan tujuan untuk memperoleh balasan yang lebih banyak dari apa yang telah kamu berikan. Hal ini khusus berlaku hanya bagi Nabi saw. karena sesungguhnya dia diperintahkan untuk mengerjakan akhlak-akhlak yang paling mulia dan pekerti yang paling baik.\qt@no{6}}%
\qt@newcmd\qurantrans@id@mmmmmdii{%
(Dan kepada Rabbmu bersabarlah) di dalam melaksanakan perintah-perintah dan menjauhi larangan-larangan-Nya.\qt@no{7}}%
\qt@newcmd\qurantrans@id@mmmmmdiii{%
(Apabila ditiup sangkakala) untuk tiupan yang kedua, guna membangkitkan manusia.\qt@no{8}}%
\qt@newcmd\qurantrans@id@mmmmmdiv{%
(Maka waktu itu) waktu peniupan sangkakala yang kedua (adalah waktu) lafal Yaumaidzin berkedudukan menjadi Badal dari lafal yang sebelumnya, dan sekaligus menjadi Mubtada. Lafal Yaumaidzin dimabnikan karena mengingat dimudhafkan kepada Isim yang Ghairu Mutamakkin. Kemudian yang menjadi Khabarnya ialah (datangnya hari yang sulit) Amil yang mempengaruhi lafal Idza adalah kalimat yang disimpulkan dari pengertian keseluruhannya. Yakni pada hari itu perkara dirasakan amat berat.\qt@no{9}}%
\qt@newcmd\qurantrans@id@mmmmmdv{%
(Bagi orang-orang kafir lagi tidak mudah) di dalam ungkapan ini terkandung pengertian, bahwa keadaan pada hari itu dirasakan amat ringan oleh orang-orang yang beriman di balik kesulitan yang dirasakan oleh orang-orang kafir.\qt@no{10}}%
\qt@newcmd\qurantrans@id@mmmmmdvi{%
(Biarkanlah Aku) artinya, serahkanlah kepada-Ku (untuk menindak orang yang Aku ciptakan) lafal Waman di'athafkan kepada Maf'ul atau kepada Maf'ul Ma'ah (dalam keadaan sendirian) menjadi Haal atau kata keterangan keadaan bagi lafal Man, atau bagi Dhamirnya yang tidak disebutkan. Maksudnya, orang yang diciptakan-Nya hanya dia sendiri, tanpa keluarga, tanpa harta benda, dia adalah Walid bin Mughirah Al-Makhzumi.\qt@no{11}}%
\qt@newcmd\qurantrans@id@mmmmmdvii{%
(Dan Aku jadikan baginya harta benda yang banyak) harta yang luas dan berlimpah, berupa tanam-tanaman, susu perahan, dan perniagaan.\qt@no{12}}%
\qt@newcmd\qurantrans@id@mmmmmdviii{%
(Dan anak-anak) yang jumlahnya sepuluh orang atau lebih (yang selalu bersama dia) di kala menyaksikan perayaan-perayaan dan kamu pun mendengar tentang persaksian mereka itu.\qt@no{13}}%
\qt@newcmd\qurantrans@id@mmmmmdix{%
(Dan Kulapangkan) Kuluaskan (baginya) kehidupan, umurnya dan anak-anak yang dimilikinya (dengan selapang-lapangnya.)\qt@no{14}}%
\qt@newcmd\qurantrans@id@mmmmmdx{%
(Kemudian dia ingin sekali supaya Aku menambahkannya.)\qt@no{15}}%
\qt@newcmd\qurantrans@id@mmmmmdxi{%
(Sekali-kali tidak) Aku tidak akan memberikan tambahan lagi kepadanya selain dari hal tersebut (karena sesungguhnya dia terhadap ayat-ayat Kami) yakni terhadap Alquran (selalu menentang) selalu melawan dan ingkar.\qt@no{16}}%
\qt@newcmd\qurantrans@id@mmmmmdxii{%
(Aku akan membebaninya) Aku akan memberatinya (mendaki pendakian yang memayahkan) yaitu kepayahan karena azab; atau gunung api yang dia daki, kemudian dia jatuh, demikianlah untuk selama-lamanya.\qt@no{17}}%
\qt@newcmd\qurantrans@id@mmmmmdxiii{%
(Sesungguhnya dia telah memikirkan) tentang apa yang dikatakannya mengenai Alquran yang ia dengar dari Nabi saw. (dan menetapkan) di dalam dirinya hal tersebut.\qt@no{18}}%
\qt@newcmd\qurantrans@id@mmmmmdxiv{%
(Maka celakalah dia) dikutuk dan diazablah dia. (Bagaimanakah dia menetapkan?) maksudnya, keadaan apakah yang telah ditetapkannya itu?\qt@no{19}}%
\qt@newcmd\qurantrans@id@mmmmmdxv{%
(Kemudian celakalah dia. Bagaimanakah dia menetapkan?)\qt@no{20}}%
\qt@newcmd\qurantrans@id@mmmmmdxvi{%
(Kemudian ia memikirkan) rencana yang ditekuninya itu, atau dia melayangkan pandangannya ke muka kaumnya.\qt@no{21}}%
\qt@newcmd\qurantrans@id@mmmmmdxvii{%
(Sesudah itu dia bermasam muka) mukanya cemberut dan suram karena merasa sempit dengan apa yang dikatakannya (dan merengut) makin bertambah masam mukanya.\qt@no{22}}%
\qt@newcmd\qurantrans@id@mmmmmdxviii{%
(Kemudian dia berpaling) dari iman (dan menyombongkan diri) sombong tidak mau mengikut Nabi saw.\qt@no{23}}%
\qt@newcmd\qurantrans@id@mmmmmdxix{%
(Lalu dia berkata) di dalam menanggapi apa yang didatangkan oleh Nabi saw. yakni Alquran ("Tiada lain) (Alquran ini hanyalah sihir yang dipelajari") maksudnya, yang diambil dari tukang-tukang sihir.\qt@no{24}}%
\qt@newcmd\qurantrans@id@mmmmmdxx{%
("Tiada lain) (ini hanyalah perkataan manusia") sama dengan apa yang dikatakan oleh orang-orang musyrik lainnya, yaitu bahwasanya Alquran ini diajarkan kepadanya oleh manusia.\qt@no{25}}%
\qt@newcmd\qurantrans@id@mmmmmdxxi{%
(Aku akan memasukkannya) akan menjerumuskannya (ke dalam Saqar) yakni neraka Jahanam.\qt@no{26}}%
\qt@newcmd\qurantrans@id@mmmmmdxxii{%
(Tahukah kamu, apakah Saqar itu?) ungkapan ini menggambarkan tentang kedahsyatannya.\qt@no{27}}%
\qt@newcmd\qurantrans@id@mmmmmdxxiii{%
(Saqar itu tidak meninggalkan dan tidak membiarkan) sedikit pun dari daging dan otot melainkan dia melahapnya habis-habisan, kemudian daging dan otot itu kembali seperti semula, lalu dilahapnya lagi, demikianlah seterusnya.\qt@no{28}}%
\qt@newcmd\qurantrans@id@mmmmmdxxiv{%
(Lagi sangat membakar kulit manusia) membakar permukaan kulit dengan cepat.\qt@no{29}}%
\qt@newcmd\qurantrans@id@mmmmmdxxv{%
(Di atasnya ada sembilan belas) malaikat yang bertugas menjaganya. Seorang di antara orang-orang kafir yang terkenal dengan kekuatan dan kekerasan tubuhnya mengatakan, ``Aku menjamin kalian untuk dapat mengalahkan tujuh belas malaikat itu, dan kalian harus menjamin aku untuk dapat mengalahkan dua malaikat lainnya." Maka Allah berfirman:\qt@no{30}}%
\qt@newcmd\qurantrans@id@mmmmmdxxvi{%
(Dan tiada Kami jadikan penjaga neraka itu melainkan malaikat) yakni mereka tidak akan dapat dilawan, tidak sebagaimana yang diduga oleh orang-orang kafir (dan tidaklah Kami menjadikan bilangan mereka) yang sembilan belas itu (melainkan untuk jadi cobaan) atau membawa kepada kesesatan (bagi orang-orang kafir) seumpamanya mereka mengatakan, mengapa jumlah malaikat-malaikat penjaga neraka itu hanya sembilan belas? (supaya menjadi yakin) menjadi tambah jelas (orang-orang yang diberi Alkitab) artinya, supaya orang-orang Yahudi yakin akan kebenaran Nabi saw. yang telah menyatakan bahwa jumlah mereka sembilan belas malaikat, dan ini sesuai dengan keterangan yang terdapat di dalam kitab mereka (dan supaya orang-orang yang beriman bertambah) yaitu, orang-orang yang beriman dari kalangan ahli kitab (imannya) kepercayaannya, karena apa yang dijelaskan oleh Nabi saw. itu sesuai dan cocok dengan keterangan yang terdapat di dalam Kitab mereka (dan supaya orang-orang yang diberi Alkitab dan orang-orang mukmin itu tidak ragu-ragu) yaitu orang-orang yang beriman bukan dari kalangan mereka; tentang bilangan malaikat-malaikat penjaga neraka itu (dan supaya orang-orang yang di dalam hatinya ada penyakit) berupa keragu-raguan; mereka berada di Madinah (dan orang-orang kafir mengatakan) yaitu orang-orang kafir Mekah: ("Apakah yang dikehendaki Allah dengan hal ini) yakni bilangan ini (sebagai suatu perumpamaan?") mereka menamakannya sebagai perumpamaan, karena hal itu amat aneh didengar oleh mereka. Lafal Matsalan berkedudukan sebagai Haal atau kata keterangan keadaan. (Demikianlah) sebagaimana disesatkan-Nya orang yang tidak mempercayai bilangan ini, dan diberi-Nya petunjuk orang yang percaya kepada-Nya (Allah membiarkan sesat orang-orang yang dikehendaki-Nya dan memberi petunjuk kepada siapa yang dikehendaki-Nya. Dan tidak ada yang mengetahui tentara Rabbmu) yaitu malaikat-malaikat tentang kekuatan dan kemampuan mereka (melainkan Dia sendiri. Dan Saqar itu tiada lain) neraka itu (hanyalah peringatan bagi manusia.)\qt@no{31}}%
\qt@newcmd\qurantrans@id@mmmmmdxxvii{%
(Ingatlah) lafal Kallaa pada ayat ini merupakan lafal yang mengandung makna Istiftah atau kata pembuka, artinya, ingatlah (demi bulan.)\qt@no{32}}%
\qt@newcmd\qurantrans@id@mmmmmdxxviii{%
(Dan malam ketika) dibaca Idzaa bukan Idz (datang) sesudah siang hari habis. Akan tetapi menurut suatu qiraat dibaca Adbara, yakni telah berlalu.\qt@no{33}}%
\qt@newcmd\qurantrans@id@mmmmmdxxix{%
(Dan subuh apabila mulai terang) mulai menampakkan sinarnya.\qt@no{34}}%
\qt@newcmd\qurantrans@id@mmmmmdxxx{%
(Sesungguhnya Saqar itu) neraka Saqar itu (adalah salah satu bencana yang amat besar) malapetaka yang paling besar.\qt@no{35}}%
\qt@newcmd\qurantrans@id@mmmmmdxxxi{%
(Sebagai ancaman) berkedudukan menjadi Haal dari lafal Ihdaa, disebutkan karena mengingat di dalamnya terkandung makna azab (bagi manusia.)\qt@no{36}}%
\qt@newcmd\qurantrans@id@mmmmmdxxxii{%
(Yaitu bagi siapa di antara kalian) lafal ayat ini berkedudukan sebagai Badal dari lafal Al-Basyar (yang berkehendak akan maju) kepada kebaikan atau surga dengan beriman (atau mundur) menuju kepada perbuatan dosa, atau neraka dengan melakukan kekafiran.\qt@no{37}}%
\qt@newcmd\qurantrans@id@mmmmmdxxxiii{%
(Tiap-tiap diri bertanggung jawab atas apa yang telah diperbuatnya) dia tergadaikan, yaitu diazab di dalam neraka disebabkan amal perbuatannya sendiri.\qt@no{38}}%
\qt@newcmd\qurantrans@id@mmmmmdxxxiv{%
(Kecuali golongan kanan) mereka adalah orang-orang yang beriman, mereka selamat dari siksa neraka, di mana mereka berada.\qt@no{39}}%
\qt@newcmd\qurantrans@id@mmmmmdxxxv{%
(Di dalam surga saling tanya-menanya) di antara sesama mereka.\qt@no{40}}%
\qt@newcmd\qurantrans@id@mmmmmdxxxvi{%
(Tentang orang-orang yang berdosa) tentang keadaan orang-orang yang berdosa, lalu mereka berkata kepada ahli neraka sesudah orang-orang yang bertauhid dikeluarkan daripadanya:\qt@no{41}}%
\qt@newcmd\qurantrans@id@mmmmmdxxxvii{%
("Apakah yang memasukkan kalian) yang menjerumuskan kalian (ke dalam Saqar?")\qt@no{42}}%
\qt@newcmd\qurantrans@id@mmmmmdxxxviii{%
(Mereka menjawab, ``Kami dahulu tidak termasuk orang-orang yang mengerjakan salat,)\qt@no{43}}%
\qt@newcmd\qurantrans@id@mmmmmdxxxix{%
(dan Kami tidak pula memberi makan orang miskin.)\qt@no{44}}%
\qt@newcmd\qurantrans@id@mmmmmdxl{%
(Dan adalah Kami tenggelam ke dalam pembicaraan) yang batil (bersama dengan orang-orang yang membicarakannya.)\qt@no{45}}%
\qt@newcmd\qurantrans@id@mmmmmdxli{%
(Dan adalah Kami mendustakan hari pembalasan) yakni hari berbangkit dan hari pembalasan.\qt@no{46}}%
\qt@newcmd\qurantrans@id@mmmmmdxlii{%
(Hingga datang kepada kami kematian") ajal kami.\qt@no{47}}%
\qt@newcmd\qurantrans@id@mmmmmdxliii{%
(Maka tidak berguna lagi bagi mereka syafaat dari orang-orang yang memberi syafaat) baik dari kalangan malaikat, para nabi atau pun orang-orang saleh. Makna yang dimaksud ialah bahwa tiada syafaat bagi mereka.\qt@no{48}}%
\qt@newcmd\qurantrans@id@mmmmmdxliv{%
(Maka mengapa) berkedudukan menjadi Mubtada (mereka) menjadi Khabar dari Mubtada, berta'alluq kepada lafal yang tidak disebutkan yang Dhamirnya dipindahkan kepadanya (berpaling dari peringatan?) lafal Mu'ridhiina menjadi Haal atau kata keterangan keadaan dari Dhamir Lahum. Makna yang dimaksud, apakah gerangan sesuatu yang terjadi pada diri mereka sehingga mereka berpaling dari peringatan?\qt@no{49}}%
\qt@newcmd\qurantrans@id@mmmmmdxlv{%
(Seakan-akan mereka itu keledai liar yang lari terkejut) keledai-keledai liar yang larat.\qt@no{50}}%
\qt@newcmd\qurantrans@id@mmmmmdxlvi{%
(Lari dari singa) lari sekencang-kencangnya karena menghindar dan menyelamatkan diri dari singa.\qt@no{51}}%
\qt@newcmd\qurantrans@id@mmmmmdxlvii{%
(Bahkan tiap-tiap orang dari mereka berkehendak supaya diberikan kepadanya lembaran-lembaran yang terbuka) dari Allah swt. disebabkan mengikuti Nabi saw. Sebagaimana yang telah mereka katakan, bahwa tidak sekali-kali kami beriman kepadamu sebelum kamu menurunkan kepada kami sebuah kitab yang kami baca.\qt@no{52}}%
\qt@newcmd\qurantrans@id@mmmmmdxlviii{%
(Sekali-kali tidak) lafal ini merupakan sanggahan terhadap apa yang mereka kehendaki itu. (Sebenarnya mereka tidak takut kepada negeri akhirat) kepada azabnya.\qt@no{53}}%
\qt@newcmd\qurantrans@id@mmmmmdxlix{%
(Ingatlah) Kallaa di sini menunjukkan makna Istiftah atau kata pembukaan (sesungguhnya dia itu) Alquran itu (adalah peringatan) nasihat dan pelajaran.\qt@no{54}}%
\qt@newcmd\qurantrans@id@mmmmmdl{%
(Maka barang siapa menghendaki, niscaya dia mengambil pelajaran daripadanya) niscaya dia membacanya kemudian mengambil pelajaran daripadanya.\qt@no{55}}%
\qt@newcmd\qurantrans@id@mmmmmdli{%
(Dan mereka tidak akan mengambil pelajaran daripadanya) dapat dibaca Yadzkuruuna dan Tadzkuruuna (kecuali bila Allah menghendakinya. Dia adalah Tuhan Yang patut kita bertakwa kepada-Nya) Dia adalah yang harus ditakwai (dan berhak memberi ampun) seumpamanya Dia memberikan ampunan-Nya kepada orang-orang yang bertakwa kepada-Nya.\qt@no{56}}%
\qt@newcmd\qurantrans@id@mmmmmdlii{%
\basmalahid (Aku bersumpah dengan hari kiamat) huruf Laa di sini adalah huruf Zaidah.\qt@no{1}}%
\qt@newcmd\qurantrans@id@mmmmmdliii{%
(Dan Aku bersumpah dengan jiwa yang amat menyesali) dirinya sendiri sekalipun ia berupaya sekuat tenaga di dalam kebaikan. Jawab Qasam tidak disebutkan; lengkapnya, Aku bersumpah dengan nama hari kiamat dan dengan nama jiwa yang banyak mencela, bahwa niscaya jiwa itu pasti akan dibangkitkan. Pengertian Jawab ini ditunjukkan oleh firman selanjutnya, yaitu:\qt@no{2}}%
\qt@newcmd\qurantrans@id@mmmmmdliv{%
(Apakah manusia mengira) yakni, orang kafir (bahwa Kami tidak akan mengumpulkan kembali tulang belulangnya) untuk dibangkitkan menjadi hidup kembali.\qt@no{3}}%
\qt@newcmd\qurantrans@id@mmmmmdlv{%
(Bukan demikian) Kami akan mengumpulkannya kembali (Kami kuasa) di samping mengumpulkan kembali tulang-tulangnya itu (menyusun kembali jari-jemarinya dengan sempurna) artinya, Kami dapat mengembalikan tulang jari-jemari itu sekalipun bentuknya kecil, maka terlebih lagi tulang-tulang lainnya yang lebih besar daripadanya.\qt@no{4}}%
\qt@newcmd\qurantrans@id@mmmmmdlvi{%
(Bahkan manusia itu hendak membuat maksiat terus-menerus) huruf Lam yang ada pada lafal Liyafjura adalah Zaidah, sedangkan lafal Yafjuru dinashabkan oleh An yang diperkirakan keberadaannya. Yakni dia selalu berbuat dusta (di dalam menghadapinya) di dalam menghadapi hari kiamat. Pengertian ini ditunjukkan oleh firman selanjutnya, yaitu:\qt@no{5}}%
\qt@newcmd\qurantrans@id@mmmmmdlvii{%
(Ia bertanya, ``Bilakah) Kapan (hari kiamat itu?") pertanyaannya itu mengandung nada mengejek dan mendustakannya.\qt@no{6}}%
\qt@newcmd\qurantrans@id@mmmmmdlviii{%
(Maka apabila mata terbelalak) dapat dibaca Bariqa dan Baraqa, artinya kaget dan bimbang setelah ia melihat apa yang dahulu selalu ia dustakan.\qt@no{7}}%
\qt@newcmd\qurantrans@id@mmmmmdlix{%
(Dan apabila bulan telah hilang cahayanya) yakni menjadi gelap dan lenyap sinarnya.\qt@no{8}}%
\qt@newcmd\qurantrans@id@mmmmmdlx{%
(Dan matahari dan bulan dikumpulkan) maka kedua-duanya terbit dari arah barat; atau kedua-duanya telah hilang sinarnya, yang demikian itu terjadi pada hari kiamat.\qt@no{9}}%
\qt@newcmd\qurantrans@id@mmmmmdlxi{%
(Pada hari itu manusia berkata, ``Ke mana tempat lari?")\qt@no{10}}%
\qt@newcmd\qurantrans@id@mmmmmdlxii{%
(Sekali-kali tidak) lafal ini menunjukkan kata tolakan terhadap pencarian jalan lari. (Tidak ada tempat berlindung) tidak ada tempat mengungsi yang dapat dijadikan perlindungan baginya.\qt@no{11}}%
\qt@newcmd\qurantrans@id@mmmmmdlxiii{%
(Hanya kepada Rabbmu sajalah pada hari itu tempat kembali) bagi semua makhluk, lalu mereka dihisab dan menerima pembalasan.\qt@no{12}}%
\qt@newcmd\qurantrans@id@mmmmmdlxiv{%
(Pada hari itu diberitakan kepada manusia apa yang telah dikerjakannya dan apa yang dilalaikannya) yaitu semua amal perbuatannya dari mulai awal hingga akhir, diberitakan kepadanya.\qt@no{13}}%
\qt@newcmd\qurantrans@id@mmmmmdlxv{%
(Bahkan manusia itu menjadi saksi atas dirinya sendiri) yakni semua anggota tubuhnya memberikan kesaksian terhadap semua amal perbuatannya, sehingga ia tidak dapat mengingkarinya lagi. Huruf Ha yang ada pada lafal Bashiirah menunjukkan makna Mubalaghah.\qt@no{14}}%
\qt@newcmd\qurantrans@id@mmmmmdlxvi{%
(Meskipun dia mengemukakan alasan-alasannya) lafal Ma'aadziir bentuk jamak dari lafal Ma'dzirah, akan tetapi tidak menurut cara yang beraturan. Makna ayat, seandainya dia mengemukakan semua alasannya, niscaya alasan-alasannya itu tidak akan diterima. Allah berfirman kepada Nabi-Nya:\qt@no{15}}%
\qt@newcmd\qurantrans@id@mmmmmdlxvii{%
(Janganlah kamu gerakkan untuk membacanya) membaca Alquran, sebelum malaikat Jibril selesai daripadanya (lisanmu karena hendak cepat-cepat menguasainya) karena kamu merasa khawatir bacaannya tidak dapat kamu kuasai.\qt@no{16}}%
\qt@newcmd\qurantrans@id@mmmmmdlxviii{%
(Sesungguhnya atas tanggungan Kamilah mengumpulkannya) di dadamu, maksudnya membuat kamu dapat menghafalnya (dan bacaannya) yakni membuatmu pandai membacanya; atau membuat mudah dibaca olehmu.\qt@no{17}}%
\qt@newcmd\qurantrans@id@mmmmmdlxix{%
(Apabila Kami telah selesai membacakannya) kepada kamu melalui bacaan malaikat Jibril (maka ikutilah bacaannya itu) artinya, dengarlah dengan seksama bacaan Jibril kepadamu terlebih dahulu. Sesungguhnya Nabi saw. setelah itu mendengarkannya terlebih dahulu dengan seksama, kemudian membacanya.\qt@no{18}}%
\qt@newcmd\qurantrans@id@mmmmmdlxx{%
(Kemudian, sesungguhnya atas tanggungan Kamilah penjelasannya) dengan memberikan pemahaman mengenainya kepadamu. Kaitan atau hubungan korelasi antara ayat ini dengan ayat-ayat sebelumnya ialah bahwasanya ayat-ayat sebelumnya itu mengandung makna berpaling dari ayat-ayat Allah. Sedangkan pada ayat ini terkandung pengertian bersegera menguasai ayat-ayat Allah dengan cara menghafalnya.\qt@no{19}}%
\qt@newcmd\qurantrans@id@mmmmmdlxxi{%
(Sekali-kali jangan) lafal Kallaa menunjukkan makna Istiftah, yakni ingatlah (sebenarnya kalian mencintai kehidupan dunia) dapat dibaca Tuhibbuuna dan Yuhibbuuna, kalau dibaca Yuhibbuuna artinya, mereka mencintai kehidupan dunia.\qt@no{20}}%
\qt@newcmd\qurantrans@id@mmmmmdlxxii{%
(Dan meninggalkan kehidupan akhirat) karena itu mereka tidak beramal untuk menyambut hari akhirat.\qt@no{21}}%
\qt@newcmd\qurantrans@id@mmmmmdlxxiii{%
(Wajah-wajah pada hari itu) pada hari kiamat (ada yang berseri-seri) tampak cerah dan bercahaya.\qt@no{22}}%
\qt@newcmd\qurantrans@id@mmmmmdlxxiv{%
(Kepada Rabbnyalah mereka melihat) mereka akan melihat Allah swt. di akhirat.\qt@no{23}}%
\qt@newcmd\qurantrans@id@mmmmmdlxxv{%
(Dan wajah-wajah pada hari itu ada yang muram) tampak gelap dan sangat muram.\qt@no{24}}%
\qt@newcmd\qurantrans@id@mmmmmdlxxvi{%
(Mereka yakin) merasa yakin (bahwa akan ditimpakan kepadanya malapetaka yang amat dahsyat) bencana yang sangat besar, yang dapat meremukkan tulang-tulang punggung.\qt@no{25}}%
\qt@newcmd\qurantrans@id@mmmmmdlxxvii{%
(Sekali-kali jangan) bermakna Alaa, yakni ingatlah. (Apabila telah sampai) napas (pada tenggorokan) atau kerongkongan.\qt@no{26}}%
\qt@newcmd\qurantrans@id@mmmmmdlxxviii{%
(Dan dikatakan) kepadanya oleh yang ada di sekitarnya: ("Siapakah yang dapat mengobati?") hingga sembuh.\qt@no{27}}%
\qt@newcmd\qurantrans@id@mmmmmdlxxix{%
(Dan dia yakin) yakni orang yang napasnya telah sampai di tenggorokan itu merasa yakin akan hal tersebut (bahwa sesungguhnya itulah waktu perpisahan) yaitu meninggalkan dunia.\qt@no{28}}%
\qt@newcmd\qurantrans@id@mmmmmdlxxx{%
(Dan bertaut betis dengan betis) betis kanan dan betis kirinya bertaut ketika ia mati. Atau makna yang dimaksud ialah saling bertaut antara sakit berpisah dengan dunia dan sakit menghadapi akhirat di dalam dirinya.\qt@no{29}}%
\qt@newcmd\qurantrans@id@mmmmmdlxxxi{%
(Kepada Rabbmulah pada hari itu mereka dihalau) atau kepada-Nyalah mereka digiring; hal ini menunjukkan tentang adanya Amil dalam lafal Idzaa. Lengkapnya, apabila nyawa telah sampai di tenggorokan, maka ia akan dihalau menuju kepada keputusan Rabbnya.\qt@no{30}}%
\qt@newcmd\qurantrans@id@mmmmmdlxxxii{%
(Dan ia tidak mau membenarkan) yaitu manusia (dan tidak mau mengerjakan salat) ia tidak mau mempercayai rasul dan tidak pula mau mendirikan salat.\qt@no{31}}%
\qt@newcmd\qurantrans@id@mmmmmdlxxxiii{%
(Tetapi ia mendustakan) Alquran (dan berpaling) dari iman.\qt@no{32}}%
\qt@newcmd\qurantrans@id@mmmmmdlxxxiv{%
(Kemudian ia pergi kepada ahlinya dengan berlagak) dengan langkah-langkah yang sombong.\qt@no{33}}%
\qt@newcmd\qurantrans@id@mmmmmdlxxxv{%
(Kecelakaanlah bagimu) di dalam ungkapan kalimat ini terkandung Iltifat dari Ghaibah, kalimat ini adalah Isim Fi'il, sedangkan huruf Lamnya menunjukkan makna Tabyin, artinya: dia menyerahkan kepadamu apa-apa yang tidak kamu sukai (maka kecelakaanlah bagimu) yakni dia lebih utama untuk diprioritaskan olehmu.\qt@no{34}}%
\qt@newcmd\qurantrans@id@mmmmmdlxxxvi{%
(Kemudian kecelakaanlah bagimu dan kecelakaanlah bagimu) mengukuhkan makna ayat di atas.\qt@no{35}}%
\qt@newcmd\qurantrans@id@mmmmmdlxxxvii{%
(Apakah manusia mengira) menduga (bahwa ia akan dibiarkan begitu saja) tanpa dibebani dengan syariat-syariat; janganlah ia menduga seperti itu.\qt@no{36}}%
\qt@newcmd\qurantrans@id@mmmmmdlxxxviii{%
(Bukankah dia dahulu) sebelum itu (setetes mani yang ditumpahkan) ke dalam rahim; lafal Yumnaa dapat pula dibaca Tumnaa.\qt@no{37}}%
\qt@newcmd\qurantrans@id@mmmmmdlxxxix{%
(Kemudian adalah) mani itu (menjadi segumpal darah lalu Allah menciptakannya) dari air mani itu menjadi manusia (dan menyempurnakannya) melengkapinya dengan anggota-anggota tubuh yang diperlukannya.\qt@no{38}}%
\qt@newcmd\qurantrans@id@mmmmmdxc{%
(Lalu Allah menjadikan daripadanya) dari air mani yang telah menjadi segumpal darah, segumpal daging (sepasang) dua jenis (laki-laki dan perempuan) terkadang menjadi satu dan terkadang tersendiri.\qt@no{39}}%
\qt@newcmd\qurantrans@id@mmmmmdxci{%
(Bukankah yang berbuat demikian) yang mengerjakan kesemuanya itu (berkuasa pula menghidupkan orang mati?) Nabi saw. menjawab, tentu saja dapat.\qt@no{40}}%
\qt@newcmd\qurantrans@id@mmmmmdxcii{%
\basmalahid (Bukankah) artinya, sesungguhnya (telah datang atas manusia) Nabi Adam (satu waktu dari masa) empat puluh tahun (sedangkan dia belum merupakan) ketika itu (sesuatu yang dapat disebut) maksudnya, Nabi Adam selama empat puluh tahun masih tetap berbentuk tanah dan bukan berarti apa-apa. Atau bila yang dimaksud dengan manusia adalah jenis manusia selain dia, maka yang dimaksud dengan lafal Al-Hiin atau masa ialah masa mengandung, jadi bukan empat puluh tahun.\qt@no{1}}%
\qt@newcmd\qurantrans@id@mmmmmdxciii{%
(Sesungguhnya Kami telah menciptakan manusia) artinya, jenis manusia (dari setetes mani yang bercampur) yang bercampur dengan indung telur, yaitu air mani laki-laki bercampur menjadi satu dengan air mani perempuan (yang Kami hendak mengujinya) dengan membebankan kewajiban-kewajiban kepadanya; jumlah ayat ini merupakan jumlah Isti`naf yakni kalimat permulaan; atau dianggap sebagai Hal dari lafal yang diperkirakan. Yaitu, Kami bermaksud hendak mengujinya ketika Kami mempersiapkan kejadiannya (karena itu Kami jadikan dia) Kami menjadikan dia dapat (mendengar dan melihat.)\qt@no{2}}%
\qt@newcmd\qurantrans@id@mmmmmdxciv{%
(Sesungguhnya Kami telah menunjukinya jalan petunjuk) maksudnya, Kami telah menjelaskan kepadanya jalan hidayah dengan mengutus rasul-rasul kepada manusia (ada yang bersyukur) yaitu menjadi orang mukmin (dan ada pula yang kafir) kedua lafal ini, yakni Syaakiran dan Kafuuran merupakan Haal dari Maf'ul; yakni Kami telah menjelaskan jalan hidayah kepadanya, baik sewaktu ia dalam keadaan bersyukur atau pun sewaktu ia kafir sesuai dengan kepastian Kami. Lafal Immaa di sini menunjukkan rincian tentang keadaan.\qt@no{3}}%
\qt@newcmd\qurantrans@id@mmmmmdxcv{%
(Sesungguhnya Kami menyediakan) telah mempersiapkan (bagi orang-orang kafir rantai) untuk menyeret mereka ke dalam neraka (dan belenggu-belenggu) pada leher mereka dan rantai itu diikatkan kepadanya (serta neraka Sair) yaitu neraka yang apinya menyala-nyala dengan besarnya, tempat mereka diazab.\qt@no{4}}%
\qt@newcmd\qurantrans@id@mmmmmdxcvi{%
(Sesungguhnya orang-orang yang berbuat kebaikan) lafal Al-Abraar bentuk jamak dari lafal Barrun atau Baarrun, artinya orang-orang yang taat (mereka minum dari gelas) atau tempat minum, yang berisikan khamar. Maksudnya, mereka meminum khamar. Hal ini diungkapkan dengan memakai nama alat peminumnya. Huruf Min bermakna Tab'idh (yang campurannya) yakni khamar itu dicampur dengan (kafur.)\qt@no{5}}%
\qt@newcmd\qurantrans@id@mmmmmdxcvii{%
(Yaitu mata air) menjadi Badal dari lafal Kaafuur artinya, mata air itu berbau kafur (yang meminum daripadanya) dari mata air itu (hamba-hamba Allah) yakni kekasih-kekasih-Nya (yang mereka dapat mengalirkannya dengan sebaik-baiknya) mereka dapat mengalirkan air dari telaga itu menurut kehendaknya dari tempat-tempat tinggal mereka.\qt@no{6}}%
\qt@newcmd\qurantrans@id@mmmmmdxcviii{%
(Mereka menunaikan nazar) untuk taat kepada Allah (dan takut akan suatu hari yang azabnya merata di mana-mana) menyebar di semua tempat.\qt@no{7}}%
\qt@newcmd\qurantrans@id@mmmmmdxcix{%
(Dan mereka memberikan makanan yang disukainya) atau yang digemarinya (kepada orang miskin) atau orang fakir (anak yatim) anak yang ayahnya sudah tiada (dan orang yang ditawan) orang yang ditahan karena membela perkara yang hak.\qt@no{8}}%
\qt@newcmd\qurantrans@id@mmmmmdc{%
(Sesungguhnya kami memberi makanan kepada kalian hanyalah demi karena Allah) demi untuk mengharapkan pahala-Nya (kami tidak menghendaki balasan dari kalian dan tidak pula ucapan terima kasih) berterima kasih atas pemberian makanan itu. Apakah mereka benar-benar mengucapkan demikian ataukah hal itu telah diketahui oleh Allah swt. kemudian Allah memuji mereka. Sesungguhnya dengan masalah ini ada dua pendapat.\qt@no{9}}%
\qt@newcmd\qurantrans@id@mmmmmdci{%
(Sesungguhnya kami takut kepada Rabb kami akan suatu hari yang penuh dengan kemasaman) yaitu muka-muka pada saat itu bermuram durja dan tidak enak dipandang karena kepahitannya (lagi penuh dengan kesulitan) yakni hari itu penuh dengan penderitaan yang sangat parah.\qt@no{10}}%
\qt@newcmd\qurantrans@id@mmmmmdcii{%
(Maka Allah memelihara mereka dari kesusahan hari itu, dan memberikan kepada mereka) atau menghadiahkan kepada mereka (kejernihan) yaitu keindahan dan kecemerlangan pada wajah-wajah mereka (dan kegembiraan hati.)\qt@no{11}}%
\qt@newcmd\qurantrans@id@mmmmmdciii{%
(Dan Dia memberi balasan kepada mereka karena kesabaran mereka) disebabkan kesabaran mereka dari perbuatan maksiat (surga) yang mereka dimasukkan ke dalamnya (dan sutera) yang menjadi pakaian mereka.\qt@no{12}}%
\qt@newcmd\qurantrans@id@mmmmmdciv{%
(Seraya bersandarkan) menjadi Haal atau kata keterangan keadaan dari Isim yang dirafa'kan oleh lafal Udkhiluuha. Lafal Udkhiluuhaa ini keberadaannya diperkirakan (di dalamnya di atas dipan-dipan) atau ranjang-ranjang yang empuk (mereka tidak melihat) tidak menemukan; menjadi Haal yang kedua (di dalamnya matahari dan tidak pula dingin yang bersangatan) maksudnya, di dalam surga mereka tidak merasakan panasnya matahari yang menyengat, dan tidak pula dingin yang mencekam. Tetapi menurut suatu pendapat bahwa lafal Zamhariiran ini artinya bulan. Maknanya, surga tetap terang-benderang sekalipun tanpa matahari dan bulan.\qt@no{13}}%
\qt@newcmd\qurantrans@id@mmmmmdcv{%
(Dan dekatlah) di'athafkan secara Mahall kepada lafal Yarauna (di atas mereka) maksudnya, di antara mereka (naungannya) yaitu naungan pohon-pohon surga (dan buahnya dimudahkan memetiknya semudah-mudahnya) artinya, buah-buahannya didekatkan sehingga dapat dipetik baik oleh orang yang berdiri, atau orang yang duduk, bahkan orang yang sedang berbaring sekalipun.\qt@no{14}}%
\qt@newcmd\qurantrans@id@mmmmmdcvi{%
(Dan diedarkan kepada mereka) di dalam surga itu (bejana-bejana dari perak dan piala-piala) atau gelas-gelas yang tanpa pengikat (yang bening laksana kaca.)\qt@no{15}}%
\qt@newcmd\qurantrans@id@mmmmmdcvii{%
(Yaitu kaca-kaca dari perak) gelas-gelas dan piala-piala itu terbuat dari perak yang bagian dalamnya dapat dilihat dari luar, sehingga tampak bening sebening kaca (yang telah diukur mereka) yakni oleh pelayan-pelayan yang mengedarkannya (dengan sebaik-baiknya) sesuai dengan kecukupan minum orang-orang yang meminumnya, tidak lebih dan tidak pula kurang; cara minum yang demikian itu merupakan cara minum yang paling nikmat.\qt@no{16}}%
\qt@newcmd\qurantrans@id@mmmmmdcviii{%
(Di dalam surga itu mereka diberi minum segelas) khamar (yang campurannya) atau sesuatu yang dicampurkan ke dalam minuman itu (adalah jahe.)\qt@no{17}}%
\qt@newcmd\qurantrans@id@mmmmmdcix{%
(Yaitu dari mata air) menjadi Badal dari lafal Zanjabiilaa (yang dinamakan salsabil) yaitu air telaga itu rasanya seperti jahe yang sangat disukai oleh orang-orang Arab, dan minuman ini sangat mudah diteguknya.\qt@no{18}}%
\qt@newcmd\qurantrans@id@mmmmmdcx{%
(Dan mereka dikelilingi oleh pelayan-pelayan muda yang tetap muda) mereka sama sekali tidak akan menjadi tua. (Apabila kamu melihat mereka, kamu akan mengira mereka) karena penampilan mereka yang indah dan jumlah mereka yang menyebar dengan sangat banyaknya (mutiara yang bertaburan) dari untaiannya atau dari tempat asalnya, yang demikian itu lebih indah dibandingkan berada di tempat lain.\qt@no{19}}%
\qt@newcmd\qurantrans@id@mmmmmdcxi{%
(Dan apabila kamu melihat di sana) maksudnya, kamu diizinkan untuk melihat surga (niscaya kamu akan melihat) menjadi Jawab Syarath dari Idzaa (berbagai macam kenikmatan) yang tak dapat digambarkan (dan kerajaan yang besar) yang luas dan tak terbatas.\qt@no{20}}%
\qt@newcmd\qurantrans@id@mmmmmdcxii{%
(Pakaian luar mereka) dinashabkan karena menjadi Zharaf, dan menjadi Khabar dari Mubtada sesudahnya. Menurut qiraat lain dibaca 'Aaliyhim karena dianggap menjadi Mubtada sedangkan lafal sesudahnya menjadi Khabarnya, dan Dhamir Muttashilnya kembali kepada Ma'thuf 'Alaih (dari sutera halus) terbuat daripadanya (yang hijau) dibaca Rafa' yakni Khudhrun (dan sutera tebal) dibaca Jaar yakni Istabraqin artinya, sutera yang tebal. Yakni pakaian bagian luar mereka terbuat dari sutera halus, sedangkan bagian dalamnya terbuat dari sutera tebal. Menurut suatu qiraat dibaca Khudhrin Waistabraqun; menurut qiraat lainnya dibaca Khudhrun Waistabraqun; dan menurut suatu qiraat lain lagi dibaca Khudrin Waistabraqin (dan mereka diberi perhiasan dari gelang-gelang perak) tetapi pada ayat lainnya disebutkan terbuat dari emas; hal ini menunjukkan bahwa mereka diberi perhiasan yang terbuat dari emas dan perak secara berbarengan, tetapi terpisah-pisah (dan Rabb mereka memberikan kepada mereka minuman yang bersih) atau sangat bersih, berbeda dengan keadaan khamar di dunia.\qt@no{21}}%
\qt@newcmd\qurantrans@id@mmmmmdcxiii{%
(Sesungguhnya ini) yakni kenikmatan ini (adalah balasan untuk kalian, dan usaha kalian adalah disyukuri.)\qt@no{22}}%
\qt@newcmd\qurantrans@id@mmmmmdcxiv{%
(Sesungguhnya Kami) lafal Nahnu berfungsi mengukuhkan makna isimnya Inna, atau dianggap sebagai Dhamir Fashal (telah menurunkan Alquran kepadamu dengan berangsur-angsur) ayat ini menjadi Khabar dari Inna, yakni Kami menurunkannya secara berangsur-angsur, tidak sekaligus.\qt@no{23}}%
\qt@newcmd\qurantrans@id@mmmmmdcxv{%
(Maka bersabarlah kamu untuk melaksanakan ketetapan Rabbmu) yang dibebankan kepadamu yaitu, menyampaikan risalah-Nya (dan janganlah kamu ikuti, di antara mereka) yakni orang-orang kafir (orang yang berdosa dan orang yang kafir) yang dimaksud adalah Atabah bin Rabi'ah dan Walid bin Mughirah, kedua-duanya telah berkata kepada Nabi saw., ``Kembalilah kamu dari perkara ini dari agama Islam." Dan dapat pula diartikan setiap orang yang berdosa dan setiap orang yang kafir; makna yang dimaksud ialah janganlah kamu mengikuti ajakan dan seruan kedua jenis orang tersebut dalam keadaan bagaimana pun, yang seruannya itu mengajakmu kepada perbuatan dosa atau kekafiran.\qt@no{24}}%
\qt@newcmd\qurantrans@id@mmmmmdcxvi{%
(Dan sebutlah nama Rabbmu) di dalam salatmu (pada waktu pagi dan petang) yakni dalam salat Subuh, Zuhur dan Asar.\qt@no{25}}%
\qt@newcmd\qurantrans@id@mmmmmdcxvii{%
(Dan pada sebagian dari malam, maka sujudlah kamu kepada-Nya) artinya, dirikanlah salat Magrib dan Isyak (dan bertasbihlah kepada-Nya pada bagian yang panjang di malam hari) lakukanlah salat sunat di malam hari, sebagaimana keterangan yang telah kami sebutkan yaitu, sepertiganya atau separohnya atau dua pertiganya.\qt@no{26}}%
\qt@newcmd\qurantrans@id@mmmmmdcxviii{%
(Sesungguhnya mereka menyukai kehidupan dunia) (dan mereka tidak mempedulikan hari yang berat) yaitu hari yang penuh dengan penderitaan, yakni hari kiamat. Maksudnya, mereka tidak beramal untuk menyambut kedatangannya.\qt@no{27}}%
\qt@newcmd\qurantrans@id@mmmmmdcxix{%
(Kami telah menciptakan mereka dan menguatkan) menjadikan kuat (persendian tubuh mereka) yakni semua anggota tubuh mereka dan sendi-sendinya (apabila Kami menghendaki, Kami sungguh-sungguh mengganti) Kami menjadikan (orang-orang yang serupa dengan mereka) dalam bentuknya sebagai pengganti mereka, seumpamanya Kami membinasakan mereka terlebih dahulu (dengan sebenar-benarnya) lafal ayat ini berfungsi mengukuhkan makna yang terdapat dalam lafal Baddalnaa. lafal Idzaa berkedudukan sama dengan lafal In seperti contoh lain, yaitu: In Yasya' Yudzhibkum, artinya; Seandainya Allah menghendaki niscaya Dia membinasakan kalian. Demikian itu karena pengertian yang terkandung di dalam lafal Idzaa hanya khusus dipakai untuk sesuatu yang pasti akan terjadi, sedangkan di sini Allah swt. tidak menghendaki hal tersebut.\qt@no{28}}%
\qt@newcmd\qurantrans@id@mmmmmdcxx{%
(Sesungguhnya ini) surah ini (adalah suatu peringatan) suatu nasihat dan pelajaran bagi makhluk (maka barang siapa menghendaki niscaya dia mengambil jalan kepada Rabbnya) yakni jalan yang dapat menyampaikan dia kepada-Nya, yaitu melalui ketaatan.\qt@no{29}}%
\qt@newcmd\qurantrans@id@mmmmmdcxxi{%
(Dan kalian tidak menghendaki) dapat dibaca Tasyaa-uuna dan Yasyaa-uuna, kalau dibaca Yasyaa-uuna artinya, dan mereka tidak menghendaki untuk mengambil jalan kepada Rabbnya dengan mengerjakan ketaatan (kecuali bila dikehendaki Allah) hal tersebut. (Sesungguhnya Allah adalah Maha Mengetahui) tentang makhluk-Nya (lagi Maha Bijaksana) di dalam perbuatan-Nya.\qt@no{30}}%
\qt@newcmd\qurantrans@id@mmmmmdcxxii{%
(Dia memasukkan siapa yang dikehendaki-Nya ke dalam rahmat-Nya) yakni surga-Nya, mereka adalah orang-orang yang beriman. (Dan bagi orang-orang lalim) dinashabkan oleh Fi'il atau kata kerja yang keberadaannya diperkirakan, lengkapnya, Dia telah menyediakan bagi mereka. Pengertian ini disimpulkan dari firman berikutnya (disediakan-Nya azab yang pedih) azab yang menyakitkan; mereka adalah orang-orang kafir.\qt@no{31}}%
\qt@newcmd\qurantrans@id@mmmmmdcxxiii{%
\basmalahid (Demi angin yang bertiup sepoi-sepoi) yang bertiup secara beruntun bagaikan beruntunnya susunan rambut kuda yang satu sama lainnya saling beriring-iringan. Dinashabkan karena menjadi Haal atau kata keterangan keadaan.\qt@no{1}}%
\qt@newcmd\qurantrans@id@mmmmmdcxxiv{%
(Dan demi angin yang bertiup dengan kencang) yang bertiup sangat kencang.\qt@no{2}}%
\qt@newcmd\qurantrans@id@mmmmmdcxxv{%
(Dan demi angin yang menyebarkan rahmat) yaitu angin yang menyebarkan hujan.\qt@no{3}}%
\qt@newcmd\qurantrans@id@mmmmmdcxxvi{%
(Dan demi yang membedakan sejelas-jelasnya) maksudnya, demi ayat-ayat Alquran yang membedakan antara perkara yang hak dan perkara yang batil, serta yang membedakan antara perkara yang halal dan perkara yang haram.\qt@no{4}}%
\qt@newcmd\qurantrans@id@mmmmmdcxxvii{%
(Dan demi malaikat-malaikat yang menyampaikan peringatan) yakni malaikat-malaikat yang turun untuk menyampaikan wahyu kepada para nabi dan para rasul supaya wahyu tersebut disampaikan kepada umat-umat manusia.\qt@no{5}}%
\qt@newcmd\qurantrans@id@mmmmmdcxxviii{%
(Untuk menolak alasan-alasan atau memberi peringatan-peringatan) dari Allah swt. Menurut suatu qiraat dibaca 'Udzuran dan Nudzuran, dengan memakai harakat damah pada kedua huruf Dzalnya.\qt@no{6}}%
\qt@newcmd\qurantrans@id@mmmmmdcxxix{%
(Sesungguhnya apa yang dijanjikan kepada kalian itu) hai orang-orang kafir Mekah, yaitu mengenai hari berbangkit dan azab yang akan menimpa kalian (pasti terjadi) pasti akan terjadi.\qt@no{7}}%
\qt@newcmd\qurantrans@id@mmmmmdcxxx{%
(Maka apabila bintang-bintang telah dihapuskan) dihilangkan cahayanya.\qt@no{8}}%
\qt@newcmd\qurantrans@id@mmmmmdcxxxi{%
(Dan apabila langit dibelah) atau menjadi terbelah.\qt@no{9}}%
\qt@newcmd\qurantrans@id@mmmmmdcxxxii{%
(Dan apabila gunung-gunung telah dihancurkan) diletuskan hingga menjadi debu yang beterbangan.\qt@no{10}}%
\qt@newcmd\qurantrans@id@mmmmmdcxxxiii{%
(Dan apabila rasul-rasul telah dikumpulkan di dalam suatu waktu) memakai Wau dan Hamzah sebagai Badal daripadanya yaitu, pada satu ketika rasul-rasul akan dikumpulkan.\qt@no{11}}%
\qt@newcmd\qurantrans@id@mmmmmdcxxxiv{%
(Sampai hari kapankah) yakni hari yang besar (ditangguhkan) persaksian terhadap umat-umat mereka tentang penyampaian mereka?\qt@no{12}}%
\qt@newcmd\qurantrans@id@mmmmmdcxxxv{%
(Sampai hari keputusan) di antara semua makhluk; dari pengertian ayat inilah diambil kesimpulan bagi Jawab lafal Idzaa yakni, terjadilah keputusan di antara semua makhluk.\qt@no{13}}%
\qt@newcmd\qurantrans@id@mmmmmdcxxxvi{%
(Dan tahukah kamu apakah hari keputusan itu?) ayat ini menggambarkan tentang kengerian yang terdapat di dalam hari tersebut.\qt@no{14}}%
\qt@newcmd\qurantrans@id@mmmmmdcxxxvii{%
(Kecelakaan yang besarlah pada hari itu bagi orang-orang yang mendustakan) ayat ini mengandung makna ancaman bagi mereka yang tidak mempercayainya.\qt@no{15}}%
\qt@newcmd\qurantrans@id@mmmmmdcxxxviii{%
(Bukankah Kami telah membinasakan orang-orang yang dahulu?) disebabkan kedustaan mereka.\qt@no{16}}%
\qt@newcmd\qurantrans@id@mmmmmdcxxxix{%
(Lalu Kami iringi mereka dengan orang-orang yang datang kemudian) di antara orang-orang yang mendustakan seperti orang-orang kafir Mekah, maka Kami kelak akan membinasakan mereka pula.\qt@no{17}}%
\qt@newcmd\qurantrans@id@mmmmmdcxl{%
(Demikianlah) sebagaimana Kami lakukan terhadap orang-orang yang mendustakan (Kami berbuat terhadap orang-orang yang berdosa) artinya, Kami akan melakukan hal yang sama terhadap orang-orang yang berdosa yang kelak akan datang, yaitu Kami pasti akan membinasakan mereka.\qt@no{18}}%
\qt@newcmd\qurantrans@id@mmmmmdcxli{%
(Kecelakaan besarlah pada hari itu bagi orang-orang yang mendustakan) sebagai pengukuh terhadap ayat sebelumnya.\qt@no{19}}%
\qt@newcmd\qurantrans@id@mmmmmdcxlii{%
(Bukankah Kami menciptakan kalian dari air yang hina?) yang lemah, yaitu air mani.\qt@no{20}}%
\qt@newcmd\qurantrans@id@mmmmmdcxliii{%
(Kemudian Kami letakkan dia dalam tempat yang kokoh) tempat yang terpelihara, yaitu dalam rahim.\qt@no{21}}%
\qt@newcmd\qurantrans@id@mmmmmdcxliv{%
(Sampai waktu yang ditentukan) yaitu sampai waktu kelahirannya.\qt@no{22}}%
\qt@newcmd\qurantrans@id@mmmmmdcxlv{%
(Lalu Kami tentukan) waktu tersebut (maka sebaik-baik yang menentukan) adalah Kami.\qt@no{23}}%
\qt@newcmd\qurantrans@id@mmmmmdcxlvi{%
(Kecelakaan yang besarlah pada hari itu bagi orang-orang yang mendustakan.)\qt@no{24}}%
\qt@newcmd\qurantrans@id@mmmmmdcxlvii{%
(Bukankah Kami menjadikan bumi tempat berkumpul) lafal Kifaatan adalah Mashdar dari lafal Kafata yang artinya berkumpul atau tempat untuk berkumpul.\qt@no{25}}%
\qt@newcmd\qurantrans@id@mmmmmdcxlviii{%
(Orang-orang hidup) pada permukaannya (dan orang-orang mati) yang ada pada perutnya.\qt@no{26}}%
\qt@newcmd\qurantrans@id@mmmmmdcxlix{%
(Dan Kami jadikan padanya gunung-gunung yang tinggi) gunung-gunung yang menjulang tinggi (dan Kami beri minum kalian dengan air yang tawar) air yang segar dan tawar.\qt@no{27}}%
\qt@newcmd\qurantrans@id@mmmmmdcl{%
(Kecelakaan yang besarlah pada hari itu bagi orang-orang yang mendustakan) kemudian pada hari kiamat dikatakan kepada orang-orang yang mendustakan:\qt@no{28}}%
\qt@newcmd\qurantrans@id@mmmmmdcli{%
("Pergilah kamu sekalian mendapatkan azab yang dahulunya kalian mendustakannya.)\qt@no{29}}%
\qt@newcmd\qurantrans@id@mmmmmdclii{%
(Pergilah kalian mendapatkan naungan yang mempunyai tiga cabang) yang dimaksud adalah asap neraka Jahanam, apabila membubung terbagi menjadi tiga, karena sangat besarnya.\qt@no{30}}%
\qt@newcmd\qurantrans@id@mmmmmdcliii{%
(Yang tidak melindungi) asap itu tidak dapat menaungi mereka dari panas hari itu (dan tiada bermanfaat) barang sedikit pun bagi mereka (untuk menolak api") yakni api neraka.\qt@no{31}}%
\qt@newcmd\qurantrans@id@mmmmmdcliv{%
(Sesungguhnya neraka itu) maksudnya, api neraka itu (melontarkan bunga api) memercikkan bunga api (sebesar istana) yakni besar dan tingginya bagaikan istana.\qt@no{32}}%
\qt@newcmd\qurantrans@id@mmmmmdclv{%
(Seolah-olah ia iringan unta) lafal Jimaalaatun bentuk jamak dari lafal Jimaalah, juga lafal Jimaalah ini adalah bentuk jamak dari lafal Jamalun. Menurut suatu qiraat dibaca Jimaalatun (yang kuning kehitam-hitaman) perwujudan dan warnanya. Di dalam sebuah hadis disebutkan: ``Manusia yang paling buruk ialah yang hitam bagaikan aspal." Orang-orang Arab menamakan unta yang berwarna hitam unta kuning, demikian itu karena warna hitamnya dicampuri dengan warna kuning. Tetapi menurut pendapat yang lain bahwa arti lafal Shufrun dalam ayat ini adalah hitam, karena alasan yang telah disebutkan tadi, tetapi menurut pendapat lainnya lagi bermakna kuning. Lafal Syararun adalah bentuk jamak dari lafal Syaraarah artinya percikan atau bunga api; dan lafal Al-Qiiru/Al-Qaaru artinya belakin atau aspal.\qt@no{33}}%
\qt@newcmd\qurantrans@id@mmmmmdclvi{%
(Kecelakaan yang besarlah pada hari itu bagi orang-orang yang mendustakan.)\qt@no{34}}%
\qt@newcmd\qurantrans@id@mmmmmdclvii{%
(Ini) yakni hari kiamat ini (adalah hari yang mereka tidak dapat berbicara) sepatah kata pun.\qt@no{35}}%
\qt@newcmd\qurantrans@id@mmmmmdclviii{%
(Dan tidak diizinkan kepada mereka) mengemukakan alasannya (sehingga mereka dapat mengemukakan alasannya) lafal Faya'tadziruuna di'athafkan kepada lafal Yu'dzanu tanpa ada penyebab yang mengaitkannya, tetapi tetap termasuk ke dalam pengertian negatif. Artinya tiada berkenan bagi mereka untuk berbicara, maka tiada alasan bagi mereka.\qt@no{36}}%
\qt@newcmd\qurantrans@id@mmmmmdclix{%
(Kecelakaan yang besarlah pada hari itu bagi orang-orang yang mendustakan.)\qt@no{37}}%
\qt@newcmd\qurantrans@id@mmmmmdclx{%
(Ini adalah hari keputusan; Kami mengumpulkan kalian) hai orang-orang yang mendustakan dari kalangan umat ini, yakni umat Nabi Muhammad (dan orang-orang yang terdahulu) dari kalangan orang-orang yang mendustakan sebelum kalian; lalu kalian semuanya akan dihisab kemudian diazab.\qt@no{38}}%
\qt@newcmd\qurantrans@id@mmmmmdclxi{%
(Jika kalian mempunyai tipu daya) tipu muslihat untuk melindungi diri kalian dari azab (maka lakukanlah tipu daya kalian itu terhadap-Ku) perbuatlah tipu daya kalian itu.\qt@no{39}}%
\qt@newcmd\qurantrans@id@mmmmmdclxii{%
(Kecelakaan yang besarlah pada hari itu bagi orang-orang yang mendustakan.)\qt@no{40}}%
\qt@newcmd\qurantrans@id@mmmmmdclxiii{%
(Sesungguhnya orang-orang yang bertakwa berada dalam naungan) berada dalam naungan pohon-pohon, yang pada hari itu bukan main panasnya, padahal tiada matahari (dan mata air-mata air) yang mengalir.\qt@no{41}}%
\qt@newcmd\qurantrans@id@mmmmmdclxiv{%
(Dan mendapat buah-buahan dari jenis-jenis yang mereka sukai) di dalam ungkapan ayat ini terkandung pengertian bahwa makanan dan minuman di surga sesuai dengan selera penghuninya masing-masing. Berbeda dengan keadaan di dunia, makanan dan minuman sesuai dengan kemampuan masing-masing. Kemudian dikatakan kepada orang-orang yang bertakwa itu:\qt@no{42}}%
\qt@newcmd\qurantrans@id@mmmmmdclxv{%
("Makan dan minumlah kalian dengan enak) lafal Haniian merupakan Haal atau kata keterangan keadaan, yakni makan dan minumlah dengan seenak-enaknya (karena apa yang telah kalian kerjakan") berupa ketaatan.\qt@no{43}}%
\qt@newcmd\qurantrans@id@mmmmmdclxvi{%
(Sesungguhnya demikianlah Kami) sebagaimana Kami memberikan balasan kepada orang-orang yang takwa (memberikan balasan kepada orang-orang yang berbuat baik.)\qt@no{44}}%
\qt@newcmd\qurantrans@id@mmmmmdclxvii{%
(Kecelakaan yang besarlah pada hari itu bagi orang-orang yang mendustakan.)\qt@no{45}}%
\qt@newcmd\qurantrans@id@mmmmmdclxviii{%
("Makanlah dan bersenang-senanglah kamu sekalian) khithab atau perintah ini ditujukan kepada orang-orang kafir di dunia (dalam waktu yang pendek) waktu yang singkat; yang batasnya adalah kematian mereka. Di dalam ungkapan ini terkandung makna ancaman terhadap mereka (sesungguhnya kalian adalah orang-orang yang berdosa.")\qt@no{46}}%
\qt@newcmd\qurantrans@id@mmmmmdclxix{%
(Kecelakaan yang besarlah pada hari itu bagi orang-orang yang mendustakan.)\qt@no{47}}%
\qt@newcmd\qurantrans@id@mmmmmdclxx{%
(Dan apabila dikatakan kepada mereka, ``Rukuklah") yakni salatlah kalian (niscaya mereka tidak mau rukuk) tidak mau salat.\qt@no{48}}%
\qt@newcmd\qurantrans@id@mmmmmdclxxi{%
(Kecelakaan yang besarlah pada hari itu bagi orang-orang yang mendustakan.)\qt@no{49}}%
\qt@newcmd\qurantrans@id@mmmmmdclxxii{%
(Maka kepada perkataan apakah sesudah ini) sesudah Alquran ini (mereka akan beriman?) maksudnya, tidak mungkin mereka akan beriman kepada kitab-kitab Allah lainnya sesudah mereka mendustakannya, karena di dalam Alquran terkandung unsur I'jaz atau mukjizat yang tidak terdapat pada kitab-kitab Allah lainnya.\qt@no{50}}%
\qt@newcmd\qurantrans@id@mmmmmdclxxiii{%
\basmalahid (Tentang apakah) mengenai apakah (mereka saling bertanya-tanya?) yakni orang-orang Quraisy sebagian di antara mereka bertanya-tanya kepada sebagian yang lainnya.\qt@no{1}}%
\qt@newcmd\qurantrans@id@mmmmmdclxxiv{%
(Tentang berita yang besar) ayat ini merupakan penjelasan bagi sesuatu yang dipertanyakan mereka itu. Sedangkan Istifham atau kata tanya pada ayat yang pertama tadi mengandung makna yang mengagungkannya. Hal yang dimaksud adalah Alquran yang disampaikan oleh Nabi saw. yang di dalamnya terkandung berita mengenai adanya hari berbangkit dan hal-hal lainnya.\qt@no{2}}%
\qt@newcmd\qurantrans@id@mmmmmdclxxv{%
(Yang mereka perselisihkan tentang ini) orang-orang yang beriman mempercayainya, sedangkan orang-orang kafir mengingkarinya.\qt@no{3}}%
\qt@newcmd\qurantrans@id@mmmmmdclxxvi{%
(Sekali-kali tidak) kata ini merupakan sanggahan yang ditujukan kepada orang-orang kafir tadi (kelak mereka mengetahui) apa yang bakal menimpa mereka sebagai akibat daripada keingkaran mereka kepada Alquran.\qt@no{4}}%
\qt@newcmd\qurantrans@id@mmmmmdclxxvii{%
(Kemudian sekali-kali tidak; kelak mereka mengetahui) ayat ini merupakan pengukuh dari ayat sebelumnya; dan pada ayat ini dipakai kata Tsumma untuk memberikan pengertian, bahwa ancaman yang kedua lebih keras dan lebih berat daripada ancaman yang dikandung pada ayat sebelumnya. Selanjutnya Allah swt. memberikan isyarat yang menunjukkan tentang kekuasaan-Nya untuk membangkitkan makhluk semuanya; untuk itu Dia berfirman:\qt@no{5}}%
\qt@newcmd\qurantrans@id@mmmmmdclxxviii{%
(Bukankah Kami telah menjadikan bumi itu sebagai hamparan) yakni terhampar bagaikan permadani.\qt@no{6}}%
\qt@newcmd\qurantrans@id@mmmmmdclxxix{%
(Dan gunung-gunung sebagai pasak) yang menstabilkan bumi, sebagaimana halnya kemah yang berdiri dengan mantapnya berkat patok-patok yang menyangganya. Istifham atau kata tanya di sini mengandung makna Taqrir atau menetapkan.\qt@no{7}}%
\qt@newcmd\qurantrans@id@mmmmmdclxxx{%
(Dan Kami jadikan kalian berpasang-pasangan) yaitu terdiri dari jenis laki-laki dan perempuan.\qt@no{8}}%
\qt@newcmd\qurantrans@id@mmmmmdclxxxi{%
(Dan Kami jadikan tidur kalian untuk istirahat) untuk istirahat bagi tubuh kalian.\qt@no{9}}%
\qt@newcmd\qurantrans@id@mmmmmdclxxxii{%
(Dan Kami jadikan malam sebagai pakaian) sebagai penutup karena kegelapannya.\qt@no{10}}%
\qt@newcmd\qurantrans@id@mmmmmdclxxxiii{%
(Dan Kami jadikan siang untuk mencari penghidupan) yaitu waktu untuk mencari penghidupan.\qt@no{11}}%
\qt@newcmd\qurantrans@id@mmmmmdclxxxiv{%
(Dan Kami bina di atas kalian tujuh lapis) maksudnya langit yang berlapis tujuh (yang kokoh) lafal Syidaadan adalah bentuk jamak dari lafal Syadidatun, artinya sangat kuat lagi sangat rapi yang tidak terpengaruh oleh berlalunya zaman.\qt@no{12}}%
\qt@newcmd\qurantrans@id@mmmmmdclxxxv{%
(Dan Kami jadikan pelita) yang menerangi (yang amat terang) yang dimaksud adalah matahari.\qt@no{13}}%
\qt@newcmd\qurantrans@id@mmmmmdclxxxvi{%
(Dan Kami turunkan dari awan yang tebal) yaitu awan yang banyak mengandung air dan sudah saatnya menurunkan air yang dikandungnya, sebagaimana halnya seorang gadis yang sudah masanya untuk berhaid (air yang tercurah) artinya bagaikan air yang dicurahkan.\qt@no{14}}%
\qt@newcmd\qurantrans@id@mmmmmdclxxxvii{%
(Supaya Kami tumbuhkan dengan air itu biji-bijian) seperti biji gandum (dan tumbuh-tumbuhan) seperti buah Tin.\qt@no{15}}%
\qt@newcmd\qurantrans@id@mmmmmdclxxxviii{%
(Dan kebun-kebun) atau taman-taman (yang lebat) tumbuh-tumbuhannya; lafal Alfaafan bentuk jamak dari lafal Lafiifun, wazannya sama dengan lafal Syariifun yang bentuk jamaknya adalah Asyraafun.\qt@no{16}}%
\qt@newcmd\qurantrans@id@mmmmmdclxxxix{%
(Sesungguhnya hari keputusan) di antara semua makhluk (adalah suatu waktu yang ditetapkan) waktu yang ditentukan untuk memberi pahala dan menimpakan siksaan.\qt@no{17}}%
\qt@newcmd\qurantrans@id@mmmmmdcxc{%
(Yaitu hari ditiup sangkakala) menjadi Badal dari lafal Yaumal Fashl; atau merupakan Bayan daripadanya; yang meniupnya adalah malaikat Israfil (lalu kalian datang) dari kuburan kalian menuju ke Mauqif atau tempat penantian (berkelompok-kelompok) secara bergelombang yang masing-masing gelombang berbeda dari gelombang yang lainnya.\qt@no{18}}%
\qt@newcmd\qurantrans@id@mmmmmdcxci{%
(Dan dibukalah langit) dapat dibaca Futtihat dan Futihat, artinya langit terbelah karena para malaikat turun (maka terdapatlah beberapa pintu) yakni langit itu membentuk beberapa pintu.\qt@no{19}}%
\qt@newcmd\qurantrans@id@mmmmmdcxcii{%
(Dan dijalankanlah gunung-gunung) maksudnya, lenyap dari tempat-tempatnya (maka menjadi fatamorganalah ia) menjadi debu yang beterbangan, atau dengan kata lain gunung-gunung itu menjadi sangat ringan jalannya bagaikan debu yang diterbangkan.\qt@no{20}}%
\qt@newcmd\qurantrans@id@mmmmmdcxciii{%
(Sesungguhnya neraka Jahanam itu padanya ada tempat pengintaian) artinya, selalu mengintai atau ada tempat pengintaian.\qt@no{21}}%
\qt@newcmd\qurantrans@id@mmmmmdcxciv{%
(Bagi orang-orang yang melampaui batas) karena itu mereka tidak akan dapat menyelamatkan diri daripadanya (sebagai tempat kembali) bagi mereka, karena mereka akan dimasukkan ke dalamnya.\qt@no{22}}%
\qt@newcmd\qurantrans@id@mmmmmdcxcv{%
(Mereka tinggal) lafal Laabitsiina adalah Haal bagi lafal yang tidak disebutkan, yakni telah dipastikan penempatan mereka (di dalamnya berabad-abad) yakni untuk selama-lamanya tanpa ada batasnya; lafal Ahqaaban bentuk jamak dari lafal Huqban.\qt@no{23}}%
\qt@newcmd\qurantrans@id@mmmmmdcxcvi{%
(Mereka tidak merasakan kesejukan di dalamnya) mereka tidak pernah merasakan tidur di dalamnya (dan tidak pula mendapat minuman) minuman yang lezat.\qt@no{24}}%
\qt@newcmd\qurantrans@id@mmmmmdcxcvii{%
(Kecuali) atau selain (air yang mendidih) yaitu air yang panasnya tak terperikan (dan nanah) dapat dibaca Ghasaaqan dan Ghassaaqan artinya nanah yang keluar dari tubuh penghuni-penghuni neraka; mereka diperbolehkan untuk meminumnya.\qt@no{25}}%
\qt@newcmd\qurantrans@id@mmmmmdcxcviii{%
(Sebagai pembalasan yang setimpal) atau sesuai dengan amal perbuatan mereka, karena tiada suatu dosa pun yang lebih besar daripada kekafiran, dan tiada azab yang lebih besar daripada azab neraka.\qt@no{26}}%
\qt@newcmd\qurantrans@id@mmmmmdcxcix{%
(Sesungguhnya mereka tidak mengharapkan) artinya, mereka tidak takut (kepada hisab) karena mereka ingkar kepada adanya hari berbangkit.\qt@no{27}}%
\qt@newcmd\qurantrans@id@mmmmmdcc{%
(Dan mereka mendustakan ayat-ayat Kami) mendustakan Alquran (dengan sesungguh-sungguhnya) maksudnya, dengan kedustaan yang sesungguhnya.\qt@no{28}}%
\qt@newcmd\qurantrans@id@mmmmmdcci{%
(Dan segala sesuatu) dari amal-amal perbuatan (telah Kami hitung) telah Kami catat (dalam suatu kitab) yaitu dalam catatan-catatan di Lohmahfuz supaya Kami memberikan balasan kepadanya, antara lain karena kedustaan mereka terhadap Alquran.\qt@no{29}}%
\qt@newcmd\qurantrans@id@mmmmmdccii{%
(Karena itu rasakanlah) artinya, lalu dikatakan kepada mereka sewaktu azab menimpa mereka, ``Rasakanlah pembalasan kalian ini." (Dan Kami sekali-kali tidak akan menambah kepada kalian selain daripada azab) di samping azab yang kalian rasakan sekarang.\qt@no{30}}%
\qt@newcmd\qurantrans@id@mmmmmdcciii{%
(Sesungguhnya orang-orang yang bertakwa mendapat kemenangan) maksudnya, mendapat tempat kemenangan di surga.\qt@no{31}}%
\qt@newcmd\qurantrans@id@mmmmmdcciv{%
(Yaitu kebun-kebun) lafal ayat ini menjadi Badal dari lafal Mafaazan, atau sebagai penjelasan daripadanya (dan buah anggur) di'athafkan kepada lafal Mafaazan.\qt@no{32}}%
\qt@newcmd\qurantrans@id@mmmmmdccv{%
(Dan gadis-gadis remaja) yaitu gadis-gadis yang buah dadanya sedang ranum-ranumnya. Lafal Kawaa'ib bentuk jamak dari lafal Kaa'ib (yang sebaya) umurnya, lafal Atraaban bentuk jamak dari lafal Tirbun.\qt@no{33}}%
\qt@newcmd\qurantrans@id@mmmmmdccvi{%
(Dan gelas-gelas yang penuh) berisi khamar; dan di dalam surah Muhammad disebutkan pada salah satu ayat-Nya, ``... sungai-sungai dari khamar (arak)." (Q.S. Muhammad, 15)\qt@no{34}}%
\qt@newcmd\qurantrans@id@mmmmmdccvii{%
(Di dalamnya mereka tidak mendengar) yakni di dalam surga itu sewaktu mereka sedang meminum khamar dan merasakan kelezatan-kelezatan lainnya (perkataan yang sia-sia) perkataan yang batil (dan tidak pula dusta) jika dibaca Kidzaaban artinya dusta, jika dibaca Kidzdzaaban artinya kedustaan yang dilakukan oleh seseorang kepada yang lainnya, keadaannya berbeda dengan apa yang terjadi di dunia sewaktu khamar diminum.\qt@no{35}}%
\qt@newcmd\qurantrans@id@mmmmmdccviii{%
(Sebagai balasan dari Rabbmu) dari Allah swt. memberikan hal tersebut kepada penghuni-penghuni surga sebagai pembalasan dari-Nya (dan pemberian) menjadi Badal daripada lafal Jazaa-an (yang cukup banyak) sebagai pembalasan yang banyak; pengertian ini diambil dari perkataan orang-orang Arab: A'thaanii Fa'ahsabanii, arti-Nya, ``Dia memberiku dengan pemberian yang cukup banyak." Atau dengan kata lain bahwa memberikan pemberian yang banyak kepadaku sehingga aku mengatakan, ``Cukuplah!"\qt@no{36}}%
\qt@newcmd\qurantrans@id@mmmmmdccix{%
(Rabb langit dan bumi) dapat dibaca Rabbis Samaawaati Wal Ardhi dan Rabus Samaawaati Wal Ardhi (dan apa yang ada di antara keduanya; Yang Maha Pemurah) demikian pula lafal Ar-Rahmaan dapat dibaca Ar-Rahmaanu dan Ar-Rahmaani disesuaikan dengan lafal Rabbun tadi. (Mereka tiada memiliki) yakni makhluk semuanya (di hadapan-Nya) di hadapan Allah swt. (sepatah kata pun) yaitu tiada seseorang pun yang dapat berbicara kepada-Nya karena takut kepada-Nya.\qt@no{37}}%
\qt@newcmd\qurantrans@id@mmmmmdccx{%
(Pada hari itu) lafal Yauma merupakan Zharaf bagi lafal Laa Yamlikuuna (ketika ruh berdiri) yakni malaikat Jibril atau bala tentara Allah swt. (dan para malaikat dengan bershaf-shaf) lafal Shaffan menjadi Haal artinya dalam keadaan berbaris bershaf-shaf (mereka tidak berkata-kata) yakni makhluk semuanya (kecuali siapa yang telah diberi izin kepadanya oleh Tuhan Yang Maha Pemurah) untuk berbicara (dan ia mengucapkan) perkataan (yang benar) mereka terdiri dari orang-orang yang beriman dan para Malaikat, seumpamanya mereka memberikan syafaat kepada orang-orang yang diridai oleh-Nya untuk mendapatkan syafaat.\qt@no{38}}%
\qt@newcmd\qurantrans@id@mmmmmdccxi{%
(Itulah hari yang pasti terjadi) hari yang pasti kejadiannya, yaitu hari kiamat. (Maka barang siapa yang menghendaki, niscaya ia menempuh jalan kembali kepada Rabbnya) yakni, kembali kepada Allah dengan mengerjakan ketaatan kepada-Nya, supaya ia selamat dari azab-Nya pada hari kiamat itu.\qt@no{39}}%
\qt@newcmd\qurantrans@id@mmmmmdccxii{%
(Sesungguhnya Kami telah memperingatkan kepada kalian) hai orang-orang kafir Mekah (siksa yang dekat) yakni siksa pada hari kiamat yang akan datang nanti; dan setiap sesuatu yang akan datang itu berarti masa terjadinya sudah dekat (pada hari) menjadi Zharaf dari lafal 'Adzaaban berikut sifatnya yakni berikut lafal Qariiban (manusia melihat) setiap manusia melihat (apa yang telah diperbuat oleh kedua tangannya) yakni perbuatan baik dan perbuatan buruk yang telah dikerjakannya semasa di dunia (dan orang kafir berkata, ``Alangkah baiknya) huruf Ya di sini bermakna Tanbih (sekiranya aku dahulu adalah tanah") maka aku tidak akan disiksa. Ia mengatakan demikian sewaktu Allah berfirman kepada binatang-binatang semuanya sesudah Dia melakukan hukum kisas sebagian dari mereka terhadap sebagian yang lain: ``Jadilah kamu sekalian tanah!"\qt@no{40}}%
\qt@newcmd\qurantrans@id@mmmmmdccxiii{%
\basmalahid (Demi yang mencabut nyawa) atau demi malaikat-malaikat yang mencabut nyawa orang-orang kafir (dengan keras) atau mencabutnya dengan kasar.\qt@no{1}}%
\qt@newcmd\qurantrans@id@mmmmmdccxiv{%
(Dan demi yang mencabut nyawa dengan lemah lembut) maksudnya, demi malaikat-malaikat yang mencabut nyawa orang-orang mukmin secara pelan-pelan.\qt@no{2}}%
\qt@newcmd\qurantrans@id@mmmmmdccxv{%
(Dan demi yang turun dari langit dengan cepat) yakni demi malaikat-malaikat yang melayang turun dari langit dengan membawa perintah-Nya.\qt@no{3}}%
\qt@newcmd\qurantrans@id@mmmmmdccxvi{%
(Dan demi yang mendahului dengan kencang) yaitu malaikat-malaikat yang mendahului dengan kencang membawa arwah orang-orang yang beriman ke surga.\qt@no{4}}%
\qt@newcmd\qurantrans@id@mmmmmdccxvii{%
(Dan yang mengatur urusan) dunia, yaitu malaikat-malaikat yang mengatur urusan dunia. Dengan kata lain, demi malaikat-malaikat yang turun untuk mengaturnya. Jawab daripada semua qasam yang telah disebutkan di atas tidak disebutkan, lengkapnya, benar-benar kalian, hai penduduk Mekah yang kafir, akan dibangkitkan. Jawab inilah yang menjadi Amil terhadap ayat berikutnya yaitu:\qt@no{5}}%
\qt@newcmd\qurantrans@id@mmmmmdccxviii{%
(Pada hari ketika terjadinya guncangan yang hebat) yakni tiupan pertama malaikat Israfil yang mengguncangkan segala sesuatu dengan hebatnya. Kemudian pengertian ini diungkapkan ke dalam bentuk kejadian yang timbul dari tiupan tersebut.\qt@no{6}}%
\qt@newcmd\qurantrans@id@mmmmmdccxix{%
(Kemudian ia diiringi dengan yang mengikutinya) dengan tiupan yang kedua dari malaikat Israfil; jarak di antara kedua tiupan itu empat puluh tahun; dan jumlah ayat ini berkedudukan menjadi Haal atau kata keterangan keadaan daripada lafal Ar-Raajifah. Dan lafal Al-Yauma dapat mencakup kedua tiupan tersebut, karena itu maka kedudukan Zharafnya dianggap sah. Tiupan yang kedua ini untuk membangkitkan semua makhluk yang mati menjadi hidup kembali, maka setelah tiupan yang kedua, mereka bangkit hidup kembali.\qt@no{7}}%
\qt@newcmd\qurantrans@id@mmmmmdccxx{%
(Hati manusia pada waktu itu sangat takut) amat takut dan cemas.\qt@no{8}}%
\qt@newcmd\qurantrans@id@mmmmmdccxxi{%
(Pandangannya tunduk) yakni hina karena kedahsyatan apa yang disaksikannya.\qt@no{9}}%
\qt@newcmd\qurantrans@id@mmmmmdccxxii{%
(Mereka berkata) yakni orang-orang kafir yang mempunyai hati dan pandangan itu mengatakan dengan nada yang memperolok-olokkan karena ingkar dan tidak percaya terhadap adanya hari berbangkit ("Apakah sesungguhnya kami) dapat dibaca secara Tahqiq dan Tas-hil, demikian pula lafal berikutnya yang sama (benar-benar dikembalikan kepada kehidupan yang semula?") maksudnya, apakah kami sesudah mati akan dikembalikan menjadi hidup seperti semula. Lafal Al-Haafirah menunjukkan makna permulaan sesuatu, antara lain dikatakan: Raja'a Fulaanun Fii Haafiratihi, artinya, si Polan kembali lagi ke arah dia datang.\qt@no{10}}%
\qt@newcmd\qurantrans@id@mmmmmdccxxiii{%
("Apakah apabila kami telah menjadi tulang belulang yang hancur lumat) juga akan dihidupkan kembali?" Menurut suatu qiraat lafal Nakhiratun dibaca Naahiratun, artinya yang lapuk dan hancur.\qt@no{11}}%
\qt@newcmd\qurantrans@id@mmmmmdccxxiv{%
(Mereka berkata, ``Hal itu) maksudnya, dihidupkan-Nya kami kembali (kalau begitu) atau seandainya hal itu benar terjadi (adalah pengembalian) suatu pengembalian (yang merugikan") diri kami. Lalu Allah berfirman:\qt@no{12}}%
\qt@newcmd\qurantrans@id@mmmmmdccxxv{%
(Sesungguhnya pengembalian itu hanyalah) maksudnya, tiupan yang kedua untuk membangkitkan semua makhluk (dengan tiupan) dengan hardikan (sekali saja) apabila tiupan yang kedua ini telah dilakukan.\qt@no{13}}%
\qt@newcmd\qurantrans@id@mmmmmdccxxvi{%
(Maka dengan serta-merta mereka) yakni semua makhluk (bangun) berada di permukaan bumi dalam keadaan hidup, yang sebelumnya mereka berada di perut bumi dalam keadaan mati.\qt@no{14}}%
\qt@newcmd\qurantrans@id@mmmmmdccxxvii{%
(Sudahkah sampai kepadamu) hai Muhammad (kisah Musa) lafal ayat ini menjadi Amil bagi lafal berikutnya, yaitu:\qt@no{15}}%
\qt@newcmd\qurantrans@id@mmmmmdccxxviii{%
(Tatkala Rabbnya memanggilnya di lembah suci ialah lembah Thuwa) dapat dibaca dengan memakai Tanwin, yaitu Thuwan, dapat pula dibaca tanpa Tanwin, yaitu Thuwa, artinya nama sebuah lembah. Lalu Rabb berkata kepadanya:\qt@no{16}}%
\qt@newcmd\qurantrans@id@mmmmmdccxxix{%
("Pergilah kamu kepada Firaun sesungguhnya dia telah melampaui batas) kekafirannya telah melampaui batas.\qt@no{17}}%
\qt@newcmd\qurantrans@id@mmmmmdccxxx{%
(Dan katakanlah, ``Adakah keinginan bagimu) artinya, aku mengajakmu (untuk membersihkan diri") dari kemusyrikan, seumpamanya kamu bersaksi bahwa tidak ada Tuhan selain Allah. Menurut suatu qiraat lafal Tazakkaa dibaca Tazzakkaa, yang asalnya adalah Tatazakka, kemudian huruf Ta yang kedua diidgamkan kepada huruf Za, sehingga jadilah Tazzakkaa.\qt@no{18}}%
\qt@newcmd\qurantrans@id@mmmmmdccxxxi{%
("Dan kamu akan kupimpin kepada Rabbmu) maksudnya, aku akan tunjukkan kamu jalan untuk mengetahui-Nya melalui bukti-bukti yang ada (supaya kamu takut kepada-Nya") karena itu lalu kamu takut kepada-Nya.\qt@no{19}}%
\qt@newcmd\qurantrans@id@mmmmmdccxxxii{%
(Lalu Musa memperlihatkan kepadanya mukjizat yang besar) di antara mukjizat-mukjizat yang dimilikinya, yang ada tujuh macam itu. Mukjizat yang diperlihatkan kepadanya pada saat itu ialah tangan atau tongkatnya.\qt@no{20}}%
\qt@newcmd\qurantrans@id@mmmmmdccxxxiii{%
(Tetapi Firaun mendustakan) Nabi Musa (dan mendurhakai) Allah swt.\qt@no{21}}%
\qt@newcmd\qurantrans@id@mmmmmdccxxxiv{%
(Kemudian dia berpaling) dari iman (seraya berjalan) di muka bumi dengan menimbulkan kerusakan.\qt@no{22}}%
\qt@newcmd\qurantrans@id@mmmmmdccxxxv{%
(Maka dia mengumpulkan) para ahli sihir dan bala tentaranya (lalu berseru.)\qt@no{23}}%
\qt@newcmd\qurantrans@id@mmmmmdccxxxvi{%
(Seraya berkata, ``Akulah tuhan kalian yang paling tinggi") tiada tuhan di atasku.\qt@no{24}}%
\qt@newcmd\qurantrans@id@mmmmmdccxxxvii{%
(Maka Allah membinasakannya) yakni menenggelamkannya hingga binasa (sebagai pembalasan) atau siksaan (atas yang terakhir ini) disebabkan perkataannya yang terakhir tadi (dan yang pertama) yaitu sebagaimana yang telah disitir oleh firman-Nya, ``... aku tidak mengetahui tuhan bagi kamu sekalian selain aku." (Q.S. Al-Qashash, 38) Jarak antara kedua perkataan yang telah dikatakannya itu empat puluh tahun.\qt@no{25}}%
\qt@newcmd\qurantrans@id@mmmmmdccxxxviii{%
(Sesungguhnya pada yang demikian itu) hal yang telah disebutkan itu (terdapat pelajaran bagi orang yang takut) kepada Allah swt.\qt@no{26}}%
\qt@newcmd\qurantrans@id@mmmmmdccxxxix{%
(Apakah kalian) hai orang-orang yang ingkar terhadap adanya hari berbangkit; lafal ayat ini dapat dibaca Tahqiq dan Tas-hil (yang lebih sulit penciptaannya ataukah langit?) yang lebih rumit penciptaannya. (Allah telah membinanya) lafal ayat ini menjelaskan tentang cara penciptaan langit.\qt@no{27}}%
\qt@newcmd\qurantrans@id@mmmmmdccxl{%
(Dia meninggikan bangunannya) ayat ini menafsirkan pengertian yang terkandung di dalam lafal Banaahaa; artinya, Dia menjadikan bangunannya berada di atas, maksudnya, dalam ketinggian yang sangat. Tetapi menurut pendapat lain dikatakan, bahwa yang dimaksud dengan Samkahaa adalah atapnya (lalu menyempurnakannya) yakni, Dia menjadikannya dengan sempurna tanpa cacat.\qt@no{28}}%
\qt@newcmd\qurantrans@id@mmmmmdccxli{%
(Dan Dia menjadikan malamnya gelap gulita) membuatnya gelap (dan menjadikan siangnya terang benderang) Dia menampakkan cahaya matahari. Di dalam ungkapan ini lafal Al-Lail atau malam hari dimudhafkan kepada As-Samaa', karena malam hari merupakan kegelapan baginya. Dan dimudhafkan pula kepada matahari, karena matahari merupakan cahaya baginya.\qt@no{29}}%
\qt@newcmd\qurantrans@id@mmmmmdccxlii{%
(Dan bumi sesudah itu dihamparkan-Nya) yakni dijadikan-Nya dalam bentuk terhampar, sebenarnya penciptaan bumi itu sebelum penciptaan langit, tetapi masih belum terhamparkan.\qt@no{30}}%
\qt@newcmd\qurantrans@id@mmmmmdccxliii{%
(Ia memancarkan) berkedudukan menjadi Haal dengan memperkirakan adanya lafal Qad sebelumnya; artinya Ia mengeluarkan (daripadanya mata air) yakni dengan mengalirkan air dari sumber-sumbernya (dan menumbuhkan tumbuh-tumbuhannya) yakni, pohon-pohon dan rumput-rumputan yang menjadi makanan ternak, dan demikian pula tumbuh-tumbuhan yang menjadi makanan pokok manusia, serta buah-buahannya. Dikaitkannya istilah Al-Mar'aa kepada bumi hanyalah merupakan ungkapan Isti'arah,\qt@no{31}}%
\qt@newcmd\qurantrans@id@mmmmmdccxliv{%
(Dan gunung-gunung dipancangkan-Nya dengan teguh) yakni dipancangkan di atas bumi supaya bumi stabil dan tidak berguncang.\qt@no{32}}%
\qt@newcmd\qurantrans@id@mmmmmdccxlv{%
(Untuk kesenangan) lafal Mataa'an berkedudukan menjadi Maf'ul Lah bagi lafal yang tidak disebutkan, lengkapnya, Dia melakukan hal tersebut untuk kesenangan. Atau lafal Mataa'an ini dianggap sebagai Mashdar, artinya memberikan kesenangan (buat kalian dan buat binatang-binatang ternak kalian) lafal An'aam ini adalah jamak dari lafal Na'amun artinya binatang ternak mencakup unta, sapi, dan kambing.\qt@no{33}}%
\qt@newcmd\qurantrans@id@mmmmmdccxlvi{%
(Maka apabila malapetaka yang sangat besar telah datang) yaitu tiupan sangkakala malaikat Israfil yang kedua.\qt@no{34}}%
\qt@newcmd\qurantrans@id@mmmmmdccxlvii{%
(Pada hari ketika manusia teringat) lafal Yauma berkedudukan menjadi Badal daripada lafal Idzaa (akan apa yang telah dikerjakannya) sewaktu ia masih di dunia, apakah itu perbuatan baik atau perbuatan buruk.\qt@no{35}}%
\qt@newcmd\qurantrans@id@mmmmmdccxlviii{%
(Dan diperlihatkan dengan jelas) ditampakkan dengan seterang-terangnya (neraka) yakni neraka Jahim yang membakar itu (kepada setiap orang yang melihat) kepada setiap orang yang melihatnya. Jawab dari lafal Idzaa ialah:\qt@no{36}}%
\qt@newcmd\qurantrans@id@mmmmmdccxlix{%
(Adapun orang yang melampaui batas) yakni orang kafir.\qt@no{37}}%
\qt@newcmd\qurantrans@id@mmmmmdccl{%
(Dan lebih mengutamakan kehidupan dunia) dengan cara selalu mengikuti kemauan hawa nafsunya.\qt@no{38}}%
\qt@newcmd\qurantrans@id@mmmmmdccli{%
(Maka sesungguhnya nerakalah tempat tinggal) bagi dia.\qt@no{39}}%
\qt@newcmd\qurantrans@id@mmmmmdcclii{%
(Dan adapun orang yang takut kepada kebesaran Rabbnya) di kala ia berdiri di hadapan-Nya (dan menahan diri) menahan nafsu amarahnya (dari keinginan hawa nafsunya) yang menjerumuskan ke dalam kebinasaan disebabkan memperturutkan kemauannya.\qt@no{40}}%
\qt@newcmd\qurantrans@id@mmmmmdccliii{%
(Maka sesungguhnya surgalah tempat tinggalnya) kesimpulan makna yang terkandung di dalam Jawab syarat ini ialah, bahwasanya orang yang durhaka akan dimasukkan ke dalam neraka, dan orang yang taat akan dimasukkan ke dalam surga.\qt@no{41}}%
\qt@newcmd\qurantrans@id@mmmmmdccliv{%
(Mereka bertanya kepadamu) yakni orang-orang kafir Mekah itu (tentang hari kiamat, kapan terjadinya) kapankah saat terjadinya.\qt@no{42}}%
\qt@newcmd\qurantrans@id@mmmmmdcclv{%
(Tentang apakah) atau mengenai apakah (hingga kamu dapat menyebutkan waktunya?) maksudnya, kamu tidak memiliki ilmu mengenai kejadiannya sehingga kamu dapat menyebutkan waktunya.\qt@no{43}}%
\qt@newcmd\qurantrans@id@mmmmmdcclvi{%
(Kepada Rabbmulah dikembalikan kesudahannya) yaitu mengenai ketentuan waktunya, tiada seseorang pun yang mengetahuinya selain Dia.\qt@no{44}}%
\qt@newcmd\qurantrans@id@mmmmmdcclvii{%
(Kamu hanyalah pemberi peringatan), maksudnya sesungguhnya peringatanmu itu hanyalah bermanfaat (bagi siapa yang takut kepadanya) yakni takut kepada hari kiamat.\qt@no{45}}%
\qt@newcmd\qurantrans@id@mmmmmdcclviii{%
(Pada hari mereka melihat hari itu, mereka merasa seakan-akan tidak tinggal) di dalam kubur mereka (melainkan sebentar saja di waktu sore atau pagi hari) artinya, pada suatu sore hari atau pada suatu pagi hari. Di sini dianggap sah mengidhafahkan lafal Adh-Dhuhaa kepada lafal Al-'Asyiyyah, disebabkan di antara keduanya terdapat kaitan yang amat erat, sebab kedua-duanya merupakan permulaan dan penghujung suatu hari, dan Idhafah di sini dianggap baik karena kedua kalimatnya terpisah.\qt@no{46}}%
\qt@newcmd\qurantrans@id@mmmmmdcclix{%
\basmalahid (Dia telah bermuka masam) yakni Nabi Muhammad telah bermuka masam (dan berpaling) yaitu memalingkan mukanya karena,\qt@no{1}}%
\qt@newcmd\qurantrans@id@mmmmmdcclx{%
(telah datang seorang buta kepadanya) yaitu Abdullah bin Umi Maktum. Nabi saw. tidak melayaninya karena pada saat itu ia sedang sibuk menghadapi orang-orang yang diharapkan untuk dapat masuk Islam, mereka terdiri dari orang-orang terhormat kabilah Quraisy, dan ia sangat menginginkan mereka masuk Islam. Sedangkan orang yang buta itu atau Abdullah bin Umi Maktum tidak mengetahui kesibukan Nabi saw. pada waktu itu, karena ia buta. Maka Abdullah bin Umi Maktum langsung menghadap dan berseru, ``Ajarkanlah kepadaku apa-apa yang telah Allah ajarkan kepadamu." Akan tetapi Nabi saw. pergi berpaling darinya menuju ke rumah, maka turunlah wahyu yang menegur sikapnya itu, yaitu sebagaimana yang disebutkan dalam surat ini. Nabi saw. setelah itu, apabila datang Abdullah bin Umi Maktum berkunjung kepadanya, beliau selalu mengatakan, ``Selamat datang orang yang menyebabkan Rabbku menegurku karenanya," lalu beliau menghamparkan kain serbannya sebagai tempat duduk Abdullah bin Umi Maktum.\qt@no{2}}%
\qt@newcmd\qurantrans@id@mmmmmdcclxi{%
(Tahukah kamu) artinya, mengertikah kamu (barangkali ia ingin membersihkan dirinya) dari dosa-dosa setelah mendengar dari kamu; lafal Yazzakkaa bentuk asalnya adalah Yatazakkaa, kemudian huruf Ta diidgamkan kepada huruf Za sehingga jadilah Yazzakkaa.\qt@no{3}}%
\qt@newcmd\qurantrans@id@mmmmmdcclxii{%
(Atau dia ingin mendapatkan pelajaran) lafal Yadzdzakkaru bentuk asalnya adalah Yatadzakkaru, kemudian huruf Ta diidgamkan kepada huruf Dzal sehingga jadilah Yadzdzakkaru, artinya mengambil pelajaran dan nasihat (lalu pengajaran itu memberi manfaat kepadanya) atau nasihat yang telah didengarnya dari kamu bermanfaat bagi dirinya. Menurut suatu qiraat lafal Fatanfa'ahu dibaca Fatanfa'uhu, yaitu dibaca Nashab karena menjadi Jawab dari Tarajji atau lafal La'allahuu tadi.\qt@no{4}}%
\qt@newcmd\qurantrans@id@mmmmmdcclxiii{%
(Adapun orang yang merasa dirinya serba cukup) karena memiliki harta.\qt@no{5}}%
\qt@newcmd\qurantrans@id@mmmmmdcclxiv{%
(Maka kamu melayaninya) atau menerima dan mengajukan tawaranmu; menurut suatu qiraat lafal Tashaddaa dibaca Tashshaddaa yang bentuk asalnya adalah Tatashaddaa, kemudian huruf Ta kedua diidgamkan kepada huruf Shad, sehingga jadilah Tashshaddaa.\qt@no{6}}%
\qt@newcmd\qurantrans@id@mmmmmdcclxv{%
(Padahal tidak ada celaan atasmu kalau dia tidak membersihkan diri) yakni orang yang serba berkecukupan itu tidak beriman.\qt@no{7}}%
\qt@newcmd\qurantrans@id@mmmmmdcclxvi{%
(Dan adapun orang yang datang kepadamu dengan bersegera) lafal Yas'aa berkedudukan sebagai Haal atau kata keterangan keadaan bagi Fa'il atau subjek yang terkandung di dalam lafal Jaa-a.\qt@no{8}}%
\qt@newcmd\qurantrans@id@mmmmmdcclxvii{%
(Sedangkan ia takut) kepada Allah swt.; lafal Yakhsyaa menjadi Haal dari fa'il yang terdapat di dalam lafal Yas'aa, yang dimaksud adalah si orang buta itu atau Abdullah bin Umi Maktum.\qt@no{9}}%
\qt@newcmd\qurantrans@id@mmmmmdcclxviii{%
(Maka kamu mengabaikannya) artinya, tiada memperhatikannya sama sekali; lafal Talahhaa asalnya Tatalahhaa, kemudian salah satu dari kedua huruf Ta dibuang, sehingga jadilah Talahhaa.\qt@no{10}}%
\qt@newcmd\qurantrans@id@mmmmmdcclxix{%
(Sekali-kali jangan) berbuat demikian, yakni janganlah kamu berbuat hal yang serupa lagi. (Sesungguhnya hal ini) maksudnya, surat ini atau ayat-ayat ini (adalah suatu peringatan) suatu pelajaran bagi makhluk semuanya.\qt@no{11}}%
\qt@newcmd\qurantrans@id@mmmmmdcclxx{%
(Maka barang siapa yang menghendaki, tentulah ia memperhatikannya) atau tentu ia menghafalnya kemudian menjadikannya sebagai nasihat bagi dirinya.\qt@no{12}}%
\qt@newcmd\qurantrans@id@mmmmmdcclxxi{%
(Di dalam kitab-kitab) menjadi Khabar yang kedua, karena sesungguhnya ia dan yang sebelumnya berkedudukan sebagai jumlah Mu'taridhah atau kalimat sisipan (yang dimuliakan) di sisi Allah.\qt@no{13}}%
\qt@newcmd\qurantrans@id@mmmmmdcclxxii{%
(Yang ditinggikan) di langit (lagi disucikan) dari sentuhan setan.\qt@no{14}}%
\qt@newcmd\qurantrans@id@mmmmmdcclxxiii{%
(Di tangan para penulis) yakni malaikat-malaikat yang menukilnya dari Lohmahfuz.\qt@no{15}}%
\qt@newcmd\qurantrans@id@mmmmmdcclxxiv{%
(Yang mulia lagi berbakti) artinya, semuanya taat kepada Allah swt.; mereka itu adalah malaikat-malaikat.\qt@no{16}}%
\qt@newcmd\qurantrans@id@mmmmmdcclxxv{%
(Binasalah manusia) maksudnya, terlaknatlah orang kafir itu (alangkah sangat kekafirannya) Istifham atau kata tanya pada ayat ini mengandung makna celaan; makna yang dimaksud, apakah gerangan yang mendorongnya berlaku kafir?\qt@no{17}}%
\qt@newcmd\qurantrans@id@mmmmmdcclxxvi{%
(Dari apakah Allah menciptakannya?) Istifham atau kata tanya di sini mengandung makna Taqrir. Kemudian Allah menjelaskannya melalui firman berikutnya:\qt@no{18}}%
\qt@newcmd\qurantrans@id@mmmmmdcclxxvii{%
(Dari setetes mani, Allah menciptakannya lalu menentukannya) menjadi 'alaqah, kemudian menjadi segumpal daging hingga akhir penciptaannya.\qt@no{19}}%
\qt@newcmd\qurantrans@id@mmmmmdcclxxviii{%
(Kemudian untuk menempuh jalannya) yakni jalan ia keluar dari perut ibunya (Dia memudahkannya.)\qt@no{20}}%
\qt@newcmd\qurantrans@id@mmmmmdcclxxix{%
(Kemudian Dia mematikannya dan memasukkannya ke dalam kubur) artinya, Dia menjadikannya berada di dalam kubur yang menutupinya.\qt@no{21}}%
\qt@newcmd\qurantrans@id@mmmmmdcclxxx{%
(Kemudian bila Dia menghendaki, Dia membangkitkannya kembali) menjadi hidup kembali pada hari berbangkit nanti.\qt@no{22}}%
\qt@newcmd\qurantrans@id@mmmmmdcclxxxi{%
(Tidaklah demikian) artinya, benarlah (manusia itu belum melaksanakan) belum mengerjakan (apa yang diperintahkan Allah kepadanya) yakni apa yang telah diperintahkan oleh Rabbnya supaya ia mengerjakannya.\qt@no{23}}%
\qt@newcmd\qurantrans@id@mmmmmdcclxxxii{%
(Maka hendaklah manusia itu memperhatikan) dengan memasang akalnya (kepada makanannya) bagaimanakah makanan itu diciptakan dan diatur untuknya?\qt@no{24}}%
\qt@newcmd\qurantrans@id@mmmmmdcclxxxiii{%
(Sesungguhnya Kami telah mencurahkan air) dari awan (dengan sebenar-benarnya.)\qt@no{25}}%
\qt@newcmd\qurantrans@id@mmmmmdcclxxxiv{%
(Kemudian Kami belah bumi) dengan tumbuh-tumbuhan yang tumbuh dari dalamnya (dengan sebaik-baiknya.)\qt@no{26}}%
\qt@newcmd\qurantrans@id@mmmmmdcclxxxv{%
(Lalu Kami tumbuhkan biji-bijian di bumi itu) seperti biji gandum dan biji jawawut.\qt@no{27}}%
\qt@newcmd\qurantrans@id@mmmmmdcclxxxvi{%
(Anggur dan sayur-sayuran) atau sayur-mayur.\qt@no{28}}%
\qt@newcmd\qurantrans@id@mmmmmdcclxxxvii{%
(Zaitun dan pohon kurma),\qt@no{29}}%
\qt@newcmd\qurantrans@id@mmmmmdcclxxxviii{%
(dan kebun-kebun yang lebat) yakni kebun-kebun yang banyak pepohonannya.\qt@no{30}}%
\qt@newcmd\qurantrans@id@mmmmmdcclxxxix{%
(Dan buah-buahan serta rumput-rumputan) yaitu tumbuh-tumbuhan yang menjadi makanan binatang ternak; tetapi menurut suatu pendapat ``Abban" artinya makanan ternak yang berasal dari tangkai atau bulir gandum atau padi dan lain sebagainya yang sejenis.\qt@no{31}}%
\qt@newcmd\qurantrans@id@mmmmmdccxc{%
(Untuk kesenangan) sebagai kesenangan atau untuk menyenangkan, penafsirannya sebagaimana yang telah disebutkan tadi pada surat sebelumnya (bagi kalian dan bagi binatang-binatang ternak kalian) penafsirannya sama dengan yang terdahulu pada surat sebelumnya.\qt@no{32}}%
\qt@newcmd\qurantrans@id@mmmmmdccxci{%
(Dan apabila datang suara yang memekakkan) yakni tiupan sangkakala yang kedua.\qt@no{33}}%
\qt@newcmd\qurantrans@id@mmmmmdccxcii{%
(Pada hari ketika manusia lari dari saudaranya.)\qt@no{34}}%
\qt@newcmd\qurantrans@id@mmmmmdccxciii{%
(Dari ibu dan bapaknya.)\qt@no{35}}%
\qt@newcmd\qurantrans@id@mmmmmdccxciv{%
(Dari teman hidupnya) yakni istrinya (dan anak-anaknya) lafal Yauma merupakan Badal dari lafal Idzaa, sebagai Jawabnya disimpulkan dari berikut ini.\qt@no{36}}%
\qt@newcmd\qurantrans@id@mmmmmdccxcv{%
(Setiap orang dari mereka pada hari itu mempunyai urusan yang cukup menyibukkannya) yakni keadaan yang membuatnya tidak mengindahkan hal-hal lainnya, atau dengan kata lain setiap orang pada hari itu sibuk dengan urusannya masing-masing.\qt@no{37}}%
\qt@newcmd\qurantrans@id@mmmmmdccxcvi{%
(Banyak muka pada hari itu berseri-seri) yakni tampak cerah ceria.\qt@no{38}}%
\qt@newcmd\qurantrans@id@mmmmmdccxcvii{%
(Tertawa dan gembira) atau bergembira, mereka itu adalah orang-orang yang beriman.\qt@no{39}}%
\qt@newcmd\qurantrans@id@mmmmmdccxcviii{%
(Dan banyak pula muka pada hari itu tertutup debu) artinya, penuh dengan debu.\qt@no{40}}%
\qt@newcmd\qurantrans@id@mmmmmdccxcix{%
(Dan ditutup pula) diselimuti pula (oleh kegelapan) dan kepekatan yang menghitam.\qt@no{41}}%
\qt@newcmd\qurantrans@id@mmmmmdccc{%
(Mereka itulah) maksudnya, orang-orang yang keadaannya demikian adalah (orang-orang kafir lagi durhaka) yakni orang-orang yang di dalam dirinya berkumpul kekafiran dan kedurhakaan.\qt@no{42}}%
\qt@newcmd\qurantrans@id@mmmmmdccci{%
\basmalahid (Apabila matahari digulung) dilipat dan sinarnya menjadi lenyap.\qt@no{1}}%
\qt@newcmd\qurantrans@id@mmmmmdcccii{%
(Dan apabila bintang-bintang berjatuhan) menukik berjatuhan ke bumi.\qt@no{2}}%
\qt@newcmd\qurantrans@id@mmmmmdccciii{%
(Dan apabila gunung-gunung dihancurkan) dilenyapkan dari muka bumi dan menjadi debu yang beterbangan.\qt@no{3}}%
\qt@newcmd\qurantrans@id@mmmmmdccciv{%
(Dan apabila unta-unta yang bunting) unta-unta yang sedang bunting (ditinggalkan) dibiarkan begitu saja tanpa penggembala atau tanpa diperah susunya, karena mereka disibukkan oleh peristiwa yang dahsyat, sehingga mereka lupa akan segala-galanya. Sesungguhnya unta yang sedang bunting itu merupakan harta yang paling berharga di kalangan mereka.\qt@no{4}}%
\qt@newcmd\qurantrans@id@mmmmmdcccv{%
(Dan apabila binatang-binatang liar dikumpulkan) yakni dikumpulkan sesudah dibangkitkan; dimaksud untuk diadakan pembalasan hukum kisas; sebagian di antara mereka mengkisas sebagian yang lain, kemudian setelah selesai, menjadi tanah semuanya.\qt@no{5}}%
\qt@newcmd\qurantrans@id@mmmmmdcccvi{%
(Dan apabila lautan dinyalakan) lafal ini dapat dibaca Sujjirat, dan Sujirat, artinya dinyalakan sehingga lautan itu menjadi api.\qt@no{6}}%
\qt@newcmd\qurantrans@id@mmmmmdcccvii{%
(Dan apabila ruh-ruh dipertemukan) dengan jasadnya masing-masing.\qt@no{7}}%
\qt@newcmd\qurantrans@id@mmmmmdcccviii{%
(Apabila bayi-bayi perempuan yang dikubur hidup-hidup) karena takut tercela mempunyai anak perempuan dan takut jatuh miskin (ditanya) untuk menjelek-jelekkan pelakunya.\qt@no{8}}%
\qt@newcmd\qurantrans@id@mmmmmdcccix{%
(Karena dosa apakah dia dibunuh) dibaca Qutilat karena mengisahkan suatu dialog, jawab bayi-bayi perempuan itu; kami dibunuh tanpa dosa.\qt@no{9}}%
\qt@newcmd\qurantrans@id@mmmmmdcccx{%
(Dan apabila catatan-catatan) yakni, catatan-catatan amal perbuatan (dibuka) dapat dibaca Nusyirat dan Nusysyirat; artinya dibuka dan dibeberkan.\qt@no{10}}%
\qt@newcmd\qurantrans@id@mmmmmdcccxi{%
(Dan apabila langit dilenyapkan) yakni dicabut dari tempatnya sebagaimana dicabutnya kulit domba.\qt@no{11}}%
\qt@newcmd\qurantrans@id@mmmmmdcccxii{%
(Dan apabila Jahim) yaitu neraka (dinyalakan) apinya dibesarkan; dapat dibaca Su''irat dan Su'irat.\qt@no{12}}%
\qt@newcmd\qurantrans@id@mmmmmdcccxiii{%
(Dan apabila surga didekatkan) didekatkan dan diperlihatkan kepada calon-calon penghuninya supaya mereka masuk ke dalamnya. Jawab dari Idzaa pada awal surat ini beserta lafal-lafal lainnya yang di'athafkan kepadanya ialah:\qt@no{13}}%
\qt@newcmd\qurantrans@id@mmmmmdcccxiv{%
(Maka tiap-tiap jiwa akan mengetahui) artinya setiap jiwa akan mengetahui waktu terjadinya hal-hal tersebut, yaitu hari kiamat (apa yang telah dikerjakannya) yaitu perbuatan baik dan perbuatan buruknya.\qt@no{14}}%
\qt@newcmd\qurantrans@id@mmmmmdcccxv{%
(Sungguh, Aku bersumpah) huruf Laa di sini adalah huruf Zaidah (dengan bintang-bintang)\qt@no{15}}%
\qt@newcmd\qurantrans@id@mmmmmdcccxvi{%
(yang beredar dan yang terbenam) yang dimaksud adalah bintang-bintang yang lima, yaitu: Uranus, Yupiter, Mars, Venus dan Pluto. Takhnusu artinya kembali beredar pada garis edarnya ke belakang, terlihat bintang-bintang itu berada di akhir garis edarnya, lalu kembali ke belakang yaitu tempat semula. Lafal Taknisu artinya yang masuk ke dalam kandangnya; maksudnya bintang-bintang tersebut terbenam ke tempat biasa terbenamnya.\qt@no{16}}%
\qt@newcmd\qurantrans@id@mmmmmdcccxvii{%
(Dan demi malam apabila hampir meninggalkan gelapnya) maksudnya, hampir berpisah dengan kegelapannya, atau pergi meninggalkan kegelapannya.\qt@no{17}}%
\qt@newcmd\qurantrans@id@mmmmmdcccxviii{%
(Dan demi subuh apabila fajarnya mulai menyingsing) yakni mulai menampakkan sinarnya hingga menjadi terang-benderang siang hari.\qt@no{18}}%
\qt@newcmd\qurantrans@id@mmmmmdcccxix{%
(Sesungguhnya ia) yakni Alquran itu (benar-benar firman Allah yang dibawa oleh utusan yang mulia) yakni, dimuliakan oleh Allah, dia adalah malaikat Jibril. Lafal Al-Qaul dimudhafkan kepada lafal Rasuulin karena Al-Qaul atau firman itu dibawa turun olehnya.\qt@no{19}}%
\qt@newcmd\qurantrans@id@mmmmmdcccxx{%
(Yang mempunyai kekuatan) yang sangat kuat (di sisi Yang mempunyai 'Arasy) yakni Allah swt. (dia mempunyai kedudukan yang tinggi) lafal 'Inda Dzil 'Arsyi berta'alluq kepada lafal ayat ini. Jelasnya, dia mempunyai kedudukan tinggi di sisi Allah Yang mempunyai Arasy.\qt@no{20}}%
\qt@newcmd\qurantrans@id@mmmmmdcccxxi{%
(Yang ditaati di sana) yakni dia ditaati oleh semua malaikat yang di langit (lagi dipercaya) untuk menurunkan wahyu.\qt@no{21}}%
\qt@newcmd\qurantrans@id@mmmmmdcccxxii{%
(Dan teman kalian itu sekali-kali bukanlah) yakni Nabi Muhammad saw. Di'athafkan kepada lafal Innahuu hingga seterusnya (orang yang gila) sebagaimana yang kalian tuduhkan kepadanya.\qt@no{22}}%
\qt@newcmd\qurantrans@id@mmmmmdcccxxiii{%
(Dan sesungguhnya dia telah melihatnya) yakni, Nabi Muhammad saw. telah melihat malaikat Jibril dalam bentuk aslinya (di ufuk yang terang) yang jelas yaitu, di ketinggian ufuk sebelah timur.\qt@no{23}}%
\qt@newcmd\qurantrans@id@mmmmmdcccxxiv{%
(Dan bukanlah dia) Nabi Muhammad saw. (terhadap perkara yang gaib) hal-hal yang gaib berupa wahyu dan berita dari langit (sebagai seseorang yang dituduh) membuat-buatnya, ini berdasarkan qiraat yang membacanya Zhaniin dengan memakai huruf Zha. Menurut suatu qiraat dibaca Dhaniin dengan memakai huruf Dhadh; artinya seorang yang bakhil untuk menerangkannya, lalu karenanya ia mengurangi sesuatu daripada wahyu dan berita dari langit tersebut.\qt@no{24}}%
\qt@newcmd\qurantrans@id@mmmmmdcccxxv{%
(Dan dia itu bukanlah) yakni, Alquran itu (perkataan setan) artinya hasil curiannya (yang terkutuk) yang dirajam.\qt@no{25}}%
\qt@newcmd\qurantrans@id@mmmmmdcccxxvi{%
(Maka ke manakah kalian akan pergi?) maksudnya jalan apakah yang kalian tempuh untuk ingkar kepada Alquran dan berpaling daripadanya?\qt@no{26}}%
\qt@newcmd\qurantrans@id@mmmmmdcccxxvii{%
(Tiada lain) tidak lain (Alquran itu hanyalah peringatan) atau pelajaran (bagi semesta alam) yakni, manusia dan jin.\qt@no{27}}%
\qt@newcmd\qurantrans@id@mmmmmdcccxxviii{%
(Yaitu bagi siapa di antara kalian yang mau) lafal ayat ini berkedudukan menjadi Badal dari lafal Al-'Aalamiina dengan mengulangi huruf Jarr-nya (menempuh jalan yang lurus) yaitu mengikuti perkara yang hak.\qt@no{28}}%
\qt@newcmd\qurantrans@id@mmmmmdcccxxix{%
(Dan kalian tidak dapat menghendaki) menempuh jalan yang hak itu (kecuali apabila dikehendaki Allah, Rabb semesta alam) barulah kalian dapat menempuh jalan itu. Lafal Al-'Aalamiina artinya mencakup semua makhluk.\qt@no{29}}%
\qt@newcmd\qurantrans@id@mmmmmdcccxxx{%
\basmalahid (Apabila langit terbelah) atau menjadi belah.\qt@no{1}}%
\qt@newcmd\qurantrans@id@mmmmmdcccxxxi{%
(Dan apabila bintang-bintang jatuh berserakan) artinya menukik dan berjatuhan.\qt@no{2}}%
\qt@newcmd\qurantrans@id@mmmmmdcccxxxii{%
(Dan apabila laut-laut dijadikan meluap) maksudnya sebagian bertemu dengan sebagian lainnya sehingga seakan-akan menjadi satu lautan, maka bercampurlah air yang tawar dengan air yang asin.\qt@no{3}}%
\qt@newcmd\qurantrans@id@mmmmmdcccxxxiii{%
(Dan apabila kuburan-kuburan dibongkar) maksudnya tanahnya dibalik lalu orang-orang mati yang ada di dalamnya dibangunkan hidup kembali. Sebagai Jawab dari lafal Idzaa berikut lafal-lafal lain yang di'athafkan kepadanya ialah:\qt@no{4}}%
\qt@newcmd\qurantrans@id@mmmmmdcccxxxiv{%
(Maka tiap-tiap jiwa akan mengetahui) waktu terjadinya hal-hal tersebut, yaitu hari kiamat (apa yang telah dikerjakannya) yaitu amal perbuatan yang telah dikerjakannya (dan) apa (yang dilalaikannya) yang tidak dikerjakannya.\qt@no{5}}%
\qt@newcmd\qurantrans@id@mmmmmdcccxxxv{%
(Hai manusia) yakni orang kafir (apakah yang telah memperdayakan kamu terhadap Rabbmu Yang Maha Mulia) sehingga kamu berbuat durhaka kepada-Nya?\qt@no{6}}%
\qt@newcmd\qurantrans@id@mmmmmdcccxxxvi{%
(Yang telah menciptakan kamu) padahal sebelumnya kamu tidak ada (lalu menyempurnakan kejadianmu) yakni Dia menjadikan kamu dalam bentuk yang sempurna, lengkap dengan anggota-anggota tubuhmu (dan menjadikan kamu seimbang) artinya Dia menjadikan bentukmu seimbang, semua anggota tubuhmu disesuaikan-Nya; tiada tangan atau kaki yang lebih panjang atau lebih pendek dari yang lainnya; dapat dibaca Fa'adalak dan Fa'addalak.\qt@no{7}}%
\qt@newcmd\qurantrans@id@mmmmmdcccxxxvii{%
(Dalam bentuk apa saja) huruf Ma di sini adalah huruf Shilah atau kata penghubung (yang Dia kehendaki. Dia menyusun tubuhmu.)\qt@no{8}}%
\qt@newcmd\qurantrans@id@mmmmmdcccxxxviii{%
(Bukan hanya durhaka saja) kalimat ini mengandung makna cegahan atau larangan bersikap lupa daratan terhadap kemurahan Allah swt. (bahkan kalian mendustakan) hai orang-orang kafir Mekah (hari pembalasan) yakni pembalasan amal perbuatan.\qt@no{9}}%
\qt@newcmd\qurantrans@id@mmmmmdcccxxxix{%
(Padahal sesungguhnya bagi kalian ada yang mengawasi) yaitu malaikat-malaikat yang mengawasi semua amal perbuatan kalian.\qt@no{10}}%
\qt@newcmd\qurantrans@id@mmmmmdcccxl{%
(Yang mulia) artinya mereka dimuliakan di sisi Allah (dan yang mencatat) maksudnya menjadi juru tulis amal perbuatan kalian.\qt@no{11}}%
\qt@newcmd\qurantrans@id@mmmmmdcccxli{%
(Mereka mengetahui semua apa yang kalian kerjakan) tanpa kecuali.\qt@no{12}}%
\qt@newcmd\qurantrans@id@mmmmmdcccxlii{%
(Sesungguhnya orang-orang yang banyak berbakti) yakni orang-orang mukmin yang benar-benar mantap dalam keimanannya, (benar-benar berada dalam surga yang penuh kenikmatan.)\qt@no{13}}%
\qt@newcmd\qurantrans@id@mmmmmdcccxliii{%
(Dan sesungguhnya orang-orang yang durhaka) yakni orang-orang kafir (benar-benar berada dalam neraka) yang apinya sangat membakar.\qt@no{14}}%
\qt@newcmd\qurantrans@id@mmmmmdcccxliv{%
(Mereka masuk ke dalamnya) atau menjadi penghuninya, ia merasakan panas api yang membakar itu (pada hari pembalasan) yaitu di saat mereka menerima pembalasan.\qt@no{15}}%
\qt@newcmd\qurantrans@id@mmmmmdcccxlv{%
(Dan mereka sekali-kali tidak dapat keluar dari neraka itu) artinya tidak bisa melepaskan diri darinya.\qt@no{16}}%
\qt@newcmd\qurantrans@id@mmmmmdcccxlvi{%
(Tahukah kamu) lafal Adraaka maknanya sama dengan lafal A'lamaka, yakni tahukah kamu (apakah hari pembalasan itu?)\qt@no{17}}%
\qt@newcmd\qurantrans@id@mmmmmdcccxlvii{%
(Sekali lagi, tahukah kamu apakah hari pembalasan itu?) ayat ini mengungkapkan tentang kedudukan hari pembalasan yang agung itu.\qt@no{18}}%
\qt@newcmd\qurantrans@id@mmmmmdcccxlviii{%
(Yaitu pada hari) yakni hari itu adalah hari (seseorang tidak berdaya sedikit pun untuk menolong orang lain) atau seseorang tidak dapat memberikan manfaat kepada orang lain. (Dan segala urusan pada hari itu dalam kekuasaan Allah) artinya tiada suatu urusan pun pada hari itu selain-Nya. Dengan kata lain, pada hari itu tiada seorang pun yang dapat menjadi perantara atau penengah, berbeda halnya dengan di dunia.\qt@no{19}}%
\qt@newcmd\qurantrans@id@mmmmmdcccxlix{%
\basmalahid (Kecelakaan besarlah) lafal Wailun merupakan kalimat yang mengandung makna azab; atau merupakan nama sebuah lembah di dalam neraka Jahanam (bagi orang-orang yang curang.)\qt@no{1}}%
\qt@newcmd\qurantrans@id@mmmmmdcccl{%
(Yaitu orang-orang yang apabila menerima takaran dari) atau mereka menerimanya dari (orang lain, mereka minta dipenuhi) minta supaya takaran itu dipenuhi.\qt@no{2}}%
\qt@newcmd\qurantrans@id@mmmmmdcccli{%
(Dan apabila mereka menakar untuk orang lain) atau menakarkan buat orang lainnya (atau menimbang buat orang lain) artinya mereka menimbang buat orang lain (mereka mengurangi) takaran atau timbangan.\qt@no{3}}%
\qt@newcmd\qurantrans@id@mmmmmdccclii{%
(Tidakkah) Istifham atau kata tanya di sini mengandung makna celaan (mempunyai sangkaan) artinya merasa yakin (mereka itu, bahwa sesungguhnya mereka akan dibangkitkan.)\qt@no{4}}%
\qt@newcmd\qurantrans@id@mmmmmdcccliii{%
(Pada suatu hari yang besar) maksudnya pada hari itu mereka dibangkitkan, yaitu pada hari kiamat.\qt@no{5}}%
\qt@newcmd\qurantrans@id@mmmmmdcccliv{%
(Yaitu hari) lafal Yauma menjadi Badal dari lafal Yaumin secara Mahall, yang dinashabkannya adalah lafal Mab'uutsuuna. Lengkapnya pada hari mereka dibangkitkan (manusia berdiri) dari kuburan mereka (menghadap Rabb semesta alam) artinya, semua makhluk dihidupkan kembali untuk memenuhi perintah, hisab dan pembalasan-Nya.\qt@no{6}}%
\qt@newcmd\qurantrans@id@mmmmmdccclv{%
(sekali-kali tidak) maksudnya, benarlah (karena sesungguhnya kitab orang-orang yang durhaka) yakni kitab catatan amal perbuatan orang-orang kafir (tersimpan dalam sijjiin) menurut suatu pendapat; sijjiin itu adalah nama sebuah kitab yang mencatat semua amal perbuatan setan dan orang kafir. Menurut suatu pendapat lagi sijjiin itu adalah nama tempat yang berada di lapisan bumi yang ketujuh; tempat itu merupakan pangkalan iblis dan bala tentaranya.\qt@no{7}}%
\qt@newcmd\qurantrans@id@mmmmmdccclvi{%
(Tahukah kamu apakah sijjiin itu?) maksudnya apakah kitab sijjiin itu?\qt@no{8}}%
\qt@newcmd\qurantrans@id@mmmmmdccclvii{%
(Ialah kitab yang bertulis) yakni yang mempunyai catatan.\qt@no{9}}%
\qt@newcmd\qurantrans@id@mmmmmdccclviii{%
(Kecelakaan yang besarlah pada hari itu bagi orang-orang yang mendustakan.)\qt@no{10}}%
\qt@newcmd\qurantrans@id@mmmmmdccclix{%
(Yaitu-orang-orang yang mendustakan hari pembalasan) lafal ayat ini berkedudukan sebagai Badal atau Bayan dari lafal Al-Mukadzdzibiin pada ayat sebelumnya.\qt@no{11}}%
\qt@newcmd\qurantrans@id@mmmmmdccclx{%
(Dan tidak ada yang mendustakan hari pembalasan itu melainkan setiap orang yang melampaui batas) atau melanggar batas (lagi berdosa) maksudnya banyak dosanya; lafal Atsiim adalah bentuk Mubalaghah dari lafal Aatsim.\qt@no{12}}%
\qt@newcmd\qurantrans@id@mmmmmdccclxi{%
(Yang apabila dibacakan kepadanya ayat-ayat Kami) yakni Alquran (ia berkata, ``Itu adalah dongengan-dongengan orang-orang yang dahulu") atau cerita-cerita yang dibuat di masa silam. Lafal Asaathiir bentuk jamak dari lafal Usthuurah atau Isthaarah.\qt@no{13}}%
\qt@newcmd\qurantrans@id@mmmmmdccclxii{%
(Sekali-kali tidak demikian) lafal ini mengandung makna hardikan dan cegahan terhadap perkataan mereka yang demikian itu (sebenarnya telah menodai) telah menutupi (atas hati mereka) sehingga hati mereka tertutup oleh noda itu (apa yang selalu mereka usahakan itu) yakni kedurhakaan-kedurhakaan yang selalu mereka kerjakan, sehingga mirip dengan karat yang menutupi hati mereka.\qt@no{14}}%
\qt@newcmd\qurantrans@id@mmmmmdccclxiii{%
(Sekali-kali tidak) artinya benarlah (sesungguhnya mereka pada hari itu terhadap Rabb mereka) pada hari kiamat (benar-benar tertutup) sehingga mereka tidak dapat melihat-Nya.\qt@no{15}}%
\qt@newcmd\qurantrans@id@mmmmmdccclxiv{%
(Kemudian, sesungguhnya mereka benar-benar masuk Jahim) yakni mereka memasuki neraka yang membakar.\qt@no{16}}%
\qt@newcmd\qurantrans@id@mmmmmdccclxv{%
(Kemudian dikatakan) kepada mereka ("Inilah) maksudnya azab ini (yang dahulu selalu kalian dustakan.")\qt@no{17}}%
\qt@newcmd\qurantrans@id@mmmmmdccclxvi{%
(Sekali-kali tidak) artinya benarlah (sesungguhnya kitab orang-orang berbakti itu) yaitu kitab catatan amal perbuatan orang-orang mukmin yang imannya benar-benar ikhlas (berada dalam 'Illiyyiin) menurut suatu pendapat 'Illiyyiin adalah nama kitab yang mencatat semua amal kebaikan para malaikat dan orang-orang yang beriman dari kalangan manusia dan jin. Menurut pendapat lain 'Illiyyiin adalah nama sebuah tempat yang terletak di langit yang ketujuh, di bawah Arasy.\qt@no{18}}%
\qt@newcmd\qurantrans@id@mmmmmdccclxvii{%
(Tahukah kamu) atau apakah kamu mengetahui (apakah 'Illiyyiin itu?) apakah kitab 'Illiyyiin itu?\qt@no{19}}%
\qt@newcmd\qurantrans@id@mmmmmdccclxviii{%
Yaitu (kitab yang bertulis) kitab yang ada catatannya.\qt@no{20}}%
\qt@newcmd\qurantrans@id@mmmmmdccclxix{%
(Yang disaksikan oleh yang didekatkan) yakni malaikat-malaikat yang didekatkan.\qt@no{21}}%
\qt@newcmd\qurantrans@id@mmmmmdccclxx{%
(Sesungguhnya orang-orang yang berbakti itu berada dalam kenikmatan yang berlimpah) yakni surga.\qt@no{22}}%
\qt@newcmd\qurantrans@id@mmmmmdccclxxi{%
(Di atas dipan-dipan) atau di atas ranjang-ranjang yang berkelambu (mereka memandang) kenikmatan-kenikmatan yang diberikan kepada mereka.\qt@no{23}}%
\qt@newcmd\qurantrans@id@mmmmmdccclxxii{%
(Kamu dapat mengetahui dari wajah mereka kesenangan hidup mereka yang penuh kenikmatan) yakni wajah-wajah yang cerah penuh dengan kenikmatan hidup.\qt@no{24}}%
\qt@newcmd\qurantrans@id@mmmmmdccclxxiii{%
(Mereka diberi minum dari khamar murni) atau khamar yang bersih dari kotoran (yang dilak) tempat-tempatnya dan tidak pernah dibuka selain oleh mereka.\qt@no{25}}%
\qt@newcmd\qurantrans@id@mmmmmdccclxxiv{%
(Laknya adalah kesturi) setelah diminum keluar daripadanya bau minyak kesturi (dan untuk meraih yang demikian itu hendaknya orang berlomba-lomba) artinya hendaklah mereka menginginkannya dengan cara bersegera taat kepada Allah swt.\qt@no{26}}%
\qt@newcmd\qurantrans@id@mmmmmdccclxxv{%
(Dan campuran khamar murni itu) yaitu barang yang dicampurkan ke dalamnya (adalah tasnim) makna tasnim ditafsirkan atau dijelaskan oleh firman berikutnya:\qt@no{27}}%
\qt@newcmd\qurantrans@id@mmmmmdccclxxvi{%
(Yaitu mata air) dinashabkan oleh lafal Amdaha yang tidak disebutkan (yang minum daripadanya orang-orang yang didekatkan kepada Allah) atau makna lafal Yasyrabu ini mengandung pengertian Yaltadzdzu; artinya yang minum dengan lezatnya adalah orang-orang yang didekatkan kepada Allah dari mata air itu.\qt@no{28}}%
\qt@newcmd\qurantrans@id@mmmmmdccclxxvii{%
(Sesungguhnya orang-orang yang berdosa) seperti Abu Jahal dan lain-lainnya (adalah mereka terhadap orang-orang yang beriman) seperti Ammar bin Yasir, Bilal bin Rabbah dan lain-lainnya (mereka selalu menertawakannya) dan memperolok-olokkannya.\qt@no{29}}%
\qt@newcmd\qurantrans@id@mmmmmdccclxxviii{%
(Dan apabila mereka berlalu) yakni orang-orang yang beriman itu (di hadapan orang-orang yang berdosa, maka orang-orang yang berdosa itu saling mengedipkan matanya) di antara sesama mereka mengisyaratkan dengan kedipan dan picingan alis mereka kepada orang-orang mukmin yang lewat di hadapan mereka. Isyarat ini untuk memperolok-olokkan mereka yang lewat itu.\qt@no{30}}%
\qt@newcmd\qurantrans@id@mmmmmdccclxxix{%
(Dan apabila orang-orang yang berdosa itu kembali) pulang (kepada kaumnya, mereka kembali dengan gembira) menurut suatu qiraat dibaca Faakihiina bukan Fakihiina; artinya mereka merasa puas karena telah memperolok-olokkan kaum mukmin.\qt@no{31}}%
\qt@newcmd\qurantrans@id@mmmmmdccclxxx{%
(Dan apabila mereka melihatnya) yakni melihat orang-orang yang beriman (mereka mengatakan, ``Sesungguhnya mereka itu benar-benar orang-orang yang sesat") karena mereka telah beriman kepada Muhammad.\qt@no{32}}%
\qt@newcmd\qurantrans@id@mmmmmdccclxxxi{%
Allah swt. berfirman (padahal orang-orang yang berdosa itu tidak dikirim) maksudnya orang-orang kafir itu tidak disuruh (kepada orang-orang yang beriman) atau kaum mukmin (sebagai penjaga) bagi mereka, atau bagi amal perbuatan mereka, sehingga berhak untuk membenarkan mereka.\qt@no{33}}%
\qt@newcmd\qurantrans@id@mmmmmdccclxxxii{%
(Maka pada hari ini) yakni hari kiamat (orang-orang yang beriman menertawakan orang-orang kafir.)\qt@no{34}}%
\qt@newcmd\qurantrans@id@mmmmmdccclxxxiii{%
(Mereka duduk di atas dipan-dipan) di surga (sambil memandang) dari tempat tinggal mereka kepada orang-orang kafir yang sedang diazab; maka orang-orang yang beriman itu menertawakan mereka sebagaimana mereka menertawakannya ketika mereka berada di dunia.\qt@no{35}}%
\qt@newcmd\qurantrans@id@mmmmmdccclxxxiv{%
(Apakah telah diberi ganjaran) atau telah diberi pembalasan (orang-orang kafir itu sesuai dengan apa yang dahulu mereka kerjakan?) jawabnya, ``Ya", atau, ``Tentu saja."\qt@no{36}}%
\qt@newcmd\qurantrans@id@mmmmmdccclxxxv{%
\basmalahid (Apabila langit terbelah)\qt@no{1}}%
\qt@newcmd\qurantrans@id@mmmmmdccclxxxvi{%
(Dan patuh) artinya mendengar dan tunduk mau membelah dirinya (kepada Rabbnya, dan sudah semestinya langit itu patuh) langit itu harus patuh dan taat kepada-Nya.\qt@no{2}}%
\qt@newcmd\qurantrans@id@mmmmmdccclxxxvii{%
(Dan apabila bumi diperlebar) diperluas sebagaimana kulit yang direntangkan, sehingga lenyaplah semua bangunan dan gunung yang ada pada permukaannya. Dengan kata lain, apabila bumi diratakan.\qt@no{3}}%
\qt@newcmd\qurantrans@id@mmmmmdccclxxxviii{%
(Dan dilemparkan apa yang ada di dalamnya) yakni orang-orang mati yang berada di dalam perutnya dicampakkan ke permukaannya (dan menjadi kosong) artinya tiada sesuatu pun yang tertinggal di dalamnya.\qt@no{4}}%
\qt@newcmd\qurantrans@id@mmmmmdccclxxxix{%
(Dan patuh) tunduk dan taat dalam hal tersebut (kepada Rabbnya dan sudah semestinya bumi itu patuh) hal tersebut terjadi pada hari kiamat. Jawab dari lafal Idzaa dan lafal-lafal yang di'athafkan kepadanya tidak disebutkan, tetapi pengertiannya diisyaratkan oleh firman selanjutnya, yaitu, ``Semua manusia akan menjumpai amal perbuatannya masing-masing."\qt@no{5}}%
\qt@newcmd\qurantrans@id@mmmmmdcccxc{%
(Hai manusia! Sesungguhnya kamu telah bekerja) telah beramal dengan sekuat tenagamu (hingga) menemui (Rabbmu) yakni mati (dengan sungguh-sungguh, maka pasti kalian akan menemuinya) yakni, menemui amal perbuatanmu yang telah disebutkan tadi pada hari kiamat nanti, baik amal kebaikan atau pun amal keburukan, semuanya pasti kamu jumpai.\qt@no{6}}%
\qt@newcmd\qurantrans@id@mmmmmdcccxci{%
(Adapun orang yang diberikan kitabnya) yakni kitab catatan amalnya (dari sebelah kanannya) dia adalah orang yang beriman.\qt@no{7}}%
\qt@newcmd\qurantrans@id@mmmmmdcccxcii{%
(Maka dia akan diperiksa dengan pemeriksaan yang mudah) yaitu pada hari ditampakkan kepadanya amal perbuatannya, sebagaimana yang telah disebutkan di dalam salah satu hadis sahih yang antara lain dikatakan, ``Barang siapa yang diinterogasi di dalam penghisabannya, niscaya dia bakal binasa atau celaka." Kemudian setelah kepada orang mukmin itu ditampakkan amal perbuatannya, lalu Allah memaafkannya.\qt@no{8}}%
\qt@newcmd\qurantrans@id@mmmmmdcccxciii{%
(Dan dia akan kembali kepada kaumnya) di dalam surga (dengan gembira) karena mendapatkan ampunan-Nya.\qt@no{9}}%
\qt@newcmd\qurantrans@id@mmmmmdcccxciv{%
(Adapun orang yang diberikan kitabnya dari belakang punggungnya) dia adalah orang kafir; tangan kanannya diikat dengan belenggu dijadikan satu dengan kepala, kemudian tangan kirinya ditekuk ke belakang berada di punggungnya, maka dengan tangan kirinya itulah ia mengambil kitab catatan amalnya.\qt@no{10}}%
\qt@newcmd\qurantrans@id@mmmmmdcccxcv{%
(Maka dia akan berteriak) yakni sewaktu dia melihat apa yang tercatat di dalam kitab amalnya ("Celakalah aku") ia berseru meratapi kebinasaannya, dengan ucapannya, ``Celakalah aku."\qt@no{11}}%
\qt@newcmd\qurantrans@id@mmmmmdcccxcvi{%
(Dan dia akan masuk ke dalam neraka Sa'iir) yakni neraka yang apinya sangat besar. Menurut suatu qiraat lafal Yashlaa dibaca Yushallaa.\qt@no{12}}%
\qt@newcmd\qurantrans@id@mmmmmdcccxcvii{%
(Sesungguhnya dia dahulu di kalangan kaumnya) maksudnya kaum kerabatnya sewaktu di dunia (selalu bergembira) yakni sombong karena selalu mengikuti hawa nafsunya.\qt@no{13}}%
\qt@newcmd\qurantrans@id@mmmmmdcccxcviii{%
(Sesungguhnya dia menyangka bahwa dia) lafal An di sini adalah bentuk Takhfif dari Anna, sedangkan Isimnya tidak disebutkan, lengkapnya Annahuu; artinya bahwasanya dia (sekali-kali tidak akan kembali) tidak akan kembali kepada Rabbnya.\qt@no{14}}%
\qt@newcmd\qurantrans@id@mmmmmdcccxcix{%
(Yang benar) dia akan dikembalikan kepada-Nya (sesungguhnya Rabbnya selalu melihatnya) artinya mengetahui bahwa dia akan kembali kepada-Nya.\qt@no{15}}%
\qt@newcmd\qurantrans@id@mmmmmcm{%
(Maka sesungguhnya aku bersumpah) huruf Laa di sini adalah huruf Zaidah (dengan cahaya merah di waktu senja) yakni dengan nama mega merah yang berada di ufuk barat sesudah matahari terbenam.\qt@no{16}}%
\qt@newcmd\qurantrans@id@mmmmmcmi{%
(Dan dengan malam dan apa yang diselubunginya) yakni semua yang ditutupinya termasuk segala jenis binatang dan makhluk lainnya.\qt@no{17}}%
\qt@newcmd\qurantrans@id@mmmmmcmii{%
(Dan dengan bulan apabila jadi purnama) bila bentuknya membulat dan sinarnya tampak penuh, yang demikian itu terjadi di malam-malam yang cerah tak berawan.\qt@no{18}}%
\qt@newcmd\qurantrans@id@mmmmmcmiii{%
(Sesungguhnya kalian melalui) hai manusia. Bentuk asal lafal Latarkabunna adalah Latarkabuunanna, kemudian huruf Nun alamat Rafa'nya dibuang karena berturut-turutnya Nun, demikian pula huruf Wau alamat jamaknya, tetapi bukan karena 'illat bertemunya kedua huruf yang disukunkan, sehingga jadilah Latarkabunna (tingkat demi tingkat) fase demi fase; yaitu mulai dari mati lalu dihidupkan kembali, kemudian menyaksikan keadaan-keadaan di hari kiamat.\qt@no{19}}%
\qt@newcmd\qurantrans@id@mmmmmcmiv{%
(Mengapa mereka) yakni orang-orang kafir itu (tidak mau beriman?) artinya apakah gerangan yang mencegah mereka hingga tidak mau beriman. Atau apakah yang menjadi alasan mereka sehingga tidak mau beriman, padahal bukti-bukti yang membimbing mereka untuk beriman sudah ada dan cukup?\qt@no{20}}%
\qt@newcmd\qurantrans@id@mmmmmcmv{%
(Dan) mengapakah mereka (apabila dibacakan kepada mereka Alquran, mereka tidak mau bersujud?) atau mengapa mereka tidak mau tunduk, seumpamanya mereka beriman kepada Alquran, karena mengingat kemukjizatan yang terkandung di dalamnya.\qt@no{21}}%
\qt@newcmd\qurantrans@id@mmmmmcmvi{%
(Bahkan orang-orang kafir itu mendustakan) adanya hari berbangkit dan lain-lainnya.\qt@no{22}}%
\qt@newcmd\qurantrans@id@mmmmmcmvii{%
(Padahal Allah mengetahui apa yang mereka kumpulkan) di dalam catatan amal perbuatan mereka; yaitu berupa kekafiran, kedustaan dan amal-amal buruk lainnya.\qt@no{23}}%
\qt@newcmd\qurantrans@id@mmmmmcmviii{%
(Maka beri kabar gembiralah mereka) beritakanlah kepada mereka (dengan azab yang pedih) atau siksaan yang menyakitkan.\qt@no{24}}%
\qt@newcmd\qurantrans@id@mmmmmcmix{%
(Kecuali) tetapi (orang-orang yang beriman dan mengerjakan amal-amal yang saleh, bagi mereka pahala yang tidak putus-putusnya) yakni pahala mereka tidak akan terputus dan tidak akan dikurangi serta tidak akan disebut-sebutkan sekalipun sangat banyak dan berlimpah ruah untuk selama-lamanya.\qt@no{25}}%
\qt@newcmd\qurantrans@id@mmmmmcmx{%
\basmalahid (Demi langit yang mempunyai gugusan bintang) yakni bintang-bintang yang dua belas gugusan, sebagaimana yang telah dijelaskan di dalam surah Al-Furqaan.\qt@no{1}}%
\qt@newcmd\qurantrans@id@mmmmmcmxi{%
(Dan demi hari yang dijanjikan) yaitu hari kiamat.\qt@no{2}}%
\qt@newcmd\qurantrans@id@mmmmmcmxii{%
(Dan demi yang menyaksikan) hari Jumat (dan yang disaksikan) yakni hari Arafah. Demikianlah menurut penafsiran hadis tentang tiga perkara tersebut; yang pertama adalah hari yang telah dijanjikan, dan yang kedua hari Jumat menyaksikan amal perbuatan yang dikerjakan pada hari itu, serta yang ketiga hari Arafah disaksikan oleh manusia dan para malaikat. Sedangkan yang menjadi Jawab Qasam kalimat permulaannya tidak disebutkan, yaitu, ``Sesungguhnya."\qt@no{3}}%
\qt@newcmd\qurantrans@id@mmmmmcmxiii{%
(Telah dibinasakan) telah dilaknat (orang-orang yang memiliki Ukhdud) artinya orang-orang yang menggali parit.\qt@no{4}}%
\qt@newcmd\qurantrans@id@mmmmmcmxiv{%
(Yaitu api) lafal An-Naari berkedudukan sebagai Badal Isytimal dari lafal Al-Ukhduud (yang dinyalakan) dengan kayu bakar.\qt@no{5}}%
\qt@newcmd\qurantrans@id@mmmmmcmxv{%
(Ketika mereka berada di sekitarnya) yaitu berada di sekitar tepi parit-parit itu seraya di atas kursi-kursi (mereka duduk.)\qt@no{6}}%
\qt@newcmd\qurantrans@id@mmmmmcmxvi{%
(Sedangkan mereka terhadap apa yang mereka perbuat terhadap orang-orang yang beriman) kepada Allah, menyiksa mereka dengan cara melemparkan mereka ke dalam parit yang penuh dengan api itu, jika mereka tidak mau kembali murtad dari imannya (menyaksikan) artinya hadir menyaksikan penyiksaan itu. Menurut suatu riwayat, bahwasanya Allah menyelamatkan orang-orang yang beriman yang dilemparkan ke dalam parit berapi itu, yaitu dengan mencabut nyawa mereka terlebih dahulu sebelum mereka jatuh ke dalam api. Kemudian api itu keluar dari dalam parit dan membakar orang-orang yang berada di sekitarnya, sehingga mereka yang menyaksikan penyiksaan itu mati terbakar.\qt@no{7}}%
\qt@newcmd\qurantrans@id@mmmmmcmxvii{%
(Dan mereka tidak menyiksa orang-orang mukmin itu melainkan karena orang-orang mukmin itu beriman kepada Allah Yang Maha Perkasa) di dalam kerajaan-Nya. (lagi Maha Terpuji) lafal Al-Hamiid bermakna Al-Mahmuud, artinya Maha Terpuji.\qt@no{8}}%
\qt@newcmd\qurantrans@id@mmmmmcmxviii{%
(Yang mempunyai kerajaan langit dan bumi; dan Allah Maha Menyaksikan segala sesuatu) yakni Dia menyaksikan, bahwa tiadalah orang-orang kafir itu ingkar kepada orang-orang yang beriman melainkan karena orang-orang yang beriman itu beriman kepada Allah.\qt@no{9}}%
\qt@newcmd\qurantrans@id@mmmmmcmxix{%
(Sesungguhnya orang-orang yang mendatangkan cobaan kepada orang-orang yang mukmin laki-laki dan perempuan) yaitu dengan cara membakar mereka hidup-hidup (kemudian mereka tidak bertobat, maka bagi mereka azab Jahanam) disebabkan kekafiran mereka (dan bagi mereka azab pembakaran) sebagai pembalasan dari pembakaran mereka terhadap orang-orang yang beriman, pembalasan itu kelak akan ditimpakan kepada mereka di akhirat. Tetapi menurut suatu pendapat bahwa azab tersebut terjadi di dunia, umpamanya api tersebut keluar dari paritnya dan langsung mengejar dan membakar mereka, sebagaimana keterangan yang disebutkan di atas.\qt@no{10}}%
\qt@newcmd\qurantrans@id@mmmmmcmxx{%
(Sesungguhnya orang-orang yang beriman dan mengerjakan amal-amal yang saleh, bagi mereka surga yang mengalir di bawahnya sungai-sungai itulah keberuntungan yang besar.)\qt@no{11}}%
\qt@newcmd\qurantrans@id@mmmmmcmxxi{%
(Sesungguhnya Azab Rabbmu) terhadap orang-orang kafir (benar-benar keras) sesuai dengan kehendak-Nya.\qt@no{12}}%
\qt@newcmd\qurantrans@id@mmmmmcmxxii{%
(Sesungguhnya Dialah yang memulai) penciptaan makhluk (dan yang mengembalikan) makhluk menjadi hidup kembali, maka tiada sesuatu pun yang dapat menghalang-halangi apa yang dikehendaki-Nya.\qt@no{13}}%
\qt@newcmd\qurantrans@id@mmmmmcmxxiii{%
(Dan Dialah Yang Maha Pengampun) kepada orang-orang mukmin yang berbuat dosa (lagi Maha Pengasih) yakni Maha Belas Kasih kepada kekasih-kekasih-Nya dengan memberikan karamah kepada mereka.\qt@no{14}}%
\qt@newcmd\qurantrans@id@mmmmmcmxxiv{%
(Yang mempunyai Arasy) yakni Yang menciptakan dan Yang memilikinya (lagi Maha Agung) dibaca Rafa' yakni Al-Majiidu, artinya Yang berhak menyandang kesempurnaan sifat-sifat Yang Maha Tinggi.\qt@no{15}}%
\qt@newcmd\qurantrans@id@mmmmmcmxxv{%
(Maha Kuasa berbuat apa yang dikehendaki-Nya) artinya tiada sesuatu pun yang dapat menghalang-halangi kehendak-Nya.\qt@no{16}}%
\qt@newcmd\qurantrans@id@mmmmmcmxxvi{%
(Sudahkah datang kepadamu) hai Muhammad (berita tentang kaum-kaum penentang.)\qt@no{17}}%
\qt@newcmd\qurantrans@id@mmmmmcmxxvii{%
(Yaitu kaum Fir'aun dan kaum Tsamud) kedua lafal ini menjadi Badal dari lafal Al-Junuud; dan di sini cukup hanya dengan menyebut nama Firaun saja tanpa menyebut bala tentaranya; adapun Tsamud adalah nama suatu kaum. Kisahnya ialah bahwasanya mereka dibinasakan karena kekafiran mereka. Hal ini merupakan peringatan bagi orang-orang yang ingkar kepada Nabi saw. dan Alquran, dimaksud supaya mereka mengambil pelajaran dari kisah tersebut.\qt@no{18}}%
\qt@newcmd\qurantrans@id@mmmmmcmxxviii{%
(Akan tetapi orang-orang kafir selalu mendustakan) hal-hal yang telah disebutkan tadi.\qt@no{19}}%
\qt@newcmd\qurantrans@id@mmmmmcmxxix{%
(Padahal Allah mengepung mereka dari belakang mereka) tiada seseorang pun yang dapat menyelamatkan dan menjaga mereka dari azab-Nya.\qt@no{20}}%
\qt@newcmd\qurantrans@id@mmmmmcmxxx{%
(Bahkan yang didustakan mereka itu ialah Alquran yang mulia) atau yang agung.\qt@no{21}}%
\qt@newcmd\qurantrans@id@mmmmmcmxxxi{%
(Yang dalam Lauh) berada di atas langit yang ketujuh (terpelihara) dari ulah setan-setan dan dari sesuatu perubahan. Panjang Lohmahfuz itu sama dengan panjangnya langit dan bumi, sedangkan lebarnya ialah sama dengan jarak antara timur dan barat; terbuat dari intan yang putih bersih. Demikianlah menurut pendapat yang telah dikemukakan oleh Ibnu Abbas r.a.\qt@no{22}}%
\qt@newcmd\qurantrans@id@mmmmmcmxxxii{%
\basmalahid (Demi langit dan yang datang pada malam hari) lafal Ath-Thaariq pada asalnya berarti segala sesuatu yang datang pada malam hari, antara lain ialah bintang-bintang, karena bintang-bintang baru muncul bila malam tiba.\qt@no{1}}%
\qt@newcmd\qurantrans@id@mmmmmcmxxxiii{%
(Tahukah kamu) artinya apakah kamu mengetahui (apakah yang datang pada malam hari itu?) lafal Maa adalah Mubtada sedangkan lafal Ath-Thaariq adalah Khabarnya, kedua lafal tersebut berkedudukan menjadi Maf'ul kedua dari lafal Adraa. Lafal Maa yang kedua juga menjadi Khabar dari lafal Maa yang pertama, di dalamnya terkandung makna yang menjelaskan kedudukan Ath-Thaariq yang agung itu; selanjutnya pengertian Ath-Thaariq dijelaskan oleh firman berikutnya.\qt@no{2}}%
\qt@newcmd\qurantrans@id@mmmmmcmxxxiv{%
(Yaitu bintang) yakni bintang Tsurayya, atau semua bintang (yang cahayanya menembus) kegelapan malam. Yang menjadi Jawab Qasam ialah:\qt@no{3}}%
\qt@newcmd\qurantrans@id@mmmmmcmxxxv{%
(Tidak ada suatu jiwa pun melainkan ada penjaganya) jika dibaca Lamaa tanpa memakai Tasydid, berarti huruf Maa adalah huruf Zaidah, dan In adalah bentuk Takhfif dari Inna sedangkan Isimnya tidak disebutkan, dan huruf Lamnya adalah huruf Fariqah. Artinya sesungguhnya setiap diri itu ada penjaganya. Jika dibaca Lammaa dengan memakai Tasydid, berarti In adalah bermakna Nafi, sedangkan Lammaa bermakna Illaa; artinya tiada suatu jiwa pun melainkan ada penjaganya, yakni penjaga yang terdiri dari malaikat; malaikat penjaga itu bertugas untuk mencatat amal baik dan amal buruknya.\qt@no{4}}%
\qt@newcmd\qurantrans@id@mmmmmcmxxxvi{%
(Maka hendaklah manusia memperhatikan) dengan perhatian yang dibarengi dengan mempelajarinya (dari apakah dia diciptakan?) artinya berasal dari apakah dia tercipta?\qt@no{5}}%
\qt@newcmd\qurantrans@id@mmmmmcmxxxvii{%
(Dia diciptakan dari air yang terpancar) yakni yang dipancarkan oleh laki-laki ke dalam rahim wanita.\qt@no{6}}%
\qt@newcmd\qurantrans@id@mmmmmcmxxxviii{%
(Yang keluar dari antara tulang sulbi) laki-laki (dan tulang dada) perempuan.\qt@no{7}}%
\qt@newcmd\qurantrans@id@mmmmmcmxxxix{%
(Sesungguhnya Dia) yakni Allah swt. (untuk mengembalikannya) atau menghidupkan kembali manusia setelah mati (benar-benar kuasa) maka apabila manusia itu benar-benar memperhatikan asal mula kejadiannya, niscaya dia akan menyimpulkan, bahwasanya Yang Maha Kuasa menciptakan demikian, berkuasa pula untuk menghidupkannya kembali.\qt@no{8}}%
\qt@newcmd\qurantrans@id@mmmmmcmxl{%
(Pada hari ditampakkan) maksudnya, diuji dan dibuka (segala rahasia) yaitu hal-hal yang terkandung di dalam kalbu berupa keyakinan-keyakinan dan niat-niat.\qt@no{9}}%
\qt@newcmd\qurantrans@id@mmmmmcmxli{%
(Maka sekali-kali tidak ada bagi manusia itu) yaitu bagi orang yang tidak mempercayai adanya hari berbangkit (suatu kekuatan pun) yang dapat melindunginya dari azab (dan tidak pula seorang penolong pun) yang dapat menolak azab Allah.\qt@no{10}}%
\qt@newcmd\qurantrans@id@mmmmmcmxlii{%
(Demi langit yang mengandung hujan) hujan dinamakan Ar-Raj'u karena berulang datang pada musimnya.\qt@no{11}}%
\qt@newcmd\qurantrans@id@mmmmmcmxliii{%
(Dan demi bumi yang mempunyai tumbuh-tumbuhan) maksudnya retak-retak karena daripadanya keluar tumbuh-tumbuhan.\qt@no{12}}%
\qt@newcmd\qurantrans@id@mmmmmcmxliv{%
(Sesungguhnya Alquran itu) yakni wahyu Alquran (benar-benar firman yang memutuskan) yang memisahkan antara perkara yang hak dan perkara yang batil.\qt@no{13}}%
\qt@newcmd\qurantrans@id@mmmmmcmxlv{%
(Dan sekali-kali bukanlah dia senda gurau) atau mainan dan kebatilan.\qt@no{14}}%
\qt@newcmd\qurantrans@id@mmmmmcmxlvi{%
(Sesungguhnya mereka) yakni orang-orang kafir (merencanakan tipu daya yang jahat dengan sebenar-benarnya) yaitu mereka melakukan tipu daya yang jahat terhadap diri Nabi saw.\qt@no{15}}%
\qt@newcmd\qurantrans@id@mmmmmcmxlvii{%
(Dan Aku pun membuat rencana pula dengan sebenar-benarnya) maksudnya, Aku biarkan mereka bersenang-senang sesuka hatinya, tanpa mereka sadari bahwa hal itu merupakan Istidraj dari Aku, yang kelak Aku akan mengazab mereka dengan sepedih-pedihnya.\qt@no{16}}%
\qt@newcmd\qurantrans@id@mmmmmcmxlviii{%
(Karena itu beri tangguhlah) hai Muhammad (orang-orang kafir itu, beri tangguhlah mereka) lafal Amhilhum mengukuhkan makna yang terkandung di dalam lafal Famahhil; dianggap baik karena lafalnya berbeda dengan yang pertama, artinya tangguhkanlah mereka itu (barang sebentar) dalam waktu yang singkat. Lafal Ruwaidan adalah mashdar yang mengukuhkan makna 'Amilnya. Ia adalah bentuk Tashghir dari lafal Rawdun atau Arwaadun yang mengandung makna Tarkhiim. Dan Allah swt. benar-benar mengazab orang-orang kafir itu dalam perang Badar. Akan tetapi ayat penangguhan ini dinasakh oleh ayat perang, yakni Allah memerintahkan Nabi-Nya supaya berjihad memerangi mereka.\qt@no{17}}%
\qt@newcmd\qurantrans@id@mmmmmcmxlix{%
\basmalahid (Sucikanlah nama Rabbmu) maksudnya sucikanlah Dia dari sifat-sifat yang tidak layak bagi-Nya lafal Ismu adalah lafal Za'id (Yang Maha Tinggi) lafal Al-A'laa berkedudukan sebagai kata sifat bagi lafal Rabbika.\qt@no{1}}%
\qt@newcmd\qurantrans@id@mmmmmcml{%
(Yang menciptakan lalu menyempurnakan) ciptaan-Nya, yakni Dia menjadikan makhluk-Nya itu seimbang semua bagian-bagiannya dan tidak pincang atau berbeda-beda.\qt@no{2}}%
\qt@newcmd\qurantrans@id@mmmmmcmli{%
(Dan Yang menentukan) apa yang dikehendaki-Nya (dan Yang memberi petunjuk) kepada apa yang telah ditentukan-Nya berupa amal kebaikan dan amal keburukan.\qt@no{3}}%
\qt@newcmd\qurantrans@id@mmmmmcmlii{%
(Dan Yang mengeluarkan rumput-rumputan) atau Yang menumbuhkan rumput-rumputan.\qt@no{4}}%
\qt@newcmd\qurantrans@id@mmmmmcmliii{%
(Lalu dijadikan-Nya) sesudah rumput-rumputan itu hijau (kering) yaitu menjadi layu dan kering (kehitam-hitaman) kehitam-hitaman karena kering.\qt@no{5}}%
\qt@newcmd\qurantrans@id@mmmmmcmliv{%
(Kami akan membacakan kepadamu) Alquran (maka kamu tidak akan lupa) apa yang kamu bacakan itu.\qt@no{6}}%
\qt@newcmd\qurantrans@id@mmmmmcmlv{%
(Kecuali kalau Allah menghendaki) kamu melupakannya karena bacaan dan hukumnya telah dinasakh. Sesungguhnya Nabi saw. selalu mengeraskan suara bacaannya mengikuti bacaan malaikat Jibril karena takut lupa. Seolah-olah dikatakan kepadanya, janganlah kamu tergesa-gesa membacanya, karena sesungguhnya kamu tidak akan lupa, karena itu janganlah kamu merepotkan dirimu dengan mengeraskan suaramu sewaktu kamu membacakannya. (Sesungguhnya Dia) yakni Allah swt. (mengetahui yang terang) maksudnya perkataan dan perbuatan yang terang-terangan (dan yang tersembunyi) dari keduanya.\qt@no{7}}%
\qt@newcmd\qurantrans@id@mmmmmcmlvi{%
(Dan Kami akan memudahkan kamu untuk menempuh jalan yang mudah) yakni syariat yang mudah, yaitu agama Islam.\qt@no{8}}%
\qt@newcmd\qurantrans@id@mmmmmcmlvii{%
(Oleh sebab itu berikanlah peringatan) dengan Alquran (karena peringatan itu bermanfaat) maksudnya memberikan peringatan dengan hal-hal yang telah disebutkan pada firman-Nya, ``Sayadzdzakkaru," sekalipun peringatan itu tidak bermanfaat bagi sebagian di antara mereka, tetapi peringatan itu pasti bermanfaat bagi sebagian yang lainnya.\qt@no{9}}%
\qt@newcmd\qurantrans@id@mmmmmcmlviii{%
(Akan mendapat peringatan) dan pelajaran dari peringatan itu (orang yang takut) kepada Allah swt. sebagaimana yang disebutkan dalam ayat yang lain yaitu, firman-Nya, ``Maka beri peringatanlah dengan Alquran orang yang takut kepada ancaman-Ku." (Q.S. Qaaf, 45)\qt@no{10}}%
\qt@newcmd\qurantrans@id@mmmmmcmlix{%
(Akan menjauhinya) yakni peringatan itu akan ditinggalkan dan diabaikan begitu saja (orang yang celaka) yakni orang yang kafir.\qt@no{11}}%
\qt@newcmd\qurantrans@id@mmmmmcmlx{%
(Yaitu orang yang akan memasuki api yang besar) yaitu api neraka; dan api dunia dinamakan api kecil.\qt@no{12}}%
\qt@newcmd\qurantrans@id@mmmmmcmlxi{%
(Kemudian dia tidak mati di dalamnya) hingga ia dapat beristirahat (dan tidak pula hidup) dengan kehidupan yang menyenangkan.\qt@no{13}}%
\qt@newcmd\qurantrans@id@mmmmmcmlxii{%
(Sesungguhnya beruntunglah) atau mendapat keberuntungan (orang yang membersihkan diri) dengan cara beriman.\qt@no{14}}%
\qt@newcmd\qurantrans@id@mmmmmcmlxiii{%
(Dan dia ingat nama Rabbnya) seraya mengagungkan-Nya (lalu dia salat) maksudnya, mengerjakan salat lima waktu, hal ini merupakan perkara akhirat; akan tetapi orang-orang kafir Mekah berpaling daripadanya.\qt@no{15}}%
\qt@newcmd\qurantrans@id@mmmmmcmlxiv{%
(Tetapi kamu sekalian lebih memilih) dapat dibaca Tu'tsiruuna dan Yu'tsiruuna (kehidupan duniawi) daripada kehidupan ukhrawi.\qt@no{16}}%
\qt@newcmd\qurantrans@id@mmmmmcmlxv{%
(Sedangkan kehidupan akhirat) yang di dalamnya terdapat surga (adalah lebih baik dan lebih kekal.)\qt@no{17}}%
\qt@newcmd\qurantrans@id@mmmmmcmlxvi{%
(Sesungguhnya ini) maksudnya keberuntungan orang-orang yang membersihkan dirinya dengan beriman dan bahwa kehidupan akhirat itu lebih baik (benar-benar terdapat dalam kitab-kitab terdahulu) yang diturunkan sebelum Alquran.\qt@no{18}}%
\qt@newcmd\qurantrans@id@mmmmmcmlxvii{%
(Yaitu Kitab-kitab Ibrahim dan Musa) sepuluh shuhuf bagi Nabi Ibrahim, dan satu shuhuf bagi Nabi Musa, yaitu kitab Taurat.\qt@no{19}}%
\qt@newcmd\qurantrans@id@mmmmmcmlxviii{%
\basmalahid (Apakah) telah (datang kepadamu berita hari kiamat) hari kiamat dinamakan hari yang menutupi karena pada hari itu semua makhluk diselimuti oleh kengerian-kengeriannya.\qt@no{1}}%
\qt@newcmd\qurantrans@id@mmmmmcmlxix{%
(Banyak muka pada hari itu) yang dimaksud dengan ungkapan lafal Wujuuh atau muka adalah orang-orangnya, demikian lafal yang sama sesudahnya nanti (tunduk) terhina.\qt@no{2}}%
\qt@newcmd\qurantrans@id@mmmmmcmlxx{%
(Pekerja keras lagi kepayahan) maksudnya dalam keadaan lelah dan payah karena diikat dengan rantai dan belenggu.\qt@no{3}}%
\qt@newcmd\qurantrans@id@mmmmmcmlxxi{%
(Memasuki) dapat dibaca Tashlaa dan Tushlaa, jika dibaca Tushlaa artinya dimasukkan ke dalam (api yang sangat panas.)\qt@no{4}}%
\qt@newcmd\qurantrans@id@mmmmmcmlxxii{%
(Diberi minum dari sumber yang sangat panas) atau dengan air yang sangat panas.\qt@no{5}}%
\qt@newcmd\qurantrans@id@mmmmmcmlxxiii{%
(Mereka tiada memperoleh makanan selain dari pohon yang berduri) Dharii' adalah sejenis pohon yang berduri, hewan ternak pun tidak mau memakannya karena duri itu keras lagi kotor.\qt@no{6}}%
\qt@newcmd\qurantrans@id@mmmmmcmlxxiv{%
(Yang tidak menggemukkan dan tidak pula menghilangkan lapar.)\qt@no{7}}%
\qt@newcmd\qurantrans@id@mmmmmcmlxxv{%
(Banyak muka pada hari itu berseri-seri) atau tampak cerah dan cantik.\qt@no{8}}%
\qt@newcmd\qurantrans@id@mmmmmcmlxxvi{%
(Karena usahanya) sewaktu di dunia yaitu karena ketaatannya (mereka merasa senang) di alam akhirat, yaitu sewaktu mereka melihat pahalanya.\qt@no{9}}%
\qt@newcmd\qurantrans@id@mmmmmcmlxxvii{%
(Dalam surga yang tinggi) secara nyata dan dapat mereka rasakan.\qt@no{10}}%
\qt@newcmd\qurantrans@id@mmmmmcmlxxviii{%
(Tidak kamu dengar) dapat dibaca Tasma'u dan Yasma'u, jika Yasma'u artinya tidak dia dengar (di dalamnya perkataan yang tak berguna) tiada seorang yang berkata melantur yang tidak ada gunanya.\qt@no{11}}%
\qt@newcmd\qurantrans@id@mmmmmcmlxxix{%
(Di dalamnya ada mata air yang mengalir) lafal `Ainun sekalipun bentuknya Mufrad tetapi maknanya jamak.\qt@no{12}}%
\qt@newcmd\qurantrans@id@mmmmmcmlxxx{%
(Di dalamnya ada takhta-takhta yang ditinggikan) yaitu tempat kedudukan dan derajatnya ditinggikan.\qt@no{13}}%
\qt@newcmd\qurantrans@id@mmmmmcmlxxxi{%
(Dan gelas-gelas) yakni tempat-tempat untuk minum tanpa gagang (yang terletak) di setiap tepi mata air yang disediakan untuk peminum-peminumnya.\qt@no{14}}%
\qt@newcmd\qurantrans@id@mmmmmcmlxxxii{%
(Dan bantal-bantal) untuk bersandar (yang tersusun) atau dalam keadaan tersusun untuk tempat bersandar.\qt@no{15}}%
\qt@newcmd\qurantrans@id@mmmmmcmlxxxiii{%
(Dan permadani-permadani) yaitu permadani yang empuk lagi tebal (yang terhampar) dalam keadaan terbentang.\qt@no{16}}%
\qt@newcmd\qurantrans@id@mmmmmcmlxxxiv{%
(Maka apakah mereka tidak memperhatikan) dengan perhatian yang dibarengi keinginan mengambil pelajaran; yang dimaksud adalah orang-orang kafir Mekah (unta bagaimana dia diciptakan?)\qt@no{17}}%
\qt@newcmd\qurantrans@id@mmmmmcmlxxxv{%
(Dan langit, bagaimanakah ia ditinggikan?)\qt@no{18}}%
\qt@newcmd\qurantrans@id@mmmmmcmlxxxvi{%
(Dan gunung-gunung, bagaimana ia dipancangkan?)\qt@no{19}}%
\qt@newcmd\qurantrans@id@mmmmmcmlxxxvii{%
(Dan bumi bagaimana ia dihamparkan?) maksudnya dijadikan sehingga terhampar. Melalui hal-hal tersebutlah mereka mengambil kesimpulan tentang kekuasaan Allah swt. dan keesaan-Nya. Pembahasan ini dimulai dengan menyebut unta, karena unta adalah binatang ternak yang paling mereka kenal daripada yang lain-lainnya. Firman Allah ``Suthihat" jelas menunjukkan bahwa bumi itu rata bentuknya. Pendapat inilah yang dianut oleh para ulama Syara'. Jadi bentuk bumi bukanlah bulat seperti bola sebagaimana yang dikatakan oleh para ahli ilmu konstruksi. Masalah ini sama sekali tidak ada sangkut-pautnya dengan salah satu rukun syariat.\qt@no{20}}%
\qt@newcmd\qurantrans@id@mmmmmcmlxxxviii{%
(Maka berilah peringatan) berilah mereka peringatan yang mengingatkan mereka kepada nikmat-nikmat Allah dan bukti-bukti yang menunjukkan keesaan-Nya (karena sesungguhnya kamu hanyalah orang yang memberi peringatan.)\qt@no{21}}%
\qt@newcmd\qurantrans@id@mmmmmcmlxxxix{%
(Kamu bukanlah orang yang berkuasa atas mereka) menurut suatu qiraat lafal Mushaithirin dibaca Musaithirin yakni dengan memakai huruf Sin bukan Shad, artinya menguasai mereka. Ayat ini diturunkan sebelum ada perintah berjihad.\qt@no{22}}%
\qt@newcmd\qurantrans@id@mmmmmcmxc{%
(Kecuali) tetapi (orang yang berpaling) dari keimanan (dan kafir) kepada Alquran, artinya ingkar kepadanya.\qt@no{23}}%
\qt@newcmd\qurantrans@id@mmmmmcmxci{%
(Maka Allah akan mengazabnya dengan azab yang besar) yaitu azab di akhirat dan azab di dunia dengan dibunuh dan ditawan.\qt@no{24}}%
\qt@newcmd\qurantrans@id@mmmmmcmxcii{%
(Sesungguhnya kepada Kamilah kembali mereka) maksudnya mereka akan kembali kepada-Nya sesudah mati.\qt@no{25}}%
\qt@newcmd\qurantrans@id@mmmmmcmxciii{%
(Kemudian sesungguhnya kewajiban Kamilah menghisab mereka) atau memberikan balasan kepada mereka, Kami sama sekali tidak akan membiarkan mereka begitu saja, mereka pasti Kami hisab.\qt@no{26}}%
\qt@newcmd\qurantrans@id@mmmmmcmxciv{%
\basmalahid (Demi fajar) yakni fajar yang terbit setiap hari.\qt@no{1}}%
\qt@newcmd\qurantrans@id@mmmmmcmxcv{%
(Dan malam yang sepuluh) maksudnya tanggal sepuluh bulan Zulhijah.\qt@no{2}}%
\qt@newcmd\qurantrans@id@mmmmmcmxcvi{%
(Dan yang genap) atau tidak ganjil (dan yang ganjil) dapat dibaca Al-Watr dan Al-Witr, artinya ganjil.\qt@no{3}}%
\qt@newcmd\qurantrans@id@mmmmmcmxcvii{%
(Dan malam bila berlalu) bila datang dan pergi.\qt@no{4}}%
\qt@newcmd\qurantrans@id@mmmmmcmxcviii{%
(Pada yang demikian itu) yakni sumpah itu (terdapat sumpah bagi orang-orang yang berakal) Jawab dari Qasam tidak disebutkan yakni, sungguh kalian hai orang-orang kafir Mekah akan diazab.\qt@no{5}}%
\qt@newcmd\qurantrans@id@mmmmmcmxcix{%
(Apakah kamu tidak memperhatikan) artinya tidak mengetahui hai Muhammad (bagaimana Rabbmu berbuat terhadap kaum 'Ad.)\qt@no{6}}%
\qt@newcmd\qurantrans@id@mmmmmm{%
(Yaitu penduduk Iram) Iram adalah nama kaum 'Ad dahulu; lafal Iram dapat dianggap sebagai 'Athaf Bayan atau Badal tidak menerima Tanwin karena 'Illat 'Alamiyah dan Mu'annats (yang mempunyai tubuh-tubuh yang tinggi) atau mereka adalah orang-orang yang tinggi tubuhnya, tersebutlah yang paling tinggi di antara mereka mencapai empat ratus hasta.\qt@no{7}}%
\qt@newcmd\qurantrans@id@mmmmmmi{%
(Yang belum pernah diciptakan sepertinya di negeri-negeri lain) dalam hal kekuatan dan keperkasaannya.\qt@no{8}}%
\qt@newcmd\qurantrans@id@mmmmmmii{%
(Dan kaum Tsamud yang memotong) yang memahat (batu-batu besar) lafal Ash-Shakhr adalah bentuk jamak dari lafal Shakhrah; kemudian batu-batu besar yang mereka lubangi itu dijadikan sebagai rumah tempat tinggal mereka (di lembah) yakni Wadil Qura namanya.\qt@no{9}}%
\qt@newcmd\qurantrans@id@mmmmmmiii{%
(Dan Firaun yang mempunyai pasak-pasak) ia dikenal dengan julukan tersebut, bila menyiksa seseorang ia membuat empat pasak, kemudian kedua tangan dan kedua kaki orang yang disiksanya itu diikatkan pada masing-masing pasak.\qt@no{10}}%
\qt@newcmd\qurantrans@id@mmmmmmiv{%
(Yang berbuat sewenang-wenang) maksudnya Firaun dan bala tentaranya berbuat angkara murka (dalam negeri.)\qt@no{11}}%
\qt@newcmd\qurantrans@id@mmmmmmv{%
(Lalu mereka berbuat banyak kerusakan dalam negeri itu) dengan melakukan pembunuhan dan kelaliman lainnya.\qt@no{12}}%
\qt@newcmd\qurantrans@id@mmmmmmvi{%
(Karena itu Rabbmu menimpakan kepada mereka cemeti) sejenis (azab.)\qt@no{13}}%
\qt@newcmd\qurantrans@id@mmmmmmvii{%
(Sesungguhnya Rabbmu benar-benar mengawasi) semua amal perbuatan hamba-hamba-Nya, maka tiada sesuatu pun yang terlewat dari-Nya di antara amal-amal perbuatan itu, supaya Dia membalasnya kepada mereka.\qt@no{14}}%
\qt@newcmd\qurantrans@id@mmmmmmviii{%
(Adapun manusia) yakni orang kafir (apabila dia diuji) dikenakan ujian (oleh Rabbnya lalu dimuliakan-Nya) dengan harta benda dan lain-lainnya (dan diberi-Nya kesenangan, maka dia berkata, ``Rabbku telah memuliakanku.")\qt@no{15}}%
\qt@newcmd\qurantrans@id@mmmmmmix{%
(Adapun bila Rabbnya mengujinya lalu Dia membatasi) atau menyempitkan (rezekinya, maka dia berkata, ``Rabbku menghinaku.")\qt@no{16}}%
\qt@newcmd\qurantrans@id@mmmmmmx{%
(Sekali-kali tidak) kalimat ini merupakan hardikan, bahwa perkara yang sebenarnya tidaklah demikian, maksud dimuliakan itu dengan diberi kekayaan, dan dihina itu dengan diberi kemiskinan. Sesungguhnya seseorang itu menjadi mulia karena ketaatannya, dan menjadi terhina karena kemaksiatannya. Orang-orang kafir Mekah tidak memperhatikan hal ini (sebenarnya kalian tidak memuliakan anak yatim) artinya kalian tidak pernah berbuat baik kepada anak-anak yatim, padahal kalian kaya atau kalian tidak memberikan harta waris yang menjadi hak anak-anak yatim.\qt@no{17}}%
\qt@newcmd\qurantrans@id@mmmmmmxi{%
(Dan kalian tidak mengajak) diri kalian atau orang lain (memberi makan) (orang miskin.)\qt@no{18}}%
\qt@newcmd\qurantrans@id@mmmmmmxii{%
(Dan kalian memakan harta pusaka) harta peninggalan (dengan cara mencampur-aduk) tanpa segan-segan lagi, maksudnya kalian mencampur-baurkan harta warisan bagian wanita dan anak-anak dengan bagian kalian; atau kalian mencampur-baurkan harta warisan mereka dengan harta kalian sendiri.\qt@no{19}}%
\qt@newcmd\qurantrans@id@mmmmmmxiii{%
(Dan kalian mencintai harta benda dengan kecintaan yang berlebihan) sehingga kalian merasa sayang untuk menafkahkannya di jalan kebaikan. Menurut suatu qiraat pada keempat Fi'il tadi, yaitu Laa Tukrimuuna, Laa Tahaadhdhuuna, Ta'kuluuna, dan Tuhibbuuna, dibaca Laa Yukrimuuna, Laa Yahaadhdhuuna, Ya'kuluuna, dan Yuhibbuuna. Makna ayat-ayat di atas berdasarkan bacaan pertama.\qt@no{20}}%
\qt@newcmd\qurantrans@id@mmmmmmxiv{%
(Jangan berbuat demikian) lafal Kallaa ini adalah kalimat cegahan supaya jangan melakukan hal-hal tersebut. (Apabila bumi diguncangkan berturut-turut) artinya secara terus-menerus sehingga hancur musnahlah semua bangunan-bangunan yang ada di permukaannya.\qt@no{21}}%
\qt@newcmd\qurantrans@id@mmmmmmxv{%
(Dan datanglah Rabbmu) yakni perintah-Nya (sedangkan malaikat-malaikat) lafal Al-Malak adalah bentuk mufrad dari lafal Al-Malaaikah (berbaris-baris) lafal Shaffan berkedudukan menjadi Hal atau kata keterangan keadaan yakni, berbaris-baris atau membentuk barisan-barisan yang banyak.\qt@no{22}}%
\qt@newcmd\qurantrans@id@mmmmmmxvi{%
(Dan pada hari itu didatangkan neraka Jahanam) ditarik dengan memakai tujuh puluh ribu kendali, pada tiap-tiap kendali dipegang oleh tujuh puluh ribu malaikat, neraka Jahanam terdengar gejolak dan gemuruhnya (pada hari itu) menjadi Badal dari lafal Idzaa dan Jawabnya (ingatlah manusia) maksudnya orang kafir ingat kepada apa yang telah dilalaikannya (akan tetapi tidak berguna lagi mengingat itu baginya) Istifham atau lafal Annaa di sini bermakna Nafi, artinya penyesalannya pada saat itu tidak ada gunanya lagi.\qt@no{23}}%
\qt@newcmd\qurantrans@id@mmmmmmxvii{%
(Dia mengatakan) sewaktu ingat akan kesalahan-kesalahannya ("Alangkah baiknya) huruf Ya di sini bermakna Tanbih (sekiranya aku dahulu mengerjakan) amal kebaikan dan beriman (untuk hidupku ini") untuk kehidupan yang baik di akhirat, atau sewaktu aku hidup di dunia.\qt@no{24}}%
\qt@newcmd\qurantrans@id@mmmmmmxviii{%
(Maka pada hari itu tiada yang mengazab) dibaca Yu'adzdzibu dengan dikasrahkan huruf Dzalnya (seperti azab-Nya) seperti azab Allah (seseorang pun) artinya Dia tidak menyerahkannya kepada seseorang pun melainkan hanya kepada diri-Nya.\qt@no{25}}%
\qt@newcmd\qurantrans@id@mmmmmmxix{%
(Dan) demikian pula (tiada yang dapat mengikat) dibaca Laa Yuutsiqu (seperti ikatannya, seseorang pun) menurut suatu qiraat lafal Laa Yu'adzdzibu dan lafal Laa Yuutsiqu dibaca Laa Yu'adzdzabu dan Laa Yuutsaqu dengan demikian maka Dhamir yang dikandung kedua lafal tersebut kembali kepada orang kafir. Lengkapnya, tiada seseorang pun yang diazab seperti azab yang ditimpakan kepada orang kafir, dan tiada seseorang pun yang diikat seperti ikatan yang dibelenggukan kepada orang kafir.\qt@no{26}}%
\qt@newcmd\qurantrans@id@mmmmmmxx{%
(Hai jiwa yang tenang) atau yang aman, dimaksud adalah jiwa yang beriman.\qt@no{27}}%
\qt@newcmd\qurantrans@id@mmmmmmxxi{%
(Kembalilah kepada Rabbmu) perkataan ini diucapkan kepadanya sewaktu ia menjelang mati; yakni kembalilah kamu kepada perintah dan kehendak-Nya (dengan hati yang puas) akan pahala yang kamu terima (lagi diridai) di sisi Allah maksudnya, semua amal perbuatanmu diridai di sisi-Nya. Jiwa yang beriman itu merasa puas dan diridai; kedudukan kedua lafal ini menjadi kata keterangan keadaan; kemudian dikatakan kepadanya pada hari kiamat nanti:\qt@no{28}}%
\qt@newcmd\qurantrans@id@mmmmmmxxii{%
("Maka masuklah ke dalam) jamaah (hamba-hamba-Ku) yang saleh.\qt@no{29}}%
\qt@newcmd\qurantrans@id@mmmmmmxxiii{%
(Dan masuklah ke dalam surga-Ku") bersama dengan hamba-hamba-Ku yang saleh.\qt@no{30}}%
\qt@newcmd\qurantrans@id@mmmmmmxxiv{%
\basmalahid (Sungguh) huruf Laa di sini adalah huruf Zaidah mengandung makna Taukid (Aku bersumpah dengan kota ini) yakni kota Mekah.\qt@no{1}}%
\qt@newcmd\qurantrans@id@mmmmmmxxv{%
(Dan kamu) hai Muhammad (halal) maksudnya dihalalkan bagimu (kota ini) artinya Dia menghalalkannya untukmu melakukan peperangan di dalamnya untuk melawan orang-orang musyrik. Allah memenuhi janji-Nya itu pada waktu penaklukan kota Mekah. Ayat ini merupakan Jumlah Mu'taridhah yang terletak di antara Qasam yang pertama dengan Qasam yang selanjutnya.\qt@no{2}}%
\qt@newcmd\qurantrans@id@mmmmmmxxvi{%
(Dan demi bapak) yaitu Nabi Adam (dan anaknya) atau anak cucunya; huruf Maa di sini bermakna Man.\qt@no{3}}%
\qt@newcmd\qurantrans@id@mmmmmmxxvii{%
(Sesungguhnya Kami telah menciptakan manusia) semuanya (berada dalam susah payah) yaitu lelah dan susah karena selalu menghadapi musibah-musibah di dunia dan kesengsaraan-kesengsaraan di akhirat.\qt@no{4}}%
\qt@newcmd\qurantrans@id@mmmmmmxxviii{%
(Apakah manusia itu menyangka) atau apakah manusia menduga, bahwa dia itu adalah kuat. Yang dimaksud adalah Asyad dari kalangan kaum Quraisy ia terkenal kekuatannya (bahwa) huruf An di sini adalah bentuk Takhfif dari Anna, sedangkan Isimnya tidak disebutkan, lengkapnya Annahuu (sekali-kali tiada seorang pun yang berkuasa atas dirinya?) Allahlah yang berkuasa atas dirinya.\qt@no{5}}%
\qt@newcmd\qurantrans@id@mmmmmmxxix{%
(Dia mengatakan, ``Aku telah menghabiskan) untuk memusuhi Muhammad (harta yang banyak") maksudnya banyak mengeluarkan harta untuk memusuhinya.\qt@no{6}}%
\qt@newcmd\qurantrans@id@mmmmmmxxx{%
(Apakah dia menyangka bahwa) dirinya (tiada seorang pun yang melihatnya?) artinya melihat apa-apa yang telah dibelanjakannya itu, sehingga ada orang yang mengetahui berapa jumlah harta yang telah dibelanjakannya. Allahlah yang mengetahui berapa jumlah yang telah dibelanjakannya itu, dan jumlah sedemikian itu tidak berarti apa-apa di sisi-Nya, bahkan Dia kelak akan membalas perbuatannya yang buruk dan keji itu.\qt@no{7}}%
\qt@newcmd\qurantrans@id@mmmmmmxxxi{%
(Bukankah Kami telah menjadikan) Istifham atau kata tanya di sini mengandung arti Taqrir (baginya dua buah mata,)\qt@no{8}}%
\qt@newcmd\qurantrans@id@mmmmmmxxxii{%
(lidah dan dua buah bibir?)\qt@no{9}}%
\qt@newcmd\qurantrans@id@mmmmmmxxxiii{%
(Dan Kami telah menunjukkan kepadanya dua jalan) maksudnya Kami telah menjelaskan kepadanya jalan kebaikan dan jalan keburukan.\qt@no{10}}%
\qt@newcmd\qurantrans@id@mmmmmmxxxiv{%
(Maka kenapa ia tidak) atau mengapa ia tidak (menempuh jalan yang sulit?)\qt@no{11}}%
\qt@newcmd\qurantrans@id@mmmmmmxxxv{%
(Tahukah kamu) maksudnya apakah kamu mengetahui (apakah jalan yang sulit) yang akan ditempuhnya itu? Ungkapan ini mengagungkan kedudukan jalan tersebut. Ayat ini merupakan Jumlah Mu'taridhah atau kalimat sisipan; kemudian dijelaskan oleh ayat berikutnya, yaitu:\qt@no{12}}%
\qt@newcmd\qurantrans@id@mmmmmmxxxvi{%
(Melepaskan budak) dari perbudakan, yaitu dengan cara memerdekakannya.\qt@no{13}}%
\qt@newcmd\qurantrans@id@mmmmmmxxxvii{%
(Atau memberi makan pada hari kelaparan) yakni sewaktu terjadi bencana kelaparan.\qt@no{14}}%
\qt@newcmd\qurantrans@id@mmmmmmxxxviii{%
(Kepada anak yatim yang ada hubungan kerabat) atau famili.\qt@no{15}}%
\qt@newcmd\qurantrans@id@mmmmmmxxxix{%
(Atau orang miskin yang sangat fakir) artinya karena amat miskinnya hanya beralaskan tanah. Menurut suatu qiraat kedua Fi'il tersebut diganti menjadi dua Mashdar yang kedua-duanya dirafa'kan. Yang pertama dimudhafkan kepada lafal Raqabatin sedangkan yang kedua ditanwinkan, maka sebelum lafal Al-'Aqabah diperkirakan adanya lafal Iqtihaam. Qiraat ini merupakan penjelasan dari makna ayat-ayat tersebut.\qt@no{16}}%
\qt@newcmd\qurantrans@id@mmmmmmxl{%
(Kemudian dia adalah) lafal ayat ini di'athafkan kepada lafal Iqtahama; dan lafal Tsumma menunjukkan makna urutan penyebutan atau Tartiibudz Dzikr. Artinya dia sewaktu menempuh jalan yang sulit itu (termasuk orang-orang yang beriman dan saling berpesan) yakni sebagian di antara mereka berpesan kepada sebagian yang lain (untuk bersabar) di dalam menjalankan amal ketaatan dan menjauhi perbuatan kemaksiatan (dan saling berpesan untuk berkasih sayang) terhadap semua makhluk.\qt@no{17}}%
\qt@newcmd\qurantrans@id@mmmmmmxli{%
(Mereka) yaitu orang-orang yang memiliki sifat-sifat demikian itu (adalah golongan kanan.)\qt@no{18}}%
\qt@newcmd\qurantrans@id@mmmmmmxlii{%
(Dan orang-orang yang kafir kepada ayat-ayat Kami, mereka itu adalah golongan kiri)\qt@no{19}}%
\qt@newcmd\qurantrans@id@mmmmmmxliii{%
(orang-orang kiri itu berada dalam neraka yang ditutup rapat) dapat dibaca Mu'shadah dan Muushadah, artinya neraka yang tertutup rapat.\qt@no{20}}%
\qt@newcmd\qurantrans@id@mmmmmmxliv{%
\basmalahid (Demi matahari dan cahayanya di pagi hari) yaitu sewaktu memancarkan sinarnya di pagi hari.\qt@no{1}}%
\qt@newcmd\qurantrans@id@mmmmmmxlv{%
(Dan bulan apabila mengiringinya) apabila muncul mengiringi terbenamnya matahari.\qt@no{2}}%
\qt@newcmd\qurantrans@id@mmmmmmxlvi{%
(Dan siang apabila menampilkannya) yaitu menampakkan matahari yang semakin meninggi.\qt@no{3}}%
\qt@newcmd\qurantrans@id@mmmmmmxlvii{%
(Dan malam apabila menutupinya) artinya menyelimuti siang dengan kegelapannya. Lafal Idzaa yang ada pada tiga tempat di atas hanya menunjukkan makna Zharaf, sedangkan yang menjadi Amilnya adalah Fi'il dari Qasam.\qt@no{4}}%
\qt@newcmd\qurantrans@id@mmmmmmxlviii{%
(Dan langit serta pembinaannya.)\qt@no{5}}%
\qt@newcmd\qurantrans@id@mmmmmmxlix{%
(Dan bumi serta penghamparannya) yang menghampar.\qt@no{6}}%
\qt@newcmd\qurantrans@id@mmmmmml{%
(Dan jiwa) sekalipun bentuk lafalnya Mufrad tetapi makna yang dimaksud adalah Jamak (serta penyempurnaannya) maksudnya kesempurnaan ciptaannya; lafal Maa pada tiga tempat di atas adalah Maa Mashdariyah, atau bermakna Man.\qt@no{7}}%
\qt@newcmd\qurantrans@id@mmmmmmli{%
(Maka Allah mengilhamkan kepada jiwa itu kefasikan dan ketakwaannya) maksudnya Allah menjelaskan kepadanya jalan kebaikan dan jalan keburukan. Lafal At-Taqwaa letaknya diakhirkan karena demi memelihara keserasian bunyi akhir ayat, sedangkan sebagai Jawab dari Qasam di atas ialah:\qt@no{8}}%
\qt@newcmd\qurantrans@id@mmmmmmlii{%
(Sesungguhnya beruntunglah) pada lafal Qad Aflaha ini sengaja tidak disebutkan huruf Lam Taukidnya karena mengingat panjangnya pembicaraan (orang yang menyucikannya) yakni menyucikan jiwanya dari dosa-dosa.\qt@no{9}}%
\qt@newcmd\qurantrans@id@mmmmmmliii{%
(Dan sesungguhnya merugilah) atau rugilah (orang yang mengotorinya) yang menodainya dengan perbuatan maksiat. Asalnya lafal Dassaahaa ialah Dassasahaa, kemudian huruf Sin yang kedua diganti menjadi Alif demi untuk meringankan pengucapannya, akhirnya jadilah Dassaahaa.\qt@no{10}}%
\qt@newcmd\qurantrans@id@mmmmmmliv{%
(Kaum Tsamud telah mendustakan) rasulnya, yaitu Nabi Saleh (karena mereka melampaui batas) disebabkan tindakan mereka yang melampaui batas.\qt@no{11}}%
\qt@newcmd\qurantrans@id@mmmmmmlv{%
(Ketika bangkit) artinya bersegera (orang yang paling celaka di antara mereka) orang tersebut dikenal dengan nama julukan si pendekar, lalu ia bersegera menyembelih unta Nabi Saleh atas izin mereka.\qt@no{12}}%
\qt@newcmd\qurantrans@id@mmmmmmlvi{%
(Lalu Rasul Allah berkata kepada mereka) yakni Nabi Saleh ("Unta betina Allah) maksudnya biarkanlah unta betina Allah ini (dan minumannya") dan hari bagian minumnya; sesungguhnya bagian minum itu digilirkan antara mereka dan unta; untuk unta sehari dan untuk mereka sehari.\qt@no{13}}%
\qt@newcmd\qurantrans@id@mmmmmmlvii{%
(Lalu mereka mendustakannya) mendustakan ucapan Nabi Saleh yang mengatakan, bahwa unta itu adalah milik Allah, dan bila mereka melanggarnya niscaya hal itu akan berakibat turunnya azab atas mereka (dan menyembelih unta itu) atau mereka membunuhnya itu, dengan maksud supaya bagian minum itu diperoleh seluruhnya oleh mereka (maka menimpakanlah) atau menurunkanlah (kepada mereka Rabb mereka) azab (disebabkan dosa mereka, lalu Allah meratakan azab) atas mereka, sehingga tidak ada seorang pun dari mereka yang dapat lolos atau menyelamatkan diri dari azab-Nya.\qt@no{14}}%
\qt@newcmd\qurantrans@id@mmmmmmlviii{%
(Dan tiadalah) dapat dibaca Walaa dan Falaa (Allah takut terhadap akibat tindakan-Nya itu) maksudnya akibat azab yang akan terjadi.\qt@no{15}}%
\qt@newcmd\qurantrans@id@mmmmmmlix{%
\basmalahid (Demi malam apabila menutupi) semua apa yang ada di langit dan di bumi dengan kegelapannya.\qt@no{1}}%
\qt@newcmd\qurantrans@id@mmmmmmlx{%
(Dan siang apabila terang benderang) apabila menampilkan dirinya. Lafal Idzaa yang ada pada dua tempat di atas hanya menunjukkan makna Zharaf atau waktu. Sedangkan yang menjadi Amilnya adalah Fi'il Qasam.\qt@no{2}}%
\qt@newcmd\qurantrans@id@mmmmmmlxi{%
(Dan apa) lafal Maa di sini bermakna Man, yakni manusia; atau dianggap sebagai Maa Mashdariyah (yang Dia telah menciptakannya, yaitu laki-laki dan perempuan) yang dimaksud adalah Adam dan Hawa, demikian pula setiap laki-laki dan perempuan lainnya. Adapun banci/wadam yang tidak dapat diketahui apakah ia sebagai laki-laki atau perempuan di sisi Allah swt., maka jika seseorang yang bersumpah bahwa dia tidak akan berbicara dengan siapa pun baik laki-laki atau perempuan, lalu dia berbicara dengan orang banci, maka dia dianggap telah melanggar sumpahnya itu.\qt@no{3}}%
\qt@newcmd\qurantrans@id@mmmmmmlxii{%
(Sesungguhnya usaha kalian) atau kerja kalian (memang berbeda-beda) beraneka macam; ada orang yang beramal atau bekerja untuk mendapatkan surga, dengan cara menempuh jalan ketaatan; dan ada pula orang yang beramal atau bekerja untuk neraka, dengan cara menempuh jalan kemaksiatan.\qt@no{4}}%
\qt@newcmd\qurantrans@id@mmmmmmlxiii{%
(Adapun orang yang memberikan) menginfakkan hartanya di jalan Allah (dan bertakwa) kepada Allah.\qt@no{5}}%
\qt@newcmd\qurantrans@id@mmmmmmlxiv{%
(Dan membenarkan perkara yang baik) yaitu makna yang terkandung di dalam lafal Laa Ilaaha Illallaah yang artinya tiada Tuhan selain Allah. Dengan kata lain, bahwa infak di jalan Allah yang dilakukannya dan bertakwa kepada-Nya yang dijalankannya itu tiada lain berangkat dari keimanannya kepada kalimat Laa Ilaaha Illallaah.\qt@no{6}}%
\qt@newcmd\qurantrans@id@mmmmmmlxv{%
(Maka Kami kelak akan menyiapkan baginya tempat yang mudah) yaitu surga.\qt@no{7}}%
\qt@newcmd\qurantrans@id@mmmmmmlxvi{%
(Dan adapun orang yang bakhil) tidak mau menginfakkan hartanya di jalan Allah (dan merasa dirinya cukup) artinya tidak membutuhkan pahala-Nya.\qt@no{8}}%
\qt@newcmd\qurantrans@id@mmmmmmlxvii{%
(Serta mendustakan perkara yang baik.)\qt@no{9}}%
\qt@newcmd\qurantrans@id@mmmmmmlxviii{%
(Maka kelak Kami akan menyiapkan baginya) menyediakan baginya (tempat yang sukar) yaitu neraka.\qt@no{10}}%
\qt@newcmd\qurantrans@id@mmmmmmlxix{%
(Dan tiadalah) huruf Maa di sini bermakna Nafi yakni tidaklah (berguna bagi dirinya harta miliknya apabila ia telah terjerumus) ke dalam neraka.\qt@no{11}}%
\qt@newcmd\qurantrans@id@mmmmmmlxx{%
(Sesungguhnya kewajiban Kamilah memberi petunjuk) untuk membedakan antara jalan hidayah dan jalan kesesatan; dimaksud supaya ia mengerjakan perintah Kami dengan menempuh jalan yang pertama, dan ia Kami larang dari menempuh jalan yang kedua.\qt@no{12}}%
\qt@newcmd\qurantrans@id@mmmmmmlxxi{%
(Dan sesungguhnya kepunyaan Kamilah akhirat dan dunia) maka barang siapa yang mencari keduanya tanpa meminta kepada Kami berarti dia telah sesat jalan.\qt@no{13}}%
\qt@newcmd\qurantrans@id@mmmmmmlxxii{%
(Maka Kami memperingatkan kalian) maksudnya Kami pertakuti kalian hai penduduk Mekah (dengan neraka yang menyala-nyala) asal kata Talazhzhaa adalah Tatalazhzhaa, kemudian salah satu di antara kedua huruf Ta dibuang, sehingga jadilah Talazhzhaa. Akan tetapi ada juga suatu qiraat yang membaca sesuai dengan huruf asalnya.\qt@no{14}}%
\qt@newcmd\qurantrans@id@mmmmmmlxxiii{%
(Tidak ada yang masuk ke dalamnya) atau memasukinya (kecuali orang yang celaka) sekalipun lafal Al-Asyqaa ini menunjukkan arti yang paling celaka, akan tetapi makna yang dimaksud ialah orang yang celaka.\qt@no{15}}%
\qt@newcmd\qurantrans@id@mmmmmmlxxiv{%
(Yang mendustakan) Nabi saw. (dan berpaling) dari iman. Pengecualian yang terdapat pada ayat sebelum ayat ini merupakan takwil dari makna yang terkandung di dalam ayat lainnya yaitu, firman-Nya, ``dan Dia mengampuni segala dosa yang selain dari (syirik) itu, bagi siapa yang dikehendaki-Nya." (Q.S. An-Nisa, 48) Dengan demikian berarti makna yang dimaksud dengan masuk neraka pada ayat 15 tadi adalah masuk untuk selama-lamanya, yakni untuk menjadi penghuni yang abadi.\qt@no{16}}%
\qt@newcmd\qurantrans@id@mmmmmmlxxv{%
(Dan kelak akan dijauhkan dari neraka itu) dihindarkan daripadanya (orang yang bertakwa) demikian pula lafal Al-Atqaa, sekalipun menunjukkan makna Tafdhil, tetapi makna yang dimaksud adalah At-Taqiyyu, yakni orang yang bertakwa.\qt@no{17}}%
\qt@newcmd\qurantrans@id@mmmmmmlxxvi{%
(Yang menafkahkan hartanya untuk membersihkannya) untuk membersihkannya di sisi Allah swt. seumpamanya dia mengeluarkannya bukan karena ria atau pamer dan gengsi, maka setelah itu harta yang dimilikinya menjadi bersih di sisi-Nya nanti. Ayat ini diturunkan berkenaan dengan Abu Bakar Ash-Shiddiq r.a. yaitu sewaktu ia membeli Bilal yang sedang disiksa oleh majikannya karena beriman. Setelah membelinya lalu langsung memerdekakannya. Pada saat itu juga orang-orang kafir mengatakan, bahwa tiada lain Abu Bakar melakukan hal tersebut karena ia telah berutang jasa kepadanya. Maka pada saat itu turunlah ayat ini.\qt@no{18}}%
\qt@newcmd\qurantrans@id@mmmmmmlxxvii{%
(Padahal tidak ada seseorang pun memberikan suatu nikmat kepadanya yang harus dibalasnya,)\qt@no{19}}%
\qt@newcmd\qurantrans@id@mmmmmmlxxviii{%
(melainkan) tetapi hanya semata-mata (karena mencari keridaan Rabbnya Yang Maha Tinggi) artinya dia memberikan hartanya itu hanya karena mengharapkan pahala Allah.\qt@no{20}}%
\qt@newcmd\qurantrans@id@mmmmmmlxxix{%
(Dan kelak Dia benar-benar mendapat kepuasan) dari pahala pemberiannya itu di surga nanti. Makna ayat ini mencakup pula setiap orang yang mengerjakan amal perbuatan seperti yang telah dilakukan oleh Abu Bakar r.a. Kelak dia akan dijauhkan dari neraka dan mendapatkan pahala yang berlimpah.\qt@no{21}}%
\qt@newcmd\qurantrans@id@mmmmmmlxxx{%
\basmalahid (Demi waktu Dhuha) yakni waktu matahari sepenggalah naik, yaitu di awal siang hari; atau makna yang dimaksud ialah siang hari seluruhnya.\qt@no{1}}%
\qt@newcmd\qurantrans@id@mmmmmmlxxxi{%
(Dan demi malam apabila telah sunyi) telah tenang, atau telah menutupi dengan kegelapannya.\qt@no{2}}%
\qt@newcmd\qurantrans@id@mmmmmmlxxxii{%
(Tiada meninggalkan kamu) tiada membiarkan kamu sendirian, hai Muhammad (Rabbmu, dan tiada pula Dia benci kepadamu) atau tidak senang kepadamu. Ayat ini diturunkan setelah selang beberapa waktu yaitu lima belas hari wahyu tidak turun-turun kepadanya, kemudian orang-orang kafir mengatakan, sesungguhnya Rabb Muhammad telah meninggalkannya dan membencinya.\qt@no{3}}%
\qt@newcmd\qurantrans@id@mmmmmmlxxxiii{%
(Dan sesungguhnya akhir itu lebih baik bagimu) maksudnya kehidupan di akhirat itu lebih baik bagimu, karena di dalamnya terdapat kemuliaan-kemuliaan bagimu (dari permulaan) dari kehidupan duniawi.\qt@no{4}}%
\qt@newcmd\qurantrans@id@mmmmmmlxxxiv{%
(Dan kelak Rabbmu pasti memberimu) di akhirat berupa kebaikan-kebaikan yang berlimpah ruah (lalu kamu menjadi puas) dengan pemberian itu. Maka Rasulullah saw. bersabda, ``Kalau begitu mana mungkin aku puas, sedangkan seseorang di antara umatku masih berada di neraka." Sampai di sini selesailah Jawab Qasam, yaitu dengan kedua kalimat yang dinisbatkan sesudah dua kalimat yang dinafikan.\qt@no{5}}%
\qt@newcmd\qurantrans@id@mmmmmmlxxxv{%
(Bukankah Dia mendapatimu) Istifham atau kata tanya di sini mengandung makna Taqrir atau menetapkan (sebagai seorang yatim) karena ayahmu telah mati meninggalkan kamu sebelum kamu dilahirkan, atau sesudahnya (lalu Dia melindungimu) yaitu dengan cara menyerahkan dirimu ke asuhan pamanmu Abu Thalib.\qt@no{6}}%
\qt@newcmd\qurantrans@id@mmmmmmlxxxvi{%
(Dan Dia mendapatimu sebagai seorang yang bingung) mengenai syariat yang harus kamu jalankan (lalu Dia memberi petunjuk) Dia menunjukimu kepadanya.\qt@no{7}}%
\qt@newcmd\qurantrans@id@mmmmmmlxxxvii{%
(Dan Dia mendapatimu sebagai seorang yang kekurangan) atau orang yang fakir (lalu Dia memberikan kecukupan) kepadamu dengan pemberian yang kamu merasa puas dengannya, yaitu dari ganimah dan dari lain-lainnya. Di dalam sebuah hadis disebutkan, ``Tiadalah kaya itu karena banyaknya harta, tetapi kaya itu adalah kaya jiwa."\qt@no{8}}%
\qt@newcmd\qurantrans@id@mmmmmmlxxxviii{%
(Adapun terhadap anak yatim maka janganlah kamu berlaku sewenang-wenang) dengan cara mengambil hartanya atau lain-lainnya yang menjadi milik anak yatim.\qt@no{9}}%
\qt@newcmd\qurantrans@id@mmmmmmlxxxix{%
(Dan terhadap orang yang minta-minta maka janganlah kamu menghardiknya) membentaknya karena dia miskin.\qt@no{10}}%
\qt@newcmd\qurantrans@id@mmmmmmxc{%
(Dan terhadap nikmat Rabbmu) yang dilimpahkan kepadamu, yaitu berupa kenabian dan nikmat-nikmat lainnya (maka hendaklah kamu menyebut-nyebutnya) yakni mengungkapkannya dengan cara mensyukurinya. Di dalam beberapa Fi'il pada surah ini Dhamir yang kembali kepada Rasulullah saw. tidak disebutkan karena demi memelihara Fawashil atau bunyi huruf di akhir ayat. Seperti lafal Qalaa asalnya Qalaaka; lafal Fa-aawaa asalnya Fa-aawaaka; lafal Fahadaa asalnya Fahadaaka; dan lafal Fa-aghnaa asalnya Fa-aghnaaka\qt@no{11}}%
\qt@newcmd\qurantrans@id@mmmmmmxci{%
\basmalahid (Bukankah Kami telah melapangkan) Istifham atau kata tanya di sini mengandung makna Taqrir atau menetapkan, yakni Kami telah melapangkan (untukmu) hai Muhammad (dadamu?) dengan kenabian dan lain-lainnya.\qt@no{1}}%
\qt@newcmd\qurantrans@id@mmmmmmxcii{%
(Dan Kami telah menghilangkan) telah melenyapkan (darimu dosamu.)\qt@no{2}}%
\qt@newcmd\qurantrans@id@mmmmmmxciii{%
(Yang memberatkan) yang memayahkan (punggungmu) ayat ini maknanya sama dengan ayat lainnya yaitu, firman-Nya, ``.... supaya Allah memberi ampunan kepadamu terhadap dosamu yang telah lalu..." (Q.S. Al-Fath: 2)\qt@no{3}}%
\qt@newcmd\qurantrans@id@mmmmmmxciv{%
(Dan Kami tinggikan bagimu sebutanmu) yakni sebutan namamu sebagai contohnya ialah namamu disebutkan bersama-sama dengan nama-Ku di dalam azan, iqamah, tasyahhud, khotbah dan lain sebagainya.\qt@no{4}}%
\qt@newcmd\qurantrans@id@mmmmmmxcv{%
(Karena sesungguhnya sesudah kesulitan itu) atau kesukaran itu (ada kelapangan) yakni kemudahan.\qt@no{5}}%
\qt@newcmd\qurantrans@id@mmmmmmxcvi{%
(Sesungguhnya sesudah kesulitan itu ada kelapangan) Nabi saw. banyak sekali mengalami kesulitan dan hambatan dari orang-orang kafir, kemudian beliau mendapatkan kelapangan dan kemudahan, yaitu setelah beliau mengalami kemenangan atas mereka.\qt@no{6}}%
\qt@newcmd\qurantrans@id@mmmmmmxcvii{%
(Maka apabila kamu telah selesai) dari salat (bersungguh-sungguhlah kamu) di dalam berdoa.\qt@no{7}}%
\qt@newcmd\qurantrans@id@mmmmmmxcviii{%
(Dan hanya kepada Rabbmulah hendaknya kamu berharap) atau meminta dengan merendahkan diri.\qt@no{8}}%
\qt@newcmd\qurantrans@id@mmmmmmxcix{%
\basmalahid (Demi Tin dan Zaitun) keduanya adalah nama buah, atau dapat juga keduanya diartikan nama dua buah gunung yang menumbuhkan kedua buah tersebut.\qt@no{1}}%
\qt@newcmd\qurantrans@id@mmmmmmc{%
(Dan demi bukit Sinai) nama sebuah bukit tempat sewaktu Allah swt. berfirman kepada Nabi Musa. Arti lafal Siiniina ialah yang diberkahi atau yang baik karena memiliki banyak pohon yang menghasilkan buah.\qt@no{2}}%
\qt@newcmd\qurantrans@id@mmmmmmci{%
(Dan demi kota ini yang aman) yaitu kota Mekah, dinamakan kota aman karena orang-orang yang tinggal di dalamnya merasa aman, baik pada zaman jahiliah maupun di zaman Islam.\qt@no{3}}%
\qt@newcmd\qurantrans@id@mmmmmmcii{%
(Sesungguhnya Kami telah menciptakan manusia) artinya semua manusia (dalam bentuk yang sebaik-baiknya) artinya baik bentuk atau pun penampilannya amatlah baik.\qt@no{4}}%
\qt@newcmd\qurantrans@id@mmmmmmciii{%
(Kemudian Kami kembalikan dia) maksudnya sebagian di antara mereka (ke tempat yang serendah-rendahnya) ungkapan ini merupakan kata kiasan bagi masa tua, karena jika usia telah lanjut kekuatan pun sudah mulai melemah dan pikun. Dengan demikian ia akan berkurang dalam beramal, berbeda dengan sewaktu masih muda; sekalipun demikian dalam hal mendapat pahala ia akan mendapat imbalan yang sama sebagaimana sewaktu ia beramal di kala masih muda, hal ini diungkapkan dalam firman selanjutnya, yaitu:\qt@no{5}}%
\qt@newcmd\qurantrans@id@mmmmmmciv{%
(Kecuali) melainkan (orang-orang yang beriman dan mengerjakan amal saleh; maka bagi mereka pahala yang tiada putus-putusnya) atau pahala yang tak pernah terputus. Di dalam sebuah hadis telah disebutkan, bahwa apabila orang mukmin mencapai usia tua hingga ia tidak mampu lagi untuk mengerjakan amal kebaikan, maka dituliskan baginya pahala amal kebaikan yang biasa ia kerjakan di masa mudanya dahulu.\qt@no{6}}%
\qt@newcmd\qurantrans@id@mmmmmmcv{%
(Maka apakah yang menyebabkan kamu mendustakan) hai orang kafir (sesudah itu) yakni sesudah hal-hal yang telah disebutkan tadi, yaitu mengenai penciptaan manusia dalam bentuk yang sebaik-baiknya, kemudian dijadikan-Nya tua dan pikun, yang hal ini menunjukkan kepada kekuasaan-Nya untuk membangkitkan makhluk hidup kembali (hari pembalasan) yang terlebih dahulu diawali dengan hari kebangkitan lalu perhitungan amal perbuatan. Maksudnya apakah gerangan yang mendorongmu mendustakan hal tersebut? Tentu saja tidak ada yang mendorongnya untuk mendustakan hal tersebut selain dirinya sendiri.\qt@no{7}}%
\qt@newcmd\qurantrans@id@mmmmmmcvi{%
(Bukankah Allah hakim yang seadil-adilnya?) artinya Dia adalah hakim yang paling adil di antara hakim-hakim yang adil lainnya, dan keputusan-Nya berdasarkan sifat tersebut. Di dalam sebuah hadis disebutkan, ``Barang siapa membaca surah At-Tiin hingga akhir surah, maka hendaknya sesudah itu ia menjawab, 'Balaa Wa Anaa 'Alaa Dzaalika Minasy Syaahidiina/tentu saja kami termasuk orang-orang yang menyaksikan akan hal tersebut.'"\qt@no{8}}%
\qt@newcmd\qurantrans@id@mmmmmmcvii{%
\basmalahid (Bacalah) maksudnya mulailah membaca dan memulainya (dengan menyebut nama Rabbmu yang menciptakan) semua makhluk.\qt@no{1}}%
\qt@newcmd\qurantrans@id@mmmmmmcviii{%
(Dia telah menciptakan manusia) atau jenis manusia (dari 'alaq) lafal 'Alaq bentuk jamak dari lafal 'Alaqah, artinya segumpal darah yang kental.\qt@no{2}}%
\qt@newcmd\qurantrans@id@mmmmmmcix{%
(Bacalah) lafal ayat ini mengukuhkan makna lafal pertama yang sama (dan Rabbmulah Yang Paling Pemurah) artinya tiada seorang pun yang dapat menandingi kemurahan-Nya. Lafal ayat ini sebagai Haal dari Dhamir yang terkandung di dalam lafal Iqra'.\qt@no{3}}%
\qt@newcmd\qurantrans@id@mmmmmmcx{%
(Yang mengajar) manusia menulis (dengan qalam) orang pertama yang menulis dengan memakai qalam atau pena ialah Nabi Idris a.s.\qt@no{4}}%
\qt@newcmd\qurantrans@id@mmmmmmcxi{%
(Dia mengajarkan kepada manusia) atau jenis manusia (apa yang tidak diketahuinya) yaitu sebelum Dia mengajarkan kepadanya hidayah, menulis dan berkreasi serta hal-hal lainnya.\qt@no{5}}%
\qt@newcmd\qurantrans@id@mmmmmmcxii{%
(Ketahuilah) artinya memang benar (sesungguhnya manusia benar-benar melampaui batas)\qt@no{6}}%
\qt@newcmd\qurantrans@id@mmmmmmcxiii{%
(karena dia melihat dirinya) sendiri (serba cukup) dengan harta benda yang dimilikinya; ayat ini diturunkan berkenaan dengan sikap Abu Jahal. Dan lafal Ra-aa tidak membutuhkan Maf'ul kedua; dan lafal An Ra-aahu berkedudukan sebagai Maf'ul Lah.\qt@no{7}}%
\qt@newcmd\qurantrans@id@mmmmmmcxiv{%
(Sesungguhnya hanya kepada Rabbmulah) hai Manusia (tempat kembali) yakni kembali kalian nanti, karena itu Dia kelak akan memberi balasan kepada orang yang melampaui batas sesuai dengan dosa-dosa yang telah dilakukannya. Di dalam ungkapan ini terkandung ancaman dan peringatan buat orang yang berlaku melampaui batas.\qt@no{8}}%
\qt@newcmd\qurantrans@id@mmmmmmcxv{%
(Bagaimana pendapatmu) lafal Ara-ayta dan dua lafal lainnya yang sama nanti mengandung makna Ta'ajjub (tentang orang yang melarang) yang dimaksud adalah Abu Jahal.\qt@no{9}}%
\qt@newcmd\qurantrans@id@mmmmmmcxvi{%
(Seorang hamba) yang dimaksud adalah Nabi Muhammad saw. (ketika dia mengerjakan salat.)\qt@no{10}}%
\qt@newcmd\qurantrans@id@mmmmmmcxvii{%
(Bagaimana pendapatmu jika orang yang dilarang itu) (berada di atas kebenaran)\qt@no{11}}%
\qt@newcmd\qurantrans@id@mmmmmmcxviii{%
(Atau) huruf Au di sini menunjukkan makna Taqsim (dia menyuruh bertakwa.)\qt@no{12}}%
\qt@newcmd\qurantrans@id@mmmmmmcxix{%
(Bagaimana pendapatmu jika orang yang melarang itu mendustakannya) yakni mendustakan Nabi saw. (dan berpaling) dari iman?\qt@no{13}}%
\qt@newcmd\qurantrans@id@mmmmmmcxx{%
(Tidakkah dia mengetahui bahwa sesungguhnya Allah melihat) apa yang dilakukannya itu; artinya Dia mengetahuinya, karena itu Dia kelak akan memberi balasan kepadanya dengan balasan yang setimpal. Maka sudah sepatutnya kamu hai orang yang diajak berbicara untuk merasa heran terhadap orang yang melarang itu, karena ia melarang Nabi melakukan salat, padahal orang yang dilarangnya itu berada dalam jalan hidayah dan memerintahkan untuk bertakwa. Yang amat mengherankan lagi ialah bahwa yang melarangnya itu mendustakannya dan berpaling dari iman.\qt@no{14}}%
\qt@newcmd\qurantrans@id@mmmmmmcxxi{%
(Sekali-kali tidaklah demikian) kalimat ini mengandung makna hardikan dan cegahan baginya (sungguh jika) huruf Lam di sini menunjukkan makna qasam atau sumpah (dia tidak berhenti) dari kekafiran yang dilakukannya itu (niscaya Kami akan tarik ubun-ubunnya) atau Kami akan seret dia masuk neraka dengan cara ditarik ubun-ubunnya.\qt@no{15}}%
\qt@newcmd\qurantrans@id@mmmmmmcxxii{%
(Yaitu ubun-ubun) lafal Naashiyatan adalah isim Nakirah yang berkedudukan menjadi Badal dari isim Ma'rifat yaitu lafal An-Naashiyah pada ayat sebelumnya (orang yang mendustakan lagi durhaka) makna yang dimaksud adalah pelakunya; dia disifati demikian secara Majaz.\qt@no{16}}%
\qt@newcmd\qurantrans@id@mmmmmmcxxiii{%
(Maka biarlah dia memanggil golongannya) yakni teman-teman senadinya; Nadi adalah sebuah majelis tempat mereka memusyawarahkan sesuatu perkara. Sesungguhnya orang yang melarang itu mengatakan kepada Nabi saw. sewaktu dia mencegahnya dari melakukan salat, ``Sesungguhnya aku telah mengetahui bahwa tiada seseorang pun di Mekah ini yang lebih banyak teman senadinya daripada aku. Sesungguhnya jika kamu mau meninggalkan salat, aku benar-benar akan memberikan kepadamu, kuda-kuda yang tak berpelana dan laki-laki pelayan sepenuh lembah ini."\qt@no{17}}%
\qt@newcmd\qurantrans@id@mmmmmmcxxiv{%
(Kelak Kami akan memanggil malaikat Zabaniyah) mereka adalah malaikat-malaikat yang terkenal sangat bengis lagi kejam, untuk membinasakannya, sebagaimana yang telah disebutkan di dalam salah satu hadis, yaitu, ``Seandainya dia benar-benar memanggil golongan senadinya, niscaya dia akan diazab oleh malaikat Zabaniyah secara terang-terangan."\qt@no{18}}%
\qt@newcmd\qurantrans@id@mmmmmmcxxv{%
(Sekali-kali tidaklah demikian) kalimat ini mengandung hardikan dan cegahan baginya (janganlah kamu patuhi dia) hai Muhammad untuk meninggalkan salat (dan sujudlah) maksudnya salatlah demi karena Allah (dan mendekatlah) kepada-Nya dengan melalui amal ketaatan.\qt@no{19}}%
\qt@newcmd\qurantrans@id@mmmmmmcxxvi{%
\basmalahid (Sesungguhnya Kami telah menurunkannya) yaitu menurunkan Alquran seluruhnya secara sekali turun dari lohmahfuz hingga ke langit yang paling bawah (pada malam kemuliaan) yaitu malam Lailatulkadar, malam yang penuh dengan kemuliaan dan kebesaran.\qt@no{1}}%
\qt@newcmd\qurantrans@id@mmmmmmcxxvii{%
(Dan tahukah kamu) Hai Muhammad (apakah malam kemuliaan itu?) ungkapan ini sebagai pernyataan takjub atas keagungan yang terdapat pada Lailatulkadar.\qt@no{2}}%
\qt@newcmd\qurantrans@id@mmmmmmcxxviii{%
(Malam kemuliaan itu lebih baik daripada seribu bulan) yang tidak ada malam lailatulkadarnya; beramal saleh pada malam itu pahalanya jauh lebih besar dan lebih baik daripada beramal saleh yang dilakukan selama seribu bulan yang tidak mengandung malam lailatulkadar.\qt@no{3}}%
\qt@newcmd\qurantrans@id@mmmmmmcxxix{%
(Turunlah malaikat-malaikat) bentuk asal dari lafal Tanazzalu adalah Tatanazzalu, kemudian salah satu huruf Ta-nya dibuang, sehingga jadilah Tanazzalu (dan Ar-Ruh) yakni malaikat Jibril (di malam itu) artinya pada malam kemuliaan/lailatulkadar itu (dengan izin Rabbnya) dengan perintah dari-Nya (untuk mengatur segala urusan) atau untuk menjalankan ketetapan Allah buat tahun itu hingga tahun berikutnya, hal ini terjadi pada malam kemuliaan itu. Huruf Min di sini bermakna Sababiyah atau sama artinya dengan huruf Ba; yakni mereka turun dengan seizin Rabbnya dengan membawa segala urusan yang telah menjadi ketetapan-Nya untuk tahun itu hingga tahun berikutnya.\qt@no{4}}%
\qt@newcmd\qurantrans@id@mmmmmmcxxx{%
(Malam itu penuh dengan kesejahteraan) lafal ayat ini sebagai Khabar Muqaddam atau Khabar yang didahulukan, sedangkan Mubtadanya ialah (sampai terbit fajar) dapat dibaca Mathla'al Fajri dan Mathla'il Fajri, artinya hingga waktu fajar. Malam itu dinamakan sebagai malam yang penuh dengan kesejahteraan, karena para malaikat banyak mengucapkan salam, yaitu setiap kali melewati seorang mukmin baik laki-laki maupun perempuan mereka selalu mengucapkan salam kepadanya.\qt@no{5}}%
\qt@newcmd\qurantrans@id@mmmmmmcxxxi{%
\basmalahid (Tiadalah orang-orang yang kafir dari) huruf Min di sini mengandung makna penjelasan (kalangan ahlulkitab dan orang-orang musyrik) orang-orang musyrik artinya orang-orang yang menyembah berhala; lafal Musyrikiina di'athafkan kepada lafal Ahlilkitaabi (mau meninggalkan) agamanya; lafal Munfakkiina sebagai Khabar dari lafal Yakun; artinya mereka akan tetap memegang agama yang mereka peluk (sebelum datang kepada mereka) artinya sampai datang kepada mereka (bukti yang nyata) berupa hujah yang jelas, yang dimaksud adalah Nabi Muhammad saw.\qt@no{1}}%
\qt@newcmd\qurantrans@id@mmmmmmcxxxii{%
(Yaitu seorang rasul dari Allah) lafal ayat ini menjadi Badal dari lafal Al-Bayyinah, yang dimaksud adalah Nabi Muhammad saw. (yang membacakan lembaran-lembaran yang disucikan) dari segala bentuk kebatilan.\qt@no{2}}%
\qt@newcmd\qurantrans@id@mmmmmmcxxxiii{%
(Di dalamnya terdapat kitab-kitab) maksudnya hukum-hukum yang tertulis (yang lurus) artinya hukum-hukum yang lurus. Dia akan membacakan apa yang dikandungnya, yaitu Alquran; di antara mereka ada orang-orang yang beriman kepadanya dan ada pula orang-orang yang kafir kepadanya.\qt@no{3}}%
\qt@newcmd\qurantrans@id@mmmmmmcxxxiv{%
(Dan tidaklah berpecah belah orang-orang yang didatangkan Alkitab) kepada mereka sehubungan dengan masalah iman kepada Nabi Muhammad saw. (melainkan sesudah datang kepada mereka bukti yang nyata) yaitu setelah datang kepada mereka Nabi Muhammad saw., atau Alquran yang dibawa olehnya sebagai mukjizat baginya. Sebelum kedatangan Nabi Muhammad saw. mereka adalah orang-orang yang sepakat untuk beriman kepadanya/Nabi Muhammad tetapi setelah Nabi Muhammad saw. datang kepada mereka, tiba-tiba mereka mengingkarinya, terutama orang-orang yang dengki dari kalangan mereka.\qt@no{4}}%
\qt@newcmd\qurantrans@id@mmmmmmcxxxv{%
(Padahal mereka tidak disuruh) di dalam kitab-kitab mereka yaitu Taurat dan Injil (kecuali menyembah Allah) kecuali supaya menyembah Allah, pada asalnya adalah An Ya'budullaaha, lalu huruf An dibuang dan ditambahkan huruf Lam sehingga jadilah Liya'budullaaha (dengan memurnikan ketaatan kepada-Nya dalam beragama) artinya membersihkannya dari kemusyrikan (dengan lurus) maksudnya berpegang teguh pada agama Nabi Ibrahim dan agama Nabi Muhammad bila telah datang nanti. Maka mengapa sewaktu ia datang mereka menjadi jadi ingkar kepadanya (dan supaya mereka mendirikan salat dan menunaikan zakat; dan yang demikian itulah agama) atau tuntunan (yang mustaqim) yang lurus.\qt@no{5}}%
\qt@newcmd\qurantrans@id@mmmmmmcxxxvi{%
(Sesungguhnya orang-orang kafir dari ahli kitab dan orang-orang musyrik -dimasukkan- ke dalam neraka Jahanam; mereka kekal di dalamnya) lafal Khaalidiina menjadi Haal atau kata keterangan keadaan dari lafal yang tidak disebutkan; lengkapnya mereka telah dipastikan oleh Allah swt. untuk menjadi penghuni tetap di dalam neraka Jahanam untuk selama-lamanya. (Mereka itu adalah seburuk-buruk makhluk.)\qt@no{6}}%
\qt@newcmd\qurantrans@id@mmmmmmcxxxvii{%
(Sesungguhnya orang-orang yang beriman dan mengerjakan amal saleh mereka itu adalah sebaik-baik makhluk) artinya makhluk yang paling baik.\qt@no{7}}%
\qt@newcmd\qurantrans@id@mmmmmmcxxxviii{%
(Balasan mereka di sisi Rabb mereka ialah surga 'Adn) sebagai tempat tinggal tetap mereka (yang mengalir di bawahnya sungai-sungai; mereka kekal di dalamnya selama-lamanya. Allah rida terhadap mereka) karena ketaatan mereka kepada-Nya (dan mereka pun rida kepada-Nya) yakni merasa puas akan pahala-Nya. (Yang demikian itu adalah balasan bagi orang yang takut kepada Rabbnya) maksudnya takut kepada siksaan-Nya, yang karena itu lalu ia berhenti dari mendurhakai-Nya.\qt@no{8}}%
\qt@newcmd\qurantrans@id@mmmmmmcxxxix{%
\basmalahid (Apabila bumi diguncangkan) yaitu mengalami gempa di saat hari kiamat tiba (dengan guncangannya) yang amat dahsyat sesuai dengan bentuknya yang besar.\qt@no{1}}%
\qt@newcmd\qurantrans@id@mmmmmmcxl{%
(Dan bumi telah mengeluarkan beban-beban beratnya) berupa semua perbendaharaan yang dikandungnya termasuk orang-orang mati, kemudian semuanya itu dicampakkan ke permukaannya.\qt@no{2}}%
\qt@newcmd\qurantrans@id@mmmmmmcxli{%
(Dan manusia bertanya) yakni orang yang ingkar kepada adanya hari berbangkit ("Mengapa bumi jadi begini?") ia mengatakan demikian dengan nada ingkar kepada kenyataan yang sedang mereka alami ketika itu, yaitu keadaan menjelang hari kiamat.\qt@no{3}}%
\qt@newcmd\qurantrans@id@mmmmmmcxlii{%
(Pada hari itu) menjadi Badal dari lafal Idzaa berikut Jawabnya (bumi menceritakan beritanya) yaitu menceritakan semua amal perbuatan yang telah dilakukan di atas permukaannya, amal baik dan amal buruk.\qt@no{4}}%
\qt@newcmd\qurantrans@id@mmmmmmcxliii{%
(Karena sesungguhnya) hal itu terjadi disebabkan karena (Rabbmu telah memerintahkan kepadanya) yang demikian itu. Di dalam sebuah hadis disebutkan, ``Setiap hamba laki-laki dan perempuan menyaksikan (pada hari itu) semua amal perbuatan yang telah dilakukannya di muka bumi."\qt@no{5}}%
\qt@newcmd\qurantrans@id@mmmmmmcxliv{%
(Pada hari itu manusia keluar) maksudnya mereka berangkat meninggalkan tempat penghisaban (dalam keadaan yang bermacam-macam) yakni terpisah-pisah; ada yang mengambil jalan ke kanan yaitu menuju ke surga dan ada yang mengambil jalan ke kiri yaitu menuju ke neraka (supaya diperlihatkan kepada mereka pekerjaan mereka) maksudnya balasan amal perbuatan mereka, berupa surga atau neraka.\qt@no{6}}%
\qt@newcmd\qurantrans@id@mmmmmmcxlv{%
(Maka barang siapa yang mengerjakan seberat zarah) atau seberat semut yang paling kecil (kebaikan, niscaya dia akan melihatnya) melihat pahalanya.\qt@no{7}}%
\qt@newcmd\qurantrans@id@mmmmmmcxlvi{%
(Dan barang siapa yang mengerjakan kejahatan seberat zarah pun, niscaya dia akan melihatnya pula) artinya dia pasti akan merasakan balasannya.\qt@no{8}}%
\qt@newcmd\qurantrans@id@mmmmmmcxlvii{%
\basmalahid (Demi yang berlari kencang) di dalam perang, yaitu kuda yang lari dengan kencangnya di dalam peperangan (dengan terengah-engah) lafal Adh-Dhabhu artinya suara napas kuda sewaktu berlari kencang.\qt@no{1}}%
\qt@newcmd\qurantrans@id@mmmmmmcxlviii{%
(Dan demi yang mencetuskan api) maksudnya kuda yang memercikkan api (dengan pukulan) teracak kakinya apabila ia berlari di tanah yang banyak batunya pada malam hari.\qt@no{2}}%
\qt@newcmd\qurantrans@id@mmmmmmcxlix{%
(Dan demi yang menyerang dengan tiba-tiba di waktu pagi) yaitu kuda yang menyerang musuh di waktu pagi, karena pengendaranya melakukan penyerbuan di waktu tersebut.\qt@no{3}}%
\qt@newcmd\qurantrans@id@mmmmmmcl{%
(Maka ia menerbangkan) atau mengepulkan (di waktu itu) di waktu tersebut, atau di tempat ia berlari (debu) karena gerakannya yang sangat keras.\qt@no{4}}%
\qt@newcmd\qurantrans@id@mmmmmmcli{%
(Dan menyerbu dalam kepulan debu ke tengah-tengah) artinya dengan membawa kepulan debu (kumpulan musuh) yang diserangnya; maksudnya kuda-kuda tersebut berada di tengah-tengah musuh dalam keadaan menyerang. Lafal Fawasathna yang kedudukannya sebagai Fi'il di'athafkan kepada Isim, karena mengingat bahwa semua Isim yang di'athafkan kepadanya mengandung makna Fi'il pula. Yakni demi yang berlari kencang, lalu mencetuskan api, lalu menerbangkan debu.\qt@no{5}}%
\qt@newcmd\qurantrans@id@mmmmmmclii{%
(Sesungguhnya manusia itu) yang dimaksud adalah manusia yang kafir (sangat ingkar kepada Rabbnya) artinya ia mengingkari semua nikmat-Nya yang telah dilimpahkan kepadanya.\qt@no{6}}%
\qt@newcmd\qurantrans@id@mmmmmmcliii{%
(Dan sesungguhnya manusia itu terhadap hal tersebut) terhadap keingkarannya (menyaksikan sendiri) atau dia menyaksikan bahwa dirinya telah berbuat ingkar.\qt@no{7}}%
\qt@newcmd\qurantrans@id@mmmmmmcliv{%
(Dan sesungguhnya karena cintanya kepada kebaikan) maksudnya cinta atas harta benda (dia sangat bakhil) artinya lantaran sangat mencintai harta, jadilah ia seorang yang amat bakhil atau kikir.\qt@no{8}}%
\qt@newcmd\qurantrans@id@mmmmmmclv{%
(Maka apakah dia tidak mengetahui apabila dibangkitkan) dibangunkan dan dikeluarkan (apa yang ada dalam kubur) yakni orang-orang mati yang dikubur di dalamnya.\qt@no{9}}%
\qt@newcmd\qurantrans@id@mmmmmmclvi{%
(Dan dilahirkan) atau ditampakkan dan dikeluarkan (apa yang ada dalam dada) maksudnya, apa yang tersimpan di dalam kalbu berupa kekafiran dan keimanan.\qt@no{10}}%
\qt@newcmd\qurantrans@id@mmmmmmclvii{%
(Sesungguhnya Rabb mereka pada hari itu Maha Mengetahui keadaan mereka) karena itu Dia akan memberikan balasan kepada mereka atas kekafiran mereka. Di sini Dhamir diulangi penyebutannya dalam bentuk jamak, hal ini tiada lain karena memandang segi makna yang dikandung lafal Al-Insaan. Jumlah ayat ini menunjukkan pengertian Maf'ul bagi lafal Ya'lamu; artinya sesungguhnya Kami akan memberikan balasan kepadanya pada saat itu. Berta'alluqnya lafal Khabiirun kepada lafal Yaumaidzin memberikan pengertian, bahwa hari itu adalah hari pembalasan, karena sesungguhnya Allah selama-lamanya Maha Mengetahui.\qt@no{11}}%
\qt@newcmd\qurantrans@id@mmmmmmclviii{%
\basmalahid (Hari kiamat) dinamakan Al-Qaari'ah karena kengerian-kengerian yang terjadi di dalamnya sangat menggentarkan kalbu.\qt@no{1}}%
\qt@newcmd\qurantrans@id@mmmmmmclix{%
(Apakah hari kiamat itu?) ungkapan ini menggambarkan tentang kengeriannya; ayat yang pertama dan ayat yang kedua merupakan Mubtada dan Khabarnya.\qt@no{2}}%
\qt@newcmd\qurantrans@id@mmmmmmclx{%
(Tahukah kamu) atau apakah kamu tahu (apakah hari kiamat itu?) ungkapan ayat ini menambah kengerian yang terdapat di hari kiamat. Lafal Maa yang pertama adalah Mubtada sedangkan lafal sesudahnya yaitu lafal Adraaka merupakan Khabarnya; dan Maa yang kedua berikut Khabarnya berkedudukan sebagai Maf'ul kedua dari lafal Adraa.\qt@no{3}}%
\qt@newcmd\qurantrans@id@mmmmmmclxi{%
(Pada hari itu) dinashabkan oleh lafal yang disimpulkan dari pengertian yang terkandung di dalam lafal Al-Qaari'ah yakni lafal Taqra'u, artinya pada hari yang menggentarkan itu (manusia adalah seperti anai-anai yang dihambur-hamburkan) atau seakan-akan belalang-belalang yang dihambur-hamburkan; sebagian di antaranya terbang beriring-iringan dengan yang lainnya secara semrawut. Demikian itu karena mereka dalam keadaan kebingungan, hal ini terus berlangsung hingga mereka dipanggil untuk menjalani perhitungan amal perbuatan.\qt@no{4}}%
\qt@newcmd\qurantrans@id@mmmmmmclxii{%
(Dan gunung-gunung adalah seperti bulu yang dihambur-hamburkan) atau bagaikan wool yang terhambur-hamburkan, karena ringannya, sehingga jatuh kembali rata dengan tanah.\qt@no{5}}%
\qt@newcmd\qurantrans@id@mmmmmmclxiii{%
(Dan adapun orang yang berat timbangannya) artinya amal kebaikannya lebih berat daripada amal keburukannya.\qt@no{6}}%
\qt@newcmd\qurantrans@id@mmmmmmclxiv{%
(Maka dia berada dalam kehidupan yang memuaskan) yaitu berada di dalam surga; atau dengan kata lain kehidupan yang diterimanya itu sangat memuaskannya.\qt@no{7}}%
\qt@newcmd\qurantrans@id@mmmmmmclxv{%
(Dan adapun orang yang ringan timbangannya) artinya amal keburukannya lebih berat daripada amal kebaikannya.\qt@no{8}}%
\qt@newcmd\qurantrans@id@mmmmmmclxvi{%
(Maka tempat kembalinya) yaitu tempat tinggalnya (adalah neraka Haawiyah.)\qt@no{9}}%
\qt@newcmd\qurantrans@id@mmmmmmclxvii{%
(Dan tahukah kamu, apakah Haawiyah itu?) atau apakah neraka Haawiyah itu?\qt@no{10}}%
\qt@newcmd\qurantrans@id@mmmmmmclxviii{%
Neraka Haawiyah itu adalah (api yang sangat panas) yang panasnya luar biasa; huruf Ha yang terdapat pada lafal Hiyah adalah Ha Sakat, baik dalam keadaan Washal ataupun Waqaf tetap dibaca. Tetapi menurut suatu qiraat tidak dibaca bila dalam keadaan Washal.\qt@no{11}}%
\qt@newcmd\qurantrans@id@mmmmmmclxix{%
\basmalahid (Telah membuat kalian lalai) atau telah melalaikan kalian dari taat kepada Allah (bermegah-megahan) yaitu saling bangga-membanggakan harta, anak-anak dan pembantu-pembantu.\qt@no{1}}%
\qt@newcmd\qurantrans@id@mmmmmmclxx{%
(Sampai kalian masuk ke dalam kubur) hingga kalian mati dikubur di dalam tanah; atau hingga kalian menghitung-hitung banyaknya orang yang telah mati.\qt@no{2}}%
\qt@newcmd\qurantrans@id@mmmmmmclxxi{%
(Janganlah begitu) kalimat ini mengandung hardikan dan cegahan (kelak kalian akan mengetahui.)\qt@no{3}}%
\qt@newcmd\qurantrans@id@mmmmmmclxxii{%
(Dan janganlah begitu, kelak kalian akan mengetahui) akibat buruk dari perbuatan kalian itu di kala kalian menjelang kematian, kemudian sewaktu kalian telah berada di dalam kubur.\qt@no{4}}%
\qt@newcmd\qurantrans@id@mmmmmmclxxiii{%
(Janganlah begitu) sesungguhnya (jika kalian mengetahui dengan pengetahuan yang yakin) tentang akibat perbuatan kalian itu, niscaya kalian tidak akan lalai taat kepada Allah.\qt@no{5}}%
\qt@newcmd\qurantrans@id@mmmmmmclxxiv{%
(Niscaya kalian benar-benar akan melihat neraka Jahim) Jawab Qasamnya tidak disebutkan, yaitu niscaya kalian tidak akan sibuk dengan bermegah-megahan yang melalaikan kalian dari taat kepada Allah. Lafal Latarawunna pada asalnya adalah Latarawunanna, kemudian Lam Fi'il dan 'Ain Fi'ilnya dibuang, kemudian harakatnya diberikan kepada Wau, sehingga jadilah Latarawunna.\qt@no{6}}%
\qt@newcmd\qurantrans@id@mmmmmmclxxv{%
(Dan sesungguhnya kalian benar-benar akan melihatnya) kalimat ayat ini mengukuhkan makna ayat sebelumnya (dengan pengetahuan yang yakin) lafal 'Ainal Yaqiin adalah Mashdar; demikian itu karena lafal Ra-aa dan lafal 'Aayana mempunyai arti yang sama.\qt@no{7}}%
\qt@newcmd\qurantrans@id@mmmmmmclxxvi{%
(Kemudian kalian pasti akan ditanyai) lafal Latus-alunna dibuang daripadanya Nun alamat Rafa' karena berturut-turutnya huruf Nun, dibuang pula daripadanya Wawu dhamir jamak, tetapi bukan karena 'Illat atau sebab bertemunya kedua huruf yang disukunkan; bentuk asal daripada Latus-alunna adalah Latus-aluunanna (pada hari itu) yakni di hari kalian melihat neraka Jahim (tentang kenikmatan) yang kalian peroleh semasa di dunia, yaitu berupa kesehatan, waktu luang, keamanan, makanan, minuman dan nikmat-nikmat lainnya. Artinya dipergunakan untuk apakah kenikmatan itu?\qt@no{8}}%
\qt@newcmd\qurantrans@id@mmmmmmclxxvii{%
\basmalahid (Demi masa) atau zaman atau waktu yang dimulai dari tergelincirnya matahari hingga terbenamnya; maksudnya adalah waktu salat Asar.\qt@no{1}}%
\qt@newcmd\qurantrans@id@mmmmmmclxxviii{%
(Sesungguhnya manusia itu) yang dimaksud adalah jenis manusia (benar-benar berada dalam kerugian) di dalam perniagaannya.\qt@no{2}}%
\qt@newcmd\qurantrans@id@mmmmmmclxxix{%
(Kecuali orang-orang yang beriman dan mengerjakan amal saleh) mereka tidak termasuk orang-orang yang merugi di dalam perniagaannya (dan nasihat-menasihati) artinya sebagian di antara mereka menasihati sebagian yang lainnya (supaya menaati kebenaran) yaitu iman (dan nasihat-menasihati dengan kesabaran) yaitu di dalam menjalankan amal ketaatan dan menjauhi kemaksiatan.\qt@no{3}}%
\qt@newcmd\qurantrans@id@mmmmmmclxxx{%
\basmalahid (Kecelakaanlah) lafal Al-Wail ini adalah kalimat kutukan, atau nama sebuah lembah di neraka Jahanam (bagi setiap pengumpat lagi pencela) artinya yang banyak mengumpat dan banyak mencela. Ayat ini diturunkan berkenaan dengan orang-orang yang suka mengumpat Nabi saw. dan orang-orang mukmin, seperti Umaiyah bin Khalaf, Walid bin Mughirah dan lain-lainnya.\qt@no{1}}%
\qt@newcmd\qurantrans@id@mmmmmmclxxxi{%
(Yang mengumpulkan) dapat dibaca Jama'a dan Jamma'a (harta dan menghitung-hitungnya) dan menjadikannya sebagai bekal untuk menghadapi bencana dan malapetaka.\qt@no{2}}%
\qt@newcmd\qurantrans@id@mmmmmmclxxxii{%
(Dia menduga) karena kebodohannya (bahwa hartanya itu dapat mengekalkannya) dapat menjadikannya hidup kekal dan tidak mati.\qt@no{3}}%
\qt@newcmd\qurantrans@id@mmmmmmclxxxiii{%
(Sekali-kali tidak!) kalimat ini mengandung makna sanggahan. (Sesungguhnya dia benar-benar akan dilemparkan) menjadi Jawab Qasam dari lafal yang tidak disebutkan; artinya sesungguhnya dia benar-benar akan dicampakkan (ke dalam Huthamah) dan segala sesuatu yang dimasukkan ke dalamnya pasti hancur berkeping-keping.\qt@no{4}}%
\qt@newcmd\qurantrans@id@mmmmmmclxxxiv{%
(Dan tahukah kamu) atau apakah kamu mengetahui (apa Huthamah itu?)\qt@no{5}}%
\qt@newcmd\qurantrans@id@mmmmmmclxxxv{%
(Yaitu api -yang disediakan- Allah yang dinyalakan) yang dinyalakan dengan besarnya.\qt@no{6}}%
\qt@newcmd\qurantrans@id@mmmmmmclxxxvi{%
(Yang naik) maksudnya panasnya naik membakar (sampai ke hati) lalu membakarnya; rasa sakit yang diakibatkan api neraka jauh lebih memedihkan daripada api lainnya, karena api neraka sangat lembut dan dapat memasuki pori-pori, lalu membakar hati.\qt@no{7}}%
\qt@newcmd\qurantrans@id@mmmmmmclxxxvii{%
(Sesungguhnya api itu atas mereka) di dalam ayat ini Dhamir dijamakkan karena memandang dari segi makna (ditutup rapat-rapat) dapat dibaca Mu`shadah dan Muushadah; artinya mereka dibakar dengan api itu dalam keadaan ditutup rapat.\qt@no{8}}%
\qt@newcmd\qurantrans@id@mmmmmmclxxxviii{%
(Pada tiang-tiang) dapat dibaca 'Amadin dan 'Umudin (yang panjang) lafal ini menjadi sifat dari lafal sebelumnya; dengan demikian maka api itu berada dalam tiang-tiang tersebut.\qt@no{9}}%
\qt@newcmd\qurantrans@id@mmmmmmclxxxix{%
\basmalahid (Apakah kamu tidak memperhatikan) Istifham atau kata tanya di sini mengandung makna takjub; artinya sepatutnya kamu merasa takjub (bagaimana Rabbmu telah bertindak terhadap tentara bergajah) orang yang mempunyai gajah itu bernama Mahmud yang disertai oleh teman-temannya, yaitu raja negeri Yaman yang bernama Abrahah berikut tentaranya. Dia telah membangun sebuah gereja di Shan'a dengan tujuan supaya orang-orang berpaling dari menziarahi Mekah dan tidak menziarahinya lagi. Pada suatu hari ada seseorang lelaki dari Kinanah telah membuat kejadian di gereja tersebut, ia melumuri bagian gereja yang dijadikan kiblat dengan kotoran unta dengan maksud menghinanya. Abrahah bersumpah untuk menghancurkan Kakbah. Lalu ia datang ke Mekah bersama tentaranya, beserta gajah-gajah milik Mahmud tadi. Ketika mereka mulai bergerak hendak menghancurkan Kakbah, Allah mengirimkan kepada mereka apa yang dikisahkan-Nya melalui firman selanjutnya yaitu:\qt@no{1}}%
\qt@newcmd\qurantrans@id@mmmmmmcxc{%
(Bukankah Dia menjadikan) telah menjadikan (tipu daya mereka itu) dalam rangka menghancurkan Kakbah (sia-sia) maksudnya hanya menjerumuskan mereka ke dalam kerugian dan kebinasaan.\qt@no{2}}%
\qt@newcmd\qurantrans@id@mmmmmmcxci{%
(Dan Dia mengirimkan kepada mereka burung yang berbondong-bondong) atau yang bergelombang secara berturut-turut. Menurut suatu pendapat bahwa lafal Abaabiil ini tidak ada bentuk Mufradnya, sama halnya dengan lafal Asaathiir. Menurut pendapat yang lain bahwa bentuk tunggalnya adalah Abuul atau Ibaal atau Ibbiil yang wazannya sama dengan 'Ajuul, Miftaah dan Sikkiin.\qt@no{3}}%
\qt@newcmd\qurantrans@id@mmmmmmcxcii{%
(Yang melempar mereka dengan batu berasal dari tanah yang terbakar) yakni tanah liat yang dibakar.\qt@no{4}}%
\qt@newcmd\qurantrans@id@mmmmmmcxciii{%
(Lalu Dia menjadikan mereka seperti daun-daun yang dimakan) atau bagaikan daun tanaman yang dimakan oleh ternak, kemudian diinjak-injak dan dicabik-cabiknya. Allah telah membinasakan setiap orang dari mereka dengan batu yang padanya telah tertulis nama orang yang dikenainya. Setiap batu bentuknya lebih besar sedikit daripada biji 'adasah dan agak kecil daripada biji kacang Humsh; batu itu dapat menembus topi baja tentara yang berjalan kaki dan gajah yang dibawanya, kemudian batu itu jatuh ke tanah setelah menembus badan mereka. Hal tersebut terjadi pada tahun kelahiran Nabi saw.\qt@no{5}}%
\qt@newcmd\qurantrans@id@mmmmmmcxciv{%
\basmalahid (Karena kebiasaan orang-orang Quraisy.)\qt@no{1}}%
\qt@newcmd\qurantrans@id@mmmmmmcxcv{%
(Yaitu kebiasaan mereka) lafal ini mengukuhkan makna lafal sebelumnya (bepergian pada musim dingin) ke negeri Yaman (dan musim panas) ke negeri Syam dalam setiap tahunnya; mereka bepergian dengan tujuan untuk berniaga yang keuntungannya mereka gunakan untuk keperluan hidup mereka di Mekah dan untuk berkhidmat kepada Baitullah yang merupakan kebanggaan mereka; mereka yang melakukan demikian adalah anak-anak An-Nadhr bin Kinanah.\qt@no{2}}%
\qt@newcmd\qurantrans@id@mmmmmmcxcvi{%
(Maka hendaklah mereka menyembah) lafal ini menjadi ta'alluq atau tempat bergantung bagi lafal Li-iilaafi; sedangkan huruf Fa adalah huruf Zaidah (Rabb rumah ini.)\qt@no{3}}%
\qt@newcmd\qurantrans@id@mmmmmmcxcvii{%
(Yang telah memberi makanan kepada mereka untuk menghilangkan lapar) agar mereka tidak kelaparan (dan mengamankan mereka dari ketakutan) artinya supaya mereka tidak merasa takut lagi. Sesungguhnya mereka sering mengalami kelaparan, karena di Mekah tidak terdapat lahan pertanian, sebagaimana mereka pun pernah dicekam oleh rasa takut, yaitu ketika tentara bergajah datang kepada mereka dengan maksud untuk menghancurkan Kakbah.\qt@no{4}}%
\qt@newcmd\qurantrans@id@mmmmmmcxcviii{%
\basmalahid (Tahukah kamu orang yang mendustakan hari pembalasan?) atau adanya hari hisab dan hari pembalasan amal perbuatan. Maksudnya apakah kamu mengetahui orang itu? Jika kamu belum mengetahui:\qt@no{1}}%
\qt@newcmd\qurantrans@id@mmmmmmcxcix{%
(Maka dia itulah) sesudah huruf Fa ditetapkan adanya lafal Huwa, artinya maka dia itulah (orang yang menghardik anak yatim) yakni menolaknya dengan keras dan tidak mau memberikan hak yang seharusnya ia terima.\qt@no{2}}%
\qt@newcmd\qurantrans@id@mmmmmmcc{%
(Dan tidak menganjurkan) dirinya atau orang lain (memberi makan orang miskin) ayat ini diturunkan berkenaan dengan orang yang bersikap demikian, yaitu Al-'Ash bin Wail atau Walid bin Mughirah.\qt@no{3}}%
\qt@newcmd\qurantrans@id@mmmmmmcci{%
(Maka kecelakaanlah bagi orang-orang yang salat.)\qt@no{4}}%
\qt@newcmd\qurantrans@id@mmmmmmccii{%
(Yaitu orang-orang yang lalai dari salatnya) artinya mengakhirkan salat dari waktunya.\qt@no{5}}%
\qt@newcmd\qurantrans@id@mmmmmmcciii{%
(orang-orang yang berbuat ria) di dalam salatnya atau dalam hal-hal lainnya.\qt@no{6}}%
\qt@newcmd\qurantrans@id@mmmmmmcciv{%
(Dan enggan menolong dengan barang yang berguna) artinya tidak mau meminjamkan barang-barang miliknya yang diperlukan orang lain; apalagi memberikannya, seperti jarum, kapak, kuali, mangkok dan sebagainya.\qt@no{7}}%
\qt@newcmd\qurantrans@id@mmmmmmccv{%
\basmalahid (Sesungguhnya Kami telah memberikan kepadamu) hai Muhammad (Al-Kautsar) merupakan sebuah sungai di surga dan telaga milik Nabi saw. kelak akan menjadi tempat minum bagi umatnya. Al-Kautsar juga berarti kebaikan yang banyak, yaitu berupa kenabian, Alquran, syafaat dan lain sebagainya.\qt@no{1}}%
\qt@newcmd\qurantrans@id@mmmmmmccvi{%
(Maka dirikanlah salat karena Rabbmu) yaitu salat Hari Raya Kurban (dan berkurbanlah) untuk manasik hajimu.\qt@no{2}}%
\qt@newcmd\qurantrans@id@mmmmmmccvii{%
(Sesungguhnya orang-orang yang membenci kamu) yakni orang-orang yang tidak menyukai kamu (dialah yang terputus) terputus dari semua kebaikan; atau putus keturunannya. Ayat ini diturunkan berkenaan dengan orang yang bersikap demikian, dia adalah 'Ash bin Wail, sewaktu Nabi saw. ditinggal wafat putranya yang bernama Qasim, lalu 'Ash menjuluki Nabi sebagai Abtar yakni orang yang terputus keturunannya.\qt@no{3}}%
\qt@newcmd\qurantrans@id@mmmmmmccviii{%
\basmalahid (Katakanlah, ``Hai orang-orang kafir!)\qt@no{1}}%
\qt@newcmd\qurantrans@id@mmmmmmccix{%
(Aku tidak akan menyembah) maksudnya sekarang aku tidak akan menyembah (apa yang kalian sembah) yakni berhala-berhala yang kalian sembah itu.\qt@no{2}}%
\qt@newcmd\qurantrans@id@mmmmmmccx{%
(Dan kalian bukan penyembah) dalam waktu sekarang (Tuhan yang aku sembah) yaitu Allah swt. semata.\qt@no{3}}%
\qt@newcmd\qurantrans@id@mmmmmmccxi{%
(Dan aku tidak mau menyembah) di masa mendatang (apa yang kalian sembah.)\qt@no{4}}%
\qt@newcmd\qurantrans@id@mmmmmmccxii{%
(Dan kalian tidak mau pula menyembah) di masa mendatang (Tuhan yang aku sembah) Allah swt. telah mengetahui melalui ilmu-Nya, bahwasanya mereka di masa mendatang pun tidak akan mau beriman. Disebutkannya lafal Maa dengan maksud Allah adalah hanya meninjau dari segi Muqabalahnya. Dengan kata lain, bahwa Maa yang pertama tidaklah sama dengan Maa yang kedua.\qt@no{5}}%
\qt@newcmd\qurantrans@id@mmmmmmccxiii{%
(Untuk kalianlah agama kalian) yaitu agama kemusyrikan (dan untukkulah agamaku") yakni agama Islam. Ayat ini diturunkan sebelum Nabi saw. diperintahkan untuk memerangi mereka. Ya Idhafah yang terdapat pada lafal ini tidak disebutkan oleh ahli qiraat sab'ah, baik dalam keadaan Waqaf atau pun Washal. Akan tetapi Imam Ya'qub menyebutkannya dalam kedua kondisi tersebut.\qt@no{6}}%
\qt@newcmd\qurantrans@id@mmmmmmccxiv{%
\basmalahid (Apabila telah datang pertolongan Allah) kepada Nabi-Nya atas musuh-musuhnya (dan kemenangan) yakni kemenangan atas kota Mekah.\qt@no{1}}%
\qt@newcmd\qurantrans@id@mmmmmmccxv{%
(Dan kamu lihat manusia masuk agama Allah) yaitu agama Islam (dengan berbondong-bondong) atau secara berkelompok, yang pada sebelumnya hanya secara satu persatu. Hal tersebut terjadi sesudah kemenangan atas kota Mekah, lalu orang-orang Arab dari semua kawasan datang kepada Nabi saw. dalam keadaan taat untuk masuk Islam.\qt@no{2}}%
\qt@newcmd\qurantrans@id@mmmmmmccxvi{%
(Maka bertasbihlah dengan memuji Rabbmu) artinya bertasbihlah seraya memuji-Nya (dan mohonlah ampun kepada-Nya. Sesungguhnya Dia adalah Maha Penerima tobat) sesungguhnya Nabi saw. sesudah surah ini diturunkan, beliau selalu memperbanyak bacaan: Subhaanallaah Wa Bihamdihi, Astaghfirullaaha Wa Atuubu Ilaihi, yang artinya: ``Maha Suci Allah dengan segala pujian-Nya, aku memohon ampun kepada Allah dan bertobat kepada-Nya." Dengan turunnya surah ini dapat diketahui bahwa saat ajalnya telah dekat. Peristiwa penaklukan kota Mekah itu terjadi pada bulan Ramadan tahun delapan Hijriah, dan beliau wafat pada bulan Rabiulawal, tahun sepuluh Hijriah.\qt@no{3}}%
\qt@newcmd\qurantrans@id@mmmmmmccxvii{%
\basmalahid (Binasalah) atau merugilah (kedua tangan Abu Lahab) maksudnya diri Abu Lahab; di sini diungkapkan dengan memakai kata-kata kedua tangan sebagai ungkapan Majaz, karena sesungguhnya kebanyakan pekerjaan yang dilakukan oleh manusia itu dikerjakan dengan kedua tangannya; Jumlah kalimat ini mengandung makna doa (dan sesungguhnya dia binasa) artinya dia benar-benar merugi. Kalimat ayat ini adalah kalimat berita; perihalnya sama dengan perkataan mereka: Ahlakahullaahu Waqad Halaka, yang artinya: ``Semoga Allah membinasakannya; dan sungguh dia benar-benar binasa." Ketika Nabi saw. menakut-nakutinya dengan azab, ia berkata, ``Jika apa yang telah dikatakan oleh anak saudaraku itu benar, maka sesungguhnya aku akan menebus diriku dari azab itu dengan harta benda dan anak-anakku." Lalu turunlah ayat selanjutnya, yaitu:\qt@no{1}}%
\qt@newcmd\qurantrans@id@mmmmmmccxviii{%
(Tidaklah berfaedah kepadanya harta benda dan apa yang ia usahakan) maksudnya apa yang telah diusahakannya itu, yakni anak-anaknya. Lafal Aghnaa di sini bermakna Yughnii, artinya tidak akan berfaedah kepadanya harta dan anak-anaknya.\qt@no{2}}%
\qt@newcmd\qurantrans@id@mmmmmmccxix{%
(Kelak dia akan masuk ke dalam api yang bergejolak) yang besar nyalanya; kata-kata ini pun dijadikan pula sebagai julukan namanya, karena ia mempunyai muka yang berbinar-binar memancarkan sinar merah api.\qt@no{3}}%
\qt@newcmd\qurantrans@id@mmmmmmccxx{%
(Dan begitu pula istrinya) lafal ini di'athafkan kepada Dhamir yang terkandung di dalam lafal Yashlaa, hal ini diperbolehkan karena di antara keduanya terdapat pemisah, yaitu Maf'ul dan sifatnya; yang dimaksud adalah Umu Jamil (pembawa) dapat dibaca Hammalaatun dan Hammaalatan (kayu bakar) yaitu duri dan kayu Sa'dan yang banyak durinya, kemudian kayu dan duri itu ia taruh di tengah jalan tempat Nabi saw. lewat.\qt@no{4}}%
\qt@newcmd\qurantrans@id@mmmmmmccxxi{%
(Yang di lehernya) atau pada lehernya (ada tali dari sabut) yakni pintalan dari sabut; Jumlah ayat ini berkedudukan menjadi Haal atau kata keterangan dari lafal Hammaalatal Hathab yang merupakan sifat dari istri Abu Lahab. Atau kalimat ayat ini dapat dianggap sebagai Khabar dari Mubtada yang tidak disebutkan.\qt@no{5}}%
\qt@newcmd\qurantrans@id@mmmmmmccxxii{%
\basmalahid (Katakanlah, ``Dialah Allah Yang Maha Esa") lafal Allah adalah Khabar dari lafal Huwa, sedangkan lafal Ahadun adalah Badal dari lafal Allah, atau Khabar kedua dari lafal Huwa.\qt@no{1}}%
\qt@newcmd\qurantrans@id@mmmmmmccxxiii{%
(Allah adalah Tuhan yang bergantung kepada-Nya segala sesuatu) lafal ayat ini terdiri dari Mubtada dan Khabar; artinya Dia adalah Tuhan yang bergantung kepada-Nya segala sesuatu untuk selama-lamanya.\qt@no{2}}%
\qt@newcmd\qurantrans@id@mmmmmmccxxiv{%
(Dia tiada beranak) karena tiada yang menyamai-Nya (dan tiada pula diperanakkan) karena mustahil hal ini terjadi bagi-Nya.\qt@no{3}}%
\qt@newcmd\qurantrans@id@mmmmmmccxxv{%
(Dan tidak ada seorang pun yang setara dengan Dia) atau yang sebanding dengan-Nya, lafal Lahu berta'alluq kepada lafal Kufuwan. Lafal Lahu ini didahulukan karena dialah yang menjadi subjek penafian; kemudian lafal Ahadun diakhirkan letaknya padahal ia sebagai isim dari lafal Yakun, sedangkan Khabar yang seharusnya berada di akhir mendahuluinya; demikian itu karena demi menjaga Fashilah atau kesamaan bunyi pada akhir ayat.\qt@no{4}}%
\qt@newcmd\qurantrans@id@mmmmmmccxxvi{%
\basmalahid (Katakanlah, ``Aku berlindung kepada Rabb Yang menguasai falaq) atau waktu subuh.\qt@no{1}}%
\qt@newcmd\qurantrans@id@mmmmmmccxxvii{%
(Dari kejahatan apa yang telah diciptakan-Nya) yaitu dari kejahatan makhluk hidup yang berakal dan yang tidak berakal; serta dari kejahatan benda mati seperti racun dan lain sebagainya.\qt@no{2}}%
\qt@newcmd\qurantrans@id@mmmmmmccxxviii{%
(Dan dari kejahatan malam apabila telah gelap gulita) artinya dari kejahatan malam hari apabila telah gelap, dan dari kejahatan waktu purnama apabila telah terbenam.\qt@no{3}}%
\qt@newcmd\qurantrans@id@mmmmmmccxxix{%
(Dan dari kejahatan wanita-wanita tukang sihir yang menghembus) yaitu tukang-tukang sihir wanita yang menghembuskan sihirnya (pada buhul-buhul) yang dibuat pada pintalan, kemudian pintalan yang berbuhul itu ditiup dengan memakai mantera-mantera tanpa ludah. Zamakhsyari mengatakan, sebagaimana yang telah dilakukan oleh anak-anak perempuan Lubaid yang telah disebutkan di atas tadi.\qt@no{4}}%
\qt@newcmd\qurantrans@id@mmmmmmccxxx{%
(Dan dari kejahatan orang yang dengki apabila ia dengki) atau apabila ia menampakkan kedengkiannya lalu berusaha atas kedengkian yang dipendamnya itu, sebagaimana yang telah dikerjakan oleh Lubaid si Yahudi tadi; dia termasuk orang-orang yang dengki terhadap Nabi saw. Ketiga jenis kejahatan yang disebutkan sesudah lafal Maa Khalaq, padahal semuanya itu telah terkandung di dalam maknanya, hal ini tiada lain mengingat kejahatan yang ditimbulkan oleh ketiga perkara tersebut sangat parah.\qt@no{5}}%
\qt@newcmd\qurantrans@id@mmmmmmccxxxi{%
\basmalahid (Katakanlah, ``Aku berlindung kepada Rabb manusia) Yang menciptakan dan Yang memiliki mereka; di sini manusia disebutkan secara khusus sebagai penghormatan buat mereka; dan sekaligus untuk menyesuaikan dengan pengertian Isti'adzah dari kejahatan yang menggoda hati mereka.\qt@no{1}}%
\qt@newcmd\qurantrans@id@mmmmmmccxxxii{%
(Raja manusia.)\qt@no{2}}%
\qt@newcmd\qurantrans@id@mmmmmmccxxxiii{%
(Sesembahan manusia) kedua ayat tersebut berkedudukan sebagai Badal atau sifat, atau 'Athaf Bayan, kemudian Mudhaf Ilaih. Lafal An-Naas disebutkan di dalam kedua ayat ini, dimaksud untuk menambah jelas makna.\qt@no{3}}%
\qt@newcmd\qurantrans@id@mmmmmmccxxxiv{%
(Dari kejahatan bisikan) setan; setan dinamakan bisikan karena kebanyakan godaan yang dilancarkannya itu melalui bisikan (yang biasa bersembunyi) karena setan itu suka bersembunyi dan meninggalkan hati manusia bila hati manusia ingat kepada Allah.\qt@no{4}}%
\qt@newcmd\qurantrans@id@mmmmmmccxxxv{%
(Yang membisikkan kejahatan ke dalam dada manusia) ke dalam kalbu manusia di kala mereka lalai mengingat Allah.\qt@no{5}}%
\qt@newcmd\qurantrans@id@mmmmmmccxxxvi{%
(Dari jin dan manusia") lafal ayat ini menjelaskan pengertian setan yang menggoda itu, yaitu terdiri dari jenis jin dan manusia, sebagaimana yang dijelaskan dalam ayat lainnya, yaitu melalui firman-Nya, ``yaitu setan-setan dari jenis manusia dan dari jenis jin." (Q.S. Al-An'am, 112) Atau lafal Minal Jinnati menjadi Bayan dari lafal Al-Waswaasil Khannaas, sedangkan lafal An-Naas di'athafkan kepada lafal Al-Waswaas. Tetapi pada garis besarnya telah mencakup kejahatan yang dilakukan oleh Lubaid dan anak-anak perempuannya yang telah disebutkan tadi. Pendapat pertama yang mengatakan bahwa di antara yang menggoda hati manusia adalah manusia di samping setan, pendapat tersebut disanggah dengan suatu kenyataan, bahwa yang dapat menggoda hati manusia hanyalah bangsa jin atau setan saja. Sanggahan ini dapat dibantah pula, bahwasanya manusia pun dapat pula menggoda manusia lainnya, yaitu dengan cara yang sesuai dengan keadaan dan kondisi mereka sebagai manusia. Godaan tersebut melalui lahiriah, kemudian merasuk ke dalam kalbu dan menjadi mantap di dalamnya, yaitu melalui cara yang dapat menjurus ke arah itu. --- Wallahu A'lam - Akhirnya hanya Allah sajalah Yang Maha Mengetahui.\qt@no{6}}%
%% End of file `qurantext-idii.translation.def'
